lemma_lex = {
"a-bomb":{"a-bomb","a-bombs"},
"a-horizon":{"a-horizon","a-horizons"},
"aardvark":{"aardvark","aardvarks"},
"aardwolf":{"aardwolf","aardwolves"},
"aarp":{"aarp","aarps"},
"aas":{"aas","aases"},
"ab":{"ab","abs"},
"aba":{"aba","abas"},
"abaca":{"abaca","abacas"},
"abacus":{"abaci","abacus","abacuses"},
"abalone":{"abalone","abalones"},
"abamp":{"abamp","abamps"},
"abampere":{"abampere","abamperes"},
"abandon":{"abandon","abandoned","abandoning","abandons"},
"abandonment":{"abandonment","abandonments"},
"abase":{"abase","abased","abases","abasing"},
"abasement":{"abasement","abasements"},
"abash":{"abash","abashed","abashes","abashing"},
"abashment":{"abashment","abashments"},
"abate":{"abate","abated","abates","abating"},
"abatement":{"abatement","abatements"},
"abatis":{"abatis","abatises"},
"abattis":{"abattis","abattises"},
"abattoir":{"abattoir","abattoirs"},
"abbacy":{"abbacies","abbacy"},
"abbe":{"abbe","abbes"},
"abbess":{"abbess","abbesses"},
"abbey":{"abbey","abbeys"},
"abbot":{"abbot","abbots"},
"abbreviate":{"abbreviate","abbreviated","abbreviates","abbreviating"},
"abbreviation":{"abbreviation","abbreviations"},
"abbreviator":{"abbreviator","abbreviators"},
"abc":{"abc","abcs"},
"abcs":{"abcs","abcses"},
"abdicate":{"abdicate","abdicated","abdicates","abdicating"},
"abdication":{"abdication","abdications"},
"abdomen":{"abdomen","abdomens"},
"abdominocentesis":{"abdominocenteses","abdominocentesis"},
"abdominousness":{"abdominousness","abdominousnesses"},
"abducens":{"abducens","abducenses","abducentes"},
"abducent":{"abducent","abducents"},
"abduct":{"abduct","abducted","abducting","abducts"},
"abductor":{"abductor","abductors"},
"abele":{"abele","abeles"},
"abelmoschus":{"abelmoschus","abelmoschuses"},
"abelmosk":{"abelmosk","abelmosks"},
"aberrance":{"aberrance","aberrances"},
"aberrancy":{"aberrancies","aberrancy"},
"aberration":{"aberration","aberrations"},
"abet":{"abet","abets","abetted","abetting"},
"abetment":{"abetment","abetments"},
"abetter":{"abetter","abetters"},
"abettor":{"abettor","abettors"},
"abeyance":{"abeyance","abeyances"},
"abhenry":{"abhenries","abhenry"},
"abhor":{"abhor","abhorred","abhorring","abhors"},
"abhorrence":{"abhorrence","abhorrences"},
"abidance":{"abidance","abidances"},
"abide":{"abide","abided","abides","abiding","abode"},
"abies":{"abies","abieses"},
"ability":{"abilities","ability"},
"abiogenesis":{"abiogeneses","abiogenesis"},
"abjection":{"abjection","abjections"},
"abjuration":{"abjuration","abjurations"},
"abjure":{"abjure","abjured","abjures","abjuring"},
"ablactation":{"ablactation","ablactations"},
"ablate":{"ablate","ablated","ablating"},
"ablation":{"ablation","ablations"},
"ablative":{"ablative","ablatives"},
"ablaut":{"ablaut","ablauts"},
"able":{"able","abler","ablest"},
"able-bodiedism":{"able-bodiedism","able-bodiedisms"},
"able-bodism":{"able-bodism","able-bodisms"},
"ableism":{"ableism","ableisms"},
"ablism":{"ablism","ablisms"},
"abls":{"abls","ablses"},
"ablution":{"ablution","ablutions"},
"abm":{"abm","abms"},
"abnegate":{"abnegate","abnegated","abnegating"},
"abnegation":{"abnegation","abnegations"},
"abnormalcy":{"abnormalcies","abnormalcy"},
"abnormality":{"abnormalities","abnormality"},
"abnormity":{"abnormities","abnormity"},
"abo":{"abo","abos"},
"abode":{"abode","abodes"},
"aboideau":{"aboideau","aboideaus","aboideaux"},
"aboiteau":{"aboiteau","aboiteaus","aboiteaux"},
"abolish":{"abolish","abolished","abolishes","abolishing"},
"abolishment":{"abolishment","abolishments"},
"abolition":{"abolition","abolitions"},
"abolitionist":{"abolitionist","abolitionists"},
"abomasum":{"abomasa","abomasum","abomasums"},
"abominate":{"abominate","abominated","abominates","abominating"},
"abomination":{"abomination","abominations"},
"abor":{"abor","abors"},
"aboriginal":{"aboriginal","aboriginals"},
"aborigine":{"aborigine","aborigines"},
"abort":{"abort","aborted","aborting"},
"aborticide":{"aborticide","aborticides"},
"abortifacient":{"abortifacient","abortifacients"},
"abortion":{"abortion","abortions"},
"abortus":{"abortus","abortuses"},
"aboulia":{"aboulia","aboulias"},
"abound":{"abound","abounded","abounding","abounds"},
"about-face":{"about-face","about-faced","about-faces","about-facing"},
"about-ship":{"about-ship","about-shipped","about-shipping","about-ships"},
"abradant":{"abradant","abradants"},
"abrade":{"abrade","abraded","abrades","abrading"},
"abrader":{"abrader","abraders"},
"abramis":{"abramis","abramises"},
"abrasion":{"abrasion","abrasions"},
"abrasive":{"abrasive","abrasives"},
"abrasiveness":{"abrasiveness","abrasivenesses"},
"abreact":{"abreact","abreacted","abreacting"},
"abreaction":{"abreaction","abreactions"},
"abridge":{"abridge","abridged","abridges","abridging"},
"abridgement":{"abridgement","abridgements"},
"abridgment":{"abridgment","abridgments"},
"abrocoma":{"abrocoma","abrocomas"},
"abrocome":{"abrocome","abrocomes"},
"abrogate":{"abrogate","abrogated","abrogating"},
"abrogation":{"abrogation","abrogations"},
"abronia":{"abronia","abronias"},
"abruption":{"abruption","abruptions"},
"abruptness":{"abruptness","abruptnesses"},
"abruzzi":{"abruzzi","abruzzis"},
"abscise":{"abscise","abscised","abscising"},
"abscissa":{"abscissa","abscissae","abscissas"},
"abscission":{"abscission","abscissions"},
"abscond":{"abscond","absconded","absconding","absconds"},
"abscondment":{"abscondment","abscondments"},
"absence":{"absence","absences"},
"absinth":{"absinth","absinths"},
"absinthe":{"absinthe","absinthes"},
"absolute":{"absolute","absolutes"},
"absolution":{"absolution","absolutions"},
"absolutism":{"absolutism","absolutisms"},
"absolutize":{"absolutize","absolutized","absolutizing"},
"absolve":{"absolve","absolved","absolves","absolving"},
"absorb":{"absorb","absorbed","absorbing","absorbs"},
"absorbent":{"absorbent","absorbents"},
"absorptance":{"absorptance","absorptances"},
"absorption":{"absorption","absorptions"},
"absorptivity":{"absorptivities","absorptivity"},
"absquatulate":{"absquatulate","absquatulated","absquatulates","absquatulating"},
"abstain":{"abstain","abstained","abstaining","abstains"},
"abstainer":{"abstainer","abstainers"},
"abstention":{"abstention","abstentions"},
"abstinence":{"abstinence","abstinences"},
"abstinent":{"abstinent","abstinents"},
"abstract":{"abstract","abstracted","abstracting","abstracts"},
"abstractedness":{"abstractedness","abstractednesses"},
"abstracter":{"abstracter","abstracters"},
"abstraction":{"abstraction","abstractions"},
"abstractionism":{"abstractionism","abstractionisms"},
"abstractionist":{"abstractionist","abstractionists"},
"abstractor":{"abstractor","abstractors"},
"abstruseness":{"abstruseness","abstrusenesses"},
"abstrusity":{"abstrusities","abstrusity"},
"absurdity":{"absurdities","absurdity"},
"absurdness":{"absurdness","absurdnesses"},
"abudefduf":{"abudefduf","abudefdufs"},
"abulia":{"abulia","abulias"},
"abundance":{"abundance","abundances"},
"abuse":{"abuse","abused","abuses","abusing"},
"abut":{"abut","abuts","abutted","abutting"},
"abutilon":{"abutilon","abutilons"},
"abuttal":{"abuttal","abuttals"},
"aby":{"abought","aby","abye","abyes","abying","abys"},
"abye":{"abought","abye","abying"},
"abysm":{"abysm","abysms"},
"abyss":{"abyss","abysses"},
"abyssinia":{"abyssinia","abyssinias"},
"abyssinian":{"abyssinian","abyssinians"},
"ac":{"ac","acs"},
"acacia":{"acacia","acacias"},
"academe":{"academe","academes"},
"academia":{"academia","academias"},
"academic":{"academic","academics"},
"academician":{"academician","academicians"},
"academicism":{"academicism","academicisms"},
"academism":{"academism","academisms"},
"academy":{"academies","academy"},
"acalypha":{"acalypha","acalyphas"},
"acanthaceae":{"acanthaceae","acanthaceaes"},
"acanthisitta":{"acanthisitta","acanthisittas"},
"acanthisittidae":{"acanthisittidae","acanthisittidaes"},
"acanthocephala":{"acanthocephala","acanthocephalas"},
"acanthocephalan":{"acanthocephalan","acanthocephalans"},
"acanthocereus":{"acanthocereus","acanthocereuses"},
"acanthocybium":{"acanthocybium","acanthocybiums"},
"acanthophis":{"acanthophis","acanthophises"},
"acanthopterygian":{"acanthopterygian","acanthopterygians"},
"acanthopterygii":{"acanthopterygii","acanthopterygiis"},
"acanthoscelides":{"acanthoscelides","acanthoscelideses"},
"acanthuridae":{"acanthuridae","acanthuridaes"},
"acanthurus":{"acanthurus","acanthuruses"},
"acanthus":{"acanthi","acanthus","acanthuses"},
"acapnia":{"acapnia","acapnias"},
"acapulco":{"acapulco","acapulcos"},
"acaracide":{"acaracide","acaracides"},
"acariasis":{"acariases","acariasis","acariasises"},
"acaricide":{"acaricide","acaricides"},
"acaridae":{"acaridae","acaridaes"},
"acaridiasis":{"acaridiases","acaridiasis"},
"acarina":{"acarina","acarinas"},
"acariosis":{"acarioses","acariosis"},
"acarus":{"acari","acarus"},
"acaryote":{"acaryote","acaryotes"},
"accede":{"accede","acceded","accedes","acceding"},
"accelerando":{"accelerando","accelerandos"},
"accelerate":{"accelerate","accelerated","accelerates","accelerating"},
"acceleration":{"acceleration","accelerations"},
"accelerator":{"accelerator","accelerators"},
"accent":{"accent","accented","accenting","accents"},
"accenting":{"accenting","accentings"},
"accentuate":{"accentuate","accentuated","accentuates","accentuating"},
"accentuation":{"accentuation","accentuations"},
"accept":{"accept","accepted","accepting","accepts"},
"acceptability":{"acceptabilities","acceptability"},
"acceptableness":{"acceptableness","acceptablenesses"},
"acceptance":{"acceptance","acceptances"},
"acceptation":{"acceptation","acceptations"},
"access":{"access","accessed","accesses","accessing"},
"accessary":{"accessaries","accessary"},
"accessibility":{"accessibilities","accessibility"},
"accession":{"accession","accessions"},
"accessory":{"accessories","accessory"},
"acciaccatura":{"acciaccatura","acciaccaturas","acciaccature"},
"accidence":{"accidence","accidences"},
"accident":{"accident","accidents"},
"accidental":{"accidental","accidentals"},
"accipiter":{"accipiter","accipiters"},
"accipitridae":{"accipitridae","accipitridaes"},
"accipitriformes":{"accipitriformes","accipitriformeses"},
"acclaim":{"acclaim","acclaimed","acclaiming","acclaims"},
"acclamation":{"acclamation","acclamations"},
"acclimate":{"acclimate","acclimated","acclimates","acclimating"},
"acclimation":{"acclimation","acclimations"},
"acclimatisation":{"acclimatisation","acclimatisations"},
"acclimatization":{"acclimatization","acclimatizations"},
"acclimatize":{"acclimatize","acclimatized","acclimatizes","acclimatizing"},
"acclivity":{"acclivities","acclivity"},
"accolade":{"accolade","accolades"},
"accommodate":{"accommodate","accommodated","accommodates","accommodating"},
"accommodation":{"accommodation","accommodations"},
"accommodator":{"accommodator","accommodators"},
"accompaniment":{"accompaniment","accompaniments"},
"accompanist":{"accompanist","accompanists"},
"accompany":{"accompanied","accompanies","accompany","accompanying"},
"accompanyist":{"accompanyist","accompanyists"},
"accomplice":{"accomplice","accomplices"},
"accomplish":{"accomplish","accomplished","accomplishes","accomplishing"},
"accomplishment":{"accomplishment","accomplishments"},
"accord":{"accord","accorded","according","accords"},
"accordance":{"accordance","accordances"},
"accordion":{"accordion","accordions"},
"accost":{"accost","accosted","accosting","accosts"},
"accouchement":{"accouchement","accouchements"},
"accoucheur":{"accoucheur","accoucheurs"},
"accoucheuse":{"accoucheuse","accoucheuses"},
"account":{"account","accounted","accounting","accounts"},
"accountability":{"accountabilities","accountability"},
"accountancy":{"accountancies","accountancy"},
"accountant":{"accountant","accountants"},
"accounting":{"accounting","accountings"},
"accouter":{"accouter","accoutered","accoutering","accouters"},
"accouterment":{"accouterment","accouterments"},
"accoutrement":{"accoutrement","accoutrements"},
"accra":{"accra","accras"},
"accredit":{"accredit","accredited","accrediting","accredits"},
"accrete":{"accrete","accreted","accreting"},
"accretion":{"accretion","accretions"},
"accroides":{"accroides","accroideses"},
"accrual":{"accrual","accruals"},
"accrue":{"accrue","accrued","accrues","accruing"},
"accruement":{"accruement","accruements"},
"acculturate":{"acculturate","acculturated","acculturating"},
"acculturation":{"acculturation","acculturations"},
"accumulate":{"accumulate","accumulated","accumulates","accumulating"},
"accumulation":{"accumulation","accumulations"},
"accumulator":{"accumulator","accumulators"},
"accuracy":{"accuracies","accuracy"},
"accusal":{"accusal","accusals"},
"accusation":{"accusation","accusations"},
"accusative":{"accusative","accusatives"},
"accuse":{"accuse","accused","accuses","accusing"},
"accused":{"accused","accuseds"},
"accuser":{"accuser","accusers"},
"accustom":{"accustom","accustomed","accustoming","accustoms"},
"ace":{"ace","aced","aces","acing"},
"acebutolol":{"acebutolol","acebutolols"},
"acedia":{"acedia","acedias"},
"acephalia":{"acephalia","acephalias"},
"acephalism":{"acephalism","acephalisms"},
"acephaly":{"acephalies","acephaly"},
"acequia":{"acequia","acequias"},
"acer":{"acer","acers"},
"aceraceae":{"aceraceae","aceraceaes"},
"acerbate":{"acerbate","acerbated","acerbates","acerbating"},
"acerbity":{"acerbities","acerbity"},
"acerola":{"acerola","acerolas"},
"acetabulum":{"acetabula","acetabulum","acetabulums"},
"acetaldol":{"acetaldol","acetaldols"},
"acetamide":{"acetamide","acetamides"},
"acetaminophen":{"acetaminophen","acetaminophens"},
"acetanilid":{"acetanilid","acetanilids"},
"acetanilide":{"acetanilide","acetanilides"},
"acetate":{"acetate","acetates"},
"acetify":{"acetified","acetifies","acetify","acetifying"},
"acetone":{"acetone","acetones"},
"acetonemia":{"acetonemia","acetonemias"},
"acetonuria":{"acetonuria","acetonurias"},
"acetophenetidin":{"acetophenetidin","acetophenetidins"},
"acetphenetidin":{"acetphenetidin","acetphenetidins"},
"acetylene":{"acetylene","acetylenes"},
"achaean":{"achaean","achaeans"},
"achaemenid":{"achaemenid","achaemenidae","achaemenides","achaemenids"},
"achaian":{"achaian","achaians"},
"ache":{"ache","ached","aches","aching"},
"acheron":{"acheron","acherons"},
"acherontia":{"acherontia","acherontias"},
"acheta":{"acheta","achetas"},
"achievability":{"achievabilities","achievability"},
"achieve":{"achieve","achieved","achieves","achieving"},
"achievement":{"achievement","achievements"},
"achiever":{"achiever","achievers"},
"achimenes":{"achimenes","achimeneses"},
"aching":{"aching","achings"},
"achira":{"achira","achiras"},
"achoerodus":{"achoerodus","achoeroduses"},
"achondroplasia":{"achondroplasia","achondroplasias"},
"achras":{"achras","achrases"},
"achromasia":{"achromasia","achromasias"},
"achromatism":{"achromatism","achromatisms"},
"achromycin":{"achromycin","achromycins"},
"achylia":{"achylia","achylias"},
"acicula":{"acicula","aciculae"},
"aciculum":{"acicula","aciculum","aciculums"},
"acid":{"acid","acids"},
"acidify":{"acidified","acidifies","acidify","acidifying"},
"acidity":{"acidities","acidity"},
"acidophil":{"acidophil","acidophils"},
"acidophile":{"acidophile","acidophiles"},
"acidulate":{"acidulate","acidulated","acidulates","acidulating"},
"acidulousness":{"acidulousness","acidulousnesses"},
"acinonyx":{"acinonyx","acinonyxes"},
"acinos":{"acinos","acinoses"},
"acinus":{"acini","acinus"},
"acipenser":{"acipenser","acipensers"},
"acipenseridae":{"acipenseridae","acipenseridaes"},
"ack-ack":{"ack-ack","ack-acks"},
"ackee":{"ackee","ackees"},
"acknowledge":{"acknowledge","acknowledged","acknowledges","acknowledging"},
"acknowledgement":{"acknowledgement","acknowledgements"},
"acknowledgment":{"acknowledgment","acknowledgments"},
"acme":{"acme","acmes"},
"acnidosporidia":{"acnidosporidia","acnidosporidias"},
"acocanthera":{"acocanthera","acocantheras"},
"acokanthera":{"acokanthera","acokantheras"},
"aconitum":{"aconitum","aconitums"},
"acoraceae":{"acoraceae","acoraceaes"},
"acorn":{"acorn","acorns"},
"acorus":{"acorus","acoruses"},
"acouchi":{"acouchi","acouchis"},
"acouchy":{"acouchies","acouchy"},
"acquaint":{"acquaint","acquainted","acquainting","acquaints"},
"acquaintance":{"acquaintance","acquaintances"},
"acquaintanceship":{"acquaintanceship","acquaintanceships"},
"acquiesce":{"acquiesce","acquiesced","acquiesces","acquiescing"},
"acquiescence":{"acquiescence","acquiescences"},
"acquire":{"acquire","acquired","acquires","acquiring"},
"acquirement":{"acquirement","acquirements"},
"acquirer":{"acquirer","acquirers"},
"acquiring":{"acquiring","acquirings"},
"acquisition":{"acquisition","acquisitions"},
"acquit":{"acquit","acquits","acquitted","acquitting"},
"acquittal":{"acquittal","acquittals"},
"acquittance":{"acquittance","acquittances"},
"acrasiomycetes":{"acrasiomycetes","acrasiomyceteses"},
"acre":{"acre","acres"},
"acre-foot":{"acre-feet","acre-foot"},
"acreage":{"acreage","acreages"},
"acres":{"acres","acreses"},
"acridid":{"acridid","acridids"},
"acrididae":{"acrididae","acrididaes"},
"acridity":{"acridities","acridity"},
"acridness":{"acridness","acridnesses"},
"acridotheres":{"acridotheres","acridothereses"},
"acrimony":{"acrimonies","acrimony"},
"acris":{"acris","acrises"},
"acroanaesthesia":{"acroanaesthesia","acroanaesthesias"},
"acroanesthesia":{"acroanesthesia","acroanesthesias"},
"acrobates":{"acrobates","acrobateses"},
"acrobatics":{"acrobatics","acrobaticses"},
"acrocarp":{"acrocarp","acrocarps"},
"acrocarpus":{"acrocarpus","acrocarpuses"},
"acrocephalus":{"acrocephalus","acrocephaluses"},
"acrocephaly":{"acrocephalies","acrocephaly"},
"acroclinium":{"acroclinium","acrocliniums"},
"acrocomia":{"acrocomia","acrocomias"},
"acrocyanosis":{"acrocyanoses","acrocyanosis"},
"acrolein":{"acrolein","acroleins"},
"acromegalia":{"acromegalia","acromegalias"},
"acromegaly":{"acromegalies","acromegaly"},
"acromicria":{"acromicria","acromicrias"},
"acromikria":{"acromikria","acromikrias"},
"acromion":{"acromia","acromimia","acromion"},
"acropolis":{"acropolis","acropolises"},
"acropora":{"acropora","acroporas"},
"acrostic":{"acrostic","acrostics"},
"acrostichum":{"acrostichum","acrostichums"},
"acrylate":{"acrylate","acrylates"},
"acrylic":{"acrylic","acrylics"},
"acrylonitrile":{"acrylonitrile","acrylonitriles"},
"act":{"act","acted","acting","acts"},
"actaea":{"actaea","actaeas"},
"acth":{"acth","acths"},
"actias":{"actias","actiases"},
"actinaria":{"actinaria","actinarias"},
"acting":{"acting","actings"},
"actinia":{"actinia","actinias"},
"actinian":{"actinian","actinians"},
"actiniaria":{"actiniaria","actiniarias"},
"actiniarian":{"actiniarian","actiniarians"},
"actinidia":{"actinidia","actinidias"},
"actinidiaceae":{"actinidiaceae","actinidiaceaes"},
"actiniopteris":{"actiniopteris","actiniopterises"},
"actinium":{"actinium","actiniums"},
"actinomeris":{"actinomeris","actinomerises"},
"actinomycetacaea":{"actinomycetacaea","actinomycetacaeas"},
"actinomycetales":{"actinomycetales","actinomycetaleses"},
"actinomyxidia":{"actinomyxidia","actinomyxidias"},
"actinopoda":{"actinopoda","actinopodas"},
"actinotherapy":{"actinotherapies","actinotherapy"},
"actinozoa":{"actinozoa","actinozoas"},
"actinozoan":{"actinozoan","actinozoans"},
"action":{"action","actions"},
"actitis":{"actitis","actitises"},
"activase":{"activase","activases"},
"activate":{"activate","activated","activates","activating"},
"activating":{"activating","activatings"},
"activation":{"activation","activations"},
"activator":{"activator","activators"},
"active":{"active","actives"},
"activeness":{"activeness","activenesses"},
"activist":{"activist","activists"},
"activity":{"activities","activity"},
"activize":{"activize","activized","activizing"},
"actor":{"actor","actors"},
"actress":{"actress","actresses"},
"acts":{"acts","actses"},
"actualisation":{"actualisation","actualisations"},
"actuality":{"actualities","actuality"},
"actualization":{"actualization","actualizations"},
"actualize":{"actualize","actualized","actualizes","actualizing"},
"actuary":{"actuaries","actuary"},
"actuate":{"actuate","actuated","actuates","actuating"},
"actuation":{"actuation","actuations"},
"acuity":{"acuities","acuity"},
"acular":{"acular","aculars"},
"acumen":{"acumen","acumens"},
"acuminate":{"acuminate","acuminated","acuminating","acuminted"},
"acupressure":{"acupressure","acupressures"},
"acupuncture":{"acupuncture","acupunctured","acupunctures","acupuncturing"},
"acute":{"acute","acuter","acutes","acutest"},
"acuteness":{"acuteness","acutenesses"},
"acyclovir":{"acyclovir","acyclovirs"},
"ad":{"ad","ads"},
"ad-lib":{"ad-lib","ad-libbed","ad-libbing","ad-libs"},
"adactylia":{"adactylia","adactylias"},
"adactylism":{"adactylism","adactylisms"},
"adactyly":{"adactylies","adactyly"},
"adage":{"adage","adages"},
"adagio":{"adagio","adagios"},
"adalia":{"adalia","adalias"},
"adam":{"adam","adams"},
"adam-and-eve":{"adam-and-eve","adam-and-eves"},
"adamance":{"adamance","adamances"},
"adamant":{"adamant","adamants"},
"adams":{"adams","adamses"},
"adansonia":{"adansonia","adansonias"},
"adapid":{"adapid","adapids"},
"adapin":{"adapin","adapins"},
"adapt":{"adapt","adapted","adapting","adapts"},
"adaptation":{"adaptation","adaptations"},
"adapter":{"adapter","adapters"},
"adaptor":{"adaptor","adaptors"},
"add":{"add","added","adding","adds"},
"addax":{"addax","addaxes"},
"addendum":{"addenda","addendum","addendums"},
"adder":{"adder","adders"},
"addict":{"addict","addicted","addicting","addicts"},
"addiction":{"addiction","addictions"},
"addition":{"addition","additions"},
"addle":{"addle","addled","addles","addling"},
"addle-head":{"addle-head","addle-heads"},
"address":{"address","addressed","addresses","addressing"},
"addressograph":{"addressograph","addressographs"},
"adduce":{"adduce","adduced","adduces","adducing"},
"adduct":{"adduct","adducted","adducting","adducts"},
"adductor":{"adductor","adductors"},
"ade":{"ade","ades"},
"adelges":{"adelges","adelgeses"},
"adelgidae":{"adelgidae","adelgidaes"},
"adelie":{"adelie","adelies"},
"adenanthera":{"adenanthera","adenantheras"},
"adenectomy":{"adenectomies","adenectomy"},
"adenium":{"adenium","adeniums"},
"adenocarcinoma":{"adenocarcinoma","adenocarcinomas","adenocarcinomata"},
"adenohypophysis":{"adenohypophyses","adenohypophysis"},
"adenoid":{"adenoid","adenoids"},
"adenoidectomy":{"adenoidectomies","adenoidectomy"},
"adenoma":{"adenoma","adenomas","adenomata"},
"adenomyosis":{"adenomyoses","adenomyosis"},
"adenosis":{"adenoses","adenosis"},
"adenota":{"adenota","adenotas"},
"adept":{"adept","adepts"},
"adeptness":{"adeptness","adeptnesses"},
"adequacy":{"adequacies","adequacy"},
"adequateness":{"adequateness","adequatenesses"},
"adermin":{"adermin","adermins"},
"adh":{"adh","adhs"},
"adhere":{"adhere","adhered","adheres","adhering"},
"adherence":{"adherence","adherences"},
"adherent":{"adherent","adherents"},
"adhesion":{"adhesion","adhesions"},
"adhesive":{"adhesive","adhesives"},
"adhesiveness":{"adhesiveness","adhesivenesses"},
"adiantaceae":{"adiantaceae","adiantaceaes"},
"adiantum":{"adiantum","adiantums"},
"adieu":{"adieu","adieus","adieux"},
"adige":{"adige","adiges"},
"adios":{"adios","adioses"},
"adiposeness":{"adiposeness","adiposenesses"},
"adiposis":{"adiposes","adiposis"},
"adiposity":{"adiposities","adiposity"},
"adirondacks":{"adirondacks","adirondackses"},
"adjacency":{"adjacencies","adjacency"},
"adjoin":{"adjoin","adjoined","adjoining","adjoins"},
"adjourn":{"adjourn","adjourned","adjourning","adjourns"},
"adjournment":{"adjournment","adjournments"},
"adjudge":{"adjudge","adjudged","adjudges","adjudging"},
"adjudicate":{"adjudicate","adjudicated","adjudicates","adjudicating"},
"adjunction":{"adjunction","adjunctions"},
"adjuration":{"adjuration","adjurations"},
"adjure":{"adjure","adjured","adjures","adjuring"},
"adjust":{"adjust","adjusted","adjusting","adjusts"},
"adjuster":{"adjuster","adjusters"},
"adjustment":{"adjustment","adjustments"},
"adjustor":{"adjustor","adjustors"},
"adjutancy":{"adjutancies","adjutancy"},
"adjutant":{"adjutant","adjutants"},
"adlumia":{"adlumia","adlumias"},
"adman":{"adman","admen"},
"admeasure":{"admeasure","admeasured","admeasuring"},
"administer":{"administer","administered","administering","administers"},
"administrate":{"administrate","administrated","administrates","administrating"},
"administration":{"administration","administrations"},
"administrator":{"administrator","administrators"},
"administratrix":{"administratrices","administratrix"},
"admirability":{"admirabilities","admirability"},
"admirableness":{"admirableness","admirablenesses"},
"admiral":{"admiral","admirals"},
"admiralty":{"admiralties","admiralty"},
"admiration":{"admiration","admirations"},
"admire":{"admire","admired","admires","admiring"},
"admirer":{"admirer","admirers"},
"admission":{"admission","admissions"},
"admit":{"admit","admits","admitted","admitting"},
"admittance":{"admittance","admittances"},
"admix":{"admix","admixed","admixing","admixt"},
"admixture":{"admixture","admixtures"},
"admonish":{"admonish","admonished","admonishes","admonishing"},
"admonisher":{"admonisher","admonishers"},
"admonishment":{"admonishment","admonishments"},
"admonition":{"admonition","admonitions"},
"adnexa":{"adnexa","adnexas"},
"ado":{"ado","ados"},
"adobe":{"adobe","adobes"},
"adolescent":{"adolescent","adolescents"},
"adonic":{"adonic","adonics"},
"adonis":{"adonis","adonises"},
"adopt":{"adopt","adopted","adopting","adopts"},
"adopter":{"adopter","adopters"},
"adoption":{"adoption","adoptions"},
"adorability":{"adorabilities","adorability"},
"adorableness":{"adorableness","adorablenesses"},
"adoration":{"adoration","adorations"},
"adore":{"adore","adored","adoring"},
"adorer":{"adorer","adorers"},
"adorn":{"adorn","adorned","adorning","adorns"},
"adornment":{"adornment","adornments"},
"adp":{"adp","adps"},
"adps":{"adps","adpses"},
"adrenal":{"adrenal","adrenals"},
"adrenalectomy":{"adrenalectomies","adrenalectomy"},
"adrenalin":{"adrenalin","adrenalins"},
"adrenaline":{"adrenaline","adrenalines"},
"adrenocorticotrophin":{"adrenocorticotrophin","adrenocorticotrophins"},
"adrenocorticotropin":{"adrenocorticotropin","adrenocorticotropins"},
"adrianople":{"adrianople","adrianoples"},
"adrianopolis":{"adrianopolis","adrianopolises"},
"adriatic":{"adriatic","adriatics"},
"adroitness":{"adroitness","adroitnesses"},
"adsorb":{"adsorb","adsorbed","adsorbing"},
"adsorbent":{"adsorbent","adsorbents"},
"adsorption":{"adsorption","adsorptions"},
"adularia":{"adularia","adularias"},
"adulate":{"adulate","adulated","adulating"},
"adulation":{"adulation","adulations"},
"adulator":{"adulator","adulators"},
"adult":{"adult","adults"},
"adulterate":{"adulterate","adulterated","adulterating","aulterated"},
"adulteration":{"adulteration","adulterations"},
"adulterer":{"adulterer","adulterers"},
"adulteress":{"adulteress","adulteresses"},
"adultery":{"adulteries","adultery"},
"adulthood":{"adulthood","adulthoods"},
"adumbrate":{"adumbrate","adumbrated","adumbrates","adumbrating"},
"advance":{"advance","advanced","advances","advancing"},
"advancement":{"advancement","advancements"},
"advantage":{"advantage","advantaged","advantages","advantaging"},
"advantageousness":{"advantageousness","advantageousnesses"},
"advent":{"advent","advents"},
"adventism":{"adventism","adventisms"},
"adventist":{"adventist","adventists"},
"adventitia":{"adventitia","adventitias"},
"adventure":{"adventure","adventured","adventures","adventuring"},
"adventurer":{"adventurer","adventurers"},
"adventurousness":{"adventurousness","adventurousnesses"},
"adverb":{"adverb","adverbs"},
"adversary":{"adversaries","adversary"},
"adversity":{"adversities","adversity"},
"advert":{"advert","adverted","adverting","adverts"},
"advertence":{"advertence","advertences"},
"advertency":{"advertencies","advertency"},
"advertise":{"advertise","advertised","advertises","advertising"},
"advertisement":{"advertisement","advertisements"},
"advertiser":{"advertiser","advertisers"},
"advertising":{"advertising","advertisings"},
"advertize":{"advertize","advertized","advertizes","advertizing"},
"advertizing":{"advertizing","advertizings"},
"advice":{"advice","advices"},
"advil":{"advil","advils"},
"advise":{"advise","advised","advises","advising"},
"advisement":{"advisement","advisements"},
"adviser":{"adviser","advisers"},
"advisor":{"advisor","advisors"},
"advisory":{"advisories","advisory"},
"advocacy":{"advocacies","advocacy"},
"advocate":{"advocate","advocated","advocates","advocating"},
"adygei":{"adygei","adygeis"},
"adyghe":{"adyghe","adyghes"},
"adytum":{"adyta","adytum"},
"adz":{"adz","adzed","adzing","adzs"},
"adze":{"adze","adzes"},
"aec":{"aec","aecs"},
"aecidium":{"aecidia","aecidium"},
"aecium":{"aecia","aecium"},
"aedes":{"aedes","aedeses"},
"aegean":{"aegean","aegeans"},
"aegiceras":{"aegiceras","aegicerases"},
"aegilops":{"aegilops","aegilopses"},
"aegir":{"aegir","aegirs"},
"aegis":{"aegis","aegises"},
"aegospotami":{"aegospotami","aegospotamis"},
"aegospotamos":{"aegospotamos","aegospotamoses"},
"aegypiidae":{"aegypiidae","aegypiidaes"},
"aegypius":{"aegypius","aegypiuses"},
"aengus":{"aengus","aenguses"},
"aeolia":{"aeolia","aeolias"},
"aeolian":{"aeolian","aeolians"},
"aeolic":{"aeolic","aeolics"},
"aeolis":{"aeolis","aeolises"},
"aeon":{"aeon","aeons"},
"aeonium":{"aeonium","aeoniums"},
"aepyceros":{"aepyceros","aepyceroses"},
"aepyornidae":{"aepyornidae","aepyornidaes"},
"aepyorniformes":{"aepyorniformes","aepyorniformeses"},
"aepyornis":{"aepyornis","aepyornises"},
"aerate":{"aerate","aerated","aerates","aerating"},
"aerial":{"aerial","aerials"},
"aerie":{"aerie","aeries"},
"aerify":{"aerified","aerifies","aerify","aerifying"},
"aerobacter":{"aerobacter","aerobacters"},
"aerobatics":{"aerobatics","aerobaticses"},
"aerobe":{"aerobe","aerobes"},
"aerobics":{"aerobics","aerobicses"},
"aerobium":{"aerobia","aerobium"},
"aerodrome":{"aerodrome","aerodromes"},
"aerodynamics":{"aerodynamics","aerodynamicses"},
"aeroembolism":{"aeroembolism","aeroembolisms"},
"aerofoil":{"aerofoil","aerofoils"},
"aerogenerator":{"aerogenerator","aerogenerators"},
"aerogram":{"aerogram","aerograms"},
"aerogramme":{"aerogramme","aerogrammes"},
"aeromechanics":{"aeromechanics","aeromechanicses"},
"aeromedicine":{"aeromedicine","aeromedicines"},
"aeronaut":{"aeronaut","aeronauts"},
"aeronautics":{"aeronautics","aeronauticses"},
"aerophyte":{"aerophyte","aerophytes"},
"aeroplane":{"aeroplane","aeroplanes"},
"aerosol":{"aerosol","aerosols"},
"aery":{"aerier","aeries","aeriest","aery"},
"aesculus":{"aesculus","aesculuses"},
"aesthete":{"aesthete","aesthetes"},
"aesthetic":{"aesthetic","aesthetics"},
"aesthetician":{"aesthetician","aestheticians"},
"aesthetics":{"aesthetics","aestheticses"},
"aestivate":{"aestivate","aestivated","aestivates","aestivating"},
"aestivation":{"aestivation","aestivations"},
"aether":{"aether","aethers"},
"aethionema":{"aethionema","aethionemas"},
"aethusa":{"aethusa","aethusas"},
"aetiologist":{"aetiologist","aetiologists"},
"aetiology":{"aetiologies","aetiology"},
"aetobatus":{"aetobatus","aetobatuses"},
"affability":{"affabilities","affability"},
"affableness":{"affableness","affablenesses"},
"affair":{"affair","affairs"},
"affaire":{"affaire","affaires"},
"affairs":{"affairs","affairses"},
"affect":{"affect","affected","affecting","affects"},
"affectation":{"affectation","affectations"},
"affection":{"affection","affections"},
"affectionateness":{"affectionateness","affectionatenesses"},
"affenpinscher":{"affenpinscher","affenpinschers"},
"affiance":{"affiance","affianced","affiances","affiancing"},
"afficionado":{"afficionado","afficionados"},
"affidavit":{"affidavit","affidavits"},
"affiliate":{"affiliate","affiliated","affiliates","affiliating"},
"affiliation":{"affiliation","affiliations"},
"affinity":{"affinities","affinity"},
"affirm":{"affirm","affirmed","affirming","affirms"},
"affirmation":{"affirmation","affirmations"},
"affirmative":{"affirmative","affirmatives"},
"affix":{"affix","affixed","affixes","affixing"},
"afflict":{"afflict","afflicted","afflicting","afflicts"},
"affliction":{"affliction","afflictions"},
"affluence":{"affluence","affluences"},
"affluent":{"affluent","affluents"},
"afford":{"afford","afforded","affording","affords"},
"afforest":{"afforest","afforested","afforesting","afforests"},
"affray":{"affray","affrays"},
"affricate":{"affricate","affricates"},
"affricative":{"affricative","affricatives"},
"affright":{"affright","affrighted","affrighting","affrights"},
"affront":{"affront","affronted","affronting","affronts"},
"affusion":{"affusion","affusions"},
"afghan":{"afghan","afghans"},
"afghani":{"afghani","afghanis"},
"afghanistani":{"afghanistani","afghanistanis"},
"aficionado":{"aficionado","aficionados"},
"afl-cio":{"afl-cio","afl-cios"},
"aflaxen":{"aflaxen","aflaxens"},
"afp":{"afp","afps"},
"aframomum":{"aframomum","aframomums"},
"afrasian":{"afrasian","afrasians"},
"african-american":{"african-american","african-americans"},
"afrikaans":{"afrikaans","afrikaanses"},
"afrikander":{"afrikander","afrikanders"},
"afrikaner":{"afrikaner","afrikaners"},
"afro":{"afro","afros"},
"afro-american":{"afro-american","afro-americans"},
"afroasiatic":{"afroasiatic","afroasiatics"},
"afrocarpus":{"afrocarpus","afrocarpuses"},
"afropavo":{"afropavo","afropavos"},
"after":{"after"},
"after-shave":{"after-shave","after-shaves"},
"afterbody":{"afterbodies","afterbody"},
"afterimage":{"afterimage","afterimages"},
"afterlife":{"afterlife","afterlives"},
"aftermath":{"aftermath","aftermaths"},
"afternoon":{"afternoon","afternoons"},
"aftersensation":{"aftersensation","aftersensations"},
"afterthought":{"afterthought","afterthoughts"},
"afterword":{"afterword","afterwords"},
"ag":{"ag","ags"},
"agalactia":{"agalactia","agalactias"},
"agalactosis":{"agalactoses","agalactosis"},
"agama":{"agama","agamas"},
"agamid":{"agamid","agamids"},
"agamidae":{"agamidae","agamidaes"},
"agamogenesis":{"agamogeneses","agamogenesis"},
"agapanthus":{"agapanthus","agapanthuses"},
"agape":{"agape","agapes"},
"agapornis":{"agapornis","agapornises"},
"agar":{"agar","agars"},
"agar-agar":{"agar-agar","agar-agars"},
"agaric":{"agaric","agarics"},
"agaricaceae":{"agaricaceae","agaricaceaes"},
"agaricales":{"agaricales","agaricaleses"},
"agaricus":{"agaricus","agaricuses"},
"agastache":{"agastache","agastaches"},
"agate":{"agate","agates"},
"agathis":{"agathis","agathises"},
"agavaceae":{"agavaceae","agavaceaes"},
"agave":{"agave","agaves"},
"age":{"age","aged","ageing","ages","aging"},
"agedness":{"agedness","agednesses"},
"ageing":{"ageing","ageings"},
"ageism":{"ageism","ageisms"},
"agelaius":{"agelaius","agelaiuses"},
"agency":{"agencies","agency"},
"agenda":{"agenda","agendas"},
"agendum":{"agenda","agendum","agendums"},
"agenesia":{"agenesia","agenesias"},
"agenesis":{"ageneses","agenesis"},
"agent":{"agent","agents"},
"agent-general":{"agent-general","agents-general"},
"ageratina":{"ageratina","ageratinas"},
"ageratum":{"ageratum","ageratums"},
"aggiornamento":{"aggiornamenti","aggiornamento"},
"agglomerate":{"agglomerate","agglomerated","agglomerating"},
"agglutinate":{"agglutinate","agglutinated","agglutinating"},
"agglutination":{"agglutination","agglutinations"},
"aggrade":{"aggrade","aggraded","aggrading"},
"aggrandisement":{"aggrandisement","aggrandisements"},
"aggrandize":{"aggrandize","aggrandized","aggrandizes","aggrandizing"},
"aggrandizement":{"aggrandizement","aggrandizements"},
"aggravate":{"aggravate","aggravated","aggravates","aggravating"},
"aggravation":{"aggravation","aggravations"},
"aggregate":{"aggregate","aggregated","aggregates","aggregating"},
"aggregation":{"aggregation","aggregations"},
"aggress":{"aggress","aggressed","aggresses","aggressing"},
"aggression":{"aggression","aggressions"},
"aggressiveness":{"aggressiveness","aggressivenesses"},
"aggressor":{"aggressor","aggressors"},
"aggrieve":{"aggrieve","aggrieved","aggrieves","aggrieving"},
"agility":{"agilities","agility"},
"aging":{"aging","agings"},
"agio":{"agio","agios"},
"agiotage":{"agiotage","agiotages"},
"agism":{"agism","agisms"},
"agitate":{"agitate","agitated","agitates","agitating"},
"agitation":{"agitation","agitations"},
"agitator":{"agitator","agitators"},
"agitprop":{"agitprop","agitprops"},
"agkistrodon":{"agkistrodon","agkistrodons"},
"aglaomorpha":{"aglaomorpha","aglaomorphas"},
"aglaonema":{"aglaonema","aglaonemas"},
"aglet":{"aglet","aglets"},
"agnail":{"agnail","agnails"},
"agnate":{"agnate","agnates"},
"agnatha":{"agnatha","agnathas"},
"agnathan":{"agnathan","agnathans"},
"agnation":{"agnation","agnations"},
"agnomen":{"agnomen","agnomina","agnonomina"},
"agnostic":{"agnostic","agnostics"},
"agnosticism":{"agnosticism","agnosticisms"},
"agon":{"agon","agones"},
"agonidae":{"agonidae","agonidaes"},
"agonize":{"agonize","agonized","agonizes","agonizing"},
"agonus":{"agonus","agonuses"},
"agony":{"agonies","agony"},
"agora":{"agora","agorae","agoras"},
"agouti":{"agouti","agouties","agoutis"},
"agranulocytosis":{"agranulocytoses","agranulocytosis"},
"agranulosis":{"agranuloses","agranulosis"},
"agraphia":{"agraphia","agraphias"},
"agrarian":{"agrarian","agrarians"},
"agree":{"agree","agreed","agreeing","agrees"},
"agreeability":{"agreeabilities","agreeability"},
"agreeableness":{"agreeableness","agreeablenesses"},
"agreement":{"agreement","agreements"},
"agribusiness":{"agribusiness","agribusinesses"},
"agriculture":{"agriculture","agricultures"},
"agriculturist":{"agriculturist","agriculturists"},
"agrimonia":{"agrimonia","agrimonias"},
"agrimony":{"agrimonies","agrimony"},
"agriocharis":{"agriocharis","agriocharises"},
"agrippa":{"agrippa","agrippas"},
"agrobacterium":{"agrobacterium","agrobacteriums"},
"agronomy":{"agronomies","agronomy"},
"agropyron":{"agropyron","agropyrons"},
"agrostemma":{"agrostemma","agrostemmas"},
"agrostis":{"agrostis","agrostises"},
"agua":{"agua","aguas"},
"ague":{"ague","agues"},
"agueweed":{"agueweed","agueweeds"},
"ai":{"ai","ais"},
"aid":{"aid","aided","aiding","aids"},
"aid-de-camp":{"aid-de-camp","aids-de-camp"},
"aide":{"aide","aides"},
"aide-de-camp":{"aide-de-camp","aide-de-camps","aides-de-camp"},
"aide-memoire":{"aide-memoire","aides-memoire"},
"aides":{"aides","aideses"},
"aidman":{"aidman","aidmen"},
"aidoneus":{"aidoneus","aidoneuses"},
"aids":{"aids","aidses"},
"aiglet":{"aiglet","aiglets"},
"aigret":{"aigret","aigrets"},
"aigrette":{"aigrette","aigrettes"},
"aiguilette":{"aiguilette","aiguilettes"},
"ail":{"ail","ailed","ailing","ails"},
"ailanthus":{"ailanthus","ailanthuses"},
"ailment":{"ailment","ailments"},
"ailuropoda":{"ailuropoda","ailuropodas"},
"ailuropodidae":{"ailuropodidae","ailuropodidaes"},
"ailurus":{"ailurus","ailuruses"},
"aim":{"aim","aimed","aiming","aims"},
"aimlessness":{"aimlessness","aimlessnesses"},
"ainu":{"ainu","ainus"},
"aioli":{"aioli","aiolis"},
"air":{"air","aired","airing","airs"},
"air-condition":{"air-condition","air-conditioned","air-conditioning"},
"air-conditioner":{"air-conditioner","air-conditioners"},
"air-conditioning":{"air-conditioning","air-conditionings"},
"air-dry":{"air-dried","air-dries","air-dry","air-drying"},
"airbrake":{"airbrake","airbrakes"},
"airbrush":{"airbrush","airbrushed","airbrushing"},
"aircraftman":{"aircraftman","aircraftmen"},
"aircraftsman":{"aircraftsman","aircraftsmen"},
"aircraftswoman":{"aircraftswoman","aircraftwomen"},
"aircraftwoman":{"aircraftwoman","aircraftwomen"},
"airdock":{"airdock","airdocks"},
"airdrome":{"airdrome","airdromes"},
"airdrop":{"airdrop","airdropped","airdropping","airdrops"},
"aire":{"aire","aires"},
"airedale":{"airedale","airedales"},
"airfield":{"airfield","airfields"},
"airfoil":{"airfoil","airfoils"},
"airforce":{"airforce","airforces"},
"airgun":{"airgun","airguns"},
"airiness":{"airiness","airinesses"},
"airing":{"airing","airings"},
"airlift":{"airlift","airlifted","airlifting","airlifts"},
"airline":{"airline","airlines"},
"airliner":{"airliner","airliners"},
"airlock":{"airlock","airlocks"},
"airmail":{"airmail","airmailed","airmailing","airmails"},
"airman":{"airman","airmen"},
"airplane":{"airplane","airplanes"},
"airport":{"airport","airports"},
"airpost":{"airpost","airposts"},
"airs":{"airs","airses"},
"airscrew":{"airscrew","airscrews"},
"airship":{"airship","airships"},
"airstream":{"airstream","airstreams"},
"airstrip":{"airstrip","airstrips"},
"airwave":{"airwave","airwaves"},
"airway":{"airway","airways"},
"airwoman":{"airwoman","airwomen"},
"airworthy":{"airworthier","airworthiest","airworthy"},
"airy":{"airier","airiest","airy"},
"aisle":{"aisle","aisles"},
"aix":{"aix","aixes"},
"aizoaceae":{"aizoaceae","aizoaceaes"},
"ajaia":{"ajaia","ajaias"},
"ajuga":{"ajuga","ajugas"},
"akaba":{"akaba","akabas"},
"akan":{"akan","akans"},
"akaryocyte":{"akaryocyte","akaryocytes"},
"akaryote":{"akaryote","akaryotes"},
"akee":{"akee","akees"},
"akeridae":{"akeridae","akeridaes"},
"akha":{"akha","akhas"},
"akinesia":{"akinesia","akinesias"},
"akinesis":{"akineses","akinesis"},
"aku":{"aku","akus"},
"akvavit":{"akvavit","akvavits"},
"al":{"al","als"},
"al-iraq":{"al-iraq","al-iraqs"},
"al-magrib":{"al-magrib","al-magribs"},
"ala":{"ala","alae"},
"alabama":{"alabama","alabamas"},
"alabamian":{"alabamian","alabamians"},
"alabaster":{"alabaster","alabasters"},
"alacrity":{"alacrities","alacrity"},
"alameda":{"alameda","alamedas"},
"alamo":{"alamo","alamos"},
"alar":{"alar","alars"},
"alarm":{"alarm","alarmed","alarming","alarms"},
"alarum":{"alarum","alarums"},
"alaska":{"alaska","alaskas"},
"alauda":{"alauda","alaudas"},
"alaudidae":{"alaudidae","alaudidaes"},
"albacore":{"albacore","albacores"},
"albany":{"albanies","albany"},
"albatrellus":{"albatrellus","albatrelluses"},
"albatross":{"albatross","albatrosses"},
"albedo":{"albedo","albedos"},
"albino":{"albino","albinos"},
"albite":{"albite","albites"},
"albizia":{"albizia","albizias"},
"albizzia":{"albizzia","albizzias"},
"albuginaceae":{"albuginaceae","albuginaceaes"},
"albugo":{"albugo","albugos"},
"albula":{"albula","albulas"},
"albulidae":{"albulidae","albulidaes"},
"album":{"album","albums"},
"albumen":{"albumen","albumens"},
"albumin":{"albumin","albumins"},
"albuminoid":{"albuminoid","albuminoids"},
"albuminuria":{"albuminuria","albuminurias"},
"albuterol":{"albuterol","albuterols"},
"alca":{"alca","alcas"},
"alcahest":{"alcahest","alcahests"},
"alcaic":{"alcaic","alcaics"},
"alcaide":{"alcaide","alcaides"},
"alcalde":{"alcalde","alcaldes"},
"alcea":{"alcea","alceas"},
"alcedinidae":{"alcedinidae","alcedinidaes"},
"alcedo":{"alcedo","alcedos"},
"alcelaphus":{"alcelaphus","alcelaphuses"},
"alces":{"alces","alceses"},
"alchemize":{"alchemize","alchemized","alchemizing"},
"alchemy":{"alchemies","alchemy"},
"alcidae":{"alcidae","alcidaes"},
"alcides":{"alcides","alcideses"},
"alcohol":{"alcohol","alcohols"},
"alcoholic":{"alcoholic","alcoholics"},
"alcoholism":{"alcoholism","alcoholisms"},
"alcove":{"alcove","alcoves"},
"alcyonacea":{"alcyonacea","alcyonaceas"},
"alcyonaria":{"alcyonaria","alcyonarias"},
"aldactone":{"aldactone","aldactones"},
"alder":{"alder","alders"},
"alderfly":{"alderflies","alderfly"},
"alderman":{"alderman","aldermen"},
"aldol":{"aldol","aldols"},
"aldomet":{"aldomet","aldomets"},
"aldosteronism":{"aldosteronism","aldosteronisms"},
"aldrovanda":{"aldrovanda","aldrovandas"},
"alecost":{"alecost","alecosts"},
"alectis":{"alectis","alectises"},
"alectoria":{"alectoria","alectorias"},
"alectoris":{"alectoris","alectorises"},
"alectura":{"alectura","alecturas"},
"alehoof":{"alehoof","alehoofs"},
"alehouse":{"alehouse","alehouses"},
"alep":{"alep","aleps"},
"aleph-nought":{"aleph-nought","aleph-noughts"},
"aleph-null":{"aleph-null","aleph-nulls"},
"aleph-zero":{"aleph-zero","aleph-zeroes","aleph-zeros"},
"alepisaurus":{"alepisaurus","alepisauruses"},
"aleppo":{"aleppo","aleppos"},
"alert":{"alert","alerted","alerting","alerts"},
"alerting":{"alerting","alertings"},
"alertness":{"alertness","alertnesses"},
"aletris":{"aletris","aletrises"},
"aleurites":{"aleurites","aleuriteses"},
"aleut":{"aleut","aleuts"},
"aleutian":{"aleutian","aleutians"},
"aleutians":{"aleutians","aleutianses"},
"aleve":{"aleve","aleves"},
"alewife":{"alewife","alewives"},
"alexander":{"alexander","alexanders"},
"alexanders":{"alexanders","alexanderses"},
"alexandria":{"alexandria","alexandrias"},
"alexia":{"alexia","alexias"},
"aleyrodes":{"aleyrodes","aleyrodeses"},
"aleyrodidae":{"aleyrodidae","aleyrodidaes"},
"alfalfa":{"alfalfa","alfalfas"},
"alfilaria":{"alfilaria","alfilarias"},
"alfileria":{"alfileria","alfilerias"},
"alforja":{"alforja","alforjas"},
"alga":{"alga","algae","algas"},
"algae":{"algae","algaes"},
"algarobilla":{"algarobilla","algarobillas"},
"algarroba":{"algarroba","algarrobas"},
"algarrobilla":{"algarrobilla","algarrobillas"},
"algeria":{"algeria","algerias"},
"algerie":{"algerie","algeries"},
"algeripithecus":{"algeripithecus","algeripithecuses"},
"algiers":{"algiers","algierses"},
"algin":{"algin","algins"},
"algonkian":{"algonkian","algonkians"},
"algonkin":{"algonkin","algonkins"},
"algonquian":{"algonquian","algonquians"},
"algonquin":{"algonquin","algonquins"},
"algorithm":{"algorithm","algorithms"},
"alias":{"alias","aliases"},
"alibi":{"alibi","alibied","alibiing","alibis"},
"alien":{"alien","aliened","aliening","aliens"},
"alienage":{"alienage","alienages"},
"alienate":{"alienate","alienated","alienates","alienating"},
"alienation":{"alienation","alienations"},
"alienism":{"alienism","alienisms"},
"alight":{"alight","alighted","alighting","alit"},
"align":{"align","aligned","aligning","aligns"},
"alignment":{"alignment","alignments"},
"alikeness":{"alikeness","alikenesses"},
"aliment":{"aliment","alimented","alimenting","aliments"},
"alimentation":{"alimentation","alimentations"},
"alimony":{"alimonies","alimony"},
"alinement":{"alinement","alinements"},
"aliquant":{"aliquant","aliquants"},
"aliquot":{"aliquot","aliquots"},
"alisma":{"alisma","alismas"},
"alismales":{"alismales","alismaleses"},
"alismataceae":{"alismataceae","alismataceaes"},
"alismatidae":{"alismatidae","alismatidaes"},
"aliterate":{"aliterate","aliterates"},
"aliveness":{"aliveness","alivenesses"},
"alizarin":{"alizarin","alizarins"},
"alizarine":{"alizarine","alizarines"},
"alkahest":{"alkahest","alkahests"},
"alkali":{"alkali","alkalies","alkalis"},
"alkalify":{"alkalified","alkalifies","alkalify","alkalifying"},
"alkalinuria":{"alkalinuria","alkalinurias"},
"alkalize":{"alkalize","alkalized","alkalizes","alkalizing"},
"alkalizer":{"alkalizer","alkalizers"},
"alkaluria":{"alkaluria","alkalurias"},
"alkane":{"alkane","alkanes"},
"alkanet":{"alkanet","alkanets"},
"alkene":{"alkene","alkenes"},
"alkeran":{"alkeran","alkerans"},
"alkie":{"alkie","alkies"},
"alky":{"alkies","alky"},
"alkyd":{"alkyd","alkyds"},
"alkyl":{"alkyl","alkyls"},
"all-rounder":{"all-rounder","all-rounders"},
"allantois":{"allantoides","allantois"},
"allay":{"allay","allayed","allaying","allays"},
"allegation":{"allegation","allegations"},
"allege":{"allege","alleged","alleges","alleging"},
"allegement":{"allegement","allegements"},
"alleghenies":{"alleghenies","alleghenieses"},
"allegiance":{"allegiance","allegiances"},
"allegorize":{"allegorize","allegorized","allegorizing"},
"allegory":{"allegories","allegory"},
"allegretto":{"allegretto","allegrettos"},
"allegro":{"allegro","allegros"},
"allele":{"allele","alleles"},
"allelomorph":{"allelomorph","allelomorphs"},
"alleluia":{"alleluia","alleluias"},
"allemande":{"allemande","allemandes"},
"allergy":{"allergies","allergy"},
"alleviate":{"alleviate","alleviated","alleviates","alleviating"},
"alleviation":{"alleviation","alleviations"},
"alley":{"alley","alleys"},
"alleyway":{"alleyway","alleyways"},
"allgood":{"allgood","allgoods"},
"allhallows":{"allhallows","allhallowses"},
"alliaceae":{"alliaceae","alliaceaes"},
"alliance":{"alliance","alliances"},
"alliaria":{"alliaria","alliarias"},
"allice":{"allice","allices"},
"alligator":{"alligator","alligators"},
"alligatorfish":{"alligatorfish","alligatorfishes"},
"alligatoridae":{"alligatoridae","alligatoridaes"},
"allionia":{"allionia","allionias"},
"allioniaceae":{"allioniaceae","allioniaceaes"},
"allis":{"allis","allises"},
"alliterate":{"alliterate","alliterated","alliterating"},
"alliteration":{"alliteration","alliterations"},
"allium":{"allium","alliums"},
"allmouth":{"allmouth","allmouths"},
"allocate":{"allocate","allocated","allocates","allocating"},
"allocation":{"allocation","allocations"},
"allod":{"allod","allods"},
"allodium":{"allodia","allodium"},
"allograft":{"allograft","allografts"},
"allonge":{"allonge","allonges"},
"allopurinol":{"allopurinol","allopurinols"},
"allosaur":{"allosaur","allosaurs"},
"allosaurus":{"allosaurus","allosauruses"},
"allot":{"allot","allots","allotted","allotting"},
"allotment":{"allotment","allotments"},
"allotropism":{"allotropism","allotropisms"},
"allotropy":{"allotropies","allotropy"},
"allow":{"allow","allowed","allowing","allows"},
"allowance":{"allowance","allowanced","allowances","allowancing"},
"allow_for":{"allowed_for","allowing_for","allows_for","allow_for"},
"alloy":{"alloy","alloyed","alloying","alloys"},
"allspice":{"allspice","allspices"},
"allude":{"allude","alluded","alludes","alluding"},
"allure":{"allure","allured","allures","alluring"},
"allurement":{"allurement","allurements"},
"allusion":{"allusion","allusions"},
"alluviation":{"alluviation","alluviations"},
"alluvium":{"alluvia","alluvium","alluviums"},
"ally":{"allied","allies","ally","allying"},
"allyl":{"allyl","allyls"},
"alma-ata":{"alma-ata","alma-atas"},
"almanac":{"almanac","almanacs"},
"almandine":{"almandine","almandines"},
"almandite":{"almandite","almandites"},
"almaty":{"almaties","almaty"},
"almighty":{"almighties","almighty"},
"almohad":{"almohad","almohads"},
"almohade":{"almohade","almohades"},
"almond":{"almond","almonds"},
"almoner":{"almoner","almoners"},
"almonry":{"almonries","almonry"},
"alms":{"alms","almses"},
"alms-giving":{"alms-giving","alms-givings"},
"almshouse":{"almshouse","almshouses"},
"almsman":{"almsman","almsmen"},
"almswoman":{"almswoman","almswomen"},
"alnus":{"alnus","alnuses"},
"alocasia":{"alocasia","alocasias"},
"alodium":{"alodia","alodium"},
"aloe":{"aloe","aloes"},
"aloeaceae":{"aloeaceae","aloeaceaes"},
"aloes":{"aloes","aloeses"},
"aloha":{"aloha","alohas"},
"aloneness":{"aloneness","alonenesses"},
"aloofness":{"aloofness","aloofnesses"},
"alopecurus":{"alopecurus","alopecuruses"},
"alopex":{"alopex","alopexes"},
"alopiidae":{"alopiidae","alopiidaes"},
"alopius":{"alopius","alopiuses"},
"alosa":{"alosa","alosas"},
"alouatta":{"alouatta","alouattas"},
"alpaca":{"alpaca","alpacas"},
"alpha":{"alpha","alphas"},
"alphabet":{"alphabet","alphabets"},
"alphabetisation":{"alphabetisation","alphabetisations"},
"alphabetization":{"alphabetization","alphabetizations"},
"alphabetize":{"alphabetize","alphabetized","alphabetizing"},
"alpinia":{"alpinia","alpinias"},
"alprazolam":{"alprazolam","alprazolams"},
"alps":{"alps","alpses"},
"als":{"als","alses"},
"alsace":{"alsace","alsaces"},
"alsatia":{"alsatia","alsatias"},
"alsatian":{"alsatian","alsatians"},
"also-ran":{"also-ran","also-rans"},
"alsobia":{"alsobia","alsobias"},
"alsophila":{"alsophila","alsophilas"},
"alstonia":{"alstonia","alstonias"},
"alstroemeriaceae":{"alstroemeriaceae","alstroemeriaceaes"},
"alt":{"alt","alts"},
"altaic":{"altaic","altaics"},
"altar":{"altar","altars"},
"altarpiece":{"altarpiece","altarpieces"},
"alter":{"alter","altered","altering","alters"},
"alteration":{"alteration","alterations"},
"altercate":{"altercate","altercated","altercates","altercating"},
"altercation":{"altercation","altercations"},
"altering":{"altering","alterings"},
"alternanthera":{"alternanthera","alternantheras"},
"alternate":{"alternate","alternated","alternates","alternating"},
"alternation":{"alternation","alternations"},
"alternative":{"alternative","alternatives"},
"althaea":{"althaea","althaeas"},
"althea":{"althaeas","althea","altheas"},
"altimeter":{"altimeter","altimeters"},
"altitude":{"altitude","altitudes"},
"alto":{"alto","altos"},
"alto-relievo":{"alto-relievo","alto-relievos"},
"alto-rilievo":{"alto-rilievo","alto-rilievos"},
"altocumulus":{"altocumuli","altocumulus","altocumuluses"},
"altogether":{"altogether","altogethers"},
"altostratus":{"altostrati","altostratus","altostratuses"},
"altruism":{"altruism","altruisms"},
"altruist":{"altruist","altruists"},
"alula":{"alula","alulae","alulas"},
"alum":{"alum","alums"},
"alumbloom":{"alumbloom","alumblooms"},
"alumina":{"alumina","aluminas"},
"aluminium":{"aluminium","aluminiums"},
"aluminize":{"aluminize","aluminized","aluminizing"},
"aluminum":{"aluminum","aluminums"},
"alumna":{"alumna","alumnae","alumnas"},
"alumnus":{"alumni","alumnus"},
"alumroot":{"alumroot","alumroots"},
"alupent":{"alupent","alupents"},
"alveolar":{"alveolar","alveolars"},
"alveolitis":{"alveolitis","alveolitises"},
"alveolus":{"alveoli","alveolus","alveoluses"},
"alyssum":{"alyssum","alyssums"},
"alytes":{"alytes","alyteses"},
"alzheimers":{"alzheimers","alzheimerses"},
"am":{"am","ams"},
"amadavat":{"amadavat","amadavats"},
"amah":{"amah","amahs"},
"amalgam":{"amalgam","amalgams"},
"amalgamate":{"amalgamate","amalgamated","amalgamates","amalgamating"},
"amalgamation":{"amalgamation","amalgamations"},
"amanita":{"amanita","amanitas"},
"amanuensis":{"amanuenses","amanuensis"},
"amaranthaceae":{"amaranthaceae","amaranthaceaes"},
"amaranthus":{"amaranthus","amaranthuses"},
"amarelle":{"amarelle","amarelles"},
"amaryllidaceae":{"amaryllidaceae","amaryllidaceaes"},
"amass":{"amass","amassed","amasses","amassing"},
"amaterasu":{"amaterasu","amaterasus"},
"amateur":{"amateur","amateurs"},
"amativeness":{"amativeness","amativenesses"},
"amatungulu":{"amatungulu","amatungulus"},
"amauropelta":{"amauropelta","amauropeltas"},
"amaze":{"amaze","amazed","amazes","amazing"},
"amazement":{"amazement","amazements"},
"amazon":{"amazon","amazons"},
"amazona":{"amazona","amazonas"},
"ambari":{"ambari","ambaris"},
"ambary":{"ambaries","ambary"},
"ambassador":{"ambassador","ambassadors"},
"amber":{"amber","ambers"},
"amberbell":{"amberbell","amberbells"},
"amberboa":{"amberboa","amberboas"},
"amberfish":{"amberfish","amberfishes"},
"amberjack":{"amberjack","amberjacks"},
"ambiance":{"ambiance","ambiances"},
"ambidexterity":{"ambidexterities","ambidexterity"},
"ambidextrousness":{"ambidextrousness","ambidextrousnesses"},
"ambience":{"ambience","ambiences"},
"ambiguity":{"ambiguities","ambiguity"},
"ambit":{"ambit","ambits"},
"ambition":{"ambition","ambitioned","ambitioning","ambitions"},
"ambitiousness":{"ambitiousness","ambitiousnesses"},
"ambivalence":{"ambivalence","ambivalences"},
"ambivalency":{"ambivalencies","ambivalency"},
"amble":{"amble","ambled","ambles","ambling"},
"ambler":{"ambler","amblers"},
"ambloplites":{"ambloplites","amblopliteses"},
"amblyrhynchus":{"amblyrhynchus","amblyrhynchuses"},
"ambo":{"ambo","amboes","ambos"},
"amboyna":{"amboyna","amboynas"},
"ambrosia":{"ambrosia","ambrosias"},
"ambrosiaceae":{"ambrosiaceae","ambrosiaceaes"},
"ambry":{"ambries","ambry"},
"ambulacrum":{"ambulacra","ambulacrum"},
"ambulance":{"ambulance","ambulances"},
"ambulate":{"ambulate","ambulated","ambulating"},
"ambulatory":{"ambulatories","ambulatory"},
"ambuscade":{"ambuscade","ambuscaded","ambuscades","ambuscading"},
"ambush":{"ambush","ambushed","ambushes","ambushing"},
"ambystoma":{"ambystoma","ambystomas"},
"ambystomatidae":{"ambystomatidae","ambystomatidaes"},
"ambystomid":{"ambystomid","ambystomids"},
"ameba":{"ameba","amebae","amebas"},
"amebiasis":{"amebiases","amebiasis"},
"amebiosis":{"amebioses","amebiosis"},
"ameer":{"ameer","ameers"},
"ameiuridae":{"ameiuridae","ameiuridaes"},
"ameiurus":{"ameiurus","ameiuruses"},
"amelanchier":{"amelanchier","amelanchiers"},
"ameliorate":{"ameliorate","ameliorated","ameliorates","ameliorating"},
"amelioration":{"amelioration","ameliorations"},
"amen":{"amen","amens"},
"amen-ra":{"amen-ra","amen-ras"},
"amenability":{"amenabilities","amenability"},
"amenableness":{"amenableness","amenablenesses"},
"amend":{"amend","amended","amending","amends"},
"amendment":{"amendment","amendments"},
"amends":{"amends","amendses"},
"amenia":{"amenia","amenias"},
"amenities":{"amenities","amenitieses"},
"amenity":{"amenities","amenity"},
"amenorrhea":{"amenorrhea","amenorrheas"},
"amenorrhoea":{"amenorrhoea","amenorrhoeas"},
"ament":{"ament","aments"},
"amentia":{"amentia","amentias"},
"amentiferae":{"amentiferae","amentiferaes"},
"amerce":{"amerce","amerced","amercing"},
"amercement":{"amercement","amercements"},
"america":{"america","americas"},
"american":{"american","americans"},
"americanize":{"americanize","americanized","americanizing"},
"americium":{"americium","americiums"},
"amerind":{"amerind","amerinds"},
"amerindian":{"amerindian","amerindians"},
"amex":{"amex","amexes"},
"amharic":{"amharic","amharics"},
"amia":{"amia","amias"},
"amiability":{"amiabilities","amiability"},
"amiableness":{"amiableness","amiablenesses"},
"amianthum":{"amianthum","amianthums"},
"amicability":{"amicabilities","amicability"},
"amicableness":{"amicableness","amicablenesses"},
"amidopyrine":{"amidopyrine","amidopyrines"},
"amigo":{"amigo","amigos"},
"amiidae":{"amiidae","amiidaes"},
"amine":{"amine","amines"},
"aminoalkane":{"aminoalkane","aminoalkanes"},
"aminobenzine":{"aminobenzine","aminobenzines"},
"aminophylline":{"aminophylline","aminophyllines"},
"aminoplast":{"aminoplast","aminoplasts"},
"aminopyrine":{"aminopyrine","aminopyrines"},
"amiodarone":{"amiodarone","amiodarones"},
"amir":{"amir","amirs"},
"amitriptyline":{"amitriptyline","amitriptylines"},
"amity":{"amities","amity"},
"ammo":{"ammo","ammos"},
"ammodytes":{"ammodytes","ammodyteses"},
"ammodytidae":{"ammodytidae","ammodytidaes"},
"ammonia":{"ammonia","ammonias"},
"ammoniac":{"ammoniac","ammoniacs"},
"ammoniate":{"ammoniate","ammoniated","ammoniating"},
"ammonify":{"ammonified","ammonifies","ammonify","ammonifying"},
"ammonite":{"ammonite","ammonites"},
"ammonium":{"ammonium","ammoniums"},
"ammonoid":{"ammonoid","ammonoids"},
"ammotragus":{"ammotragus","ammotraguses"},
"ammunition":{"ammunition","ammunitions"},
"amnesia":{"amnesia","amnesias"},
"amnesiac":{"amnesiac","amnesiacs"},
"amnesic":{"amnesic","amnesics"},
"amnesty":{"amnestied","amnesties","amnesty","amnestying"},
"amniocentesis":{"amniocenteses","amniocentesis"},
"amnion":{"amnia","amnion","amnions"},
"amnios":{"amnios","amnioses"},
"amoeba":{"amoeba","amoebae","amoebas"},
"amoebiasis":{"amoebiases","amoebiasis"},
"amoebida":{"amoebida","amoebidas"},
"amoebina":{"amoebina","amoebinas"},
"amoebiosis":{"amoebioses","amoebiosis"},
"amole":{"amole","amoles"},
"amon":{"amon","amons"},
"amon-ra":{"amon-ra","amon-ras"},
"amor":{"amor","amors"},
"amoretto":{"amoretretti","amoretti","amoretto"},
"amorino":{"amorini","amorino","amoririni"},
"amorousness":{"amorousness","amorousnesses"},
"amortisation":{"amortisation","amortisations"},
"amortization":{"amortization","amortizations"},
"amount":{"amount","amounted","amounting","amounts"},
"amour":{"amour","amours"},
"amoxicillin":{"amoxicillin","amoxicillins"},
"amoxil":{"amoxil","amoxils"},
"amoy":{"amoy","amoys"},
"amp":{"amp","amps"},
"ampere":{"ampere","amperes"},
"ampere-second":{"ampere-second","ampere-seconds"},
"amphetamine":{"amphetamine","amphetamines"},
"amphiarthrosis":{"amphiarthroses","amphiarthrosis"},
"amphibia":{"amphibia","amphibias"},
"amphibian":{"amphibian","amphibians"},
"amphibolips":{"amphibolips","amphibolipses"},
"amphibology":{"amphibologies","amphibology"},
"amphiboly":{"amphibolies","amphiboly"},
"amphicarpa":{"amphicarpa","amphicarpas"},
"amphicarpaea":{"amphicarpaea","amphicarpaeas"},
"amphictyony":{"amphictyonies","amphictyony"},
"amphigory":{"amphigories","amphigory"},
"amphigouri":{"amphigouri","amphigouris"},
"amphimixis":{"amphimixes","amphimixis"},
"amphineura":{"amphineura","amphineuras"},
"amphioxidae":{"amphioxidae","amphioxidaes"},
"amphioxus":{"amphioxi","amphioxus","amphioxuses"},
"amphipoda":{"amphipoda","amphipodas"},
"amphiprion":{"amphiprion","amphiprions"},
"amphisbaena":{"amphisbaena","amphisbaenae","amphisbaenas"},
"amphisbaenia":{"amphisbaenia","amphisbaenias"},
"amphisbaenidae":{"amphisbaenidae","amphisbaenidaes"},
"amphitheater":{"amphitheater","amphitheaters"},
"amphitheatre":{"amphitheatre","amphitheatres"},
"amphithecium":{"amphicia","amphithecia","amphithecium"},
"amphiuma":{"amphiuma","amphiumas"},
"amphiumidae":{"amphiumidae","amphiumidaes"},
"amphora":{"amphophorae","amphophoras","amphora","amphorae","amphoras"},
"ampicillin":{"ampicillin","ampicillins"},
"ample":{"ample","ampler","amplest"},
"amplification":{"amplification","amplifications"},
"amplify":{"amplified","amplifies","amplify","amplifying"},
"amplitude":{"amplitude","amplitudes"},
"ampoule":{"ampoule","ampoules"},
"ampul":{"ampul","ampuls"},
"ampule":{"ampule","ampules"},
"ampulla":{"ampulla","ampullae"},
"amputate":{"amputate","amputated","amputates","amputating"},
"amrinone":{"amrinone","amrinones"},
"amsinckia":{"amsinckia","amsinckias"},
"amsonia":{"amsonia","amsonias"},
"amsterdam":{"amsterdam","amsterdams"},
"amulet":{"amulet","amulets"},
"amur":{"amur","amurs"},
"amusd":{"amusd","amusds"},
"amuse":{"amuse","amused","amuses","amusing"},
"amusement":{"amusement","amusements"},
"amygdala":{"amygdala","amygdalae","amygdalas"},
"amygdalaceae":{"amygdalaceae","amygdalaceaes"},
"amygdalus":{"amygdalus","amygdaluses"},
"amylum":{"amylum","amylums"},
"amyotonia":{"amyotonia","amyotonias"},
"amyotrophia":{"amyotrophia","amyotrophias"},
"amyotrophy":{"amyotrophies","amyotrophy"},
"amytal":{"amytal","amytals"},
"an":{"an","ans"},
"anabaena":{"anabaena","anabaenas"},
"anabasis":{"anabases","anabasis"},
"anabolism":{"anabolism","anabolisms"},
"anabrus":{"anabrus","anabruses"},
"anacanthini":{"anacanthini","anacanthinis"},
"anacardiaceae":{"anacardiaceae","anacardiaceaes"},
"anacardium":{"anacardium","anacardiums"},
"anachronism":{"anachronism","anachronisms"},
"anacoluthia":{"anacoluthia","anacoluthias"},
"anacoluthon":{"anacoluthon","anacoluthons"},
"anaconda":{"anaconda","anacondas"},
"anacrusis":{"anacruses","anacrusis"},
"anacyclus":{"anacyclus","anacycluses"},
"anadenanthera":{"anadenanthera","anadenantheras"},
"anadiplosis":{"anadiploses","anadiplosis"},
"anaemia":{"anaemia","anaemias"},
"anaerobe":{"anaerobe","anaerobes"},
"anaerobium":{"anaerobia","anaerobium"},
"anaesthesia":{"anaesthesia","anaesthesias"},
"anaesthetic":{"anaesthetic","anaesthetics"},
"anaesthetist":{"anaesthetist","anaesthetists"},
"anagallis":{"anagallis","anagallises"},
"anagasta":{"anagasta","anagastas"},
"anagnorisis":{"anagnorises","anagnorisis"},
"anagrammatize":{"anagrammatize","anagrammatized","anagrammatizes","anagrammatizing"},
"anagyris":{"anagyris","anagyrises"},
"analecta":{"analecta","analectas"},
"analects":{"analects","analectses"},
"analemma":{"analemma","analemmas","analemmata"},
"analgesic":{"analgesic","analgesics"},
"analog":{"analog","analogs"},
"analogize":{"analogize","analogized","analogizing"},
"analogue":{"analogue","analogues"},
"analogy":{"analogies","analogy"},
"analphabetic":{"analphabetic","analphabetics"},
"analyse":{"analyse","analysed","analyses","analysing"},
"analyser":{"analyser","analysers"},
"analysis":{"analyses","analysis"},
"analyst":{"analyst","analysts"},
"analyze":{"analyze","analyzed","analyzes","analyzing"},
"analyzer":{"analyzer","analyzers"},
"anamnesis":{"anamneses","anamnesis"},
"anamorphosis":{"anamorphoses","anamorphosis"},
"ananas":{"ananas","ananases"},
"anapaest":{"anapaest","anapaests"},
"anapest":{"anapest","anapests"},
"anaphalis":{"anaphalis","anaphalises"},
"anaphora":{"anaphora","anaphoras"},
"anaplasty":{"anaplasties","anaplasty"},
"anaprox":{"anaprox","anaproxes"},
"anapsid":{"anapsid","anapsids"},
"anapsida":{"anapsida","anapsidas"},
"anaptyxis":{"anaptyxis","anatyxes"},
"anapurna":{"anapurna","anapurnas"},
"anarchist":{"anarchist","anarchists"},
"anarchy":{"anarchies","anarchy"},
"anarhichadidae":{"anarhichadidae","anarhichadidaes"},
"anarhichas":{"anarhichas","anarhichases"},
"anas":{"anas","anases"},
"anasa":{"anasa","anasas"},
"anaspida":{"anaspida","anaspidas"},
"anastatica":{"anastatica","anastaticas"},
"anastomosis":{"anastomoses","anastomosis"},
"anastomus":{"anastomus","anastomuses"},
"anastrophe":{"anastrophe","anastrophes"},
"anathema":{"anathema","anathemas"},
"anathematize":{"anathematize","anathematized","anathematizes","anathematizing"},
"anatidae":{"anatidae","anatidaes"},
"anatolia":{"anatolia","anatolias"},
"anatolian":{"anatolian","anatolians"},
"anatomical":{"anatomical","anatomicals"},
"anatomize":{"anatomize","anatomized","anatomizes","anatomizing"},
"anatomy":{"anatomies","anatomy"},
"anatto":{"anatto","anattos"},
"anbury":{"anburies","anbury"},
"ancestor":{"ancestor","ancestors"},
"ancestry":{"ancestries","ancestry"},
"anchor":{"anchor","anchored","anchoring","anchors"},
"anchorage":{"anchorage","anchorages"},
"anchorite":{"anchorite","anchorites"},
"anchorman":{"anchorman","anchormen"},
"anchorperson":{"anchorperson","anchorpersons"},
"anchorwoman":{"anchorwoman","anchorwomen"},
"anchovy":{"anchovies","anchovy"},
"anchylosis":{"anchyloses","anchylosis"},
"ancient":{"ancient","ancients"},
"ancientness":{"ancientness","ancientnesses"},
"ancilla":{"ancilla","ancillas"},
"ancillary":{"ancillaries","ancillary"},
"ancistrodon":{"ancistrodon","ancistrodons"},
"ancon":{"ancon","ancones"},
"ancylidae":{"ancylidae","ancylidaes"},
"ancylostomatidae":{"ancylostomatidae","ancylostomatidaes"},
"ancylus":{"ancylus","ancyluses"},
"andalucia":{"andalucia","andalucias"},
"andalusia":{"andalusia","andalusias"},
"andante":{"andante","andantes"},
"andantino":{"andantino","andantinos"},
"andelmin":{"andelmin","andelmins"},
"andersen":{"andersen","andersens"},
"andira":{"andira","andiras"},
"andiron":{"andiron","andirons"},
"andreaea":{"andreaea","andreaeas"},
"andreaeales":{"andreaeales","andreaealeses"},
"andrena":{"andrena","andrenas"},
"andrenid":{"andrenid","andrenids"},
"andrenidae":{"andrenidae","andrenidaes"},
"andrew":{"andrew","andrews"},
"andricus":{"andricus","andricuses"},
"androclinium":{"androclinia","androclinium"},
"androecia":{"androecia"},
"androecium":{"androecia","androecium"},
"androgen":{"androgen","androgens"},
"androgenesis":{"androgeneses","androgenesis"},
"androgeny":{"androgenies","androgeny"},
"androgyne":{"androgyne","androgynes"},
"androgyny":{"androgynies","androgyny"},
"android":{"android","androids"},
"andromeda":{"andromeda","andromedas"},
"andropogon":{"andropogon","andropogons"},
"androsphinx":{"androsphinges","androsphinx","androsphinxes"},
"anecdote":{"anecdote","anecdotes"},
"anecdotist":{"anecdotist","anecdotists"},
"aneides":{"aneides","aneideses"},
"anemia":{"anemia","anemias"},
"anemometer":{"anemometer","anemometers"},
"anemone":{"anemone","anemones"},
"anemonella":{"anemonella","anemonellas"},
"anemopsis":{"anemopses","anemopsis"},
"anencephalia":{"anencephalia","anencephalias"},
"anencephaly":{"anencephalies","anencephaly"},
"aneroid":{"aneroid","aneroids"},
"anesthesia":{"anesthesia","anesthesias"},
"anesthesiologist":{"anesthesiologist","anesthesiologists"},
"anesthetic":{"anesthetic","anesthetics"},
"anesthetist":{"anesthetist","anesthetists"},
"anesthetize":{"anesthetize","anesthetized","anesthetizes","anesthetizing"},
"anestrum":{"anestrum","anestrums"},
"anestrus":{"anestrus","anestruses"},
"anethum":{"anethum","anethums"},
"aneurin":{"aneurin","aneurins"},
"anfractuosity":{"anfractuosities","anfractuosity"},
"angel":{"angel","angeled","angeling","angels"},
"angeleno":{"angeleno","angelenos"},
"angelfish":{"angelfish","angelfishes"},
"angelica":{"angelica","angelicas"},
"angelim":{"angelim","angelims"},
"angelique":{"angelique","angeliques"},
"angelus":{"angelus","angeluses"},
"anger":{"anger","angered","angering","angers"},
"angevin":{"angevin","angevins"},
"angevine":{"angevine","angevines"},
"angina":{"angina","anginas"},
"angiohemophilia":{"angiohemophilia","angiohemophilias"},
"angioma":{"angioma","angiomas","angiomata"},
"angiopteris":{"angiopteris","angiopterises"},
"angiosperm":{"angiosperm","angiosperms"},
"angiospermae":{"angiospermae","angiospermaes"},
"angiotensin":{"angiotensin","angiotensins"},
"angiotonin":{"angiotonin","angiotonins"},
"angle":{"angle","angled","angles","angling"},
"angler":{"angler","anglers"},
"anglerfish":{"anglerfish","anglerfishes"},
"angleworm":{"angleworm","angleworms"},
"anglicise":{"anglicise","anglicised","anglicises","anglicising"},
"anglicism":{"anglicism","anglicisms"},
"anglicize":{"anglicize","anglicized","anglicizes","anglicizing"},
"anglify":{"anglified","anglifies","anglify","anglifying"},
"anglo":{"anglo","anglos"},
"anglo-catholicism":{"anglo-catholicism","anglo-catholicisms"},
"anglo-french":{"anglo-french","anglo-frenches"},
"anglo-norman":{"anglo-norman","anglo-normen"},
"anglo-saxon":{"anglo-saxon","anglo-saxons"},
"anglophil":{"anglophil","anglophils"},
"anglophile":{"anglophile","anglophiles"},
"angora":{"angora","angoras","argoras"},
"angostura":{"angostura","angosturas"},
"angraecum":{"angraecum","angraecums"},
"angriness":{"angriness","angrinesses"},
"angry":{"angrier","angriest","angry"},
"angstrom":{"angstrom","angstroms"},
"anguidae":{"anguidae","anguidaes"},
"anguilla":{"anguilla","anguillas"},
"anguillidae":{"anguillidae","anguillidaes"},
"anguilliformes":{"anguilliformes","anguilliformeses"},
"anguillula":{"anguillula","anguillulas"},
"anguis":{"anguis","anguises"},
"anguish":{"anguish","anguished","anguishes","anguishing"},
"angularity":{"angularities","angularity"},
"angulate":{"angulate","angulated","angulating"},
"angus":{"angus","anguses"},
"angwantibo":{"angwantibo","angwantibos"},
"anhima":{"anhima","anhimas"},
"anhimidae":{"anhimidae","anhimidaes"},
"anhinga":{"anhinga","anhingas"},
"anhingidae":{"anhingidae","anhingidaes"},
"ani":{"ani","anis"},
"anigozanthus":{"anigozanthus","anigozanthuses"},
"anil":{"anil","anils"},
"aniline":{"aniline","anilines"},
"anima":{"anima","animas"},
"animadversion":{"animadversion","animadversions"},
"animadvert":{"animadvert","animadverted","animadverting","animadverts"},
"animal":{"animal","animals"},
"animal-worship":{"animal-worship","animal-worships"},
"animalcule":{"animalcule","animalcules"},
"animalculum":{"animalcula","animalculum","animalculums"},
"animalia":{"animalia","animalias"},
"animalisation":{"animalisation","animalisations"},
"animalism":{"animalism","animalisms"},
"animality":{"animalities","animality"},
"animalization":{"animalization","animalizations"},
"animalize":{"animalize","animalized","animalizing"},
"animate":{"animate","animated","animates","animating"},
"animateness":{"animateness","animatenesses"},
"animation":{"animation","animations"},
"animator":{"animator","animators"},
"anime":{"anime","animes"},
"animosity":{"animosities","animosity"},
"animus":{"animus","animuses"},
"anionic":{"anionic","anionics"},
"anise":{"anise","anises"},
"aniseed":{"aniseed","aniseeds"},
"anisette":{"anisette","anisettes"},
"anisoptera":{"anisoptera","anisopteras"},
"anisotremus":{"anisotremus","anisotremuses"},
"ankara":{"ankara","ankaras"},
"ankle":{"ankle","ankles"},
"anklebone":{"anklebone","anklebones"},
"anklet":{"anklet","anklets"},
"anklets":{"anklets","ankletses"},
"ankus":{"ankus","ankuses"},
"ankyloglossia":{"ankyloglossia","ankyloglossias"},
"ankylosaur":{"ankylosaur","ankylosaurs"},
"ankylosaurus":{"ankylosaurus","ankylosauruses"},
"ankylosis":{"ankyloses","ankylosis"},
"anlage":{"anlage","anlagen","anlages"},
"annals":{"annals","annalses"},
"annam":{"annam","annams"},
"annamese":{"annamese","annameses"},
"annamite":{"annamite","annamites"},
"annapolis":{"annapolis","annapolises"},
"annapurna":{"annapurna","annapurnas"},
"annatto":{"annatto","annattos"},
"anneal":{"anneal","annealed","annealing","anneals"},
"annealing":{"annealing","annealings"},
"annelid":{"annelid","annelids"},
"annelida":{"annelida","annelidas"},
"annex":{"annex","annexed","annexes","annexing"},
"annexa":{"annexa","annexas"},
"annexation":{"annexation","annexations"},
"annexe":{"annexe","annexes"},
"anniellidae":{"anniellidae","anniellidaes"},
"annihilate":{"annihilate","annihilated","annihilates","annihilating"},
"annihilation":{"annihilation","annihilations"},
"annihilator":{"annihilator","annihilators"},
"anniversary":{"anniversaries","anniversary"},
"annona":{"annona","annonas"},
"annonaceae":{"annonaceae","annonaceaes"},
"annotate":{"annotate","annotated","annotates","annotating"},
"annotating":{"annotating","annotatings"},
"annotation":{"annotation","annotations"},
"announce":{"announce","announced","announces","announcing"},
"announcement":{"announcement","announcements"},
"announcer":{"announcer","announcers"},
"annoy":{"annoy","annoyed","annoying","annoys"},
"annoyance":{"annoyance","annoyances"},
"annoyer":{"annoyer","annoyers"},
"annoying":{"annoying","annoyings"},
"annual":{"annual","annuals"},
"annualry":{"annualries","annualry"},
"annuitant":{"annuitant","annuitants"},
"annuity":{"annuities","annuity"},
"annul":{"annul","annulled","annulling","annuls"},
"annulet":{"annulet","annulets"},
"annulment":{"annulment","annulments"},
"annulus":{"annuli","annulus","annuluses"},
"annunciate":{"annunciate","annunciated","annunciates","annunciating"},
"annunciation":{"annunciation","annunciations"},
"annwfn":{"annwfn","annwfns"},
"annwn":{"annwn","annwns"},
"anoa":{"anoa","anoas"},
"anobiidae":{"anobiidae","anobiidaes"},
"anodize":{"anodize","anodized","anodizing"},
"anodonta":{"anodonta","anodontas"},
"anodyne":{"anodyne","anodynes"},
"anoectochilus":{"anoectochilus","anoectochiluses"},
"anoestrum":{"anoestrum","anoestrums"},
"anoestrus":{"anoestrus","anoestruses"},
"anogramma":{"anogramma","anogrammas"},
"anoint":{"anoint","anointed","anointing","anoints"},
"anointing":{"anointing","anointings"},
"anointment":{"anointment","anointments"},
"anole":{"anole","anoles"},
"anolis":{"anolis","anolises"},
"anomala":{"anomala","anomalas"},
"anomalopidae":{"anomalopidae","anomalopidaes"},
"anomalops":{"anomalops","anomalopses"},
"anomalopteryx":{"anomalopteryx","anomalopteryxes"},
"anomalousness":{"anomalousness","anomalousnesses"},
"anomaly":{"anomalies","anomaly"},
"anomia":{"anomia","anomias"},
"anomiidae":{"anomiidae","anomiidaes"},
"anon":{"anon","anons"},
"anonym":{"anonym","anonyms"},
"anonymity":{"anonymities","anonymity"},
"anopheles":{"anopheles","anopheleses"},
"anoplura":{"anoplura","anopluras"},
"anorak":{"anorak","anoraks"},
"anorchia":{"anorchia","anorchias"},
"anorchidism":{"anorchidism","anorchidisms"},
"anorchism":{"anorchism","anorchisms"},
"anorthography":{"anorthographies","anorthography"},
"anosmia":{"anosmia","anosmias"},
"anostraca":{"anostraca","anostracas"},
"ans":{"ans","anses"},
"ansaid":{"ansaid","ansaids"},
"anser":{"anser","ansers"},
"anseres":{"anseres","ansereses"},
"anseriformes":{"anseriformes","anseriformeses"},
"anserinae":{"anserinae","anserinaes"},
"answer":{"answer","answered","answering","answers"},
"answerability":{"answerabilities","answerability"},
"answerableness":{"answerableness","answerablenesses"},
"answerer":{"answerer","answerers"},
"ant":{"ant","ants"},
"anta":{"anta","antae"},
"antabuse":{"antabuse","antabuses"},
"antacid":{"antacid","antacids"},
"antagonism":{"antagonism","antagonisms"},
"antagonist":{"antagonist","antagonists"},
"antagonize":{"antagonize","antagonized","antagonizes","antagonizing"},
"antalkali":{"antalkali","antalkalies","antalkalis"},
"antananarivo":{"antananarivo","antananarivos"},
"antarctic":{"antarctic","antarctics"},
"antarctica":{"antarctica","antarcticas"},
"antbird":{"antbird","antbirds"},
"ante":{"ante","anted","anteed","anteing","antes"},
"anteater":{"anteater","anteaters"},
"antecedence":{"antecedence","antecedences"},
"antecedency":{"antecedencies","antecedency"},
"antecedent":{"antecedent","antecedents"},
"antechamber":{"antechamber","antechambers"},
"antedate":{"antedate","antedated","antedates","antedating"},
"antediluvian":{"antediluvian","antediluvians"},
"antedon":{"antedon","antedons"},
"antedonidae":{"antedonidae","antedonidaes"},
"antefix":{"antefix","antefixa","antefixes"},
"antelope":{"antelope","antelopes"},
"antenna":{"antenna","antennae","antennas"},
"antennaria":{"antennaria","antennarias"},
"antennariidae":{"antennariidae","antennariidaes"},
"antependium":{"antependia","antependium"},
"antepenult":{"antepenult","antepenults"},
"antepenultimate":{"antepenultimate","antepenultimates"},
"anterior":{"anterior","anteriors"},
"anteriority":{"anteriorities","anteriority"},
"anteroom":{"anteroom","anterooms"},
"anthelion":{"anthelia","anthelion"},
"anthelix":{"anthelices","anthelix"},
"anthelminthic":{"anthelminthic","anthelminthics"},
"anthelmintic":{"anthelmintic","anthelmintics"},
"anthem":{"anthem","anthems"},
"anthemion":{"anthemia","anthemion"},
"anthemis":{"anthemis","anthemises"},
"anther":{"anther","anthers"},
"antheraea":{"antheraea","antheraeas"},
"anthericum":{"anthericum","anthericums"},
"antheridium":{"antheridia","antheridiia","antheridium"},
"antheropeas":{"antheropeas","antheropeases"},
"antherozoid":{"antherozoid","antherozoids"},
"anthesis":{"antheses","anthesis"},
"anthidium":{"anthidium","anthidiums"},
"anthoceropsida":{"anthoceropsida","anthoceropsidas"},
"anthoceros":{"anthoceros","anthoceroses"},
"anthocerotaceae":{"anthocerotaceae","anthocerotaceaes"},
"anthocerotales":{"anthocerotales","anthocerotaleses"},
"anthodium":{"anthodia","anthodium"},
"anthologize":{"anthologize","anthologized","anthologizing"},
"anthology":{"anthologies","anthology"},
"anthonomus":{"anthonomus","anthonomuses"},
"anthophyta":{"anthophyta","anthophytas"},
"anthozoa":{"anthozoa","anthozoas"},
"anthozoan":{"anthozoan","anthozoans"},
"anthracite":{"anthracite","anthracites"},
"anthracosis":{"anthracoses","anthracosis"},
"anthrax":{"anthraces","anthrax","anthraxes"},
"anthriscus":{"anthriscus","anthriscuses"},
"anthropocentricity":{"anthropocentricities","anthropocentricity"},
"anthropocentrism":{"anthropocentrism","anthropocentrisms"},
"anthropogenesis":{"anthropogeneses","anthropogenesis"},
"anthropogeny":{"anthropogenies","anthropogeny"},
"anthropoid":{"anthropoid","anthropoids"},
"anthropoidea":{"anthropoidea","anthropoideas"},
"anthropolatry":{"anthropolatries","anthropolatry"},
"anthropomorphism":{"anthropomorphism","anthropomorphisms"},
"anthropomorphize":{"anthropomorphize","anthropomorphized","anthropomorphizing"},
"anthropophagi":{"anthropophagi","anthropophagus"},
"anthropophagite":{"anthropophagite","anthropophagites"},
"anthropophagus":{"anthropophagus","anthropophaguses"},
"anthurium":{"anthurium","anthuriums"},
"anthus":{"anthus","anthuses"},
"anthyllis":{"anthyllis","anthyllises"},
"anti":{"anti","antis"},
"anti-hero":{"anti-hero","anti-heroes"},
"anti-inflammatory":{"anti-inflammatories","anti-inflammatory"},
"anti-semite":{"anti-semite","anti-semites"},
"antiaircraft":{"antiaircraft","antiaircrafts"},
"antiarrhythmic":{"antiarrhythmic","antiarrhythmics"},
"antibacterial":{"antibacterial","antibacterials"},
"antibiotic":{"antibiotic","antibiotics"},
"antibody":{"antibodies","antibody"},
"antic":{"antic","anticked","anticking","antics"},
"anticipate":{"anticipate","anticipated","anticipates","anticipating"},
"anticipation":{"anticipation","anticipations"},
"anticipator":{"anticipator","anticipators"},
"anticlimax":{"anticlimax","anticlimaxes"},
"anticlinorium":{"anticlinonoria","anticlinorium"},
"anticoagulant":{"anticoagulant","anticoagulants"},
"anticonvulsant":{"anticonvulsant","anticonvulsants"},
"antidepressant":{"antidepressant","antidepressants"},
"antidiabetic":{"antidiabetic","antidiabetics"},
"antidiarrheal":{"antidiarrheal","antidiarrheals"},
"antidiuretic":{"antidiuretic","antidiuretics"},
"antidorcas":{"antidorcas","antidorcases"},
"antidote":{"antidote","antidotes"},
"antielectron":{"antielectron","antielectrons"},
"antiemetic":{"antiemetic","antiemetics"},
"antiepileptic":{"antiepileptic","antiepileptics"},
"antifeminism":{"antifeminism","antifeminisms"},
"antifungal":{"antifungal","antifungals"},
"antigonia":{"antigonia","antigonias"},
"antigonus":{"antigonus","antigonuses"},
"antihelix":{"antihelices","antihelix","antihelixes"},
"antihero":{"antihero","antiheroes"},
"antihypertensive":{"antihypertensive","antihypertensives"},
"antilocapra":{"antilocapra","antilocapras"},
"antilocapridae":{"antilocapridae","antilocapridaes"},
"antilog":{"antilog","antilogs"},
"antilogarithm":{"antilogarithm","antilogarithms"},
"antilogy":{"antilogies","antilogy"},
"antilope":{"antilope","antilopes"},
"antimalarial":{"antimalarial","antimalarials"},
"antimicrobial":{"antimicrobial","antimicrobials"},
"antimicrobic":{"antimicrobic","antimicrobics"},
"antimony":{"antimonies","antimony"},
"antimuon":{"antimuon","antimuons"},
"antimycotic":{"antimycotic","antimycotics"},
"antineoplastic":{"antineoplastic","antineoplastics"},
"antineutrino":{"antineutrino","antineutrinos"},
"antinomy":{"antinomies","antinomy"},
"antipasto":{"antipasti","antipasto","antipastos"},
"antipathy":{"antipathies","antipathy"},
"antiphon":{"antiphon","antiphons"},
"antiphonal":{"antiphonal","antiphonals"},
"antiphonary":{"antiphonaries","antiphonary"},
"antiphony":{"antiphonies","antiphony"},
"antipodal":{"antipodal","antipodals"},
"antipsychotic":{"antipsychotic","antipsychotics"},
"antipyretic":{"antipyretic","antipyretics"},
"antiquarian":{"antiquarian","antiquarians"},
"antiquary":{"antiquaries","antiquary"},
"antiquate":{"antiquate","antiquated","antiquates","antiquating"},
"antique":{"antique","antiqued","antiques","antiquing"},
"antiquity":{"antiquities","antiquity"},
"antirrhinum":{"antirrhinum","antirrhinums"},
"antisepsis":{"antisepses","antisepsis"},
"antiseptic":{"antiseptic","antiseptics"},
"antisepticize":{"antisepticize","antisepticized","antisepticizing"},
"antiserum":{"antisera","antiserum","antiserums"},
"antispasmodic":{"antispasmodic","antispasmodics"},
"antitauon":{"antitauon","antitauons"},
"antithesis":{"antitheses","antithesis"},
"antitoxin":{"antitoxin","antitoxins"},
"antitrade":{"antitrade","antitrades"},
"antitragus":{"antitragi","antitragus"},
"antivert":{"antivert","antiverts"},
"antlion":{"antlion","antlions"},
"antony":{"antonies","antony"},
"antonym":{"antonym","antonyms"},
"antrozous":{"antrozous","antrozouses"},
"antrum":{"antra","antrum"},
"antwerp":{"antwerp","antwerps"},
"antwerpen":{"antwerpen","antwerpens"},
"anulus":{"anulus","anuluses"},
"anunnaki":{"anunnaki","anunnakis"},
"anura":{"anura","anuras"},
"anuran":{"anuran","anurans"},
"anuresis":{"anureses","anuresis"},
"anuria":{"anuria","anurias"},
"anus":{"anus","anuses"},
"anvers":{"anvers","anverses"},
"anvil":{"anvil","anvils"},
"anxiety":{"anxieties","anxiety"},
"anxiolytic":{"anxiolytic","anxiolytics"},
"anxiousness":{"anxiousness","anxiousnesses"},
"anybody":{"anybodies","anybody"},
"aorta":{"aorta","aortae","aortas"},
"aotus":{"aotus","aotuses"},
"aoudad":{"aoudad","aoudads"},
"apache":{"apache","apaches"},
"apalachicola":{"apalachicola","apalachicolas"},
"apanage":{"apanage","apanages"},
"apar":{"apar","apars"},
"aparejo":{"aparejo","aparejos"},
"apartheid":{"apartheid","apartheids"},
"apartment":{"apartment","apartments"},
"apathy":{"apathies","apathy"},
"apatosaur":{"apatosaur","apatosaurs"},
"apatosaurus":{"apatosaurus","apatosauruses"},
"apatura":{"apatura","apaturas"},
"ape":{"ape","aped","apes","aping"},
"ape-man":{"ape-man","ape-men"},
"apeman":{"apeman","apemen"},
"aper":{"aper","apers"},
"aperea":{"aperea","apereas"},
"aperient":{"aperient","aperients"},
"aperture":{"aperture","apertures"},
"apery":{"aperies","apery"},
"apex":{"apex","apexes","apices"},
"aphaeresis":{"aphaereses","aphaeresis"},
"aphasmidia":{"aphasmidia","aphasmidias"},
"aphelion":{"aphelia","aphelilia","aphelion"},
"apheresis":{"aphereses","apheresis"},
"aphididae":{"aphididae","aphididaes"},
"aphidoidea":{"aphidoidea","aphidoideas"},
"aphis":{"aphides","aphis","aphises"},
"aphonia":{"aphonia","aphonias"},
"aphorism":{"aphorism","aphorisms"},
"aphorize":{"aphorize","aphorized","aphorizing"},
"aphriza":{"aphriza","aphrizas"},
"aphrodite":{"aphrodite","aphrodites"},
"aphrophora":{"aphrophora","aphrophoras"},
"aphyllanthaceae":{"aphyllanthaceae","aphyllanthaceaes"},
"aphyllanthes":{"aphyllanthes","aphyllantheses"},
"aphyllophorales":{"aphyllophorales","aphyllophoraleses"},
"apia":{"apia","apias"},
"apiaceae":{"apiaceae","apiaceaes"},
"apiarist":{"apiarist","apiarists"},
"apiary":{"apiaries","apiary"},
"apiculture":{"apiculture","apicultures"},
"apiculturist":{"apiculturist","apiculturists"},
"apidae":{"apidae","apidaes"},
"apios":{"apios","apioses"},
"apis":{"apis","apises"},
"apium":{"apium","apiums"},
"aplacophora":{"aplacophora","aplacophoras"},
"aplacophoran":{"aplacophoran","aplacophorans"},
"aplectrum":{"aplectrum","aplectrums"},
"aplodontia":{"aplodontia","aplodontias"},
"aplodontiidae":{"aplodontiidae","aplodontiidaes"},
"aplomb":{"aplomb","aplombs"},
"aplysia":{"aplysia","aplysias"},
"aplysiidae":{"aplysiidae","aplysiidaes"},
"apoapsis":{"apoapses","apoapsis"},
"apocalypse":{"apocalypse","apocalypses"},
"apocopate":{"apocopate","apocopated","apocopating"},
"apocynaceae":{"apocynaceae","apocynaceaes"},
"apocynum":{"apocynum","apocynums"},
"apodemus":{"apodemus","apodemuses"},
"apodidae":{"apodidae","apodidaes"},
"apodiformes":{"apodiformes","apodiformeses"},
"apodosis":{"apodoses","apodosis"},
"apogee":{"apogee","apogees"},
"apogon":{"apogon","apogons"},
"apogonidae":{"apogonidae","apogonidaes"},
"apoidea":{"apoidea","apoideas"},
"apollo":{"apollo","apollos"},
"apologetic":{"apologetic","apologetics"},
"apologia":{"apologia","apologias"},
"apologist":{"apologist","apologists"},
"apologize":{"apologize","apologized","apologizes","apologizing"},
"apologue":{"apologue","apologues"},
"apology":{"apologies","apology"},
"apolune":{"apolune","apolunes"},
"apomixis":{"apomixes","apomixis"},
"aponeurosis":{"aponeuroses","aponeurosis"},
"apophthegm":{"apophthegm","apophthegms"},
"apophysis":{"apophyses","apophysis"},
"apoplexy":{"apoplexies","apoplexy"},
"aporocactus":{"aporocactus","aporocactuses"},
"aposelene":{"aposelene","aposelenes"},
"aposiopesis":{"aposiopeses","aposiopesis"},
"apostasy":{"apostasies","apostasy"},
"apostate":{"apostate","apostates"},
"apostatize":{"apostatize","apostatized","apostatizes","apostatizing"},
"apostrophize":{"apostrophize","apostrophized","apostrophizing"},
"apothecary":{"apothecaries","apothecary"},
"apothecium":{"apothecia","apothecium"},
"apothegm":{"apothegm","apothegms"},
"apotheosis":{"apotheoses","apotheosis"},
"apotheosize":{"apotheosize","apotheosized","apotheosizes","apotheosizing"},
"appal":{"appal","appalled","appalling","appals"},
"appalachians":{"appalachians","appalachianses"},
"appall":{"appall","appalled","appalling","appalls"},
"appaloosa":{"appaloosa","appaloosas"},
"appanage":{"appanage","appanages"},
"apparatus":{"apparatus","apparatuses"},
"apparel":{"apparel","appareled","appareling","apparelled","apparelling","apparels"},
"apparency":{"apparencies","apparency"},
"apparentness":{"apparentness","apparentnesses"},
"apparition":{"apparition","apparitions"},
"appeal":{"appeal","appealed","appealing","appeals"},
"appealingness":{"appealingness","appealingnesses"},
"appear":{"appear","appeared","appearing","appears"},
"appearance":{"appearance","appearances"},
"appearing":{"appearing","appearings"},
"appease":{"appease","appeased","appeases","appeasing"},
"appeasement":{"appeasement","appeasements"},
"appeaser":{"appeaser","appeasers"},
"appellant":{"appellant","appellants"},
"appellation":{"appellation","appellations"},
"appellative":{"appellative","appellatives"},
"append":{"append","appended","appending","appends"},
"appendage":{"appendage","appendages"},
"appendectomy":{"appendectomies","appendectomy","appendicectomies"},
"appendicectomy":{"appendicectomies","appendicectomy"},
"appendix":{"appendices","appendix","appendixed","appendixes","appendixing"},
"apperceive":{"apperceive","apperceived","apperceiving"},
"appertain":{"appertain","appertained","appertaining","appertains"},
"appetence":{"appetence","appetences"},
"appetency":{"appetencies","appetency"},
"appetite":{"appetite","appetites"},
"applaud":{"applaud","applauded","applauding","applauds"},
"applauder":{"applauder","applauders"},
"applause":{"applause","applauses"},
"apple":{"apple","apples"},
"apple-polish":{"apple-polish","apple-polished","apple-polishing"},
"applemint":{"applemint","applemints"},
"applesauce":{"applesauce","applesauces"},
"appliance":{"appliance","appliances"},
"applicability":{"applicabilities","applicability"},
"applicant":{"applicant","applicants"},
"application":{"application","applications"},
"applicator":{"applicator","applicators"},
"applier":{"applier","appliers"},
"applique":{"applique","appliqued","appliqueing","appliques"},
"apply":{"applied","applies","apply","applying"},
"appoggiatura":{"appoggiatura","appoggiaturas"},
"appoint":{"appoint","appointed","appointing","appoints"},
"appointee":{"appointee","appointees"},
"appointment":{"appointment","appointments"},
"apportion":{"apportion","apportioned","apportioning","apportions"},
"apportioning":{"apportioning","apportionings"},
"apportionment":{"apportionment","apportionments"},
"appose":{"appose","apposed","apposing"},
"appositeness":{"appositeness","appositenesses"},
"appraisal":{"appraisal","appraisals"},
"appraise":{"appraise","appraised","appraises","appraising"},
"appraiser":{"appraiser","appraisers"},
"appreciate":{"appreciate","appreciated","appreciates","appreciating"},
"appreciation":{"appreciation","appreciations"},
"appreciativeness":{"appreciativeness","appreciativenesses"},
"appreciator":{"appreciator","appreciators"},
"apprehend":{"apprehend","apprehended","apprehending","apprehends"},
"apprehension":{"apprehension","apprehensions"},
"apprehensiveness":{"apprehensiveness","apprehensivenesses"},
"apprentice":{"apprentice","apprenticed","apprentices","apprenticing"},
"apprenticeship":{"apprenticeship","apprenticeships"},
"apprisal":{"apprisal","apprisals"},
"apprise":{"apprise","apprised","apprises","apprising"},
"apprize":{"apprize","apprized","apprizes","apprizing"},
"approach":{"approach","approached","approaches","approaching"},
"approachability":{"approachabilities","approachability"},
"approaching":{"approaching","approachings"},
"approbate":{"approbate","approbated","approbating"},
"appropriate":{"appropriate","appropriated","appropriates","appropriating"},
"appropriateness":{"appropriateness","appropriatenesses"},
"appropriation":{"appropriation","appropriations"},
"appropriator":{"appropriator","appropriators"},
"approval":{"approval","approvals"},
"approve":{"approve","approved","approves","approving"},
"approver":{"approver","approvers"},
"approving":{"approving","approvings"},
"approximate":{"approximate","approximated","approximates","approximating"},
"approximation":{"approximation","approximations"},
"appurtenance":{"appurtenance","appurtenances"},
"appurtenances":{"appurtenances","appurtenanceses"},
"apr":{"apr","aprs"},
"apricot":{"apricot","apricots"},
"april":{"april","aprils"},
"apron":{"apron","aprons"},
"apse":{"apse","apses"},
"apsis":{"apses","apsis"},
"apt":{"apt","apter","aptest"},
"aptenodytes":{"aptenodytes","aptenodyteses"},
"apterygidae":{"apterygidae","apterygidaes"},
"apterygiformes":{"apterygiformes","apterygiformeses"},
"apteryx":{"apteryx","apteryxes"},
"aptitude":{"aptitude","aptitudes"},
"aptness":{"aptness","aptnesses"},
"apulia":{"apulia","apulias"},
"apus":{"apus","apuses"},
"aqaba":{"aqaba","aqabas"},
"aqua":{"aqua","aquae","aquas"},
"aqualung":{"aqualung","aqualungs"},
"aquamarine":{"aquamarine","aquamarines"},
"aquanaut":{"aquanaut","aquanauts"},
"aquarium":{"aquaria","aquarium","aquariums"},
"aquarius":{"aquarii","aquarius","aquariuses"},
"aquatic":{"aquatic","aquatics"},
"aquatics":{"aquatics","aquaticses"},
"aquavit":{"aquavit","aquavits"},
"aqueduct":{"aqueduct","aqueducts"},
"aquiculture":{"aquiculture","aquicultures"},
"aquifoliaceae":{"aquifoliaceae","aquifoliaceaes"},
"aquila":{"aquila","aquilas"},
"aquilege":{"aquilege","aquileges"},
"aquilegia":{"aquilegia","aquilegias"},
"aquinas":{"aquinas","aquinases"},
"aquitaine":{"aquitaine","aquitaines"},
"aquitania":{"aquitania","aquitanias"},
"ar":{"ar","ars"},
"ara":{"ara","aras"},
"arab":{"arab","arabs"},
"arabia":{"arabia","arabias"},
"arabian":{"arabian","arabians"},
"arabic":{"arabic","arabics"},
"arabis":{"arabis","arabises"},
"arabize":{"arabize","arabized","arabizing"},
"araceae":{"araceae","araceaes"},
"arachis":{"arachis","arachises"},
"arachnid":{"arachnid","arachnids"},
"arachnida":{"arachnida","arachnidas"},
"arachnoid":{"arachnoid","arachnoids"},
"arak":{"arak","araks"},
"arales":{"arales","araleses"},
"araliaceae":{"araliaceae","araliaceaes"},
"aramus":{"aramus","aramuses"},
"aranea":{"aranea","araneas"},
"araneae":{"araneae","araneaes"},
"araneida":{"araneida","araneidas"},
"araneus":{"araneus","araneuses"},
"arapaho":{"arapaho","arapahos"},
"arapahoe":{"arapahoe","arapahoes"},
"ararat":{"ararat","ararats"},
"arariba":{"arariba","araribas"},
"araroba":{"araroba","ararobas"},
"araucaria":{"araucaria","araucarias"},
"araucariaceae":{"araucariaceae","araucariaceaes"},
"araujia":{"araujia","araujias"},
"arawak":{"arawak","arawaks"},
"arawakan":{"arawakan","arawakans"},
"arb":{"arb","arbs"},
"arbiter":{"arbiter","arbiters"},
"arbitrager":{"arbitrager","arbitragers"},
"arbitrageur":{"arbitrageur","arbitrageurs"},
"arbitrament":{"arbitrament","arbitraments"},
"arbitrariness":{"arbitrariness","arbitrarinesses"},
"arbitrary":{"arbitraries","arbitrary"},
"arbitrate":{"arbitrate","arbitrated","arbitrates","arbitrating"},
"arbitration":{"arbitration","arbitrations"},
"arbitrator":{"arbitrator","arbitrators"},
"arbitrement":{"arbitrement","arbitrements"},
"arbor":{"arbor","arbores","arbors"},
"arboretum":{"arboreta","arboretum","arboretums"},
"arboriculture":{"arboriculture","arboricultures"},
"arboriculturist":{"arboriculturist","arboriculturists"},
"arborize":{"arborize","arborized","arborizes","arborizing"},
"arborolatry":{"arborolatries","arborolatry"},
"arbour":{"arbour","arbours"},
"arbutus":{"arbutus","arbutuses"},
"arc":{"arc","arced","arcing","arcs"},
"arc-boutant":{"arc-boutant","arc-boutants"},
"arca":{"arca","arcas"},
"arcade":{"arcade","arcades"},
"arcanum":{"arcana","arcanum","arcanums"},
"arcdegree":{"arcdegree","arcdegrees"},
"arcellidae":{"arcellidae","arcellidaes"},
"arceuthobium":{"arceuthobium","arceuthobiums"},
"arch":{"arch","arched","archer","arches","archest","arching"},
"archaebacteria":{"archaebacteria","archaebacterias"},
"archaebacterium":{"archaebacterium","archaebacteriums"},
"archaeobacteria":{"archaeobacteria","archaeobacterias"},
"archaeologist":{"archaeologist","archaeologists"},
"archaeology":{"archaeologies","archaeology"},
"archaeopteryx":{"archaeopteryx","archaeopteryxes"},
"archaeornithes":{"archaeornithes","archaeornitheses"},
"archaeozoic":{"archaeozoic","archaeozoics"},
"archaicism":{"archaicism","archaicisms"},
"archaism":{"archaism","archaisms"},
"archaize":{"archaize","archaized","archaizing"},
"archangel":{"archangel","archangels"},
"archbishop":{"archbishop","archbishops"},
"archdeaconry":{"archdeaconries","archdeaconry"},
"archduchy":{"archduchies","archduchy"},
"archegonium":{"archegonia","archegonium"},
"archenemy":{"archenemies","archenemy"},
"archenteron":{"archentera","archenteron"},
"archeologist":{"archeologist","archeologists"},
"archeology":{"archeologies","archeology"},
"archeopteryx":{"archeopteryx","archeopteryxes"},
"archeozoic":{"archeozoic","archeozoics"},
"archer":{"archer","archers"},
"archerfish":{"archerfish","archerfishes"},
"archespore":{"archespore","archespores"},
"archesporium":{"archesporium","archesporiums"},
"archetype":{"archetype","archetypes"},
"archiannelida":{"archiannelida","archiannelidas"},
"archidiskidon":{"archidiskidon","archidiskidons"},
"archil":{"archil","archils"},
"archilochus":{"archilochus","archilochuses"},
"archimandrite":{"archimandrite","archimandrites"},
"archipallium":{"archipallium","archipalliums"},
"archipelago":{"archipelago","archipelagoes","archipelagos"},
"architect":{"architect","architects"},
"architectonics":{"architectonics","architectonicses"},
"architecture":{"architecture","architectures"},
"architeuthis":{"architeuthis","architeuthises"},
"archive":{"archive","archived","archives","archiving"},
"archives":{"archives","archiveses"},
"archness":{"archness","archnesses"},
"archosargus":{"archosargus","archosarguses"},
"archosaur":{"archosaur","archosaurs"},
"archosauria":{"archosauria","archosaurias"},
"archosaurian":{"archosaurian","archosaurians"},
"archpriest":{"archpriest","archpriests"},
"archway":{"archway","archways"},
"arcidae":{"arcidae","arcidaes"},
"arcminute":{"arcminute","arcminutes"},
"arcsecond":{"arcsecond","arcseconds"},
"arctic":{"arctic","arctics"},
"arctictis":{"arctictis","arctictises"},
"arctiid":{"arctiid","arctiids"},
"arctiidae":{"arctiidae","arctiidaes"},
"arctium":{"arctium","arctiums"},
"arctocebus":{"arctocebus","arctocebuses"},
"arctocephalus":{"arctocephalus","arctocephaluses"},
"arctonyx":{"arctonyx","arctonyxes"},
"arctostaphylos":{"arctostaphylos","arctostaphyloses"},
"arctotis":{"arctotis","arctotises"},
"arcus":{"arcus","arcuses"},
"ardea":{"ardea","ardeas"},
"ardeidae":{"ardeidae","ardeidaes"},
"ardisia":{"ardisia","ardisias"},
"ardor":{"ardor","ardors"},
"ardour":{"ardour","ardours"},
"arduousness":{"arduousness","arduousnesses"},
"area":{"area","areas"},
"areca":{"areca","arecas"},
"arecaceae":{"arecaceae","arecaceaes"},
"arecidae":{"arecidae","arecidaes"},
"arena":{"arena","arenas"},
"arenaria":{"arenaria","arenarias"},
"arenaria-melanocephala":{"arenaria-melanocephala","arenaria-melanocephalas"},
"arenga":{"arenga","arengas"},
"areola":{"areola","areolae","areolas"},
"arere":{"arere","areres"},
"arethusa":{"arethusa","arethusas"},
"argal":{"argal","argals"},
"argali":{"argali","argalis"},
"argasid":{"argasid","argasids"},
"argasidae":{"argasidae","argasidaes"},
"argemone":{"argemone","argemones"},
"argentina":{"argentina","argentinas"},
"argentinidae":{"argentinidae","argentinidaes"},
"argiope":{"argiope","argiopes"},
"argiopidae":{"argiopidae","argiopidaes"},
"argon":{"argon","argons"},
"argonauta":{"argonauta","argonautas"},
"argonautidae":{"argonautidae","argonautidaes"},
"argonne":{"argonne","argonnes"},
"argonon":{"argonon","argonons"},
"argosy":{"argosies","argosy"},
"argot":{"argot","argots"},
"argue":{"argue","argued","argues","arguing"},
"arguer":{"arguer","arguers"},
"argufy":{"argufied","argufies","argufy","argufying"},
"arguing":{"arguing","arguings"},
"argument":{"argument","arguments"},
"argumentation":{"argumentation","argumentations"},
"argumentum":{"argumenta","argumentum"},
"argus":{"argus","arguses"},
"argusianus":{"argusianus","argusianuses"},
"argy-bargy":{"argy-bargies","argy-bargy"},
"argyle":{"argyle","argyles"},
"argyles":{"argyles","argyleses"},
"argynnis":{"argynnis","argynnises"},
"argyranthemum":{"argyranthemum","argyranthemums"},
"argyreia":{"argyreia","argyreias"},
"argyrol":{"argyrol","argyrols"},
"argyrotaenia":{"argyrotaenia","argyrotaenias"},
"argyroxiphium":{"argyroxiphium","argyroxiphiums"},
"arhant":{"arhant","arhants"},
"arhat":{"arhat","arhats"},
"aria":{"aria","arias"},
"arianrhod":{"arianrhod","arianrhods"},
"arianrod":{"arianrod","arianrods"},
"aricara":{"aricara","aricaras"},
"aridity":{"aridities","aridity"},
"aridness":{"aridness","aridnesses"},
"aries":{"aries","arieses"},
"arietta":{"arietta","ariettas","ariette"},
"ariette":{"ariette","ariettes"},
"ariidae":{"ariidae","ariidaes"},
"arikara":{"arikara","arikaras"},
"arilus":{"arilus","ariluses"},
"ariocarpus":{"ariocarpus","ariocarpuses"},
"ariomma":{"ariomma","ariommas"},
"arioso":{"arioso","ariosos"},
"arisaema":{"arisaema","arisaemas"},
"arisarum":{"arisarum","arisarums"},
"arise":{"arise","arisen","arises","arising","arose"},
"arishth":{"arishth","arishths"},
"arista":{"arista","aristae"},
"aristocracy":{"aristocracies","aristocracy"},
"aristocrat":{"aristocrat","aristocrats"},
"aristolochia":{"aristolochia","aristolochias"},
"aristolochiaceae":{"aristolochiaceae","aristolochiaceaes"},
"aristolochiales":{"aristolochiales","aristolochialeses"},
"aristotelean":{"aristotelean","aristoteleans"},
"aristotelia":{"aristotelia","aristotelias"},
"aristotelian":{"aristotelian","aristotelians"},
"arius":{"arius","ariuses"},
"arizona":{"arizona","arizonas"},
"arizonan":{"arizonan","arizonans"},
"arizonian":{"arizonian","arizonians"},
"ark":{"ark","arks"},
"arkansan":{"arkansan","arkansans"},
"arkansas":{"arkansas","arkansases"},
"arkansawyer":{"arkansawyer","arkansawyers"},
"arm":{"arm","armed","arming","arms"},
"armada":{"armada","armadas"},
"armadillidiidae":{"armadillidiidae","armadillidiidaes"},
"armadillidium":{"armadillidium","armadillidiums"},
"armadillo":{"armadillo","armadillos"},
"armament":{"armament","armaments"},
"armamentarium":{"armamentariia","armamentarium","armamentariums"},
"armchair":{"armchair","armchairs"},
"armenia":{"armenia","armenias"},
"armenian":{"armenian","armenians"},
"armeria":{"armeria","armerias"},
"armful":{"armful","armfuls"},
"armiger":{"armiger","armigers"},
"armillaria":{"armillaria","armillarias"},
"armillariella":{"armillariella","armillariellas"},
"armin":{"armin","armins"},
"arming":{"arming","armings"},
"arminius":{"arminius","arminiuses"},
"armistice":{"armistice","armistices"},
"armlet":{"armlet","armlets"},
"armor":{"armor","armored","armoring","armors"},
"armor-bearer":{"armor-bearer","armor-bearers"},
"armoracia":{"armoracia","armoracias"},
"armorer":{"armorer","armorers"},
"armory":{"armories","armory"},
"armour":{"armour","armours"},
"armourer":{"armourer","armourers"},
"armoury":{"armouries","armoury"},
"armpit":{"armpit","armpits"},
"arms":{"arms","armses"},
"arms-runner":{"arms-runner","arms-runners"},
"armstrong":{"armstrong","armstrongs"},
"army":{"armies","army"},
"armyworm":{"armyworm","armyworms"},
"arnica":{"arnica","arnicas"},
"arno":{"arno","arnos"},
"arnoseris":{"arnoseris","arnoserises"},
"aroid":{"aroid","aroids"},
"aroma":{"aroma","aromas"},
"aromatic":{"aromatic","aromatics"},
"aromatize":{"aromatize","aromatized","aromatizes","aromatizing"},
"arousal":{"arousal","arousals"},
"arouse":{"arouse","aroused","arouses","arousing"},
"arpeggio":{"arpeggio","arpeggios"},
"arquebus":{"arquebus","arquebuses"},
"arrack":{"arrack","arracks"},
"arraign":{"arraign","arraigned","arraigning"},
"arraignment":{"arraignment","arraignments"},
"arrange":{"arrange","arranged","arranges","arranging"},
"arrangement":{"arrangement","arrangements"},
"arranger":{"arranger","arrangers"},
"arranging":{"arranging","arrangings"},
"arras":{"arras","arrases"},
"array":{"array","arrayed","arraying","arrays"},
"arrearage":{"arrearage","arrearages"},
"arrest":{"arrest","arrested","arresting","arrests"},
"arrester":{"arrester","arresters"},
"arrhenatherum":{"arrhenatherum","arrhenatherums"},
"arriere-pensee":{"arriere-pensee","arriere-pensees"},
"arris":{"arris","arrises"},
"arrival":{"arrival","arrivals"},
"arrive":{"arrive","arrived","arrives","arriving"},
"arrivederci":{"arrivederci","arrivedercis"},
"arriver":{"arriver","arrivers"},
"arroba":{"arroba","arrobas"},
"arrogance":{"arrogance","arrogances"},
"arrogate":{"arrogate","arrogated","arrogates","arrogating"},
"arrogation":{"arrogation","arrogations"},
"arrow":{"arrow","arrowed","arrowing","arrows"},
"arrowroot":{"arrowroot","arrowroots"},
"arrowworm":{"arrowworm","arrowworms"},
"arroyo":{"arroyo","arroyos"},
"arse":{"arse","arses"},
"arsehole":{"arsehole","arseholes"},
"arsenal":{"arsenal","arsenals"},
"arsenic":{"arsenic","arsenics"},
"arsenopyrite":{"arsenopyrite","arsenopyrites"},
"arsis":{"arses","arsis"},
"arson":{"arson","arsons"},
"arsonist":{"arsonist","arsonists"},
"art":{"art","arts"},
"artamidae":{"artamidae","artamidaes"},
"artamus":{"artamus","artamuses"},
"artefact":{"artefact","artefacts"},
"artemia":{"artemia","artemias"},
"artemis":{"artemis","artemises"},
"artemisia":{"artemisia","artemisias"},
"arteria":{"arteria","arterias"},
"arteriectasia":{"arteriectasia","arteriectasias"},
"arteriectasis":{"arteriectases","arteriectasis"},
"arteriola":{"arteriola","arteriolas"},
"arteriole":{"arteriole","arterioles"},
"arteriosclerosis":{"arterioscleroses","arteriosclerosis"},
"artery":{"arteries","artery"},
"arthropoda":{"arthropoda","arthropodas"},
"arthropteris":{"arthropteris","arthropterises"},
"arthur":{"arthur","arthurs"},
"artichoke":{"artichoke","artichokes"},
"article":{"article","articled","articles","articling"},
"articulate":{"articulate","articulated","articulates","articulating"},
"articulateness":{"articulateness","articulatenesses"},
"articulatio":{"articulatio","articulatios"},
"articulation":{"articulation","articulations"},
"artifact":{"artifact","artifacts"},
"artifice":{"artifice","artifices"},
"artificer":{"artificer","artificers"},
"artillery":{"artilleries","artillery"},
"artilleryman":{"artilleryman","artillerymen"},
"artiodactyl":{"artiodactyl","artiodactyls"},
"artiodactyla":{"artiodactyla","artiodactylas"},
"artisan":{"artisan","artisans"},
"artist":{"artist","artists"},
"artistry":{"artistries","artistry"},
"artlessness":{"artlessness","artlessnesses"},
"artocarpus":{"artocarpus","artocarpuses"},
"arts":{"arts","artses"},
"artsd":{"artsd","artsds"},
"artwork":{"artwork","artworks"},
"arty":{"artier","artiest","arty"},
"arugula":{"arugula","arugulas"},
"arui":{"arui","aruis"},
"arum":{"arum","arums"},
"arundinaria":{"arundinaria","arundinarias"},
"arundo":{"arundo","arundos"},
"aruspex":{"aruspex","aruspices"},
"arvicola":{"arvicola","arvicolas"},
"aryan":{"aryan","aryans"},
"arytaenoid":{"arytaenoid","arytaenoids"},
"arytenoid":{"arytenoid","arytenoids"},
"as":{"as","ases"},
"asamiya":{"asamiya","asamiyas"},
"asarabacca":{"asarabacca","asarabaccas"},
"asarum":{"asarum","asarums"},
"ascaphidae":{"ascaphidae","ascaphidaes"},
"ascaphus":{"ascaphus","ascaphuses"},
"ascaridae":{"ascaridae","ascaridaes"},
"ascaridia":{"ascaridia","ascaridias"},
"ascaris":{"ascaris","ascarises"},
"ascend":{"ascend","ascended","ascending","ascends"},
"ascendance":{"ascendance","ascendances"},
"ascendancy":{"ascendancies","ascendancy"},
"ascendant":{"ascendant","ascendants"},
"ascendence":{"ascendence","ascendences"},
"ascendency":{"ascendencies","ascendency"},
"ascendent":{"ascendent","ascendents"},
"ascending":{"ascending","ascendings"},
"ascension":{"ascension","ascensions"},
"ascent":{"ascent","ascents"},
"ascertain":{"ascertain","ascertained","ascertaining","ascertains"},
"ascesis":{"asceses","ascesis"},
"ascetic":{"ascetic","ascetics"},
"asceticism":{"asceticism","asceticisms"},
"aschelminthes":{"aschelminthes","aschelmintheses"},
"ascidiaceae":{"ascidiaceae","ascidiaceaes"},
"ascidium":{"ascidcidia","ascidia","ascidium"},
"asclepiadaceae":{"asclepiadaceae","asclepiadaceaes"},
"asclepias":{"asclepias","asclepiases"},
"ascogonium":{"ascogonia","ascogonium"},
"ascomycete":{"ascomycete","ascomycetes"},
"ascomycetes":{"ascomycetes","ascomyceteses"},
"ascomycota":{"ascomycota","ascomycotas"},
"ascomycotina":{"ascomycotina","ascomycotinas"},
"ascophyllum":{"ascophyllum","ascophyllums"},
"ascribe":{"ascribe","ascribed","ascribes","ascribing"},
"ascription":{"ascription","ascriptions"},
"ascus":{"asci","ascus"},
"asdic":{"asdic","asdics"},
"asepsis":{"asepses","asepsis"},
"asexuality":{"asexualities","asexuality"},
"ash":{"ash","ashes"},
"ashbin":{"ashbin","ashbins"},
"ashcake":{"ashcake","ashcakes"},
"ashcan":{"ashcan","ashcans"},
"ashir":{"ashir","ashirs"},
"ashkenazi":{"ashkenazi","ashkenazim"},
"ashkhabad":{"ashkhabad","ashkhabads"},
"ashtray":{"ashtray","ashtrays"},
"ashur":{"ashur","ashurs"},
"ashy":{"ashier","ashiest","ashy"},
"asian":{"asian","asians"},
"asiatic":{"asiatic","asiatics"},
"aside":{"aside","asides"},
"asilidae":{"asilidae","asilidaes"},
"asimina":{"asimina","asiminas"},
"asio":{"asio","asios"},
"ask":{"ask","asked","asking","asks"},
"asker":{"asker","askers"},
"asking":{"asking","askings"},
"asl":{"asl","asls"},
"asp":{"asp","asps"},
"aspalathus":{"aspalathus","aspalathuses"},
"asparagaceae":{"asparagaceae","asparagaceaes"},
"asparagus":{"asparagus","asparaguses"},
"aspect":{"aspect","aspects"},
"aspergill":{"aspergill","aspergills"},
"aspergillaceae":{"aspergillaceae","aspergillaceaes"},
"aspergillales":{"aspergillales","aspergillaleses"},
"aspergillosis":{"aspergilloses","aspergillosis"},
"aspergillum":{"aspergilla","aspergillum","aspergillums"},
"aspergillus":{"aspergillus","aspergilluses"},
"asperity":{"asperities","asperity"},
"asperse":{"asperse","aspersed","asperses","aspersing"},
"aspersion":{"aspersion","aspersions"},
"aspersorium":{"aspersoria","aspersorium"},
"asperula":{"asperula","asperulas"},
"asphalt":{"asphalt","asphalted","asphalting","asphalts"},
"asphodelaceae":{"asphodelaceae","asphodelaceaes"},
"asphodeline":{"asphodeline","asphodelines"},
"asphodelus":{"asphodelus","asphodeluses"},
"asphyxiate":{"asphyxiate","asphyxiated","asphyxiates","asphyxiating"},
"asphyxiation":{"asphyxiation","asphyxiations"},
"aspidelaps":{"aspidelaps","aspidelapses"},
"aspidiotus":{"aspidiotus","aspidiotuses"},
"aspidistra":{"aspidistra","aspidistras"},
"aspidophoroides":{"aspidophoroides","aspidophoroideses"},
"aspirant":{"aspirant","aspirants"},
"aspirate":{"aspirate","aspirated","aspirates","aspirating"},
"aspiration":{"aspiration","aspirations"},
"aspire":{"aspire","aspired","aspires","aspiring"},
"aspirin":{"aspirin","aspirins"},
"aspis":{"aspis","aspises"},
"aspleniaceae":{"aspleniaceae","aspleniaceaes"},
"asplenium":{"asplenium","aspleniums"},
"ass":{"ass","asses"},
"ass-kisser":{"ass-kisser","ass-kissers"},
"assagai":{"assagai","assagais","assegais"},
"assail":{"assail","assailed","assailing","assails"},
"assailant":{"assailant","assailants"},
"assamese":{"assamese","assameses"},
"assassin":{"assassin","assassins"},
"assassinate":{"assassinate","assassinated","assassinating"},
"assassination":{"assassination","assassinations"},
"assassinator":{"assassinator","assassinators"},
"assault":{"assault","assaulted","assaulting","assaults"},
"assay":{"assay","assayed","assaying","assays"},
"assay-mark":{"assay-mark","assay-marks"},
"assayer":{"assayer","assayers"},
"assegai":{"assegai","assegais"},
"assemblage":{"assemblage","assemblages"},
"assemble":{"assemble","assembled","assembles","assembling"},
"assembler":{"assembler","assemblers"},
"assembling":{"assembling","assemblings"},
"assembly":{"assemblies","assembly"},
"assemblyman":{"assemblyman","assemblymen"},
"assent":{"assent","assented","assenting","assents"},
"assenting":{"assenting","assentings"},
"assentor":{"assentor","assentors"},
"assert":{"assert","asserted","asserting","asserts"},
"assertion":{"assertion","assertions"},
"assertiveness":{"assertiveness","assertivenesses"},
"assertor":{"assertor","assertors"},
"assess":{"assess","assessed","assesses","assessing"},
"assessment":{"assessment","assessments"},
"assessor":{"assessor","assessors"},
"asset":{"asset","assets"},
"asseverate":{"asseverate","asseverated","asseverates","asseverating"},
"asseveration":{"asseveration","asseverations"},
"asshole":{"asshole","assholes"},
"assiduity":{"assiduities","assiduity"},
"assiduousness":{"assiduousness","assiduousnesses"},
"assign":{"assign","assigned","assigning","assigns"},
"assignat":{"assignat","assignats"},
"assignation":{"assignation","assignations"},
"assigning":{"assigning","assignings"},
"assignment":{"assignment","assignments"},
"assimilate":{"assimilate","assimilated","assimilates","assimilating"},
"assimilation":{"assimilation","assimilations"},
"assist":{"assist","assisted","assisting","assists"},
"assistance":{"assistance","assistances"},
"assistant":{"assistant","assistants"},
"assize":{"assize","assizes"},
"assizes":{"assizes","assizeses"},
"associability":{"associabilities","associability"},
"associableness":{"associableness","associablenesses"},
"associate":{"associate","associated","associates","associating"},
"association":{"association","associations"},
"assoil":{"assoil","assoiled","assoiling","assoils"},
"assonance":{"assonance","assonances"},
"assort":{"assort","assorted","assorting","assorts"},
"assortment":{"assortment","assortments"},
"assouan":{"assouan","assouans"},
"assuage":{"assuage","assuaged","assuages","assuaging"},
"assuagement":{"assuagement","assuagements"},
"assuan":{"assuan","assuans"},
"assume":{"assume","assumed","assumes","assuming"},
"assumption":{"assumption","assumptions"},
"assurance":{"assurance","assurances"},
"assure":{"assure","assured","assures","assuring"},
"assuredness":{"assuredness","assurednesses"},
"astacidae":{"astacidae","astacidaes"},
"astacura":{"astacura","astacuras"},
"astacus":{"astacus","astacuses"},
"astatine":{"astatine","astatines"},
"asteraceae":{"asteraceae","asteraceaes"},
"asteridae":{"asteridae","asteridaes"},
"asterisk":{"asterisk","asterisked","asterisking","asterisks"},
"asteroid":{"asteroid","asteroids"},
"asteroidea":{"asteroidea","asteroideas"},
"asterope":{"asterope","asteropes"},
"asthenia":{"asthenia","asthenias"},
"asthenopia":{"asthenopia","asthenopias"},
"astheny":{"asthenies","astheny"},
"asthma":{"asthma","asthmas"},
"astigmatism":{"astigmatism","astigmatisms"},
"astigmia":{"astigmia","astigmias"},
"astonish":{"astonish","astonished","astonishes","astonishing"},
"astonishment":{"astonishment","astonishments"},
"astound":{"astound","astounded","astounding","astounds"},
"astragal":{"astragal","astragals"},
"astragalus":{"astragali","astragalus","astragaluses"},
"astreus":{"astreus","astreuses"},
"astringence":{"astringence","astringences"},
"astringency":{"astringencies","astringency"},
"astringent":{"astringent","astringents"},
"astroglia":{"astroglia","astroglias"},
"astrolatry":{"astrolatries","astrolatry"},
"astrologer":{"astrologer","astrologers"},
"astrologist":{"astrologist","astrologists"},
"astrology":{"astrologies","astrology"},
"astroloma":{"astroloma","astrolomas"},
"astronaut":{"astronaut","astronauts"},
"astronautics":{"astronautics","astronauticses"},
"astronavigation":{"astronavigation","astronavigations"},
"astronium":{"astronium","astroniums"},
"astronomer":{"astronomer","astronomers"},
"astronomy":{"astronomies","astronomy"},
"astrophyton":{"astrophyton","astrophytons"},
"astropogon":{"astropogon","astropogons"},
"astuteness":{"astuteness","astutenesses"},
"asuncion":{"asuncion","asuncions"},
"aswan":{"aswan","aswans"},
"asylum":{"asylum","asylums"},
"asymmetry":{"asymmetries","asymmetry"},
"asynchronism":{"asynchronism","asynchronisms"},
"asynchrony":{"asynchronies","asynchrony"},
"asynclitism":{"asynclitism","asynclitisms"},
"asyndeton":{"asyndeta","asyndeton"},
"asynergia":{"asynergia","asynergias"},
"asynergy":{"asynergies","asynergy"},
"asystole":{"asystole","asystoles"},
"at":{"at","ats"},
"at-bat":{"at-bat","at-bats"},
"atabrine":{"atabrine","atabrines"},
"atakapa":{"atakapa","atakapas"},
"atakapan":{"atakapan","atakapans"},
"ataman":{"ataman","atamans"},
"atar":{"atar","atars"},
"ataractic":{"ataractic","ataractics"},
"atarax":{"atarax","ataraxes"},
"ataraxic":{"ataraxic","ataraxics"},
"ataraxis":{"ataraxes","ataraxis"},
"atavism":{"atavism","atavisms"},
"atavist":{"atavist","atavists"},
"ataxia":{"ataxia","ataxias"},
"ataxy":{"ataxies","ataxy"},
"atayalic":{"atayalic","atayalics"},
"ateleiosis":{"ateleioses","ateleiosis"},
"ateles":{"ateles","ateleses"},
"atelier":{"atelier","ateliers"},
"ateliosis":{"atelioses","ateliosis"},
"atenolol":{"atenolol","atenolols"},
"athabascan":{"athabascan","athabascans"},
"athabaskan":{"athabaskan","athabaskans"},
"athapascan":{"athapascan","athapascans"},
"athapaskan":{"athapaskan","athapaskans"},
"athar":{"athar","athars"},
"atheism":{"atheism","atheisms"},
"atheist":{"atheist","atheists"},
"athena":{"athena","athenas"},
"athenaeum":{"athenaeum","athenaeums"},
"athene":{"athene","athenes"},
"atheneum":{"atheneum","atheneums"},
"athens":{"athens","athenses"},
"atherinidae":{"atherinidae","atherinidaes"},
"atherinopsis":{"atherinopses","atherinopsis"},
"atherodyde":{"atherodyde","atherodydes"},
"atheroma":{"atheroma","atheromas","atheromata"},
"atherosclerosis":{"atheroscleroses","atherosclerosis"},
"atherurus":{"atherurus","atheruruses"},
"athiorhodaceae":{"athiorhodaceae","athiorhodaceaes"},
"athlete":{"athlete","athletes"},
"athleticism":{"athleticism","athleticisms"},
"athletics":{"athletics","athleticses"},
"athodyd":{"athodyd","athodyds"},
"athrotaxis":{"athrotaxes","athrotaxis"},
"athyriaceae":{"athyriaceae","athyriaceaes"},
"athyrium":{"athyrium","athyriums"},
"atlanta":{"atlanta","atlantas"},
"atlantic":{"atlantic","atlantics"},
"atlantides":{"atlantides","atlantideses"},
"atlas":{"atlantes","atlas","atlases"},
"atm":{"atm","atms"},
"atmolysis":{"atmolyses","atmolysis"},
"atmometer":{"atmometer","atmometers"},
"atmosphere":{"atmosphere","atmospheres"},
"atmospherics":{"atmospherics","atmosphericses"},
"atom":{"atom","atoms"},
"atomisation":{"atomisation","atomisations"},
"atomiser":{"atomiser","atomisers"},
"atomization":{"atomization","atomizations"},
"atomize":{"atomize","atomized","atomizes","atomizing"},
"atomizer":{"atomizer","atomizers"},
"atomy":{"atomies","atomy"},
"atonalism":{"atonalism","atonalisms"},
"atonality":{"atonalities","atonality"},
"atone":{"atone","atoned","atones","atoning"},
"atonement":{"atonement","atonements"},
"atonia":{"atonia","atonias"},
"atonicity":{"atonicities","atonicity"},
"atony":{"atonies","atony"},
"atopognosia":{"atopognosia","atopognosias"},
"atopognosis":{"atopognoses","atopognosis"},
"atopy":{"atopies","atopy"},
"atp":{"atp","atps"},
"atrichornis":{"atrichornis","atrichornises"},
"atrichornithidae":{"atrichornithidae","atrichornithidaes"},
"atriplex":{"atriplex","atriplexes"},
"atrium":{"atria","atrium","atriums"},
"atrociousness":{"atrociousness","atrociousnesses"},
"atrocity":{"atrocities","atrocity"},
"atromid-s":{"atromid-s","atromid-ses"},
"atropa":{"atropa","atropas"},
"atrophy":{"atrophied","atrophies","atrophy","atrophying"},
"atropidae":{"atropidae","atropidaes"},
"atrovent":{"atrovent","atrovents"},
"attacapa":{"attacapa","attacapas"},
"attacapan":{"attacapan","attacapans"},
"attach":{"attach","attached","attaches","attaching"},
"attache":{"attache","attaches"},
"attachment":{"attachment","attachments"},
"attack":{"attack","attacked","attacking","attacks"},
"attacker":{"attacker","attackers"},
"attain":{"attain","attained","attaining","attains"},
"attainability":{"attainabilities","attainability"},
"attainableness":{"attainableness","attainablenesses"},
"attainder":{"attainder","attainders"},
"attainment":{"attainment","attainments"},
"attaint":{"attaint","attainted","attainting","attaints"},
"attalea":{"attalea","attaleas"},
"attar":{"attar","attars"},
"attempt":{"attempt","attempted","attempting","attempts"},
"attend":{"attend","attended","attending","attends"},
"attendance":{"attendance","attendances"},
"attendant":{"attendant","attendants"},
"attender":{"attender","attenders"},
"attending":{"attending","attendings"},
"attention":{"attention","attentions"},
"attentiveness":{"attentiveness","attentivenesses"},
"attenuate":{"attenuate","attenuated","attenuates","attenuating"},
"attenuation":{"attenuation","attenuations"},
"attest":{"attest","attested","attesting","attests"},
"attestant":{"attestant","attestants"},
"attestation":{"attestation","attestations"},
"attic":{"attic","attics"},
"atticus":{"atticus","atticuses"},
"attila":{"attila","attilas"},
"attire":{"attire","attired","attires","attiring"},
"attitude":{"attitude","attitudes"},
"attitudinize":{"attitudinize","attitudinized","attitudinizes","attitudinizing"},
"attorn":{"attorn","attorned","attorning"},
"attorney":{"attorney","attorneys"},
"attorney-at-law":{"attorney-at-law","attorneys-at-law"},
"attract":{"attract","attracted","attracting","attracts"},
"attraction":{"attraction","attractions"},
"attractiveness":{"attractiveness","attractivenesses"},
"attribute":{"attribute","attributed","attributes","attributing"},
"attribution":{"attribution","attributions"},
"attrition":{"attrition","attritions"},
"attune":{"attune","attuned","attuning"},
"atypicality":{"atypicalities","atypicality"},
"au":{"au","aus"},
"aubergine":{"aubergine","aubergines"},
"auction":{"auction","auctioned","auctioning","auctions"},
"auctioneer":{"auctioneer","auctioneered","auctioneering","auctioneers"},
"audaciousness":{"audaciousness","audaciousnesses"},
"audacity":{"audacities","audacity"},
"audad":{"audad","audads"},
"auden":{"auden","audens"},
"audibility":{"audibilities","audibility"},
"audibleness":{"audibleness","audiblenesses"},
"audience":{"audience","audiences"},
"audio":{"audio","audios"},
"audiology":{"audiologies","audiology"},
"audiometry":{"audiometries","audiometry"},
"audiovisual":{"audiovisual","audiovisuals"},
"audit":{"audit","audited","auditing","audits"},
"audition":{"audition","auditioned","auditioning","auditions"},
"auditor":{"auditor","auditors"},
"auditorium":{"auditoria","auditorium","auditoriums","auditotoria","auditotoriums"},
"auditory":{"auditories","auditory"},
"aug":{"aug","augs"},
"auger":{"auger","augers"},
"aught":{"aught","aughts"},
"augment":{"augment","augmented","augmenting","augments"},
"augur":{"augur","augured","auguring","augurs"},
"augury":{"auguries","augury"},
"august":{"august","augusts"},
"augusta":{"augusta","augustas"},
"augustine":{"augustine","augustines"},
"augustinian":{"augustinian","augustinians"},
"augustus":{"augustus","augustuses"},
"aulacorhyncus":{"aulacorhyncus","aulacorhyncuses"},
"aulostomidae":{"aulostomidae","aulostomidaes"},
"aulostomus":{"aulostomus","aulostomuses"},
"aunt":{"aunt","aunts"},
"auntie":{"auntie","aunties"},
"aunty":{"aunties","aunty"},
"aura":{"aura","aurae","auras"},
"aurar":{"aurar","aurars"},
"aureola":{"aureola","aureolas"},
"aureolaria":{"aureolaria","aureolarias"},
"aureole":{"aureolas","aureole","aureoles"},
"aureomycin":{"aureomycin","aureomycins"},
"aureus":{"aurei","aureus"},
"auricle":{"auricle","auricles"},
"auricula":{"auricula","auriculas"},
"auricularia":{"auricularia","auricularias"},
"auriculariaceae":{"auriculariaceae","auriculariaceaes"},
"auriculariales":{"auriculariales","auricularialeses"},
"auriparus":{"auriparus","auriparuses"},
"aurochs":{"aurochs","aurochses"},
"aurora":{"aurora","aurorae","auroras"},
"auscultate":{"auscultate","auscultated","auscultating"},
"auspex":{"auspex","auspexes","auspices"},
"auspice":{"auspice","auspices"},
"auspices":{"auspices","auspiceses"},
"auspiciousness":{"auspiciousness","auspiciousnesses"},
"aussie":{"aussie","aussies"},
"austereness":{"austereness","austerenesses"},
"austerity":{"austerities","austerity"},
"austerlitz":{"austerlitz","austerlitzs"},
"austin":{"austin","austins"},
"australia":{"australia","australias"},
"australian":{"australian","australians"},
"australopithecus":{"australopithecus","australopithecuses"},
"austria":{"austria","austrias"},
"austro-asiatic":{"austro-asiatic","austro-asiatics"},
"austrocedrus":{"austrocedrus","austrocedruses"},
"austronesian":{"austronesian","austronesians"},
"austrotaxus":{"austrotaxus","austrotaxuses"},
"autacoid":{"autacoid","autacoids"},
"autarchy":{"autarchies","autarchy"},
"autarky":{"autarkies","autarky"},
"authenticate":{"authenticate","authenticated","authenticating"},
"authentication":{"authentication","authentications"},
"authenticity":{"authenticities","authenticity"},
"author":{"author","authored","authoring","authors"},
"authorisation":{"authorisation","authorisations"},
"authoritarian":{"authoritarian","authoritarians"},
"authoritarianism":{"authoritarianism","authoritarianisms"},
"authorities":{"authorities","authoritieses"},
"authority":{"authorities","authority"},
"authorization":{"authorization","authorizations"},
"authorize":{"authorize","authorized","authorizes","authorizing"},
"authorship":{"authorship","authorships"},
"auto":{"auto","autoed","autoing","autos"},
"auto-changer":{"auto-changer","auto-changers"},
"auto-da-fe":{"auto-da-fe","autos-da-fe"},
"auto-mechanic":{"auto-mechanic","auto-mechanics"},
"autoantibody":{"autoantibodies","autoantibody"},
"autobiographer":{"autobiographer","autobiographers"},
"autobiography":{"autobiographies","autobiography"},
"autobus":{"autobus","autobuses"},
"autocatalysis":{"autocatalyses","autocatalysis"},
"autochthon":{"autochthon","autochthones","autochthons"},
"autochthony":{"autochthonies","autochthony"},
"autocoid":{"autocoid","autocoids"},
"autocracy":{"autocracies","autocracy"},
"autocrat":{"autocrat","autocrats"},
"autocue":{"autocue","autocues"},
"autoeroticism":{"autoeroticism","autoeroticisms"},
"autoerotism":{"autoerotism","autoerotisms"},
"autogenesis":{"autogeneses","autogenesis"},
"autogenics":{"autogenics","autogenicses"},
"autogeny":{"autogenies","autogeny"},
"autogiro":{"autogiro","autogiros"},
"autograph":{"autograph","autographed","autographing","autographs"},
"autogyro":{"autogyro","autogyros"},
"autolatry":{"autolatries","autolatry"},
"autolyze":{"autolyze","autolyzed","autolyzing"},
"automate":{"automate","automated","automates","automating"},
"automatic":{"automatic","automatics"},
"automation":{"automation","automations"},
"automatize":{"automatize","automatized","automatizes","automatizing"},
"automaton":{"automata","automaton","automatons"},
"automeris":{"automeris","automerises"},
"automobile":{"automobile","automobiles"},
"automobilist":{"automobilist","automobilists"},
"autonomy":{"autonomies","autonomy"},
"autophyte":{"autophyte","autophytes"},
"autopilot":{"autopilot","autopilots"},
"autopsy":{"autopsies","autopsy"},
"autosome":{"autosome","autosomes"},
"autostrada":{"autostrada","autostradas","autostrade"},
"autosuggestion":{"autosuggestion","autosuggestions"},
"autotomize":{"autotomize","autotomized","autotomizing"},
"autotomy":{"autotomies","autotomy"},
"autotroph":{"autotroph","autotrophs"},
"autotype":{"autotype","autotypes"},
"autotypy":{"autotypies","autotypy"},
"autumn":{"autumn","autumns"},
"auxiliary":{"auxiliaries","auxiliary"},
"av":{"av","avs"},
"avadavat":{"avadavat","avadavats"},
"avahi":{"avahi","avahis"},
"avail":{"avail","availed","availing","avails"},
"availability":{"availabilities","availability"},
"availableness":{"availableness","availablenesses"},
"avalanche":{"avalanche","avalanched","avalanches","avalanching"},
"avalokiteshvara":{"avalokiteshvara","avalokiteshvaras"},
"avalokitesvara":{"avalokitesvara","avalokitesvaras"},
"avaram":{"avaram","avarams"},
"avarice":{"avarice","avarices"},
"avariciousness":{"avariciousness","avariciousnesses"},
"avaritia":{"avaritia","avaritias"},
"avatar":{"avatar","avatars"},
"avena":{"avena","avenas"},
"avenge":{"avenge","avenged","avenges","avenging"},
"avenger":{"avenger","avengers"},
"avens":{"avens","avenses"},
"aventail":{"aventail","aventails"},
"aventurine":{"aventurine","aventurines"},
"avenue":{"avenue","avenues"},
"aver":{"aver","avering","averred","averring","avers"},
"average":{"average","averaged","averages","averaging"},
"averageness":{"averageness","averagenesses"},
"averment":{"averment","averments"},
"averrhoa":{"averrhoa","averrhoas"},
"aversion":{"aversion","aversions"},
"avert":{"avert","averted","averting","averts"},
"aves":{"aves","aveses"},
"avesta":{"avesta","avestas"},
"avestan":{"avestan","avestans"},
"aviary":{"aviaries","aviary"},
"aviate":{"aviate","aviated","aviates","aviating"},
"aviation":{"aviation","aviations"},
"aviator":{"aviator","aviators"},
"aviatress":{"aviatress","aviatresses"},
"aviatrix":{"aviatrices","aviatrix","aviatrixes"},
"avicennia":{"avicennia","avicennias"},
"avicenniaceae":{"avicenniaceae","avicenniaceaes"},
"avidity":{"avidities","avidity"},
"avidness":{"avidness","avidnesses"},
"avifauna":{"avifauna","avifaunae","avifaunas"},
"avitaminosis":{"avitaminoses","avitaminosis"},
"avocado":{"avocado","avocados"},
"avocation":{"avocation","avocations"},
"avoid":{"avoid","avoided","avoiding","avoids"},
"avoidance":{"avoidance","avoidances"},
"avoirdupois":{"avoirdupois","avoirdupoises"},
"avouch":{"avouch","avouched","avouches","avouching"},
"avow":{"avow","avowed","avowing","avows"},
"avowal":{"avowal","avowals"},
"avulse":{"avulse","avulsed","avulsing"},
"await":{"await","awaited","awaiting","awaits"},
"awake":{"awake","awaked","awakes","awaking","awoke","awoken"},
"awaken":{"awaken","awakened","awakening","awakens"},
"awakening":{"awakening","awakenings"},
"award":{"award","awarded","awarding","awards"},
"awarding":{"awarding","awardings"},
"awareness":{"awareness","awarenesses"},
"awe":{"awe","awed","awes","awing"},
"awfulness":{"awfulness","awfulnesses"},
"awkward":{"awkward","awkwarder","awkwardest"},
"awkwardness":{"awkwardness","awkwardnesses"},
"awlwort":{"awlwort","awlworts"},
"awning":{"awning","awnings"},
"ax":{"ax","axed","axes","axing"},
"axe":{"axe","axed","axes","axing"},
"axerophthol":{"axerophthol","axerophthols"},
"axilemma":{"axilemma","axilemmata"},
"axilla":{"axilla","axillae","axillas"},
"axillary":{"axillaries","axillary"},
"axiom":{"axiom","axioms"},
"axis":{"axes","axis"},
"axle":{"axle","axles"},
"axman":{"axman","axmen"},
"axolotl":{"axolotl","axolotls"},
"axon":{"axon","axons"},
"axone":{"axone","axones"},
"axseed":{"axseed","axseeds"},
"ayapana":{"ayapana","ayapanas"},
"aye":{"aye","ayes"},
"aye-aye":{"aye-aye","aye-ayes"},
"aymara":{"aymara","aymaras"},
"aythya":{"aythya","aythyas"},
"az":{"az","azs"},
"azactam":{"azactam","azactams"},
"azadirachta":{"azadirachta","azadirachtas"},
"azalea":{"azalea","azaleas"},
"azaleastrum":{"azaleastrum","azaleastrums"},
"azathioprine":{"azathioprine","azathioprines"},
"azedarach":{"azedarach","azedaraches"},
"azederach":{"azederach","azederaches"},
"azerbaijan":{"azerbaijan","azerbaijans"},
"azerbaijani":{"azerbaijani","azerbaijanis"},
"azerbajdzhan":{"azerbajdzhan","azerbajdzhans"},
"azidothymidine":{"azidothymidine","azidothymidines"},
"azimuth":{"azimuth","azimuths"},
"azoimide":{"azoimide","azoimides"},
"azolla":{"azolla","azollas"},
"azollaceae":{"azollaceae","azollaceaes"},
"azotaemia":{"azotaemia","azotaemias"},
"azotemia":{"azotemia","azotemias"},
"azt":{"azt","azts"},
"aztreonam":{"aztreonam","aztreonams"},
"azure":{"azure","azures"},
"b":{"b","bs"},
"b-girl":{"b-girl","b-girls"},
"b-horizon":{"b-horizon","b-horizons"},
"ba":{"ba","bas"},
"baa":{"baa","baaed","baaing","baas"},
"baal":{"baal","baalim","baals"},
"baba":{"baba","babas"},
"babassu":{"babassu","babassus"},
"babbiting":{"babbiting","babbitings"},
"babbitt":{"babbitt","babbitted","babbitting","babbitts"},
"babbitting":{"babbitting","babbittings"},
"babble":{"babble","babbled","babbles","babbling"},
"babbler":{"babbler","babblers"},
"babbling":{"babbling","babblings"},
"babe":{"babe","babes"},
"babel":{"babel","babels"},
"babesia":{"babesia","babesias"},
"babesiidae":{"babesiidae","babesiidaes"},
"babi":{"babi","babis"},
"babinski":{"babinski","babinskis"},
"babiroussa":{"babiroussa","babiroussas"},
"babirusa":{"babirusa","babirusas"},
"babirussa":{"babirussa","babirussas"},
"babka":{"babka","babkas"},
"baboo":{"baboo","baboos"},
"baboon":{"baboon","baboons"},
"babu":{"babu","babus"},
"babushka":{"babushka","babushkas"},
"baby":{"babied","babies","baby","babying"},
"baby-sit":{"baby-sat","baby-sit","baby-sits","baby-sitting"},
"baby-walker":{"baby-walker","baby-walkers"},
"babyhood":{"babyhood","babyhoods"},
"babyminder":{"babyminder","babyminders"},
"babyrousa":{"babyrousa","babyrousas"},
"babysitter":{"babysitter","babysitters"},
"bacca":{"bacca","baccas"},
"baccalaureate":{"baccalaureate","baccalaureates"},
"baccarat":{"baccarat","baccarats"},
"bacchanal":{"bacchanal","bacchanals"},
"bacchanalia":{"bacchanalia","bacchanalias"},
"bacchant":{"bacchant","bacchantes","bacchants"},
"baccharis":{"baccharis","baccharises"},
"bacchius":{"bacchii","bacchius"},
"baccy":{"baccies","baccy"},
"bach":{"bach","bached","baches","baching"},
"bachelor":{"bachelor","bachelored","bacheloring","bachelors"},
"bachelor-at-arms":{"bachelor-at-arms","bachelor-at-armses","bachelors-at-arms"},
"bacillaceae":{"bacillaceae","bacillaceaes"},
"bacillariophyceae":{"bacillariophyceae","bacillariophyceaes"},
"bacilli":{"bacilli","bacillis"},
"bacillus":{"bacilli","bacillus"},
"back":{"back","backed","backing","backs"},
"back-check":{"back-check","back-checked","back-checking"},
"back-number":{"back-number","back-numbers"},
"back-order":{"back-order","back-ordered","back-ordering"},
"back-pedal":{"back-pedal","back-pedaled","back-pedaling","back-pedalled","back-pedalling","back-pedals"},
"backache":{"backache","backaches"},
"backbite":{"backbit","backbite","backbites","backbiting","backbitten"},
"backbiter":{"backbiter","backbiters"},
"backboard":{"backboard","backboards"},
"backbone":{"backbone","backbones"},
"backchat":{"backchat","backchats"},
"backcloth":{"backcloth","backcloths"},
"backcross":{"backcross","backcrossed","backcrossing"},
"backdate":{"backdate","backdated","backdating"},
"backdown":{"backdown","backdowns"},
"backdrop":{"backdrop","backdrops"},
"backer":{"backer","backers"},
"backfill":{"backfill","backfilled","backfilling"},
"backfire":{"backfire","backfired","backfires","backfiring"},
"backflow":{"backflow","backflows"},
"backflowing":{"backflowing","backflowings"},
"background":{"background","backgrounded","backgrounding","backgrounds"},
"backgrounding":{"backgrounding","backgroundings"},
"backhand":{"backhand","backhands"},
"backing":{"backing","backings"},
"backlash":{"backlash","backlashes"},
"backlog":{"backlog","backlogs"},
"backpack":{"backpack","backpacked","backpacking","backpacks"},
"backpacking":{"backpacking","backpackings"},
"backpedal":{"backpedal","backpedaled","backpedaling","backpedalled","backpedalling"},
"backrest":{"backrest","backrests"},
"backsheesh":{"backsheesh","backsheeshes"},
"backside":{"backside","backsides"},
"backslide":{"backslid","backslidden","backslide","backslides","backsliding"},
"backslider":{"backslider","backsliders"},
"backsliding":{"backsliding","backslidings"},
"backspace":{"backspace","backspaced","backspacing"},
"backspacer":{"backspacer","backspacers"},
"backstage":{"backstage","backstages"},
"backstitch":{"backstitch","backstitched","backstitching"},
"backswimmer":{"backswimmer","backswimmers"},
"backsword":{"backsword","backswords"},
"backtalk":{"backtalk","backtalks"},
"backtrack":{"backtrack","backtracked","backtracking","backtracks"},
"backup":{"backup","backups"},
"backwardness":{"backwardness","backwardnesses"},
"backwash":{"backwash","backwashes"},
"backwoods":{"backwoods","backwoodses"},
"backwoodsman":{"backwoodsman","backwoodsmen"},
"bacon":{"bacon","bacons"},
"bacteremia":{"bacteremia","bacteremias"},
"bacteria":{"bacteria","bacterias"},
"bacteriacide":{"bacteriacide","bacteriacides"},
"bacteriaemia":{"bacteriaemia","bacteriaemias"},
"bactericide":{"bactericide","bactericides"},
"bacteriemia":{"bacteriemia","bacteriemias"},
"bacteriophage":{"bacteriophage","bacteriophages"},
"bacteriostasis":{"bacteriostasis","bacteriostastases"},
"bacterium":{"bacteria","bacterium"},
"bacterize":{"bacterize","bacterized","bacterizes","bacterizing"},
"bacteroidaceae":{"bacteroidaceae","bacteroidaceaes"},
"bacteroides":{"bacteroides","bacteroideses"},
"baculum":{"bacula","baculum","baculums"},
"bad":{"bad","bads","worse","worst"},
"bad-mouth":{"bad-mouth","bad-mouthed","bad-mouthing"},
"baddie":{"baddie","baddies"},
"badge":{"badge","badged","badges","badging"},
"badger":{"badger","badgered","badgering","badgers"},
"badgerer":{"badgerer","badgerers"},
"badgering":{"badgering","badgerings"},
"badinage":{"badinage","badinaged","badinaging"},
"badlands":{"badlands","badlandses"},
"badly":{"badly","worse","worst"},
"badman":{"badman","badmen"},
"badness":{"badness","badnesses"},
"baffle":{"baffle","baffled","baffles","baffling"},
"bafflement":{"bafflement","bafflements"},
"bag":{"bag","bagged","bagging","bags"},
"bagascosis":{"bagascoses","bagascosis"},
"bagassosis":{"bagassoses","bagassosis"},
"bagatelle":{"bagatelle","bagatelles"},
"bagdad":{"bagdad","bagdads"},
"bagful":{"bagful","bagfuls"},
"baggage":{"baggage","baggages"},
"bagger":{"bagger","baggers"},
"bagging":{"bagging","baggings"},
"baggy":{"baggier","baggies","baggiest","baggy"},
"baghdad":{"baghdad","baghdads"},
"bagie":{"bagie","bagies"},
"bagman":{"bagman","bagmen"},
"bagnio":{"bagnio","bagnios"},
"bagpipe":{"bagpipe","bagpipes"},
"bagpiper":{"bagpiper","bagpipers"},
"baguet":{"baguet","baguets"},
"baguette":{"baguette","baguettes"},
"baha'i":{"baha'i","bahais"},
"bahamas":{"bahamas","bahamases"},
"bahasa":{"bahasa","bahasas"},
"bahrain":{"bahrain","bahrains"},
"bahraini":{"bahraini","bahrainis"},
"bahrein":{"bahrein","bahreins"},
"bahreini":{"bahreini","bahreinis"},
"baht":{"baht","bahts"},
"bai":{"bai","bais"},
"baic":{"baic","baics"},
"bail":{"bail","bailed","bailing","bails"},
"bailer":{"bailer","bailers"},
"bailey":{"bailey","baileys"},
"bailiff":{"bailiff","bailiffs"},
"bailor":{"bailor","bailors"},
"bailsman":{"bailsman","bailsmen"},
"bain-marie":{"bain-marie","bains-marie"},
"baiomys":{"baiomys","baiomyses"},
"bairdiella":{"bairdiella","bairdiellas"},
"bait":{"bait","baited","baiting","baits"},
"bake":{"bake","baked","bakes","baking"},
"bakeapple":{"bakeapple","bakeapples"},
"baker":{"baker","bakers"},
"bakery":{"bakeries","bakery"},
"baking":{"baking","bakings"},
"bakra":{"bakra","bakras"},
"baksheesh":{"baksheesh","baksheeshes"},
"bakshis":{"bakshis","bakshises"},
"bakshish":{"bakshish","bakshishes"},
"baku":{"baku","bakus"},
"balaclava":{"balaclava","balaclavas"},
"balaena":{"balaena","balaenas"},
"balaeniceps":{"balaeniceps","balaenicepses"},
"balaenicipitidae":{"balaenicipitidae","balaenicipitidaes"},
"balaenidae":{"balaenidae","balaenidaes"},
"balaenoptera":{"balaenoptera","balaenopteras"},
"balaenopteridae":{"balaenopteridae","balaenopteridaes"},
"balalaika":{"balalaika","balalaikas"},
"balance":{"balance","balanced","balances","balancing"},
"balancer":{"balancer","balancers"},
"balancing":{"balancing","balancings"},
"balanidae":{"balanidae","balanidaes"},
"balanus":{"balanus","balanuses"},
"balas":{"balas","balases"},
"balata":{"balata","balatas"},
"balboa":{"balboa","balboas"},
"balcony":{"balconies","balcony"},
"bald":{"bald","balder","baldest"},
"baldachin":{"baldachin","baldachinos"},
"balder":{"balder","balders"},
"balderdash":{"balderdash","balderdashes"},
"baldhead":{"baldhead","baldheads"},
"baldness":{"baldness","baldnesses"},
"baldpate":{"baldpate","baldpates"},
"baldr":{"baldr","baldrs"},
"baldric":{"baldric","baldrics"},
"baldrick":{"baldrick","baldricks"},
"baldy":{"baldies","baldy"},
"bale":{"bale","baled","bales","baling"},
"baleen":{"baleen","baleens"},
"balefire":{"balefire","balefires"},
"balefulness":{"balefulness","balefulnesses"},
"balibago":{"balibago","balibagos"},
"balistes":{"balistes","balisteses"},
"balistidae":{"balistidae","balistidaes"},
"balk":{"balk","balked","balking","balks"},
"balkanize":{"balkanize","balkanized","balkanizes","balkanizing"},
"balkans":{"balkans","balkanses"},
"balkline":{"balkline","balklines"},
"balky":{"balkier","balkiest","balky"},
"ball":{"ball","balled","balling","balls"},
"ballad":{"ballad","ballads"},
"balladeer":{"balladeer","balladeers"},
"ballast":{"ballast","ballasted","ballasting"},
"ballcock":{"ballcock","ballcocks"},
"ballerina":{"ballerina","ballerinas"},
"ballet":{"ballet","ballets"},
"ballista":{"ballista","ballistae"},
"ballistics":{"ballistics","ballisticses"},
"ballock":{"ballock","ballocks"},
"balloon":{"balloon","ballooned","ballooning","balloons"},
"balloonfish":{"balloonfish","balloonfishes"},
"ballot":{"ballot","balloted","balloting","ballots"},
"ballota":{"ballota","ballotas"},
"balloting":{"balloting","ballotings"},
"ballpark":{"ballpark","ballparks"},
"ballpen":{"ballpen","ballpens"},
"ballplayer":{"ballplayer","ballplayers"},
"ballpoint":{"ballpoint","ballpoints"},
"ballroom":{"ballroom","ballrooms"},
"balls-up":{"balls-up","balls-ups"},
"ballsy":{"ballsier","ballsiest","ballsy"},
"ballup":{"ballup","ballups"},
"ballyhoo":{"ballyhoo","ballyhooed","ballyhooing","ballyhoos"},
"ballyrag":{"ballyrag","ballyragged","ballyragging","ballyrags"},
"balm":{"balm","balms"},
"balmoral":{"balmoral","balmorals"},
"balmy":{"balmier","balmiest","balmy"},
"balochi":{"balochi","balochis"},
"baloney":{"baloney","baloneys"},
"balsa":{"balsa","balsas"},
"balsam":{"balsam","balsams"},
"balsaminaceae":{"balsaminaceae","balsaminaceaes"},
"balsamorhiza":{"balsamorhiza","balsamorhizas"},
"baltic":{"baltic","baltics"},
"balto-slavic":{"balto-slavic","balto-slavics"},
"balto-slavonic":{"balto-slavonic","balto-slavonics"},
"baluchi":{"baluchi","baluchis"},
"baluster":{"baluster","balusters"},
"balusters":{"balusters","balusterses"},
"balustrade":{"balustrade","balustrades"},
"balzac":{"balzac","balzacs"},
"bambara":{"bambara","bambaras"},
"bambino":{"bambini","bambino","bambinos"},
"bamboo":{"bamboo","bamboos"},
"bamboozle":{"bamboozle","bamboozled","bamboozles","bamboozling"},
"bambusa":{"bambusa","bambusas"},
"bambuseae":{"bambuseae","bambuseaes"},
"ban":{"ban","bani","banned","banning","bans"},
"banality":{"banalities","banality"},
"banalize":{"banalize","banalized","banalizing"},
"banana":{"banana","bananas"},
"band":{"band","banded","banding","bands"},
"bandage":{"bandage","bandaged","bandages","bandaging"},
"bandaging":{"bandaging","bandagings"},
"bandana":{"bandana","bandanas"},
"bandanna":{"bandanna","bandannas"},
"bandbox":{"bandbox","bandboxes"},
"bandeau":{"bandeau","bandeaus","bandeaux"},
"bandelet":{"bandelet","bandelets"},
"bandelette":{"bandelette","bandelettes"},
"banderillero":{"banderillero","banderilleros"},
"banding":{"banding","bandings"},
"bandit":{"bandit","bandits","banditti"},
"banditry":{"banditries","banditry"},
"bandlet":{"bandlet","bandlets"},
"bandoleer":{"bandoleer","bandoleers"},
"bandolier":{"bandolier","bandoliers"},
"bandore":{"bandoras","bandore","bandores"},
"bandsman":{"bandsman","bandsmen"},
"bandstand":{"bandstand","bandstands"},
"bandtail":{"bandtail","bandtails"},
"bandwagon":{"bandwagon","bandwagons"},
"bandy":{"bandied","bandieds","bandier","bandies","bandiest","bandy","bandying"},
"bandy-bandy":{"bandy-bandies","bandy-bandy"},
"bane":{"bane","banes"},
"baneberry":{"baneberries","baneberry"},
"bang":{"bang","banged","banging","bangs"},
"banger":{"banger","bangers"},
"bangiaceae":{"bangiaceae","bangiaceaes"},
"banging":{"banging","bangings"},
"bangkok":{"bangkok","bangkoks"},
"bangladesh":{"bangladesh","bangladeshes"},
"bangle":{"bangle","bangles"},
"bangtail":{"bangtail","bangtails"},
"bangui":{"bangui","banguis"},
"banian":{"banian","banians"},
"banish":{"banish","banished","banishes","banishing"},
"banishment":{"banishment","banishments"},
"banister":{"banister","banisters"},
"banjo":{"banjo","banjoes","banjos"},
"bank":{"bank","banked","banking","banks"},
"bankbook":{"bankbook","bankbooks"},
"banker":{"banker","bankers"},
"bankia":{"bankia","bankias"},
"banknote":{"banknote","banknotes"},
"bankroll":{"bankroll","bankrolled","bankrolling","bankrolls"},
"bankrupt":{"bankrupt","bankrupted","bankrupting","bankrupts"},
"bankruptcy":{"bankruptcies","bankruptcy"},
"banner":{"banner","bannered","bannering","banners"},
"banneret":{"banneret","bannerets"},
"banning":{"banning","bannings"},
"bannister":{"bannister","bannisters"},
"banquet":{"banquet","banqueted","banqueting","banquets"},
"banqueting":{"banqueting","banquetings"},
"banteng":{"banteng","bantengs"},
"banter":{"banter","bantered","bantering","banters"},
"banting":{"banting","bantings"},
"bantu":{"bantu","bantus"},
"banyan":{"banyan","banyans"},
"baobab":{"baobab","baobabs"},
"baphia":{"baphia","baphias"},
"baptisia":{"baptisia","baptisias"},
"baptism":{"baptism","baptisms"},
"baptistery":{"baptisteries","baptistery"},
"baptistry":{"baptistries","baptistry"},
"baptists":{"baptists","baptistses"},
"baptize":{"baptize","baptized","baptizes","baptizing"},
"bar":{"bar","barred","barring","bars"},
"baranduki":{"baranduki","barandukis"},
"barb":{"barb","barbed","barbing","barbs"},
"barbacan":{"barbacan","barbacans"},
"barbarea":{"barbarea","barbareas"},
"barbarian":{"barbarian","barbarians"},
"barbarisation":{"barbarisation","barbarisations"},
"barbarism":{"barbarism","barbarisms"},
"barbarity":{"barbarities","barbarity"},
"barbarization":{"barbarization","barbarizations"},
"barbarize":{"barbarize","barbarized","barbarizes","barbarizing"},
"barbarossa":{"barbarossa","barbarossas"},
"barbarousness":{"barbarousness","barbarousnesses"},
"barbasco":{"barbasco","barbascos"},
"barbecue":{"barbecue","barbecued","barbecues","barbecuing"},
"barbel":{"barbel","barbels"},
"barber":{"barber","barbered","barbering","barbers"},
"barberry":{"barberries","barberry"},
"barbican":{"barbican","barbicans"},
"barbital":{"barbital","barbitals"},
"barbitone":{"barbitone","barbitones"},
"barbu":{"barbu","barbus"},
"barcarole":{"barcarole","barcaroles"},
"barcarolle":{"barcarolle","barcarolles"},
"bard":{"bard","barded","barding","bards"},
"bare":{"bare","bared","barer","barest","baring"},
"bareness":{"bareness","barenesses"},
"barf":{"barf","barfed","barfing","barfs"},
"barfly":{"barflies","barfly"},
"bargain":{"bargain","bargained","bargaining","bargains"},
"bargainer":{"bargainer","bargainers"},
"barge":{"barge","barged","barges","barging"},
"bargee":{"bargee","bargees"},
"bargeman":{"bargeman","bargemen"},
"barhop":{"barhop","barhopped","barhopping"},
"barilla":{"barilla","barillas"},
"baring":{"baring","barings"},
"barish":{"barish","barishes"},
"barite":{"barite","barites"},
"baritone":{"baritone","baritones"},
"barium":{"barium","bariums"},
"bark":{"bark","barked","barking","barks"},
"barkeep":{"barkeep","barkeeps"},
"barkeeper":{"barkeeper","barkeepers"},
"barklouse":{"barklice","barklouse"},
"barky":{"barkier","barkiest","barky"},
"barley":{"barley","barleys"},
"barley-sugar":{"barley-sugar","barley-sugars"},
"barleycorn":{"barleycorn","barleycorns"},
"barm":{"barm","barms"},
"barman":{"barman","barmen"},
"barmy":{"barmier","barmiest","barmy"},
"barn":{"barn","barns"},
"barnacle":{"barnacle","barnacles"},
"barnstorm":{"barnstorm","barnstormed","barnstorming","barnstorms"},
"barnstormer":{"barnstormer","barnstormers"},
"barnyard":{"barnyard","barnyards"},
"barometer":{"barometer","barometers"},
"baron":{"baron","barons"},
"baronage":{"baronage","baronages"},
"baronduki":{"baronduki","barondukis"},
"baroness":{"baroness","baronesses"},
"baronet":{"baronet","baronets"},
"baronetcy":{"baronetcies","baronetcy"},
"barony":{"baronies","barony"},
"baroque":{"baroque","baroques"},
"baroqueness":{"baroqueness","baroquenesses"},
"barosaur":{"barosaur","barosaurs"},
"barosaurus":{"barosaurus","barosauruses"},
"barotse":{"barotse","barotses"},
"barque":{"barque","barques"},
"barrack":{"barrack","barracked","barracking","barracks"},
"barracking":{"barracking","barrackings"},
"barracuda":{"barracuda","barracudas"},
"barrage":{"barrage","barraged","barrages","barraging"},
"barramunda":{"barramunda","barramundas"},
"barramundi":{"barramundi","barramundies","barramundis"},
"barranca":{"barranca","barrancas"},
"barranco":{"barranco","barrancos"},
"barrel":{"barrel","barreled","barreling","barrelled","barrelling","barrels"},
"barrel-roll":{"barrel-roll","barrel-rolled","barrel-rolling"},
"barrelfish":{"barrelfish","barrelfishes"},
"barrelful":{"barrelful","barrelfuls"},
"barrelhouse":{"barrelhouse","barrelhouses"},
"barren":{"barren","barrens"},
"barrenness":{"barrenness","barrennesses"},
"barrenwort":{"barrenwort","barrenworts"},
"barretter":{"barretter","barretters"},
"barricade":{"barricade","barricaded","barricades","barricading"},
"barrie":{"barrie","barries"},
"barrier":{"barrier","barriers"},
"barring":{"barring","barrings"},
"barrio":{"barrio","barrios"},
"barrister":{"barrister","barristers"},
"barroom":{"barroom","barrooms"},
"barrow":{"barrow","barrows"},
"barrow-boy":{"barrow-boy","barrow-boys"},
"barrow-man":{"barrow-man","barrow-men"},
"barrowful":{"barrowful","barrowfuls"},
"bars":{"bars","barses"},
"bart":{"bart","barts"},
"bartend":{"bartend","bartended","bartending"},
"bartender":{"bartender","bartenders"},
"barter":{"barter","bartered","bartering","barters"},
"bartlett":{"bartlett","bartletts"},
"bartonia":{"bartonia","bartonias"},
"bartramia":{"bartramia","bartramias"},
"barunduki":{"barunduki","barundukis"},
"barye":{"barye","baryes"},
"baryon":{"baryon","baryons"},
"barytes":{"barytes","baryteses"},
"barytone":{"barytone","barytones"},
"base":{"base","based","baser","bases","basest","basing"},
"baseball":{"baseball","baseballs"},
"baseboard":{"baseboard","baseboards"},
"basel":{"basel","basels"},
"baseman":{"baseman","basemen"},
"basement":{"basement","basements"},
"baseness":{"baseness","basenesses"},
"basenji":{"basenji","basenjis"},
"base_on_balls":{"bases-on-balls","bases_on_balls","base_on_balls"},
"bash":{"bash","bashed","bashes","bashing"},
"bashfulness":{"bashfulness","bashfulnesses"},
"basic":{"basic","basics"},
"basics":{"basics","basicses"},
"basidiomycete":{"basidiomycete","basidiomycetes"},
"basidiomycetes":{"basidiomycetes","basidiomyceteses"},
"basidiomycota":{"basidiomycota","basidiomycotas"},
"basidiomycotina":{"basidiomycotina","basidiomycotinas"},
"basidium":{"basidia","basidiia","basidium"},
"basify":{"basified","basifies","basify","basifying"},
"basil":{"basil","basils"},
"basileus":{"basileis","basileus"},
"basilica":{"basilica","basilicas"},
"basilicata":{"basilicata","basilicatas"},
"basiliscus":{"basiliscus","basiliscuses"},
"basin":{"basin","basins"},
"basinful":{"basinful","basinfuls"},
"basis":{"bases","basis"},
"bask":{"bask","basked","basking","basks"},
"basket":{"basket","baskets"},
"basketball":{"basketball","basketballs"},
"basketeer":{"basketeer","basketeers"},
"basketful":{"basketful","basketfuls"},
"basketmaker":{"basketmaker","basketmakers"},
"basketweaver":{"basketweaver","basketweavers"},
"basle":{"basle","basles"},
"basophil":{"basophil","basophils"},
"basophile":{"basophile","basophiles"},
"basotho":{"basotho","basothos"},
"bass":{"bass","basses"},
"bassariscidae":{"bassariscidae","bassariscidaes"},
"bassariscus":{"bassariscus","bassariscuses"},
"bassarisk":{"bassarisk","bassarisks"},
"basse-normandie":{"basse-normandie","basse-normandies"},
"basset":{"basset","bassets"},
"bassia":{"bassia","bassias"},
"basso":{"bassi","basso","bassos"},
"basswood":{"basswood","basswoods"},
"bast":{"bast","basts"},
"bastard":{"bastard","bastards"},
"bastardisation":{"bastardisation","bastardisations"},
"bastardization":{"bastardization","bastardizations"},
"bastardize":{"bastardize","bastardized","bastardizes","bastardizing"},
"bastardy":{"bastardies","bastardy"},
"baste":{"baste","basted","bastes","basting"},
"bastinado":{"bastinado","bastinadoed","bastinadoes","bastinadoing"},
"basting":{"basting","bastings"},
"bastion":{"bastion","bastions"},
"bastnaesite":{"bastnaesite","bastnaesites"},
"bastnasite":{"bastnasite","bastnasites"},
"basuto":{"basuto","basutos"},
"basutoland":{"basutoland","basutolands"},
"bat":{"bat","bats","batted","batting"},
"bataan":{"bataan","bataans"},
"batch":{"batch","batches"},
"bate":{"bate","bated","bating"},
"bateau":{"bateau","bateaux"},
"batfish":{"batfish","batfishes"},
"batfowl":{"batfowl","batfowled","batfowling"},
"bath":{"bath","bathed","bathing","baths"},
"bathe":{"bathe","bathed","bathing"},
"bather":{"bather","bathers"},
"bathhouse":{"bathhouse","bathhouses"},
"bathing":{"bathing","bathings"},
"batholite":{"batholite","batholites"},
"batholith":{"batholith","batholiths"},
"bathos":{"bathos","bathoses"},
"bathrobe":{"bathrobe","bathrobes"},
"bathroom":{"bathroom","bathrooms"},
"bathtub":{"bathtub","bathtubs"},
"bathurst":{"bathurst","bathursts"},
"bathyergidae":{"bathyergidae","bathyergidaes"},
"bathyergus":{"bathyergus","bathyerguses"},
"bathymetry":{"bathymetries","bathymetry"},
"bathyscape":{"bathyscape","bathyscapes"},
"bathyscaph":{"bathyscaph","bathyscaphs"},
"bathyscaphe":{"bathyscaphe","bathyscaphes"},
"batidaceae":{"batidaceae","batidaceaes"},
"batis":{"batis","batises"},
"batman":{"batman","batmen"},
"batoidei":{"batoidei","batoideis"},
"batrachia":{"batrachia","batrachias"},
"batrachian":{"batrachian","batrachians"},
"batrachoididae":{"batrachoididae","batrachoididaes"},
"batrachoseps":{"batrachoseps","batrachosepses"},
"batsman":{"batsman","batsmen"},
"batswana":{"batswana","batswanas"},
"battalion":{"battalion","battalions"},
"batten":{"batten","battened","battening","battens"},
"batter":{"batter","battered","battering","batters"},
"battercake":{"battercake","battercakes"},
"battering":{"battering","batterings"},
"battery":{"batteries","battery"},
"battle":{"battle","battled","battles","battling"},
"battle-ax":{"battle-ax","battle-axes"},
"battle-axe":{"battle-axe","battle-axes"},
"battledore":{"battledore","battledores"},
"battlefield":{"battlefield","battlefields"},
"battlefront":{"battlefront","battlefronts"},
"battleground":{"battleground","battlegrounds"},
"battlement":{"battlement","battlements"},
"battler":{"battler","battlers"},
"battleship":{"battleship","battleships"},
"battlewagon":{"battlewagon","battlewagons"},
"battue":{"battue","battues"},
"batty":{"battier","battiest","batty"},
"batwoman":{"batwoman","batwomen"},
"bauble":{"bauble","baubles"},
"baud":{"baud","bauds"},
"baudelaire":{"baudelaire","baudelaires"},
"bauhinia":{"bauhinia","bauhinias"},
"baulk":{"baulk","baulks"},
"baulky":{"baulkier","baulkiest","baulky"},
"bawd":{"bawd","bawds"},
"bawdiness":{"bawdiness","bawdinesses"},
"bawdry":{"bawdries","bawdry"},
"bawdy":{"bawdier","bawdies","bawdiest","bawdy"},
"bawdyhouse":{"bawdyhouse","bawdyhouses"},
"bawl":{"bawl","bawled","bawling","bawls"},
"bawling":{"bawling","bawlings"},
"bay":{"bay","bayed","baying","bays"},
"baya":{"baya","bayas"},
"bayberry":{"bayberries","bayberry"},
"bayer":{"bayer","bayers"},
"bayonet":{"bayonet","bayoneted","bayoneting","bayonets","bayonetted","bayonetting"},
"bayou":{"bayou","bayous"},
"bazaar":{"bazaar","bazaars"},
"bazar":{"bazar","bazars"},
"bazooka":{"bazooka","bazookas"},
"bb":{"bb","bbs"},
"bbl":{"bbl","bbls"},
"bbs":{"bbs","bbses"},
"bd":{"bd","bds"},
"be":{"am","are","be","been","being","bes","is","was","were","'re","'m"},
"beach":{"beach","beached","beaches","beaching"},
"beachhead":{"beachhead","beachheads"},
"beacon":{"beacon","beaconed","beaconing","beacons"},
"bead":{"bead","beaded","beading","beads"},
"bead-ruby":{"bead-rubies","bead-ruby"},
"beading":{"beading","beadings"},
"beads":{"beads","beadses"},
"beadsman":{"beadsman","beadsmen"},
"beadwork":{"beadwork","beadworks"},
"beady":{"beadier","beadiest","beady"},
"beak":{"beak","beaked","beaking","beaks"},
"beam":{"beam","beamed","beaming","beams"},
"beamy":{"beamier","beamiest","beamy"},
"bean":{"bean","beaned","beaning","beans"},
"beanball":{"beanball","beanballs"},
"beaner":{"beaner","beaners"},
"beanery":{"beaneries","beanery"},
"beanie":{"beanie","beanies"},
"beano":{"beano","beanos"},
"beantown":{"beantown","beantowns"},
"beany":{"beanies","beany"},
"bear":{"bear","beared","bearing","bears","bore","born","borne"},
"bearberry":{"bearberries","bearberry"},
"bearcat":{"bearcat","bearcats"},
"beard":{"beard","bearded","bearding","beards"},
"bearer":{"bearer","bearers"},
"bearing":{"bearing","bearings"},
"bearskin":{"bearskin","bearskins"},
"bearwood":{"bearwood","bearwoods"},
"beast":{"beast","beasts"},
"beastliness":{"beastliness","beastlinesses"},
"beastly":{"beastlier","beastliest","beastly"},
"beat":{"beat","beaten","beating","beats"},
"beater":{"beater","beaters"},
"beatify":{"beatified","beatifies","beatify","beatifying"},
"beating":{"beating","beatings"},
"beatitude":{"beatitude","beatitudes"},
"beau":{"beau","beaus","beaux"},
"beaugregory":{"beaugregories","beaugregory"},
"beaumontia":{"beaumontia","beaumontias"},
"beaut":{"beaut","beauts"},
"beauteousness":{"beauteousness","beauteousnesses"},
"beautician":{"beautician","beauticians"},
"beautify":{"beautified","beautifies","beautify","beautifying"},
"beauty":{"beauties","beauty"},
"beaver":{"beaver","beavered","beavering","beavers"},
"bebop":{"bebop","bebops"},
"becalm":{"becalm","becalmed","becalming","becalms"},
"beccafico":{"beccafico","beccaficos"},
"bechamel":{"bechamel","bechamels"},
"bechance":{"bechance","bechanced","bechances","bechancing"},
"beche-de-mer":{"beche-de-mer","beches-de-mer"},
"bechuana":{"bechuana","bechuanas"},
"beck":{"beck","becks"},
"becket":{"becket","beckets"},
"beckett":{"beckett","becketts"},
"beckon":{"beckon","beckoned","beckoning","beckons"},
"becloud":{"becloud","beclouded","beclouding","beclouds"},
"become":{"became","become","becomes","becoming"},
"become_known":{"became_known","becomes_know","become_known"},
"bed":{"bed","bedded","bedding","beds"},
"bed-wetting":{"bed-wetting","bed-wettings"},
"bedaub":{"bedaub","bedaubed","bedaubing","bedaubs"},
"bedazzle":{"bedazzle","bedazzled","bedazzles","bedazzling"},
"bedbug":{"bedbug","bedbugs"},
"bedchamber":{"bedchamber","bedchambers"},
"bedclothes":{"bedclothes","bedclotheses"},
"bedcover":{"bedcover","bedcovers"},
"bedder":{"bedder","bedders"},
"bedding":{"bedding","beddings"},
"bedeck":{"bedeck","bedecked","bedecking","bedecks"},
"bedesman":{"bedesman","bedesmen"},
"bedevil":{"bedevil","bedeviled","bedeviling","bedevilled","bedevilling","bedevils"},
"bedevilment":{"bedevilment","bedevilments"},
"bedew":{"bedew","bedewed","bedewing"},
"bedframe":{"bedframe","bedframes"},
"bedight":{"bedight","bedighted","bedighting","bedights"},
"bedim":{"bedim","bedimmed","bedimming","bedims"},
"bedizen":{"bedizen","bedizened","bedizening","bedizens"},
"bedlam":{"bedlam","bedlams"},
"bedouin":{"bedouin","bedouins"},
"bedraggle":{"bedraggle","bedraggled","bedraggling"},
"bedrock":{"bedrock","bedrocks"},
"bedroom":{"bedroom","bedrooms"},
"bedside":{"bedside","bedsides"},
"bedsit":{"bedsit","bedsits"},
"bedsitter":{"bedsitter","bedsitters"},
"bedsore":{"bedsore","bedsores"},
"bedspread":{"bedspread","bedspreads"},
"bedstead":{"bedstead","bedsteads"},
"bedtime":{"bedtime","bedtimes"},
"beduin":{"beduin","beduins"},
"bee":{"bee","bees"},
"beebalm":{"beebalm","beebalms"},
"beebread":{"beebread","beebreads"},
"beech":{"beech","beeches"},
"beechwood":{"beechwood","beechwoods"},
"beef":{"beef","beefed","beefing","beefs","beeves"},
"beefalo":{"beefalo","beefaloes","beefalos"},
"beefburger":{"beefburger","beefburgers"},
"beefeater":{"beefeater","beefeaters"},
"beefwood":{"beefwood","beefwoods"},
"beefy":{"beefier","beefiest","beefy"},
"beehive":{"beehive","beehives"},
"beekeeper":{"beekeeper","beekeepers"},
"beekeeping":{"beekeeping","beekeepings"},
"beelzebub":{"beelzebub","beelzebubs"},
"beento":{"beento","beentos"},
"beep":{"beep","beeped","beeping","beeps"},
"beer":{"beer","beers"},
"beery":{"beerier","beeriest","beery"},
"beet":{"beet","beets"},
"beetfly":{"beetflies","beetfly"},
"beethoven":{"beethoven","beethovens"},
"beetle":{"beetle","beetled","beetles","beetling"},
"beetleweed":{"beetleweed","beetleweeds"},
"beetroot":{"beetroot","beetroots"},
"befall":{"befall","befallen","befalling","befalls","befell"},
"befit":{"befit","befits","befitted","befitting"},
"befog":{"befog","befogged","befogging","befogs"},
"befool":{"befool","befooled","befooling","befools"},
"befooling":{"befooling","befoolings"},
"befoul":{"befoul","befouled","befouling","befouls"},
"befoulment":{"befoulment","befoulments"},
"befriend":{"befriend","befriended","befriending"},
"befuddle":{"befuddle","befuddled","befuddles","befuddling"},
"befuddlement":{"befuddlement","befuddlements"},
"beg":{"beg","begged","begging","begs"},
"beget":{"begat","beget","begets","begetting","begot","begotten"},
"begetter":{"begetter","begetters"},
"beggar":{"beggar","beggared","beggaring","beggars"},
"beggar-ticks":{"beggar-ticks","beggar-tickses"},
"beggarweed":{"beggarweed","beggarweeds"},
"beggary":{"beggaries","beggary"},
"begging":{"begging","beggings"},
"begin":{"began","begin","beginning","begins","begun"},
"beginner":{"beginner","beginners"},
"beginning":{"beginning","beginnings"},
"begird":{"begird","begirded","begirding","begirds","begirt"},
"begonia":{"begonia","begonias"},
"begoniaceae":{"begoniaceae","begoniaceaes"},
"begrime":{"begrime","begrimed","begrimes","begriming"},
"begrudge":{"begrudge","begrudged","begrudges","begrudging"},
"beguile":{"beguile","beguiled","beguiles","beguiling"},
"beguilement":{"beguilement","beguilements"},
"beguiler":{"beguiler","beguilers"},
"behave":{"behave","behaved","behaves","behaving"},
"behavior":{"behavior","behaviors"},
"behaviorism":{"behaviorism","behaviorisms"},
"behaviorist":{"behaviorist","behaviorists"},
"behaviour":{"behaviour","behaviours"},
"behaviourism":{"behaviourism","behaviourisms"},
"behaviourist":{"behaviourist","behaviourists"},
"behead":{"behead","beheaded","beheading","beheads"},
"beheading":{"beheading","beheadings"},
"behemoth":{"behemoth","behemoths"},
"behind":{"behind","behinds"},
"behmen":{"behmen","behmens"},
"behmenism":{"behmenism","behmenisms"},
"behold":{"beheld","behold","beholden","beholding","beholds"},
"beholder":{"beholder","beholders"},
"beholding":{"beholding","beholdings"},
"behoof":{"behoof","behooves"},
"behoove":{"behoove","behooved","behooves","behooving"},
"beige":{"beige","beiges"},
"beijing":{"beijing","beijings"},
"being":{"being","beings"},
"beingness":{"beingness","beingnesses"},
"beirut":{"beirut","beiruts"},
"bejewel":{"bejewel","bejeweled","bejeweling","bejewelled","bejewelling","bejewels"},
"bel":{"bel","bels"},
"bel-merodach":{"bel-merodach","bel-merodaches"},
"belabor":{"belabor","belabored","belaboring","belabors"},
"belamcanda":{"belamcanda","belamcandas"},
"belarus":{"belarus","belaruses"},
"belarusian":{"belarusian","belarusians"},
"belay":{"belay","belayed","belaying","belays"},
"belch":{"belch","belched","belches","belching"},
"belching":{"belching","belchings"},
"beldam":{"beldam","beldams"},
"beldame":{"beldame","beldames"},
"beleaguer":{"beleaguer","beleaguered","beleaguering","beleaguers"},
"beleaguering":{"beleaguering","beleaguerings"},
"belemnitidae":{"belemnitidae","belemnitidaes"},
"belemnoidea":{"belemnoidea","belemnoideas"},
"belfast":{"belfast","belfasts"},
"belfry":{"belfries","belfry"},
"belgique":{"belgique","belgiques"},
"belgium":{"belgium","belgiums"},
"belgrade":{"belgrade","belgrades"},
"belie":{"belie","belied","belies","belying"},
"belief":{"belief","beliefs","believes"},
"believability":{"believabilities","believability"},
"believe":{"believe","believed","believes","believing"},
"believer":{"believer","believers"},
"belittle":{"belittle","belittled","belittles","belittling"},
"belittling":{"belittling","belittlings"},
"belize":{"belize","belizes"},
"bell":{"bell","belled","belling","bells"},
"bell-bottom":{"bell-bottom","bell-bottoms"},
"belladonna":{"belladonna","belladonnas"},
"bellarmine":{"bellarmine","bellarmines"},
"bellbottoms":{"bellbottoms","bellbottomses"},
"bellboy":{"bellboy","bellboys"},
"belles-lettres":{"belles-lettres","belles-lettreses"},
"bellflower":{"bellflower","bellflowers"},
"bellhop":{"bellhop","bellhops"},
"belligerence":{"belligerence","belligerences"},
"belligerency":{"belligerencies","belligerency"},
"belligerent":{"belligerent","belligerents"},
"belling":{"belling","bellings"},
"bellis":{"bellis","bellises"},
"bellman":{"bellman","bellmen"},
"bellow":{"bellow","bellowed","bellowing","bellows"},
"bellowing":{"bellowing","bellowings"},
"bellows":{"bellows","bellowses"},
"bellwort":{"bellwort","bellworts"},
"belly":{"bellied","bellies","belly","bellying"},
"belly-flop":{"belly-flop","belly-flopped","belly-flopping","belly-flops"},
"bellyache":{"bellyache","bellyached","bellyaches","bellyaching"},
"bellyacher":{"bellyacher","bellyachers"},
"bellybutton":{"bellybutton","bellybuttons"},
"bellyful":{"bellyful","bellyfuls"},
"belong":{"belong","belonged","belonging","belongs"},
"belongings":{"belongings","belongingses"},
"belonidae":{"belonidae","belonidaes"},
"belorussia":{"belorussia","belorussias"},
"belorussian":{"belorussian","belorussians"},
"belostomatidae":{"belostomatidae","belostomatidaes"},
"beloved":{"beloved","beloveds"},
"belt":{"belt","belted","belting","belts"},
"beluga":{"beluga","belugas"},
"belvedere":{"belvedere","belvederes"},
"bema":{"bema","bemas"},
"bemba":{"bemba","bembas"},
"bemire":{"bemire","bemired","bemires","bemiring"},
"bemisia":{"bemisia","bemisias"},
"bemoan":{"bemoan","bemoaned","bemoaning","bemoans"},
"bemock":{"bemock","bemocked","bemocking","bemocks"},
"bemuse":{"bemuse","bemused","bemuses","bemusing"},
"bemusement":{"bemusement","bemusements"},
"bename":{"bename","benamed","benames","benaming","benempt"},
"bench":{"bench","benched","benches","benching"},
"benchmark":{"benchmark","benchmarks"},
"bend":{"bend","bending","bends","bent"},
"bendability":{"bendabilities","bendability"},
"bender":{"bender","benders"},
"bending":{"bending","bendings"},
"bends":{"bends","bendses"},
"bendy":{"bendier","bendiest","bendy"},
"benedick":{"benedick","benedicks"},
"benedict":{"benedict","benedicts"},
"benediction":{"benediction","benedictions"},
"benefaction":{"benefaction","benefactions"},
"benefactor":{"benefactor","benefactors"},
"benefice":{"benefice","benefices"},
"beneficence":{"beneficence","beneficences"},
"beneficiary":{"beneficiaries","beneficiary"},
"beneficiation":{"beneficiation","beneficiations"},
"benefit":{"benefit","benefited","benefiting","benefits"},
"benevolence":{"benevolence","benevolences"},
"benghazi":{"benghazi","benghazis"},
"beni":{"beni","benis"},
"benignancy":{"benignancies","benignancy"},
"benignity":{"benignities","benignity"},
"benin":{"benin","benins"},
"benjamin":{"benjamin","benjamins"},
"benne":{"benne","bennes"},
"bennet":{"bennet","bennets"},
"bennettitaceae":{"bennettitaceae","bennettitaceaes"},
"bennettitales":{"bennettitales","bennettitaleses"},
"bennettitis":{"bennettitis","bennettitises"},
"benni":{"benni","bennis"},
"bennie":{"bennie","bennies"},
"benniseed":{"benniseed","benniseeds"},
"benny":{"bennies","benny"},
"bent":{"bent","bents"},
"bentgrass":{"bentgrass","bentgrasses"},
"benthos":{"benthos","benthoses"},
"benumb":{"benumb","benumbed","benumbing","benumbs"},
"benweed":{"benweed","benweeds"},
"benzedrine":{"benzedrine","benzedrines"},
"benzene":{"benzene","benzenes"},
"benzine":{"benzine","benzines"},
"benzocaine":{"benzocaine","benzocaines"},
"benzofuran":{"benzofuran","benzofurans"},
"benzoin":{"benzoin","benzoins"},
"benzol":{"benzol","benzols"},
"benzyl":{"benzyl","benzyls"},
"beograd":{"beograd","beograds"},
"bequeath":{"bequeath","bequeathed","bequeathing","bequeaths"},
"bequest":{"bequest","bequests"},
"berate":{"berate","berated","berates","berating"},
"berating":{"berating","beratings"},
"berberidaceae":{"berberidaceae","berberidaceaes"},
"berberis":{"berberis","berberises"},
"berceuse":{"berceuse","berceuses"},
"bercy":{"bercies","bercy"},
"bereave":{"bereave","bereaved","bereaving","bereft"},
"bereavement":{"bereavement","bereavements"},
"berg":{"berg","bergs"},
"bergall":{"bergall","bergalls"},
"bergamot":{"bergamot","bergamots"},
"berith":{"berith","beriths"},
"berkeley":{"berkeley","berkeleys"},
"berkelium":{"berkelium","berkeliums"},
"berkshires":{"berkshires","berkshireses"},
"berlin":{"berlin","berlins"},
"bermuda":{"bermuda","bermudas"},
"bermudan":{"bermudan","bermudans"},
"bermudas":{"bermudas","bermudases"},
"bermudian":{"bermudian","bermudians"},
"bern":{"bern","berns"},
"berne":{"berne","bernes"},
"berry":{"berried","berries","berry","berrying"},
"bersagliere":{"bersagliere","bersaglieri"},
"berteroa":{"berteroa","berteroas"},
"berth":{"berth","berthed","berthing","berths"},
"bertha":{"bertha","berthas"},
"bertholletia":{"bertholletia","bertholletias"},
"berycomorphi":{"berycomorphi","berycomorphis"},
"beryllium":{"beryllium","berylliums"},
"beseech":{"beseech","beseeched","beseeches","beseeching","besought"},
"beseem":{"beseem","beseemed","beseeming","beseems"},
"beset":{"beset","besets","besetted","besetting"},
"besetment":{"besetment","besetments"},
"besiege":{"besiege","besieged","besieges","besieging"},
"besieger":{"besieger","besiegers"},
"besieging":{"besieging","besiegings"},
"besmear":{"besmear","besmeared","besmearing","besmears"},
"besmirch":{"besmirch","besmirched","besmirches","besmirching"},
"besot":{"besot","besots","besotted","besotting"},
"bespatter":{"bespatter","bespattered","bespattering","bespatters"},
"bespeak":{"bespeak","bespeaking","bespeaks","bespoke","bespoken"},
"bespread":{"bespread","bespreading","bespreads"},
"besprinkle":{"besprinkle","besprinkled","besprinkles","besprinkling"},
"bessera":{"bessera","besseras"},
"besseya":{"besseya","besseyas"},
"best":{"best","bested","besting","bests"},
"bestead":{"bestead","besteaded","besteading","besteads"},
"bestiality":{"bestialities","bestiality"},
"bestialize":{"bestialize","bestialized","bestializes","bestializing"},
"bestiary":{"bestiaries","bestiary"},
"bestir":{"bestir","bestirred","bestirring","bestirs"},
"bestow":{"bestow","bestowed","bestowing","bestows"},
"bestowal":{"bestowal","bestowals"},
"bestowment":{"bestowment","bestowments"},
"bestrew":{"bestrew","bestrewed","bestrewing","bestrewn","bestrews"},
"bestride":{"bestrid","bestridden","bestride","bestrides","bestriding","bestrode"},
"bet":{"bet","bets","betted","betting"},
"beta":{"beta","betas"},
"betake":{"betake","betaken","betakes","betaking","betook"},
"betatron":{"betatron","betatrons"},
"betel":{"betel","betels"},
"betelgeuse":{"betelgeuse","betelgeuses"},
"bethink":{"bethink","bethinking","bethinks","bethought"},
"betide":{"betide","betided","betides","betiding"},
"betise":{"betise","betises"},
"betoken":{"betoken","betokened","betokening","betokens"},
"betony":{"betonies","betony"},
"betray":{"betray","betrayed","betraying","betrays"},
"betrayal":{"betrayal","betrayals"},
"betrayer":{"betrayer","betrayers"},
"betroth":{"betroth","betrothed","betrothing","betroths"},
"betrothal":{"betrothal","betrothals"},
"better":{"better","bettered","bettering","betters"},
"betterment":{"betterment","betterments"},
"bettongia":{"bettongia","bettongias"},
"bettor":{"bettor","bettors"},
"betula":{"betula","betulas"},
"betulaceae":{"betulaceae","betulaceaes"},
"betweeenbrain":{"betweeenbrain","betweeenbrains"},
"bevel":{"bevel","beveled","beveling","bevelled","bevelling","bevels"},
"beverage":{"beverage","beverages"},
"bevvy":{"bevvies","bevvy"},
"bevy":{"bevies","bevy"},
"bewail":{"bewail","bewailed","bewailing","bewails"},
"bewilder":{"bewilder","bewildered","bewildering","bewilders"},
"bewilderment":{"bewilderment","bewilderments"},
"bewitch":{"bewitch","bewitched","bewitches","bewitching"},
"bewitchery":{"bewitcheries","bewitchery"},
"bewitchment":{"bewitchment","bewitchments"},
"bewray":{"bewray","bewrayed","bewraying","bewrays"},
"bezant":{"bezant","bezants"},
"bezique":{"bezique","beziques"},
"bezzant":{"bezzant","bezzants"},
"bharat":{"bharat","bharats"},
"bheesty":{"bheesty","bhishties"},
"bhishti":{"bhishti","bhishties"},
"bhutanese":{"bhutanese","bhutaneses"},
"bhutani":{"bhutani","bhutanis"},
"bi":{"bi","bis"},
"bialy":{"bialies","bialy"},
"bialystoker":{"bialystoker","bialystokers"},
"bias":{"bias","biased","biases","biasing","biassed","biassing"},
"bib":{"bib","bibbed","bibbing","bibs"},
"bible":{"bible","bibles"},
"bible-worship":{"bible-worship","bible-worships"},
"bibliography":{"bibliographies","bibliography"},
"bibliolatry":{"bibliolatries","bibliolatry"},
"bibliophile":{"bibliophile","bibliophiles"},
"bibliopole":{"bibliopole","bibliopoles"},
"bibliopolist":{"bibliopolist","bibliopolists"},
"bibliothec":{"bibliothec","bibliothecs"},
"bibliotheca":{"bibliotheca","bibliothecae","bibliothecas"},
"bibos":{"bibos","biboses"},
"bicarbonate":{"bicarbonate","bicarbonates"},
"bicentenary":{"bicennaries","bicentenaries","bicentenary"},
"bicentennial":{"bicennaries","bicentennial","bicentennials"},
"biceps":{"biceps","bicepses"},
"bichloride":{"bichloride","bichlorides"},
"bichromate":{"bichromate","bichromates"},
"bicker":{"bicker","bickered","bickering","bickers"},
"bickering":{"bickering","bickerings"},
"bicorn":{"bicorn","bicorns"},
"bicorne":{"bicorne","bicornes"},
"bicuspid":{"bicuspid","bicuspids"},
"bicycle":{"bicycle","bicycled","bicycles","bicycling"},
"bicycle-built-for-two":{"bicycle-built-for-two","bicycle-built-for-twos"},
"bicyclist":{"bicyclist","bicyclists"},
"bid":{"bade","bid","bidden","bidding","bids"},
"bida":{"bida","bidas"},
"bidding":{"bidding","biddings"},
"biddy":{"biddies","biddy"},
"biddy-biddy":{"biddy-biddies","biddy-biddy"},
"bide":{"bide","bided","biding","bode"},
"bidens":{"bidens","bidenses"},
"biegnet":{"biegnet","biegnets"},
"bier":{"bier","biers"},
"biff":{"biff","biffed","biffing","biffs"},
"bifocal":{"bifocal","bifocals"},
"bifurcate":{"bifurcate","bifurcated","bifurcating"},
"bifurcation":{"bifurcation","bifurcations"},
"big":{"big","bigger","biggest"},
"bigamy":{"bigamies","bigamy"},
"bigarade":{"bigarade","bigarades"},
"bigeye":{"bigeye","bigeyes"},
"bigfoot":{"bigfeet","bigfoot","bigfoots"},
"bighorn":{"bighorn","bighorns"},
"bigmouth":{"bigmouth","bigmouths"},
"bigness":{"bigness","bignesses"},
"bignonia":{"bignonia","bignonias"},
"bignoniaceae":{"bignoniaceae","bignoniaceaes"},
"bigotry":{"bigotries","bigotry"},
"bigwig":{"bigwig","bigwigs"},
"bijou":{"bijou","bijoux"},
"bike":{"bike","biked","bikes","biking"},
"bikini":{"bikini","bikinis"},
"bilateralism":{"bilateralism","bilateralisms"},
"bilaterality":{"bilateralities","bilaterality"},
"bilberry":{"bilberries","bilberry"},
"bilbo":{"bilbo","bilboes","bilbos","bilobes"},
"bilby":{"bilbies","bilby"},
"bilestone":{"bilestone","bilestones"},
"bilge":{"bilge","bilged","bilges","bilging"},
"bilgewater":{"bilgewater","bilgewaters"},
"bilharzia":{"bilharzia","bilharzias"},
"bilharziasis":{"bilharziases","bilharziasis"},
"bilimbi":{"bilimbi","bilimbis"},
"biliousness":{"biliousness","biliousnesses"},
"bilk":{"bilk","bilked","bilking","bilks"},
"bill":{"bill","billed","billing","bills"},
"billboard":{"billboard","billboards"},
"billet":{"billet","billeted","billeting","billets"},
"billet-doux":{"billet-doux","billets-doux"},
"billfish":{"billfish","billfishes"},
"billfold":{"billfold","billfolds"},
"billhook":{"billhook","billhooks"},
"billing":{"billing","billings"},
"billingsgate":{"billingsgate","billingsgates"},
"billion":{"billion","billions"},
"billions":{"billions","billionses"},
"billionth":{"billionth","billionths"},
"billow":{"billow","billowed","billowing","billows"},
"billowy":{"billowier","billowiest","billowy"},
"billy":{"billies","billy"},
"billy-ho":{"billy-ho","billy-hos"},
"billycan":{"billycan","billycans"},
"billyo":{"billyo","billyos"},
"billyoh":{"billyoh","billyohs"},
"billystick":{"billystick","billysticks"},
"bilsted":{"bilsted","bilsteds"},
"bimbo":{"bimbo","bimboes","bimbos"},
"bimillenary":{"bimillenaries","bimillenary"},
"bimillennium":{"bimillennium","bimillenniums"},
"bimli":{"bimli","bimlis"},
"bimonthly":{"bimonthlies","bimonthly"},
"bin":{"bin","binned","binning","bins"},
"binary":{"binaries","binary"},
"bind":{"bind","binding","binds","bound"},
"binder":{"binder","binders"},
"bindery":{"binderies","bindery"},
"binding":{"binding","bindings"},
"bine":{"bine","bines"},
"binful":{"binful","binfuls"},
"binge":{"binge","binges"},
"bingey":{"bingey","bingeys"},
"bingle":{"bingle","bingles"},
"bingo":{"bingo","bingos"},
"bingy":{"bingies","bingy"},
"binocular":{"binocular","binoculars"},
"binoculars":{"binoculars","binocularses"},
"binturong":{"binturong","binturongs"},
"bioassay":{"bioassay","bioassayed","bioassaying"},
"biodegrade":{"biodegrade","biodegraded","biodegrading"},
"bioengineering":{"bioengineering","bioengineerings"},
"bioflavinoid":{"bioflavinoid","bioflavinoids"},
"biogenesis":{"biogeneses","biogenesis"},
"biogeny":{"biogenies","biogeny"},
"biographer":{"biographer","biographers"},
"biography":{"biographies","biography"},
"biological":{"biological","biologicals"},
"biologist":{"biologist","biologists"},
"biology":{"biologies","biology"},
"bionomics":{"bionomics","bionomicses"},
"biopsy":{"biopsies","biopsy"},
"bioscopy":{"bioscopies","bioscopy"},
"biosynthesis":{"biosyntheses","biosynthesis"},
"biosystematics":{"biosystematics","biosystematicses"},
"biosystematy":{"biosystematies","biosystematy"},
"biota":{"biota","biotas"},
"biotechnology":{"biotechnologies","biotechnology"},
"biotin":{"biotin","biotins"},
"biquadrate":{"biquadrate","biquadrates"},
"biquadratic":{"biquadratic","biquadratics"},
"birch":{"birch","birched","birches","birching"},
"birchbark":{"birchbark","birchbarks"},
"bird":{"bird","birded","birding","birds"},
"bird-dog":{"bird-dog","bird-dogged","bird-dogging","bird-dogs"},
"bird-on-the-wing":{"bird-on-the-wing","bird-on-the-wings"},
"bird-watch":{"bird-watch","bird-watched","bird-watching"},
"birdbath":{"birdbath","birdbaths"},
"birdbrain":{"birdbrain","birdbrains"},
"birdcall":{"birdcall","birdcalls"},
"birder":{"birder","birders"},
"birdhouse":{"birdhouse","birdhouses"},
"birdie":{"birdie","birdied","birdieing","birdies"},
"birdlime":{"birdlime","birdlimes"},
"birdman":{"birdman","birdmen"},
"birdseed":{"birdseed","birdseeds"},
"birdsong":{"birdsong","birdsongs"},
"birefringence":{"birefringence","birefringences"},
"biretta":{"biretta","birettas"},
"birle":{"birle","birled","birles","birling"},
"birling":{"birling","birlings"},
"birmingham":{"birmingham","birminghams"},
"biro":{"biro","biros"},
"birth":{"birth","birthed","birthing","births"},
"birthcontrol":{"birthcontrol","birthcontrols"},
"birthday":{"birthday","birthdays"},
"birthing":{"birthing","birthings"},
"birthmark":{"birthmark","birthmarks"},
"birthplace":{"birthplace","birthplaces"},
"birthrate":{"birthrate","birthrates"},
"birthright":{"birthright","birthrights"},
"birthroot":{"birthroot","birthroots"},
"birthwort":{"birthwort","birthworts"},
"bisayan":{"bisayan","bisayans"},
"bisayas":{"bisayas","bisayases"},
"biscuit":{"biscuit","biscuits"},
"biscutella":{"biscutella","biscutellas"},
"bise":{"bise","bises"},
"bisect":{"bisect","bisected","bisecting"},
"bisectrix":{"bisectrices","bisectrix"},
"bisexual":{"bisexual","bisexuals"},
"bisexuality":{"bisexualities","bisexuality"},
"bishop":{"bishop","bishops"},
"bishopric":{"bishopric","bishoprics"},
"biskek":{"biskek","biskeks"},
"bismarck":{"bismarck","bismarcks"},
"bismark":{"bismark","bismarks"},
"bismuth":{"bismuth","bismuths"},
"bissau":{"bissau","bissaus"},
"bister":{"bister","bisters"},
"bistoury":{"bistouries","bistoury"},
"bistre":{"bistre","bistres"},
"bistro":{"bistro","bistros"},
"bit":{"bit","bits","bitted","bitting"},
"bitch":{"bitch","bitches"},
"bitchiness":{"bitchiness","bitchinesses"},
"bitchy":{"bitchier","bitchiest","bitchy"},
"bite":{"bit","bite","bites","biting","bitten"},
"bitis":{"bitis","bitises"},
"bitmap":{"bitmap","bitmaps"},
"bitstock":{"bitstock","bitstocks"},
"bitt":{"bitt","bitted","bitting","bitts"},
"bitter":{"bitter","bitterer","bitterest","bitters"},
"bitter-bark":{"bitter-bark","bitter-barks"},
"bittercress":{"bittercress","bittercresses"},
"bitterness":{"bitterness","bitternesses"},
"bitternut":{"bitternut","bitternuts"},
"bitterroot":{"bitterroot","bitterroots"},
"bittersweet":{"bittersweet","bittersweets"},
"bitterweed":{"bitterweed","bitterweeds"},
"bitterwood":{"bitterwood","bitterwoods"},
"bitty":{"bittier","bittiest","bitty"},
"bituminize":{"bituminize","bituminized","bituminizing"},
"bivalve":{"bivalve","bivalves"},
"bivalvia":{"bivalvia","bivalvias"},
"bivouac":{"bivouac","bivouacked","bivouacking","bivouacs"},
"bivouacking":{"bivouacking","bivouackings"},
"bivvy":{"bivvies","bivvy"},
"biweekly":{"biweeklies","biweekly"},
"biz":{"biz","bizs"},
"bizarreness":{"bizarreness","bizarrenesses"},
"bize":{"bize","bizes"},
"bk":{"bk","bks"},
"blab":{"blab","blabbed","blabbing","blabs"},
"blabbermouth":{"blabbermouth","blabbermouths"},
"blaberus":{"blaberus","blaberuses"},
"black":{"black","blacked","blacker","blackest","blacking","blacks"},
"blackamoor":{"blackamoor","blackamoors"},
"blackball":{"blackball","blackballed","blackballing","blackballs"},
"blackbeard":{"blackbeard","blackbeards"},
"blackbeetle":{"blackbeetle","blackbeetles"},
"blackberry":{"blackberries","blackberry"},
"blackberry-lily":{"blackberry-lilies","blackberry-lily"},
"blackbird":{"blackbird","blackbirds"},
"blackboard":{"blackboard","blackboards"},
"blackbody":{"blackbodies","blackbody"},
"blackbuck":{"blackbuck","blackbucks"},
"blackburn":{"blackburn","blackburns"},
"blackcap":{"blackcap","blackcaps"},
"blackcock":{"blackcock","blackcocks"},
"blackdamp":{"blackdamp","blackdamps"},
"blacken":{"blacken","blackened","blackening","blackens"},
"blackening":{"blackening","blackenings"},
"blackfish":{"blackfish","blackfishes"},
"blackfly":{"blackflies","blackfly"},
"blackfoot":{"blackfeet","blackfoot"},
"blackfriar":{"blackfriar","blackfriars"},
"blackguard":{"blackguard","blackguarded","blackguarding","blackguards"},
"blackhead":{"blackhead","blackheads"},
"blackheart":{"blackheart","blackhearts"},
"blacking":{"blacking","blackings"},
"blackjack":{"blackjack","blackjacked","blackjacking","blackjacks"},
"blackleg":{"blackleg","blacklegs"},
"blacklist":{"blacklist","blacklisted","blacklisting","blacklists"},
"blackmail":{"blackmail","blackmailed","blackmailing","blackmails"},
"blackmailer":{"blackmailer","blackmailers"},
"blackness":{"blackness","blacknesses"},
"blackout":{"blackout","blackouts"},
"blackpoll":{"blackpoll","blackpolls"},
"blackseed":{"blackseed","blackseeds"},
"blacksmith":{"blacksmith","blacksmiths"},
"blacksnake":{"blacksnake","blacksnakes"},
"blacktail":{"blacktail","blacktails"},
"blackthorn":{"blackthorn","blackthorns"},
"blacktop":{"blacktop","blacktops"},
"blacktopping":{"blacktopping","blacktoppings"},
"blackwood":{"blackwood","blackwoods"},
"bladder":{"bladder","bladders"},
"bladdernose":{"bladdernose","bladdernoses"},
"bladderpod":{"bladderpod","bladderpods"},
"bladderwrack":{"bladderwrack","bladderwracks"},
"blade":{"blade","blades"},
"blaeberry":{"blaeberries","blaeberry"},
"blah":{"blah","blahs"},
"blame":{"blame","blamed","blames","blaming"},
"blamelessness":{"blamelessness","blamelessnesses"},
"blameworthiness":{"blameworthiness","blameworthinesses"},
"blanch":{"blanch","blanched","blanches","blanching"},
"bland":{"bland","blander","blandest"},
"blandfordia":{"blandfordia","blandfordias"},
"blandish":{"blandish","blandished","blandishes","blandishing"},
"blandishment":{"blandishment","blandishments"},
"blandness":{"blandness","blandnesses"},
"blank":{"blank","blanked","blanker","blankest","blanking","blanks"},
"blanket":{"blanket","blanketed","blanketing","blankets"},
"blanquillo":{"blanquillo","blanquillos"},
"blare":{"blare","blared","blares","blaring"},
"blarina":{"blarina","blarinas"},
"blaring":{"blaring","blarings"},
"blarney":{"blarney","blarneys"},
"blaspheme":{"blaspheme","blasphemed","blasphemes","blaspheming"},
"blasphemy":{"blasphemies","blasphemy"},
"blast":{"blast","blasted","blasting","blasts"},
"blastema":{"blastema","blastemas","blastemata"},
"blastocladia":{"blastocladia","blastocladias"},
"blastocladiales":{"blastocladiales","blastocladialeses"},
"blastocoel":{"blastocoel","blastocoels"},
"blastoderm":{"blastoderm","blastoderms"},
"blastodiaceae":{"blastodiaceae","blastodiaceaes"},
"blastodisc":{"blastodisc","blastodiscs"},
"blastoff":{"blastoff","blastoffs"},
"blastomyces":{"blastomyces","blastomyceses"},
"blastosphere":{"blastosphere","blastospheres"},
"blastula":{"blastula","blastulae","blastulas"},
"blat":{"blat","blats","blatted","blatting"},
"blather":{"blather","blathered","blathering","blathers"},
"blatherskite":{"blatherskite","blatherskites"},
"blatta":{"blatta","blattas"},
"blattaria":{"blattaria","blattarias"},
"blattella":{"blattella","blattellas"},
"blatter":{"blatter","blattered","blattering"},
"blattidae":{"blattidae","blattidaes"},
"blattodea":{"blattodea","blattodeas"},
"blaubok":{"blaubok","blauboks"},
"blaze":{"blaze","blazed","blazes","blazing"},
"blazer":{"blazer","blazers"},
"blazing":{"blazing","blazings"},
"blazon":{"blazon","blazoned","blazoning","blazons"},
"blazonry":{"blazonries","blazonry"},
"bleach":{"bleach","bleached","bleaches","bleaching"},
"bleacher":{"bleacher","bleachers"},
"bleak":{"bleak","bleaker","bleakest"},
"bleakness":{"bleakness","bleaknesses"},
"blear":{"blear","bleared","blearing","blears"},
"bleary":{"blearier","bleariest","bleary"},
"bleat":{"bleat","bleated","bleating","bleats"},
"bleb":{"bleb","blebs"},
"blechnaceae":{"blechnaceae","blechnaceaes"},
"blechnum":{"blechnum","blechnums"},
"bleed":{"bled","bleed","bleeding","bleeds"},
"bleeder":{"bleeder","bleeders"},
"bleeding":{"bleeding","bleedings"},
"bleep":{"bleep","bleeped","bleeping","bleeps"},
"blemish":{"blemish","blemished","blemishes","blemishing"},
"blench":{"blench","blenched","blenches","blenching"},
"blend":{"blend","blended","blending","blends","blent"},
"blende":{"blende","blendes"},
"blender":{"blender","blenders"},
"blending":{"blending","blendings"},
"blenniidae":{"blenniidae","blenniidaes"},
"blennioid":{"blennioid","blennioids"},
"blennioidea":{"blennioidea","blennioideas"},
"blennius":{"blennius","blenniuses"},
"blenny":{"blennies","blenny"},
"blephilia":{"blephilia","blephilias"},
"blesbok":{"blesbok","blesboks"},
"blesbuck":{"blesbuck","blesbucks"},
"bless":{"bless","blessed","blesses","blessing","blest"},
"blessedness":{"blessedness","blessednesses"},
"blessing":{"blessing","blessings"},
"blether":{"blether","blethers"},
"bletilla":{"bletilla","bletillas"},
"bleu":{"bleu","bleus"},
"blewits":{"blewits","blewitses"},
"bligh":{"bligh","blighs"},
"blighia":{"blighia","blighias"},
"blight":{"blight","blighted","blighting","blights"},
"blighter":{"blighter","blighters"},
"blighty":{"blighties","blighty"},
"blimp":{"blimp","blimps"},
"blind":{"blind","blinded","blinder","blindest","blinding","blinds"},
"blinder":{"blinder","blinders"},
"blindfish":{"blindfish","blindfishes"},
"blindfold":{"blindfold","blindfolded","blindfolding","blindfolds"},
"blindness":{"blindness","blindnesses"},
"blindstorey":{"blindstorey","blindstoreys"},
"blindstory":{"blindstories","blindstory"},
"blindworm":{"blindworm","blindworms"},
"blini":{"blini","blinis"},
"blink":{"blink","blinked","blinking","blinks"},
"blinker":{"blinker","blinkers"},
"blinks":{"blinks","blinkses"},
"blintz":{"blintz","blintzs"},
"blintze":{"blintze","blintzes"},
"bliny":{"blinies","bliny"},
"blip":{"blip","blips"},
"bliss":{"bliss","blisses"},
"blissfulness":{"blissfulness","blissfulnesses"},
"blissus":{"blissus","blissuses"},
"blister":{"blister","blistered","blistering","blisters"},
"blithe":{"blithe","blither","blithest"},
"blitheness":{"blitheness","blithenesses"},
"blither":{"blither","blithered","blithering","blithers"},
"blitt":{"blitt","blitts"},
"blitz":{"blitz","blitzed","blitzing","blitzs"},
"blizzard":{"blizzard","blizzards"},
"bloat":{"bloat","bloated","bloating"},
"blob":{"blob","blobbed","blobbing","blobs"},
"bloc":{"bloc","blocs"},
"block":{"block","blocked","blocking","blocks"},
"blockade":{"blockade","blockaded","blockades","blockading"},
"blockage":{"blockage","blockages"},
"blockhead":{"blockhead","blockheads"},
"blockhouse":{"blockhouse","blockhouses"},
"blocking":{"blocking","blockings"},
"blocky":{"blockier","blockiest","blocky"},
"bloke":{"bloke","blokes"},
"blolly":{"blollies","blolly"},
"blond":{"blond","blonder","blondest","blonds"},
"blonde":{"blonde","blonder","blondes","blondest"},
"blondness":{"blondness","blondnesses"},
"blood":{"blood","blooded","blooding","bloods"},
"blood-twig":{"blood-twig","blood-twigs"},
"bloodbath":{"bloodbath","bloodbaths"},
"bloodberry":{"bloodberries","bloodberry"},
"bloodhound":{"bloodhound","bloodhounds"},
"bloodletting":{"bloodletting","bloodlettings"},
"bloodline":{"bloodline","bloodlines"},
"bloodroot":{"bloodroot","bloodroots"},
"bloodshed":{"bloodshed","bloodsheds"},
"bloodstone":{"bloodstone","bloodstones"},
"bloodsucker":{"bloodsucker","bloodsuckers"},
"bloodthirstiness":{"bloodthirstiness","bloodthirstinesses"},
"bloodthirsty":{"bloodthirstier","bloodthirstiest","bloodthirsty"},
"bloody":{"bloodied","bloodier","bloodies","bloodiest","bloody","bloodying"},
"bloom":{"bloom","bloomed","blooming","blooms"},
"bloomeria":{"bloomeria","bloomerias"},
"bloomers":{"bloomers","bloomerses"},
"bloomery":{"bloomeries","bloomery"},
"blooming":{"blooming","bloomings"},
"bloomy":{"bloomier","bloomiest","bloomy"},
"bloop":{"bloop","blooped","blooping"},
"blooper":{"blooper","bloopers"},
"blossom":{"blossom","blossomed","blossoming","blossoms"},
"blossoming":{"blossoming","blossomings"},
"blot":{"blot","blots","blotted","blotting"},
"blotch":{"blotch","blotched","blotches","blotching"},
"blotchy":{"blotchier","blotchiest","blotchy"},
"blotter":{"blotter","blotters"},
"blouse":{"blouse","blouses"},
"blow":{"blew","blow","blowing","blown","blows"},
"blowball":{"blowball","blowballs"},
"blower":{"blower","blowers"},
"blowfish":{"blowfish","blowfishes"},
"blowfly":{"blowflies","blowfly"},
"blowgun":{"blowgun","blowguns"},
"blowhard":{"blowhard","blowhards"},
"blowhole":{"blowhole","blowholes"},
"blowjob":{"blowjob","blowjobs"},
"blowlamp":{"blowlamp","blowlamps"},
"blowout":{"blowout","blowouts"},
"blowpipe":{"blowpipe","blowpipes"},
"blowsy":{"blowsier","blowsiest","blowsy"},
"blowtorch":{"blowtorch","blowtorches"},
"blowtube":{"blowtube","blowtubes"},
"blowup":{"blowup","blowups"},
"blowy":{"blowier","blowiest","blowy"},
"blowzy":{"blowzier","blowziest","blowzy"},
"blow_one's_nose":{"blew_one's_nose","blowing_one's_nose","blows_one's_nose","blow_one's_nose"},
"blt":{"blt","blts"},
"blub":{"blub","blubbed","blubbing","blubs"},
"blubber":{"blubber","blubbered","blubbering","blubbers"},
"blucher":{"blucher","bluchers"},
"bluchers":{"bluchers","blucherses"},
"bludgeon":{"bludgeon","bludgeoned","bludgeoning","bludgeons"},
"blue":{"blue","blued","blueing","bluer","blues","bluest","bluing"},
"blue-belly":{"blue-bellies","blue-belly"},
"blue-blindness":{"blue-blindness","blue-blindnesses"},
"blue-pencil":{"blue-pencil","blue-penciled","blue-penciling","blue-pencilled","blue-pencilling","blue-pencills"},
"bluebell":{"bluebell","bluebells"},
"blueberry":{"blueberries","blueberry"},
"bluebill":{"bluebill","bluebills"},
"bluebird":{"bluebird","bluebirds"},
"bluebonnet":{"bluebonnet","bluebonnets"},
"bluebottle":{"bluebottle","bluebottles"},
"bluefin":{"bluefin","bluefins"},
"bluefish":{"bluefish","bluefishes"},
"bluegill":{"bluegill","bluegills"},
"bluehead":{"bluehead","blueheads"},
"blueing":{"blueing","blueings"},
"bluejacket":{"bluejacket","bluejackets"},
"blueness":{"blueness","bluenesses"},
"bluepoint":{"bluepoint","bluepoints"},
"blueprint":{"blueprint","blueprinted","blueprinting","blueprints"},
"blues":{"blues","blueses"},
"bluestem":{"bluestem","bluestems"},
"bluestocking":{"bluestocking","bluestockings"},
"bluet":{"bluet","bluets"},
"bluethroat":{"bluethroat","bluethroats"},
"blueweed":{"blueweed","blueweeds"},
"bluewing":{"bluewing","bluewings"},
"bluff":{"bluff","bluffed","bluffer","bluffest","bluffing","bluffs"},
"bluing":{"bluing","bluings"},
"blunder":{"blunder","blundered","blundering","blunders"},
"blunderer":{"blunderer","blunderers"},
"blunt":{"blunt","blunted","blunter","bluntest","blunting"},
"bluntness":{"bluntness","bluntnesses"},
"blur":{"blur","blurred","blurring","blurs"},
"blurb":{"blurb","blurbs"},
"blurriness":{"blurriness","blurrinesses"},
"blurry":{"blurrier","blurriest","blurry"},
"blurt":{"blurt","blurted","blurting","blurts"},
"blush":{"blush","blushed","blushes","blushing"},
"blusher":{"blusher","blushers"},
"bluster":{"bluster","blustered","blustering","blusters"},
"blusterer":{"blusterer","blusterers"},
"bm":{"bm","bms"},
"bmr":{"bmr","bmrs"},
"bmus":{"bmus","bmuses"},
"bns":{"bns","bnses"},
"boa":{"boa","boas"},
"boar":{"boar","boars"},
"board":{"board","boarded","boarding","boards"},
"boarder":{"boarder","boarders"},
"boarding":{"boarding","boardings"},
"boardinghouse":{"boardinghouse","boardinghouses"},
"boardroom":{"boardroom","boardrooms"},
"boarfish":{"boarfish","boarfishes"},
"boast":{"boast","boasted","boasting","boasts"},
"boaster":{"boaster","boasters"},
"boastfulness":{"boastfulness","boastfulnesses"},
"boasting":{"boasting","boastings"},
"boat":{"boat","boated","boating","boats"},
"boatbill":{"boatbill","boatbills"},
"boater":{"boater","boaters"},
"boathouse":{"boathouse","boathouses"},
"boating":{"boating","boatings"},
"boatload":{"boatload","boatloads"},
"boatman":{"boatman","boatmen"},
"boatswain":{"boatswain","boatswains"},
"bob":{"bob","bobbed","bobbing","bobs"},
"bobber":{"bobber","bobbers"},
"bobbery":{"bobberies","bobbery"},
"bobbin":{"bobbin","bobbins"},
"bobble":{"bobble","bobbled","bobbles","bobbling"},
"bobby":{"bobbies","bobby"},
"bobbysock":{"bobbysock","bobbysocks"},
"bobbysocker":{"bobbysocker","bobbysockers"},
"bobbysocks":{"bobbysocks","bobbysockses"},
"bobbysoxer":{"bobbysoxer","bobbysoxers"},
"bobcat":{"bobcat","bobcats"},
"bobfloat":{"bobfloat","bobfloats"},
"bobolink":{"bobolink","bobolinks"},
"bobsled":{"bobsled","bobsleds"},
"bobsleigh":{"bobsleigh","bobsleighs"},
"bobtail":{"bobtail","bobtails"},
"bobwhite":{"bobwhite","bobwhites"},
"bocce":{"bocce","bocces"},
"bocci":{"bocci","boccis"},
"boccie":{"boccie","boccies"},
"bocconia":{"bocconia","bocconias"},
"boche":{"boche","boches"},
"bock":{"bock","bocks"},
"bod":{"bod","bods"},
"boddhisatva":{"boddhisatva","boddhisatvas"},
"bode":{"bode","boded","bodes","boding"},
"bodega":{"bodega","bodegas"},
"bodhisattva":{"bodhisattva","bodhisattvas"},
"bodice":{"bodice","bodices"},
"boding":{"boding","bodings"},
"bodkin":{"bodkin","bodkins"},
"bodo-garo":{"bodo-garo","bodo-garos"},
"bodoni":{"bodoni","bodonis"},
"body":{"bodied","bodies","body","bodying"},
"body-build":{"body-build","body-builds"},
"bodybuilder":{"bodybuilder","bodybuilders"},
"bodybuilding":{"bodybuilding","bodybuildings"},
"bodyguard":{"bodyguard","bodyguards"},
"bodysurf":{"bodysurf","bodysurfed","bodysurfing"},
"boehm":{"boehm","boehms"},
"boehme":{"boehme","boehmes"},
"boehmenism":{"boehmenism","boehmenisms"},
"boehmeria":{"boehmeria","boehmerias"},
"boer":{"boer","boers"},
"boeuf":{"boeuf","boeufs"},
"boffo":{"boffo","boffos"},
"bog":{"bog","bogged","bogging","bogs"},
"bog-down":{"bog-down","bogged-down","bogging-down","bogs-down"},
"bogart":{"bogart","bogarts"},
"bogbean":{"bogbean","bogbeans"},
"bogey":{"bogey","bogeys"},
"bogeyman":{"bogeyman","bogeymen"},
"boggle":{"boggle","boggled","boggles","boggling"},
"bogie":{"bogie","bogies"},
"bogmat":{"bogmat","bogmats"},
"bogota":{"bogota","bogotas"},
"bogy":{"bogies","bogy"},
"bog_down":{"bogged_down","bogging_down","bogs_down","bog_down"},
"bohme":{"bohme","bohmes"},
"boidae":{"boidae","boidaes"},
"boil":{"boil","boiled","boiling","boils"},
"boiler":{"boiler","boilers","boils"},
"boilersuit":{"boilersuit","boilersuits"},
"boiling":{"boiling","boilings"},
"boise":{"boise","boises"},
"bokkos":{"bokkos","bokkoses"},
"bokmal":{"bokmal","bokmals"},
"bola":{"bola","bolas"},
"bolanci":{"bolanci","bolancis"},
"bolas":{"bolas","bolases"},
"bolbitis":{"bolbitis","bolbitises"},
"bold":{"bold","bolder","boldest"},
"boldness":{"boldness","boldnesses"},
"bole":{"bole","boles"},
"bolero":{"bolero","boleros"},
"boletaceae":{"boletaceae","boletaceaes"},
"boletellus":{"boletellus","boletelluses"},
"boletus":{"boleti","boletus","boletuses"},
"boleyn":{"boleyn","boleyns"},
"bolide":{"bolide","bolides"},
"bolingbroke":{"bolingbroke","bolingbrokes"},
"bolivar":{"bolivar","bolivares","bolivars"},
"boliviano":{"boliviano","bolivianos"},
"boll":{"boll","bolls"},
"bollard":{"bollard","bollards"},
"bollix":{"bollix","bollixed","bollixes","bollixing"},
"bollock":{"bollock","bollocks"},
"bolo":{"bolo","bolos"},
"bologna":{"bologna","bolognas"},
"bologram":{"bologram","bolograms"},
"bolograph":{"bolograph","bolographs"},
"boloney":{"boloney","boloneys"},
"bolshevik":{"bolshevik","bolsheviki","bolsheviks"},
"bolshevism":{"bolshevism","bolshevisms"},
"bolshie":{"bolshie","bolshies"},
"bolshy":{"bolshies","bolshy"},
"bolster":{"bolster","bolstered","bolstering","bolsters"},
"bolt":{"bolt","bolted","bolting","bolts"},
"bolti":{"bolti","boltis"},
"boltonia":{"boltonia","boltonias"},
"bolus":{"bolus","boluses"},
"bomarea":{"bomarea","bomareas"},
"bomb":{"bomb","bombed","bombing","bombs"},
"bombacaceae":{"bombacaceae","bombacaceaes"},
"bombard":{"bombard","bombarded","bombarding","bombards"},
"bombardment":{"bombardment","bombardments"},
"bombardon":{"bombardon","bombardons"},
"bombast":{"bombast","bombasts"},
"bombax":{"bombax","bombaxes"},
"bomber":{"bomber","bombers"},
"bombina":{"bombina","bombinas"},
"bombinate":{"bombinate","bombinated","bombinates","bombinating"},
"bombing":{"bombing","bombings"},
"bombproof":{"bombproof","bombproofs"},
"bombshell":{"bombshell","bombshells"},
"bombus":{"bombus","bombuses"},
"bombycid":{"bombycid","bombycids"},
"bombycidae":{"bombycidae","bombycidaes"},
"bombycilla":{"bombycilla","bombycillas"},
"bombycillidae":{"bombycillidae","bombycillidaes"},
"bombyliidae":{"bombyliidae","bombyliidaes"},
"bombyx":{"bombyx","bombyxes"},
"bonanza":{"bonanza","bonanzas"},
"bonasa":{"bonasa","bonasas"},
"bonavist":{"bonavist","bonavists"},
"bonbon":{"bonbon","bonbons"},
"bond":{"bond","bonded","bonding","bonds"},
"bondage":{"bondage","bondages"},
"bonding":{"bonding","bondings"},
"bondmaid":{"bondmaid","bondmaids"},
"bondman":{"bondman","bondmen"},
"bondsman":{"bondsman","bondsmen"},
"bondswoman":{"bondswoman","bondswomen"},
"bonduc":{"bonduc","bonducs"},
"bondwoman":{"bondwoman","bondwomen"},
"bone":{"bone","boned","bones","boning"},
"bonefish":{"bonefish","bonefishes"},
"bonehead":{"bonehead","boneheads"},
"bonelet":{"bonelet","bonelets"},
"boner":{"boner","boners"},
"bones":{"bones","boneses"},
"boneset":{"boneset","bonesets"},
"bonfire":{"bonfire","bonfires"},
"bong":{"bong","bonged","bonging"},
"bongo":{"bongo","bongoes","bongos"},
"bonhomie":{"bonhomie","bonhomies"},
"boniness":{"boniness","boninesses"},
"bonito":{"bonito","bonitos"},
"bonnet":{"bonnet","bonneted","bonneting","bonnets"},
"bonnethead":{"bonnethead","bonnetheads"},
"bonnie":{"bonnie","bonnier","bonniest"},
"bonny":{"bonnier","bonniest","bonny"},
"bonobo":{"bonobo","bonobos"},
"bontebok":{"bontebok","bonteboks"},
"bonus":{"bonus","bonuses"},
"bonxie":{"bonxie","bonxies"},
"bony":{"bonier","boniest","bony"},
"boo":{"boo","booed","booing","boos"},
"boo-boo":{"boo-boo","boo-boos"},
"boob":{"boob","boobs"},
"booby":{"boobies","booby"},
"booby-trap":{"booby-trap","booby-trapped","booby-trapping","booby-traps"},
"boodle":{"boodle","boodles"},
"booger":{"booger","boogers"},
"boogeyman":{"boogeyman","boogeymen"},
"boogie":{"boogie","boogies"},
"boogie-woogie":{"boogie-woogie","boogie-woogies"},
"boogieman":{"boogieman","boogiemen"},
"boohoo":{"boohoo","boohooed","boohooing","boohoos"},
"book":{"book","booked","booking","books"},
"bookbindery":{"bookbindereries","bookbinderies","bookbindery"},
"bookcase":{"bookcase","bookcases"},
"bookdealer":{"bookdealer","bookdealers"},
"bookend":{"bookend","bookends"},
"booker":{"booker","bookers"},
"bookie":{"bookie","bookies"},
"booking":{"booking","bookings"},
"bookkeeper":{"bookkeeper","bookkeepers"},
"bookkeeping":{"bookkeeping","bookkeepings"},
"booklet":{"booklet","booklets"},
"booklouse":{"booklice","booklouse"},
"booklover":{"booklover","booklovers"},
"bookmaker":{"bookmaker","bookmakers"},
"bookman":{"bookman","bookmen"},
"bookmark":{"bookmark","bookmarks"},
"bookmarker":{"bookmarker","bookmarkers"},
"bookplate":{"bookplate","bookplates"},
"bookshelf":{"bookshelf","bookshelves"},
"bookshop":{"bookshop","bookshops"},
"bookstall":{"bookstall","bookstalls"},
"bookstore":{"bookstore","bookstores"},
"bookworm":{"bookworm","bookworms"},
"boole":{"boole","booles"},
"boom":{"boom","boomed","booming","booms"},
"boomer":{"boomer","boomers"},
"boomerang":{"boomerang","boomeranged","boomeranging","boomerangs"},
"boon":{"boon","boons"},
"boondocks":{"boondocks","boondockses"},
"boondoggle":{"boondoggle","boondoggled","boondoggling"},
"boone":{"boone","boones"},
"boor":{"boor","boors"},
"boorishness":{"boorishness","boorishnesses"},
"boost":{"boost","boosted","boosting","boosts"},
"booster":{"booster","boosters"},
"boosters":{"boosters","boosterses"},
"boot":{"boot","booted","booting","boots"},
"bootblack":{"bootblack","bootblacks"},
"bootee":{"bootee","bootees"},
"bootees":{"bootees","booteeses"},
"booth":{"booth","booths"},
"bootie":{"bootie","booties"},
"booties":{"booties","bootieses"},
"bootleg":{"bootleg","bootlegged","bootlegging","bootlegs"},
"bootlegger":{"bootlegger","bootleggers"},
"bootlick":{"bootlick","bootlicked","bootlicking","bootlicks"},
"bootlicker":{"bootlicker","bootlickers"},
"bootmaker":{"bootmaker","bootmakers"},
"boots":{"boots"},
"booty":{"booties","booty"},
"booyong":{"booyong","booyongs"},
"booze":{"booze","boozed","boozes","boozing"},
"booze-up":{"booze-up","booze-ups"},
"boozer":{"boozer","boozers"},
"boozing":{"boozing","boozings"},
"boozy":{"boozier","booziest","boozy"},
"bop":{"bop","bops"},
"bopeep":{"bopeep","bopeeps"},
"borage":{"borage","borages"},
"boraginaceae":{"boraginaceae","boraginaceaes"},
"borago":{"borago","boragos"},
"borassus":{"borassus","borassuses"},
"borax":{"boraces","borax","boraxes"},
"borborygmus":{"borborygmi","borborygmus"},
"bordeaux":{"bordeaux","bordeauxes"},
"bordello":{"bordello","bordellos"},
"border":{"border","bordered","bordering","borders"},
"bordereau":{"bordereau","bordereaux"},
"borderland":{"borderland","borderlands"},
"borderline":{"borderline","borderlines"},
"bore":{"bore","bored","bores","boring"},
"bore-hole":{"bore-hole","bore-holes"},
"boreas":{"boreas","boreases"},
"borecole":{"borecole","borecoles"},
"boredom":{"boredom","boredoms"},
"borer":{"borer","borers"},
"boring":{"boring","borings"},
"boringness":{"boringness","boringnesses"},
"borneo":{"borneo","borneos"},
"bornite":{"bornite","bornites"},
"boron":{"boron","borons"},
"borough":{"borough","boroughs"},
"borrow":{"borrow","borrowed","borrowing","borrows"},
"borrowing":{"borrowing","borrowings"},
"borsch":{"borsch","borsches"},
"borscht":{"borscht","borschts"},
"borsh":{"borsh","borshes"},
"borshch":{"borshch","borshches"},
"borsht":{"borsht","borshts"},
"borstal":{"borstal","borstals"},
"bortsch":{"bortsch","bortsches"},
"borzoi":{"borzoi","borzois"},
"bos":{"bos","boses"},
"boschbok":{"bok","boschbok","boschboks","bushbok","bushboks"},
"boselaphus":{"boselaphus","boselaphuses"},
"bosh":{"bosh","boshes"},
"bosie":{"bosie","bosies"},
"bosky":{"boskier","boskiest","bosky"},
"bosnia":{"bosnia","bosnias"},
"bosnia-herzegovina":{"bosnia-herzegovina","bosnia-herzegovinas"},
"bosom":{"bosom","bosomed","bosoming","bosoms"},
"boss":{"boss","bossed","bosses","bossing"},
"bossy":{"bossier","bossiest","bossy"},
"boston":{"boston","bostons"},
"bosun":{"bosun","bosuns"},
"boswellia":{"boswellia","boswellias"},
"botanical":{"botanical","botanicals"},
"botanist":{"botanist","botanists"},
"botanize":{"botanize","botanized","botanizes","botanizing"},
"botany":{"botanies","botany"},
"botargo":{"botargo","botargoes"},
"botaurus":{"botaurus","botauruses"},
"botch":{"botch","botched","botches","botching"},
"botcher":{"botcher","botchers"},
"botchy":{"botchier","botchiest","botchy"},
"botfly":{"botflies","botfly"},
"bother":{"bother","bothered","bothering","bothers"},
"botheration":{"botheration","botherations"},
"bothidae":{"bothidae","bothidaes"},
"bothrops":{"bothrops","bothropses"},
"bothy":{"bothies","bothy"},
"botrychium":{"botrychium","botrychiums"},
"bottle":{"bottle","bottled","bottles","bottling"},
"bottle-feed":{"bottle-fed","bottle-feed","bottle-feeding","bottle-feeds"},
"bottleful":{"bottleful","bottlefuls"},
"bottlegrass":{"bottlegrass","bottlegrasses"},
"bottleneck":{"bottleneck","bottlenecks"},
"bottlenose":{"bottlenose","bottlenoses"},
"bottom":{"bottom","bottomed","bottoming","bottoms"},
"bottomland":{"bottomland","bottomlands"},
"bottomry":{"bottomries","bottomry"},
"botulinum":{"botulinum","botulinums"},
"botulinus":{"botulinus","botulinuses"},
"boubou":{"boubou","boubous"},
"bouchee":{"bouchee","bouchees"},
"boucle":{"boucle","boucles"},
"bouffe":{"bouffe","bouffes"},
"bougainvillaea":{"bougainvillaea","bougainvillaeas"},
"bougainvillea":{"bougainvillea","bougainvilleas"},
"bough":{"bough","boughs"},
"bouillon":{"bouillon","bouillons"},
"boulder":{"boulder","boulders"},
"boule":{"boule","boules"},
"boulevard":{"boulevard","boulevards"},
"boulle":{"boulle","boulles"},
"bounce":{"bounce","bounced","bounces","bouncing"},
"bouncer":{"bouncer","bouncers"},
"bounciness":{"bounciness","bouncinesses"},
"bouncing":{"bouncing","bouncings"},
"bouncing_betty":{"bouncing_betties","bouncing_betty"},
"bouncy":{"bouncier","bounciest","bouncy"},
"bound":{"bound","bounded","bounding","bounds"},
"boundary":{"boundaries","boundary"},
"boundedness":{"boundedness","boundednesses"},
"bounder":{"bounder","bounders"},
"boundlessness":{"boundlessness","boundlessnesses"},
"bounds":{"bounds","boundses"},
"bounteousness":{"bounteousness","bounteousnesses"},
"bountifulness":{"bountifulness","bountifulnesses"},
"bounty":{"bounties","bounty"},
"bouquet":{"bouquet","bouquets"},
"bourdon":{"bourdon","bourdons"},
"bourgeois":{"bourgeois","bourgeoises"},
"bourgeoisie":{"bourgeoisie","bourgeoisies"},
"bourgogne":{"bourgogne","bourgognes"},
"bourguignon":{"bourguignon","bourguignons"},
"bourn":{"bourn","bourns"},
"bourne":{"bourne","bournes"},
"bourtree":{"bourtree","bourtrees"},
"bouse":{"bouse","boused","bouses","bousing"},
"bout":{"bout","bouts"},
"bouteloua":{"bouteloua","boutelouas"},
"boutique":{"boutique","boutiques"},
"bouyei":{"bouyei","bouyeis"},
"bovidae":{"bovidae","bovidaes"},
"bovinae":{"bovinae","bovinaes"},
"bovini":{"bovini","bovinis"},
"bovril":{"bovril","bovrils"},
"bow":{"bow","bowed","bowing","bows"},
"bow-wow":{"bow-wow","bow-wows"},
"bowdlerisation":{"bowdlerisation","bowdlerisations"},
"bowdlerization":{"bowdlerization","bowdlerizations"},
"bowdlerize":{"bowdlerize","bowdlerized","bowdlerizes","bowdlerizing"},
"bowel":{"bowel","boweled","boweling","bowelled","bowelling","bowels"},
"bower":{"bower","bowered","bowering","bowers"},
"bowerbird":{"bowerbird","bowerbirds"},
"bowfin":{"bowfin","bowfins"},
"bowhead":{"bowhead","bowheads"},
"bowiea":{"bowiea","bowieas"},
"bowing":{"bowing","bowings"},
"bowknot":{"bowknot","bowknots"},
"bowl":{"bowl","bowled","bowling","bowls"},
"bowlder":{"bowlder","bowlders"},
"bowleg":{"bowleg","bowlegs"},
"bowler":{"bowler","bowlers"},
"bowlful":{"bowlful","bowlfuls"},
"bowline":{"bowline","bowlines"},
"bowman":{"bowman","bowmen"},
"bowstring":{"bowstring","bowstringed","bowstringing","bowstrings","bowstrung"},
"bowwow":{"bowwow","bowwowed","bowwowing","bowwows"},
"box":{"box","boxed","boxes","boxing"},
"boxberry":{"boxberries","boxberry"},
"boxer":{"boxer","boxers"},
"boxfish":{"boxfish","boxfishes"},
"boxful":{"boxful","boxfuls"},
"boxhaul":{"boxhaul","boxhauled","boxhauling"},
"boxing":{"boxing","boxings"},
"boxthorn":{"boxthorn","boxthorns"},
"boxwood":{"boxwood","boxwoods"},
"boxy":{"boxier","boxiest","boxy"},
"box_kodak":{"box-kodaks","box_kodak"},
"boy":{"boy","boys"},
"boycott":{"boycott","boycotted","boycotting","boycotts"},
"boyfriend":{"boyfriend","boyfriends"},
"boyhood":{"boyhood","boyhoods"},
"boykinia":{"boykinia","boykinias"},
"boyne":{"boyne","boynes"},
"boys-and-girls":{"boys-and-girls","boys-and-girlses"},
"boysenberry":{"boysenberries","boysenberry"},
"bozo":{"bozo","bozos"},
"bpi":{"bpi","bpis"},
"bpm":{"bpm","bpms"},
"bps":{"bps","bpses"},
"br":{"br","brs"},
"bra":{"bra","bras"},
"brabble":{"brabble","brabbled","brabbles","brabbling"},
"brace":{"brace","braced","braces","bracing"},
"bracelet":{"bracelet","bracelets"},
"bracer":{"bracer","bracers"},
"bracero":{"bracero","braceros"},
"braces":{"braces","braceses"},
"brachiate":{"brachiate","brachiated","brachiating"},
"brachinus":{"brachinus","brachinuses"},
"brachiopod":{"brachiopod","brachiopods"},
"brachiopoda":{"brachiopoda","brachiopodas"},
"brachium":{"brachia","brachium"},
"brachychiton":{"brachychiton","brachychitons"},
"brachycome":{"brachycome","brachycomes"},
"brachydactylia":{"brachydactylia","brachydactylias"},
"brachylogy":{"brachylogies","brachylogy"},
"brachystegia":{"brachystegia","brachystegias"},
"brachytactyly":{"brachytactylies","brachytactyly"},
"brachyura":{"brachyura","brachyuras"},
"bracing":{"bracing","bracings"},
"bracken":{"bracken","brackens"},
"bracket":{"bracket","bracketed","bracketing","brackets"},
"brad":{"brad","bradded","bradding","brads"},
"bradawl":{"bradawl","bradawls"},
"bradypodidae":{"bradypodidae","bradypodidaes"},
"bradypus":{"bradypus","bradypuses"},
"brag":{"brag","bragged","bragging","brags"},
"brage":{"brage","brages"},
"bragg":{"bragg","braggs"},
"braggadocio":{"braggadocio","braggadocios"},
"braggart":{"braggart","braggarts"},
"bragging":{"bragging","braggings"},
"bragi":{"bragi","bragis"},
"brahma":{"brahma","brahmas"},
"brahman":{"brahman","brahmans","brahmen"},
"brahmani":{"brahmani","brahmanis"},
"brahmanism":{"brahmanism","brahmanisms"},
"brahmaputra":{"brahmaputra","brahmaputras"},
"brahmin":{"brahmin","brahmins"},
"brahminism":{"brahminism","brahminisms"},
"brahms":{"brahms","brahmses"},
"brahui":{"brahui","brahuis"},
"braid":{"braid","braided","braiding","braids"},
"braiding":{"braiding","braidings"},
"brail":{"brail","brailed","brailing"},
"braille":{"braille","brailled","brailling"},
"brain":{"brain","brained","braining","brains"},
"brain-fag":{"brain-fag","brain-fags"},
"brain-teaser":{"brain-teaser","brain-teasers"},
"braincase":{"braincase","braincases"},
"brainchild":{"brainchild","brainchildren"},
"brainpan":{"brainpan","brainpans"},
"brainpower":{"brainpower","brainpowers"},
"brainstem":{"brainstem","brainstems"},
"brainstorm":{"brainstorm","brainstorms"},
"brainwash":{"brainwash","brainwashed","brainwashing"},
"brainwave":{"brainwave","brainwaves"},
"brainy":{"brainier","brainiest","brainy"},
"braise":{"braise","braised","braising"},
"brake":{"brake","braked","brakes","braking"},
"brakeman":{"brakeman","brakemen"},
"brakes":{"brakes","brakeses"},
"brakesman":{"brakesman","brakesmen"},
"brama":{"brama","bramas"},
"bramble":{"bramble","brambles"},
"brambling":{"brambling","bramblings"},
"brambly":{"bramblier","brambliest","brambly"},
"bramidae":{"bramidae","bramidaes"},
"branch":{"branch","branched","branches","branching"},
"branchia":{"branchia","branchiae","branchias"},
"branching":{"branching","branchings"},
"branchiobdella":{"branchiobdella","branchiobdellas"},
"branchiobdellidae":{"branchiobdellidae","branchiobdellidaes"},
"branchiopod":{"branchiopod","branchiopods"},
"branchiopoda":{"branchiopoda","branchiopodas"},
"branchiopodan":{"branchiopodan","branchiopodans"},
"branchiostegidae":{"branchiostegidae","branchiostegidaes"},
"branchiostomidae":{"branchiostomidae","branchiostomidaes"},
"branchiura":{"branchiura","branchiuras"},
"branchlet":{"branchlet","branchlets"},
"brand":{"brand","branded","branding","brands"},
"branding":{"branding","brandings"},
"brandish":{"brandish","brandished","brandishes","brandishing"},
"brandy":{"brandied","brandies","brandy","brandying"},
"brant":{"brant","brants"},
"branta":{"branta","brantas"},
"brasenia":{"brasenia","brasenias"},
"brash":{"brash","brasher","brashest"},
"brashness":{"brashness","brashnesses"},
"brashy":{"brashier","brashiest","brashy"},
"brasier":{"brasier","brasiers"},
"brasil":{"brasil","brasils"},
"brasilia":{"brasilia","brasilias"},
"brass":{"brass","brasses"},
"brassia":{"brassia","brassias"},
"brassica":{"brassica","brassicas"},
"brassicaceae":{"brassicaceae","brassicaceaes"},
"brassie":{"brassie","brassies"},
"brassiere":{"brassiere","brassieres"},
"brassy":{"brassier","brassies","brassiest","brassy"},
"brat":{"brat","brats"},
"bratty":{"brattier","brattiest","bratty"},
"braunschweig":{"braunschweig","braunschweigs"},
"bravado":{"bravado","bravadoes","bravados"},
"brave":{"brave","braved","braver","bravest","braving"},
"bravery":{"braveries","bravery"},
"braving":{"braving","bravings"},
"bravo":{"bravo","bravoes","bravos"},
"brawl":{"brawl","brawled","brawling","brawls"},
"brawn":{"brawn","brawns"},
"brawny":{"brawnier","brawniest","brawny"},
"bray":{"bray","brayed","braying","brays"},
"braze":{"braze","brazed","brazing"},
"brazen":{"brazen","brazened","brazening"},
"brazenness":{"brazenness","brazennesses"},
"brazier":{"brazier","braziers"},
"brazil":{"brazil","brazils"},
"brazilwood":{"brazilwood","brazilwoods"},
"brazos":{"brazos","brazoses"},
"brazzaville":{"brazzaville","brazzavilles"},
"breach":{"breach","breached","breaches","breaching"},
"bread":{"bread","breaded","breading","breads"},
"bread-bin":{"bread-bin","bread-bins"},
"breadbasket":{"breadbasket","breadbaskets"},
"breadboard":{"breadboard","breadboards"},
"breadbox":{"breadbox","breadboxes"},
"breadfruit":{"breadfruit","breadfruits"},
"breadline":{"breadline","breadlines"},
"breadroot":{"breadroot","breadroots"},
"breadstuff":{"breadstuff","breadstuffs"},
"breadth":{"breadth","breadths"},
"break":{"break","breaking","breaks","broke","broken"},
"break-in":{"break-in","break-ins"},
"breakability":{"breakabilities","breakability"},
"breakage":{"breakage","breakages"},
"breakaway":{"breakaway","breakaways"},
"breakax":{"breakax","breakaxes"},
"breakaxe":{"breakaxe","breakaxes"},
"breakdown":{"breakdown","breakdowns"},
"breaker":{"breaker","breakers"},
"breakers":{"breakers","breakerses"},
"breakfast":{"breakfast","breakfasted","breakfasting","breakfasts"},
"breaking":{"breaking","breakings"},
"breakout":{"breakout","breakouts"},
"breakstone":{"breakstone","breakstones"},
"breakthrough":{"breakthrough","breakthroughs"},
"breakup":{"breakup","breakups"},
"breakwater":{"breakwater","breakwaters"},
"bream":{"bream","breamed","breaming","breams"},
"breast":{"breast","breasted","breasting","breasts"},
"breast-feed":{"breast-fed","breast-feed","breast-feeding","breast-feeds"},
"breastbone":{"breastbone","breastbones"},
"breastpin":{"breastpin","breastpins"},
"breastplate":{"breastplate","breastplates"},
"breastwork":{"breastwork","breastworks"},
"breath":{"breath","breaths"},
"breathalyser":{"breathalyser","breathalysers"},
"breathalyzer":{"breathalyzer","breathalyzers"},
"breathe":{"breathe","breathed","breathes","breathing"},
"breather":{"breather","breathers"},
"breathing":{"breathing","breathings"},
"breathy":{"breathier","breathiest","breathy"},
"breech":{"breech","breeched","breeches","breeching"},
"breechblock":{"breechblock","breechblocks"},
"breechcloth":{"breechcloth","breechcloths"},
"breechclout":{"breechclout","breechclouts"},
"breeches":{"breeches","breecheses"},
"breed":{"bred","breed","breeding","breeds"},
"breeder":{"breeder","breeders"},
"breeding":{"breeding","breedings"},
"breeze":{"breeze","breezed","breezes","breezing"},
"breeziness":{"breeziness","breezinesses"},
"breezy":{"breezier","breeziest","breezy"},
"bregma":{"bregma","bregmata"},
"brei":{"brei","breid","breiing","breis"},
"breiz":{"breiz","breizs"},
"bren":{"bren","brens"},
"brent":{"brent","brents"},
"breslau":{"breslau","breslaus"},
"bretagne":{"bretagne","bretagnes"},
"brethren":{"brethren","brothers"},
"brevet":{"brevet","breveted","breveting","brevets","brevetted","brevetting"},
"breviary":{"breviaries","breviary"},
"brevicipitidae":{"brevicipitidae","brevicipitidaes"},
"brevity":{"brevities","brevity"},
"brevoortia":{"brevoortia","brevoortias"},
"brew":{"brew","brewed","brewing","brews"},
"brewage":{"brewage","brewages"},
"brewer":{"brewer","brewers"},
"brewery":{"breweries","brewery"},
"briar":{"briar","briars"},
"briarwood":{"briarwood","briarwoods"},
"bribe":{"bribe","bribed","bribes","bribing"},
"briber":{"briber","bribers"},
"bribery":{"briberies","bribery"},
"bric-a-brac":{"bric-a-brac","bric-a-bracs"},
"brick":{"brick","bricked","bricking","bricks"},
"brickellia":{"brickellia","brickellias"},
"brickfield":{"brickfield","brickfields"},
"brickyard":{"brickyard","brickyards"},
"bricole":{"bricole","bricoles"},
"bridal":{"bridal","bridals"},
"bridalwreath":{"bridalwreath","bridalwreaths"},
"bride":{"bride","brides"},
"bride-to-be":{"bride-to-be","bride-to-bes"},
"bridecake":{"bridecake","bridecakes"},
"bridegroom":{"bridegroom","bridegrooms"},
"bridesmaid":{"bridesmaid","bridesmaids"},
"bridge":{"bridge","bridged","bridges","bridging"},
"bridgehead":{"bridgehead","bridgeheads"},
"bridget":{"bridget","bridgets"},
"bridgework":{"bridgework","bridgeworks"},
"bridle":{"bridle","bridled","bridles","bridling"},
"brie":{"brie","bries"},
"brief":{"brief","briefed","briefer","briefest","briefing","briefs"},
"briefcase":{"briefcase","briefcases"},
"briefness":{"briefness","briefnesses"},
"brier":{"brier","briers"},
"brierpatch":{"brierpatch","brierpatches"},
"brierwood":{"brierwood","brierwoods"},
"brig":{"brig","brigs"},
"brigade":{"brigade","brigaded","brigades","brigading"},
"brigadier":{"brigadier","brigadiers"},
"brigand":{"brigand","brigands"},
"brigantine":{"brigantine","brigantines"},
"bright":{"bright","brighter","brightest","brights"},
"brighten":{"brighten","brightened","brightening","brightens"},
"brightness":{"brightness","brightnesses"},
"brigid":{"brigid","brigids"},
"brill":{"brill","brills"},
"brilliance":{"brilliance","brilliances"},
"brilliancy":{"brilliancies","brilliancy"},
"brilliant":{"brilliant","brilliants"},
"brim":{"brim","brimmed","brimming","brims"},
"brimstone":{"brimstone","brimstones"},
"brine":{"brine","brined","brines","brining"},
"bring":{"bring","bringing","brings","brought"},
"bringing":{"bringing","bringings"},
"brininess":{"brininess","brininesses"},
"brinjal":{"brinjal","brinjals"},
"brink":{"brink","brinks"},
"briny":{"brinier","brinies","briniest","briny"},
"briony":{"brionies","briony","bryonies"},
"briquet":{"briquet","briquets"},
"briquette":{"briquette","briquettes"},
"bris":{"bris","brises"},
"brisk":{"brisk","brisked","brisker","briskest","brisking"},
"briskness":{"briskness","brisknesses"},
"brisling":{"brisling","brislings"},
"bristle":{"bristle","bristled","bristles","bristling"},
"bristlegrass":{"bristlegrass","bristlegrasses"},
"bristly":{"bristlier","bristliest","bristly"},
"brit":{"brit","brits"},
"britain":{"britain","britains"},
"brith":{"brith","briths"},
"briticism":{"briticism","briticisms"},
"british":{"british","britishes"},
"britisher":{"britisher","britishers"},
"britishism":{"britishism","britishisms"},
"briton":{"briton","britons"},
"brits":{"brits","britses"},
"britt":{"britt","britts"},
"brittanic":{"brittanic","brittanics"},
"brittany":{"brittanies","brittany"},
"brittle":{"brittle","brittler","brittles","brittlest"},
"brittlebush":{"brittlebush","brittlebushes"},
"brittleness":{"brittleness","brittlenesses"},
"brittlestar":{"brittlestar","brittlestars"},
"broach":{"broach","broached","broaches","broaching"},
"broad":{"broad","broader","broadest","broads"},
"broadax":{"broadax","broadaxes"},
"broadaxe":{"broadaxe","broadaxes"},
"broadbean":{"broadbean","broadbeans"},
"broadbill":{"broadbill","broadbills"},
"broadcast":{"broadcast","broadcasted","broadcasting","broadcasts"},
"broadcaster":{"broadcaster","broadcasters"},
"broadcasting":{"broadcasting","broadcastings"},
"broaden":{"broaden","broadened","broadening","broadens"},
"broadening":{"broadening","broadenings"},
"broadleaf":{"broadleaf","broadleaves"},
"broadness":{"broadness","broadnesses"},
"broadsheet":{"broadsheet","broadsheets"},
"broadside":{"broadside","broadsides"},
"broadsword":{"broadsword","broadswords"},
"broadtail":{"broadtail","broadtails"},
"broadway":{"broadway","broadways"},
"brocade":{"brocade","brocaded","brocading"},
"broccoli":{"broccoli","broccolis"},
"brochure":{"brochure","brochures"},
"brogan":{"brogan","brogans"},
"brogue":{"brogue","brogues"},
"broider":{"broider","broidered","broidering","broiders"},
"broil":{"broil","broiled","broiling","broils"},
"broiling":{"broiling","broilings"},
"brokenheartedness":{"brokenheartedness","brokenheartednesses"},
"broker":{"broker","brokered","brokering","brokers"},
"brokerage":{"brokerage","brokerages"},
"brolly":{"brollies","brolly"},
"bromate":{"bromate","bromated","bromates","bromating"},
"brome":{"brome","bromes"},
"bromegrass":{"bromegrass","bromegrasses"},
"bromeliaceae":{"bromeliaceae","bromeliaceaes"},
"bromeosin":{"bromeosin","bromeosins"},
"bromide":{"bromide","bromides"},
"brominate":{"brominate","brominated","brominates","brominating"},
"bromine":{"bromine","bromines"},
"bromus":{"bromus","bromuses"},
"bronc":{"bronc","broncs"},
"broncho":{"broncho","bronchos"},
"bronchus":{"bronchi","bronchus","bronchuses"},
"bronco":{"bronco","broncos"},
"brontosaur":{"brontosaur","brontosaurs"},
"brontosaurus":{"brontosaurus","brontosauruses"},
"bronx":{"bronx","bronxes"},
"bronze":{"bronze","bronzed","bronzes","bronzing"},
"brooch":{"brooch","brooched","brooches","brooching"},
"brood":{"brood","brooded","brooding","broods"},
"brooder":{"brooder","brooders"},
"brooding":{"brooding","broodings"},
"broodmare":{"broodmare","broodmares"},
"broody":{"broodier","broodies","broodiest","broody"},
"brook":{"brook","brooked","brooking","brooks"},
"brooklime":{"brooklime","brooklimes"},
"brookweed":{"brookweed","brookweeds"},
"broom":{"broom","broomed","brooming","brooms"},
"broomcorn":{"broomcorn","broomcorns"},
"broomweed":{"broomweed","broomweeds"},
"brosmius":{"brosmius","brosmiuses"},
"broth":{"broth","brothes","broths"},
"brothel":{"brothel","brothels"},
"brother":{"brethren","brother","brothers"},
"brother-in-law":{"brother-in-law","brothers-in-law"},
"brotherhood":{"brotherhood","brotherhoods"},
"brotulidae":{"brotulidae","brotulidaes"},
"brouhaha":{"brouhaha","brouhahas"},
"broussonetia":{"broussonetia","broussonetias"},
"brow":{"brow","brows"},
"browallia":{"browallia","browallias"},
"browbeat":{"browbeat","browbeaten","browbeating","browbeats"},
"brown":{"brown","browned","browner","brownest","browning","browns"},
"brown-nose":{"brown-nose","brown-nosed","brown-noses","brown-nosing"},
"brownie":{"brownie","brownies"},
"browning":{"browning","brownings"},
"brownness":{"brownness","brownnesses"},
"brownout":{"brownout","brownouts"},
"browntail":{"browntail","browntails"},
"browse":{"browse","browsed","browses","browsing"},
"browser":{"browser","browsers"},
"browsing":{"browsing","browsings"},
"bruce":{"bruce","bruces"},
"brucellosis":{"brucelloses","brucellosis"},
"bruchidae":{"bruchidae","bruchidaes"},
"bruchus":{"bruchus","bruchuses"},
"bruckenthalia":{"bruckenthalia","bruckenthalias"},
"bruges":{"bruges","brugeses"},
"brugmansia":{"brugmansia","brugmansias"},
"bruin":{"bruin","bruins"},
"bruise":{"bruise","bruised","bruises","bruising"},
"bruiser":{"bruiser","bruisers"},
"bruit":{"bruit","bruited","bruiting","bruits"},
"brumby":{"brumbies","brumby"},
"brunanburh":{"brunanburh","brunanburhs"},
"brunet":{"brunet","brunets"},
"brunette":{"brunette","brunettes"},
"brunfelsia":{"brunfelsia","brunfelsias"},
"brunhild":{"brunhild","brunhilds"},
"brunnhilde":{"brunnhilde","brunnhildes"},
"brunswick":{"brunswick","brunswicks"},
"brush":{"brush","brushed","brushes","brushing"},
"brushing":{"brushing","brushings"},
"brushup":{"brushup","brushups"},
"brushwood":{"brushwood","brushwoods"},
"brushy":{"brushier","brushiest","brushy"},
"brusqueness":{"brusqueness","brusquenesses"},
"brussels":{"brussels","brusselses"},
"brutalisation":{"brutalisation","brutalisations"},
"brutality":{"brutalities","brutality"},
"brutalization":{"brutalization","brutalizations"},
"brutalize":{"brutalize","brutalized","brutalizes","brutalizing"},
"brute":{"brute","brutes"},
"brutify":{"brutified","brutifies","brutify","brutifying"},
"brutus":{"brutus","brutuses"},
"brya":{"brya","bryas"},
"bryaceae":{"bryaceae","bryaceaes"},
"bryales":{"bryales","bryaleses"},
"brynhild":{"brynhild","brynhilds"},
"bryony":{"bryonies","bryony"},
"bryophyta":{"bryophyta","bryophytas"},
"bryophyte":{"bryophyte","bryophytes"},
"bryopsida":{"bryopsida","bryopsidas"},
"bryozoa":{"bryozoa","bryozoas"},
"bryozoan":{"bryozoan","bryozoans"},
"brythonic":{"brythonic","brythonics"},
"bryum":{"bryum","bryums"},
"bs":{"bs","bses"},
"bsarch":{"bsarch","bsarches"},
"btu":{"btu","btus"},
"bubalus":{"bubalus","bubaluses"},
"bubble":{"bubble","bubbled","bubbles","bubbling"},
"bubbler":{"bubbler","bubblers"},
"bubbliness":{"bubbliness","bubblinesses"},
"bubbly":{"bubblier","bubblies","bubbliest","bubbly"},
"bubo":{"bubo","buboes"},
"bubulcus":{"bubulcus","bubulcuses"},
"buccaneer":{"buccaneer","buccaneers"},
"buccaneering":{"buccaneering","buccaneerings"},
"buccinidae":{"buccinidae","buccinidaes"},
"bucconidae":{"bucconidae","bucconidaes"},
"bucephala":{"bucephala","bucephalas"},
"buceros":{"buceros","buceroses"},
"bucerotidae":{"bucerotidae","bucerotidaes"},
"buchanan":{"buchanan","buchanans"},
"bucharest":{"bucharest","bucharests"},
"buchloe":{"buchloe","buchloes"},
"buck":{"buck","bucked","bucking","bucks"},
"buckaroo":{"buckaroo","buckaroos"},
"buckbean":{"buckbean","buckbeans"},
"bucket":{"bucket","bucketed","bucketing","buckets"},
"bucketful":{"bucketful","bucketfuls"},
"buckeye":{"buckeye","buckeyes"},
"buckle":{"buckle","buckled","buckles","buckling"},
"buckler":{"buckler","bucklered","bucklering","bucklers"},
"buckleya":{"buckleya","buckleyas"},
"bucko":{"bucko","buckoes"},
"buckra":{"buckra","buckras"},
"buckram":{"buckram","buckramed","buckraming","buckrams"},
"buckshot":{"buckshot","buckshots"},
"buckskin":{"buckskin","buckskins"},
"buckthorn":{"buckthorn","buckthorns"},
"bucktooth":{"buckteeth","bucktooth"},
"buckwheat":{"buckwheat","buckwheats"},
"bucolic":{"bucolic","bucolics"},
"bucuresti":{"bucuresti","bucurestis"},
"bud":{"bud","budded","budding","buds"},
"budapest":{"budapest","budapests"},
"buddha":{"buddha","buddhas"},
"buddleia":{"buddleia","buddleias"},
"buddy":{"buddied","buddies","buddy","buddying"},
"budge":{"budge","budged","budges","budging"},
"budgereegah":{"budgereegah","budgereegahs"},
"budgerigar":{"budgerigar","budgerigars"},
"budgerygah":{"budgerygah","budgerygahs"},
"budget":{"budget","budgeted","budgeting","budgets"},
"budgie":{"budgie","budgies"},
"budorcas":{"budorcas","budorcases"},
"buff":{"buff","buffed","buffing","buffs"},
"buffalo":{"buffalo","buffaloed","buffaloes","buffaloing","buffalos"},
"buffalofish":{"buffalofish","buffalofishes"},
"buffer":{"buffer","buffers"},
"bufferin":{"bufferin","bufferins"},
"buffet":{"buffet","buffeted","buffeting","buffets"},
"buffeting":{"buffeting","buffetings"},
"bufflehead":{"bufflehead","buffleheads"},
"buffo":{"buffi","buffo","buffos"},
"buffoon":{"buffoon","buffoons"},
"buffoonery":{"buffooneries","buffoonery"},
"bufonidae":{"bufonidae","bufonidaes"},
"bug":{"bug","bugged","bugging","bugs"},
"bug-hunter":{"bug-hunter","bug-hunters"},
"bugaboo":{"bugaboo","bugaboos"},
"bugbane":{"bugbane","bugbanes"},
"bugbear":{"bugbear","bugbears"},
"bugger":{"bugger","buggered","buggering","buggers"},
"buggery":{"buggeries","buggery"},
"buggy":{"buggier","buggies","buggiest","buggy"},
"bughouse":{"bughouse","bughouses"},
"bugle":{"bugle","bugled","bugles","bugling"},
"bugler":{"bugler","buglers"},
"bugleweed":{"bugleweed","bugleweeds"},
"bugloss":{"bugloss","buglosses"},
"bugologist":{"bugologist","bugologists"},
"buhl":{"buhl","buhls"},
"build":{"build","building","builds","built"},
"builder":{"builder","builders"},
"building":{"building","buildings"},
"bujumbura":{"bujumbura","bujumburas"},
"bulb":{"bulb","bulbed","bulbing","bulbs"},
"bulbil":{"bulbil","bulbils"},
"bulblet":{"bulblet","bulblets"},
"bulge":{"bulge","bulged","bulges","bulging"},
"bulghur":{"bulghur","bulghurs"},
"bulginess":{"bulginess","bulginesses"},
"bulgur":{"bulgur","bulgurs"},
"bulgy":{"bulgier","bulgiest","bulgy"},
"bulk":{"bulk","bulked","bulking","bulks"},
"bulkiness":{"bulkiness","bulkinesses"},
"bulky":{"bulkier","bulkiest","bulky"},
"bull":{"bull","bulled","bulling","bulls"},
"bulla":{"bulla","bullae","bullas"},
"bullace":{"bullace","bullaces"},
"bullbat":{"bullbat","bullbats"},
"bullbrier":{"bullbrier","bullbriers"},
"bulldog":{"bulldog","bulldogs"},
"bulldoze":{"bulldoze","bulldozed","bulldozing"},
"bulldozer":{"bulldozer","bulldozers"},
"bullet":{"bullet","bullets"},
"bulletin":{"bulletin","bulletined","bulletining","bulletins"},
"bullfight":{"bullfight","bullfights"},
"bullfighter":{"bullfighter","bullfighters"},
"bullfinch":{"bullfinch","bullfinches"},
"bullfrog":{"bullfrog","bullfrogs"},
"bullheadedness":{"bullheadedness","bullheadednesses"},
"bullhorn":{"bullhorn","bullhorns"},
"bullnose":{"bullnose","bullnoses"},
"bullock":{"bullock","bullocks"},
"bullpen":{"bullpen","bullpens"},
"bullrush":{"bullrush","bullrushes"},
"bullshit":{"bullshit","bullshits"},
"bullsnake":{"bullsnake","bullsnakes"},
"bullterrier":{"bullterrier","bullterriers"},
"bullwhip":{"bullwhip","bullwhipped","bullwhipping","bullwhips"},
"bully":{"bullied","bullies","bully","bullying"},
"bullying":{"bullying","bullyings"},
"bullyrag":{"bullyrag","bullyragged","bullyragging","bullyrags"},
"bulnesia":{"bulnesia","bulnesias"},
"bulrush":{"bulrush","bulrushes"},
"bulwark":{"bulwark","bulwarked","bulwarking","bulwarks"},
"bulwarks":{"bulwarks","bulwarkses"},
"bum":{"bum","bummed","bummer","bummest","bumming","bums"},
"bumble":{"bumble","bumbled","bumbles","bumbling"},
"bumblebee":{"bumblebee","bumblebees"},
"bumbler":{"bumbler","bumblers"},
"bumelia":{"bumelia","bumelias"},
"bump":{"bump","bumped","bumping","bumps"},
"bumper":{"bumper","bumpers"},
"bumpkin":{"bumpkin","bumpkins"},
"bumptiousness":{"bumptiousness","bumptiousnesses"},
"bumpy":{"bumpier","bumpiest","bumpy"},
"bun":{"bun","buns"},
"bunce":{"bunce","bunces"},
"bunch":{"bunch","bunched","bunches","bunching"},
"bunchberry":{"bunchberries","bunchberry"},
"bunchgrass":{"bunchgrass","bunchgrasses"},
"bunchy":{"bunchier","bunchiest","bunchy"},
"bunco":{"bunco","buncoed","buncoing","buncos"},
"buncombe":{"buncombe","buncombes"},
"bund":{"bund","bunde","bunds"},
"bundle":{"bundle","bundled","bundles","bundling"},
"bung":{"bung","bunged","bunging","bungs"},
"bungalow":{"bungalow","bungalows"},
"bungarus":{"bungarus","bungaruses"},
"bungee":{"bungee","bungees"},
"bungle":{"bungle","bungled","bungles","bungling"},
"bungler":{"bungler","bunglers"},
"bunji-bunji":{"bunji-bunji","bunji-bunjis"},
"bunk":{"bunk","bunked","bunking","bunks"},
"bunker":{"bunker","bunkered","bunkering","bunkers"},
"bunkhouse":{"bunkhouse","bunkhouses"},
"bunko":{"bunko","bunkoed","bunkoing","bunkos"},
"bunkum":{"bunkum","bunkums"},
"bunny":{"bunnies","bunny"},
"buns":{"buns","bunses"},
"bunsen":{"bunsen","bunsens"},
"bunt":{"bunt","bunted","bunting","bunts"},
"bunting":{"bunting","buntings"},
"bunyan":{"bunyan","bunyans"},
"buoy":{"buoy","buoyed","buoying","buoys"},
"buoyancy":{"buoyancies","buoyancy"},
"buphthalmum":{"buphthalmum","buphthalmums"},
"bur":{"bur","burred","burring","burs"},
"bura":{"bura","buras"},
"burberry":{"burberries","burberry"},
"burble":{"burble","burbled","burbles","burbling"},
"burbot":{"burbot","burbots"},
"burden":{"burden","burdened","burdening","burdens"},
"burdensomeness":{"burdensomeness","burdensomenesses"},
"burdock":{"burdock","burdocks"},
"bureau":{"bureau","bureaus","bureaux"},
"bureaucracy":{"bureaucracies","bureaucracy"},
"bureaucrat":{"bureaucrat","bureaucrats"},
"bureaucratism":{"bureaucratism","bureaucratisms"},
"bureaucratize":{"bureaucratize","bureaucratized","bureaucratizing"},
"burgeon":{"burgeon","burgeoned","burgeoning"},
"burgess":{"burgess","burgesses"},
"burgher":{"burgher","burghers"},
"burglar":{"burglar","burglared","burglaring","burglars"},
"burglarize":{"burglarize","burglarized","burglarizes","burglarizing"},
"burglary":{"burglaries","burglary"},
"burgle":{"burgle","burgled","burgles","burgling"},
"burgoo":{"burgoo","burgoos"},
"burgoyne":{"burgoyne","burgoynes"},
"burgrass":{"burgrass","burgrasses"},
"burgundy":{"burgundies","burgundy"},
"burhinidae":{"burhinidae","burhinidaes"},
"burhinus":{"burhinus","burhinuses"},
"burial":{"burial","burials"},
"burke":{"burke","burked","burkes","burking"},
"burl":{"burl","burled","burling","burls"},
"burlap":{"burlap","burlaps"},
"burlesk":{"burlesk","burlesked","burlesking","burlesks"},
"burlesque":{"burlesque","burlesqued","burlesques","burlesquing"},
"burley":{"burley","burleys"},
"burly":{"burlier","burliest","burly"},
"burma":{"burma","burmas"},
"burmannia":{"burmannia","burmannias"},
"burmanniaceae":{"burmanniaceae","burmanniaceaes"},
"burmeisteria":{"burmeisteria","burmeisterias"},
"burmese-yi":{"burmese-yi","burmese-yis"},
"burn":{"burn","burned","burning","burns","burnt"},
"burner":{"burner","burners"},
"burning":{"burning","burnings"},
"burnish":{"burnish","burnished","burnishes","burnishing"},
"burnisher":{"burnisher","burnishers"},
"burnoose":{"burnoose","burnooses"},
"burnous":{"burnous","burnouses"},
"burnouse":{"burnouse","burnouses"},
"burnside":{"burnside","burnsides"},
"buroo":{"buroo","buroos"},
"burp":{"burp","burped","burping","burps"},
"burping":{"burping","burpings"},
"burr":{"burr","burred","burring","burrs"},
"burrawong":{"burrawong","burrawongs"},
"burro":{"burro","burros"},
"burrow":{"burrow","burrowed","burrowing","burrows"},
"burry":{"burrier","burriest","burry"},
"bursa":{"bursa","bursae","bursas"},
"bursary":{"bursaries","bursary"},
"bursera":{"bursera","burseras"},
"burseraceae":{"burseraceae","burseraceaes"},
"burst":{"burst","bursted","bursting","bursts"},
"burster":{"burster","bursters"},
"burunduki":{"burunduki","burundukis"},
"bury":{"buried","buries","bury","burying"},
"burying":{"burying","buryings"},
"bus":{"bus","bused","buses","busing","bussed","busses","bussing"},
"busbar":{"busbar","busbars"},
"busboy":{"busboy","busboys"},
"busby":{"busbies","busby"},
"bush":{"bush","bushed","bushes","bushing"},
"bushbaby":{"bushbabies","bushbaby"},
"bushbuck":{"bushbuck","bushbucks"},
"bushel":{"bushel","busheled","busheling","bushelled","bushelling","bushels"},
"bushie":{"bushie","bushies"},
"bushing":{"bushing","bushings"},
"bushman":{"bushman","bushmen"},
"bushtit":{"bushtit","bushtits"},
"bushwhack":{"bushwhack","bushwhacked","bushwhacking","bushwhacks"},
"bushwhacker":{"bushwhacker","bushwhackers"},
"bushy":{"bushier","bushies","bushiest","bushy"},
"business":{"business","businesses"},
"businessman":{"businessman","businessmen"},
"businessmen":{"businessmen","businessmens"},
"businessperson":{"businessperson","businesspersons"},
"businesswoman":{"businesswoman","businesswomen"},
"busk":{"busk","busked","busking"},
"buskin":{"buskin","buskins"},
"busman":{"busman","busmen"},
"buss":{"buss","bussed","busses","bussing"},
"bust":{"bust","busted","busting","busts"},
"buster":{"buster","busters"},
"bustle":{"bustle","bustled","bustles","bustling"},
"busty":{"bustier","bustiest","busty"},
"busy":{"busied","busier","busies","busiest","busy","busying"},
"busybody":{"busybodies","busybody"},
"busywork":{"busywork","busyworks"},
"but":{"but","buts"},
"butacaine":{"butacaine","butacaines"},
"butanol":{"butanol","butanols"},
"butat":{"butat","butats"},
"butazolidin":{"butazolidin","butazolidins"},
"butch":{"butch","butches"},
"butcher":{"butcher","butchered","butchering","butchers"},
"butchering":{"butchering","butcherings"},
"butchery":{"butcheries","butchery"},
"butea":{"butea","buteas"},
"butene":{"butene","butenes"},
"buteo":{"buteo","buteos"},
"butler":{"butler","butlers"},
"butlery":{"butleries","butlery"},
"butt":{"butt","butted","butting","butts"},
"butte":{"butte","buttes"},
"butter":{"butter","buttered","buttering"},
"butter-and-eggs":{"butter-and-eggs","butter-and-eggses"},
"butter-print":{"butter-print","butter-prints"},
"butterball":{"butterball","butterballs"},
"butterbean":{"butterbean","butterbeans"},
"butterbur":{"butterbur","butterburs"},
"buttercup":{"buttercup","buttercups"},
"butterfish":{"butterfish","butterfishes"},
"butterflower":{"butterflower","butterflowers"},
"butterfly":{"butterflies","butterfly"},
"butterflyfish":{"butterflyfish","butterflyfishes"},
"butternut":{"butternut","butternuts"},
"butterweed":{"butterweed","butterweeds"},
"buttery":{"butteries","buttery"},
"buttinsky":{"buttinskies","buttinsky"},
"buttock":{"buttock","buttocks"},
"buttocks":{"buttocks","buttockses"},
"button":{"button","buttoned","buttoning","buttons"},
"buttonhole":{"buttonhole","buttonholed","buttonholes","buttonholing"},
"buttonquail":{"buttonquail","buttonquails"},
"buttonwood":{"buttonwood","buttonwoods"},
"buttress":{"buttress","buttressed","buttresses","buttressing"},
"buttressing":{"buttressing","buttressings"},
"butty":{"butties","butty"},
"butut":{"butut","bututs"},
"butylene":{"butylene","butylenes"},
"buxaceae":{"buxaceae","buxaceaes"},
"buxus":{"buxus","buxuses"},
"buy":{"bought","buy","buying","buys"},
"buyback":{"buyback","buybacks"},
"buyer":{"buyer","buyers"},
"buyi":{"buyi","buyis"},
"buying":{"buying","buyings"},
"buzz":{"buzz","buzzed","buzzes","buzzing"},
"buzzard":{"buzzard","buzzards"},
"buzzer":{"buzzer","buzzers"},
"buzzword":{"buzzword","buzzwords"},
"bw":{"bw","bws"},
"bwr":{"bwr","bwrs"},
"by-blow":{"by-blow","by-blows"},
"by-line":{"by-line","by-lines"},
"by-product":{"by-product","by-products"},
"bye":{"bye","byes"},
"bye-bye":{"bye-bye","bye-byes"},
"byelarus":{"byelarus","byelaruses"},
"byelorussia":{"byelorussia","byelorussias"},
"byelorussian":{"byelorussian","byelorussians"},
"bygone":{"bygone","bygones"},
"bylaw":{"bylaw","bylaws"},
"bypass":{"bypass","bypasses"},
"bypath":{"bypath","bypaths"},
"byplay":{"byplay","byplays"},
"byrnie":{"byrnie","byrnies"},
"byroad":{"byroad","byroads"},
"byssus":{"byssus","byssuses"},
"byway":{"byway","byways"},
"byword":{"byword","bywords"},
"byzant":{"byzant","byzants"},
"byzantine":{"byzantine","byzantines"},
"byzantinism":{"byzantinism","byzantinisms"},
"c":{"c","cs"},
"c-horizon":{"c-horizon","c-horizons"},
"c-note":{"c-note","c-notes"},
"c-section":{"c-section","c-sections"},
"ca":{"ca","cas"},
"cab":{"cab","cabbed","cabbing","cabs"},
"cabal":{"cabal","caballed","caballing","cabals"},
"cabala":{"cabala","cabalas"},
"caballero":{"caballero","caballeros"},
"cabana":{"cabana","cabanas"},
"cabaret":{"cabaret","cabarets"},
"cabasset":{"cabasset","cabassets"},
"cabassous":{"cabassous","cabassouses"},
"cabbage":{"cabbage","cabbaged","cabbages","cabbaging"},
"cabbageworm":{"cabbageworm","cabbageworms"},
"cabbala":{"cabbala","cabbalas"},
"cabbalah":{"cabbalah","cabbalahs"},
"cabby":{"cabbies","cabby"},
"cabdriver":{"cabdriver","cabdrivers"},
"cabernet":{"cabernet","cabernets"},
"cabin":{"cabin","cabined","cabining","cabins"},
"cabinet":{"cabinet","cabinets"},
"cabinetmaking":{"cabinetmaking","cabinetmakings"},
"cabinetry":{"cabinetries","cabinetry"},
"cabinetwork":{"cabinetwork","cabinetworks"},
"cable":{"cable","cabled","cables","cabling"},
"cablegram":{"cablegram","cablegrams"},
"cabman":{"cabman","cabmen"},
"cabomba":{"cabomba","cabombas"},
"cabombaceae":{"cabombaceae","cabombaceaes"},
"caboodle":{"caboodle","caboodles"},
"caboose":{"caboose","cabooses"},
"cabrilla":{"cabrilla","cabrillas"},
"cabriolet":{"cabriolet","cabriolets"},
"cabstand":{"cabstand","cabstands"},
"cacajao":{"cacajao","cacajaos"},
"cacalia":{"cacalia","cacalias"},
"cacao":{"cacao","cacaos"},
"cacatua":{"cacatua","cacatuas"},
"cachalot":{"cachalot","cachalots"},
"cache":{"cache","cached","caches","caching"},
"cachet":{"cachet","cachets"},
"cachexia":{"cachexia","cachexias"},
"cachexy":{"cachexies","cachexy"},
"cachinnate":{"cachinnate","cachinnated","cachinnating"},
"cacicus":{"cacicus","cacicuses"},
"cacique":{"cacique","caciques"},
"cackle":{"cackle","cackled","cackles","cackling"},
"cackler":{"cackler","cacklers"},
"cacodaemon":{"cacodaemon","cacodaemons"},
"cacodemon":{"cacodemon","cacodemons"},
"cacodyl":{"cacodyl","cacodyls"},
"cacoethes":{"cacoethes","cacoetheses"},
"cacogenics":{"cacogenics","cacogenicses"},
"cacography":{"cacographies","cacography"},
"cacomistle":{"cacomistle","cacomistles"},
"cacomixle":{"cacomixle","cacomixles"},
"cacophony":{"cacophonies","cacophony"},
"cactaceae":{"cactaceae","cactaceaes"},
"cactus":{"cacti","cactus","cactuses"},
"cad":{"cad","cads"},
"cadaster":{"cadaster","cadasters"},
"cadastre":{"cadastre","cadastres"},
"cadaver":{"cadaver","cadavers"},
"caddicefly":{"caddiceflies","caddicefly"},
"caddie":{"caddie","caddied","caddies","caddying"},
"caddisfly":{"caddisflies","caddisfly"},
"caddisworm":{"caddisworm","caddisworms"},
"caddo":{"caddo","caddos"},
"caddoan":{"caddoan","caddoans"},
"caddy":{"caddied","caddies","caddy","caddying"},
"cadence":{"cadence","cadences"},
"cadency":{"cadencies","cadency"},
"cadenza":{"cadenza","cadenzas"},
"cadet":{"cadet","cadets"},
"cadge":{"cadge","cadged","cadges","cadging"},
"cadger":{"cadger","cadgers"},
"cadi":{"cadi","cadis"},
"cadmium":{"cadmium","cadmiums"},
"cadra":{"cadra","cadras"},
"cadre":{"cadre","cadres"},
"caduceus":{"caducei","caduceus"},
"caecilian":{"caecilian","caecilians"},
"caeciliidae":{"caeciliidae","caeciliidaes"},
"caecum":{"caeca","caecum","caecums"},
"caenogenesis":{"caenogeneses","caenogenesis"},
"caenolestes":{"caenolestes","caenolesteses"},
"caenolestidae":{"caenolestidae","caenolestidaes"},
"caesalpinia":{"caesalpinia","caesalpinias"},
"caesalpiniaceae":{"caesalpiniaceae","caesalpiniaceaes"},
"caesalpinioideae":{"caesalpinioideae","caesalpinioideaes"},
"caesar":{"caesar","caesars"},
"caesarean":{"caesarean","caesareans"},
"caesarism":{"caesarism","caesarisms"},
"caesaropapism":{"caesaropapism","caesaropapisms"},
"caesium":{"caesium","caesiums"},
"caestus":{"caestus","caestuses","cestuses"},
"caesura":{"caesura","caesurae","caesuras"},
"cafe":{"cafe","cafes"},
"cafeteria":{"cafeteria","cafeterias"},
"caffein":{"caffein","caffeins"},
"caffeine":{"caffeine","caffeines"},
"caffeinism":{"caffeinism","caffeinisms"},
"caffer":{"caffer","caffers"},
"caffre":{"caffre","caffres"},
"caftan":{"caftan","caftans"},
"cage":{"cage","caged","cages","caging"},
"cager":{"cager","cagers"},
"cagey":{"cagey","cagier","cagiest"},
"cagy":{"cagier","cagiest","cagy"},
"cahier":{"cahier","cahiers"},
"cahoot":{"cahoot","cahoots"},
"caiman":{"caiman","caimans","caimen"},
"caimitillo":{"caimitillo","caimitillos"},
"caimito":{"caimito","caimitos"},
"cainogenesis":{"cainogeneses","cainogenesis"},
"cairina":{"cairina","cairinas"},
"cairn":{"cairn","cairns"},
"cairngorm":{"cairngorm","cairngorms"},
"cairo":{"cairo","cairos"},
"caisson":{"caisson","caissons"},
"cajanus":{"cajanus","cajanuses"},
"cajole":{"cajole","cajoled","cajoles","cajoling"},
"cajolery":{"cajoleries","cajolery"},
"cake":{"cake","caked","cakes","caking"},
"cakewalk":{"cakewalk","cakewalked","cakewalking"},
"cakile":{"cakile","cakiles"},
"caky":{"cakier","cakiest","caky"},
"calaba":{"calaba","calabas"},
"calabash":{"calabash","calabashes"},
"calabazilla":{"calabazilla","calabazillas"},
"calabura":{"calabura","calaburas"},
"calamagrostis":{"calamagrostis","calamagrostises"},
"calamari":{"calamari","calamaris"},
"calamary":{"calamaries","calamary"},
"calamine":{"calamine","calamines"},
"calamintha":{"calamintha","calaminthas"},
"calamity":{"calamities","calamity"},
"calamus":{"calami","calamus","calamuses"},
"calan":{"calan","calans"},
"calandrinia":{"calandrinia","calandrinias"},
"calapooya":{"calapooya","calapooyas"},
"calapuya":{"calapuya","calapuyas"},
"calash":{"calash","calashes"},
"calathus":{"calathi","calathus"},
"calcaneum":{"calcanei","calcaneum"},
"calcaneus":{"calcanei","calcaneus","calcaneuses"},
"calcedony":{"calcedonies","calcedony"},
"calceolaria":{"calceolaria","calceolarias"},
"calciferol":{"calciferol","calciferols"},
"calcify":{"calcified","calcifies","calcify","calcifying"},
"calcimine":{"calcimine","calcimined","calcimining"},
"calcine":{"calcine","calcined","calcining"},
"calcium":{"calcium","calciums"},
"calcium-cyanamide":{"calcium-cyanamide","calcium-cyanamides"},
"calculate":{"calculate","calculated","calculates","calculating"},
"calculation":{"calculation","calculations"},
"calculator":{"calculator","calculators"},
"calculus":{"calculi","calculus","calculuses"},
"caldarium":{"caldaria","caldarium"},
"caldera":{"caldera","calderas"},
"caldron":{"caldron","caldrons"},
"caleche":{"caleche","caleches"},
"calefaction":{"calefaction","calefactions"},
"calefactory":{"calefactories","calefactory"},
"calendar":{"calendar","calendared","calendaring","calendars"},
"calender":{"calender","calendered","calendering"},
"calf":{"calf","calves"},
"calfskin":{"calfskin","calfskins"},
"caliber":{"caliber","calibers"},
"calibrate":{"calibrate","calibrated","calibrates","calibrating"},
"calibration":{"calibration","calibrations"},
"calibre":{"calibre","calibres"},
"caliche":{"caliche","caliches"},
"calico":{"calico","calicoes","calicos"},
"caliculus":{"caliculus","caliculuses"},
"calidris":{"calidris","calidrises"},
"calif":{"calif","califs"},
"california":{"california","californias"},
"californium":{"californium","californiums"},
"caliper":{"caliper","calipers"},
"calipers":{"calipers","caliperses"},
"caliph":{"caliph","caliphs"},
"calisaya":{"calisaya","calisayas"},
"calisthenics":{"calisthenics","calisthenicses"},
"calix":{"calices","calix"},
"calk":{"calk","calked","calking","calks"},
"calkin":{"calkin","calkins"},
"call":{"call","called","calling","calls"},
"calla":{"calla","callas"},
"callathump":{"callathump","callathumps"},
"caller":{"caller","callers"},
"callicebus":{"callicebus","callicebuses"},
"calligrapher":{"calligrapher","calligraphers"},
"calligraphist":{"calligraphist","calligraphists"},
"calligraphy":{"calligraphies","calligraphy"},
"callimorpha":{"callimorpha","callimorphas"},
"callinectes":{"callinectes","callinecteses"},
"calling":{"calling","callings"},
"callionymidae":{"callionymidae","callionymidaes"},
"calliope":{"calliope","calliopes"},
"calliophis":{"calliophis","calliophises"},
"calliopsis":{"calliopses","calliopsis"},
"calliper":{"calliper","callipers"},
"callipers":{"callipers","calliperses"},
"calliphora":{"calliphora","calliphoras"},
"calliphoridae":{"calliphoridae","calliphoridaes"},
"callirhoe":{"callirhoe","callirhoes"},
"callisaurus":{"callisaurus","callisauruses"},
"callistephus":{"callistephus","callistephuses"},
"callisthenics":{"callisthenics","callisthenicses"},
"callithricidae":{"callithricidae","callithricidaes"},
"callithrix":{"callithrix","callithrixes"},
"callithump":{"callithump","callithumps"},
"callitrichaceae":{"callitrichaceae","callitrichaceaes"},
"callitriche":{"callitriche","callitriches"},
"callitris":{"callitris","callitrises"},
"callophis":{"callophis","callophises"},
"callorhinus":{"callorhinus","callorhinuses"},
"callosity":{"callosities","callosity"},
"callous":{"callous","callouses"},
"callousness":{"callousness","callousnesses"},
"callowness":{"callowness","callownesses"},
"calluna":{"calluna","callunas"},
"callus":{"callus","callused","calluses","callusing"},
"calm":{"calm","calmed","calmer","calmest","calming","calms"},
"calming":{"calming","calmings"},
"calmness":{"calmness","calmnesses"},
"calocarpum":{"calocarpum","calocarpums"},
"calocedrus":{"calocedrus","calocedruses"},
"calochortus":{"calochortus","calochortuses"},
"calomel":{"calomel","calomels"},
"calophyllum":{"calophyllum","calophyllums"},
"calopogon":{"calopogon","calopogons"},
"calorie":{"calorie","calories"},
"calory":{"calories","calory"},
"calostomataceae":{"calostomataceae","calostomataceaes"},
"calpe":{"calpe","calpes"},
"calque":{"calque","calqued","calques","calquing"},
"caltha":{"caltha","calthas"},
"caltrop":{"caltrop","caltrops"},
"calumet":{"calumet","calumets"},
"calumniate":{"calumniate","calumniated","calumniates","calumniating"},
"calumny":{"calumnies","calumny"},
"calvaria":{"calvaria","calvarias"},
"calvary":{"calvaries","calvary"},
"calvatia":{"calvatia","calvatias"},
"calve":{"calve","calved","calves","calving"},
"calvin":{"calvin","calvins"},
"calx":{"calces","calx","calxes"},
"calycanthaceae":{"calycanthaceae","calycanthaceaes"},
"calycanthus":{"calycanthus","calycanthuses"},
"calycle":{"calycle","calycles"},
"calycophyllum":{"calycophyllum","calycophyllums"},
"calyculus":{"calyculus","calyculuses"},
"calypso":{"calypso","calypsoes","calypsos"},
"calypter":{"calypter","calypters"},
"calystegia":{"calystegia","calystegias"},
"calyx":{"calyces","calyx","calyxes"},
"camachile":{"camachile","camachiles"},
"camail":{"camail","camails"},
"camaraderie":{"camaraderie","camaraderies"},
"camarilla":{"camarilla","camarillas"},
"camas":{"camas","camases"},
"camash":{"camash","camashes"},
"camass":{"camass","camasses"},
"camassia":{"camassia","camassias"},
"cambarus":{"cambarus","cambaruses"},
"camber":{"camber","cambered","cambering","cambers"},
"cambium":{"cambia","cambium","cambiums"},
"cambodia":{"cambodia","cambodias"},
"cambodian":{"cambodian","cambodians"},
"cambrian":{"cambrian","cambrians"},
"cambridge":{"cambridge","cambridges"},
"camel":{"camel","camels"},
"camelhair":{"camelhair","camelhairs"},
"camelia":{"camelia","camelias"},
"camelidae":{"camelidae","camelidaes"},
"camelina":{"camelina","camelinas"},
"camellia":{"camellia","camellias"},
"camelopard":{"camelopard","camelopards"},
"camelus":{"camelus","cameluses"},
"cameo":{"cameo","cameos"},
"camera":{"camera","cameras"},
"cameraman":{"cameraman","cameramen"},
"camerlengo":{"camerlengo","camerlengos"},
"camerlingo":{"camerlingo","camerlingos"},
"cameroon":{"cameroon","cameroons"},
"cameroun":{"cameroun","camerouns"},
"camfer":{"camfer","camfers"},
"camion":{"camion","camions"},
"camisade":{"camisade","camisades"},
"camisado":{"camisado","camisados"},
"camisole":{"camisole","camisoles"},
"camomile":{"camomile","camomiles"},
"camosh":{"camosh","camoshes"},
"camouflage":{"camouflage","camouflaged","camouflages","camouflaging"},
"camp":{"camp","camped","camping","camps"},
"campaign":{"campaign","campaigned","campaigning","campaigns"},
"campaigner":{"campaigner","campaigners"},
"campaigning":{"campaigning","campaignings"},
"campana":{"campana","campanas"},
"campanile":{"campanile","campaniles","campanili"},
"campanula":{"campanula","campanulas"},
"campanulaceae":{"campanulaceae","campanulaceaes"},
"campanulales":{"campanulales","campanulaleses"},
"campeachy":{"campeachies","campeachy"},
"campephilus":{"campephilus","campephiluses"},
"camper":{"camper","campers"},
"campesino":{"campesino","campesinos"},
"campground":{"campground","campgrounds"},
"camphorate":{"camphorate","camphorated","camphorating"},
"camphorweed":{"camphorweed","camphorweeds"},
"camping":{"camping","campings"},
"campion":{"campion","campions"},
"campo":{"campo","campos"},
"campong":{"campong","campongs"},
"camponotus":{"camponotus","camponotuses"},
"campsite":{"campsite","campsites"},
"camptosorus":{"camptosorus","camptosoruses"},
"campus":{"campus","campused","campuses","campusing","campussed","campussing"},
"campy":{"campier","campiest","campy"},
"campyloneurum":{"campyloneurum","campyloneurums"},
"campylorhynchus":{"campylorhynchus","campylorhynchuses"},
"camwood":{"camwood","camwoods"},
"can":{"can","canned","canning","cans","could"},
"canaan":{"canaan","canaans"},
"canaanitic":{"canaanitic","canaanitics"},
"canachites":{"canachites","canachiteses"},
"canadian":{"canadian","canadians"},
"canafistola":{"canafistola","canafistolas"},
"canafistula":{"canafistula","canafistulas"},
"canal":{"canal","canaled","canaling","canalled","canalling","canals"},
"canaliculus":{"canaliculi","canaliculus"},
"canalisation":{"canalisation","canalisations"},
"canalization":{"canalization","canalizations"},
"canalize":{"canalize","canalized","canalizes","canalizing"},
"cananga":{"cananga","canangas"},
"canangium":{"canangium","canangiums"},
"canape":{"canape","canapes"},
"canaries":{"canaries","canarieses"},
"canary":{"canaries","canary"},
"canasta":{"canasta","canastas"},
"canavalia":{"canavalia","canavalias"},
"canberra":{"canberra","canberras"},
"cancel":{"cancel","canceled","canceling","cancelled","cancelling","cancels"},
"cancer":{"cancer","cancers"},
"cancerweed":{"cancerweed","cancerweeds"},
"cancridae":{"cancridae","cancridaes"},
"cancroid":{"cancroid","cancroids"},
"candela":{"candela","candelas"},
"candelabra":{"candelabra","candelabras"},
"candelabrum":{"candelabra","candelabrum","candelabrums"},
"candelilla":{"candelilla","candelillas"},
"candidacy":{"candidacies","candidacy"},
"candidate":{"candidate","candidates"},
"candidature":{"candidature","candidatures"},
"candidiasis":{"candidiases","candidiasis"},
"candidness":{"candidness","candidnesses"},
"candle":{"candle","candled","candles","candling"},
"candleberry":{"candleberries","candleberry"},
"candlefish":{"candlefish","candlefishes"},
"candlelight":{"candlelight","candlelights"},
"candlemas":{"candlemas","candlemases"},
"candlenut":{"candlenut","candlenuts"},
"candlepins":{"candlepins","candlepinses"},
"candlestick":{"candlestick","candlesticks"},
"candor":{"candor","candors"},
"candour":{"candour","candours"},
"candy":{"candied","candies","candy","candying"},
"candyfloss":{"candyfloss","candyflosses"},
"candymaker":{"candymaker","candymakers"},
"candyweed":{"candyweed","candyweeds"},
"cane":{"cane","caned","canes","caning"},
"canecutter":{"canecutter","canecutters"},
"canella":{"canella","canellas"},
"canella-alba":{"canella-alba","canella-albas"},
"canellaceae":{"canellaceae","canellaceaes"},
"canful":{"canful","canfuls"},
"canicula":{"canicula","caniculas"},
"canicule":{"canicule","canicules"},
"canid":{"canid","canids"},
"canidae":{"canidae","canidaes"},
"canine":{"canine","canines"},
"caning":{"caning","canings"},
"canis":{"canis","canises"},
"canistel":{"canistel","canistels"},
"canister":{"canister","canisters"},
"canker":{"canker","cankered","cankering","cankers"},
"cankerweed":{"cankerweed","cankerweeds"},
"canna":{"canna","cannas"},
"cannabidaceae":{"cannabidaceae","cannabidaceaes"},
"cannabin":{"cannabin","cannabins"},
"cannabis":{"cannabis","cannabises"},
"cannaceae":{"cannaceae","cannaceaes"},
"cannery":{"canneries","cannery"},
"cannibal":{"cannibal","cannibals"},
"cannibalize":{"cannibalize","cannibalized","cannibalizes","cannibalizing"},
"cannister":{"cannister","cannisters"},
"cannon":{"cannon","cannoned","cannoning","cannons"},
"cannonade":{"cannonade","cannonaded","cannonades","cannonading"},
"cannonball":{"cannonball","cannonballs"},
"cannoneer":{"cannoneer","cannoneers"},
"cannonry":{"cannonries","cannonry"},
"cannula":{"cannula","cannulas"},
"cannulation":{"cannulation","cannulations"},
"cannulization":{"cannulization","cannulizations"},
"canny":{"cannier","canniest","canny"},
"canoe":{"canoe","canoed","canoeing","canoes"},
"canoeist":{"canoeist","canoeists"},
"canon":{"canon","canons"},
"canonisation":{"canonisation","canonisations"},
"canonization":{"canonization","canonizations"},
"canonize":{"canonize","canonized","canonizes","canonizing"},
"canonry":{"canonries","canonry"},
"canopy":{"canopied","canopies","canopy","canopying"},
"cant":{"cant","canted","canting","cants"},
"cantala":{"cantala","cantalas"},
"cantaloup":{"cantaloup","cantaloups"},
"cantaloupe":{"cantaloupe","cantaloupes"},
"cantata":{"cantata","cantatas"},
"canteen":{"canteen","canteens"},
"canter":{"canter","cantered","cantering","canters"},
"cantharellus":{"cantharellus","cantharelluses"},
"canthus":{"canthi","canthus"},
"cantilena":{"cantilena","cantilenas"},
"cantina":{"cantina","cantinas"},
"canto":{"canto","cantos"},
"canton":{"canton","cantoned","cantoning","cantons"},
"cantonese":{"cantonese","cantoneses"},
"cantonment":{"cantonment","cantonments"},
"cantor":{"cantor","cantors"},
"canty":{"cantier","cantiest","canty"},
"canula":{"canula","canulae","canulas"},
"canulation":{"canulation","canulations"},
"canulization":{"canulization","canulizations"},
"canvas":{"canvas","canvased","canvases","canvasing","canvassed","canvassing"},
"canvasback":{"canvasback","canvasbacks"},
"canvass":{"canvass","canvassed","canvasses","canvassing"},
"canvasser":{"canvasser","canvassers"},
"canvassing":{"canvassing","canvassings"},
"canyon":{"canyon","canyons"},
"canzone":{"canzone","canzones","canzoni"},
"caoutchouc":{"caoutchouc","caoutchoucs"},
"cap":{"cap","capped","capping","caps"},
"capability":{"capabilities","capability"},
"capableness":{"capableness","capablenesses"},
"capaciousness":{"capaciousness","capaciousnesses"},
"capacitance":{"capacitance","capacitances"},
"capacitor":{"capacitor","capacitors"},
"capacity":{"capacities","capacity"},
"caparison":{"caparison","caparisoned","caparisoning","caparisons"},
"cape":{"cape","capes"},
"capelan":{"capelan","capelans"},
"capelin":{"capelin","capelins"},
"capella":{"capella","capellas"},
"caper":{"caper","capered","capering","capers"},
"capercaillie":{"capercaillie","capercaillies"},
"capercailzie":{"capercailzie","capercailzies"},
"capeweed":{"capeweed","capeweeds"},
"capibara":{"capibara","capibaras"},
"capillarity":{"capillarities","capillarity"},
"capillary":{"capillaries","capillary"},
"capital":{"capital","capitals"},
"capitalisation":{"capitalisation","capitalisations"},
"capitalism":{"capitalism","capitalisms"},
"capitalist":{"capitalist","capitalists"},
"capitalization":{"capitalization","capitalizations"},
"capitalize":{"capitalize","capitalized","capitalizes","capitalizing"},
"capitate":{"capitate","capitates"},
"capitol":{"capitol","capitols"},
"capitonidae":{"capitonidae","capitonidaes"},
"capitulary":{"capitularies","capitulary"},
"capitulate":{"capitulate","capitulated","capitulating"},
"capitulation":{"capitulation","capitulations"},
"capitulum":{"capitulum","capitulums"},
"capiz":{"capiz","capizs"},
"caplin":{"caplin","caplins"},
"capo":{"capo","capos"},
"caporetto":{"caporetto","caporettos"},
"capote":{"capote","capotes"},
"capoten":{"capoten","capotens"},
"capparidaceae":{"capparidaceae","capparidaceaes"},
"capparis":{"capparis","capparises"},
"cappelletti":{"cappelletti","cappellettis"},
"cappuccino":{"cappuccino","cappuccinos"},
"capra":{"capra","capras"},
"caprella":{"caprella","caprellas"},
"capreolus":{"capreolus","capreoluses"},
"capriccio":{"capricci","capriccio","capriccios"},
"caprice":{"caprice","caprices"},
"capriciousness":{"capriciousness","capriciousnesses"},
"capricorn":{"capricorn","capricorns"},
"capricornis":{"capricornis","capricornises"},
"capricornus":{"capricornus","capricornuses"},
"caprifig":{"caprifig","caprifigs"},
"caprifoliaceae":{"caprifoliaceae","caprifoliaceaes"},
"caprimulgid":{"caprimulgid","caprimulgids"},
"caprimulgidae":{"caprimulgidae","caprimulgidaes"},
"caprimulgiformes":{"caprimulgiformes","caprimulgiformeses"},
"caprimulgus":{"caprimulgus","caprimulguses"},
"capriole":{"capriole","caprioled","caprioling"},
"caproidae":{"caproidae","caproidaes"},
"capromyidae":{"capromyidae","capromyidaes"},
"capros":{"capros","caproses"},
"capsella":{"capsella","capsellas"},
"capsicum":{"capsicum","capsicums"},
"capsid":{"capsid","capsids"},
"capsidae":{"capsidae","capsidaes"},
"capsize":{"capsize","capsized","capsizes","capsizing"},
"capsizing":{"capsizing","capsizings"},
"capstone":{"capstone","capstones"},
"capsule":{"capsule","capsuled","capsules","capsuling"},
"capsulize":{"capsulize","capsulized","capsulizing"},
"captain":{"captain","captained","captaining","captains"},
"captaincy":{"captaincies","captaincy"},
"captainship":{"captainship","captainships"},
"caption":{"caption","captioned","captioning","captions"},
"captivate":{"captivate","captivated","captivates","captivating"},
"captivation":{"captivation","captivations"},
"captive":{"captive","captives"},
"captivity":{"captivities","captivity"},
"captopril":{"captopril","captoprils"},
"captor":{"captor","captors"},
"capture":{"capture","captured","captures","capturing"},
"capuccino":{"capuccino","capuccinos"},
"capuchin":{"capuchin","capuchins"},
"capulin":{"capulin","capulins"},
"caput":{"capita","caput","caputs"},
"capybara":{"capybara","capybaras"},
"car":{"car","cars"},
"car-mechanic":{"car-mechanic","car-mechanics"},
"carabao":{"carabao","carabaos"},
"carabidae":{"carabidae","carabidaes"},
"carabineer":{"carabineer","carabineers"},
"carabiner":{"carabiner","carabiners"},
"carabinier":{"carabinier","carabiniers"},
"carabiniere":{"carabiniere","carabinieri"},
"caracal":{"caracal","caracals"},
"caracas":{"caracas","caracases"},
"carack":{"carack","caracks"},
"caracole":{"caracole","caracoled","caracoling"},
"caracolito":{"caracolito","caracolitos"},
"caracul":{"caracul","caraculs"},
"carafate":{"carafate","carafates"},
"carafe":{"carafe","carafes"},
"caragana":{"caragana","caraganas"},
"carageen":{"carageen","carageens"},
"carambola":{"carambola","carambolas"},
"caramel":{"caramel","caramels"},
"carancha":{"carancha","caranchas"},
"caranda":{"caranda","carandas"},
"caranday":{"caranday","carandays"},
"carangid":{"carangid","carangids"},
"carangidae":{"carangidae","carangidaes"},
"caranx":{"caranx","caranxes"},
"carapace":{"carapace","carapaces"},
"carapidae":{"carapidae","carapidaes"},
"carassius":{"carassius","carassiuses"},
"carat":{"carat","carats"},
"caravan":{"caravan","caravans"},
"caravansary":{"caravansaries","caravansary"},
"caravanserai":{"caravanserai","caravanserais"},
"caraway":{"caraway","caraways"},
"carbamide":{"carbamide","carbamides"},
"carbohydrate":{"carbohydrate","carbohydrates"},
"carbon":{"carbon","carbons"},
"carbonado":{"carbonado","carbonadoed","carbonadoes","carbonadoing","carbonados"},
"carbonate":{"carbonate","carbonated","carbonating"},
"carboniferous":{"carboniferous","carboniferouses"},
"carbonisation":{"carbonisation","carbonisations"},
"carbonization":{"carbonization","carbonizations"},
"carbonize":{"carbonize","carbonized","carbonizes","carbonizing"},
"carboxyl":{"carboxyl","carboxyls"},
"carburet":{"carburet","carbureted","carbureting","carburets","carburetted","carburetting"},
"carburetor":{"carburetor","carburetors"},
"carburettor":{"carburettor","carburettors"},
"carby":{"carbies","carby"},
"carcajou":{"carcajou","carcajous"},
"carcase":{"carcase","carcases"},
"carcass":{"carcass","carcasses"},
"carcharhinidae":{"carcharhinidae","carcharhinidaes"},
"carcharhinus":{"carcharhinus","carcharhinuses"},
"carcharias":{"carcharias","carchariases"},
"carchariidae":{"carchariidae","carchariidaes"},
"carcharodon":{"carcharodon","carcharodons"},
"carcinoma":{"carcinoma","carcinomas","carcinomata"},
"card":{"card","carded","carding","cards"},
"cardamine":{"cardamine","cardamines"},
"cardamom":{"cardamom","cardamoms"},
"cardamon":{"cardamon","cardamons"},
"cardamum":{"cardamum","cardamums"},
"cardboard":{"cardboard","cardboards"},
"cardcase":{"cardcase","cardcases"},
"cardcastle":{"cardcastle","cardcastles"},
"cardhouse":{"cardhouse","cardhouses"},
"cardigan":{"cardigan","cardigans"},
"cardiidae":{"cardiidae","cardiidaes"},
"cardinal":{"cardinal","cardinals"},
"cardiogram":{"cardiogram","cardiograms"},
"cardiograph":{"cardiograph","cardiographs"},
"cardiography":{"cardiographies","cardiography"},
"cardiologist":{"cardiologist","cardiologists"},
"cardiomegaly":{"cardiomegalies","cardiomegaly"},
"cardiopathy":{"cardiopathies","cardiopathy"},
"cardiospermum":{"cardiospermum","cardiospermums"},
"cardium":{"cardium","cardiums"},
"cardizem":{"cardizem","cardizems"},
"cardoon":{"cardoon","cardoons"},
"cards":{"cards","cardses"},
"cardsharp":{"cardsharp","cardsharps"},
"cardsharper":{"cardsharper","cardsharpers"},
"carduelinae":{"carduelinae","carduelinaes"},
"carduelis":{"carduelis","carduelises"},
"carduus":{"carduus","carduuses"},
"care":{"care","cared","cares","caring"},
"careen":{"careen","careened","careening","careens"},
"career":{"career","careered","careering","careers"},
"carefreeness":{"carefreeness","carefreenesses"},
"carefulness":{"carefulness","carefulnesses"},
"caregiver":{"caregiver","caregivers"},
"carelessness":{"carelessness","carelessnesses"},
"carelian":{"carelian","carelians"},
"caress":{"caress","caressed","caresses","caressing"},
"caressing":{"caressing","caressings"},
"caretaker":{"caretaker","caretakers"},
"caretta":{"caretta","carettas"},
"carex":{"carex","carexes"},
"carfare":{"carfare","carfares"},
"cargo":{"cargo","cargoes","cargos"},
"cariama":{"cariama","cariamas"},
"cariamidae":{"cariamidae","cariamidaes"},
"carib":{"carib","caribs"},
"caribbean":{"caribbean","caribbeans"},
"caribe":{"caribe","caribes"},
"caribees":{"caribees","caribeeses"},
"caribou":{"caribou","caribous"},
"carica":{"carica","caricas"},
"caricaceae":{"caricaceae","caricaceaes"},
"caricature":{"caricature","caricatured","caricatures","caricaturing"},
"caries":{"caries","carieses"},
"carillon":{"carillon","carillons"},
"carina":{"carina","carinae","carinas"},
"carinate":{"carinate","carinates"},
"caring":{"caring","carings"},
"carioca":{"carioca","cariocas"},
"carlina":{"carlina","carlinas"},
"carload":{"carload","carloads"},
"carman":{"carman","carmen"},
"carmelite":{"carmelite","carmelites"},
"carmine":{"carmine","carmines"},
"carnage":{"carnage","carnages"},
"carnality":{"carnalities","carnality"},
"carnation":{"carnation","carnations"},
"carnauba":{"carnauba","carnaubas"},
"carnegie":{"carnegie","carnegies"},
"carnegiea":{"carnegiea","carnegieas"},
"carnelian":{"carnelian","carnelians"},
"carney":{"carney","carneyed","carneying","carneys"},
"carnify":{"carnified","carnifies","carnify","carnifying"},
"carnival":{"carnival","carnivals"},
"carnivora":{"carnivora","carnivoras"},
"carnosaura":{"carnosaura","carnosauras"},
"carny":{"carnied","carnies","carny","carnying"},
"carob":{"carob","carobs"},
"carol":{"carol","caroled","caroling","carolled","carolling","carols"},
"caroler":{"caroler","carolers"},
"caroller":{"caroller","carollers"},
"carolus":{"caroli","carolus","caroluses"},
"carom":{"carom","caromed","caroming","caroms"},
"carotene":{"carotene","carotenes"},
"carotenemia":{"carotenemia","carotenemias"},
"carotin":{"carotin","carotins"},
"carousal":{"carousal","carousals"},
"carouse":{"carouse","caroused","carouses","carousing"},
"carousel":{"carousel","carousels"},
"carouser":{"carouser","carousers"},
"carp":{"carp","carped","carping","carps"},
"carpal":{"carpal","carpals"},
"carpenter":{"carpenter","carpentered","carpentering","carpenters"},
"carpenteria":{"carpenteria","carpenterias"},
"carpentry":{"carpentries","carpentry"},
"carper":{"carper","carpers"},
"carpet":{"carpet","carpeted","carpeting","carpets"},
"carpetbag":{"carpetbag","carpetbagged","carpetbagging"},
"carpeting":{"carpeting","carpetings"},
"carpetweed":{"carpetweed","carpetweeds"},
"carphophis":{"carphophis","carphophises"},
"carpinaceae":{"carpinaceae","carpinaceaes"},
"carping":{"carping","carpings"},
"carpinus":{"carpinus","carpinuses"},
"carpobrotus":{"carpobrotus","carpobrotuses"},
"carpocapsa":{"carpocapsa","carpocapsas"},
"carpodacus":{"carpodacus","carpodacuses"},
"carpogonium":{"carpogonia","carpogonium"},
"carport":{"carport","carports"},
"carpus":{"carpi","carpus","carpuses"},
"carrack":{"carrack","carracks"},
"carrageen":{"carrageen","carrageens"},
"carrageenan":{"carrageenan","carrageenans"},
"carrageenin":{"carrageenin","carrageenins"},
"carragheen":{"carragheen","carragheens"},
"carrefour":{"carrefour","carrefours"},
"carrel":{"carrel","carrels"},
"carrell":{"carrell","carrells"},
"carriage":{"carriage","carriages"},
"carrier":{"carrier","carriers"},
"carrizo":{"carrizo","carrizos"},
"carroll":{"carroll","carrolls"},
"carrot":{"carrot","carrots"},
"carrottop":{"carrottop","carrottops"},
"carry":{"carried","carries","carry","carrying"},
"carry-forward":{"carry-forward","carry-forwards"},
"carry-over":{"carry-over","carry-overs"},
"carryall":{"carryall","carryalls"},
"carrying-on":{"carrying-on","carryings-on"},
"cart":{"cart","carted","carting","carts"},
"cartage":{"cartage","cartages"},
"carte":{"carte","cartes"},
"cartel":{"cartel","cartels"},
"carter":{"carter","carters"},
"carthamus":{"carthamus","carthamuses"},
"carthorse":{"carthorse","carthorses"},
"cartilage":{"cartilage","cartilages"},
"carting":{"carting","cartings"},
"cartographer":{"cartographer","cartographers"},
"cartography":{"cartographies","cartography"},
"carton":{"carton","cartoned","cartoning","cartons"},
"cartonful":{"cartonful","cartonfuls"},
"cartoon":{"cartoon","cartooned","cartooning","cartoons"},
"cartouch":{"cartouch","cartouches"},
"cartouche":{"cartouche","cartouches"},
"cartridge":{"cartridge","cartridges"},
"cartroad":{"cartroad","cartroads"},
"cartulary":{"cartularies","cartulary"},
"cartwheel":{"cartwheel","cartwheels"},
"carum":{"carum","carums"},
"caruncle":{"caruncle","caruncles"},
"caruncula":{"caruncula","carunculas"},
"carve":{"carve","carved","carves","carving"},
"carver":{"carver","carvers"},
"carving":{"carving","carvings"},
"carya":{"carya","caryas"},
"caryatid":{"carides","caryatid","caryatides","caryatids"},
"caryocar":{"caryocar","caryocars"},
"caryocaraceae":{"caryocaraceae","caryocaraceaes"},
"caryophyllaceae":{"caryophyllaceae","caryophyllaceaes"},
"caryophyllales":{"caryophyllales","caryophyllaleses"},
"caryophyllidae":{"caryophyllidae","caryophyllidaes"},
"caryopsis":{"caryopses","caryopsis"},
"caryota":{"caryota","caryotas"},
"casaba":{"casaba","casabas"},
"casanova":{"casanova","casanovas"},
"casava":{"casava","casavas"},
"cascabel":{"cascabel","cascabels"},
"cascade":{"cascade","cascaded","cascades","cascading"},
"cascades":{"cascades","cascadeses"},
"cascara":{"cascara","cascaras"},
"cascarilla":{"cascarilla","cascarillas"},
"case":{"case","cased","cases","casing"},
"caseful":{"caseful","casefuls"},
"casefy":{"casefied","casefies","casefy","casefying"},
"caseharden":{"caseharden","casehardened","casehardening"},
"casein":{"casein","caseins"},
"casement":{"casement","casements"},
"caseworker":{"caseworker","caseworkers"},
"cash":{"cash","cashed","cashes","cashing"},
"cash-and-carry":{"cash-and-carries","cash-and-carry"},
"cashbox":{"cashbox","cashboxes"},
"cashew":{"cashew","cashews"},
"cashier":{"cashier","cashiered","cashiering","cashiers"},
"cashmere":{"cashmere","cashmeres"},
"casing":{"casing","casings"},
"casino":{"casino","casinos"},
"casino-hotel":{"casino-hotel","casino-hotels"},
"cask":{"cask","casks"},
"casket":{"casket","casketed","casketing","caskets"},
"caskful":{"caskful","caskfuls"},
"casmerodius":{"casmerodius","casmerodiuses"},
"casquet":{"casquet","casquets"},
"casquetel":{"casquetel","casquetels"},
"cassandra":{"cassandra","cassandras"},
"cassava":{"cassava","cassavas"},
"casserole":{"casserole","casseroles"},
"cassette":{"cassette","cassettes"},
"cassia":{"cassia","cassias"},
"cassie":{"cassie","cassies"},
"cassino":{"cassino","cassinos"},
"cassiope":{"cassiope","cassiopes"},
"cassite":{"cassite","cassites"},
"cassius":{"cassius","cassiuses"},
"cassowary":{"cassowaries","cassowary"},
"cast":{"cast","casting","casts"},
"castanea":{"castanea","castaneas"},
"castanet":{"castanet","castanets"},
"castanets":{"castanets","castanetses"},
"castanopsis":{"castanopses","castanopsis"},
"castanospermum":{"castanospermum","castanospermums"},
"castaway":{"castaway","castaways"},
"caste":{"caste","castes"},
"castellany":{"castellanies","castellany"},
"caster":{"caster","casters"},
"castigate":{"castigate","castigated","castigates","castigating"},
"castigation":{"castigation","castigations"},
"castile":{"castile","castiles"},
"castilla":{"castilla","castillas"},
"castilleia":{"castilleia","castilleias"},
"castilleja":{"castilleja","castillejas"},
"casting":{"casting","castings"},
"castle":{"castle","castled","castles","castling"},
"castling":{"castling","castlings"},
"castor":{"castor","castors"},
"castoridae":{"castoridae","castoridaes"},
"castoroides":{"castoroides","castoroideses"},
"castrate":{"castrate","castrated","castrates","castrating"},
"castration":{"castration","castrations"},
"castrato":{"castrati","castrato","castratos"},
"casual":{"casual","casuals"},
"casualness":{"casualness","casualnesses"},
"casualty":{"casualties","casualty"},
"casuaridae":{"casuaridae","casuaridaes"},
"casuariiformes":{"casuariiformes","casuariiformeses"},
"casuarinaceae":{"casuarinaceae","casuarinaceaes"},
"casuarinales":{"casuarinales","casuarinaleses"},
"casuarius":{"casuarius","casuariuses"},
"casuist":{"casuist","casuists"},
"casuistry":{"casuistries","casuistry"},
"cat":{"cat","cats","catted","catting"},
"catabasis":{"catabases","catabasis"},
"catabolism":{"catabolism","catabolisms"},
"catacala":{"catacala","catacalas"},
"cataclasis":{"cataclases","cataclasis"},
"cataclysm":{"cataclysm","cataclysms"},
"catacomb":{"catacomb","catacombs"},
"cataflam":{"cataflam","cataflams"},
"catalo":{"catalo","cataloes","catalos"},
"catalog":{"catalog","cataloged","cataloging","catalogs"},
"cataloger":{"cataloger","catalogers"},
"catalogue":{"catalogue","catalogued","catalogues","cataloguing"},
"cataloguer":{"cataloguer","cataloguers"},
"catalpa":{"catalpa","catalpas"},
"catalufa":{"catalufa","catalufas"},
"catalysis":{"catalyses","catalysis"},
"catalyst":{"catalyst","catalysts"},
"catalyze":{"catalyze","catalyzed","catalyzing"},
"catamenia":{"catamenia","catamenias"},
"catamount":{"catamount","catamounts"},
"catamountain":{"catamountain","catamountains"},
"cataphoresis":{"cataphoreses","cataphoresis"},
"cataplasm":{"cataplasm","cataplasms"},
"catapres":{"catapres","catapreses"},
"catapult":{"catapult","catapulted","catapulting","catapults"},
"cataract":{"cataract","cataracts"},
"catasetum":{"catasetum","catasetums"},
"catastasis":{"catastases","catastasis"},
"catastrophe":{"catastrophe","catastrophes"},
"catatonia":{"catatonia","catatonias"},
"catawba":{"catawba","catawbas"},
"catbird":{"catbird","catbirds"},
"catbrier":{"catbrier","catbriers"},
"catcall":{"catcall","catcalled","catcalling"},
"catch":{"catch","catches","catching","caught"},
"catcher":{"catcher","catchers"},
"catchfly":{"catchflies","catchfly"},
"catching":{"catching","catchings"},
"catchpenny":{"catchpennies","catchpenny"},
"catchweed":{"catchweed","catchweeds"},
"catchword":{"catchword","catchwords"},
"catchy":{"catchier","catchiest","catchy"},
"catclaw":{"catclaw","catclaws"},
"cate":{"cate","cates"},
"catechize":{"catechize","catechized","catechizes","catechizing"},
"catechu":{"catechu","catechus"},
"catechumen":{"catechumen","catechumens"},
"categorisation":{"categorisation","categorisations"},
"categorization":{"categorization","categorizations"},
"categorize":{"categorize","categorized","categorizing"},
"category":{"categories","category"},
"catena":{"catena","catenae","catenas"},
"catenary":{"catenaries","catenary"},
"catenate":{"catenate","catenated","catenates","catenating"},
"cater":{"cater","catered","catering","caters"},
"caterpillar":{"caterpillar","caterpillars"},
"caterwaul":{"caterwaul","caterwauled","caterwauling","caterwauls"},
"catfish":{"catfish","catfishes"},
"catgut":{"catgut","catguts"},
"cathar":{"cathar","cathari","cathars"},
"catharacta":{"catharacta","catharactas"},
"catharanthus":{"catharanthus","catharanthuses"},
"catharist":{"catharist","catharists"},
"catharsis":{"catharses","catharsis"},
"cathartes":{"cathartes","catharteses"},
"cathartic":{"cathartic","cathartics"},
"cathartid":{"cathartid","cathartids"},
"cathartidae":{"cathartidae","cathartidaes"},
"cathedra":{"cathedra","cathedrae","cathedras"},
"cathedral":{"cathedral","cathedrals"},
"catherine":{"catherine","catherines"},
"catheterize":{"catheterize","catheterized","catheterizing"},
"cathexis":{"cathexes","cathexis"},
"catholicism":{"catholicism","catholicisms"},
"catholicity":{"catholicities","catholicity"},
"catholicize":{"catholicize","catholicized","catholicizes","catholicizing"},
"cathouse":{"cathouse","cathouses"},
"catkin":{"catkin","catkins"},
"catmint":{"catmint","catmints"},
"catnap":{"catnap","catnaps"},
"catnip":{"catnip","catnips"},
"catoptrophorus":{"catoptrophorus","catoptrophoruses"},
"catostomidae":{"catostomidae","catostomidaes"},
"catostomus":{"catostomus","catostomuses"},
"catskills":{"catskills","catskillses"},
"catsup":{"catsup","catsups"},
"cattalo":{"cattalo","cattaloes","cattalos"},
"cattery":{"catteries","cattery"},
"cattie":{"cattie","catties"},
"cattiness":{"cattiness","cattinesses"},
"cattleman":{"cattleman","cattlemen"},
"cattleship":{"cattleship","cattleships"},
"cattleya":{"cattleya","cattleyas"},
"catty":{"cattier","catties","cattiest","catty"},
"caucasia":{"caucasia","caucasias"},
"caucasian":{"caucasian","caucasians"},
"caucasus":{"caucasus","caucasuses"},
"caucus":{"caucus","caucused","caucuses","caucusing"},
"caudata":{"caudata","caudatas"},
"caudate":{"caudate","caudates"},
"caudex":{"caudex","caudexes"},
"caudillo":{"caudillo","caudillos"},
"caul":{"caul","cauls"},
"cauldron":{"cauldron","cauldrons"},
"cauliflower":{"cauliflower","cauliflowers"},
"caulis":{"caules","caulis"},
"caulk":{"caulk","caulked","caulking","caulks"},
"caulophyllum":{"caulophyllum","caulophyllums"},
"causa":{"causa","causas"},
"causality":{"causalities","causality"},
"causation":{"causation","causations"},
"cause":{"cause","caused","causes","causing"},
"causerie":{"causerie","causeries"},
"causeway":{"causeway","causewayed","causewaying","causeways"},
"causing":{"causing","causings"},
"caustic":{"caustic","caustics"},
"cauterisation":{"cauterisation","cauterisations"},
"cauterization":{"cauterization","cauterizations"},
"cauterize":{"cauterize","cauterized","cauterizes","cauterizing"},
"cautery":{"cauteries","cautery"},
"caution":{"caution","cautioned","cautioning","cautions"},
"cautious":{"cautious","cautiouses"},
"cautiousness":{"cautiousness","cautiousnesses"},
"cavalier":{"cavalier","cavaliers"},
"cavalla":{"cavalla","cavallas"},
"cavally":{"cavallies","cavally"},
"cavalry":{"cavalries","cavalry"},
"cavalryman":{"cavalryman","cavalrymen"},
"cavatina":{"cavatina","cavatinas","cavatine"},
"cave":{"cave","caved","caves","caving"},
"caveat":{"caveat","caveats"},
"cavefish":{"cavefish","cavefishes"},
"caveman":{"caveman","cavemen"},
"cavern":{"cavern","caverned","caverning","caverns"},
"cavetto":{"cavetti","cavetto"},
"cavia":{"cavia","cavias"},
"caviar":{"caviar","caviars"},
"caviare":{"caviare","caviares"},
"caviidae":{"caviidae","caviidaes"},
"cavil":{"cavil","caviled","caviling","cavilled","cavilling","cavils"},
"cavity":{"cavities","cavity"},
"cavo-relievo":{"cavo-relievo","cavo-relievos"},
"cavo-rilievo":{"cavo-rilievi","cavo-rilievo"},
"cavort":{"cavort","cavorted","cavorting","cavorts"},
"cavum":{"cavum","cavums"},
"cavy":{"cavies","cavy"},
"caw":{"caw","cawed","cawing","caws"},
"cay":{"cay","cays"},
"cayenne":{"cayenne","cayennes"},
"cayman":{"cayman","caymans","caymen"},
"cayuga":{"cayuga","cayugas"},
"cayuse":{"cayuse","cayuses"},
"cazique":{"cazique","caziques"},
"cbc":{"cbc","cbcs"},
"cbel":{"cbel","cbeled","cbeling","cbelled","cbelling","cbels"},
"cc":{"cc","ccs"},
"cd":{"cd","cds"},
"cd-r":{"cd-r","cd-rs"},
"cd-rom":{"cd-rom","cd-roms"},
"cd-wo":{"cd-wo","cd-wos"},
"ce":{"ce","ces"},
"cease":{"cease","ceased","ceases","ceasing"},
"cease-fire":{"cease-fire","cease-fires"},
"ceaselessness":{"ceaselessness","ceaselessnesses"},
"cebidae":{"cebidae","cebidaes"},
"cebuan":{"cebuan","cebuans"},
"cebuano":{"cebuano","cebuanos"},
"cebuella":{"cebuella","cebuellas"},
"cebus":{"cebus","cebuses"},
"cecidomyidae":{"cecidomyidae","cecidomyidaes"},
"cecity":{"cecities","cecity"},
"cecropia":{"cecropia","cecropias"},
"cecropiaceae":{"cecropiaceae","cecropiaceaes"},
"cecum":{"ceca","cecum","cecums"},
"cedar":{"cedar","cedars"},
"cedarbird":{"cedarbird","cedarbirds"},
"cedarwood":{"cedarwood","cedarwoods"},
"cede":{"cede","ceded","cedes","ceding"},
"cedi":{"cedi","cedis"},
"cedilla":{"cedilla","cedillas"},
"ceding":{"ceding","cedings"},
"cedrela":{"cedrela","cedrelas"},
"cedrus":{"cedrus","cedruses"},
"cefobid":{"cefobid","cefobids"},
"cefoperazone":{"cefoperazone","cefoperazones"},
"cefotaxime":{"cefotaxime","cefotaximes"},
"ceftazidime":{"ceftazidime","ceftazidimes"},
"ceftin":{"ceftin","ceftins"},
"ceftriaxone":{"ceftriaxone","ceftriaxones"},
"cefuroxime":{"cefuroxime","cefuroximes"},
"ceiba":{"ceiba","ceibas"},
"ceibo":{"ceibo","ceibos"},
"ceil":{"ceil","ceiled","ceiling"},
"ceiling":{"ceiling","ceilings"},
"celandine":{"celandine","celandines"},
"celastraceae":{"celastraceae","celastraceaes"},
"celastrus":{"celastrus","celastruses"},
"celebes":{"celebes","celebeses"},
"celebrant":{"celebrant","celebrants"},
"celebrate":{"celebrate","celebrated","celebrates","celebrating"},
"celebrater":{"celebrater","celebraters"},
"celebration":{"celebration","celebrations"},
"celebrator":{"celebrator","celebrators"},
"celebrity":{"celebrities","celebrity"},
"celeriac":{"celeriac","celeriacs"},
"celerity":{"celerities","celerity"},
"celery":{"celeries","celery"},
"celesta":{"celesta","celestas"},
"celestial":{"celestial","celestials"},
"celibacy":{"celibacies","celibacy"},
"cell":{"cell","cells"},
"cella":{"cella","cellae"},
"cellar":{"cellar","cellared","cellaring","cellars"},
"cellaret":{"cellaret","cellarets"},
"cellblock":{"cellblock","cellblocks"},
"cello":{"cello","cellos"},
"celluloid":{"celluloid","celluloids"},
"celom":{"celom","celoms"},
"celoma":{"celoma","celomas"},
"celosia":{"celosia","celosias"},
"celt":{"celt","celts"},
"celtic":{"celtic","celtics"},
"celtis":{"celtis","celtises"},
"celtuce":{"celtuce","celtuces"},
"cembalo":{"cembali","cembalo","cembalos"},
"cement":{"cement","cemented","cementing","cements"},
"cementite":{"cementite","cementites"},
"cementum":{"cementum","cementums"},
"cemetery":{"cemeteries","cemetery"},
"cenchrus":{"cenchrus","cenchruses"},
"cenobite":{"cenobite","cenobites"},
"cenogenesis":{"cenogeneses","cenogenesis"},
"cenozoic":{"cenozoic","cenozoics"},
"cense":{"cense","censed","censes","censing"},
"censer":{"censer","censers"},
"censor":{"censor","censored","censoring","censors"},
"censoring":{"censoring","censorings"},
"censorship":{"censorship","censorships"},
"censure":{"censure","censured","censures","censuring"},
"census":{"census","censused","censuses","censusing"},
"cent":{"cent","cents"},
"cental":{"cental","centals"},
"centare":{"centare","centares"},
"centaur":{"centaur","centaurs"},
"centaurea":{"centaurea","centaureas"},
"centaurium":{"centaurium","centauriums"},
"centaurus":{"centaurus","centauruses"},
"centaury":{"centauries","centaury"},
"centavo":{"centavo","centavos"},
"centenary":{"centenaries","centenary"},
"centennial":{"centennial","centennials"},
"center":{"center","centered","centering","centers"},
"centerboard":{"centerboard","centerboards"},
"centerfield":{"centerfield","centerfields"},
"centering":{"centering","centerings"},
"centerline":{"centerline","centerlines"},
"centerpiece":{"centerpiece","centerpieces"},
"centesimo":{"centesimi","centesimo","centesimos"},
"centiliter":{"centiliter","centiliters"},
"centilitre":{"centilitre","centilitres"},
"centillion":{"centillion","centillions"},
"centime":{"centime","centimes"},
"centimeter":{"centimeter","centimeters"},
"centimetre":{"centimetre","centimetres"},
"centimo":{"centimo","centimos"},
"centner":{"centner","centners"},
"cento":{"cento","centos"},
"central":{"central","centrals"},
"centralisation":{"centralisation","centralisations"},
"centrality":{"centralities","centrality"},
"centralization":{"centralization","centralizations"},
"centralize":{"centralize","centralized","centralizes","centralizing"},
"centranthus":{"centranthus","centranthuses"},
"centrarchid":{"centrarchid","centrarchids"},
"centrarchidae":{"centrarchidae","centrarchidaes"},
"centre":{"centre","centred","centres","centring"},
"centreboard":{"centreboard","centreboards"},
"centred":{"centred","centreds"},
"centrepiece":{"centrepiece","centrepieces"},
"centrifuge":{"centrifuge","centrifuges"},
"centriscidae":{"centriscidae","centriscidaes"},
"centrist":{"centrist","centrists"},
"centrocercus":{"centrocercus","centrocercuses"},
"centroid":{"centroid","centroids"},
"centrolobium":{"centrolobium","centrolobiums"},
"centropomidae":{"centropomidae","centropomidaes"},
"centropomus":{"centropomus","centropomuses"},
"centropristis":{"centropristis","centropristises"},
"centropus":{"centropus","centropuses"},
"centrosema":{"centrosema","centrosemas"},
"centrosome":{"centrosome","centrosomes"},
"centrospermae":{"centrospermae","centrospermaes"},
"centrum":{"centra","centrum","centrums"},
"centunculus":{"centunculus","centunculuses"},
"century":{"centuries","century"},
"ceo":{"ceo","ceos"},
"cephalalgia":{"cephalalgia","cephalalgias"},
"cephalanthera":{"cephalanthera","cephalantheras"},
"cephalaspid":{"cephalaspid","cephalaspids"},
"cephalaspida":{"cephalaspida","cephalaspidas"},
"cephalexin":{"cephalexin","cephalexins"},
"cephalhematoma":{"cephalhematoma","cephalhematomas"},
"cephalobidae":{"cephalobidae","cephalobidaes"},
"cephalochordata":{"cephalochordata","cephalochordatas"},
"cephalohematoma":{"cephalohematoma","cephalohematomas"},
"cephalopod":{"cephalopod","cephalopods"},
"cephalopoda":{"cephalopoda","cephalopodas"},
"cephalopterus":{"cephalopterus","cephalopteruses"},
"cephalosporin":{"cephalosporin","cephalosporins"},
"cephalotaceae":{"cephalotaceae","cephalotaceaes"},
"cephalotaxaceae":{"cephalotaxaceae","cephalotaxaceaes"},
"cephalotaxus":{"cephalotaxus","cephalotaxuses"},
"cephalothorax":{"cephalothoraces","cephalothorax","cephalothoraxes"},
"cephalotus":{"cephalotus","cephalotuses"},
"cepphus":{"cepphus","cepphuses"},
"cer":{"cer","cers"},
"cerambycidae":{"cerambycidae","cerambycidaes"},
"ceramicist":{"ceramicist","ceramicists"},
"ceramist":{"ceramist","ceramists"},
"cerapteryx":{"cerapteryx","cerapteryxes"},
"cerastes":{"cerastes","cerasteses"},
"cerastium":{"cerastium","cerastiums"},
"ceratin":{"ceratin","ceratins"},
"ceratitis":{"ceratitis","ceratitises"},
"ceratodontidae":{"ceratodontidae","ceratodontidaes"},
"ceratodus":{"ceratodus","ceratoduses"},
"ceratonia":{"ceratonia","ceratonias"},
"ceratopetalum":{"ceratopetalum","ceratopetalums"},
"ceratophyllaceae":{"ceratophyllaceae","ceratophyllaceaes"},
"ceratophyllum":{"ceratophyllum","ceratophyllums"},
"ceratopogon":{"ceratopogon","ceratopogons"},
"ceratopogonidae":{"ceratopogonidae","ceratopogonidaes"},
"ceratopsia":{"ceratopsia","ceratopsias"},
"ceratopsian":{"ceratopsian","ceratopsians"},
"ceratopsidae":{"ceratopsidae","ceratopsidaes"},
"ceratopteris":{"ceratopteris","ceratopterises"},
"ceratosaur":{"ceratosaur","ceratosaurs"},
"ceratosaurus":{"ceratosaurus","ceratosauruses"},
"ceratostomataceae":{"ceratostomataceae","ceratostomataceaes"},
"ceratostomella":{"ceratostomella","ceratostomellas"},
"ceratotherium":{"ceratotherium","ceratotheriums"},
"cercaria":{"cercaria","cercariiae"},
"cercidiphyllaceae":{"cercidiphyllaceae","cercidiphyllaceaes"},
"cercidiphyllum":{"cercidiphyllum","cercidiphyllums"},
"cercidium":{"cercidium","cercidiums"},
"cercis":{"cercis","cercises"},
"cercocebus":{"cercocebus","cercocebuses"},
"cercopidae":{"cercopidae","cercopidaes"},
"cercopithecidae":{"cercopithecidae","cercopithecidaes"},
"cercopithecus":{"cercopithecus","cercopithecuses"},
"cercospora":{"cercospora","cercosporas"},
"cercosporella":{"cercosporella","cercosporellas"},
"cercus":{"cerci","cercus"},
"cereal":{"cereal","cereals"},
"cerebellum":{"cerebella","cerebellum","cerebellums"},
"cerebrate":{"cerebrate","cerebrated","cerebrates","cerebrating"},
"cerebration":{"cerebration","cerebrations"},
"cerebrum":{"cerebra","cerebrum","cerebrums"},
"cerement":{"cerement","cerements"},
"ceremonial":{"ceremonial","ceremonials"},
"ceremony":{"ceremonies","ceremony"},
"cereus":{"cereus","cereuses"},
"ceriman":{"ceriman","cerimen"},
"cerise":{"cerise","cerises"},
"cerium":{"cerium","ceriums"},
"cero":{"cero","ceros"},
"ceroxylon":{"ceroxylon","ceroxylons"},
"cerriped":{"cerriped","cerripeds"},
"cerripede":{"cerripede","cerripedes"},
"certainty":{"certainties","certainty"},
"certhia":{"certhia","certhias"},
"certhiidae":{"certhiidae","certhiidaes"},
"certificate":{"certificate","certificated","certificates","certificating"},
"certification":{"certification","certifications"},
"certify":{"certified","certifies","certify","certifying"},
"certiorari":{"certiorari","certioraris"},
"certitude":{"certitude","certitudes"},
"cerulean":{"cerulean","ceruleans"},
"cerumen":{"cerumen","cerumens"},
"cerussite":{"cerussite","cerussites"},
"cervantes":{"cervantes","cervanteses"},
"cervid":{"cervid","cervids"},
"cervidae":{"cervidae","cervidaes"},
"cervix":{"cervices","cervix","cervixes"},
"cervus":{"cervus","cervuses"},
"ceryle":{"ceryle","ceryles"},
"cesarean":{"cesarean","cesareans"},
"cesarian":{"cesarian","cesarians"},
"cesium":{"cesium","cesiums"},
"cessation":{"cessation","cessations"},
"cession":{"cession","cessions"},
"cessionary":{"cessionaries","cessionary"},
"cesspit":{"cesspit","cesspits"},
"cesspool":{"cesspool","cesspools"},
"cestida":{"cestida","cestidas"},
"cestidae":{"cestidae","cestidaes"},
"cestoda":{"cestoda","cestodas"},
"cestode":{"cestode","cestodes"},
"cestrum":{"cestrum","cestrums"},
"cestum":{"cestum","cestums"},
"cestus":{"cesti","cestus"},
"cesura":{"cesura","cesurae","cesuras"},
"cetacea":{"cetacea","cetaceas"},
"cetacean":{"cetacean","cetaceans"},
"cetchup":{"cetchup","cetchups"},
"ceterach":{"ceterach","ceteraches"},
"cetonia":{"cetonia","cetonias"},
"cetoniidae":{"cetoniidae","cetoniidaes"},
"cetorhinidae":{"cetorhinidae","cetorhinidaes"},
"cetorhinus":{"cetorhinus","cetorhinuses"},
"cetraria":{"cetraria","cetrarias"},
"ceylon":{"ceylon","ceylons"},
"ceylonite":{"ceylonite","ceylonites"},
"cf":{"cf","cfs"},
"cfc":{"cfc","cfcs"},
"cha-cha":{"cha-cha","cha-chas"},
"cha-cha-cha":{"cha-cha-cha","cha-cha-chas"},
"chablis":{"chablis","chablises"},
"chacma":{"chacma","chacmas"},
"chad":{"chad","chads"},
"chadic":{"chadic","chadics"},
"chadlock":{"chadlock","chadlocks"},
"chaenomeles":{"chaenomeles","chaenomeleses"},
"chaenopsis":{"chaenopses","chaenopsis"},
"chaeta":{"chaeta","chaetae"},
"chaetodipterus":{"chaetodipterus","chaetodipteruses"},
"chaetodontidae":{"chaetodontidae","chaetodontidaes"},
"chaetognath":{"chaetognath","chaetognaths"},
"chaetognatha":{"chaetognatha","chaetognathas"},
"chafe":{"chafe","chafed","chafes","chafing"},
"chafeweed":{"chafeweed","chafeweeds"},
"chaff":{"chaff","chaffed","chaffing","chaffs"},
"chaffer":{"chaffer","chaffered","chaffering","chaffers"},
"chaffinch":{"chaffinch","chaffinches"},
"chaffweed":{"chaffweed","chaffweeds"},
"chaga":{"chaga","chagas"},
"chagatai":{"chagatai","chagatais"},
"chagga":{"chagga","chaggas"},
"chagrin":{"chagrin","chagrined","chagrining","chagrins"},
"chahta":{"chahta","chahtas"},
"chain":{"chain","chained","chaining","chains"},
"chain-smoke":{"chain-smoke","chain-smoked","chain-smoking"},
"chainman":{"chainman","chainmen"},
"chains":{"chains","chainses"},
"chainsaw":{"chainsaw","chainsaws"},
"chair":{"chair","chaired","chairing","chairs"},
"chairlift":{"chairlift","chairlifts"},
"chairman":{"chairman","chairmanned","chairmanning","chairmans","chairmen"},
"chairperson":{"chairperson","chairpersons"},
"chairwoman":{"chairwoman","chairwomen"},
"chaise":{"chaise","chaises"},
"chaise_longue":{"chaises_longues","chaise_longue","chaise_longues"},
"chaja":{"chaja","chajas"},
"chalaza":{"chalaza","chalazae","chalazas"},
"chalazion":{"chalazion","chalazions"},
"chalcanthite":{"chalcanthite","chalcanthites"},
"chalcedony":{"chalcedonies","chalcedony"},
"chalcid":{"chalcid","chalcids"},
"chalcidae":{"chalcidae","chalcidaes"},
"chalcidfly":{"chalcidflies","chalcidfly"},
"chalcididae":{"chalcididae","chalcididaes"},
"chalcis":{"chalcis","chalcises"},
"chalcocite":{"chalcocite","chalcocites"},
"chalcopyrite":{"chalcopyrite","chalcopyrites"},
"chalcostigma":{"chalcostigma","chalcostigmas"},
"chalice":{"chalice","chalices"},
"chalk":{"chalk","chalked","chalking","chalks"},
"chalkboard":{"chalkboard","chalkboards"},
"challah":{"challah","challahs"},
"challenge":{"challenge","challenged","challenges","challenging"},
"challenger":{"challenger","challengers"},
"chalons":{"chalons","chalonses"},
"chalons-sur-marne":{"chalons-sur-marne","chalons-sur-marnes"},
"chalutz":{"chalutz","chalutzim"},
"chalybite":{"chalybite","chalybites"},
"cham":{"cham","chams"},
"chamaea":{"chamaea","chamaeas"},
"chamaecrista":{"chamaecrista","chamaecristas"},
"chamaecyparis":{"chamaecyparis","chamaecyparises"},
"chamaecytisus":{"chamaecytisus","chamaecytisuses"},
"chamaedaphne":{"chamaedaphne","chamaedaphnes"},
"chamaeleo":{"chamaeleo","chamaeleos"},
"chamaeleon":{"chamaeleon","chamaeleons"},
"chamaeleonidae":{"chamaeleonidae","chamaeleonidaes"},
"chamaeleontidae":{"chamaeleontidae","chamaeleontidaes"},
"chamaemelum":{"chamaemelum","chamaemelums"},
"chamber":{"chamber","chambered","chambering","chambers"},
"chamberlain":{"chamberlain","chamberlains"},
"chambermaid":{"chambermaid","chambermaids"},
"chamberpot":{"chamberpot","chamberpots"},
"chameleon":{"chameleon","chameleons"},
"chamfron":{"chamfron","chamfrons"},
"chammy":{"chammies","chammy"},
"chamois":{"chamois","chamoises","chamoix"},
"chamomile":{"chamomile","chamomiles"},
"champ":{"champ","champed","champing","champs"},
"champagne":{"champagne","champagnes"},
"champagne-ardenne":{"champagne-ardenne","champagne-ardennes"},
"champaign":{"champaign","champaigns"},
"champerty":{"champerties","champerty"},
"champignon":{"champignon","champignons"},
"champion":{"champion","championed","championing","champions"},
"championship":{"championship","championships"},
"chanal":{"chanal","chanals"},
"chanar":{"chanar","chanars"},
"chance":{"chance","chanced","chances","chancing"},
"chancel":{"chancel","chancels"},
"chancellery":{"chancelleries","chancellery"},
"chancellor":{"chancellor","chancellors"},
"chancellory":{"chancellories","chancellory"},
"chancery":{"chanceries","chancery"},
"chancy":{"chancier","chanciest","chancy"},
"chandelier":{"chandelier","chandeliers"},
"chandlery":{"chandleries","chandlery"},
"chanfron":{"chanfron","chanfrons"},
"chang":{"chang","changs"},
"changan":{"changan","changans"},
"change":{"change","changed","changes","changing"},
"change-of-pace":{"change-of-pace","change-of-paces"},
"change-up":{"change-up","change-ups"},
"changeability":{"changeabilities","changeability"},
"changeableness":{"changeableness","changeablenesses"},
"changefulness":{"changefulness","changefulnesses"},
"changelessness":{"changelessness","changelessnesses"},
"changeling":{"changeling","changelings"},
"changeover":{"changeover","changeovers"},
"changer":{"changer","changers"},
"channel":{"channel","channeled","channeling","channelled","channelling","channels"},
"channelisation":{"channelisation","channelisations"},
"channelization":{"channelization","channelizations"},
"channelize":{"channelize","channelized","channelizes","channelizing"},
"chanson":{"chanson","chansons"},
"chansonnier":{"chansonnier","chansonniers"},
"chant":{"chant","chanted","chanting","chants"},
"chantarelle":{"chantarelle","chantarelles"},
"chanter":{"chanter","chanters"},
"chanterelle":{"chanterelle","chanterelles"},
"chantey":{"chantey","chanteys"},
"chanting":{"chanting","chantings"},
"chantry":{"chantries","chantry"},
"chanty":{"chanties","chanty"},
"chanukah":{"chanukah","chanukahs"},
"chaos":{"chaos","chaoses"},
"chap":{"chap","chapped","chapping","chaps"},
"chaparral":{"chaparral","chaparrals"},
"chapati":{"chapati","chapatis"},
"chapatti":{"chapatti","chapattis"},
"chapeau":{"chapeau","chapeaus","chapeaux"},
"chapel":{"chapel","chapels"},
"chapelgoer":{"chapelgoer","chapelgoers"},
"chaperon":{"chaperon","chaperoned","chaperoning","chaperons"},
"chaperone":{"chaperone","chaperoned","chaperones","chaperoning"},
"chapiter":{"chapiter","chapiters"},
"chaplain":{"chaplain","chaplains"},
"chaplaincy":{"chaplaincies","chaplaincy"},
"chaplainship":{"chaplainship","chaplainships"},
"chaplet":{"chaplet","chaplets"},
"chapman":{"chapman","chapmen"},
"chapter":{"chapter","chaptered","chaptering","chapters"},
"chapterhouse":{"chapterhouse","chapterhouses"},
"char":{"char","charred","charring","chars"},
"chara":{"chara","charas"},
"charabanc":{"charabanc","charabancs"},
"characeae":{"characeae","characeaes"},
"characid":{"characid","characids"},
"characidae":{"characidae","characidaes"},
"characin":{"characin","characins"},
"characinidae":{"characinidae","characinidaes"},
"character":{"character","charactered","charactering","characters"},
"characteristic":{"characteristic","characteristics"},
"characterization":{"characterization","characterizations"},
"characterize":{"characterize","characterized","characterizes","characterizing"},
"charactery":{"characteries","charactery"},
"charade":{"charade","charades"},
"charadrii":{"charadrii","charadriis"},
"charadriidae":{"charadriidae","charadriidaes"},
"charadriiformes":{"charadriiformes","charadriiformeses"},
"charadrius":{"charadrius","charadriuses"},
"charales":{"charales","charaleses"},
"charcoal":{"charcoal","charcoaled","charcoaling","charcoals"},
"chard":{"chard","chards"},
"chardonnay":{"chardonnay","chardonnays"},
"charge":{"charge","charged","charges","charging"},
"charger":{"charger","chargers"},
"charina":{"charina","charinas"},
"chariness":{"chariness","charinesses"},
"chariot":{"chariot","charioted","charioting","chariots"},
"charisma":{"charisma","charismas","charismata"},
"charity":{"charities","charity"},
"charivari":{"charivari","charivaris"},
"charlady":{"charladies","charlady"},
"charlatan":{"charlatan","charlatans"},
"charlatanism":{"charlatanism","charlatanisms"},
"charlemagne":{"charlemagne","charlemagnes"},
"charles":{"charles","charleses"},
"charleston":{"charleston","charlestons"},
"charlock":{"charlock","charlocks"},
"charm":{"charm","charmed","charming","charms"},
"charmer":{"charmer","charmers"},
"charnel":{"charnel","charnels"},
"charophyceae":{"charophyceae","charophyceaes"},
"charr":{"charr","charrs"},
"charronia":{"charronia","charronias"},
"chart":{"chart","charted","charting","charts"},
"charter":{"charter","chartered","chartering","charters"},
"chartreuse":{"chartreuse","chartreuses"},
"chartulary":{"chartularies","chartulary"},
"charwoman":{"charwoman","charwomen"},
"chary":{"charier","chariest","chary"},
"chase":{"chase","chased","chases","chasing"},
"chased":{"chased","chaseds"},
"chaser":{"chaser","chasers"},
"chasm":{"chasm","chasms"},
"chasse":{"chasse","chasses"},
"chassis":{"chasses","chassis"},
"chaste":{"chaste","chaster","chastest"},
"chasten":{"chasten","chastened","chastening","chastens"},
"chasteness":{"chasteness","chastenesses"},
"chastening":{"chastening","chastenings"},
"chastise":{"chastise","chastised","chastises","chastising"},
"chastisement":{"chastisement","chastisements"},
"chastity":{"chastities","chastity"},
"chat":{"chat","chats","chatted","chatting"},
"chateau":{"chateau","chateaus","chateaux"},
"chateau-thierry":{"chateau-thierries","chateau-thierry"},
"chateura":{"chateura","chateuras"},
"chattanooga":{"chattanooga","chattanoogas"},
"chattel":{"chattel","chattels"},
"chatter":{"chatter","chattered","chattering","chatters"},
"chatterbox":{"chatterbox","chatterboxes"},
"chatterer":{"chatterer","chatterers"},
"chattering":{"chattering","chatterings"},
"chatty":{"chattier","chattiest","chatty"},
"chaucer":{"chaucer","chaucers"},
"chauffer":{"chauffer","chauffers"},
"chauffeur":{"chauffeur","chauffeured","chauffeuring","chauffeurs"},
"chaulmoogra":{"chaulmoogra","chaulmoogras"},
"chaulmugra":{"chaulmugra","chaulmugras"},
"chauna":{"chauna","chaunas"},
"chauvinism":{"chauvinism","chauvinisms"},
"chauvinist":{"chauvinist","chauvinists"},
"chaw":{"chaw","chawed","chawing","chaws"},
"chawbacon":{"chawbacon","chawbacons"},
"chazan":{"chazan","chazanim","chazans"},
"cheap":{"cheap","cheaper","cheapest"},
"cheap-jack":{"cheap-jack","cheap-jacks"},
"cheapen":{"cheapen","cheapened","cheapening","cheapens"},
"cheapness":{"cheapness","cheapnesses"},
"cheapskate":{"cheapskate","cheapskates"},
"cheat":{"cheat","cheated","cheating","cheats"},
"cheater":{"cheater","cheaters"},
"cheatgrass":{"cheatgrass","cheatgrasses"},
"cheating":{"cheating","cheatings"},
"chechen":{"chechen","chechens"},
"chechoslovak":{"chechoslovak","chechoslovaks"},
"check":{"check","checked","checking","checks"},
"checkbook":{"checkbook","checkbooks"},
"checker":{"checker","checkered","checkering","checkers"},
"checkerberry":{"checkerberries","checkerberry"},
"checkerbloom":{"checkerbloom","checkerblooms"},
"checkerboard":{"checkerboard","checkerboards"},
"checkers":{"checkers","checkerses"},
"checkmate":{"checkmate","checkmated","checkmating"},
"checkout":{"checkout","checkouts"},
"checkrein":{"checkrein","checkreins"},
"checkroom":{"checkroom","checkrooms"},
"checkup":{"checkup","checkups"},
"cheddar":{"cheddar","cheddars"},
"cheder":{"chadarim","chedarim","cheder"},
"cheek":{"cheek","cheeked","cheeking","cheeks"},
"cheekbone":{"cheekbone","cheekbones"},
"cheekiness":{"cheekiness","cheekinesses"},
"cheeky":{"cheekier","cheekiest","cheeky"},
"cheep":{"cheep","cheeped","cheeping","cheeps"},
"cheer":{"cheer","cheered","cheering","cheers"},
"cheerfulness":{"cheerfulness","cheerfulnesses"},
"cheering":{"cheering","cheerings"},
"cheerio":{"cheerio","cheerios"},
"cheerlessness":{"cheerlessness","cheerlessnesses"},
"cheery":{"cheerier","cheeriest","cheery"},
"cheese":{"cheese","cheesed","cheeses","cheesing"},
"cheeseboard":{"cheeseboard","cheeseboards"},
"cheeseflower":{"cheeseflower","cheeseflowers"},
"cheesy":{"cheesier","cheesiest","cheesy"},
"cheetah":{"cheetah","cheetahs"},
"cheewink":{"cheewink","cheewinks"},
"chef":{"chef","chefs"},
"chef-d'ouvre":{"chef-d'ouvre","chefs-d'ouvre"},
"cheilanthes":{"cheilanthes","cheilantheses"},
"cheiloschisis":{"cheiloschises","cheiloschisis"},
"cheilosis":{"cheiloses","cheilosis"},
"cheiranthus":{"cheiranthus","cheiranthuses"},
"chekhov":{"chekhov","chekhovs"},
"chekov":{"chekov","chekovs"},
"chela":{"chela","chelas"},
"chelate":{"chelate","chelated","chelates","chelating"},
"chelicera":{"chelicera","chelicerae"},
"chelicerata":{"chelicerata","cheliceratas"},
"chelidonium":{"chelidonium","chelidoniums"},
"chelifer":{"chelifer","chelifers"},
"chelone":{"chelone","chelones"},
"chelonethida":{"chelonethida","chelonethidas"},
"chelonia":{"chelonia","chelonias"},
"chelonian":{"chelonian","chelonians"},
"chelonidae":{"chelonidae","chelonidaes"},
"cheloniidae":{"cheloniidae","cheloniidaes"},
"chelydra":{"chelydra","chelydras"},
"chelydridae":{"chelydridae","chelydridaes"},
"chemical":{"chemical","chemicals"},
"chemise":{"chemise","chemises"},
"chemisorption":{"chemisorption","chemisorptions"},
"chemist":{"chemist","chemists"},
"chemistry":{"chemistries","chemistry"},
"chemosorption":{"chemosorption","chemosorptions"},
"chen":{"chen","chens"},
"chenfish":{"chenfish","chenfishes"},
"chenopodiaceae":{"chenopodiaceae","chenopodiaceaes"},
"chenopodiales":{"chenopodiales","chenopodialeses"},
"chenopodium":{"chenopodium","chenopodiums"},
"cheque":{"cheque","chequed","cheques","chequing"},
"chequebook":{"chequebook","chequebooks"},
"cheremis":{"cheremis","cheremises"},
"cheremiss":{"cheremiss","cheremisses"},
"cherimolla":{"cherimolla","cherimollas"},
"cherimoya":{"cherimoya","cherimoyas"},
"cherish":{"cherish","cherished","cherishes","cherishing"},
"chermidae":{"chermidae","chermidaes"},
"cherokee":{"cherokee","cherokees"},
"cherry":{"cherries","cherry"},
"cherrystone":{"cherrystone","cherrystones"},
"cherub":{"cherub","cherubim","cherubs"},
"chervil":{"chervil","chervils"},
"chess":{"chess","chesses"},
"chessboard":{"chessboard","chessboards"},
"chessman":{"chessman","chessmen"},
"chest":{"chest","chests"},
"chestnut":{"chestnut","chestnuts"},
"chesty":{"chestier","chestiest","chesty"},
"chetah":{"chetah","chetahs"},
"cheval-de-frise":{"cheval-de-frise","cheval-de-frises"},
"chevalier":{"chevalier","chevaliers"},
"chevaux-de-frise":{"chevaux-de-frise","chevaux-de-frises"},
"chevre":{"chevre","chevres"},
"chevron":{"chevron","chevrons"},
"chevrotain":{"chevrotain","chevrotains"},
"chew":{"chew","chewed","chewing","chews"},
"chewa":{"chewa","chewas"},
"chewing":{"chewing","chewings"},
"chewink":{"chewink","chewinks"},
"chewy":{"chewier","chewiest","chewy"},
"cheyenne":{"cheyenne","cheyennes"},
"chi":{"chi","chis"},
"chi-chi":{"chi-chi","chi-chis"},
"chiaroscuro":{"chiaroscuro","chiaroscuros"},
"chiasm":{"chiasm","chiasms"},
"chiasma":{"chiasma","chiasmas","chiasmata"},
"chiasmus":{"chiasmi","chiasmus"},
"chic":{"chic","chicer","chicest","chics"},
"chicago":{"chicago","chicagos"},
"chicane":{"chicane","chicaned","chicanes","chicaning"},
"chicanery":{"chicaneries","chicanery"},
"chicano":{"chicano","chicanos"},
"chiccory":{"chiccories","chiccory"},
"chichipe":{"chichipe","chichipes"},
"chick":{"chick","chicks"},
"chickabiddy":{"chickabiddies","chickabiddy"},
"chickamauga":{"chickamauga","chickamaugas"},
"chickasaw":{"chickasaw","chickasaws"},
"chicken":{"chicken","chickens"},
"chickenfeed":{"chickenfeed","chickenfeeds"},
"chickenpox":{"chickenpox","chickenpoxes"},
"chickeree":{"chickeree","chickerees"},
"chickpea":{"chickpea","chickpeas"},
"chickweed":{"chickweed","chickweeds"},
"chicle":{"chicle","chicles"},
"chicness":{"chicness","chicnesses"},
"chico":{"chico","chicos"},
"chicory":{"chicories","chicory"},
"chicot":{"chicot","chicots"},
"chide":{"chid","chidden","chide","chided","chides","chiding"},
"chiding":{"chiding","chidings"},
"chief":{"chief","chiefs"},
"chieftain":{"chieftain","chieftains"},
"chieftaincy":{"chieftaincies","chieftaincy"},
"chieftainship":{"chieftainship","chieftainships"},
"chiffon":{"chiffon","chiffons"},
"chiffonier":{"chiffonier","chiffoniers"},
"chigetai":{"chigetai","chigetais"},
"chigger":{"chigger","chiggers"},
"chiggerflower":{"chiggerflower","chiggerflowers"},
"chigoe":{"chigoe","chigoes"},
"chilblain":{"chilblain","chilblains"},
"chilblains":{"chilblains","chilblainses"},
"child":{"child","children"},
"childbearing":{"childbearing","childbearings"},
"childbed":{"childbed","childbeds"},
"childbirth":{"childbirth","childbirths"},
"childcare":{"childcare","childcares"},
"childhood":{"childhood","childhoods"},
"childishness":{"childishness","childishnesses"},
"chile":{"chile","chiles"},
"chili":{"chili","chilis"},
"chiliad":{"chiliad","chiliads"},
"chill":{"chill","chilled","chiller","chillest","chilling","chills"},
"chilli":{"chilli","chillies","chillis"},
"chilliness":{"chilliness","chillinesses"},
"chilling":{"chilling","chillings"},
"chilly":{"chillier","chillies","chilliest","chilly"},
"chilomastix":{"chilomastices","chilomastix","chilomastixes"},
"chilomeniscus":{"chilomeniscus","chilomeniscuses"},
"chilomycterus":{"chilomycterus","chilomycteruses"},
"chilopoda":{"chilopoda","chilopodas"},
"chilopsis":{"chilopses","chilopsis"},
"chimaera":{"chimaera","chimaeras"},
"chimaeridae":{"chimaeridae","chimaeridaes"},
"chimaphila":{"chimaphila","chimaphilas"},
"chime":{"chime","chimed","chimes","chiming"},
"chimera":{"chimera","chimeras"},
"chimney":{"chimney","chimneys"},
"chimneypiece":{"chimneypiece","chimneypieces"},
"chimneysweep":{"chimneysweep","chimneysweeps"},
"chimneysweeper":{"chimneysweeper","chimneysweepers"},
"chimonanthus":{"chimonanthus","chimonanthuses"},
"chimp":{"chimp","chimps"},
"chimpanzee":{"chimpanzee","chimpanzees"},
"chin":{"chin","chinned","chinning","chins"},
"chin-wag":{"chin-wag","chin-wags"},
"chin-wagging":{"chin-wagging","chin-waggings"},
"china":{"china","chinas"},
"chinaberry":{"chinaberries","chinaberry"},
"chinaman":{"chinaman","chinamen"},
"chincapin":{"chincapin","chincapins"},
"chinch":{"chinch","chinches"},
"chincherinchee":{"chincherinchee","chincherinchees"},
"chinchilla":{"chinchilla","chinchillas"},
"chinchillidae":{"chinchillidae","chinchillidaes"},
"chinchillon":{"chinchillon","chinchillons"},
"chinchona":{"chinchona","chinchonas"},
"chinese_eddo":{"chinese_eddo","chinese_eddoes"},
"chingpo":{"chingpo","chingpos"},
"chink":{"chink","chinked","chinking","chinks"},
"chinkapin":{"chinkapin","chinkapins"},
"chino":{"chino","chinos"},
"chinook":{"chinook","chinooks"},
"chinookan":{"chinookan","chinookans"},
"chinquapin":{"chinquapin","chinquapins"},
"chintzy":{"chintzier","chintziest","chintzy"},
"chiococca":{"chiococca","chiococcas"},
"chionanthus":{"chionanthus","chionanthuses"},
"chip":{"chip","chipped","chipping","chips"},
"chipboard":{"chipboard","chipboards"},
"chipewyan":{"chipewyan","chipewyans"},
"chippewa":{"chippewa","chippewas"},
"chippewaian":{"chippewaian","chippewaians"},
"chippeway":{"chippeway","chippeways"},
"chippewyan":{"chippewyan","chippewyans"},
"chippie":{"chippie","chippies"},
"chipping":{"chipping","chippings"},
"chippy":{"chippier","chippies","chippiest","chippy"},
"chirk":{"chirk","chirked","chirking"},
"chirocephalus":{"chirocephalus","chirocephaluses"},
"chiromancer":{"chiromancer","chiromancers"},
"chiromancy":{"chiromancies","chiromancy"},
"chironomidae":{"chironomidae","chironomidaes"},
"chironomus":{"chironomus","chironomuses"},
"chiropodist":{"chiropodist","chiropodists"},
"chiropody":{"chiropodies","chiropody"},
"chiroptera":{"chiroptera","chiropteras"},
"chiropteran":{"chiropteran","chiropterans"},
"chirp":{"chirp","chirped","chirping","chirps"},
"chirpy":{"chirpier","chirpiest","chirpy"},
"chirr":{"chirr","chirred","chirring"},
"chirrup":{"chirrup","chirruped","chirruping","chirrups"},
"chisel":{"chisel","chiseled","chiseling","chiselled","chiselling","chisels"},
"chiseler":{"chiseler","chiselers"},
"chiseller":{"chiseller","chisellers"},
"chisinau":{"chisinau","chisinaus"},
"chislev":{"chislev","chislevs"},
"chit":{"chit","chits"},
"chitarrone":{"chitarrone","chitarroni"},
"chitchat":{"chitchat","chitchats","chitchatted","chitchatting"},
"chitlings":{"chitlings","chitlingses"},
"chitlins":{"chitlins","chitlinses"},
"chiton":{"chiton","chitons"},
"chittamwood":{"chittamwood","chittamwoods"},
"chitterlings":{"chitterlings","chitterlingses"},
"chittimwood":{"chittimwood","chittimwoods"},
"chiv":{"chiv","chivs","chivved","chivving"},
"chivalry":{"chivalries","chivalry"},
"chivaree":{"chivaree","chivarees"},
"chive":{"chive","chives"},
"chives":{"chives","chiveses"},
"chivy":{"chevied","chevies","chevying","chivied","chivies","chivvied","chivvies","chivvying","chivy","chivying"},
"chlamydera":{"chlamydera","chlamyderas"},
"chlamydiaceae":{"chlamydiaceae","chlamydiaceaes"},
"chlamydomonadaceae":{"chlamydomonadaceae","chlamydomonadaceaes"},
"chlamydomonas":{"chlamydomonas","chlamydomonases"},
"chlamydosaurus":{"chlamydosaurus","chlamydosauruses"},
"chlamyphore":{"chlamyphore","chlamyphores"},
"chlamyphorus":{"chlamyphorus","chlamyphoruses"},
"chlamys":{"chlamys","chlamyses"},
"chloasma":{"chloasma","chloasmas"},
"chlorambucil":{"chlorambucil","chlorambucils"},
"chloramine":{"chloramine","chloramines"},
"chloramine-t":{"chloramine-t","chloramine-ts"},
"chloramphenicol":{"chloramphenicol","chloramphenicols"},
"chloranthaceae":{"chloranthaceae","chloranthaceaes"},
"chloranthus":{"chloranthus","chloranthuses"},
"chlordiazepoxide":{"chlordiazepoxide","chlordiazepoxides"},
"chlorella":{"chlorella","chlorellas"},
"chloride":{"chloride","chlorides"},
"chlorinate":{"chlorinate","chlorinated","chlorinating"},
"chlorine":{"chlorine","chlorines"},
"chloris":{"chloris","chlorises"},
"chlorococcales":{"chlorococcales","chlorococcaleses"},
"chlorococcum":{"chlorococcum","chlorococcums"},
"chlorofluorocarbon":{"chlorofluorocarbon","chlorofluorocarbons"},
"chloroform":{"chloroform","chloroformed","chloroforming","chloroforms"},
"chloromycetin":{"chloromycetin","chloromycetins"},
"chlorophis":{"chlorophis","chlorophises"},
"chlorophoneus":{"chlorophoneus","chlorophoneuses"},
"chlorophthalmidae":{"chlorophthalmidae","chlorophthalmidaes"},
"chlorophyceae":{"chlorophyceae","chlorophyceaes"},
"chlorophyl":{"chlorophyl","chlorophyls"},
"chlorophyll":{"chlorophyll","chlorophylls"},
"chlorophyta":{"chlorophyta","chlorophytas"},
"chlorophyte":{"chlorophyte","chlorophytes"},
"chlorosis":{"chloroses","chlorosis"},
"chlorothiazide":{"chlorothiazide","chlorothiazides"},
"chloroxylon":{"chloroxylon","chloroxylons"},
"chlorpromazine":{"chlorpromazine","chlorpromazines"},
"chlortetracycline":{"chlortetracycline","chlortetracyclines"},
"chlorura":{"chlorura","chloruras"},
"choanocyte":{"choanocyte","choanocytes"},
"chocho":{"chocho","chochos"},
"chock":{"chock","chocked","chocking","chocks"},
"chocolate":{"chocolate","chocolates"},
"choctaw":{"choctaw","choctaws"},
"choeronycteris":{"choeronycteris","choeronycterises"},
"choice":{"choice","choicer","choices","choicest"},
"choiceness":{"choiceness","choicenesses"},
"choir":{"choir","choired","choiring","choirs"},
"choirmaster":{"choirmaster","choirmasters"},
"choke":{"choke","choked","chokes","choking"},
"chokeberry":{"chokeberries","chokeberry"},
"chokecherry":{"chokecherries","chokecherry"},
"chokedamp":{"chokedamp","chokedamps"},
"choker":{"choker","chokers"},
"chokey":{"chokey","chokeys"},
"choking":{"choking","chokings"},
"choko":{"choko","chokos"},
"choky":{"chokier","chokies","chokiest","choky"},
"cholecarciferol":{"cholecarciferol","cholecarciferols"},
"cholecystectomy":{"cholecystectomies","cholecystectomy"},
"choler":{"choler","cholers"},
"cholera":{"cholera","choleras"},
"cholla":{"cholla","chollas"},
"choloepus":{"choloepus","choloepuses"},
"chomp":{"chomp","chomped","chomping","chomps"},
"chondrichthian":{"chondrichthian","chondrichthians"},
"chondrichthyes":{"chondrichthyes","chondrichthyeses"},
"chondrify":{"chondrified","chondrifies","chondrify","chondrifying"},
"chondriosome":{"chondriosome","chondriosomes"},
"chondrodystrophy":{"chondrodystrophies","chondrodystrophy"},
"chondroma":{"chondroma","chondromas","chondromata"},
"chondrus":{"chondrus","chondruses"},
"choo-choo":{"choo-choo","choo-choos"},
"choose":{"choose","chooses","choosing","chose","chosen"},
"choosy":{"choosier","choosiest","choosy"},
"chop":{"chop","chopped","chopping","chops"},
"chophouse":{"chophouse","chophouses"},
"chopin":{"chopin","chopins"},
"chopine":{"chopine","chopines"},
"chopines":{"chopines","chopineses"},
"chopper":{"chopper","choppers"},
"choppiness":{"choppiness","choppinesses"},
"choppy":{"choppier","choppiest","choppy"},
"chopsteak":{"chopsteak","chopsteaks"},
"chopstick":{"chopstick","chopsticks"},
"chopsticks":{"chopsticks","chopstickses"},
"choragus":{"choragi","choragus","choraguses"},
"choral":{"choral","chorals"},
"chorale":{"chorale","chorales"},
"chord":{"chord","chorded","chording","chords"},
"chordamesoderm":{"chordamesoderm","chordamesoderms"},
"chordata":{"chordata","chordatas"},
"chordeiles":{"chordeiles","chordeileses"},
"chordomesoderm":{"chordomesoderm","chordomesoderms"},
"chordospartium":{"chordospartium","chordospartiums"},
"chore":{"chore","chores"},
"chorea":{"chorea","choreas"},
"choreograph":{"choreograph","choreographed","choreographing"},
"choreography":{"choreographies","choreography"},
"choriamb":{"choriamb","choriambs"},
"choriambus":{"choriamambi","choriambus"},
"chorine":{"chorine","chorines"},
"chorioallantois":{"chorioallantois","chorioallantoises"},
"choriotis":{"choriotis","choriotises"},
"chorizagrotis":{"chorizagrotis","chorizagrotises"},
"chorizema":{"chorizema","chorizemas"},
"chorizo":{"chorizo","chorizos"},
"choroid":{"choroid","choroids"},
"chortle":{"chortle","chortled","chortles","chortling"},
"chorus":{"chorus","chorused","choruses","chorusing"},
"chosen":{"chosen","chosens"},
"choson":{"choson","chosons"},
"chou":{"chou","chous"},
"chouse":{"chouse","choused","chouses","chousing"},
"chow":{"chow","chowed","chowing","chows"},
"chrestomathy":{"chrestomathies","chrestomathy"},
"chrism":{"chrism","chrisms"},
"chrismatory":{"chrismatories","chrismatory"},
"chrisom":{"chrisom","chrisoms"},
"christ":{"christ","christs"},
"christen":{"christen","christened","christening","christens"},
"christendom":{"christendom","christendoms"},
"christening":{"christening","christenings"},
"christiania":{"christiania","christianias"},
"christianity":{"christianities","christianity"},
"christianize":{"christianize","christianized","christianizing"},
"christmas":{"christmas","christmased","christmases","christmasing"},
"christmasberry":{"christmasberries","christmasberry"},
"christmastide":{"christmastide","christmastides"},
"christmastime":{"christmastime","christmastimes"},
"christology":{"christologies","christology"},
"christopher":{"christopher","christophers"},
"christy":{"christies","christy"},
"chroma":{"chroma","chromas"},
"chromaesthesia":{"chromaesthesia","chromaesthesias"},
"chromaticity":{"chromaticities","chromaticity"},
"chromesthesia":{"chromesthesia","chromesthesias"},
"chromium":{"chromium","chromiums"},
"chromo":{"chromo","chromos"},
"chromonema":{"chromonema","chromonemata"},
"chronicle":{"chronicle","chronicled","chronicles","chronicling"},
"chronicler":{"chronicler","chroniclers"},
"chronology":{"chronologies","chronology"},
"chronoperates":{"chronoperates","chronoperateses"},
"chrysalid":{"chrysalid","chrysalids"},
"chrysalis":{"chrisalides","chrysalides","chrysalis","chrysalises"},
"chrysaora":{"chrysaora","chrysaoras"},
"chrysarobin":{"chrysarobin","chrysarobins"},
"chrysemys":{"chrysemys","chrysemyses"},
"chrysobalanus":{"chrysobalanus","chrysobalanuses"},
"chrysochloridae":{"chrysochloridae","chrysochloridaes"},
"chrysochloris":{"chrysochloris","chrysochlorises"},
"chrysolepis":{"chrysolepis","chrysolepises"},
"chrysolophus":{"chrysolophus","chrysolophuses"},
"chrysomelid":{"chrysomelid","chrysomelids"},
"chrysomelidae":{"chrysomelidae","chrysomelidaes"},
"chrysophrys":{"chrysophrys","chrysophryses"},
"chrysophyceae":{"chrysophyceae","chrysophyceaes"},
"chrysophyllum":{"chrysophyllum","chrysophyllums"},
"chrysophyta":{"chrysophyta","chrysophytas"},
"chrysopid":{"chrysopid","chrysopids"},
"chrysopidae":{"chrysopidae","chrysopidaes"},
"chrysopsis":{"chrysopses","chrysopsis"},
"chrysosplenium":{"chrysosplenium","chrysospleniums"},
"chrysothamnus":{"chrysothamnus","chrysothamnuses"},
"chub":{"chub","chubs"},
"chubbiness":{"chubbiness","chubbinesses"},
"chubby":{"chubbier","chubbiest","chubby"},
"chuck":{"chuck","chucked","chucking","chucks"},
"chucker-out":{"chucker-out","chucker-outs"},
"chuckhole":{"chuckhole","chuckholes"},
"chuckle":{"chuckle","chuckled","chuckles","chuckling"},
"chuckwalla":{"chuckwalla","chuckwallas"},
"chufa":{"chufa","chufas"},
"chuffy":{"chuffier","chuffiest","chuffy"},
"chug":{"chug","chugged","chugging","chugs"},
"chug-a-lug":{"chug-a-lug","chug-a-lugged","chug-a-lugging"},
"chum":{"chum","chummed","chumming","chums"},
"chumminess":{"chumminess","chumminesses"},
"chummy":{"chummier","chummiest","chummy"},
"chump":{"chump","chumps"},
"chunga":{"chunga","chungas"},
"chunk":{"chunk","chunked","chunking","chunks"},
"chunky":{"chunkier","chunkiest","chunky"},
"chunnel":{"chunnel","chunnels"},
"church":{"church","churched","churches","churching"},
"churchgoer":{"churchgoer","churchgoers"},
"churchill":{"churchill","churchills"},
"churchman":{"churchman","churchmen"},
"churchwoman":{"churchwoman","churchwomen"},
"churchy":{"churchier","churchiest","churchy"},
"churchyard":{"churchyard","churchyards"},
"churinga":{"churinga","churingas"},
"churl":{"churl","churls"},
"churn":{"churn","churned","churning","churns"},
"churr":{"churr","churred","churring","churrs"},
"chute":{"chute","chutes"},
"chute-the-chute":{"chute-the-chute","chute-the-chutes"},
"chutney":{"chutney","chutneys"},
"chutzpah":{"chutzpah","chutzpahs"},
"chuvash":{"chuvash","chuvashes"},
"chyloderma":{"chyloderma","chylodermas"},
"chymosin":{"chymosin","chymosins"},
"chytridiaceae":{"chytridiaceae","chytridiaceaes"},
"chytridiales":{"chytridiales","chytridialeses"},
"chytridiomycetes":{"chytridiomycetes","chytridiomyceteses"},
"ci":{"ci","cis"},
"cia":{"cia","cias"},
"ciao":{"ciao","ciaos"},
"ciborium":{"ciboria","ciborium"},
"cibotium":{"cibotium","cibotiums"},
"cicada":{"cicada","cicadae","cicadas"},
"cicadellidae":{"cicadellidae","cicadellidaes"},
"cicadidae":{"cicadidae","cicadidaes"},
"cicala":{"cicala","cicalas"},
"cicatrice":{"cicatrice","cicatrices"},
"cicatrix":{"cicatrices","cicatrix"},
"cicely":{"cicelies","cicely"},
"cicer":{"cicer","cicers"},
"cicero":{"cicero","ciceros"},
"cicerone":{"cicerone","cicerones","ciceroni"},
"cichlid":{"cichlid","cichlids"},
"cichlidae":{"cichlidae","cichlidaes"},
"cichorium":{"cichorium","cichoriums"},
"cicindelidae":{"cicindelidae","cicindelidaes"},
"cicisbeo":{"cicisbei","cicisbeo"},
"ciconia":{"ciconia","ciconias"},
"ciconiidae":{"ciconiidae","ciconiidaes"},
"ciconiiformes":{"ciconiiformes","ciconiiformeses"},
"cicuta":{"cicuta","cicutas"},
"cider":{"cider","ciders"},
"cig":{"cig","cigs"},
"cigar":{"cigar","cigars"},
"cigaret":{"cigaret","cigarets"},
"cigarette":{"cigarette","cigarettes"},
"cigarfish":{"cigarfish","cigarfishes"},
"cigarillo":{"cigarillo","cigarillos"},
"ciggy":{"ciggies","ciggy"},
"cilantro":{"cilantro","cilantros"},
"cilia":{"cilia"},
"ciliata":{"ciliata","ciliatas"},
"ciliate":{"ciliate","ciliates"},
"cilioflagellata":{"cilioflagellata","cilioflagellatas"},
"ciliophora":{"ciliophora","ciliophoras"},
"ciliophoran":{"ciliophoran","ciliophorans"},
"cilium":{"cilia","cilium","ciliums"},
"cimabue":{"cimabue","cimabues"},
"cimarron":{"cimarron","cimarrons"},
"cimetidine":{"cimetidine","cimetidines"},
"cimex":{"cimex","cimexes","cimices"},
"cimicidae":{"cimicidae","cimicidaes"},
"cimicifuga":{"cimicifuga","cimicifugas"},
"cinch":{"cinch","cinched","cinches","cinching"},
"cinchona":{"cinchona","cinchonas"},
"cinclidae":{"cinclidae","cinclidaes"},
"cinclus":{"cinclus","cincluses"},
"cincture":{"cincture","cinctured","cinctures","cincturing"},
"cinder":{"cinder","cinders"},
"cinderella":{"cinderella","cinderellas"},
"cine":{"cine","cines"},
"cine-camera":{"cine-camera","cine-cameras"},
"cine-film":{"cine-film","cine-films"},
"cinema":{"cinema","cinemas"},
"cinematize":{"cinematize","cinematized","cinematizing"},
"cinematographer":{"cinematographer","cinematographers"},
"cinematography":{"cinematographies","cinematography"},
"cineraria":{"cineraria","cinerarias"},
"cinerarium":{"cineraria","cinerarium"},
"cingulum":{"cingula","cingulum"},
"cinnabar":{"cinnabar","cinnabars"},
"cinnamene":{"cinnamene","cinnamenes"},
"cinnamomum":{"cinnamomum","cinnamomums"},
"cinnamon":{"cinnamon","cinnamons"},
"cinque":{"cinque","cinques"},
"cinquefoil":{"cinquefoil","cinquefoils"},
"cipher":{"cipher","ciphered","ciphering","ciphers"},
"cipro":{"cipro","cipros"},
"ciprofloxacin":{"ciprofloxacin","ciprofloxacins"},
"circaea":{"circaea","circaeas"},
"circaetus":{"circaetus","circaetuses"},
"circle":{"circle","circled","circles","circling"},
"circuit":{"circuit","circuited","circuiting","circuits"},
"circuity":{"circuities","circuity"},
"circular":{"circular","circulars"},
"circularisation":{"circularisation","circularisations"},
"circularity":{"circularities","circularity"},
"circularization":{"circularization","circularizations"},
"circularize":{"circularize","circularized","circularizes","circularizing"},
"circulate":{"circulate","circulated","circulates","circulating"},
"circulation":{"circulation","circulations"},
"circulator":{"circulator","circulators"},
"circumambulate":{"circumambulate","circumambulated","circumambulates","circumambulating"},
"circumcise":{"circumcise","circumcised","circumcising"},
"circumference":{"circumference","circumferences"},
"circumferential":{"circumferential","circumferentials"},
"circumfuse":{"circumfrsed","circumfuse","circumfused","circumfusing"},
"circumlocution":{"circumlocution","circumlocutions"},
"circumnavigate":{"circumnavigate","circumnavigated","circumnavigates","circumnavigating"},
"circumnutate":{"circumnutate","circumnutated","circumnutating"},
"circumrotate":{"circumrotate","circumrotated","circumrotating"},
"circumscribe":{"circumscribe","circumscribed","circumscribes","circumscribing"},
"circumspection":{"circumspection","circumspections"},
"circumstance":{"circumstance","circumstances"},
"circumstances":{"circumstances","circumstanceses"},
"circumstantiate":{"circumstantiate","circumstantiated","circumstantiating"},
"circumvent":{"circumvent","circumvented","circumventing","circumvents"},
"circumvolve":{"circumvolve","circumvolved","circumvolving"},
"circus":{"circus","circuses"},
"cirio":{"cirio","cirios"},
"cirque":{"cirque","cirques"},
"cirrhosis":{"cirrhoses","cirrhosis"},
"cirrhus":{"cirrhus","cirrhuses"},
"cirripedia":{"cirripedia","cirripedias"},
"cirrocumulus":{"cirrocumuli","cirrocumulus","cirrocumuluses"},
"cirrostratus":{"cirrostrati","cirrostratus","cirrostratuses"},
"cirrus":{"cirri","cirrus","cirruses"},
"cirsium":{"cirsium","cirsiums"},
"cis":{"cis","cises"},
"cisc":{"cisc","ciscs"},
"cisco":{"cisco","ciscoes","ciscos"},
"cistaceae":{"cistaceae","cistaceaes"},
"cistercian":{"cistercian","cistercians"},
"cistern":{"cistern","cisterns"},
"cisterna":{"cisterna","cisternas"},
"cistothorus":{"cistothorus","cistothoruses"},
"cistus":{"cistus","cistuses"},
"citadel":{"citadel","citadels"},
"citation":{"citation","citations"},
"cite":{"cite","cited","cites","citing"},
"citellus":{"citellus","citelluses"},
"citharichthys":{"citharichthys","citharichthyses"},
"cither":{"cither","cithers"},
"citify":{"citified","citifies","citify","citifying"},
"citizen":{"citizen","citizens"},
"citizenry":{"citizenries","citizenry"},
"citlaltepetl":{"citlaltepetl","citlaltepetls"},
"citrange":{"citrange","citranges"},
"citrin":{"citrin","citrins"},
"citron":{"citron","citrons"},
"citroncirus":{"citroncirus","citronciruses"},
"citronwood":{"citronwood","citronwoods"},
"citrullus":{"citrullus","citrulluses"},
"citrus":{"citrus","citruses"},
"city":{"cities","city"},
"cive":{"cive","cives"},
"civet":{"civet","civets"},
"civies":{"civies","civieses"},
"civilian":{"civilian","civilians"},
"civility":{"civilities","civility"},
"civilization":{"civilization","civilizations"},
"civilize":{"civilize","civilized","civilizes","civilizing"},
"civvies":{"civvies","civvieses"},
"civvy":{"civies","civvies","civvy"},
"cl":{"cl","cls"},
"clabber":{"clabber","clabbered","clabbering","clabbers"},
"clack":{"clack","clacked","clacking","clacks"},
"clad":{"clad","cladding","clads"},
"cladding":{"cladding","claddings"},
"cladode":{"cladode","cladodes"},
"cladonia":{"cladonia","cladonias"},
"cladoniaceae":{"cladoniaceae","cladoniaceaes"},
"cladophyll":{"cladophyll","cladophylls"},
"cladorhyncus":{"cladorhyncus","cladorhyncuses"},
"cladrastis":{"cladrastis","cladrastises"},
"claforan":{"claforan","claforans"},
"claim":{"claim","claimed","claiming","claims"},
"claimant":{"claimant","claimants"},
"clairvoyance":{"clairvoyance","clairvoyances"},
"clam":{"clam","clammed","clamming","clams"},
"clamatores":{"clamatores","clamatoreses"},
"clamber":{"clamber","clambered","clambering","clambers"},
"clamminess":{"clamminess","clamminesses"},
"clammy":{"clammier","clammiest","clammy"},
"clammyweed":{"clammyweed","clammyweeds"},
"clamor":{"clamor","clamored","clamoring","clamors"},
"clamoring":{"clamoring","clamorings"},
"clamour":{"clamour","clamours"},
"clamouring":{"clamouring","clamourings"},
"clamp":{"clamp","clamped","clamping","clamps"},
"clamshell":{"clamshell","clamshells"},
"clan":{"clan","clans"},
"clang":{"clang","clanged","clanging","clangs"},
"clangor":{"clangor","clangored","clangoring","clangors"},
"clangoring":{"clangoring","clangorings"},
"clangour":{"clangour","clangours"},
"clangula":{"clangula","clangulas"},
"clank":{"clank","clanked","clanking","clanks"},
"clannishness":{"clannishness","clannishnesses"},
"clansman":{"clansman","clansmen"},
"clanswoman":{"clanswoman","clanswomen"},
"clap":{"clap","clapped","clapping","claps"},
"clapboard":{"clapboard","clapboards"},
"clapper":{"clapper","clappers"},
"clappers":{"clappers","clapperses"},
"clapping":{"clapping","clappings"},
"claptrap":{"claptrap","claptraps"},
"claret":{"claret","clarets"},
"clarification":{"clarification","clarifications"},
"clarify":{"clarified","clarifies","clarify","clarifying"},
"clarinetist":{"clarinetist","clarinetists"},
"clarinettist":{"clarinettist","clarinettists"},
"clarino":{"clani","clanos","clarino"},
"clarity":{"clarities","clarity"},
"claro":{"claro","claroes","claros"},
"clary":{"claries","clary"},
"clash":{"clash","clashed","clashes","clashing"},
"clasp":{"clasp","clasped","clasping","clasps"},
"class":{"class","classed","classes","classing"},
"classic":{"classic","classics"},
"classicize":{"classicize","classicized","classicizing"},
"classification":{"classification","classifications"},
"classify":{"classified","classifies","classify","classifying"},
"classmate":{"classmate","classmates"},
"classroom":{"classroom","classrooms"},
"classy":{"classier","classiest","classy"},
"clathraceae":{"clathraceae","clathraceaes"},
"clathrus":{"clathrus","clathruses"},
"clatter":{"clatter","clattered","clattering","clatters"},
"claudication":{"claudication","claudications"},
"clause":{"clause","clauses"},
"clavariaceae":{"clavariaceae","clavariaceaes"},
"clavicembalo":{"clavicembalo","clavicembalos"},
"claviceps":{"claviceps","clavicepses"},
"clavicipitaceae":{"clavicipitaceae","clavicipitaceaes"},
"clavicle":{"clavicle","clavicles"},
"clavier":{"clavier","claviers"},
"clavus":{"clavus","clavuses"},
"claw":{"claw","clawed","clawing","claws"},
"clawfoot":{"clawfeet","clawfoot"},
"clawhammer":{"clawhammer","clawhammers"},
"claxon":{"claxon","claxons"},
"clay":{"clay","clays"},
"clayey":{"clayey","clayier","clayiest"},
"claytonia":{"claytonia","claytonias"},
"clayware":{"clayware","claywares"},
"clean":{"clean","cleaned","cleaner","cleanest","cleaning","cleans"},
"cleaner":{"cleaner","cleaners"},
"cleaners":{"cleaners","cleanerses"},
"cleaning":{"cleaning","cleanings"},
"cleanly":{"cleanlier","cleanliest","cleanly"},
"cleanse":{"cleanse","cleansed","cleanses","cleansing"},
"cleanser":{"cleanser","cleansers"},
"cleansing":{"cleansing","cleansings"},
"cleanup":{"cleanup","cleanups"},
"clear":{"clear","cleared","clearer","clearest","clearing","clears"},
"clearance":{"clearance","clearances"},
"clearcutness":{"clearcutness","clearcutnesses"},
"clearing":{"clearing","clearings"},
"clearinghouse":{"clearinghouse","clearinghouses"},
"clearness":{"clearness","clearnesses"},
"clearstory":{"clearstories","clearstory"},
"clearweed":{"clearweed","clearweeds"},
"cleat":{"cleat","cleated","cleating","cleats"},
"cleavage":{"cleavage","cleavages"},
"cleave":{"cleave","cleaved","cleaves","cleaving","cleft","clove","cloven"},
"cleaver":{"cleaver","cleavers"},
"cleavers":{"cleavers","cleaverses"},
"cleft":{"cleft","clefts"},
"cleg":{"cleg","clegs"},
"clegg":{"clegg","cleggs"},
"cleistes":{"cleistes","cleisteses"},
"cleistocarp":{"cleistocarp","cleistocarps"},
"cleistothecium":{"cleistothecium","cleistotheciums"},
"clem":{"clem","clemmed","clemming","clems"},
"clemency":{"clemencies","clemency"},
"clementine":{"clementine","clementines"},
"clench":{"clench","clenched","clenches","clenching"},
"cleome":{"cleome","cleomes"},
"clepe":{"clepe","cleped","clepes","cleping","clept","ycleped","yclept"},
"clepsydra":{"clepsydra","clepsydrae","clepsydras"},
"clerestory":{"clerestories","clerestory"},
"clergy":{"clergies","clergy"},
"clergyman":{"clergyman","clergymen"},
"clergywoman":{"clergywoman","clergywomen"},
"cleric":{"cleric","clerics"},
"clerical":{"clerical","clericals"},
"clerid":{"clerid","clerids"},
"cleridae":{"cleridae","cleridaes"},
"clerisy":{"clerisies","clerisy"},
"clerk":{"clerk","clerked","clerking","clerks"},
"clerking":{"clerking","clerkings"},
"clerkly":{"clerklier","clerkliest","clerkly"},
"cleruchy":{"cleruchies","cleruchy"},
"clethra":{"clethra","clethras"},
"clethraceae":{"clethraceae","clethraceaes"},
"clethrionomys":{"clethrionomys","clethrionomyses"},
"cleveland":{"cleveland","clevelands"},
"clever":{"clever","cleverer","cleverest"},
"cleverness":{"cleverness","clevernesses"},
"clew":{"clew","clewed","clewing","clews"},
"cli":{"cli","clis"},
"clianthus":{"clianthus","clianthuses"},
"cliche":{"cliche","cliches"},
"click":{"click","clicked","clicking","clicks"},
"clickety-clack":{"clickety-clack","clickety-clacks"},
"clickety-click":{"clickety-click","clickety-clicks"},
"client":{"client","clients"},
"clientele":{"clientele","clienteles"},
"cliff":{"cliff","cliffs"},
"cliffbrake":{"cliffbrake","cliffbrakes"},
"cliftonia":{"cliftonia","cliftonias"},
"climacteric":{"climacteric","climacterics"},
"climate":{"climate","climates"},
"climax":{"climax","climaxed","climaxes","climaxing"},
"climb":{"climb","climbed","climbing","climbs"},
"climb-down":{"climb-down","climb-downs"},
"climber":{"climber","climbers"},
"climbing":{"climbing","climbings"},
"clime":{"clime","climes"},
"clinandrium":{"clinandria","clinandrium"},
"clinch":{"clinch","clinched","clinches","clinching"},
"clincher":{"clincher","clinchers"},
"cling":{"cling","clinging","clings","clung"},
"clingfish":{"clingfish","clingfishes"},
"clingstone":{"clingstone","clingstones"},
"clingy":{"clingier","clingiest","clingy"},
"clinic":{"clinic","clinics"},
"clinid":{"clinid","clinids"},
"clinidae":{"clinidae","clinidaes"},
"clink":{"clink","clinked","clinking","clinks"},
"clinker":{"clinker","clinkers"},
"clinocephalism":{"clinocephalism","clinocephalisms"},
"clinocephaly":{"clinocephalies","clinocephaly"},
"clinometer":{"clinometer","clinometers"},
"clinopodium":{"clinopodium","clinopodiums"},
"clinoril":{"clinoril","clinorils"},
"clinton":{"clinton","clintons"},
"clintonia":{"clintonia","clintonias"},
"clip":{"clip","clipped","clipping","clips"},
"clipper":{"clipper","clippers"},
"clippers":{"clippers","clipperses"},
"clipping":{"clipping","clippings"},
"clique":{"clique","cliqued","cliques","cliquing"},
"cliquishness":{"cliquishness","cliquishnesses"},
"clit":{"clit","clits"},
"clitellum":{"clitella","clitellum"},
"clitocybe":{"clitocybe","clitocybes"},
"clitoria":{"clitoria","clitorias"},
"clitoris":{"clitores","clitoris","clitorises"},
"clivers":{"clivers","cliverses"},
"cloaca":{"cloaca","cloacas"},
"cloak":{"cloak","cloaked","cloaking","cloaks"},
"cloakmaker":{"cloakmaker","cloakmakers"},
"cloakroom":{"cloakroom","cloakrooms"},
"clobber":{"clobber","clobbered","clobbering","clobbers"},
"clock":{"clock","clocked","clocking","clocks"},
"clockmaker":{"clockmaker","clockmakers"},
"clocks":{"clocks","clockses"},
"clocksmith":{"clocksmith","clocksmiths"},
"clod":{"clod","clods"},
"clodhopper":{"clodhopper","clodhoppers"},
"clofibrate":{"clofibrate","clofibrates"},
"clog":{"clog","clogged","clogging","clogs"},
"cloggy":{"cloggier","cloggiest","cloggy"},
"cloister":{"cloister","cloistered","cloistering","cloisters"},
"clomid":{"clomid","clomids"},
"clomiphene":{"clomiphene","clomiphenes"},
"clomp":{"clomp","clomped","clomping","clomps"},
"clon":{"clon","clons"},
"clone":{"clone","clones"},
"clonidine":{"clonidine","clonidines"},
"clonus":{"clonus","clonuses"},
"clop":{"clop","clopped","clopping","clops"},
"close":{"close","closed","closer","closes","closest","closing"},
"close-up":{"close-up","close-ups"},
"closedown":{"closedown","closedowns"},
"closeness":{"closeness","closenesses"},
"closeout":{"closeout","closeouts"},
"closet":{"closet","closeted","closeting","closets"},
"closing":{"closing","closings"},
"clostridia":{"clostridia","clostridias"},
"clostridium":{"clostridium","clostridiums"},
"closure":{"closure","closured","closures","closuring"},
"clot":{"clot","clots","clotted","clotting"},
"clotbur":{"clotbur","clotburs"},
"cloth":{"cloth","cloths"},
"clothe":{"clad","clothe","clothed","clothes","clothing"},
"clotheshorse":{"clotheshorse","clotheshorses"},
"clothespin":{"clothespin","clothespins"},
"clothespress":{"clothespress","clothespresses"},
"clothier":{"clothier","clothiers"},
"clothing":{"clothing","clothings"},
"clotting":{"clotting","clottings"},
"cloture":{"cloture","clotures"},
"cloud":{"cloud","clouded","clouding","clouds"},
"cloudberry":{"cloudberries","cloudberry"},
"cloudburst":{"cloudburst","cloudbursts"},
"cloudiness":{"cloudiness","cloudinesses"},
"clouding":{"clouding","cloudings"},
"cloudy":{"cloudier","cloudiest","cloudy"},
"clout":{"clout","clouted","clouting","clouts"},
"clove":{"clove","cloves"},
"clover":{"clover","clovers"},
"cloverleaf":{"cloverleaf","cloverleafs","cloverleaves"},
"cloveroot":{"cloveroot","cloveroots"},
"clovis":{"clovis","clovises"},
"clown":{"clown","clowned","clowning","clowns"},
"clowning":{"clowning","clownings"},
"cloy":{"cloy","cloyed","cloying","cloys"},
"club":{"club","clubbed","clubbing","clubs"},
"clubby":{"clubbier","clubbiest","clubby"},
"clubfoot":{"clubfeet","clubfoot"},
"clubhead":{"clubhead","clubheads"},
"clubhouse":{"clubhouse","clubhouses"},
"clubman":{"clubman","clubmen"},
"clubmoss":{"clubmoss","clubmosses"},
"clubwoman":{"clubwoman","clubwomen"},
"cluck":{"cluck","clucked","clucking","clucks"},
"clue":{"clue","clued","clues","cluing"},
"clumber":{"clumber","clumbers"},
"clump":{"clump","clumped","clumping","clumps"},
"clumsiness":{"clumsiness","clumsinesses"},
"clumsy":{"clumsier","clumsiest","clumsy"},
"clunk":{"clunk","clunks"},
"clupea":{"clupea","clupeas"},
"clupeid":{"clupeid","clupeids"},
"clupeidae":{"clupeidae","clupeidaes"},
"clusiaceae":{"clusiaceae","clusiaceaes"},
"cluster":{"cluster","clustered","clustering","clusters"},
"clutch":{"clutch","clutched","clutches","clutching"},
"clutches":{"clutches","clutcheses"},
"clutter":{"clutter","cluttered","cluttering","clutters"},
"clypeus":{"clypei","clypeus"},
"clyster":{"clyster","clysters"},
"cm":{"cm","cms"},
"cnemidophorus":{"cnemidophorus","cnemidophoruses"},
"cnicus":{"cnicus","cnicuses"},
"cnidaria":{"cnidaria","cnidarias"},
"cnidarian":{"cnidarian","cnidarians"},
"cnidoscolus":{"cnidoscolus","cnidoscoluses"},
"cnidosporidia":{"cnidosporidia","cnidosporidias"},
"cns":{"cns","cnses"},
"co":{"co","cos"},
"co-ed":{"co-ed","co-eds"},
"co-occurrence":{"co-occurrence","co-occurrences"},
"co-op":{"co-op","co-ops"},
"co-opt":{"co-opt","co-opted","co-opting"},
"co-optation":{"co-optation","co-optations"},
"co-option":{"co-option","co-options"},
"co-star":{"co-star","co-starred","co-starring","co-stars"},
"co-worker":{"co-worker","co-workers"},
"coach":{"coach","coached","coaches","coaching"},
"coach-and-four":{"coach-and-four","coach-and-fours"},
"coaching":{"coaching","coachings"},
"coachman":{"coachman","coachmen"},
"coachwhip":{"coachwhip","coachwhips"},
"coact":{"coact","coacted","coacting"},
"coaction":{"coaction","coactions"},
"coagulate":{"coagulate","coagulated","coagulates","coagulating"},
"coagulation":{"coagulation","coagulations"},
"coagulum":{"coagula","coagulum","coagulums"},
"coal":{"coal","coaled","coaling","coals"},
"coalbin":{"coalbin","coalbins"},
"coalesce":{"coalesce","coalesced","coalesces","coalescing"},
"coalescence":{"coalescence","coalescences"},
"coalescency":{"coalescencies","coalescency"},
"coalfish":{"coalfish","coalfishes"},
"coalhole":{"coalhole","coalholes"},
"coalition":{"coalition","coalitions"},
"coalmine":{"coalmine","coalmines"},
"coalpit":{"coalpit","coalpits"},
"coarse":{"coarse","coarser","coarsest"},
"coarsen":{"coarsen","coarsened","coarsening"},
"coarseness":{"coarseness","coarsenesses"},
"coarsening":{"coarsening","coarsenings"},
"coast":{"coast","coasted","coasting","coasts"},
"coat":{"coat","coated","coating","coats"},
"coati":{"coati","coatis"},
"coati-mondi":{"coati-mondi","coati-mondis"},
"coati-mundi":{"coati-mundi","coati-mundis"},
"coating":{"coating","coatings"},
"coatrack":{"coatrack","coatracks"},
"coatroom":{"coatroom","coatrooms"},
"coattails":{"coattails","coattailses"},
"coauthor":{"coauthor","coauthors"},
"coax":{"coax","coaxed","coaxes","coaxing"},
"coaxing":{"coaxing","coaxings"},
"cob":{"cob","cobs"},
"cobalamin":{"cobalamin","cobalamins"},
"cobalt":{"cobalt","cobalts"},
"cobble":{"cobble","cobbled","cobbles","cobbling"},
"cobbler":{"cobbler","cobblers"},
"cobblestone":{"cobblestone","cobblestones"},
"cobbling":{"cobbling","cobblings"},
"cobia":{"cobia","cobias"},
"cobitidae":{"cobitidae","cobitidaes"},
"cobnut":{"cobnut","cobnuts"},
"cobra":{"cobra","cobras"},
"cobweb":{"cobweb","cobwebbed","cobwebbing","cobwebs"},
"coca":{"coca","cocas"},
"cocain":{"cocain","cocains"},
"cocaine":{"cocaine","cocaines"},
"cocci":{"cocci","coccis"},
"coccidae":{"coccidae","coccidaes"},
"coccidia":{"coccidia","coccidias"},
"coccidioidomycosis":{"coccidioidomycoses","coccidioidomycosis"},
"coccidiomycosis":{"coccidiomycoses","coccidiomycosis"},
"coccidium":{"coccidium","coccidiums"},
"coccinellidae":{"coccinellidae","coccinellidaes"},
"coccoidea":{"coccoidea","coccoideas"},
"coccothraustes":{"coccothraustes","coccothrausteses"},
"cocculus":{"cocculus","cocculuses"},
"coccus":{"cocci","coccus","coccuses"},
"coccyx":{"coccyges","coccyx","coccyxes"},
"coccyzus":{"coccyzus","coccyzuses"},
"cochin":{"cochin","cochins"},
"cochineal":{"cochineal","cochineals"},
"cochlea":{"cochlea","cochleae","cochleas"},
"cochlearia":{"cochlearia","cochlearias"},
"cochlearius":{"cochlearius","cochleariuses"},
"cock":{"cock","cocked","cocking","cocks"},
"cock-a-leekie":{"cock-a-leekie","cock-a-leekies"},
"cockateel":{"cockateel","cockateels"},
"cockatiel":{"cockatiel","cockatiels"},
"cockatoo":{"cockatoo","cockatoos"},
"cockchafer":{"cockchafer","cockchafers"},
"cockcrow":{"cockcrow","cockcrows"},
"cocker":{"cocker","cockered","cockering","cockers"},
"cockeye":{"cockeye","cockeyes"},
"cockhorse":{"cockhorse","cockhorses"},
"cockiness":{"cockiness","cockinesses"},
"cockle":{"cockle","cockled","cockles","cockling"},
"cocklebur":{"cocklebur","cockleburs"},
"cockleburr":{"cockleburr","cockleburrs"},
"cockney":{"cockney","cockneys"},
"cockneyfy":{"cockneyfied","cockneyfies","cockneyfy","cockneyfying"},
"cockpit":{"cockpit","cockpits"},
"cockroach":{"cockroach","cockroaches"},
"cockscomb":{"cockscomb","cockscombs"},
"cocksfoot":{"cocksfeet","cocksfoot","cocksfoots"},
"cockshy":{"cockshies","cockshy"},
"cockspur":{"cockspur","cockspurs"},
"cocksucker":{"cocksucker","cocksuckers"},
"cocksureness":{"cocksureness","cocksurenesses"},
"cocktail":{"cocktail","cocktails"},
"cockup":{"cockup","cockups"},
"cocky":{"cockier","cockiest","cocky"},
"cocky-leeky":{"cocky-leekies","cocky-leeky"},
"coco":{"coco","cocos"},
"cocoa":{"cocoa","cocoas"},
"cocoanut":{"cocoanut","cocoanuts"},
"cocobolo":{"cocobolo","cocobolos"},
"coconspirator":{"coconspirator","coconspirators"},
"coconut":{"coconut","coconuts"},
"cocoon":{"cocoon","cocooned","cocooning","cocoons"},
"cocopa":{"cocopa","cocopas"},
"cocopah":{"cocopah","cocopahs"},
"cocos":{"cocos","cocoses"},
"cocoswood":{"cocoswood","cocoswoods"},
"cocotte":{"cocotte","cocottes"},
"cocoyam":{"cocoyam","cocoyams"},
"cocozelle":{"cocozelle","cocozelles"},
"cocuswood":{"cocuswood","cocuswoods"},
"cocytus":{"cocytus","cocytuses"},
"cod":{"cod","codded","codding","cods"},
"coda":{"coda","codas"},
"codariocalyx":{"codariocalyx","codariocalyxes"},
"coddle":{"coddle","coddled","coddles","coddling"},
"code":{"code","coded","codes","coding"},
"codex":{"codex","codices"},
"codfish":{"codfish","codfishes"},
"codger":{"codger","codgers"},
"codiaeum":{"codiaeum","codiaeums"},
"codification":{"codification","codifications"},
"codify":{"codified","codifies","codify","codifying"},
"codlins-and-cream":{"codlins-and-cream","codlins-and-creams"},
"coelacanth":{"coelacanth","coelacanths"},
"coelenterata":{"coelenterata","coelenteratas"},
"coelenterate":{"coelenterate","coelenterates"},
"coelenteron":{"coelentera","coelenteron"},
"coeloglossum":{"coeloglossum","coeloglossums"},
"coelom":{"coelom","coelomata","coeloms"},
"coenobite":{"coenobite","coenobites"},
"coenurus":{"coenuri","coenurus"},
"coerce":{"coerce","coerced","coerces","coercing"},
"coercion":{"coercion","coercions"},
"coereba":{"coereba","coerebas"},
"coerebidae":{"coerebidae","coerebidaes"},
"coeval":{"coeval","coevals"},
"coevals":{"coevals","coevalses"},
"coexist":{"coexist","coexisted","coexisting"},
"coextend":{"coextend","coextended","coextending"},
"coffea":{"coffea","coffeas"},
"coffee":{"coffee","coffees"},
"coffeeberry":{"coffeeberries","coffeeberry"},
"coffeecake":{"coffeecake","coffeecakes"},
"coffeehouse":{"coffeehouse","coffeehouses"},
"coffer":{"coffer","coffered","coffering","coffers"},
"cofferdam":{"cofferdam","cofferdams"},
"coffin":{"coffin","coffined","coffining","coffins"},
"cog":{"cog","cogged","cogging","cogs"},
"cogency":{"cogencies","cogency"},
"cogitate":{"cogitate","cogitated","cogitates","cogitating"},
"cogitation":{"cogitation","cogitations"},
"cognate":{"cognate","cognates"},
"cognation":{"cognation","cognations"},
"cognition":{"cognition","cognitions"},
"cognizance":{"cognizance","cognizances"},
"cognize":{"cognize","cognized","cognizes","cognizing"},
"cognomen":{"cognomen","cognomens"},
"cognoscente":{"cognoscente","cognoscenti"},
"cognoscenti":{"cognoscenti","cognoscentis"},
"cogwheel":{"cogwheel","cogwheels"},
"cohabit":{"cohabit","cohabited","cohabiting","cohabits"},
"cohabitation":{"cohabitation","cohabitations"},
"cohere":{"cohere","cohered","coheres","cohering"},
"coherence":{"coherence","coherences"},
"coherency":{"coherencies","coherency"},
"coherer":{"coherer","coherers"},
"cohesion":{"cohesion","cohesions"},
"cohesiveness":{"cohesiveness","cohesivenesses"},
"coho":{"coho","cohos"},
"cohoe":{"cohoe","cohoes"},
"cohosh":{"cohosh","cohoshes"},
"cohune":{"cohune","cohunes"},
"coif":{"coif","coifed","coiffed","coiffing","coifing","coifs"},
"coiffeur":{"coiffeur","coiffeurs"},
"coiffure":{"coiffure","coiffured","coiffures","coiffuring"},
"coign":{"coign","coigns"},
"coigne":{"coigne","coignes"},
"coigue":{"coigue","coigues"},
"coil":{"coil","coiled","coiling","coils"},
"coin":{"coin","coined","coining","coins"},
"coinage":{"coinage","coinages"},
"coincide":{"coincide","coincided","coincides","coinciding"},
"coincidence":{"coincidence","coincidences"},
"coinsure":{"coinsure","coinsured","coinsuring"},
"coition":{"coition","coitions"},
"coitus":{"coitus","coituses"},
"coke":{"coke","coked","cokes","coking"},
"col":{"col","cols"},
"cola":{"cola","colas"},
"colander":{"colander","colanders"},
"colaptes":{"colaptes","colapteses"},
"colbert":{"colbert","colberts"},
"colchicaceae":{"colchicaceae","colchicaceaes"},
"colchicum":{"colchicum","colchicums"},
"cold":{"cold","colder","coldest","colds"},
"cold-shoulder":{"cold-shoulder","cold-shouldered","cold-shouldering","cold-shoulders"},
"coldheartedness":{"coldheartedness","coldheartednesses"},
"coldness":{"coldness","coldnesses"},
"cole":{"cole","coles"},
"colectomy":{"colectomies","colectomy"},
"coleonyx":{"coleonyx","coleonyxes"},
"coleoptera":{"coleoptera","coleopteras"},
"coleorhiza":{"coleorhiza","coleorhizae"},
"coleridge":{"coleridge","coleridges"},
"coleslaw":{"coleslaw","coleslaws"},
"coleus":{"coleus","coleuses"},
"colewort":{"colewort","coleworts"},
"colic":{"colic","colics"},
"colicroot":{"colicroot","colicroots"},
"colima":{"colima","colimas"},
"colinus":{"colinus","colinuses"},
"coliseum":{"coliseum","coliseums"},
"collaborate":{"collaborate","collaborated","collaborates","collaborating"},
"collaboration":{"collaboration","collaborations"},
"collaborationist":{"collaborationist","collaborationists"},
"collaborator":{"collaborator","collaborators"},
"collage":{"collage","collages"},
"collapse":{"collapse","collapsed","collapses","collapsing"},
"collar":{"collar","collared","collaring","collars"},
"collarbone":{"collarbone","collarbones"},
"collards":{"collards","collardses"},
"collate":{"collate","collated","collates","collating"},
"collateral":{"collateral","collaterals"},
"collateralize":{"collateralize","collateralized","collateralizing"},
"collation":{"collation","collations"},
"colleague":{"colleague","colleagued","colleagues","colleaguing"},
"collect":{"collect","collected","collecting","collects"},
"collecting":{"collecting","collectings"},
"collection":{"collection","collections"},
"collective":{"collective","collectives"},
"collectivisation":{"collectivisation","collectivisations"},
"collectivism":{"collectivism","collectivisms"},
"collectivist":{"collectivist","collectivists"},
"collectivity":{"collectivities","collectivity"},
"collectivization":{"collectivization","collectivizations"},
"collectivize":{"collectivize","collectivized","collectivizes","collectivizing"},
"collector":{"collector","collectors"},
"college":{"college","colleges"},
"collegian":{"collegian","collegians"},
"collegium":{"collegigia","collegigiums","collegium"},
"collembola":{"collembola","collembolas"},
"collembolan":{"collembolan","collembolans"},
"collet":{"collet","collets"},
"collide":{"collide","collided","collides","colliding"},
"collie":{"collie","collies"},
"collier":{"collier","colliers"},
"colliery":{"collieries","colliery"},
"colligate":{"colligate","colligated","colligates","colligating"},
"collimate":{"collimate","collimated","collimates","collimating"},
"collins":{"collins","collinses"},
"collinsia":{"collinsia","collinsias"},
"collinsonia":{"collinsonia","collinsonias"},
"collision":{"collision","collisions"},
"collocalia":{"collocalia","collocalias"},
"collocate":{"collocate","collocated","collocates","collocating"},
"collogue":{"collogue","collogued","collogues","colloguing"},
"colloquialism":{"colloquialism","colloquialisms"},
"colloquium":{"colloquia","colloquium","colloquiums"},
"colloquy":{"colloquies","colloquy"},
"collotype":{"collotype","collotypes"},
"collude":{"collude","colluded","colludes","colluding"},
"collusion":{"collusion","collusions"},
"colluvium":{"colluvia","colluvium","colluviums"},
"colly":{"collied","collier","colliest","colly","collying"},
"collyrium":{"collyria","collyrium","collyriums"},
"colobus":{"colobus","colobuses"},
"colocasia":{"colocasia","colocasias"},
"cologne":{"cologne","colognes"},
"colombo":{"colombo","colombos"},
"colon":{"cola","colon","colons"},
"colonial":{"colonial","colonials"},
"colonic":{"colonic","colonics"},
"colonisation":{"colonisation","colonisations"},
"colonist":{"colonist","colonists"},
"colonization":{"colonization","colonizations"},
"colonize":{"colonize","colonized","colonizing"},
"colonizer":{"colonizer","colonizers"},
"colonnade":{"colonnade","colonnades"},
"colony":{"colonies","colony"},
"color":{"color","colored","coloring","colors"},
"coloradillo":{"coloradillo","coloradillos"},
"colorado":{"colorado","colorados"},
"colorcast":{"colorcast","colorcasting"},
"colored":{"colored","coloreds"},
"colorimeter":{"colorimeter","colorimeters"},
"colorimetry":{"colorimetries","colorimetry"},
"coloring":{"coloring","colorings"},
"colorlessness":{"colorlessness","colorlessnesses"},
"colors":{"colors","colorses"},
"colossus":{"colossi","colossus","colossuses"},
"colostomy":{"colostomies","colostomy"},
"colostrum":{"colostrum","colostrums"},
"colotomy":{"colotomies","colotomy"},
"colour":{"colour","coloured","colouring","colours"},
"coloured":{"coloured","coloureds"},
"colourimeter":{"colourimeter","colourimeters"},
"colouring":{"colouring","colourings"},
"colourman":{"colourman","colourmen"},
"colours":{"colours","colourses"},
"colpocele":{"colpocele","colpoceles"},
"colpocystocele":{"colpocystocele","colpocystoceles"},
"colt":{"colt","colted","colting","colts"},
"colter":{"colter","colters"},
"coltsfoot":{"coltsfoot","coltsfoots"},
"coluber":{"coluber","colubers"},
"colubrid":{"colubrid","colubrids"},
"colubridae":{"colubridae","colubridaes"},
"colubrina":{"colubrina","colubrinas"},
"colugo":{"colugo","colugos"},
"columba":{"columba","columbas"},
"columbarium":{"columbarium","columbariums"},
"columbia":{"columbia","columbias"},
"columbidae":{"columbidae","columbidaes"},
"columbiformes":{"columbiformes","columbiformeses"},
"columbine":{"columbine","columbines"},
"columbite":{"columbite","columbites"},
"columbo":{"columbo","columbos"},
"columbus":{"columbus","columbuses"},
"columella":{"columella","columellae"},
"column":{"column","columns"},
"columnist":{"columnist","columnists"},
"colutea":{"colutea","coluteas"},
"coly":{"colies","coly"},
"colymbiformes":{"colymbiformes","colymbiformeses"},
"colza":{"colza","colzas"},
"coma":{"coma","comas"},
"comanche":{"comanche","comanches"},
"comandra":{"comandra","comandras"},
"comaraderie":{"comaraderie","comaraderies"},
"comatoseness":{"comatoseness","comatosenesses"},
"comatula":{"comatula","comatulae"},
"comatulid":{"comatulid","comatulids"},
"comb":{"comb","combed","combing","combs"},
"comb-out":{"comb-out","comb-outs"},
"combat":{"combat","combated","combating","combats","combatted","combatting"},
"combatant":{"combatant","combatants"},
"combativeness":{"combativeness","combativenesses"},
"combination":{"combination","combinations"},
"combine":{"combine","combined","combines","combining"},
"combing":{"combing","combings"},
"combining":{"combining","combinings"},
"combo":{"combo","combos"},
"combretaceae":{"combretaceae","combretaceaes"},
"combustible":{"combustible","combustibles"},
"combustion":{"combustion","combustions"},
"come":{"came","come","comes","coming"},
"come-on":{"come-on","come-ons"},
"comeback":{"comeback","comebacks"},
"comedian":{"comedian","comedians"},
"comedo":{"comedo","comedones","comedos"},
"comedy":{"comedies","comedy"},
"comeliness":{"comeliness","comelinesses"},
"comely":{"comelier","comeliest","comely"},
"comer":{"comer","comers"},
"comestible":{"comestible","comestibles"},
"comet":{"comet","comets"},
"comfort":{"comfort","comforted","comforting","comforts"},
"comfortable":{"comfortable","comfortables"},
"comfortableness":{"comfortableness","comfortablenesses"},
"comforter":{"comforter","comforters"},
"comforts":{"comforts","comfortses"},
"comfrey":{"comfrey","comfreys"},
"comfy":{"comfier","comfiest","comfy"},
"comic":{"comic","comics"},
"coming":{"coming","comings"},
"comint":{"comint","comints"},
"comity":{"comities","comity"},
"comma":{"comma","commas"},
"command":{"command","commanded","commanding","commands"},
"commandant":{"commandant","commandants"},
"commandeer":{"commandeer","commandeered","commandeering","commandeers"},
"commander":{"commander","commanders"},
"commandment":{"commandment","commandments"},
"commando":{"commando","commandoes","commandos"},
"commelinaceae":{"commelinaceae","commelinaceaes"},
"commelinales":{"commelinales","commelinaleses"},
"commelinidae":{"commelinidae","commelinidaes"},
"commemorate":{"commemorate","commemorated","commemorates","commemorating"},
"commemoration":{"commemoration","commemorations"},
"commence":{"commence","commenced","commences","commencing"},
"commencement":{"commencement","commencements"},
"commend":{"commend","commended","commending","commends"},
"commendation":{"commendation","commendations"},
"commensurateness":{"commensurateness","commensuratenesses"},
"comment":{"comment","commented","commenting","comments"},
"commentary":{"commentaries","commentary"},
"commentate":{"commentate","commentated","commentating"},
"commentator":{"commentator","commentators"},
"commerce":{"commerce","commerces"},
"commercial":{"commercial","commercials"},
"commercialisation":{"commercialisation","commercialisations"},
"commercialism":{"commercialism","commercialisms"},
"commercialization":{"commercialization","commercializations"},
"commercialize":{"commercialize","commercialized","commercializes","commercializing"},
"commie":{"commie","commies"},
"commingle":{"commingle","commingled","commingles","commingling"},
"comminute":{"comminute","comminuted","comminutes","comminuting"},
"commiphora":{"commiphora","commiphoras"},
"commiserate":{"commiserate","commiserated","commiserates","commiserating"},
"commiseration":{"commiseration","commiserations"},
"commissar":{"commissar","commissars"},
"commissariat":{"commissariat","commissariats"},
"commissary":{"commissaries","commissary"},
"commission":{"commission","commissioned","commissioning","commissions"},
"commissioner":{"commissioner","commissioners"},
"commissioning":{"commissioning","commissionings"},
"commit":{"commit","commits","committed","committing"},
"commitedness":{"commitedness","commitednesses"},
"commitment":{"commitment","commitments"},
"committal":{"committal","committals"},
"committee":{"committee","committees"},
"committeeman":{"committeeman","committeemen"},
"commix":{"commix","commixed","commixes","commixing"},
"commixture":{"commixture","commixtures"},
"commo":{"commo","commos"},
"commode":{"commode","commodes"},
"commodiousness":{"commodiousness","commodiousnesses"},
"commodity":{"commodities","commodity"},
"commodore":{"commodore","commodores"},
"common":{"common","commons"},
"commonality":{"commonalities","commonality"},
"commonalty":{"commonalties","commonalty"},
"commoner":{"commoner","commoners"},
"commonness":{"commonness","commonnesses"},
"commonplace":{"commonplace","commonplaces"},
"commonplaceness":{"commonplaceness","commonplacenesses"},
"commons":{"commons","commonses"},
"commonweal":{"commonweal","commonweals"},
"commonwealth":{"commonwealth","commonwealths"},
"commotion":{"commotion","commotions"},
"commove":{"commove","commoved","commoves","commoving"},
"communalize":{"communalize","communalized","communalizes","communalizing"},
"commune":{"commune","communed","communes","communing"},
"communicate":{"communicate","communicated","communicates","communicating"},
"communicating":{"communicating","communicatings"},
"communication":{"communication","communications"},
"communion":{"communion","communions"},
"communique":{"communique","communiques"},
"communisation":{"communisation","communisations"},
"communist":{"communist","communists"},
"community":{"communities","community"},
"communization":{"communization","communizations"},
"communize":{"communize","communized","communizes","communizing"},
"commutability":{"commutabilities","commutability"},
"commutate":{"commutate","commutated","commutating"},
"commutation":{"commutation","commutations"},
"commute":{"commute","commuted","commutes","commuting"},
"commuter":{"commuter","commuters"},
"commuting":{"commuting","commutings"},
"commy":{"commies","commy"},
"comp":{"comp","comps"},
"compact":{"compact","compacted","compacting","compacts"},
"compaction":{"compaction","compactions"},
"compactness":{"compactness","compactnesses"},
"companion":{"companion","companioned","companioning","companions"},
"companionability":{"companionabilities","companionability"},
"companionableness":{"companionableness","companionablenesses"},
"companionship":{"companionship","companionships"},
"company":{"companied","companies","company","companying"},
"comparability":{"comparabilities","comparability"},
"compare":{"compare","compared","compares","comparing"},
"comparing":{"comparing","comparings"},
"comparison":{"comparison","comparisons"},
"compart":{"compart","comparted","comparting"},
"compartment":{"compartment","compartmented","compartmenting","compartments"},
"compartmentalize":{"compartmentalize","compartmentalized","compartmentalizes","compartmentalizing"},
"compass":{"compass","compassed","compasses","compassing"},
"compassion":{"compassion","compassions"},
"compassionate":{"compassionate","compassionated","compassionates","compassionating"},
"compassionateness":{"compassionateness","compassionatenesses"},
"compatibility":{"compatibilities","compatibility"},
"compatriot":{"compatriot","compatriots"},
"compeer":{"compeer","compeers"},
"compel":{"compel","compelled","compelling","compels"},
"compendium":{"compendia","compendium","compendiums"},
"compensate":{"compensate","compensated","compensates","compensating"},
"compensation":{"compensation","compensations"},
"compensator":{"compensator","compensators"},
"compete":{"compete","competed","competes","competing"},
"competence":{"competence","competences"},
"competency":{"competencies","competency"},
"competition":{"competition","competitions"},
"competitiveness":{"competitiveness","competitivenesses"},
"competitor":{"competitor","competitors"},
"compilation":{"compilation","compilations"},
"compile":{"compile","compiled","compiles","compiling"},
"compiler":{"compiler","compilers"},
"compiling":{"compiling","compilings"},
"complacence":{"complacence","complacences"},
"complacency":{"complacencies","complacency"},
"complain":{"complain","complained","complaining","complains"},
"complainant":{"complainant","complainants"},
"complainer":{"complainer","complainers"},
"complaint":{"complaint","complaints"},
"complaisance":{"complaisance","complaisances"},
"complection":{"complection","complections"},
"complement":{"complement","complemented","complementing","complements"},
"complete":{"complete","completed","completes","completing"},
"completion":{"completion","completions"},
"complex":{"complex","complexes"},
"complexion":{"complexion","complexioned","complexioning","complexions"},
"complexity":{"complexities","complexity"},
"complexness":{"complexness","complexnesses"},
"compliance":{"compliance","compliances"},
"compliancy":{"compliancies","compliancy"},
"complicacy":{"complicacies","complicacy"},
"complicate":{"complicate","complicated","complicates","complicating"},
"complicatedness":{"complicatedness","complicatednesses"},
"complicating":{"complicating","complicatings"},
"complication":{"complication","complications"},
"complicity":{"complicities","complicity"},
"compliment":{"compliment","complimented","complimenting","compliments"},
"compliments":{"compliments","complimentses"},
"complin":{"complin","complins"},
"compline":{"compline","complines"},
"complot":{"complot","complots","complotted","complotting"},
"comply":{"complied","complies","comply","complying"},
"compo":{"compo","compos"},
"component":{"component","components"},
"comport":{"comport","comported","comporting","comports"},
"comportment":{"comportment","comportments"},
"compose":{"compose","composed","composes","composing"},
"composer":{"composer","composers"},
"composing":{"composing","composings"},
"compositae":{"compositae","compositaes"},
"composite":{"composite","composites"},
"composition":{"composition","compositions"},
"compositor":{"compositor","compositors"},
"compost":{"compost","composted","composting"},
"composure":{"composure","composures"},
"compote":{"compote","compotes"},
"compound":{"compound","compounded","compounding","compounds"},
"compounding":{"compounding","compoundings"},
"comprehend":{"comprehend","comprehended","comprehending","comprehends"},
"comprehensibility":{"comprehensibilities","comprehensibility"},
"comprehension":{"comprehension","comprehensions"},
"comprehensive":{"comprehensive","comprehensives"},
"comprehensiveness":{"comprehensiveness","comprehensivenesses"},
"compress":{"compress","compressed","compresses","compressing"},
"compressibility":{"compressibilities","compressibility"},
"compressing":{"compressing","compressings"},
"compression":{"compression","compressions"},
"comprimario":{"comprimario","comprimarios"},
"comprise":{"comprise","comprised","comprises","comprising"},
"comprising":{"comprising","comprisings"},
"compromise":{"compromise","compromised","compromises","compromising"},
"comptonia":{"comptonia","comptonias"},
"comptroller":{"comptroller","comptrollers"},
"compulsion":{"compulsion","compulsions"},
"compulsiveness":{"compulsiveness","compulsivenesses"},
"compulsivity":{"compulsivities","compulsivity"},
"compunction":{"compunction","compunctions"},
"computation":{"computation","computations"},
"compute":{"compute","computed","computes","computing"},
"computer":{"computer","computers"},
"computerize":{"computerize","computerized","computerizing"},
"comrade":{"comrade","comrades"},
"comradeliness":{"comradeliness","comradelinesses"},
"comradery":{"comraderies","comradery"},
"comradeship":{"comradeship","comradeships"},
"con":{"con","conned","conning","cons"},
"conacaste":{"conacaste","conacastes"},
"conakry":{"conakries","conakry"},
"concatenate":{"concatenate","concatenated","concatenating"},
"concatenation":{"concatenation","concatenations"},
"concave":{"concave","concaved","concaves","concaving"},
"concaveness":{"concaveness","concavenesses"},
"concavity":{"concavities","concavity"},
"conceal":{"conceal","concealed","concealing","conceals"},
"concealing":{"concealing","concealings"},
"concealment":{"concealment","concealments"},
"concede":{"concede","conceded","concedes","conceding"},
"conceding":{"conceding","concedings"},
"conceit":{"conceit","conceits"},
"conceivability":{"conceivabilities","conceivability"},
"conceivableness":{"conceivableness","conceivablenesses"},
"conceive":{"conceive","conceived","conceives","conceiving"},
"conceiver":{"conceiver","conceivers"},
"concentrate":{"concentrate","concentrated","concentrates","concentrating"},
"concentration":{"concentration","concentrations"},
"concept":{"concept","concepts"},
"conception":{"conception","conceptions"},
"conceptualisation":{"conceptualisation","conceptualisations"},
"conceptuality":{"conceptualities","conceptuality"},
"conceptualization":{"conceptualization","conceptualizations"},
"conceptualize":{"conceptualize","conceptualized","conceptualizes","conceptualizing"},
"conceptus":{"conceptus","conceptuses"},
"concern":{"concern","concerned","concerning","concerns"},
"concert":{"concert","concerted","concerting","concerts"},
"concert-goer":{"concert-goer","concert-goers"},
"concertante":{"concertante","concertanti"},
"concertina":{"concertina","concertinaed","concertinaing","concertinas"},
"concertino":{"concertini","concertino"},
"concertize":{"concertize","concertized","concertizing"},
"concerto":{"concerti","concerto","concertos"},
"concerto_grosso":{"concerti_grossi","concerto_grosso","concerto_grossos"},
"concession":{"concession","concessions"},
"concessionaire":{"concessionaire","concessionaires"},
"concessionary":{"concessionaries","concessionary"},
"concessioner":{"concessioner","concessioners"},
"conch":{"conch","conches","conchs"},
"concha":{"concha","conchae"},
"conchfish":{"conchfish","conchfishes"},
"conchie":{"conchie","conchies"},
"conchology":{"conchologies","conchology"},
"conchy":{"conchies","conchy"},
"concierge":{"concierge","concierges"},
"conciliate":{"conciliate","conciliated","conciliates","conciliating"},
"conciliation":{"conciliation","conciliations"},
"conciliator":{"conciliator","conciliators"},
"concinnity":{"concinnities","concinnity"},
"conciseness":{"conciseness","concisenesses"},
"conclude":{"conclude","concluded","concludes","concluding"},
"conclusion":{"conclusion","conclusions"},
"conclusiveness":{"conclusiveness","conclusivenesses"},
"concoct":{"concoct","concocted","concocting","concocts"},
"concoction":{"concoction","concoctions"},
"concomitant":{"concomitant","concomitants"},
"concord":{"concord","concords"},
"concordance":{"concordance","concordances"},
"concordat":{"concordat","concordats"},
"concourse":{"concourse","concourses"},
"concrete":{"concrete","concreted","concreting"},
"concretion":{"concretion","concretions"},
"concretism":{"concretism","concretisms"},
"concretize":{"concretize","concretized","concretizing"},
"concubine":{"concubine","concubines"},
"concupiscence":{"concupiscence","concupiscences"},
"concur":{"concur","concurred","concurring","concurs"},
"concurrence":{"concurrence","concurrences"},
"concuss":{"concuss","concussed","concussing"},
"concussion":{"concussion","concussions"},
"condemn":{"condemn","condemned","condemning","condemns"},
"condemnation":{"condemnation","condemnations"},
"condensate":{"condensate","condensates"},
"condensation":{"condensation","condensations"},
"condense":{"condense","condensed","condenses","condensing"},
"condenser":{"condenser","condensers"},
"condensing":{"condensing","condensings"},
"condescend":{"condescend","condescended","condescending","condescends"},
"condescension":{"condescension","condescensions"},
"condition":{"condition","conditioned","conditioning","conditions"},
"conditional":{"conditional","conditionals"},
"condo":{"condo","condos"},
"condole":{"condole","condoled","condoling"},
"condolence":{"condolence","condolences"},
"condom":{"condom","condoms"},
"condominium":{"condominium","condominiums"},
"condone":{"condone","condoned","condones","condoning"},
"condor":{"condor","condors"},
"condordance":{"condordance","condordances"},
"condottiere":{"condottiere","condottieri"},
"conduce":{"conduce","conduced","conduces","conducing"},
"conduct":{"conduct","conducted","conducting","conducts"},
"conduction":{"conduction","conductions"},
"conductivity":{"conductivities","conductivity"},
"conductor":{"conductor","conductors"},
"conduit":{"conduit","conduits"},
"condyloma":{"condyloma","condylomas","condylomata"},
"condylura":{"condylura","condyluras"},
"cone":{"cone","coned","cones","coning"},
"conenose":{"conenose","conenoses"},
"conepatus":{"conepatus","conepatuses"},
"conessi":{"conessi","conessis"},
"conestoga":{"conestoga","conestogas"},
"coney":{"coney","coneys"},
"confab":{"confab","confabbed","confabbing","confabs"},
"confabulate":{"confabulate","confabulates","confabulating","confabulted"},
"confabulation":{"confabulation","confabulations"},
"confection":{"confection","confectioned","confectioning","confections"},
"confectionary":{"confectionaries","confectionary"},
"confectioner":{"confectioner","confectioners"},
"confectionery":{"confectioneries","confectionery"},
"confederacy":{"confederacies","confederacy"},
"confederate":{"confederate","confederated","confederates","confederating"},
"confederation":{"confederation","confederations"},
"confer":{"confer","conferred","conferring","confers"},
"conference":{"conference","conferences"},
"conferment":{"conferment","conferments"},
"conferral":{"conferral","conferrals"},
"conferva":{"conferva","confervae","confervas"},
"confess":{"confess","confessed","confesses","confessing"},
"confession":{"confession","confessions"},
"confessor":{"confessor","confessors"},
"confidant":{"confidant","confidants"},
"confide":{"confide","confided","confides","confiding"},
"confidence":{"confidence","confidences"},
"configuration":{"configuration","configurations"},
"configurationism":{"configurationism","configurationisms"},
"confine":{"confine","confined","confines","confining"},
"confinement":{"confinement","confinements"},
"confirm":{"confirm","confirmed","confirming","confirms"},
"confirmation":{"confirmation","confirmations"},
"confiscate":{"confiscate","confiscated","confiscates","confiscating"},
"confiscation":{"confiscation","confiscations"},
"conflagration":{"conflagration","conflagrations"},
"conflate":{"conflate","conflated","conflates","conflating"},
"conflict":{"conflict","conflicted","conflicting","conflicts"},
"confluence":{"confluence","confluences"},
"conflux":{"conflux","confluxes"},
"conform":{"conform","conformed","conforming","conforms"},
"conformance":{"conformance","conformances"},
"conformation":{"conformation","conformations"},
"conformism":{"conformism","conformisms"},
"conformity":{"conformities","conformity"},
"confound":{"confound","confounded","confounding","confounds"},
"confounding":{"confounding","confoundings"},
"confraternity":{"confraternities","confraternity"},
"confrere":{"confrere","confreres"},
"confront":{"confront","confronted","confronting","confronts"},
"confrontation":{"confrontation","confrontations"},
"confronting":{"confronting","confrontings"},
"confucius":{"confucius","confuciuses"},
"confuse":{"confuse","confused","confuses","confusing"},
"confusion":{"confusion","confusions"},
"confute":{"confute","confuted","confutes","confuting"},
"confuting":{"confuting","confutings"},
"conga":{"conga","congaed","congaing","congas"},
"congeal":{"congeal","congealed","congealing","congeals"},
"congee":{"congee","congeed","congeeing","congees"},
"congenator":{"congenator","congenators"},
"congener":{"congener","congeners"},
"congeniality":{"congenialities","congeniality"},
"congenialness":{"congenialness","congenialnesses"},
"conger":{"conger","congers"},
"congeries":{"congeries","congerieses"},
"congest":{"congest","congested","congesting","congests"},
"congestion":{"congestion","congestions"},
"congius":{"congius","congiuses"},
"conglobate":{"conglobate","conglobated","conglobates","conglobating"},
"conglomerate":{"conglomerate","conglomerated","conglomerates","conglomerating"},
"conglomeration":{"conglomeration","conglomerations"},
"conglutinate":{"conglutinate","conglutinated","conglutinates","conglutinating"},
"congo":{"congo","congos"},
"congou":{"congou","congous"},
"congratulate":{"congratulate","congratulated","congratulates","congratulating"},
"congratulation":{"congratulation","congratulations"},
"congratulations":{"congratulations","congratulationses"},
"congregate":{"congregate","congregated","congregates","congregating"},
"congregating":{"congregating","congregatings"},
"congregation":{"congregation","congregations"},
"congress":{"congress","congresses"},
"congress-gaiter":{"congress-gaiter","congress-gaiters"},
"congressman":{"congressman","congressmen"},
"congresswoman":{"congresswoman","congresswomen"},
"congridae":{"congridae","congridaes"},
"congruence":{"congruence","congruences"},
"congruency":{"congruencies","congruency"},
"congruity":{"congruities","congruity"},
"congruousness":{"congruousness","congruousnesses"},
"conic":{"conic","conics"},
"conidiospore":{"conidiospore","conidiospores"},
"conidium":{"conidium","conidiums"},
"conifer":{"conifer","conifers"},
"coniferales":{"coniferales","coniferaleses"},
"coniferophyta":{"coniferophyta","coniferophytas"},
"coniferophytina":{"coniferophytina","coniferophytinas"},
"coniferopsida":{"coniferopsida","coniferopsidas"},
"conilurus":{"conilurus","coniluruses"},
"coniogramme":{"coniogramme","coniogrammes"},
"conium":{"conium","coniums"},
"conjecture":{"conjecture","conjectured","conjectures","conjecturing"},
"conjoin":{"conjoin","conjoined","conjoining","conjoins"},
"conjugate":{"conjugate","conjugated","conjugates","conjugating"},
"conjugation":{"conjugation","conjugations"},
"conjunction":{"conjunction","conjunctions"},
"conjunctiva":{"conjunctiva","conjunctivae","conjunctivas"},
"conjunctive":{"conjunctive","conjunctives"},
"conjunctivitis":{"conjunctivitis","conjunctivitises"},
"conjuration":{"conjuration","conjurations"},
"conjure":{"conjure","conjured","conjures","conjuring"},
"conjurer":{"conjurer","conjurers"},
"conjuring":{"conjuring","conjurings"},
"conjuror":{"conjuror","conjurors"},
"conjury":{"conjuries","conjury"},
"conk":{"conk","conked","conking","conks"},
"conker":{"conker","conkers"},
"conn":{"conn","conned","conning"},
"connaraceae":{"connaraceae","connaraceaes"},
"connarus":{"connarus","connaruses"},
"connect":{"connect","connected","connecting","connects"},
"connectedness":{"connectedness","connectednesses"},
"connecter":{"connecter","connecters"},
"connecticut":{"connecticut","connecticuts"},
"connecting":{"connecting","connectings"},
"connection":{"connection","connections"},
"connective":{"connective","connectives"},
"connector":{"connector","connectors"},
"connexion":{"connexion","connexions"},
"connivance":{"connivance","connivances"},
"connive":{"connive","connived","connives","conniving"},
"connochaetes":{"connochaetes","connochaeteses"},
"connoisseur":{"connoisseur","connoisseurs"},
"connoisseurship":{"connoisseurship","connoisseurships"},
"connotation":{"connotation","connotations"},
"connote":{"connote","connoted","connotes","connoting"},
"conocarpus":{"conocarpus","conocarpuses"},
"conoclinium":{"conoclinium","conocliniums"},
"conodonta":{"conodonta","conodontas"},
"conodontophorida":{"conodontophorida","conodontophoridas"},
"conoid":{"conoid","conoids"},
"conopodium":{"conopodium","conopodiums"},
"conospermum":{"conospermum","conospermums"},
"conquer":{"conquer","conquered","conquering","conquers"},
"conquering":{"conquering","conquerings"},
"conqueror":{"conqueror","conquerors"},
"conquest":{"conquest","conquests"},
"conquistador":{"conquistador","conquistadores","conquistadors"},
"conradina":{"conradina","conradinas"},
"consanguinity":{"consanguinities","consanguinity"},
"conscience":{"conscience","consciences"},
"conscientiousness":{"conscientiousness","conscientiousnesses"},
"consciousness":{"consciousness","consciousnesses"},
"conscribe":{"conscribe","conscribed","conscribing"},
"conscript":{"conscript","conscripted","conscripting","conscripts"},
"conscription":{"conscription","conscriptions"},
"consecrate":{"consecrate","consecrated","consecrates","consecrating"},
"consensus":{"consensus","consensuses"},
"consent":{"consent","consented","consenting","consents"},
"consequence":{"consequence","consequences"},
"consequent":{"consequent","consequents"},
"conservancy":{"conservancies","conservancy"},
"conservation":{"conservation","conservations"},
"conservationist":{"conservationist","conservationists"},
"conservative":{"conservative","conservatives"},
"conservativist":{"conservativist","conservativists"},
"conservatoire":{"conservatoire","conservatoires"},
"conservator":{"conservator","conservators"},
"conservatory":{"conservatories","conservatory"},
"conserve":{"conserve","conserved","conserves","conserving"},
"conserves":{"conserves","conserveses"},
"conserving":{"conserving","conservings"},
"consider":{"consider","considered","considering","considers"},
"considerateness":{"considerateness","consideratenesses"},
"consideration":{"consideration","considerations"},
"consign":{"consign","consigned","consigning","consigns"},
"consigner":{"consigner","consigners"},
"consignment":{"consignment","consignments"},
"consignor":{"consignor","consignors"},
"consist":{"consist","consisted","consisting","consists"},
"consistence":{"consistence","consistences"},
"consistency":{"consistencies","consistency"},
"consistory":{"consistories","consistory"},
"consociate":{"consociate","consociated","consociates","consociating"},
"consolation":{"consolation","consolations"},
"console":{"console","consoled","consoles","consoling"},
"consolida":{"consolida","consolidas"},
"consolidate":{"consolidate","consolidated","consolidating"},
"consolidation":{"consolidation","consolidations"},
"consonance":{"consonance","consonances"},
"consonancy":{"consonancies","consonancy","consonannancies"},
"consonant":{"consonant","consonants"},
"consort":{"consort","consorted","consorting","consorts"},
"consortium":{"consortia","consortium","consortiums"},
"conspectus":{"conspectus","conspectuses"},
"conspicuousness":{"conspicuousness","conspicuousnesses"},
"conspiracy":{"conspiracies","conspiracy"},
"conspirator":{"conspirator","conspirators"},
"conspire":{"conspire","conspired","conspires","conspiring"},
"constable":{"constable","constables"},
"constabulary":{"constabularies","constabulary"},
"constancy":{"constancies","constancy"},
"constant":{"constant","constants"},
"constantan":{"constantan","constantans"},
"constantinople":{"constantinople","constantinoples"},
"constatation":{"constatation","constatations"},
"constellate":{"constellate","constellated","constellates","constellating"},
"constellation":{"constellation","constellations"},
"consternate":{"consternate","consternated","consternates","consternating"},
"consternation":{"consternation","consternations"},
"constipate":{"constipate","constipated","constipates","constipating"},
"constipation":{"constipation","constipations"},
"constituency":{"constituencies","constituency"},
"constituent":{"constituent","constituents"},
"constitute":{"constitute","constituted","constitutes","constituting"},
"constitution":{"constitution","constitutions"},
"constitutional":{"constitutional","constitutionals"},
"constitutionalist":{"constitutionalist","constitutionalists"},
"constrain":{"constrain","constrained","constraining","constrains"},
"constraint":{"constraint","constraints"},
"constrict":{"constrict","constricted","constricting","constricts"},
"constriction":{"constriction","constrictions"},
"constringe":{"constringe","constringed","constringes","constringing"},
"construal":{"construal","construals"},
"construct":{"construct","constructed","constructing","constructs"},
"construction":{"construction","constructions"},
"constructionist":{"constructionist","constructionists"},
"constructor":{"constructor","constructors"},
"construe":{"construe","construed","construes","construing"},
"consubstantiate":{"consubstantiate","consubstantiated","consubstantiates","consubstantiating"},
"consuetudinal":{"consuetudinal","consuetudinals"},
"consuetudinary":{"consuetudinaries","consuetudinary"},
"consul":{"consul","consuls"},
"consult":{"consult","consulted","consulting","consults"},
"consultant":{"consultant","consultants"},
"consultation":{"consultation","consultations"},
"consume":{"consume","consumed","consumes","consuming"},
"consumer":{"consumer","consumers"},
"consummate":{"consummate","consummated","consummates","consummating"},
"consumption":{"consumption","consumptions"},
"consumptive":{"consumptive","consumptives"},
"contact":{"contact","contacted","contacting","contacts"},
"contacting":{"contacting","contactings"},
"contagion":{"contagion","contagions"},
"contagium":{"contagia","contagium"},
"contain":{"contain","contained","containing","contains"},
"container":{"container","containers"},
"containerize":{"containerize","containerized","containerizing"},
"containership":{"containership","containerships"},
"contaminant":{"contaminant","contaminants"},
"contaminate":{"contaminate","contaminated","contaminates","contaminating"},
"contamination":{"contamination","contaminations"},
"contango":{"contango","contangoed","contangoes","contangoing","contangos"},
"conte":{"conte","contes"},
"contemn":{"contemn","contemned","contemning","contemns"},
"contemplate":{"contemplate","contemplated","contemplates","contemplating"},
"contemplation":{"contemplation","contemplations"},
"contemplativeness":{"contemplativeness","contemplativenesses"},
"contemplator":{"contemplator","contemplators"},
"contemporaneity":{"contemporaneities","contemporaneity"},
"contemporaneousness":{"contemporaneousness","contemporaneousnesses"},
"contemporaries":{"contemporaries","contemporarieses"},
"contemporary":{"contemporaries","contemporary"},
"contempt":{"contempt","contempts"},
"contemptibility":{"contemptibilities","contemptibility"},
"contend":{"contend","contended","contending","contends"},
"contender":{"contender","contenders"},
"content":{"content","contented","contenting","contents"},
"contentedness":{"contentedness","contentednesses"},
"contention":{"contention","contentions"},
"contentiousness":{"contentiousness","contentiousnesses"},
"contents":{"contents","contentses"},
"contessa":{"contessa","contesse"},
"contest":{"contest","contested","contesting","contests"},
"contestant":{"contestant","contestants"},
"contestation":{"contestation","contestations"},
"context":{"context","contexts"},
"contiguity":{"contiguities","contiguity"},
"contiguousness":{"contiguousness","contiguousnesses"},
"continence":{"continence","continences"},
"continency":{"continencies","continency"},
"continent":{"continent","continents"},
"continental":{"continental","continentals"},
"contingency":{"contingencies","contingency"},
"contingent":{"contingent","contingents"},
"continuance":{"continuance","continuances"},
"continuant":{"continuant","continuants"},
"continuation":{"continuation","continuations"},
"continue":{"continue","continued","continues","continuing"},
"continuity":{"continuities","continuity"},
"continuo":{"continuo","continuos"},
"continuousness":{"continuousness","continuousnesses"},
"continuum":{"contintinua","contintinuums","continua","continuum"},
"conto":{"conto","contos"},
"contopus":{"contopus","contopuses"},
"contort":{"contort","contorted","contorting","contorts"},
"contortion":{"contortion","contortions"},
"contour":{"contour","contoured","contouring","contours"},
"contra":{"contra","contras"},
"contrabandist":{"contrabandist","contrabandists"},
"contrabass":{"contrabass","contrabasses"},
"contrabassoon":{"contrabassoon","contrabassoons"},
"contraception":{"contraception","contraceptions"},
"contraceptive":{"contraceptive","contraceptives"},
"contract":{"contract","contracted","contracting","contracts"},
"contracting":{"contracting","contractings"},
"contraction":{"contraction","contractions"},
"contractor":{"contractor","contractors"},
"contradict":{"contradict","contradicted","contradicting","contradicts"},
"contradiction":{"contradiction","contradictions"},
"contradictory":{"contradictories","contradictory"},
"contradistinguish":{"contradistinguish","contradistinguished","contradistinguishing"},
"contrafagotto":{"contrafagotto","contrafagottos"},
"contrail":{"contrail","contrails"},
"contraindicate":{"contraindicate","contraindicated","contraindicating"},
"contralto":{"contralto","contraltos"},
"contraption":{"contraption","contraptions"},
"contrariety":{"contrarieties","contrariety"},
"contrariness":{"contrariness","contrarinesses"},
"contrary":{"contraries","contrary"},
"contrast":{"contrast","contrasted","contrasting","contrasts"},
"contravene":{"contravene","contravened","contravenes","contravening"},
"contravention":{"contravention","contraventions"},
"contredanse":{"contredanse","contredansed","contredanses","contredansing"},
"contribute":{"contribute","contributed","contributes","contributing"},
"contribution":{"contribution","contributions"},
"contributor":{"contributor","contributors"},
"contributory":{"contributories","contributory"},
"contriteness":{"contriteness","contritenesses"},
"contrition":{"contrition","contritions"},
"contrivance":{"contrivance","contrivances"},
"contrive":{"contrive","contrived","contrives","contriving"},
"contriver":{"contriver","contrivers"},
"control":{"control","controlled","controlling","controls"},
"controller":{"controller","controllers"},
"controlling":{"controlling","controllings"},
"controversialist":{"controversialist","controversialists"},
"controversy":{"controversies","controversy"},
"controvert":{"controvert","controverted","controverting","controverts"},
"contumacy":{"contumacies","contumacy"},
"contumely":{"contumelies","contumely"},
"contuse":{"contuse","contused","contuses","contusing"},
"contusion":{"contusion","contusions"},
"conundrum":{"conundrum","conundrums"},
"conurbation":{"conurbation","conurbations"},
"conuropsis":{"conuropses","conuropsis"},
"convalesce":{"convalesce","convalesced","convalesces","convalescing"},
"convalescence":{"convalescence","convalescences"},
"convalescent":{"convalescent","convalescents"},
"convallaria":{"convallaria","convallarias"},
"convallariaceae":{"convallariaceae","convallariaceaes"},
"convect":{"convect","convected","convecting"},
"convenance":{"convenance","convenances"},
"convene":{"convene","convened","convenes","convening"},
"convener":{"convener","conveners"},
"convenience":{"convenience","conveniences"},
"conveniences":{"conveniences","convenienceses"},
"convening":{"convening","convenings"},
"convent":{"convent","convents"},
"conventicle":{"conventicle","conventicles"},
"convention":{"convention","conventions"},
"conventionalisation":{"conventionalisation","conventionalisations"},
"conventionalism":{"conventionalism","conventionalisms"},
"conventionality":{"conventionalities","conventionality"},
"conventionalization":{"conventionalization","conventionalizations"},
"conventionalize":{"conventionalize","conventionalized","conventionalizes","conventionalizing"},
"converge":{"converge","converged","converges","converging"},
"convergence":{"convergence","convergences"},
"convergency":{"convergencies","convergency"},
"converging":{"converging","convergings"},
"conversance":{"conversance","conversances"},
"conversancy":{"conversancies","conversancy"},
"conversation":{"conversation","conversations"},
"conversazione":{"conversazione","conversaziozioni"},
"converse":{"converse","conversed","converses","conversing"},
"conversion":{"conversion","conversions"},
"convert":{"convert","converted","converting","converts"},
"converter":{"converter","converters"},
"convertible":{"convertible","convertibles"},
"converting":{"converting","convertings"},
"convertor":{"convertor","convertors"},
"convexity":{"convexities","convexity"},
"convexness":{"convexness","convexnesses"},
"convey":{"convey","conveyed","conveying","conveys"},
"conveyance":{"conveyance","conveyances"},
"conveyancing":{"conveyancing","conveyancings"},
"conveyer":{"conveyer","conveyers"},
"conveying":{"conveying","conveyings"},
"conveyor":{"conveyor","conveyors"},
"convict":{"convict","convicted","convicting","convicts"},
"convictfish":{"convictfish","convictfishes"},
"conviction":{"conviction","convictions"},
"convince":{"convince","convinced","convinces","convincing"},
"conviviality":{"convivialities","conviviality"},
"convocation":{"convocation","convocations"},
"convoke":{"convoke","convoked","convokes","convoking"},
"convolute":{"convolute","convoluted","convolutes","convoluting"},
"convolution":{"convolution","convolutions"},
"convolve":{"convolve","convolved","convolves","convolving"},
"convolvulaceae":{"convolvulaceae","convolvulaceaes"},
"convolvulus":{"convolvuli","convolvulus","convolvuluses"},
"convoy":{"convoy","convoyed","convoying","convoys"},
"convulse":{"convulse","convulsed","convulses","convulsing"},
"convulsion":{"convulsion","convulsions"},
"convulsionary":{"convulsionaries","convulsionary"},
"cony":{"conies","cony"},
"conyza":{"conyza","conyzas"},
"coo":{"coo","cooed","cooing","coos"},
"cooee":{"cooee","cooeed","cooeeing","cooees"},
"cooey":{"cooey","cooeyed","cooeying","cooeys"},
"cook":{"cook","cooked","cooking","cooks"},
"cook-general":{"cook-general","cooks-general"},
"cookbook":{"cookbook","cookbooks"},
"cooker":{"cooker","cookers"},
"cookery":{"cookeries","cookery"},
"cookhouse":{"cookhouse","cookhouses"},
"cookie":{"cookie","cookies"},
"cooking":{"cooking","cookings"},
"cookware":{"cookware","cookwares"},
"cooky":{"cookies","cooky"},
"cool":{"cool","cooled","cooler","coolest","cooling","cools"},
"cooler":{"cooler","coolers"},
"coolidge":{"coolidge","coolidges"},
"coolie":{"coolie","coolies"},
"cooling":{"cooling","coolings"},
"coolness":{"coolness","coolnesses"},
"coolwart":{"coolwart","coolwarts"},
"cooly":{"coolies","cooly"},
"coon":{"coon","coons"},
"coonskin":{"coonskin","coonskins"},
"coontie":{"coontie","coonties"},
"coop":{"coop","cooped","cooping","coops"},
"cooper":{"cooper","coopered","coopering","coopers"},
"cooperate":{"cooperate","cooperated","cooperates","cooperating"},
"cooperation":{"cooperation","cooperations"},
"cooperative":{"cooperative","cooperatives"},
"cooperativeness":{"cooperativeness","cooperativenesses"},
"cooperator":{"cooperator","cooperators"},
"coopery":{"cooperies","coopery"},
"coopts":{"co-opts","coopts"},
"coordinate":{"co-ordinate","co-ordinated","co-ordinates","co-ordinating","coordinate","coordinated","coordinates","coordinating"},
"coordinator":{"coordinator","coordinators"},
"cooter":{"cooter","cooters"},
"cop":{"cop","copped","copping","cops"},
"copaiba":{"copaiba","copaibas"},
"copaline":{"copaline","copalines"},
"copalite":{"copalite","copalites"},
"cope":{"cope","coped","copes","coping"},
"copeck":{"copeck","copecks"},
"copenhagen":{"copenhagen","copenhagens"},
"copepod":{"copepod","copepods"},
"copepoda":{"copepoda","copepodas"},
"copernicia":{"copernicia","copernicias"},
"copernicus":{"copernicus","copernicuses"},
"copier":{"copier","copiers"},
"coping":{"coping","copings"},
"copiousness":{"copiousness","copiousnesses"},
"copolymerize":{"copolymerize","copolymerized","copolymerizes","copolymerizing"},
"copper":{"copper","coppered","coppering","coppers"},
"copperhead":{"copperhead","copperheads"},
"coppice":{"coppice","coppices"},
"coprinaceae":{"coprinaceae","coprinaceaes"},
"coprinus":{"coprinus","coprinuses"},
"copse":{"copse","copses"},
"coptis":{"coptis","coptises"},
"copula":{"copula","copulae","copulas"},
"copulate":{"copulate","copulated","copulates","copulating"},
"copulation":{"copulation","copulations"},
"copulative":{"copulative","copulatives"},
"copy":{"copied","copies","copy","copying"},
"copy-edit":{"copy-edit","copy-edited","copy-editing"},
"copycat":{"copycat","copycats"},
"copyist":{"copyist","copyists"},
"copyread":{"copyread","copyreading","copyreads"},
"copyreader":{"copyreader","copyreaders"},
"copyright":{"copyright","copyrighted","copyrighting","copyrights"},
"coquet":{"coquet","coquets","coquetted","coquetting"},
"coquetry":{"coquetries","coquetry"},
"coquette":{"coquette","coquettes"},
"coquito":{"coquito","coquitos"},
"cora":{"cora","coras"},
"coracan":{"coracan","coracans"},
"coracias":{"coracias","coraciases"},
"coraciidae":{"coraciidae","coraciidaes"},
"coraciiformes":{"coraciiformes","coraciiformeses"},
"coragyps":{"coragyps","coragypses"},
"corakan":{"corakan","corakans"},
"coral":{"coral","corals"},
"coralbells":{"coralbells","coralbellses"},
"coralberry":{"coralberries","coralberry"},
"corallorhiza":{"corallorhiza","corallorhizas"},
"coralroot":{"coralroot","coralroots"},
"coralwood":{"coralwood","coralwoods"},
"coralwort":{"coralwort","coralworts"},
"coranto":{"coranto","corantos"},
"corbel":{"corbel","corbeled","corbeling","corbelled","corbelling","corbels"},
"corbicula":{"corbicula","corbiculae"},
"corbie-step":{"corbie-step","corbie-steps"},
"corbiestep":{"corbiestep","corbiesteps"},
"corbina":{"corbina","corbinas"},
"cord":{"cord","corded","cording","cords"},
"cordaitaceae":{"cordaitaceae","cordaitaceaes"},
"cordaitales":{"cordaitales","cordaitaleses"},
"cordaites":{"cordaites","cordaiteses"},
"cordarone":{"cordarone","cordarones"},
"cordgrass":{"cordgrass","cordgrasses"},
"cordia":{"cordia","cordias"},
"cordial":{"cordial","cordials"},
"cordiality":{"cordialities","cordiality"},
"cordoba":{"cordoba","cordobas"},
"cordon":{"cordon","cordoned","cordoning"},
"cordova":{"cordova","cordovas"},
"cords":{"cords","cordses"},
"corduroy":{"corduroy","corduroys"},
"corduroys":{"corduroys","corduroyses"},
"cordylidae":{"cordylidae","cordylidaes"},
"cordyline":{"cordyline","cordylines"},
"cordylus":{"cordylus","cordyluses"},
"core":{"core","cored","cores","coring"},
"coregonidae":{"coregonidae","coregonidaes"},
"coregonus":{"coregonus","coregonuses"},
"coreid":{"coreid","coreids"},
"coreidae":{"coreidae","coreidaes"},
"coreopsis":{"coreopses","coreopsis"},
"corgard":{"corgard","corgards"},
"corgi":{"corgi","corgis"},
"coriander":{"coriander","corianders"},
"coriandrum":{"coriandrum","coriandrums"},
"coricidin":{"coricidin","coricidins"},
"corinth":{"corinth","corinths"},
"corinthian":{"corinthian","corinthians"},
"corium":{"corium","coriums"},
"corixa":{"corixa","corixas"},
"corixidae":{"corixidae","corixidaes"},
"cork":{"cork","corked","corking","corks"},
"corkscrew":{"corkscrew","corkscrewed","corkscrewing","corkscrews"},
"corkwood":{"corkwood","corkwoods"},
"corky":{"corkier","corkiest","corky"},
"cormorant":{"cormorant","cormorants"},
"corn":{"corn","corned","corning","corns"},
"cornaceae":{"cornaceae","cornaceaes"},
"corncrake":{"corncrake","corncrakes"},
"corncrib":{"corncrib","corncribs"},
"cornea":{"cornea","corneae","corneas"},
"cornel":{"cornel","cornels"},
"cornelian":{"cornelian","cornelians"},
"corner":{"corner","cornered","cornering","corners"},
"cornerstone":{"cornerstone","cornerstones"},
"cornet":{"cornet","cornets"},
"cornet-a-pistons":{"cornet-a-pistons","cornets-a-pistons"},
"cornetcy":{"cornetcies","cornetcy"},
"cornetist":{"cornetist","cornetists"},
"corneum":{"corneum","corneums"},
"cornfield":{"cornfield","cornfields"},
"cornflour":{"cornflour","cornflours"},
"cornflower":{"cornflower","cornflowers"},
"cornhusker":{"cornhusker","cornhuskers"},
"cornhusking":{"cornhusking","cornhuskings"},
"cornice":{"cornice","corniced","cornices","cornicing"},
"cornmeal":{"cornmeal","cornmeals"},
"cornpone":{"cornpone","cornpones"},
"cornsmut":{"cornsmut","cornsmuts"},
"cornstarch":{"cornstarch","cornstarches"},
"cornu":{"cornu","cornua"},
"cornucopia":{"cornucopia","cornucopias"},
"cornus":{"cornus","cornuses"},
"corny":{"cornier","corniest","corny"},
"corody":{"corodies","corody"},
"corolla":{"corolla","corollas"},
"corollary":{"corollaries","corollary"},
"corona":{"corona","coronae","coronas"},
"coronach":{"coronach","coronaches"},
"coronal":{"coronal","coronals"},
"coronary":{"coronaries","coronary"},
"coronation":{"coronation","coronations"},
"coroner":{"coroner","coroners"},
"coronet":{"coronet","coronets"},
"corozo":{"corozo","corozos"},
"corp":{"corp","corps"},
"corporal":{"corporal","corporals"},
"corporation":{"corporation","corporations"},
"corporeality":{"corporealities","corporeality"},
"corposant":{"corposant","corposants"},
"corpse":{"corpse","corpses"},
"corpsman":{"corpsman","corpsmen"},
"corpulence":{"corpulence","corpulences"},
"corpus":{"corpora","corpus","corpuses"},
"corpuscle":{"corpuscle","corpuscles"},
"corrade":{"corrade","corraded","corrades","corrading"},
"corral":{"corral","corralled","corralling","corrals"},
"corrasion":{"corrasion","corrasions"},
"correct":{"correct","corrected","correcting","corrects"},
"correcting":{"correcting","correctings"},
"correction":{"correction","corrections"},
"correctitude":{"correctitude","correctitudes"},
"corrective":{"corrective","correctives"},
"correctness":{"correctness","correctnesses"},
"corregidor":{"corregidor","corregidors"},
"correlate":{"correlate","correlated","correlates","correlating"},
"correlation":{"correlation","correlations"},
"correlative":{"correlative","correlatives"},
"correlativity":{"correlativities","correlativity"},
"correspond":{"correspond","corresponded","corresponding","corresponds"},
"correspondence":{"correspondence","correspondences"},
"correspondent":{"correspondent","correspondents"},
"corrida":{"corrida","corridas"},
"corridor":{"corridor","corridors"},
"corrie":{"corrie","corries"},
"corrigendum":{"corrigenda","corrigendum"},
"corroborate":{"corroborate","corroborated","corroborates","corroborating"},
"corroboration":{"corroboration","corroborations"},
"corroborator":{"corroborator","corroborators"},
"corroboree":{"corroboree","corroborees"},
"corrode":{"corrode","corroded","corrodes","corroding"},
"corrodentia":{"corrodentia","corrodentias"},
"corroding":{"corroding","corrodings"},
"corrody":{"corrodies","corrody"},
"corrosion":{"corrosion","corrosions"},
"corrugate":{"corrugate","corrugated","corrugating"},
"corrupt":{"corrupt","corrupted","corrupting","corrupts"},
"corruption":{"corruption","corruptions"},
"corruptness":{"corruptness","corruptnesses"},
"corruscation":{"corruscation","corruscations"},
"corsage":{"corsage","corsages"},
"corsair":{"corsair","corsairs"},
"corse":{"corse","corses"},
"corselet":{"corselet","corselets"},
"corset":{"corset","corseted","corseting","corsets"},
"corsica":{"corsica","corsicas"},
"corslet":{"corslet","corslets"},
"cortaderia":{"cortaderia","cortaderias"},
"cortege":{"cortege","corteges"},
"cortes":{"cortes","corteses"},
"cortex":{"cortex","cortexes","cortices"},
"cortez":{"cortez","cortezs"},
"corticium":{"corticium","corticiums"},
"corticoid":{"corticoid","corticoids"},
"corticosteroid":{"corticosteroid","corticosteroids"},
"corticotrophin":{"corticotrophin","corticotrophins"},
"corticotropin":{"corticotropin","corticotropins"},
"cortinariaceae":{"cortinariaceae","cortinariaceaes"},
"cortinarius":{"cortinarius","cortinariuses"},
"cortisol":{"cortisol","cortisols"},
"corundom":{"corundom","corundoms"},
"corundum":{"corundum","corundums"},
"coruscate":{"coruscate","coruscated","coruscates","coruscating"},
"corvidae":{"corvidae","corvidaes"},
"corvus":{"corvus","corvuses"},
"coryanthes":{"coryanthes","coryantheses"},
"corybant":{"corybant","corybantes","corybants"},
"corydalidae":{"corydalidae","corydalidaes"},
"corydalis":{"corydalis","corydalises"},
"corydalus":{"corydalus","corydaluses"},
"corylaceae":{"corylaceae","corylaceaes"},
"corylopsis":{"corylopses","corylopsis"},
"corylus":{"corylus","coryluses"},
"corypha":{"corypha","coryphas"},
"coryphaenidae":{"coryphaenidae","coryphaenidaes"},
"coryphaeus":{"coryphaei","coryphaeus"},
"coryphee":{"coryphee","coryphees"},
"corythosaur":{"corythosaur","corythosaurs"},
"corythosaurus":{"corythosaurus","corythosauruses"},
"coryza":{"coryza","coryzas"},
"cos":{"cos","coses"},
"cosey":{"cosey","coseys"},
"cosh":{"cosh","coshed","coshes","coshing"},
"cosher":{"cosher","coshered","coshering"},
"cosign":{"cosign","cosigned","cosigning"},
"cosignatory":{"cosignatories","cosignatory"},
"cosigner":{"cosigner","cosigners"},
"cosiness":{"cosiness","cosinesses"},
"cosmetic":{"cosmetic","cosmetics"},
"cosmetician":{"cosmetician","cosmeticians"},
"cosmeticize":{"cosmeticize","cosmeticized","cosmeticizing"},
"cosmetics":{"cosmetics","cosmeticses"},
"cosmocampus":{"cosmocampus","cosmocampuses"},
"cosmogony":{"cosmogonies","cosmogony"},
"cosmographer":{"cosmographer","cosmographers"},
"cosmographist":{"cosmographist","cosmographists"},
"cosmography":{"cosmographies","cosmography"},
"cosmology":{"cosmologies","cosmology"},
"cosmonaut":{"cosmonaut","cosmonauts"},
"cosmopolitan":{"cosmopolitan","cosmopolitans"},
"cosmopolite":{"cosmopolite","cosmopolites"},
"cosmos":{"cosmos","cosmoses"},
"coss":{"coss","cosses"},
"cosset":{"cosset","cosseted","cosseting","cossets"},
"cost":{"cost","costing","costs"},
"costa":{"costa","costae","costas"},
"costalgia":{"costalgia","costalgias"},
"costar":{"costar","costarred","costarring"},
"costermonger":{"costermonger","costermongers"},
"costia":{"costia","costias"},
"costliness":{"costliness","costlinesses"},
"costly":{"costlier","costliest","costly"},
"costmary":{"costmaries","costmary"},
"costotomy":{"costotomies","costotomy"},
"costume":{"costume","costumed","costumes","costuming"},
"costumier":{"costumier","costumiers"},
"costusroot":{"costusroot","costusroots"},
"cosy":{"cosier","cosies","cosiest","cosy"},
"cot":{"cot","cots","cotted","cotting"},
"cote":{"cote","cotes"},
"coterie":{"coterie","coteries"},
"cothurn":{"cothurn","cothurns"},
"cothurnus":{"cothurni","cothurnus"},
"cotilion":{"cotilion","cotilions"},
"cotillion":{"cotillion","cotillions"},
"cotinga":{"cotinga","cotingas"},
"cotingidae":{"cotingidae","cotingidaes"},
"cotinus":{"cotinus","cotinuses"},
"cotswolds":{"cotswolds","cotswoldses"},
"cotta":{"cotta","cottae"},
"cottage":{"cottage","cottages"},
"cottager":{"cottager","cottagers"},
"cottar":{"cottar","cottars"},
"cotter":{"cotter","cotters"},
"cottidae":{"cottidae","cottidaes"},
"cottier":{"cottier","cottiers"},
"cotton":{"cotton","cottoned","cottoning","cottons"},
"cottonmouth":{"cottonmouth","cottonmouths"},
"cottonseed":{"cottonseed","cottonseeds"},
"cottontail":{"cottontail","cottontails"},
"cottonweed":{"cottonweed","cottonweeds"},
"cottonwick":{"cottonwick","cottonwicks"},
"cottonwood":{"cottonwood","cottonwoods"},
"cottus":{"cottus","cottuses"},
"cotula":{"cotula","cotulas"},
"coturnix":{"coturnices","coturnix","coturnixes"},
"cotyledon":{"cotyledon","cotyledons"},
"couch":{"couch","couched","couches","couching"},
"cougar":{"cougar","cougars"},
"cough":{"cough","coughed","coughing","coughs"},
"coughing":{"coughing","coughings"},
"coulisse":{"coulisse","coulisses"},
"coulomb":{"coulomb","coulombs"},
"coulter":{"coulter","coulters"},
"coumadin":{"coumadin","coumadins"},
"coumarone":{"coumarone","coumarones"},
"coumarouna":{"coumarouna","coumarounas"},
"council":{"council","councils"},
"councillor":{"councillor","councillors"},
"councillorship":{"councillorship","councillorships"},
"councilman":{"councilman","councilmen"},
"councilor":{"councilor","councilors"},
"councilorship":{"councilorship","councilorships"},
"counsel":{"counsel","counseled","counseling","counselled","counselling","counsels"},
"counseling":{"counseling","counselings"},
"counsellor":{"counsellor","counsellors"},
"counsellorship":{"counsellorship","counsellorships"},
"counselor":{"counselor","counselors"},
"counselor-at-law":{"counselor-at-law","counselor-at-laws","counselors-at-law"},
"counselorship":{"counselorship","counselorships"},
"count":{"count","counted","counting","counts"},
"countenance":{"countenance","countenanced","countenances","countenancing"},
"counter":{"counter","countered","countering","counters"},
"counter-revolutionary":{"counter-revolutionaries","counter-revolutionary"},
"counteract":{"counteract","counteracted","counteracting","counteracts"},
"counteraction":{"counteraction","counteractions"},
"counterattack":{"counterattack","counterattacked","counterattacking","counterattacks"},
"counterbalance":{"counterbalance","counterbalanced","counterbalances","counterbalancing"},
"counterbore":{"counterbore","counterbores"},
"counterchange":{"counterchange","counterchanged","counterchanges","counterchanging"},
"countercharge":{"countercharge","countercharged","countercharging"},
"countercheck":{"countercheck","counterchecked","counterchecking","counterchecks"},
"counterclaim":{"counterclaim","counterclaimed","counterclaiming"},
"counterfeit":{"counterfeit","counterfeited","counterfeiting","counterfeits"},
"counterfeiter":{"counterfeiter","counterfeiters"},
"counterfoil":{"counterfoil","counterfoils"},
"counterglow":{"counterglow","counterglows"},
"counterman":{"counterman","countermen"},
"countermand":{"countermand","countermanded","countermanding","countermands"},
"countermarch":{"countermarch","countermarched","countermarching"},
"countermine":{"countermine","countermined","countermines","countermining"},
"countermove":{"countermove","countermoves"},
"counterpane":{"counterpane","counterpanes"},
"counterpart":{"counterpart","counterparts"},
"counterplot":{"counterplot","counterplots","counterplotted","counterplotting"},
"counterpoint":{"counterpoint","counterpointed","counterpointing","counterpoints"},
"counterpoise":{"counterpoise","counterpoised","counterpoises","counterpoising"},
"counterpoison":{"counterpoison","counterpoisons"},
"counterpunch":{"counterpunch","counterpunches"},
"counterrevolution":{"counterrevolution","counterrevolutions"},
"counterrevolutionary":{"counterrevolutionaries","counterrevolutionary"},
"counterrevolutionist":{"counterrevolutionist","counterrevolutionists"},
"countersign":{"countersign","countersigned","countersigning","countersigns"},
"countersignature":{"countersignature","countersignatures"},
"countersink":{"countersank","countersink","countersinking","countersinks","countersunk"},
"counterspy":{"counterspies","counterspy"},
"countertenor":{"countertenor","countertenors"},
"countervail":{"countervail","countervailed","countervailing","countervails"},
"counterweigh":{"counterweigh","counterweighed","counterweighing"},
"counterweight":{"counterweight","counterweights"},
"countess":{"countess","countesses"},
"counting":{"counting","countings"},
"countlessness":{"countlessness","countlessnesses"},
"country":{"countries","country"},
"country-dance":{"country-dance","country-dances"},
"countryman":{"countryman","countrymen"},
"countrywoman":{"countrywoman","countrywomen"},
"counts/minute":{"counts/minute","counts/minutes"},
"county":{"counties","county"},
"coup":{"coup","coups"},
"coupe":{"coupe","coupes"},
"couple":{"couple","coupled","couples","coupling"},
"coupler":{"coupler","couplers"},
"couplet":{"couplet","couplets"},
"coupling":{"coupling","couplings"},
"coupon":{"coupon","coupons"},
"courage":{"courage","courages"},
"courageousness":{"courageousness","courageousnesses"},
"courbaril":{"courbaril","courbarils"},
"courgette":{"courgette","courgettes"},
"courier":{"courier","couriers"},
"courlan":{"courlan","courlans"},
"course":{"course","coursed","courses","coursing"},
"court":{"court","courted","courting","courts"},
"court-martial":{"court-martial","court-martialed","court-martialing","court-martialled","court-martialling","court-martials","courts-martial"},
"courtesan":{"courtesan","courtesans"},
"courtesy":{"courtesies","courtesy"},
"courthouse":{"courthouse","courthouses"},
"courtier":{"courtier","courtiers"},
"courting":{"courting","courtings"},
"courtly":{"courtlier","courtliest","courtly"},
"courtroom":{"courtroom","courtrooms"},
"courtship":{"courtship","courtships"},
"courtyard":{"courtyard","courtyards"},
"court_martial":{"courts_martial","court_martial","court_martialsor"},
"cousin":{"cousin","cousins"},
"cousin-german":{"cousin-german","cousin-germen"},
"couteau":{"couteau","couteaux"},
"couturier":{"couturier","couturiers"},
"covalence":{"covalence","covalences"},
"covalency":{"covalencies","covalency"},
"cove":{"cove","coved","coves","coving"},
"covenant":{"covenant","covenanted","covenanting","covenants"},
"cover":{"cover","covered","covering","covers"},
"coverage":{"coverage","coverages"},
"covering":{"covering","coverings"},
"coverlet":{"coverlet","coverlets"},
"covert":{"covert","coverts"},
"covet":{"covet","coveted","coveting"},
"covetousness":{"covetousness","covetousnesses"},
"covey":{"covey","coveys"},
"coville":{"coville","covilles"},
"cow":{"cow","cowed","cowing","cows"},
"cowage":{"cowage","cowages"},
"coward":{"coward","cowards"},
"cowardice":{"cowardice","cowardices"},
"cowardliness":{"cowardliness","cowardlinesses"},
"cowbarn":{"cowbarn","cowbarns"},
"cowberry":{"cowberries","cowberry"},
"cowboy":{"cowboy","cowboys"},
"cowcatcher":{"cowcatcher","cowcatchers"},
"cower":{"cower","cowered","cowering","cowers"},
"cowfish":{"cowfish","cowfishes"},
"cowhand":{"cowhand","cowhands"},
"cowherb":{"cowherb","cowherbs"},
"cowherd":{"cowherd","cowherds"},
"cowhide":{"cowhide","cowhided","cowhides","cowhiding"},
"cowhouse":{"cowhouse","cowhouses"},
"cowl":{"cowl","cowled","cowling","cowls"},
"cowling":{"cowling","cowlings"},
"cowman":{"cowman","cowmen"},
"cowpea":{"cowpea","cowpeas"},
"cowpens":{"cowpens","cowpenses"},
"cowpoke":{"cowpoke","cowpokes"},
"cowpox":{"cowpox","cowpoxes"},
"cowpuncher":{"cowpuncher","cowpunchers"},
"cowrie":{"cowrie","cowries"},
"cowry":{"cowries","cowry"},
"cows":{"cows","cowses"},
"cowshed":{"cowshed","cowsheds"},
"cowskin":{"cowskin","cowskins"},
"cowslip":{"cowslip","cowslips"},
"cox":{"cox","coxed","coxes","coxing"},
"coxa":{"coxa","coxae","coxas"},
"coxcomb":{"coxcomb","coxcombs"},
"coxcombry":{"coxcombries","coxcombry"},
"coxsackievirus":{"coxsackievirus","coxsackieviruses"},
"coxswain":{"coxswain","coxswains"},
"coy":{"coy","coyed","coyer","coyest","coying"},
"coyness":{"coyness","coynesses"},
"coyol":{"coyol","coyols"},
"coyote":{"coyote","coyotes"},
"coyotillo":{"coyotillo","coyotillos"},
"coypu":{"coypu","coypus"},
"cozen":{"cozen","cozened","cozening","cozens"},
"cozenage":{"cozenage","cozenages"},
"cozey":{"cozey","cozeys"},
"cozie":{"cozie","cozies"},
"coziness":{"coziness","cozinesses"},
"cozy":{"cozier","cozies","coziest","cozy"},
"cpa":{"cpa","cpas"},
"cpi":{"cpi","cpis"},
"cpr":{"cpr","cprs"},
"cps":{"cps","cpses"},
"cpu":{"cpu","cpus"},
"cr":{"cr","crs"},
"crab":{"crab","crabbed","crabbing","crabs"},
"crabbedness":{"crabbedness","crabbednesses"},
"crabbiness":{"crabbiness","crabbinesses"},
"crabby":{"crabbier","crabbiest","crabby"},
"crabgrass":{"crabgrass","crabgrasses"},
"crabmeat":{"crabmeat","crabmeats"},
"cracidae":{"cracidae","cracidaes"},
"crack":{"crack","cracked","cracking","cracks"},
"crack-up":{"crack-up","crack-ups"},
"cracker":{"cracker","crackers"},
"crackerberry":{"crackerberries","crackerberry"},
"crackerjack":{"crackerjack","crackerjacks"},
"cracking":{"cracking","crackings"},
"crackle":{"crackle","crackled","crackles","crackling"},
"crackleware":{"crackleware","cracklewares"},
"crackling":{"crackling","cracklings"},
"crackly":{"cracklier","crackliest","crackly"},
"cracknel":{"cracknel","cracknels"},
"crackpot":{"crackpot","crackpots"},
"cracksman":{"cracksman","cracksmen"},
"cracow":{"cracow","cracows"},
"cracticidae":{"cracticidae","cracticidaes"},
"cracticus":{"cracticus","cracticuses"},
"cradle":{"cradle","cradled","cradles","cradling"},
"cradlesong":{"cradlesong","cradlesongs"},
"craft":{"craft","crafted","crafting","crafts"},
"crafter":{"crafter","crafters"},
"craftiness":{"craftiness","craftinesses"},
"craftsman":{"craftsman","craftsmen"},
"craftsmanship":{"craftsmanship","craftsmanships"},
"craftswoman":{"craftswoman","craftswomen"},
"crafty":{"craftier","craftiest","crafty"},
"crag":{"crag","crags"},
"craggy":{"craggier","craggiest","craggy"},
"cragsman":{"cragsman","cragsmen"},
"cram":{"cram","crammed","cramming","crams"},
"crambe":{"crambe","crambes"},
"crambo":{"crambo","cramboes"},
"crammer":{"crammer","crammers"},
"cramp":{"cramp","cramped","cramping","cramps"},
"crampbark":{"crampbark","crampbarks"},
"crampfish":{"crampfish","crampfishes"},
"crampon":{"crampon","crampons"},
"crampoon":{"crampoon","crampoons"},
"cranberry":{"cranberries","cranberry"},
"crane":{"crane","craned","cranes","craning"},
"cranesbill":{"cranesbill","cranesbills"},
"crangon":{"crangon","crangons"},
"crangonidae":{"crangonidae","crangonidaes"},
"craniata":{"craniata","craniatas"},
"craniate":{"craniate","craniates"},
"craniologist":{"craniologist","craniologists"},
"craniotomy":{"craniotomies","craniotomy"},
"cranium":{"crania","cranium","craniums"},
"crank":{"crank","cranked","cranking","cranks"},
"crankiness":{"crankiness","crankinesses"},
"crankle":{"crankle","crankled","crankling"},
"cranky":{"crankier","crankiest","cranky"},
"cranny":{"crannies","cranny"},
"crap":{"crap","craps"},
"crapaud":{"crapaud","crapauds"},
"crape":{"crape","craped","crapes","craping"},
"crapette":{"crapette","crapettes"},
"crapper":{"crapper","crappers"},
"crappie":{"crappie","crappies"},
"craps":{"craps","crapses"},
"crapulence":{"crapulence","crapulences"},
"crash":{"crash","crashed","crashes","crashing"},
"crash-dive":{"crash-dive","crash-dived","crash-diving"},
"crash-land":{"crash-land","crash-landed","crash-landing"},
"crasher":{"crasher","crashers"},
"crasis":{"crases","crasis"},
"craspedia":{"craspedia","craspedias"},
"crass":{"crass","crasser","crassest"},
"crassitude":{"crassitude","crassitudes"},
"crassness":{"crassness","crassnesses"},
"crassostrea":{"crassostrea","crassostreas"},
"crassula":{"crassula","crassulas"},
"crassulaceae":{"crassulaceae","crassulaceaes"},
"crataegus":{"crataegus","crataeguses"},
"crate":{"crate","crated","crates","crating"},
"crateful":{"crateful","cratefuls"},
"crater":{"crater","cratered","cratering","craters"},
"cravat":{"cravat","cravats"},
"crave":{"crave","craved","craves","craving"},
"craven":{"craven","cravens"},
"craving":{"craving","cravings"},
"craw":{"craw","craws"},
"crawdad":{"crawdad","crawdads"},
"crawdaddy":{"crawdaddies","crawdaddy"},
"crawfish":{"crawfish","crawfished","crawfishes","crawfishing"},
"crawl":{"crawl","crawled","crawling","crawls"},
"crawler":{"crawler","crawlers"},
"crawling":{"crawling","crawlings"},
"crawly":{"crawlier","crawliest","crawly"},
"crax":{"crax","craxes"},
"crayfish":{"crayfish","crayfishes"},
"crayon":{"crayon","crayoned","crayoning","crayons"},
"crayonist":{"crayonist","crayonists"},
"craze":{"craze","crazed","crazes","crazing"},
"craziness":{"craziness","crazinesses"},
"crazy":{"crazier","crazies","craziest","crazy"},
"crazyweed":{"crazyweed","crazyweeds"},
"creak":{"creak","creaked","creaking","creaks"},
"creaking":{"creaking","creakings"},
"creaky":{"creakier","creakiest","creaky"},
"cream":{"cream","creamed","creaming","creams"},
"creamcups":{"creamcups","creamcupses"},
"creamer":{"creamer","creamers"},
"creamery":{"creameries","creamery"},
"creaminess":{"creaminess","creaminesses"},
"creamy":{"creamier","creamiest","creamy"},
"crease":{"crease","creased","creases","creasing"},
"creashak":{"creashak","creashaks"},
"creasy":{"creasier","creasiest","creasy"},
"create":{"create","created","creates","creating"},
"creatin":{"creatin","creatins"},
"creatine":{"creatine","creatines"},
"creation":{"creation","creations"},
"creativeness":{"creativeness","creativenesses"},
"creativity":{"creativities","creativity"},
"creator":{"creator","creators"},
"creature":{"creature","creatures"},
"creche":{"creche","creches"},
"crecy":{"crecies","crecy"},
"credence":{"credence","credences"},
"credendum":{"credenda","credendum"},
"credential":{"credential","credentials"},
"credentials":{"credentials","credentialses"},
"credenza":{"credenza","credenzas"},
"credibility":{"credibilities","credibility"},
"credibleness":{"credibleness","crediblenesses"},
"credit":{"credit","credited","crediting","credits"},
"credo":{"credo","credos"},
"credulousness":{"credulousness","credulousnesses"},
"cree":{"cree","crees"},
"creed":{"creed","creeds"},
"creek":{"creek","creeks"},
"creep":{"creep","creeped","creeping","creeps","crept"},
"creeper":{"creeper","creepers"},
"creeping":{"creeping","creepings"},
"creepy":{"creepier","creepiest","creepy"},
"creepy-crawly":{"creepy-crawlier","creepy-crawlies","creepy-crawliest","creepy-crawly"},
"cremate":{"cremate","cremated","cremating"},
"crematorium":{"crematoria","crematorium","crematoriums"},
"crematory":{"crematories","crematory"},
"creme":{"creme","cremes"},
"crenelation":{"crenelation","crenelations"},
"crenellation":{"crenellation","crenellations"},
"creole-fish":{"creole-fish","creole-fishes"},
"creosote":{"creosote","creosoted","creosotes","creosoting"},
"crepe":{"crepe","creped","crepes","creping"},
"crepis":{"crepis","crepises"},
"crepitate":{"crepitate","crepitated","crepitates","crepitating"},
"crepitation":{"crepitation","crepitations"},
"crescendo":{"crescendi","crescendo","crescendoed","crescendoes","crescendoing","crescendos"},
"crescent":{"crescent","crescents"},
"crescentia":{"crescentia","crescentias"},
"cresol":{"cresol","cresols"},
"cress":{"cress","cresses"},
"crest":{"crest","crested","cresting","crests"},
"cretaceous":{"cretaceous","cretaceouses"},
"cretin":{"cretin","cretins"},
"crevice":{"crevice","crevices"},
"crew":{"crew","crews"},
"crewet":{"crewet","crewets"},
"crewman":{"crewman","crewmen"},
"crex":{"crex","crexes"},
"crib":{"crib","cribbed","cribbing","cribs"},
"cribbage":{"cribbage","cribbages"},
"cribellum":{"cribella","cribellum"},
"cricetidae":{"cricetidae","cricetidaes"},
"cricetus":{"cricetus","cricetuses"},
"crick":{"crick","cricked","cricking","cricks"},
"cricket":{"cricket","cricketed","cricketing","crickets"},
"crier":{"crier","criers"},
"crime":{"crime","crimed","crimes","criming"},
"criminal":{"criminal","criminals"},
"criminalism":{"criminalism","criminalisms"},
"criminality":{"criminalities","criminality"},
"criminalness":{"criminalness","criminalnesses"},
"criminate":{"criminate","criminated","criminates","criminating"},
"crimp":{"crimp","crimped","crimping","crimps"},
"crimper":{"crimper","crimpers"},
"crimple":{"crimple","crimpled","crimpling"},
"crimpy":{"crimpier","crimpiest","crimpy"},
"crimson":{"crimson","crimsoned","crimsoning","crimsons"},
"cringe":{"cringe","cringed","cringes","cringing"},
"cringle":{"cringle","cringles"},
"crinion":{"crinion","crinions"},
"crinkle":{"crinkle","crinkled","crinkles","crinkling"},
"crinkleroot":{"crinkleroot","crinkleroots"},
"crinkly":{"crinklier","crinkliest","crinkly"},
"crinoidea":{"crinoidea","crinoideas"},
"crinoline":{"crinoline","crinolines"},
"criollo":{"criollo","criollos"},
"cripple":{"cripple","crippled","cripples","crippling"},
"crisis":{"crises","crisis"},
"crisp":{"crisp","crisped","crisper","crispest","crisping","crisps"},
"crispiness":{"crispiness","crispinesses"},
"crispness":{"crispness","crispnesses"},
"crispy":{"crispier","crispiest","crispy"},
"crisscross":{"crisscross","crisscrossed","crisscrosses","crisscrossing"},
"crissum":{"crissa","crissum"},
"crista":{"crista","cristae"},
"criterion":{"criteria","criterion","criterions"},
"critic":{"critic","critics"},
"criticality":{"criticalities","criticality"},
"criticalness":{"criticalness","criticalnesses"},
"criticise":{"criticise","criticised","criticises","criticising"},
"criticism":{"criticism","criticisms"},
"criticize":{"criticize","criticized","criticizes","criticizing"},
"critique":{"critique","critiques"},
"cro":{"cro","cros"},
"croak":{"croak","croaked","croaking","croaks"},
"croaking":{"croaking","croakings"},
"croat":{"croat","croats"},
"croatian":{"croatian","croatians"},
"crocethia":{"crocethia","crocethias"},
"crochet":{"crochet","crocheted","crocheting","crochets"},
"crocheting":{"crocheting","crochetings"},
"crock":{"crock","crocked","crocking","crocks"},
"crockery":{"crockeries","crockery"},
"crocodile":{"crocodile","crocodiles"},
"crocodilia":{"crocodilia","crocodilias"},
"crocodilian":{"crocodilian","crocodilians"},
"crocodilus":{"crocodilus","crocodiluses"},
"crocodylia":{"crocodylia","crocodylias"},
"crocodylidae":{"crocodylidae","crocodylidaes"},
"crocodylus":{"crocodylus","crocodyluses"},
"crocus":{"crocus","crocuses"},
"crocuta":{"crocuta","crocutas"},
"croissant":{"croissant","croissants"},
"cromlech":{"cromlech","cromleches"},
"cromorne":{"cromorne","cromornes"},
"cromwell":{"cromwell","cromwells"},
"cronartium":{"cronartium","cronartiums"},
"crone":{"crone","crones"},
"crony":{"cronies","crony"},
"crook":{"crook","crooked","crooking","crooks"},
"crookback":{"crookback","crookbacks"},
"crookedness":{"crookedness","crookednesses"},
"crookneck":{"crookneck","crooknecks"},
"croon":{"croon","crooned","crooning"},
"crooner":{"crooner","crooners"},
"crop":{"crop","cropped","cropping","crops"},
"crop-dusting":{"crop-dusting","crop-dustings"},
"cropper":{"cropper","croppers"},
"croquet":{"croquet","croqueted","croqueting","croquets"},
"croquette":{"croquette","croquettes"},
"crosier":{"crosier","crosiers"},
"cross":{"cross","crossed","crosser","crosses","crossest","crossing"},
"cross-check":{"cross-check","cross-checked","cross-checking"},
"cross-classification":{"cross-classification","cross-classifications"},
"cross-division":{"cross-division","cross-divisions"},
"cross-dresser":{"cross-dresser","cross-dressers"},
"cross-examine":{"cross-examine","cross-examined","cross-examining"},
"cross-examiner":{"cross-examiner","cross-examiners"},
"cross-eye":{"cross-eye","cross-eyes"},
"cross-fertilisation":{"cross-fertilisation","cross-fertilisations"},
"cross-fertilization":{"cross-fertilization","cross-fertilizations"},
"cross-fertilize":{"cross-fertilize","cross-fertilized","cross-fertilizes","cross-fertilizing"},
"cross-file":{"cross-file","cross-filed","cross-files","cross-filing"},
"cross-index":{"cross-index","cross-indexed","cross-indexes","cross-indexing"},
"cross-link":{"cross-link","cross-links"},
"cross-linkage":{"cross-linkage","cross-linkages"},
"cross-pollinate":{"cross-pollinate","cross-pollinated","cross-pollinates","cross-pollinating"},
"cross-purpose":{"cross-purpose","cross-purposes"},
"cross-question":{"cross-question","cross-questioned","cross-questioning"},
"cross-questioner":{"cross-questioner","cross-questioners"},
"cross-refer":{"cross-refer","cross-referred","cross-referring"},
"cross-reference":{"cross-reference","cross-referenced","cross-references","cross-referencing"},
"cross-stitch":{"cross-stitch","cross-stitched","cross-stitching"},
"crossbeam":{"crossbeam","crossbeams"},
"crossbill":{"crossbill","crossbills"},
"crossbow":{"crossbow","crossbows"},
"crossbowman":{"crossbowman","crossbowmen"},
"crossbreed":{"crossbred","crossbreed","crossbreeding","crossbreeds"},
"crossbreeding":{"crossbreeding","crossbreedings"},
"crosscurrent":{"crosscurrent","crosscurrents"},
"crosscut":{"crosscut","crosscuts","crosscutting"},
"crosshatch":{"crosshatch","crosshatched","crosshatches","crosshatching"},
"crosshead":{"crosshead","crossheads"},
"crossheading":{"crossheading","crossheadings"},
"crossing":{"crossing","crossings"},
"crossjack":{"crossjack","crossjacks"},
"crossness":{"crossness","crossnesses"},
"crossopterygian":{"crossopterygian","crossopterygians"},
"crossopterygii":{"crossopterygii","crossopterygiis"},
"crossover":{"crossover","crossovers"},
"crosspatch":{"crosspatch","crosspatches"},
"crosspiece":{"crosspiece","crosspieces"},
"crossroad":{"crossroad","crossroads"},
"crossroads":{"crossroads"},
"crosstalk":{"crosstalk","crosstalks"},
"crosstie":{"crosstie","crossties"},
"crosswalk":{"crosswalk","crosswalks"},
"crossway":{"crossway","crossways"},
"crossword":{"crossword","crosswords"},
"crotal":{"crotal","crotals"},
"crotalaria":{"crotalaria","crotalarias"},
"crotalidae":{"crotalidae","crotalidaes"},
"crotalus":{"crotalus","crotaluses"},
"crotaphytus":{"crotaphytus","crotaphytuses"},
"crotch":{"crotch","crotches"},
"crotchet":{"crotchet","crotchets"},
"crotchetiness":{"crotchetiness","crotchetinesses"},
"croton":{"croton","crotons"},
"crotonbug":{"crotonbug","crotonbugs"},
"crotophaga":{"crotophaga","crotophagas"},
"crottal":{"crottal","crottals"},
"crottle":{"crottle","crottles"},
"crouch":{"crouch","crouched","crouches","crouching"},
"croup":{"croup","croups"},
"croupe":{"croupe","croupes"},
"crow":{"crew","crow","crowed","crowing","crows"},
"crowbar":{"crowbar","crowbars"},
"crowberry":{"crowberries","crowberry"},
"crowd":{"crowd","crowded","crowding","crowds"},
"crowfoot":{"crowfeet","crowfoot","crowfoots"},
"crowing":{"crowing","crowings"},
"crown":{"crown","crowned","crowning","crowns"},
"crown-of-the-field":{"crown-of-the-field","crown-of-the-fields"},
"crownbeard":{"crownbeard","crownbeards"},
"crownwork":{"crownwork","crownworks"},
"crozier":{"crozier","croziers"},
"crt":{"crt","crts"},
"cruciality":{"crucialities","cruciality"},
"crucible":{"crucible","crucibles"},
"crucifer":{"crucifer","crucifers"},
"cruciferae":{"cruciferae","cruciferaes"},
"crucifix":{"crucifix","crucifixes"},
"crucifixion":{"crucifixion","crucifixions"},
"crucify":{"crucified","crucifies","crucify","crucifying"},
"crude":{"crude","cruder","crudes","crudest"},
"crudeness":{"crudeness","crudenesses"},
"crudity":{"crudities","crudity"},
"cruel":{"cruel","crueler","cruelest","crueller","cruellest"},
"cruelness":{"cruelness","cruelnesses"},
"cruelty":{"cruelties","cruelty"},
"cruet":{"cruet","cruets"},
"cruise":{"cruise","cruised","cruises","cruising"},
"cruiser":{"cruiser","cruisers"},
"cruller":{"cruller","crullers"},
"crumb":{"crumb","crumbed","crumbing","crumbs"},
"crumble":{"crumble","crumbled","crumbles","crumbling"},
"crumbliness":{"crumbliness","crumblinesses"},
"crumbly":{"crumblier","crumbliest","crumbly"},
"crumby":{"crumbier","crumbiest","crumby"},
"crumhorn":{"crumhorn","crumhorns"},
"crummy":{"crummier","crummies","crummiest","crummy"},
"crump":{"crump","crumped","crumping","crumps"},
"crumpet":{"crumpet","crumpets"},
"crumple":{"crumple","crumpled","crumples","crumpling"},
"crunch":{"crunch","crunched","crunches","crunching"},
"crus":{"crura","crus"},
"crusade":{"crusade","crusaded","crusades","crusading"},
"crusader":{"crusader","crusaders"},
"crusado":{"crusado","crusadoes","crusados"},
"crush":{"crush","crushed","crushes","crushing"},
"crushing":{"crushing","crushings"},
"crust":{"crust","crusted","crusting","crusts"},
"crustacea":{"crustacea","crustaceas"},
"crusty":{"crustier","crustiest","crusty"},
"crutch":{"crutch","crutched","crutches","crutching"},
"crux":{"cruces","crux","cruxes"},
"cruzado":{"cruzado","cruzadoes","cruzados"},
"cruzeiro":{"cruzeiro","cruzeiros"},
"cry":{"cried","cries","cry","crying"},
"cryaesthesia":{"cryaesthesia","cryaesthesias"},
"crybaby":{"crybabies","crybaby"},
"cryesthesia":{"cryesthesia","cryesthesias"},
"crying":{"crying","cryings"},
"cryoanaesthesia":{"cryoanaesthesia","cryoanaesthesias"},
"cryoanesthesia":{"cryoanesthesia","cryoanesthesias"},
"cryogenics":{"cryogenics","cryogenicses"},
"cryogeny":{"cryogenies","cryogeny"},
"cryolite":{"cryolite","cryolites"},
"cryopathy":{"cryopathies","cryopathy"},
"cryoscopy":{"cryoscopies","cryoscopy"},
"cryptacanthodes":{"cryptacanthodes","cryptacanthodeses"},
"crypto":{"crypto","cryptos"},
"cryptobranchidae":{"cryptobranchidae","cryptobranchidaes"},
"cryptobranchus":{"cryptobranchus","cryptobranchuses"},
"cryptocercidae":{"cryptocercidae","cryptocercidaes"},
"cryptocercus":{"cryptocercus","cryptocercuses"},
"cryptocoryne":{"cryptocoryne","cryptocorynes"},
"cryptogram":{"cryptogram","cryptograms"},
"cryptogramma":{"cryptogramma","cryptogrammas"},
"cryptogrammataceae":{"cryptogrammataceae","cryptogrammataceaes"},
"cryptograph":{"cryptograph","cryptographs"},
"cryptomeria":{"cryptomeria","cryptomerias"},
"cryptomonad":{"cryptomonad","cryptomonads"},
"cryptophyceae":{"cryptophyceae","cryptophyceaes"},
"cryptophyta":{"cryptophyta","cryptophytas"},
"cryptophyte":{"cryptophyte","cryptophytes"},
"cryptoprocta":{"cryptoprocta","cryptoproctas"},
"cryptorchidism":{"cryptorchidism","cryptorchidisms"},
"cryptorchidy":{"cryptorchidies","cryptorchidy"},
"cryptorchism":{"cryptorchism","cryptorchisms"},
"cryptotermes":{"cryptotermes","cryptotermeses"},
"cryptotis":{"cryptotis","cryptotises"},
"crystal":{"crystal","crystals"},
"crystallisation":{"crystallisation","crystallisations"},
"crystallization":{"crystallization","crystallizations"},
"crystallize":{"crystallize","crystallized","crystallizes","crystallizing"},
"cs":{"cs","cses"},
"cst":{"cst","csts"},
"ct":{"ct","cts"},
"ctenidium":{"ctenidiia","ctenidium"},
"ctenizidae":{"ctenizidae","ctenizidaes"},
"ctenocephalides":{"ctenocephalides","ctenocephalideses"},
"ctenophora":{"ctenophora","ctenophoras"},
"ctenophore":{"ctenophore","ctenophores"},
"cu":{"cu","cus"},
"cub":{"cub","cubbed","cubbing","cubs"},
"cubby":{"cubbies","cubby"},
"cubbyhole":{"cubbyhole","cubbyholes"},
"cube":{"cube","cubed","cubes","cubing"},
"cubeb":{"cubeb","cubebs"},
"cubicle":{"cubicle","cubicles"},
"cubiculum":{"cubicula","cubiculum"},
"cubit":{"cubit","cubits"},
"cubitus":{"cubitus","cubituses"},
"cuckold":{"cuckold","cuckolded","cuckolding","cuckolds"},
"cuckoo":{"cuckoo","cuckooed","cuckooing","cuckoos"},
"cuckooflower":{"cuckooflower","cuckooflowers"},
"cuckoopint":{"cuckoopint","cuckoopints"},
"cuculidae":{"cuculidae","cuculidaes"},
"cuculiformes":{"cuculiformes","cuculiformeses"},
"cuculus":{"cuculus","cuculuses"},
"cucumber":{"cucumber","cucumbers"},
"cucumis":{"cucumis","cucumises"},
"cucurbita":{"cucurbita","cucurbitas"},
"cucurbitaceae":{"cucurbitaceae","cucurbitaceaes"},
"cud":{"cud","cuds"},
"cudbear":{"cudbear","cudbears"},
"cuddle":{"cuddle","cuddled","cuddles","cuddling"},
"cuddling":{"cuddling","cuddlings"},
"cuddy":{"cuddies","cuddy"},
"cudgel":{"cudgel","cudgeled","cudgeling","cudgelled","cudgelling","cudgels"},
"cudweed":{"cudweed","cudweeds"},
"cue":{"cue","cued","cues","cuing"},
"cuff":{"cuff","cuffed","cuffing","cuffs"},
"cuffs":{"cuffs","cuffses"},
"cuisine":{"cuisine","cuisines"},
"cuke":{"cuke","cukes"},
"cul":{"cul","culs"},
"cul-de-sac":{"cul-de-sac","cul-de-sacs","culs-de-sac"},
"culcita":{"culcita","culcitas"},
"culex":{"culex","culexes"},
"culicidae":{"culicidae","culicidaes"},
"cull":{"cull","culled","culling","culls"},
"cullender":{"cullender","cullenders"},
"cully":{"cullies","cully"},
"culm":{"culm","culmed","culming"},
"culminate":{"culminate","culminated","culminates","culminating"},
"culmination":{"culmination","culminations"},
"culotte":{"culotte","culottes"},
"culottes":{"culottes","culotteses"},
"culpa":{"culpa","culpae"},
"culpability":{"culpabilities","culpability"},
"culpableness":{"culpableness","culpablenesses"},
"culprit":{"culprit","culprits"},
"cult":{"cult","cults"},
"cultivate":{"cultivate","cultivated","cultivates","cultivating"},
"cultivator":{"cultivator","cultivators"},
"culture":{"culture","cultures"},
"cultus":{"culti","cultus","cultuses"},
"cumarone":{"cumarone","cumarones"},
"cumber":{"cumber","cumbered","cumbering","cumbers"},
"cumberland":{"cumberland","cumberlands"},
"cumbersomeness":{"cumbersomeness","cumbersomenesses"},
"cumfrey":{"cumfrey","cumfreys"},
"cumin":{"cumin","cumins"},
"cuminum":{"cuminum","cuminums"},
"cumquat":{"cumquat","cumquats"},
"cumulate":{"cumulate","cumulated","cumulates","cumulating"},
"cumulocirrus":{"cumulocirri","cumulocirrus"},
"cumulonimbus":{"cumulonimbi","cumulonimbus","cumulonimbuses"},
"cumulostratus":{"cumulostrati","cumulostratus"},
"cumulus":{"cumuli","cumulus","cumuluses"},
"cunaxa":{"cunaxa","cunaxas"},
"cunctation":{"cunctation","cunctations"},
"cunctator":{"cunctator","cunctators"},
"cuneus":{"cuneus","cuneuses"},
"cuniculus":{"cuniculus","cuniculuses"},
"cunner":{"cunner","cunners"},
"cunnilinctus":{"cunnilinctus","cunnilinctuses"},
"cunnilingus":{"cunnilingus","cunnilinguses"},
"cunning":{"cunning","cunnings"},
"cunoniaceae":{"cunoniaceae","cunoniaceaes"},
"cunt":{"cunt","cunts"},
"cuon":{"cuon","cuons"},
"cup":{"cup","cupped","cupping","cups"},
"cupboard":{"cupboard","cupboards"},
"cupel":{"cupel","cupels"},
"cupflower":{"cupflower","cupflowers"},
"cupful":{"cupful","cupfuls","cupsful"},
"cupid":{"cupid","cupids"},
"cupidity":{"cupidities","cupidity"},
"cupola":{"cupola","cupolas"},
"cuppa":{"cuppa","cuppas"},
"cupper":{"cupper","cuppers"},
"cupressaceae":{"cupressaceae","cupressaceaes"},
"cupressus":{"cupressus","cupressuses"},
"cupule":{"cupule","cupules"},
"cuquenan":{"cuquenan","cuquenans"},
"cur":{"cur","curs"},
"curability":{"curabilities","curability"},
"curableness":{"curableness","curablenesses"},
"curacao":{"curacao","curacaos"},
"curacoa":{"curacoa","curacoas"},
"curacy":{"curacies","curacy"},
"curare":{"curare","curares"},
"curarize":{"curarize","curarized","curarizes","curarizing"},
"curate":{"curate","curates"},
"curative":{"curative","curatives"},
"curator":{"curator","curators"},
"curb":{"curb","curbed","curbing","curbs"},
"curbstone":{"curbstone","curbstones"},
"curculio":{"curculio","curculios"},
"curculionidae":{"curculionidae","curculionidaes"},
"curcuma":{"curcuma","curcumas"},
"curd":{"curd","curded","curding","curds"},
"curdle":{"curdle","curdled","curdles","curdling"},
"curdling":{"curdling","curdlings"},
"curdy":{"curdier","curdiest","curdy"},
"cure":{"cure","cured","cures","curing"},
"cure-all":{"cure-all","cure-alls"},
"curet":{"curet","curets"},
"curettage":{"curettage","curettages"},
"curette":{"curette","curetted","curettes","curetting"},
"curettement":{"curettement","curettements"},
"curia":{"curia","curiae"},
"curie":{"curie","curies"},
"curio":{"curio","curios"},
"curiosity":{"curiosities","curiosity"},
"curiousness":{"curiousness","curiousnesses"},
"curium":{"curium","curiums"},
"curl":{"curl","curled","curling","curls"},
"curler":{"curler","curlers"},
"curlicue":{"curlicue","curlicues"},
"curly":{"curlier","curliest","curly"},
"curly-heads":{"curly-heads","curly-headses"},
"currajong":{"currajong","currajongs"},
"currant":{"currant","currants"},
"currawong":{"currawong","currawongs"},
"currency":{"currencies","currency"},
"current":{"current","currents"},
"currentness":{"currentness","currentnesses"},
"curriculum":{"curricula","curriculum","curriculums"},
"curriery":{"currieries","curriery"},
"curry":{"curried","curries","curry","currying"},
"currycomb":{"currycomb","currycombed","currycombing","currycombs"},
"curse":{"curse","cursed","curses","cursing","curst"},
"cursive":{"cursive","cursives"},
"cursor":{"cursor","cursors"},
"cursorius":{"cursorius","cursoriuses"},
"curt":{"curt","curter","curtest"},
"curtail":{"curtail","curtailed","curtailing","curtails"},
"curtailment":{"curtailment","curtailments"},
"curtain":{"curtain","curtained","curtaining","curtains"},
"curtness":{"curtness","curtnesses"},
"curtsey":{"curtsey","curtseyed","curtseying","curtseys"},
"curtsy":{"curtsied","curtsies","curtsy","curtsying"},
"curvaceousness":{"curvaceousness","curvaceousnesses"},
"curvature":{"curvature","curvatures"},
"curve":{"curve","curved","curves","curving"},
"curvet":{"curvet","curveted","curveting","curvets","curvetted","curvetting"},
"curvy":{"curvier","curviest","curvy"},
"cuscuta":{"cuscuta","cuscutas"},
"cush-cush":{"cush-cush","cush-cushes"},
"cushat":{"cushat","cushats"},
"cushaw":{"cushaw","cushaws"},
"cushion":{"cushion","cushioned","cushioning","cushions"},
"cushioning":{"cushioning","cushionings"},
"cushy":{"cushier","cushiest","cushy"},
"cusk":{"cusk","cusks"},
"cusp":{"cusp","cusps"},
"cuspid":{"cuspid","cuspids"},
"cuspidor":{"cuspidor","cuspidors"},
"cuss":{"cuss","cussed","cusses","cussing"},
"cussedness":{"cussedness","cussednesses"},
"custard":{"custard","custards"},
"custodian":{"custodian","custodians"},
"custody":{"custodies","custody"},
"custom":{"custom","customs"},
"customary":{"customaries","customary"},
"customer":{"customer","customers"},
"customhouse":{"customhouse","customhouses"},
"customize":{"customize","customized","customizes","customizing"},
"customs":{"customs","customses"},
"customs_duty":{"customs_duties","customs_duty"},
"custos":{"custodes","custos"},
"cut":{"cut","cuts","cutting"},
"cut-and-thrust":{"cut-and-thrust","cut-and-thrusts"},
"cut-in":{"cut-in","cut-ins"},
"cutaway":{"cutaway","cutaways"},
"cutch":{"cutch","cutches"},
"cutcherry":{"cutcherries","cutcherry"},
"cutchery":{"cutcheries","cutchery"},
"cuteness":{"cuteness","cutenesses"},
"cuterebra":{"cuterebra","cuterebras"},
"cuterebridae":{"cuterebridae","cuterebridaes"},
"cuticle":{"cuticle","cuticles"},
"cuticula":{"cuticula","cuticulae"},
"cutinize":{"cutinize","cutinized","cutinizes","cutinizing"},
"cutis":{"cutes","cutis","cutises"},
"cutlas":{"cutlas","cutlases"},
"cutlass":{"cutlass","cutlasses"},
"cutlassfish":{"cutlassfish","cutlassfishes"},
"cutler":{"cutler","cutlers"},
"cutlery":{"cutleries","cutlery"},
"cutlet":{"cutlet","cutlets"},
"cutoff":{"cutoff","cutoffs"},
"cutpurse":{"cutpurse","cutpurses"},
"cutter":{"cutter","cutters"},
"cutting":{"cutting","cuttings"},
"cuttle":{"cuttle","cuttles"},
"cuttlefish":{"cuttlefish","cuttlefishes"},
"cutty":{"cutties","cutty"},
"cva":{"cva","cvas"},
"cwm":{"cwm","cwms"},
"cwt":{"cwt","cwts"},
"cyamopsis":{"cyamopses","cyamopsis"},
"cyamus":{"cyamus","cyamuses"},
"cyanamid":{"cyanamid","cyanamids"},
"cyanamide":{"cyanamide","cyanamides"},
"cyanide":{"cyanide","cyanided","cyanides","cyaniding"},
"cyanobacteria":{"cyanobacteria","cyanobacterias"},
"cyanocitta":{"cyanocitta","cyanocittas"},
"cyanocobalamin":{"cyanocobalamin","cyanocobalamins"},
"cyanophyceae":{"cyanophyceae","cyanophyceaes"},
"cyanophyta":{"cyanophyta","cyanophytas"},
"cyanuramide":{"cyanuramide","cyanuramides"},
"cyathea":{"cyathea","cyatheas"},
"cyatheaceae":{"cyatheaceae","cyatheaceaes"},
"cybele":{"cybele","cybeles"},
"cyberspace":{"cyberspace","cyberspaces"},
"cyborg":{"cyborg","cyborgs"},
"cycadaceae":{"cycadaceae","cycadaceaes"},
"cycadales":{"cycadales","cycadaleses"},
"cycadofilicales":{"cycadofilicales","cycadofilicaleses"},
"cycadophyta":{"cycadophyta","cycadophytas"},
"cycadophytina":{"cycadophytina","cycadophytinas"},
"cycadopsida":{"cycadopsida","cycadopsidas"},
"cycas":{"cycas","cycases"},
"cyclades":{"cyclades","cycladeses"},
"cyclamen":{"cyclamen","cyclamens"},
"cycle":{"cycle","cycled","cycles","cycling"},
"cycles/second":{"cycles/second","cycles/seconds"},
"cyclicity":{"cyclicities","cyclicity"},
"cycliophora":{"cycliophora","cycliophoras"},
"cyclist":{"cyclist","cyclists"},
"cycloloma":{"cycloloma","cyclolomas"},
"cyclone":{"cyclone","cyclones"},
"cyclopaedia":{"cyclopaedia","cyclopaedias"},
"cyclopedia":{"cyclopedia","cyclopedias"},
"cyclopes":{"cyclopes","cyclopeses"},
"cyclophorus":{"cyclophorus","cyclophoruses"},
"cyclops":{"cyclopes","cyclops","cyclopses"},
"cyclopteridae":{"cyclopteridae","cyclopteridaes"},
"cyclopterus":{"cyclopterus","cyclopteruses"},
"cyclorama":{"cyclorama","cycloramas"},
"cyclosis":{"cycloses","cyclosis"},
"cyclosorus":{"cyclosorus","cyclosoruses"},
"cyclosporeae":{"cyclosporeae","cyclosporeaes"},
"cyclostomata":{"cyclostomata","cyclostomatas"},
"cyclothymia":{"cyclothymia","cyclothymias"},
"cycnoches":{"cycnoches","cycnocheses"},
"cyder":{"cyder","cyders"},
"cydippea":{"cydippea","cydippeas"},
"cydippida":{"cydippida","cydippidas"},
"cydippidea":{"cydippidea","cydippideas"},
"cydonia":{"cydonia","cydonias"},
"cygnus":{"cygnus","cygnuses"},
"cylinder":{"cylinder","cylinders"},
"cylindricality":{"cylindricalities","cylindricality"},
"cylindricalness":{"cylindricalness","cylindricalnesses"},
"cylix":{"cylices","cylikes","cylix"},
"cyma":{"cyma","cymae","cymas"},
"cymatiidae":{"cymatiidae","cymatiidaes"},
"cymatium":{"cymatium","cymatiums"},
"cymbal":{"cymbal","cymbals"},
"cymbalo":{"cymbalo","cymbalos"},
"cymbid":{"cymbid","cymbids"},
"cymbidium":{"cymbidium","cymbidiums"},
"cymling":{"cymling","cymlings"},
"cymograph":{"cymograph","cymographs"},
"cymru":{"cymru","cymrus"},
"cynara":{"cynara","cynaras"},
"cynic":{"cynic","cynics"},
"cynipidae":{"cynipidae","cynipidaes"},
"cynips":{"cynips","cynipses"},
"cynocephalidae":{"cynocephalidae","cynocephalidaes"},
"cynocephalus":{"cynocephalus","cynocephaluses"},
"cynodon":{"cynodon","cynodons"},
"cynodontia":{"cynodontia","cynodontias"},
"cynoglossidae":{"cynoglossidae","cynoglossidaes"},
"cynoglossum":{"cynoglossum","cynoglossums"},
"cynomys":{"cynomys","cynomyses"},
"cynopterus":{"cynopterus","cynopteruses"},
"cynoscephalae":{"cynoscephalae","cynoscephalaes"},
"cynoscion":{"cynoscion","cynoscions"},
"cynthia":{"cynthia","cynthias"},
"cyon":{"cyon","cyons"},
"cyperaceae":{"cyperaceae","cyperaceaes"},
"cyperus":{"cyperus","cyperuses"},
"cypher":{"cypher","cyphered","cyphering","cyphers"},
"cyphomandra":{"cyphomandra","cyphomandras"},
"cypraea":{"cypraea","cypraeas"},
"cypraeidae":{"cypraeidae","cypraeidaes"},
"cypre":{"cypre","cypres"},
"cypress":{"cypress","cypresses"},
"cyprian":{"cyprian","cyprians"},
"cyprinid":{"cyprinid","cyprinids"},
"cyprinidae":{"cyprinidae","cyprinidaes"},
"cypriniformes":{"cypriniformes","cypriniformeses"},
"cyprinodontidae":{"cyprinodontidae","cyprinodontidaes"},
"cyprinus":{"cyprinus","cyprinuses"},
"cypriot":{"cypriot","cypriots"},
"cypriote":{"cypriote","cypriotes"},
"cypripedium":{"cypripedium","cypripediums"},
"cyproheptadine":{"cyproheptadine","cyproheptadines"},
"cypsela":{"cypsela","cypselae"},
"cyrilla":{"cyrilla","cyrillas"},
"cyrilliaceae":{"cyrilliaceae","cyrilliaceaes"},
"cyrillic":{"cyrillic","cyrillics"},
"cyrtomium":{"cyrtomium","cyrtomiums"},
"cyst":{"cyst","cysts"},
"cystectomy":{"cystectomies","cystectomy"},
"cysticercus":{"cysticerci","cysticercus"},
"cystocele":{"cystocele","cystoceles"},
"cystolith":{"cystolith","cystoliths"},
"cystoparalysis":{"cystoparalyses","cystoparalysis"},
"cystophora":{"cystophora","cystophoras"},
"cystoplegia":{"cystoplegia","cystoplegias"},
"cystopteris":{"cystopteris","cystopterises"},
"cystotomy":{"cystotomies","cystotomy"},
"cytherea":{"cytherea","cythereas"},
"cytisus":{"cytisus","cytisuses"},
"cytoarchitectonics":{"cytoarchitectonics","cytoarchitectonicses"},
"cytoarchitecture":{"cytoarchitecture","cytoarchitectures"},
"czar":{"czar","czars"},
"czarevna":{"czarevna","czarevnas"},
"czarina":{"czarina","czarinas"},
"czaritza":{"czaritza","czaritzas"},
"czech":{"czech","czeches"},
"czechoslovakian":{"czechoslovakian","czechoslovakians"},
"d":{"d","ds"},
"d-day":{"d-day","d-days"},
"d-layer":{"d-layer","d-layers"},
"da":{"da","das"},
"dab":{"dab","dabbed","dabbing","dabs"},
"daba":{"daba","dabas"},
"dabble":{"dabble","dabbled","dabbles","dabbling"},
"dabbler":{"dabbler","dabblers"},
"dabchick":{"dabchick","dabchicks"},
"daboecia":{"daboecia","daboecias"},
"dacca":{"dacca","daccas"},
"dace":{"dace","daces"},
"dacelo":{"dacelo","dacelos"},
"dachshund":{"dachshund","dachshunds"},
"dachsie":{"dachsie","dachsies"},
"dacninae":{"dacninae","dacninaes"},
"dacoit":{"dacoit","dacoits"},
"dacoity":{"dacoities","dacoity"},
"dacron":{"dacron","dacrons"},
"dacrycarpus":{"dacrycarpus","dacrycarpuses"},
"dacrydium":{"dacrydium","dacrydiums"},
"dacrymyces":{"dacrymyces","dacrymyceses"},
"dacrymycetaceae":{"dacrymycetaceae","dacrymycetaceaes"},
"dacryocyst":{"dacryocyst","dacryocysts"},
"dactyl":{"dactyl","dactyls"},
"dactylis":{"dactylis","dactylises"},
"dactyloctenium":{"dactyloctenium","dactylocteniums"},
"dactylology":{"dactylologies","dactylology"},
"dactylopiidae":{"dactylopiidae","dactylopiidaes"},
"dactylopius":{"dactylopius","dactylopiuses"},
"dactylopteridae":{"dactylopteridae","dactylopteridaes"},
"dactylopterus":{"dactylopterus","dactylopteruses"},
"dactylorhiza":{"dactylorhiza","dactylorhizas"},
"dactyloscopidae":{"dactyloscopidae","dactyloscopidaes"},
"dad":{"dad","dads"},
"dada":{"dada","dadas"},
"dadaism":{"dadaism","dadaisms"},
"daddy":{"daddies","daddy"},
"dado":{"dado","dadoes","dados"},
"daemon":{"daemon","daemons"},
"daff":{"daff","daffed","daffing"},
"daffo":{"daffo","daffos"},
"daffodil":{"daffodil","daffodils"},
"daffy":{"daffier","daffiest","daffy"},
"dafla":{"dafla","daflas"},
"daft":{"daft","dafter","daftest"},
"daftness":{"daftness","daftnesses"},
"dag":{"dag","dags"},
"dagame":{"dagame","dagames"},
"dagga":{"dagga","daggas"},
"dagger":{"dagger","daggered","daggering","daggers"},
"dago":{"dago","dagoes","dagos"},
"daguerreotype":{"daguerreotype","daguerreotyped","daguerreotyping"},
"dah":{"dah","dahs"},
"dahl":{"dahl","dahls"},
"dahlia":{"dahlia","dahlias"},
"dahomey":{"dahomey","dahomeys"},
"daikon":{"daikon","daikons"},
"dail":{"dail","dails"},
"daily":{"dailies","daily"},
"daimio":{"daimio","daimios","daymio","daymios"},
"daimon":{"daimon","daimons"},
"daimyo":{"daimyo","daimyos"},
"daintiness":{"daintiness","daintinesses"},
"dainty":{"daintier","dainties","daintiest","dainty"},
"daiquiri":{"daiquiri","daiquiris"},
"dairy":{"dairies","dairy"},
"dairying":{"dairying","dairyings"},
"dairymaid":{"dairymaid","dairymaids"},
"dairyman":{"dairyman","dairymen"},
"dairywoman":{"dairywoman","dairywomen"},
"dais":{"dais","daises"},
"daisy":{"daisies","daisy"},
"daisybush":{"daisybush","daisybushes"},
"dak":{"dak","daks"},
"dakar":{"dakar","dakars"},
"dakoit":{"dakoit","dakoits"},
"dakoity":{"dakoities","dakoity"},
"dakota":{"dakota","dakotas"},
"dal":{"dal","dals"},
"dalasi":{"dalasi","dalasis"},
"dalbergia":{"dalbergia","dalbergias"},
"dale":{"dale","dales"},
"dalea":{"dalea","daleas"},
"dalesman":{"dalesman","dalesmen"},
"dalliance":{"dalliance","dalliances"},
"dallier":{"dallier","dalliers"},
"dallisgrass":{"dallisgrass","dallisgrasses"},
"dally":{"dallied","dallies","dally","dallying"},
"dalmatian":{"dalmatian","dalmatians"},
"dalo":{"dalo","dalos"},
"dalton":{"dalton","daltons"},
"daltonism":{"daltonism","daltonisms"},
"dam":{"dam","dammed","damming","dams"},
"dama":{"dama","damas"},
"damage":{"damage","damaged","damages","damaging"},
"damages":{"damages","damageses"},
"damaliscus":{"damaliscus","damaliscuses"},
"damar":{"damar","damars"},
"damara":{"damara","damaras"},
"damascene":{"damascene","damascened","damascening"},
"damascus":{"damascus","damascuses"},
"damask":{"damask","damasked","damasking"},
"dame":{"dame","dames"},
"damgalnunna":{"damgalnunna","damgalnunnas"},
"daminozide":{"daminozide","daminozides"},
"damkina":{"damkina","damkinas"},
"dammar":{"dammar","dammars"},
"damn":{"damn","damned","damning","damns"},
"damnation":{"damnation","damnations"},
"damned":{"damndest","damned","damneder","damnedest"},
"damnify":{"damnified","damnifies","damnify","damnifying"},
"damoiselle":{"damoiselle","damoiselles"},
"damosel":{"damosel","damosels"},
"damozel":{"damozel","damozels"},
"damp":{"damp","damped","damper","dampest","damping","damps"},
"dampen":{"dampen","dampened","dampening","dampens"},
"dampening":{"dampening","dampenings"},
"dampness":{"dampness","dampnesses"},
"damsel":{"damsel","damsels"},
"damselfish":{"damselfish","damselfishes"},
"damselfly":{"damselflies","damselfly"},
"damson":{"damson","damsons"},
"dana":{"dana","danas"},
"danaea":{"danaea","danaeas"},
"danaid":{"danaid","danaids"},
"danaidae":{"danaidae","danaidaes"},
"danaus":{"danaus","danauses"},
"dance":{"dance","danced","dances","dancing"},
"dancer":{"dancer","dancers"},
"dancing":{"dancing","dancings"},
"dandelion":{"dandelion","dandelions"},
"dander":{"dander","danders"},
"dandify":{"dandified","dandifies","dandify","dandifying"},
"dandle":{"dandle","dandled","dandling"},
"dandy":{"dandier","dandies","dandiest","dandy"},
"danewort":{"danewort","daneworts"},
"dangaleat":{"dangaleat","dangaleats"},
"danger":{"danger","dangers"},
"dangla":{"dangla","danglas"},
"dangle":{"dangle","dangled","dangles","dangling"},
"dangleberry":{"dangleberries","dangleberry"},
"dangling":{"dangling","danglings"},
"danio":{"danio","danios"},
"danish":{"danish","danishes"},
"dank":{"dank","danker","dankest"},
"dankness":{"dankness","danknesses"},
"danmark":{"danmark","danmarks"},
"dano-norwegian":{"dano-norwegian","dano-norwegians"},
"danseur":{"danseur","danseurs"},
"danseuse":{"danseuse","danseuses"},
"dante":{"dante","dantes"},
"danu":{"danu","danus"},
"danube":{"danube","danubes"},
"danzig":{"danzig","danzigs"},
"daoism":{"daoism","daoisms"},
"dap":{"dap","dapped","dapping","daps"},
"daphnia":{"daphnia","daphnias"},
"dapperness":{"dapperness","dappernesses"},
"dapple":{"dapple","dappled","dapples","dappling"},
"dapple-gray":{"dapple-gray","dapple-grays"},
"dapple-grey":{"dapple-grey","dapple-greys"},
"dappled-gray":{"dappled-gray","dappled-grays"},
"dappled-grey":{"dappled-grey","dappled-greys"},
"dapsang":{"dapsang","dapsangs"},
"dard":{"dard","dards"},
"dardanelles":{"dardanelles","dardanelleses"},
"dardic":{"dardic","dardics"},
"dare":{"dare","dared","dares","daring"},
"daredevil":{"daredevil","daredevils"},
"daredevilry":{"daredevilries","daredevilry"},
"daredeviltry":{"daredeviltries","daredeviltry"},
"dari":{"dari","daris"},
"daring":{"daring","darings"},
"dark":{"dark","darker","darkest","darks"},
"darken":{"darken","darkened","darkening","darkens"},
"darkening":{"darkening","darkenings"},
"darkey":{"darkey","darkeys"},
"darkie":{"darkie","darkies"},
"darkle":{"darkle","darkled","darkling"},
"darkness":{"darkness","darknesses"},
"darky":{"darkies","darky"},
"darling":{"darling","darlings"},
"darlingtonia":{"darlingtonia","darlingtonias"},
"darmera":{"darmera","darmeras"},
"darn":{"darn","darned","darning","darns"},
"darnel":{"darnel","darnels"},
"dart":{"dart","darted","darting","darts"},
"dartboard":{"dartboard","dartboards"},
"darter":{"darter","darters"},
"darvon":{"darvon","darvons"},
"darwin":{"darwin","darwins"},
"das":{"das","dases"},
"dash":{"dash","dashed","dashes","dashing"},
"dashboard":{"dashboard","dashboards"},
"dasheen":{"dasheen","dasheens"},
"dashiki":{"dashiki","dashikis"},
"dassie":{"dassie","dassies"},
"dasyatidae":{"dasyatidae","dasyatidaes"},
"dasyatis":{"dasyatis","dasyatises"},
"dasypodidae":{"dasypodidae","dasypodidaes"},
"dasyprocta":{"dasyprocta","dasyproctas"},
"dasyproctidae":{"dasyproctidae","dasyproctidaes"},
"dasypus":{"dasypus","dasypuses"},
"dasyurid":{"dasyurid","dasyurids"},
"dasyuridae":{"dasyuridae","dasyuridaes"},
"dasyurus":{"dasyurus","dasyuruses"},
"dat":{"dat","dats"},
"data":{"data","datas"},
"datary":{"dataries","datary"},
"date":{"date","dated","dates","dating"},
"dateline":{"dateline","datelined","datelines","datelining"},
"dative":{"dative","datives"},
"dato":{"dato","datos"},
"datril":{"datril","datrils"},
"datum":{"data","datum","datums"},
"datura":{"datura","daturas"},
"daub":{"daub","daubed","daubing","daubs"},
"daubentonia":{"daubentonia","daubentonias"},
"daubentoniidae":{"daubentoniidae","daubentoniidaes"},
"daubing":{"daubing","daubings"},
"daucus":{"daucus","daucuses"},
"daughter":{"daughter","daughters"},
"daughter-in-law":{"daughter-in-law","daughters-in-law"},
"daunt":{"daunt","daunted","daunting","daunts"},
"dauntlessness":{"dauntlessness","dauntlessnesses"},
"davalliaceae":{"davalliaceae","davalliaceaes"},
"daviesia":{"daviesia","daviesias"},
"daw":{"daw","daws"},
"dawdle":{"dawdle","dawdled","dawdles","dawdling"},
"dawdler":{"dawdler","dawdlers"},
"dawdling":{"dawdling","dawdlings"},
"dawn":{"dawn","dawned","dawning","dawns"},
"dawning":{"dawning","dawnings"},
"day":{"day","days"},
"dayak":{"dayak","dayaks"},
"daybed":{"daybed","daybeds"},
"daybook":{"daybook","daybooks"},
"daybreak":{"daybreak","daybreaks"},
"daycare":{"daycare","daycares"},
"daydream":{"daydream","daydreamed","daydreaming","daydreams"},
"daydreamer":{"daydreamer","daydreamers"},
"dayflower":{"dayflower","dayflowers"},
"dayfly":{"dayflies","dayfly"},
"daylight":{"daylight","daylights"},
"daylily":{"daylilies","daylily"},
"daypro":{"daypro","daypros"},
"days":{"days","dayses"},
"dayspring":{"dayspring","daysprings"},
"daytime":{"daytime","daytimes"},
"daze":{"daze","dazed","dazes","dazing"},
"dazzle":{"dazzle","dazzled","dazzles","dazzling"},
"db":{"db","dbs"},
"dbms":{"dbms","dbmses"},
"dc":{"dc","dcs"},
"dd":{"dd","dds"},
"dds":{"dds","ddses"},
"de-emphasize":{"de-emphasize","de-emphasized","de-emphasizes","de-emphasizing"},
"de-escalate":{"de-escalate","de-escalated","de-escalates","de-escalating"},
"deacon":{"deacon","deaconed","deaconing","deacons"},
"deaconry":{"deaconries","deaconry"},
"deactivate":{"deactivate","deactivated","deactivates","deactivating"},
"deactivation":{"deactivation","deactivations"},
"deadbeat":{"deadbeat","deadbeats"},
"deadbolt":{"deadbolt","deadbolts"},
"deaden":{"deaden","deadened","deadening","deadens"},
"deadend":{"deadend","deadends"},
"deadening":{"deadening","deadenings"},
"deadeye":{"deadeye","deadeyes"},
"deadline":{"deadline","deadlines"},
"deadliness":{"deadliness","deadlinesses"},
"deadlock":{"deadlock","deadlocked","deadlocking","deadlocks"},
"deadly":{"deadlier","deadliest","deadly"},
"deaerate":{"deaerate","deaerated","deaerating"},
"deaf":{"deaf","deafer","deafest","deafs"},
"deaf-aid":{"deaf-aid","deaf-aids"},
"deaf-mute":{"deaf-mute","deaf-mutes"},
"deaf-muteness":{"deaf-muteness","deaf-mutenesses"},
"deaf-mutism":{"deaf-mutism","deaf-mutisms"},
"deafen":{"deafen","deafened","deafening","deafens"},
"deal":{"deal","dealing","deals","dealt"},
"dealer":{"dealer","dealers"},
"dealership":{"dealership","dealerships"},
"dealfish":{"dealfish","dealfishes"},
"dealing":{"dealing","dealings"},
"dealings":{"dealings","dealingses"},
"deaminate":{"deaminate","deaminated","deaminating"},
"deaminize":{"deaminize","deaminized","deaminizes","deaminizing"},
"dean":{"dean","deans"},
"deanery":{"deaneries","deanery"},
"deanship":{"deanship","deanships"},
"dear":{"dear","dearer","dearest","dears"},
"dearest":{"dearest","dearests"},
"dearie":{"dearie","dearies"},
"dearness":{"dearness","dearnesses"},
"dearth":{"dearth","dearths"},
"deary":{"dearies","deary"},
"death":{"death","deaths"},
"deathbed":{"deathbed","deathbeds"},
"deathblow":{"deathblow","deathblows"},
"deathrate":{"deathrate","deathrates"},
"deathwatch":{"deathwatch","deathwatches"},
"deb":{"deb","debs"},
"debacle":{"debacle","debacles"},
"debar":{"debar","debarred","debarring","debars"},
"debark":{"debark","debarked","debarking","debarks"},
"debarkation":{"debarkation","debarkations"},
"debarment":{"debarment","debarments"},
"debarring":{"debarring","debarrings"},
"debase":{"debase","debased","debases","debasing"},
"debasement":{"debasement","debasements"},
"debate":{"debate","debated","debates","debating"},
"debater":{"debater","debaters"},
"debauch":{"debauch","debauched","debauches","debauching"},
"debauchee":{"debauchee","debauchees"},
"debaucher":{"debaucher","debauchers"},
"debauchery":{"debaucheries","debauchery"},
"debenture":{"debenture","debentures"},
"debilitate":{"debilitate","debilitated","debilitates","debilitating"},
"debilitation":{"debilitation","debilitations"},
"debility":{"debilities","debility"},
"debit":{"debit","debited","debiting","debits"},
"debouch":{"debouch","debouched","debouches","debouching"},
"debrief":{"debrief","debriefed","debriefing"},
"debris":{"debris","debrises"},
"debt":{"debt","debts"},
"debtor":{"debtor","debtors"},
"debug":{"debug","debugged","debugging","debugs"},
"debunk":{"debunk","debunked","debunking","debunks"},
"debunking":{"debunking","debunkings"},
"debus":{"debus","debused","debuses","debusing","debussed","debusses","debussing"},
"debut":{"debut","debuts"},
"debutante":{"debutante","debutantes"},
"dec":{"dec","decs"},
"decade":{"decade","decades"},
"decadency":{"decadencies","decadency"},
"decadent":{"decadent","decadents"},
"decadron":{"decadron","decadrons"},
"decaf":{"decaf","decafs"},
"decagram":{"decagram","decagrams"},
"decahedron":{"decahedra","decahedron","decahedrons"},
"decal":{"decal","decals"},
"decalcify":{"decalcified","decalcifies","decalcify","decalcifying"},
"decalcomania":{"decalcomania","decalcomanias"},
"decaliter":{"decaliter","decaliters"},
"decalitre":{"decalitre","decalitres"},
"decalogue":{"decalogue","decalogues"},
"decameter":{"decameter","decameters"},
"decametre":{"decametre","decametres"},
"decamp":{"decamp","decamped","decamping","decamps"},
"decampment":{"decampment","decampments"},
"decant":{"decant","decanted","decanting","decants"},
"decanter":{"decanter","decanters"},
"decapitate":{"decapitate","decapitated","decapitates","decapitating"},
"decapitation":{"decapitation","decapitations"},
"decapod":{"decapod","decapods"},
"decapoda":{"decapoda","decapodas"},
"decapterus":{"decapterus","decapteruses"},
"decarbonate":{"decarbonate","decarbonated","decarbonating"},
"decarbonize":{"decarbonize","decarbonized","decarbonizes","decarbonizing"},
"decarburize":{"decarburize","decarburized","decarburizes","decarburizing"},
"decasualize":{"decasualize","decasualized","decasualizing"},
"decay":{"decay","decayed","decaying","decays"},
"decease":{"decease","deceased","deceases","deceasing"},
"deceased":{"deceased","deceaseds"},
"decedent":{"decedent","decedents"},
"deceit":{"deceit","deceits"},
"deceitfulness":{"deceitfulness","deceitfulnesses"},
"deceive":{"deceive","deceived","deceives","deceiving"},
"deceiver":{"deceiver","deceivers"},
"decelerate":{"decelerate","decelerated","decelerates","decelerating"},
"deceleration":{"deceleration","decelerations"},
"december":{"december","decembers"},
"decemvir":{"decemvir","decemviri","decemvirs"},
"decency":{"decencies","decency"},
"decennary":{"decennaries","decennary"},
"decennium":{"decennium","decenniums"},
"decentralisation":{"decentralisation","decentralisations"},
"decentralization":{"decentralization","decentralizations"},
"decentralize":{"decentralize","decentralized","decentralizes","decentralizing"},
"deception":{"deception","deceptions"},
"deceptiveness":{"deceptiveness","deceptivenesses"},
"decibel":{"decibel","decibels"},
"decide":{"decide","decided","decides","deciding"},
"deciding":{"deciding","decidings"},
"decidua":{"decidua","deciduae","deciduas"},
"decigram":{"decigram","decigrams"},
"deciliter":{"deciliter","deciliters"},
"decilitre":{"decilitre","decilitres"},
"decimal":{"decimal","decimals"},
"decimalisation":{"decimalisation","decimalisations"},
"decimalization":{"decimalization","decimalizations"},
"decimalize":{"decimalize","decimalized","decimalizes","decimalizing"},
"decimate":{"decimate","decimated","decimates","decimating"},
"decimeter":{"decimeter","decimeters"},
"decimetre":{"decimetre","decimetres"},
"decipher":{"decipher","deciphered","deciphering","deciphers"},
"decipherment":{"decipherment","decipherments"},
"decision":{"decision","decisions"},
"decisiveness":{"decisiveness","decisivenesses"},
"deck":{"deck","decked","decking","decks"},
"deckhand":{"deckhand","deckhands"},
"deckhouse":{"deckhouse","deckhouses"},
"deckle":{"deckle","deckles"},
"declaim":{"declaim","declaimed","declaiming","declaims"},
"declaration":{"declaration","declarations"},
"declarative":{"declarative","declaratives"},
"declare":{"declare","declared","declares","declaring"},
"declass":{"declass","declassed","declassing"},
"declassify":{"declassified","declassifies","declassify","declassifying"},
"declination":{"declination","declinations"},
"decline":{"decline","declined","declines","declining"},
"declinometer":{"declinometer","declinometers"},
"declivity":{"declivities","declivity"},
"decoagulant":{"decoagulant","decoagulants"},
"decoct":{"decoct","decocted","decocting","decocts"},
"decode":{"decode","decoded","decodes","decoding"},
"decoding":{"decoding","decodings"},
"decollate":{"decollate","decollated","decollating"},
"decolonisation":{"decolonisation","decolonisations"},
"decolonization":{"decolonization","decolonizations"},
"decolonize":{"decolonize","decolonized","decolonizing"},
"decolor":{"decolor","decolored","decoloring","decolors"},
"decommission":{"decommission","decommissioned","decommissioning"},
"decompose":{"decompose","decomposed","decomposes","decomposing"},
"decomposition":{"decomposition","decompositions"},
"decompound":{"decompound","decompounded","decompounding"},
"decompress":{"decompress","decompressed","decompresses","decompressing"},
"decompressing":{"decompressing","decompressings"},
"decompression":{"decompression","decompressions"},
"deconcentrate":{"deconcentrate","deconcentrated","deconcentrates","deconcentrating"},
"decongest":{"decongest","decongested","decongesting"},
"deconstruction":{"deconstruction","deconstructions"},
"deconstructionism":{"deconstructionism","deconstructionisms"},
"decontaminate":{"decontaminate","decontaminated","decontaminating"},
"decontrol":{"decontrol","decontrolled","decontrolling","decontrols"},
"decor":{"decor","decors"},
"decorate":{"decorate","decorated","decorates","decorating"},
"decoration":{"decoration","decorations"},
"decorator":{"decorator","decorators"},
"decorousness":{"decorousness","decorousnesses"},
"decorticate":{"decorticate","decorticated","decorticating"},
"decorum":{"decorum","decorums"},
"decouple":{"decouple","decoupled","decoupling"},
"decoy":{"decoy","decoyed","decoying","decoys"},
"decrease":{"decrease","decreased","decreases","decreasing"},
"decree":{"decree","decreed","decreeing","decrees"},
"decrement":{"decrement","decrements"},
"decrepitate":{"decrepitate","decrepitated","decrepitates","decrepitating"},
"decrepitude":{"decrepitude","decrepitudes"},
"decrescendo":{"decrescendi","decrescendo","decrescendos"},
"decry":{"decried","decries","decry","decrying"},
"decrypt":{"decrypt","decrypted","decrypting"},
"decryption":{"decryption","decryptions"},
"decumaria":{"decumaria","decumarias"},
"decumary":{"decumaries","decumary"},
"decury":{"decuries","decury"},
"decussate":{"decussate","decussated","decussating"},
"ded":{"ded","deds"},
"dedicate":{"dedicate","dedicated","dedicates","dedicating"},
"dedication":{"dedication","dedications"},
"dedicator":{"dedicator","dedicators"},
"deduce":{"deduce","deduced","deduces","deducing"},
"deduct":{"deduct","deducted","deducting","deducts"},
"deductible":{"deductible","deductibles"},
"deduction":{"deduction","deductions"},
"deed":{"deed","deeded","deeding","deeds"},
"deedbox":{"deedbox","deedboxes"},
"deeds":{"deeds","deedses"},
"deem":{"deem","deemed","deeming","deems"},
"deep":{"deep","deeper","deepest","deeps"},
"deep-fry":{"deep-fried","deep-fries","deep-fry","deep-frying"},
"deep-kiss":{"deep-kiss","deep-kissed","deep-kissing"},
"deep-six":{"deep-six","deep-sixed","deep-sixes","deep-sixing"},
"deepen":{"deepen","deepened","deepening","deepens"},
"deepfreeze":{"deepfreeze","deepfreezed","deepfreezes","deepfreezing","deepfroze","deepfrozen"},
"deepness":{"deepness","deepnesses"},
"deer":{"deer","deers"},
"deerberry":{"deerberries","deerberry"},
"deerhound":{"deerhound","deerhounds"},
"deface":{"deface","defaced","defaces","defacing"},
"defacement":{"defacement","defacements"},
"defalcate":{"defalcate","defalcated","defalcating"},
"defalcation":{"defalcation","defalcations"},
"defamation":{"defamation","defamations"},
"defame":{"defame","defamed","defames","defaming"},
"defamer":{"defamer","defamers"},
"defang":{"defang","defanged","defanging"},
"defat":{"defat","defatted","defatting"},
"default":{"default","defaulted","defaulting","defaults"},
"defaulter":{"defaulter","defaulters"},
"defeat":{"defeat","defeated","defeating","defeats"},
"defeated":{"defeated","defeateds"},
"defeatist":{"defeatist","defeatists"},
"defecate":{"defecate","defecated","defecates","defecating"},
"defecation":{"defecation","defecations"},
"defect":{"defect","defected","defecting","defects"},
"defection":{"defection","defections"},
"defective":{"defective","defectives"},
"defectiveness":{"defectiveness","defectivenesses"},
"defector":{"defector","defectors"},
"defence":{"defence","defences"},
"defencelessness":{"defencelessness","defencelessnesses"},
"defend":{"defend","defended","defending","defends"},
"defendant":{"defendant","defendants"},
"defender":{"defender","defenders"},
"defense":{"defense","defensed","defenses","defensing"},
"defenselessness":{"defenselessness","defenselessnesses"},
"defensive":{"defensive","defensives"},
"defer":{"defer","deferred","deferring","defers"},
"deference":{"deference","deferences"},
"deferment":{"deferment","deferments"},
"deferral":{"deferral","deferrals"},
"defiance":{"defiance","defiances"},
"deficiency":{"deficiencies","deficiency"},
"deficit":{"deficit","deficits"},
"defilade":{"defilade","defiladed","defilading"},
"defile":{"defile","defiled","defiles","defiling"},
"defilement":{"defilement","defilements"},
"define":{"define","defined","defines","defining"},
"definiendum":{"definienda","definiendum"},
"definiens":{"definiens","definientia"},
"defining":{"defining","definings"},
"definiteness":{"definiteness","definitenesses"},
"definition":{"definition","definitions"},
"deflagrate":{"deflagrate","deflagrated","deflagrating"},
"deflate":{"deflate","deflated","deflates","deflating"},
"deflect":{"deflect","deflected","deflecting","deflects"},
"deflection":{"deflection","deflections"},
"deflexion":{"deflexion","deflexions"},
"deflower":{"deflower","deflowered","deflowering","deflowers"},
"defog":{"defog","defogged","defogging"},
"defoliate":{"defoliate","defoliated","defoliates","defoliating"},
"deforce":{"deforce","deforced","deforcing"},
"deforest":{"deforest","deforested","deforesting","deforests"},
"deforestation":{"deforestation","deforestations"},
"deform":{"deform","deformed","deforming","deforms"},
"deformation":{"deformation","deformations"},
"deformity":{"deformities","deformity"},
"defraud":{"defraud","defrauded","defrauding","defrauds"},
"defray":{"defray","defrayed","defraying"},
"defrayal":{"defrayal","defrayals"},
"defrayment":{"defrayment","defrayments"},
"defrock":{"defrock","defrocked","defrocking","defrocks"},
"defrost":{"defrost","defrosted","defrosting","defrosts"},
"defroster":{"defroster","defrosters"},
"deft":{"deft","defter","deftest"},
"deftness":{"deftness","deftnesses"},
"defunctness":{"defunctness","defunctnesses"},
"defuse":{"defuse","defused","defusing"},
"defusing":{"defusing","defusings"},
"defy":{"defied","defies","defy","defying"},
"degas":{"degas","degases","degassed","degasses","degassing"},
"degauss":{"degauss","degaussed","degausses","degaussing"},
"degeneracy":{"degeneracies","degeneracy"},
"degenerate":{"degenerate","degenerated","degenerates","degenerating"},
"degeneration":{"degeneration","degenerations"},
"deglutition":{"deglutition","deglutitions"},
"degradation":{"degradation","degradations"},
"degrade":{"degrade","degraded","degrades","degrading"},
"degrease":{"degrease","degreased","degreasing"},
"degree":{"degree","degrees"},
"degum":{"degum","degummed","degumming"},
"degust":{"degust","degusted","degusting"},
"dehisce":{"dehisce","dehisced","dehiscing"},
"dehorn":{"dehorn","dehorned","dehorning"},
"dehort":{"dehort","dehorted","dehorting"},
"dehumanisation":{"dehumanisation","dehumanisations"},
"dehumanization":{"dehumanization","dehumanizations"},
"dehumanize":{"dehumanize","dehumanized","dehumanizing"},
"dehumidify":{"dehumidified","dehumidifies","dehumidify","dehumidifying"},
"dehydrate":{"dehydrate","dehydrated","dehydrates","dehydrating"},
"dehydration":{"dehydration","dehydrations"},
"dehydrogenate":{"dehydrogenate","dehydrogenated","dehydrogenating"},
"dehydrogenize":{"dehydrogenize","dehydrogenized","dehydrogenizes","dehydrogenizing"},
"dehydroretinol":{"dehydroretinol","dehydroretinols"},
"deice":{"deice","deiced","deices","deicing"},
"deicer":{"deicer","deicers"},
"deictic":{"deictic","deictics"},
"deification":{"deification","deifications"},
"deify":{"deified","deifies","deify","deifying"},
"deign":{"deign","deigned","deigning","deigns"},
"deionize":{"deionize","deionized","deionizing"},
"deism":{"deism","deisms"},
"deist":{"deist","deists"},
"deity":{"deities","deity"},
"deject":{"deject","dejected","dejecting","dejects"},
"dejection":{"dejection","dejections"},
"dejeuner":{"dejeuner","dejeuners"},
"dekagram":{"dekagram","dekagrams"},
"dekaliter":{"dekaliter","dekaliters"},
"dekalitre":{"dekalitre","dekalitres"},
"dekameter":{"dekameter","dekameters"},
"dekametre":{"dekametre","dekametres"},
"dekko":{"dekko","dekkos"},
"delairea":{"delairea","delaireas"},
"delaminate":{"delaminate","delaminated","delaminates","delaminating"},
"delate":{"delate","delated","delating"},
"delaware":{"delaware","delawares"},
"delawarean":{"delawarean","delawareans"},
"delawarian":{"delawarian","delawarians"},
"delay":{"delay","delayed","delaying","delays"},
"dele":{"dele","deled","deleing","deles"},
"delectability":{"delectabilities","delectability"},
"delectate":{"delectate","delectated","delectating"},
"delectation":{"delectation","delectations"},
"delegacy":{"delegacies","delegacy"},
"delegalize":{"delegalize","delegalized","delegalizing"},
"delegate":{"delegate","delegated","delegates","delegating"},
"delegating":{"delegating","delegatings"},
"delegation":{"delegation","delegations"},
"delete":{"delete","deleted","deletes","deleting"},
"deletion":{"deletion","deletions"},
"delhi":{"delhi","delhis"},
"deli":{"deli","delis"},
"deliberate":{"deliberate","deliberated","deliberates","deliberating"},
"deliberateness":{"deliberateness","deliberatenesses"},
"deliberation":{"deliberation","deliberations"},
"delicacy":{"delicacies","delicacy"},
"delicatessen":{"delicatessen","delicatessens"},
"delichon":{"delichon","delichons"},
"deliciousness":{"deliciousness","deliciousnesses"},
"delight":{"delight","delighted","delighting","delights"},
"delilah":{"delilah","delilahs"},
"delimit":{"delimit","delimited","delimiting","delimits"},
"delimitate":{"delimitate","delimitated","delimitates","delimitating"},
"delimitation":{"delimitation","delimitations"},
"delineate":{"delineate","delineated","delineates","delineating"},
"delineation":{"delineation","delineations"},
"delinquency":{"delinquencies","delinquency"},
"delinquent":{"delinquent","delinquents"},
"delirium":{"deliria","delirium","deliriums"},
"deliver":{"deliver","delivered","delivering","delivers"},
"deliverance":{"deliverance","deliverances"},
"deliverer":{"deliverer","deliverers"},
"delivery":{"deliveries","delivery"},
"deliveryman":{"deliveryman","deliverymen"},
"dell":{"dell","dells"},
"delocalize":{"delocalize","delocalized","delocalizes","delocalizing"},
"delonix":{"delonix","delonixes"},
"delouse":{"delouse","deloused","delousing"},
"delphinapterus":{"delphinapterus","delphinapteruses"},
"delphinidae":{"delphinidae","delphinidaes"},
"delphinium":{"delphiniia","delphiniua","delphinium","delphiniums"},
"delphinus":{"delphinus","delphinuses"},
"delta":{"delta","deltas"},
"deltoid":{"deltoid","deltoids"},
"delude":{"delude","deluded","deludes","deluding"},
"deluge":{"deluge","deluged","deluges","deluging"},
"delusion":{"delusion","delusions"},
"delve":{"delve","delved","delves","delving"},
"demagnetize":{"demagnetize","demagnetized","demagnetizes","demagnetizing"},
"demagog":{"demagog","demagogs"},
"demagogue":{"demagogue","demagogues"},
"demagoguery":{"demagogueries","demagoguery"},
"demagogy":{"demagogies","demagogy"},
"demand":{"demand","demanded","demanding","demands"},
"demarcate":{"demarcate","demarcated","demarcates","demarcating"},
"demarcation":{"demarcation","demarcations"},
"demarche":{"demarche","demarches"},
"dematerialize":{"dematerialize","dematerialized","dematerializing"},
"dematiaceae":{"dematiaceae","dematiaceaes"},
"demean":{"demean","demeaned","demeaning","demeans"},
"demeanor":{"demeanor","demeanors"},
"demeanour":{"demeanour","demeanours"},
"dementedness":{"dementedness","dementednesses"},
"dementia":{"dementia","dementias"},
"demerit":{"demerit","demerits"},
"demerol":{"demerol","demerols"},
"demesne":{"demesne","demesnes"},
"demetrius":{"demetrius","demetriuses"},
"demi-glaze":{"demi-glaze","demi-glazes"},
"demiglace":{"demiglace","demiglaces"},
"demigod":{"demigod","demigods"},
"demilitarize":{"demilitarize","demilitarized","demilitarizes","demilitarizing"},
"demineralize":{"demineralize","demineralized","demineralizing"},
"demise":{"demise","demised","demises","demising"},
"demisemiquaver":{"demisemiquaver","demisemiquavers"},
"demit":{"demit","demits","demitted","demitting"},
"demitasse":{"demitasse","demitasses"},
"demo":{"demo","demos"},
"demob":{"demob","demobbed","demobbing","demobs"},
"demobilisation":{"demobilisation","demobilisations"},
"demobilization":{"demobilization","demobilizations"},
"demobilize":{"demobilize","demobilized","demobilizes","demobilizing"},
"demochelys":{"demochelys","demochelyses"},
"democracy":{"democracies","democracy"},
"democrat":{"democrat","democrats"},
"democratisation":{"democratisation","democratisations"},
"democratization":{"democratization","democratizations"},
"democratize":{"democratize","democratized","democratizing"},
"demodulate":{"demodulate","demodulated","demodulating"},
"demodulator":{"demodulator","demodulators"},
"demographer":{"demographer","demographers"},
"demographist":{"demographist","demographists"},
"demography":{"demographies","demography"},
"demoiselle":{"demoiselle","demoiselles"},
"demolish":{"demolish","demolished","demolishes","demolishing"},
"demolishing":{"demolishing","demolishings"},
"demolition":{"demolition","demolitions"},
"demon":{"demon","demons"},
"demonetisation":{"demonetisation","demonetisations"},
"demonetization":{"demonetization","demonetizations"},
"demonetize":{"demonetize","demonetized","demonetizing"},
"demonism":{"demonism","demonisms"},
"demonolatry":{"demonolatries","demonolatry"},
"demonstrability":{"demonstrabilities","demonstrability"},
"demonstrate":{"demonstrate","demonstrated","demonstrates","demonstrating"},
"demonstration":{"demonstration","demonstrations"},
"demonstrationist":{"demonstrationist","demonstrationists"},
"demonstrative":{"demonstrative","demonstratives"},
"demonstrator":{"demonstrator","demonstrators"},
"demoralize":{"demoralize","demoralized","demoralizes","demoralizing"},
"demote":{"demote","demoted","demotes","demoting"},
"demotic":{"demotic","demotics"},
"demount":{"demount","demounted","demounting"},
"demulsify":{"demulsified","demulsifies","demulsify","demulsifying"},
"demur":{"demur","demurred","demurring","demurs"},
"demure":{"demure","demurer","demurest"},
"demureness":{"demureness","demurenesses"},
"demurral":{"demurral","demurrals"},
"demurrer":{"demurrer","demurrers"},
"demy":{"demies","demy"},
"demystify":{"demystified","demystifies","demystify","demystifying"},
"demythologisation":{"demythologisation","demythologisations"},
"demythologization":{"demythologization","demythologizations"},
"demythologize":{"demythologize","demythologized","demythologizing"},
"den":{"den","denned","denning","dens"},
"denarius":{"denarii","denarius","denarnarii"},
"denationalisation":{"denationalisation","denationalisations"},
"denationalization":{"denationalization","denationalizations"},
"denationalize":{"denationalize","denationalized","denationalizing"},
"denaturalize":{"denaturalize","denaturalized","denaturalizing"},
"denature":{"denature","denatured","denaturing"},
"denazify":{"denazified","denazifies","denazify","denazifying"},
"dendranthema":{"dendranthema","dendranthemas"},
"dendraspis":{"dendraspis","dendraspises"},
"dendroaspis":{"dendroaspis","dendroaspises"},
"dendrocalamus":{"dendrocalamus","dendrocalamuses"},
"dendrocolaptes":{"dendrocolaptes","dendrocolapteses"},
"dendrocolaptidae":{"dendrocolaptidae","dendrocolaptidaes"},
"dendroctonus":{"dendroctonus","dendroctonuses"},
"dendroica":{"dendroica","dendroicas"},
"dendrolagus":{"dendrolagus","dendrolaguses"},
"dendromecon":{"dendromecon","dendromecons"},
"denervate":{"denervate","denervated","denervating"},
"dengue":{"dengue","dengues"},
"denial":{"denial","denials"},
"denigrate":{"denigrate","denigrated","denigrates","denigrating"},
"denigration":{"denigration","denigrations"},
"denim":{"denim","denims"},
"denisonia":{"denisonia","denisonias"},
"denitrify":{"denitrified","denitrifies","denitrify","denitrifying"},
"denizen":{"denizen","denizened","denizening","denizens"},
"denmark":{"denmark","denmarks"},
"dennstaedtia":{"dennstaedtia","dennstaedtias"},
"dennstaedtiaceae":{"dennstaedtiaceae","dennstaedtiaceaes"},
"denominate":{"denominate","denominated","denominates","denominating"},
"denomination":{"denomination","denominations"},
"denominationalism":{"denominationalism","denominationalisms"},
"denotation":{"denotation","denotations"},
"denote":{"denote","denoted","denotes","denoting"},
"denounce":{"denounce","denounced","denounces","denouncing"},
"denouncement":{"denouncement","denouncements"},
"dense":{"dense","denser","densest"},
"denseness":{"denseness","densenesses"},
"densification":{"densification","densifications"},
"density":{"densities","density"},
"dent":{"dent","dented","denting","dents"},
"dental":{"dental","dentals"},
"dentalium":{"dentalia","dentalium","dentaliums"},
"dentaria":{"dentaria","dentarias"},
"dentin":{"dentin","dentins"},
"dentine":{"dentine","dentines"},
"dentist":{"dentist","dentists"},
"dentistry":{"dentistries","dentistry"},
"denture":{"denture","dentures"},
"denturist":{"denturist","denturists"},
"denuclearize":{"denuclearize","denuclearized","denuclearizing"},
"denudate":{"denudate","denudated","denudates","denudating"},
"denudation":{"denudation","denudations"},
"denude":{"denude","denuded","denudes","denuding"},
"denunciate":{"denunciate","denunciated","denunciating"},
"denunciation":{"denunciation","denunciations"},
"denver":{"denver","denvers"},
"deny":{"denied","denies","deny","denying"},
"deodar":{"deodar","deodars"},
"deodorize":{"deodorize","deodorized","deodorizing"},
"deoxidize":{"deoxidize","deoxidized","deoxidizes","deoxidizing"},
"deoxyephedrine":{"deoxyephedrine","deoxyephedrines"},
"deoxygenate":{"deoxygenate","deoxygenated","deoxygenating"},
"deparia":{"deparia","deparias"},
"depart":{"depart","departed","departing","departs"},
"departed":{"departed","departeds"},
"departer":{"departer","departers"},
"department":{"department","departments"},
"departmentalize":{"departmentalize","departmentalized","departmentalizing"},
"departure":{"departure","departures"},
"depend":{"depend","depended","depending"},
"dependability":{"dependabilities","dependability"},
"dependableness":{"dependableness","dependablenesses"},
"dependance":{"dependance","dependances"},
"dependancy":{"dependancies","dependancy"},
"dependant":{"dependant","dependants"},
"dependence":{"dependence","dependences"},
"dependency":{"dependencies","dependency"},
"dependent":{"dependent","dependents"},
"depersonalize":{"depersonalize","depersonalized","depersonalizing"},
"depict":{"depict","depicted","depicting","depicts"},
"depicting":{"depicting","depictings"},
"depiction":{"depiction","depictions"},
"depilate":{"depilate","depilated","depilating"},
"depilatory":{"depilatories","depilatory"},
"deplane":{"deplane","deplaned","deplaning"},
"deplenish":{"deplenish","deplenished","deplenishes","deplenishing"},
"deplete":{"deplete","depleted","depletes","depleting"},
"deplore":{"deplore","deplored","deplores","deploring"},
"deploy":{"deploy","deployed","deploying"},
"deplume":{"deplume","deplumed","deplumes","depluming"},
"depolarize":{"depolarize","depolarized","depolarizing"},
"depone":{"depone","deponed","depones","deponing"},
"deponent":{"deponent","deponents"},
"depopulate":{"depopulate","depopulated","depopulates","depopulating"},
"deport":{"deport","deported","deporting","deports"},
"deportation":{"deportation","deportations"},
"deportee":{"deportee","deportees"},
"deportment":{"deportment","deportments"},
"depose":{"depose","deposed","deposes","deposing"},
"deposit":{"deposit","deposited","depositing","deposits"},
"depositary":{"depositaries","depositary"},
"deposition":{"deposition","depositions"},
"depositor":{"depositor","depositors"},
"depository":{"depositories","depository"},
"depot":{"depot","depots"},
"deprave":{"deprave","depraved","depraves","depraving"},
"depravity":{"depravities","depravity"},
"deprecate":{"deprecate","deprecated","deprecates","deprecating"},
"deprecation":{"deprecation","deprecations"},
"depreciate":{"depreciate","depreciated","depreciates","depreciating"},
"depreciation":{"depreciation","depreciations"},
"depreciator":{"depreciator","depreciators"},
"depredate":{"depredate","depredated","depredating"},
"depredation":{"depredation","depredations"},
"depress":{"depress","depressed","depresses","depressing"},
"depressant":{"depressant","depressants"},
"depression":{"depression","depressions"},
"depressor":{"depressor","depressors"},
"deprivation":{"deprivation","deprivations"},
"deprive":{"deprive","deprived","deprives","depriving"},
"depth":{"depth","depths"},
"deputation":{"deputation","deputations"},
"depute":{"depute","deputed","deputes","deputing"},
"deputize":{"deputize","deputized","deputizes","deputizing"},
"deputy":{"deputies","deputy"},
"deracinate":{"deracinate","deracinated","deracinates","deracinating"},
"derail":{"derail","derailed","derailing","derails"},
"derange":{"derange","deranged","deranges","deranging"},
"derangement":{"derangement","derangements"},
"derby":{"derbies","derby"},
"deregulate":{"deregulate","deregulated","deregulating"},
"deregulating":{"deregulating","deregulatings"},
"deregulation":{"deregulation","deregulations"},
"derelict":{"derelict","derelicts"},
"dereliction":{"dereliction","derelictions"},
"deride":{"deride","derided","deriding"},
"derision":{"derision","derisions"},
"derivation":{"derivation","derivations"},
"derivative":{"derivative","derivatives"},
"derive":{"derive","derived","derives","deriving"},
"deriving":{"deriving","derivings"},
"derma":{"derma","dermas"},
"dermacentor":{"dermacentor","dermacentors"},
"dermaptera":{"dermaptera","dermapteras"},
"dermatobia":{"dermatobia","dermatobias"},
"dermatologist":{"dermatologist","dermatologists"},
"dermatoplasty":{"dermatoplasties","dermatoplasty"},
"dermatosis":{"dermatoses","dermatosis","dermatotoses"},
"dermestidae":{"dermestidae","dermestidaes"},
"dermis":{"dermis","dermises"},
"dermochelyidae":{"dermochelyidae","dermochelyidaes"},
"dermoptera":{"dermoptera","dermopteras"},
"derogate":{"derogate","derogated","derogates","derogating"},
"derogation":{"derogation","derogations"},
"derrick":{"derrick","derricks"},
"derriere":{"derriere","derrieres"},
"dervish":{"dervish","dervishes"},
"des":{"des","deses"},
"desalinate":{"desalinate","desalinated","desalinates","desalinating"},
"desalination":{"desalination","desalinations"},
"desalinisation":{"desalinisation","desalinisations"},
"desalinization":{"desalinization","desalinizations"},
"desalinize":{"desalinize","desalinized","desalinizes","desalinizing"},
"desalt":{"desalt","desalted","desalting","desalts"},
"descant":{"descant","descanted","descanting","descants"},
"descartes":{"descartes","descarteses"},
"descend":{"descend","descended","descending","descends"},
"descendant":{"descendant","descendants"},
"descendants":{"descendants","descendantses"},
"descendent":{"descendent","descendents"},
"descent":{"descent","descents"},
"describe":{"describe","described","describes","describing"},
"description":{"description","descriptions"},
"descry":{"descried","descries","descry","descrying"},
"descurainia":{"descurainia","descurainias"},
"desecrate":{"desecrate","desecrated","desecrates","desecrating"},
"desecration":{"desecration","desecrations"},
"desegregate":{"desegregate","desegregated","desegregates","desegregating"},
"desegregation":{"desegregation","desegregations"},
"desensitisation":{"desensitisation","desensitisations"},
"desensitization":{"desensitization","desensitizations"},
"desensitize":{"desensitize","desensitized","desensitizing"},
"desert":{"desert","deserted","deserting","deserts"},
"deserter":{"deserter","deserters"},
"desertion":{"desertion","desertions"},
"deserve":{"deserve","deserved","deserves","deserving"},
"deservingness":{"deservingness","deservingnesses"},
"desex":{"desex","desexed","desexes","desexing"},
"desexualize":{"desexualize","desexualized","desexualizes","desexualizing"},
"deshabille":{"deshabille","deshabilles"},
"desiccant":{"desiccant","desiccants"},
"desiccate":{"desiccate","desiccated","desiccating"},
"desiderate":{"desiderate","desiderated","desiderating"},
"desideratum":{"desiderata","desideratum"},
"design":{"design","designed","designing","designs"},
"designate":{"designate","designated","designates","designating"},
"designation":{"designation","designations"},
"designee":{"designee","designees"},
"designer":{"designer","designers"},
"designing":{"designing","designings"},
"desirability":{"desirabilities","desirability"},
"desirable":{"desirable","desirables"},
"desirableness":{"desirableness","desirablenesses"},
"desire":{"desire","desired","desires","desiring"},
"desist":{"desist","desisted","desisting","desists"},
"desk":{"desk","desks"},
"deskman":{"deskman","deskmen"},
"desktop":{"desktop","desktops"},
"desman":{"desman","desmans"},
"desmanthus":{"desmanthus","desmanthuses"},
"desmidiaceae":{"desmidiaceae","desmidiaceaes"},
"desmidium":{"desmidium","desmidiums"},
"desmodium":{"desmodium","desmodiums"},
"desmodontidae":{"desmodontidae","desmodontidaes"},
"desmodus":{"desmodus","desmoduses"},
"desmograthus":{"desmograthus","desmograthuses"},
"desolate":{"desolate","desolated","desolates","desolating"},
"desolation":{"desolation","desolations"},
"desorb":{"desorb","desorbed","desorbing"},
"despair":{"despair","despaired","despairing","despairs"},
"despatch":{"despatch","despatched","despatches","despatching"},
"desperado":{"desperado","desperadoes","desperados"},
"desperation":{"desperation","desperations"},
"despicability":{"despicabilities","despicability"},
"despicableness":{"despicableness","despicablenesses"},
"despisal":{"despisal","despisals"},
"despise":{"despise","despised","despises","despising"},
"despising":{"despising","despisings"},
"despoil":{"despoil","despoiled","despoiling","despoils"},
"despoiler":{"despoiler","despoilers"},
"despoilment":{"despoilment","despoilments"},
"despoina":{"despoina","despoinas"},
"despoliation":{"despoliation","despoliations"},
"despond":{"despond","desponded","desponding"},
"despondence":{"despondence","despondences"},
"despondency":{"despondencies","despondency"},
"despot":{"despot","despots"},
"despotism":{"despotism","despotisms"},
"desquamate":{"desquamate","desquamated","desquamates","desquamating"},
"dessert":{"dessert","desserts"},
"dessertspoon":{"dessertspoon","dessertspoons"},
"dessertspoonful":{"dessertspoonful","dessertspoonfuls"},
"dessication":{"dessication","dessications"},
"destination":{"destination","destinations"},
"destine":{"destine","destined","destines","destining"},
"destiny":{"destinies","destiny"},
"destroy":{"destroy","destroyed","destroying","destroys"},
"destroyer":{"destroyer","destroyers"},
"destruction":{"destruction","destructions"},
"desulfur":{"desulfur","desulfured","desulfuring"},
"desulfurize":{"desulfurize","desulfurized","desulfurizing"},
"desynchronisation":{"desynchronisation","desynchronisations"},
"desynchronization":{"desynchronization","desynchronizations"},
"desynchronizing":{"desynchronizing","desynchronizings"},
"detach":{"detach","detached","detaches","detaching"},
"detachment":{"detachment","detachments"},
"detail":{"detail","detailed","detailing","details"},
"detailing":{"detailing","detailings"},
"details":{"details","detailses"},
"detain":{"detain","detained","detaining","detains"},
"detainee":{"detainee","detainees"},
"detect":{"detect","detected","detecting","detects"},
"detecting":{"detecting","detectings"},
"detection":{"detection","detections"},
"detective":{"detective","detectives"},
"detector":{"detector","detectors"},
"detent":{"detent","detents"},
"detention":{"detention","detentions"},
"deter":{"deter","deterred","deterring","deters"},
"deterge":{"deterge","deterged","deterging"},
"detergence":{"detergence","detergences"},
"detergency":{"detergencies","detergency"},
"detergent":{"detergent","detergents"},
"deteriorate":{"deteriorate","deteriorated","deteriorates","deteriorating"},
"deterioration":{"deterioration","deteriorations"},
"determent":{"determent","determents"},
"determinant":{"determinant","determinants"},
"determinateness":{"determinateness","determinatenesses"},
"determination":{"determination","determinations"},
"determinative":{"determinative","determinatives"},
"determine":{"determine","determined","determines","determining"},
"determiner":{"determiner","determiners"},
"determinist":{"determinist","determinists"},
"deterrence":{"deterrence","deterrences"},
"deterrent":{"deterrent","deterrents"},
"detest":{"detest","detested","detesting","detests"},
"detestation":{"detestation","detestations"},
"dethrone":{"dethrone","dethroned","dethroning"},
"dethronement":{"dethronement","dethronements"},
"detonate":{"detonate","detonated","detonates","detonating"},
"detonation":{"detonation","detonations"},
"detonator":{"detonator","detonators"},
"detour":{"detour","detoured","detouring","detours"},
"detoxicate":{"detoxicate","detoxicated","detoxicates","detoxicating"},
"detoxify":{"detoxified","detoxifies","detoxify","detoxifying"},
"detract":{"detract","detracted","detracting","detracts"},
"detraction":{"detraction","detractions"},
"detractor":{"detractor","detractors"},
"detrain":{"detrain","detrained","detraining"},
"detribalisation":{"detribalisation","detribalisations"},
"detribalization":{"detribalization","detribalizations"},
"detribalize":{"detribalize","detribalized","detribalizing"},
"detriment":{"detriment","detriments"},
"detrition":{"detrition","detritions"},
"detritus":{"detritus","detrituses"},
"detroit":{"detroit","detroits"},
"deuce":{"deuce","deuces"},
"deuce-ace":{"deuce-ace","deuce-aces"},
"deuteranopia":{"deuteranopia","deuteranopias"},
"deuterate":{"deuterate","deuterated","deuterates","deuterating"},
"deuterium":{"deuterium","deuteriums"},
"deuteromycetes":{"deuteromycetes","deuteromyceteses"},
"deuteromycota":{"deuteromycota","deuteromycotas"},
"deuteromycotina":{"deuteromycotina","deuteromycotinas"},
"deutschland":{"deutschland","deutschlands"},
"deutschmark":{"deutschmark","deutschmarks"},
"devaluate":{"devaluate","devaluated","devaluates","devaluating"},
"devalue":{"devalue","devalued","devalues","devaluing"},
"devanagari":{"devanagari","devanagaris"},
"devastate":{"devastate","devastated","devastates","devastating"},
"devastation":{"devastation","devastations"},
"devastator":{"devastator","devastators"},
"develop":{"develop","developed","developing","develops"},
"developer":{"developer","developers"},
"developing":{"developing","developings"},
"development":{"development","developments"},
"devest":{"devest","devested","devesting"},
"deviance":{"deviance","deviances"},
"deviant":{"deviant","deviants"},
"deviate":{"deviate","deviated","deviates","deviating"},
"deviation":{"deviation","deviations"},
"device":{"device","devices"},
"devil":{"devil","deviled","deviling","devilled","devilling","devils"},
"devil-worship":{"devil-worship","devil-worships"},
"devilfish":{"devilfish","devilfishes"},
"devilment":{"devilment","devilments"},
"devilry":{"devilries","devilry"},
"deviltry":{"deviltries","deviltry"},
"devilwood":{"devilwood","devilwoods"},
"deviousness":{"deviousness","deviousnesses"},
"devisal":{"devisal","devisals"},
"devise":{"devise","devised","devises","devising"},
"deviser":{"deviser","devisers"},
"devising":{"devising","devisings"},
"devitalisation":{"devitalisation","devitalisations"},
"devitalization":{"devitalization","devitalizations"},
"devitalize":{"devitalize","devitalized","devitalizes","devitalizing"},
"devitrify":{"devitrified","devitrifies","devitrify","devitrifying"},
"devocalize":{"devocalize","devocalized","devocalizing"},
"devoice":{"devoice","devoiced","devoicing"},
"devolatilize":{"devolatilize","devolatilized","devolatilizes","devolatilizing"},
"devolution":{"devolution","devolutions"},
"devolve":{"devolve","devolved","devolves","devolving"},
"devolvement":{"devolvement","devolvements"},
"devonian":{"devonian","devonians"},
"devote":{"devote","devoted","devotes","devoting"},
"devotedness":{"devotedness","devotednesses"},
"devotee":{"devotee","devotees"},
"devotion":{"devotion","devotions"},
"devour":{"devour","devoured","devouring","devours"},
"devourer":{"devourer","devourers"},
"devout":{"devout","devouter","devoutest"},
"devoutness":{"devoutness","devoutnesses"},
"dew":{"dew","dewed","dewing"},
"dewar":{"dewar","dewars"},
"dewater":{"dewater","dewatered","dewatering"},
"dewberry":{"dewberries","dewberry"},
"dewdrop":{"dewdrop","dewdrops"},
"dewey":{"dewey","deweys"},
"dewy":{"dewier","dewiest","dewy"},
"dexamethasone":{"dexamethasone","dexamethasones"},
"dexedrine":{"dexedrine","dexedrines"},
"dexterity":{"dexterities","dexterity"},
"dextrality":{"dextralities","dextrality"},
"dextroglucose":{"dextroglucose","dextroglucoses"},
"dextrose":{"dextrose","dextroses"},
"dg":{"dg","dgs"},
"dhak":{"dhak","dhaks"},
"dhaka":{"dhaka","dhakas"},
"dhal":{"dhal","dhals"},
"dhava":{"dhava","dhavas"},
"dhawa":{"dhawa","dhawas"},
"dhegiha":{"dhegiha","dhegihas"},
"dhole":{"dhole","dholes"},
"dhoti":{"dhoti","dhotis"},
"diabeta":{"diabeta","diabetas"},
"diabetic":{"diabetic","diabetics"},
"diabolatry":{"diabolatries","diabolatry"},
"diabolism":{"diabolism","diabolisms"},
"diabolist":{"diabolist","diabolists"},
"diabolize":{"diabolize","diabolized","diabolizes","diabolizing"},
"diabolo":{"diabolo","diabolos"},
"diacalpa":{"diacalpa","diacalpas"},
"diachrony":{"diachronies","diachrony"},
"diacritic":{"diacritic","diacritics"},
"diadem":{"diadem","diademed","diademing","diadems"},
"diadophis":{"diadophis","diadophises"},
"diaeresis":{"diaereses","diaeresis"},
"diaglyph":{"diaglyph","diaglyphs"},
"diagnose":{"diagnose","diagnosed","diagnoses","diagnosing"},
"diagnosing":{"diagnosing","diagnosings"},
"diagnosis":{"diagnoses","diagnosis"},
"diagnostician":{"diagnostician","diagnosticians"},
"diagnostics":{"diagnostics","diagnosticses"},
"diagonal":{"diagonal","diagonals"},
"diagram":{"diagram","diagramed","diagraming","diagrammed","diagramming","diagrams"},
"diagramming":{"diagramming","diagrammings"},
"dial":{"dial","dialed","dialing","dialled","dialling","dials"},
"dialect":{"dialect","dialects"},
"dialeurodes":{"dialeurodes","dialeurodeses"},
"dialog":{"dialog","dialogs"},
"dialogue":{"dialogue","dialogues"},
"dialysis":{"dialyses","dialysis"},
"dialyze":{"dialyze","dialyzed","dialyzes","dialyzing"},
"dialyzer":{"dialyzer","dialyzers"},
"diam":{"diam","diams"},
"diameter":{"diameter","diameters"},
"diamond":{"diamond","diamonds"},
"diamondback":{"diamondback","diamondbacks"},
"dianthus":{"dianthus","dianthuses"},
"diapason":{"diapason","diapasons"},
"diapensiaceae":{"diapensiaceae","diapensiaceaes"},
"diapensiales":{"diapensiales","diapensialeses"},
"diaper":{"diaper","diapered","diapering","diapers"},
"diapheromera":{"diapheromera","diapheromeras"},
"diaphoresis":{"diaphoreses","diaphoresis"},
"diaphragm":{"diaphragm","diaphragms"},
"diaphysis":{"diaphyses","diaphysis"},
"diapophysis":{"diapophyses","diapophysis"},
"diapsid":{"diapsid","diapsids"},
"diapsida":{"diapsida","diapsidas"},
"diarchy":{"diarchies","diarchy"},
"diarist":{"diarist","diarists"},
"diarrhea":{"diarrhea","diarrheas"},
"diarrhoea":{"diarrhoea","diarrhoeas"},
"diarthrosis":{"diarthroses","diarthrosis"},
"diary":{"diaries","diary"},
"diaspididae":{"diaspididae","diaspididaes"},
"diastalsis":{"diastalses","diastalsis"},
"diastasis":{"diastases","diastasis"},
"diastema":{"diastema","diastemata"},
"diathermancy":{"diathermancies","diathermancy"},
"diathesis":{"diatheses","diathesis","diathses"},
"diatomite":{"diatomite","diatomites"},
"diatomophyceae":{"diatomophyceae","diatomophyceaes"},
"diatribe":{"diatribe","diatribes"},
"diazepam":{"diazepam","diazepams"},
"diazo":{"diazo","diazoes","diazos"},
"dib":{"dib","dibbed","dibbing","dibs"},
"dibber":{"dibber","dibbers"},
"dibble":{"dibble","dibbled","dibbles","dibbling"},
"dibbuk":{"dibbuk","dibbuks"},
"dibrach":{"dibrach","dibraches"},
"dibranch":{"dibranch","dibranches"},
"dibranchia":{"dibranchia","dibranchias"},
"dibranchiata":{"dibranchiata","dibranchiatas"},
"dibranchiate":{"dibranchiate","dibranchiates"},
"dicamptodon":{"dicamptodon","dicamptodons"},
"dicamptodontid":{"dicamptodontid","dicamptodontids"},
"dicamptodontidae":{"dicamptodontidae","dicamptodontidaes"},
"dice":{"dice","diced","dices","dicing"},
"dicentra":{"dicentra","dicentras"},
"diceros":{"diceros","diceroses"},
"dicey":{"dicey","dicier","diciest"},
"dichasium":{"dichasia","dichasium"},
"dichloride":{"dichloride","dichlorides"},
"dichondra":{"dichondra","dichondras"},
"dichotomisation":{"dichotomisation","dichotomisations"},
"dichotomization":{"dichotomization","dichotomizations"},
"dichotomize":{"dichotomize","dichotomized","dichotomizing"},
"dichotomy":{"dichotomies","dichotomy"},
"dichromate":{"dichromate","dichromates"},
"dick":{"dick","dicks"},
"dickens":{"dickens","dickenses"},
"dicker":{"dicker","dickered","dickering","dickers"},
"dickey":{"dickey","dickeys"},
"dickey-seat":{"dickey-seat","dickey-seats"},
"dickeybird":{"dickeybird","dickeybirds"},
"dickie":{"dickie","dickies"},
"dickie-seat":{"dickie-seat","dickie-seats"},
"dicksonia":{"dicksonia","dicksonias"},
"dicksoniaceae":{"dicksoniaceae","dicksoniaceaes"},
"dicky":{"dickies","dicky"},
"dicky-seat":{"dicky-seat","dicky-seats"},
"dickybird":{"dickybird","dickybirds"},
"dicot":{"dicot","dicots"},
"dicotyledon":{"dicotyledon","dicotyledons"},
"dicotyledonae":{"dicotyledonae","dicotyledonaes"},
"dicotyledones":{"dicotyledones","dicotyledoneses"},
"dicranaceae":{"dicranaceae","dicranaceaes"},
"dicranales":{"dicranales","dicranaleses"},
"dicranopteris":{"dicranopteris","dicranopterises"},
"dicranum":{"dicranum","dicranums"},
"dicrostonyx":{"dicrostonyx","dicrostonyxes"},
"dictamnus":{"dictamnus","dictamnuses"},
"dictate":{"dictate","dictated","dictates","dictating"},
"dictation":{"dictation","dictations"},
"dictator":{"dictator","dictators"},
"dictatorship":{"dictatorship","dictatorships"},
"diction":{"diction","dictions"},
"dictionary":{"dictionaries","dictionary"},
"dictum":{"dicta","dictum","dictums"},
"dictyophera":{"dictyophera","dictyopheras"},
"dictyoptera":{"dictyoptera","dictyopteras"},
"dicynodontia":{"dicynodontia","dicynodontias"},
"didakai":{"didakai","didakais"},
"diddicoy":{"diddicoy","diddicoys"},
"diddle":{"diddle","diddled","diddles","diddling"},
"didelphidae":{"didelphidae","didelphidaes"},
"didelphis":{"didelphis","didelphises"},
"dido":{"dido","didoes","didos"},
"die":{"dice","die","died","dies","dying"},
"die-cast":{"die-cast","die-casting","die-casts"},
"dieffenbachia":{"dieffenbachia","dieffenbachias"},
"diehard":{"diehard","diehards"},
"dielectric":{"dielectric","dielectrics"},
"diemaker":{"diemaker","diemakers"},
"diencephalon":{"diencephala","diencephalon","diencephalons"},
"dieresis":{"diereses","dieresis"},
"diervilla":{"diervilla","diervillas"},
"diesel":{"diesel","diesels"},
"dieses":{"dieses","dieseses"},
"diesinker":{"diesinker","diesinkers"},
"diesis":{"dieses","diesis"},
"diestrum":{"diestrum","diestrums"},
"diestrus":{"diestrus","diestruses"},
"diet":{"diet","dieted","dieting","diets"},
"dietary":{"dietaries","dietartaries","dietary"},
"diethylmalonylurea":{"diethylmalonylurea","diethylmalonylureas"},
"diethylstilbestrol":{"diethylstilbestrol","diethylstilbestrols"},
"diethylstilboestrol":{"diethylstilboestrol","diethylstilboestrols"},
"dietician":{"dietician","dieticians"},
"dieting":{"dieting","dietings"},
"dietitian":{"dietitian","dietitians"},
"differ":{"differ","differed","differing","differs"},
"difference":{"difference","differenced","differences","differencing"},
"differentia":{"differentia","differentiae"},
"differential":{"differential","differentials"},
"differentiate":{"differentiate","differentiated","differentiates","differentiating"},
"differentiation":{"differentiation","differentiations"},
"differentiator":{"differentiator","differentiators"},
"difficultness":{"difficultness","difficultnesses"},
"difficulty":{"difficulties","difficulty"},
"diffidence":{"diffidence","diffidences"},
"diffract":{"diffract","diffracted","diffracting"},
"diffuse":{"diffuse","diffused","diffuses","diffusing"},
"diffuser":{"diffuser","diffusers"},
"diffusion":{"diffusion","diffusions"},
"diffusor":{"diffusor","diffusors"},
"diflunisal":{"diflunisal","diflunisals"},
"dig":{"dig","digging","digs","dug"},
"digamy":{"digamies","digamy"},
"digenesis":{"digeneses","digenesis"},
"digest":{"digest","digested","digesting","digests"},
"digestibility":{"digestibilities","digestibility"},
"digestibleness":{"digestibleness","digestiblenesses"},
"digestion":{"digestion","digestions"},
"digestive":{"digestive","digestives"},
"digger":{"digger","diggers"},
"digging":{"digging","diggings"},
"diggings":{"diggings","diggingses"},
"dight":{"dight","dighted","dighting","dights"},
"digit":{"digit","digits"},
"digitalin":{"digitalin","digitalins"},
"digitalis":{"digitalis","digitalises"},
"digitalisation":{"digitalisation","digitalisations"},
"digitalization":{"digitalization","digitalizations"},
"digitalize":{"digitalize","digitalized","digitalizes","digitalizing"},
"digitaria":{"digitaria","digitarias"},
"digitize":{"digitize","digitized","digitizing"},
"digitizer":{"digitizer","digitizers"},
"dignify":{"dignified","dignifies","dignify","dignifying"},
"dignitary":{"dignitaries","dignitary"},
"dignity":{"dignities","dignity"},
"digress":{"digress","digressed","digresses","digressing"},
"digression":{"digression","digressions"},
"digs":{"digs","digses"},
"dika":{"dika","dikas"},
"dike":{"dike","diked","dikes","diking"},
"dilantin":{"dilantin","dilantins"},
"dilapidate":{"dilapidate","dilapidated","dilapidating"},
"dilapidation":{"dilapidation","dilapidations"},
"dilatation":{"dilatation","dilatations"},
"dilate":{"dilate","dilated","dilates","dilating"},
"dilation":{"dilation","dilations"},
"dilatoriness":{"dilatoriness","dilatorinesses"},
"dildo":{"dildo","dildos"},
"dildoe":{"dildoe","dildoes"},
"dilemma":{"dilemma","dilemmas"},
"dilettante":{"dilettante","dilettantes","dilettanti"},
"diligence":{"diligence","diligences"},
"dill":{"dill","dills"},
"dilleniaceae":{"dilleniaceae","dilleniaceaes"},
"dilleniidae":{"dilleniidae","dilleniidaes"},
"dilly":{"dillies","dilly"},
"dilly-dally":{"dilly-dallied","dilly-dallies","dilly-dally","dilly-dallying"},
"dillydallier":{"dillydallier","dillydalliers"},
"diltiazem":{"diltiazem","diltiazems"},
"dilutant":{"dilutant","dilutants"},
"dilute":{"dilute","diluted","dilutes","diluting"},
"diluting":{"diluting","dilutings"},
"dilution":{"dilution","dilutions"},
"diluvium":{"diluvia","diluvium"},
"dim":{"dim","dimmed","dimmer","dimmest","dimming","dims"},
"dime":{"dime","dimes"},
"dimenhydrinate":{"dimenhydrinate","dimenhydrinates"},
"dimension":{"dimension","dimensioned","dimensioning","dimensions"},
"diminish":{"diminish","diminished","diminishes","diminishing"},
"diminuendo":{"diminuendo","diminuendoes","diminuendos"},
"diminution":{"diminution","diminutions"},
"diminutive":{"diminutive","diminutives"},
"diminutiveness":{"diminutiveness","diminutivenesses"},
"dimity":{"dimities","dimity"},
"dimness":{"dimness","dimnesses"},
"dimocarpus":{"dimocarpus","dimocarpuses"},
"dimorphotheca":{"dimorphotheca","dimorphothecas"},
"dimout":{"dimout","dimouts"},
"dimple":{"dimple","dimpled","dimples","dimpling"},
"dimwit":{"dimwit","dimwits"},
"din":{"din","dinned","dinning","dins"},
"dinar":{"dinar","dinars"},
"dindymene":{"dindymene","dindymenes"},
"dine":{"dine","dined","dines","dining"},
"diner":{"diner","diners"},
"dinero":{"dinero","dineros"},
"ding":{"ding","dinged","dinging","dings"},
"dingey":{"dingey","dingeys"},
"dinghy":{"dinghies","dinghy"},
"dingle":{"dingle","dingles"},
"dingo":{"dingo","dingoes"},
"dingus":{"dingus","dinguses"},
"dingy":{"dingier","dingies","dingiest","dingy"},
"diningroom":{"diningroom","diningrooms"},
"dinka":{"dinka","dinkas"},
"dinkey":{"dinkey","dinkeys"},
"dinky":{"dinkier","dinkiest","dinky"},
"dinner":{"dinner","dinners"},
"dinnertime":{"dinnertime","dinnertimes"},
"dinoceras":{"dinoceras","dinocerases"},
"dinocerata":{"dinocerata","dinoceratas"},
"dinoflagellata":{"dinoflagellata","dinoflagellatas"},
"dinornis":{"dinornis","dinornises"},
"dinornithidae":{"dinornithidae","dinornithidaes"},
"dinornithiformes":{"dinornithiformes","dinornithiformeses"},
"dinosaur":{"dinosaur","dinosaurs"},
"dint":{"dint","dinted","dinting","dints"},
"diocese":{"diocese","dioceses"},
"diode":{"diode","diodes"},
"diodon":{"diodon","diodons"},
"diodontidae":{"diodontidae","diodontidaes"},
"diol":{"diol","diols"},
"diomedeidae":{"diomedeidae","diomedeidaes"},
"dionaea":{"dionaea","dionaeas"},
"dionysia":{"dionysia","dionysias"},
"diorama":{"diorama","dioramas"},
"dioscorea":{"dioscorea","dioscoreas"},
"dioscoreaceae":{"dioscoreaceae","dioscoreaceaes"},
"diospyros":{"diospyros","diospyroses"},
"dioxide":{"dioxide","dioxides"},
"dip":{"dip","dipped","dipping","dips"},
"diphenylhydantoin":{"diphenylhydantoin","diphenylhydantoins"},
"diphthongize":{"diphthongize","diphthongized","diphthongizing"},
"diphylla":{"diphylla","diphyllas"},
"dipladenia":{"dipladenia","dipladenias"},
"diplococcus":{"diplococci","diplococcocci","diplococcus"},
"diplodocus":{"diplodocus","diplodocuses"},
"diploma":{"diploma","diplomas","diplomata"},
"diplomacy":{"diplomacies","diplomacy"},
"diplomat":{"diplomat","diplomats"},
"diplomatist":{"diplomatist","diplomatists"},
"diplopoda":{"diplopoda","diplopodas"},
"diplopterygium":{"diplopterygium","diplopterygiums"},
"diplotaxis":{"diplotaxes","diplotaxis"},
"dipnoi":{"dipnoi","dipnois"},
"dipodidae":{"dipodidae","dipodidaes"},
"dipodomys":{"dipodomys","dipodomyses"},
"dipody":{"dipodies","dipody"},
"dipogon":{"dipogon","dipogons"},
"dipole":{"dipole","dipoles"},
"dipper":{"dipper","dippers"},
"dippers":{"dippers","dipperses"},
"dippy":{"dippier","dippiest","dippy"},
"dipsacaceae":{"dipsacaceae","dipsacaceaes"},
"dipsacus":{"dipsacus","dipsacuses"},
"dipsomania":{"dipsomania","dipsomanias"},
"dipsomaniac":{"dipsomaniac","dipsomaniacs"},
"dipsosaurus":{"dipsosaurus","dipsosauruses"},
"diptera":{"diptera","dipteras"},
"dipteran":{"dipteran","dipterans"},
"dipterocarpaceae":{"dipterocarpaceae","dipterocarpaceaes"},
"dipteron":{"dipteron","dipterons"},
"dipteronia":{"dipteronia","dipteronias"},
"dipteryx":{"dipteryx","dipteryxes"},
"dipus":{"dipus","dipuses"},
"dipylon":{"dipylon","dipylons"},
"dirca":{"dirca","dircas"},
"dire":{"dire","direr","direst"},
"direct":{"direct","directed","directing","directs"},
"direction":{"direction","directions"},
"directionality":{"directionalities","directionality"},
"directivity":{"directivities","directivity"},
"directness":{"directness","directnesses"},
"director":{"director","directors"},
"director-general":{"director-general","directors-general"},
"directorate":{"directorate","directorates"},
"directory":{"directories","directory"},
"dirge":{"dirge","dirges"},
"dirham":{"dirham","dirhams"},
"dirigible":{"dirigible","dirigibles"},
"dirk":{"dirk","dirked","dirking"},
"dirt":{"dirt","dirts"},
"dirtiness":{"dirtiness","dirtinesses"},
"dirty":{"dirtied","dirtier","dirties","dirtiest","dirty","dirtying"},
"dirtying":{"dirtying","dirtyings"},
"dis":{"dis","dises","dissed","dissing"},
"disability":{"disabilities","disability"},
"disable":{"disable","disabled","disables","disabling"},
"disablement":{"disablement","disablements"},
"disabuse":{"disabuse","disabused","disabusing"},
"disaccord":{"disaccord","disaccorded","disaccording","disaccords"},
"disaccustom":{"disaccustom","disaccustomed","disaccustoming"},
"disadvantage":{"disadvantage","disadvantaged","disadvantages","disadvantaging"},
"disaffect":{"disaffect","disaffected","disaffecting","disaffects"},
"disaffection":{"disaffection","disaffections"},
"disaffiliate":{"disaffiliate","disaffiliated","disaffiliating"},
"disaffirm":{"disaffirm","disaffirmed","disaffirming"},
"disagree":{"disagree","disagreed","disagreeing","disagrees"},
"disagreement":{"disagreement","disagreements"},
"disallow":{"disallow","disallowed","disallowing","disallows"},
"disambiguate":{"disambiguate","disambiguated","disambiguating"},
"disannul":{"disannul","disannulled","disannulling","disannuls"},
"disappear":{"disappear","disappeared","disappearing","disappears"},
"disappearance":{"disappearance","disappearances"},
"disappearing":{"disappearing","disappearings"},
"disappoint":{"disappoint","disappointed","disappointing","disappoints"},
"disappointing":{"disappointing","disappointings"},
"disappointment":{"disappointment","disappointments"},
"disapprobation":{"disapprobation","disapprobations"},
"disapproval":{"disapproval","disapprovals"},
"disapprove":{"disapprove","disapproved","disapproves","disapproving"},
"disarm":{"disarm","disarmed","disarming","disarms"},
"disarmament":{"disarmament","disarmaments"},
"disarmer":{"disarmer","disarmers"},
"disarming":{"disarming","disarmings"},
"disarrange":{"disarrange","disarranged","disarranging"},
"disarrangement":{"disarrangement","disarrangements"},
"disarray":{"disarray","disarrayed","disarraying","disarrays"},
"disarticulate":{"disarticulate","disarticulated","disarticulates","disarticulating"},
"disassemble":{"disassemble","disassembled","disassembles","disassembling"},
"disassembly":{"disassemblies","disassembly"},
"disassociate":{"disassociate","disassociated","disassociating"},
"disassociation":{"disassociation","disassociations"},
"disaster":{"disaster","disasters"},
"disavow":{"disavow","disavowed","disavowing"},
"disband":{"disband","disbanded","disbanding","disbands"},
"disbar":{"disbar","disbarred","disbarring","disbars"},
"disbelief":{"disbelief","disbelieves"},
"disbelieve":{"disbelieve","disbelieved","disbelieves","disbelieving"},
"disbeliever":{"disbeliever","disbelievers"},
"disbud":{"disbud","disbudded","disbudding","disbuds"},
"disburden":{"disburden","disburdened","disburdening","disburdens"},
"disbursal":{"disbursal","disbursals"},
"disburse":{"disburse","disbursed","disburses","disbursing"},
"disbursement":{"disbursement","disbursements"},
"disburser":{"disburser","disbursers"},
"disc":{"disc","discs"},
"discant":{"discant","discants"},
"discard":{"discard","discarded","discarding","discards"},
"discarding":{"discarding","discardings"},
"discern":{"discern","discerned","discerning","discerns"},
"discernability":{"discernabilities","discernability"},
"discernment":{"discernment","discernments"},
"discharge":{"discharge","discharged","discharges","discharging"},
"disciple":{"disciple","disciples"},
"disciplinarian":{"disciplinarian","disciplinarians"},
"discipline":{"discipline","disciplined","disciplines","disciplining"},
"disclaim":{"disclaim","disclaimed","disclaiming"},
"disclose":{"disclose","disclosed","discloses","disclosing"},
"disclosure":{"disclosure","disclosures"},
"disco":{"disco","discos"},
"discobolos":{"discoboli","discobolos"},
"discobolus":{"discoboli","discobolus"},
"discocephali":{"discocephali","discocephalis"},
"discoglossidae":{"discoglossidae","discoglossidaes"},
"discography":{"discographies","discography"},
"discolor":{"discolor","discolored","discoloring","discolors"},
"discoloration":{"discoloration","discolorations"},
"discolour":{"discolour","discoloured","discolouring","discolours"},
"discolouration":{"discolouration","discolourations"},
"discombobulate":{"discombobulate","discombobulated","discombobulates","discombobulating"},
"discombobulation":{"discombobulation","discombobulations"},
"discomfit":{"discomfit","discomfited","discomfiting","discomfits"},
"discomfited":{"discomfited","discomfiteds"},
"discomfiture":{"discomfiture","discomfitures"},
"discomfort":{"discomfort","discomforted","discomforting","discomforts"},
"discommend":{"discommend","discommended","discommending","discommends"},
"discommode":{"discommode","discommoded","discommodes","discommoding"},
"discommodity":{"discommodities","discommodity"},
"discompose":{"discompose","discomposed","discomposes","discomposing"},
"discomposure":{"discomposure","discomposures"},
"discomycete":{"discomycete","discomycetes"},
"discomycetes":{"discomycetes","discomyceteses"},
"disconcert":{"disconcert","disconcerted","disconcerting","disconcerts"},
"disconcertion":{"disconcertion","disconcertions"},
"disconcertment":{"disconcertment","disconcertments"},
"disconfirm":{"disconfirm","disconfirmed","disconfirming"},
"disconformity":{"disconformities","disconformity"},
"disconnect":{"disconnect","disconnected","disconnecting","disconnects"},
"disconnectedness":{"disconnectedness","disconnectednesses"},
"disconnection":{"disconnection","disconnections"},
"disconsolateness":{"disconsolateness","disconsolatenesses"},
"discontent":{"discontent","discontented","discontenting","discontents"},
"discontentedness":{"discontentedness","discontentednesses"},
"discontentment":{"discontentment","discontentments"},
"discontinuance":{"discontinuance","discontinuances"},
"discontinuation":{"discontinuation","discontinuations"},
"discontinue":{"discontinue","discontinued","discontinues","discontinuing"},
"discontinuity":{"discontinuities","discontinuity"},
"discord":{"discord","discorded","discording","discords"},
"discordance":{"discordance","discordances"},
"discotheque":{"discotheque","discotheques"},
"discount":{"discount","discounted","discounting","discounts"},
"discountenance":{"discountenance","discountenanced","discountenancing"},
"discounter":{"discounter","discounters"},
"discourage":{"discourage","discouraged","discourages","discouraging"},
"discouragement":{"discouragement","discouragements"},
"discourse":{"discourse","discoursed","discourses","discoursing"},
"discourtesy":{"discourtesies","discourtesy"},
"discover":{"discover","discovered","discovering","discovers"},
"discoverer":{"discoverer","discoverers"},
"discovery":{"discoveries","discovery"},
"discredit":{"discredit","discredited","discrediting","discredits"},
"discreetness":{"discreetness","discreetnesses"},
"discrepancy":{"discrepancies","discrepancy"},
"discreteness":{"discreteness","discretenesses"},
"discretion":{"discretion","discretions"},
"discriminate":{"discriminate","discriminated","discriminates","discriminating"},
"discrimination":{"discrimination","discriminations"},
"discriminator":{"discriminator","discriminators"},
"discus":{"disci","discus","discuses"},
"discuss":{"discuss","discussed","discusses","discussing"},
"discussant":{"discussant","discussants"},
"discussion":{"discussion","discussions"},
"disdain":{"disdain","disdained","disdaining","disdains"},
"disdainfulness":{"disdainfulness","disdainfulnesses"},
"disease":{"disease","diseased","diseases","diseasing"},
"diseconomy":{"diseconomies","diseconomy"},
"disembark":{"disembark","disembarked","disembarking","disembarks"},
"disembarkation":{"disembarkation","disembarkations"},
"disembarkment":{"disembarkment","disembarkments"},
"disembarrass":{"disembarrass","disembarrassed","disembarrasses","disembarrassing"},
"disembody":{"disembodied","disembodies","disembody","disembodying"},
"disembogue":{"disembogue","disembogued","disembogues","disemboguing"},
"disembowel":{"disembowel","disemboweled","disemboweling","disembowelled","disembowelling","disembowels"},
"disenchant":{"disenchant","disenchanted","disenchanting","disenchants"},
"disenchantment":{"disenchantment","disenchantments"},
"disencumber":{"disencumber","disencumbered","disencumbering","disencumbers"},
"disendow":{"disendow","disendowed","disendowing"},
"disenfranchise":{"disenfranchise","disenfranchised","disenfranchises","disenfranchising"},
"disengage":{"disengage","disengaged","disengages","disengaging"},
"disengagement":{"disengagement","disengagements"},
"disentail":{"disentail","disentailed","disentailing"},
"disentangle":{"disentangle","disentangled","disentangles","disentangling"},
"disentanglement":{"disentanglement","disentanglements"},
"disenthral":{"disenthral","disenthralled","disenthralling","disenthralls"},
"disenthrall":{"disenthrall","disenthralled","disenthralling","disenthrals"},
"disestablish":{"disestablish","disestablished","disestablishing"},
"disesteem":{"disesteem","disesteemed","disesteeming","disesteems"},
"disfavor":{"disfavor","disfavored","disfavoring","disfavors"},
"disfavour":{"disfavour","disfavours"},
"disfeature":{"disfeature","disfeatured","disfeaturing"},
"disfigure":{"disfigure","disfigured","disfigures","disfiguring"},
"disfigurement":{"disfigurement","disfigurements"},
"disforestation":{"disforestation","disforestations"},
"disfranchise":{"disfranchise","disfranchised","disfranchises","disfranchising"},
"disfrock":{"disfrock","disfrocked","disfrocking"},
"disfurnish":{"disfurnish","disfurnished","disfurnishing"},
"disgorge":{"disgorge","disgorged","disgorges","disgorging"},
"disgorgement":{"disgorgement","disgorgements"},
"disgrace":{"disgrace","disgraced","disgraces","disgracing"},
"disgracefulness":{"disgracefulness","disgracefulnesses"},
"disgruntle":{"disgruntle","disgruntled","disgruntling"},
"disguise":{"disguise","disguised","disguises","disguising"},
"disgust":{"disgust","disgusted","disgusting","disgusts"},
"disgustingness":{"disgustingness","disgustingnesses"},
"dish":{"dish","dished","dishes","dishing"},
"dishabille":{"dishabille","dishabilles"},
"disharmonize":{"disharmonize","disharmonized","disharmonizing"},
"disharmony":{"disharmonies","disharmony"},
"dishcloth":{"dishcloth","dishcloths"},
"dishearten":{"dishearten","disheartened","disheartening","disheartens"},
"disheartenment":{"disheartenment","disheartenments"},
"dishevel":{"dishevel","disheveled","disheveling","dishevelled","dishevelling","dishevels"},
"dishful":{"dishful","dishfuls"},
"dishonesty":{"dishonesties","dishonesty"},
"dishonor":{"dishonor","dishonored","dishonoring","dishonors"},
"dishonorableness":{"dishonorableness","dishonorablenesses"},
"dishonour":{"dishonour","dishonours"},
"dishonourableness":{"dishonourableness","dishonourablenesses"},
"dishrag":{"dishrag","dishrags"},
"dishware":{"dishware","dishwares"},
"dishwasher":{"dishwasher","dishwashers"},
"dishy":{"dishier","dishiest","dishy"},
"disillusion":{"disillusion","disillusioned","disillusioning","disillusions"},
"disillusionment":{"disillusionment","disillusionments"},
"disincentive":{"disincentive","disincentives"},
"disinclination":{"disinclination","disinclinations"},
"disincline":{"disincline","disinclined","disinclines","disinclining"},
"disinfect":{"disinfect","disinfected","disinfecting"},
"disinfectant":{"disinfectant","disinfectants"},
"disinfest":{"disinfest","disinfested","disinfesting"},
"disinherit":{"disinherit","disinherited","disinheriting","disinherits"},
"disintegrate":{"disintegrate","disintegrated","disintegrates","disintegrating"},
"disintegration":{"disintegration","disintegrations"},
"disintegrator":{"disintegrator","disintegrators"},
"disinter":{"disinter","disinterred","disinterring","disinters"},
"disinterest":{"disinterest","disinterested","disinteresting","disinterests"},
"disinterment":{"disinterment","disinterments"},
"disjoin":{"disjoin","disjoined","disjoining","disjoins"},
"disjoint":{"disjoint","disjointed","disjointing","disjoints"},
"disjunction":{"disjunction","disjunctions"},
"disjuncture":{"disjuncture","disjunctures"},
"disk":{"disk","disked","disking","disks"},
"diskette":{"diskette","diskettes"},
"dislike":{"dislike","disliked","dislikes","disliking"},
"dislocate":{"dislocate","dislocated","dislocates","dislocating"},
"dislocation":{"dislocation","dislocations"},
"dislodge":{"dislodge","dislodged","dislodges","dislodging"},
"dislodgement":{"dislodgement","dislodgements"},
"dislodgment":{"dislodgment","dislodgments"},
"disloyalty":{"disloyalties","disloyalty"},
"dismal":{"dismal","dismals"},
"dismantle":{"dismantle","dismantled","dismantles","dismantling"},
"dismantlement":{"dismantlement","dismantlements"},
"dismantling":{"dismantling","dismantlings"},
"dismast":{"dismast","dismasted","dismasting"},
"dismay":{"dismay","dismayed","dismaying","dismays"},
"dismember":{"dismember","dismembered","dismembering","dismembers"},
"dismemberment":{"dismemberment","dismemberments"},
"dismiss":{"dismiss","dismissed","dismisses","dismissing"},
"dismissal":{"dismissal","dismissals"},
"dismount":{"dismount","dismounted","dismounting","dismounts"},
"disobedience":{"disobedience","disobediences"},
"disobey":{"disobey","disobeyed","disobeying"},
"disoblige":{"disoblige","disobliged","disobliges","disobliging"},
"disorder":{"disorder","disordered","disordering","disorders"},
"disorderliness":{"disorderliness","disorderlinesses"},
"disorganization":{"disorganization","disorganizations"},
"disorganize":{"disorganize","disorganized","disorganizing"},
"disorient":{"disorient","disoriented","disorienting","disorients"},
"disorientation":{"disorientation","disorientations"},
"disown":{"disown","disowned","disowning","disowns"},
"disowning":{"disowning","disownings"},
"disownment":{"disownment","disownments"},
"disparage":{"disparage","disparaged","disparages","disparaging"},
"disparagement":{"disparagement","disparagements"},
"disparager":{"disparager","disparagers"},
"disparateness":{"disparateness","disparatenesses"},
"disparity":{"disparities","disparity"},
"dispart":{"dispart","disparted","disparting"},
"dispassion":{"dispassion","dispassions"},
"dispassionateness":{"dispassionateness","dispassionatenesses"},
"dispatch":{"dispatch","dispatched","dispatches","dispatching"},
"dispatcher":{"dispatcher","dispatchers"},
"dispel":{"dispel","dispelled","dispelling","dispels"},
"dispensability":{"dispensabilities","dispensability"},
"dispensableness":{"dispensableness","dispensablenesses"},
"dispensary":{"dispensaries","dispensary"},
"dispensation":{"dispensation","dispensations"},
"dispensatory":{"dispensatories","dispensatory"},
"dispense":{"dispense","dispensed","dispenses","dispensing"},
"dispensing":{"dispensing","dispensings"},
"dispeople":{"dispeople","dispeopled","dispeopling"},
"dispersal":{"dispersal","dispersals"},
"disperse":{"disperse","dispersed","disperses","dispersing"},
"dispersion":{"dispersion","dispersions"},
"dispirit":{"dispirit","dispirited","dispiriting","dispirits"},
"dispiritedness":{"dispiritedness","dispiritednesses"},
"displace":{"displace","displaced","displaces","displacing"},
"displacement":{"displacement","displacements"},
"display":{"display","displayed","displaying","displays"},
"displease":{"displease","displeased","displeasing"},
"displode":{"displode","disploded","disploding"},
"disport":{"disport","disported","disporting","disports"},
"disposal":{"disposal","disposals"},
"dispose":{"dispose","disposed","disposes","disposing"},
"disposition":{"disposition","dispositions"},
"dispossess":{"dispossess","dispossessed","dispossesses","dispossessing"},
"dispossession":{"dispossession","dispossessions"},
"dispraise":{"dispraise","dispraised","dispraises","dispraising"},
"dispread":{"dispread","dispreading"},
"disprize":{"disprize","disprized","disprizing"},
"disproof":{"disproof","disproofs","disprooves"},
"disproportion":{"disproportion","disproportioned","disproportioning"},
"disprove":{"disprove","disproved","disproves","disproving"},
"disproving":{"disproving","disprovings"},
"disputant":{"disputant","disputants"},
"disputation":{"disputation","disputations"},
"dispute":{"dispute","disputed","disputes","disputing"},
"disqualification":{"disqualification","disqualifications"},
"disqualify":{"disqualified","disqualifies","disqualify","disqualifying"},
"disqualifying":{"disqualifying","disqualifyings"},
"disquiet":{"disquiet","disquieted","disquieting","disquiets"},
"disquietude":{"disquietude","disquietudes"},
"disrate":{"disrate","disrated","disrating"},
"disregard":{"disregard","disregarded","disregarding","disregards"},
"disrelish":{"disrelish","disrelished","disrelishing"},
"disremember":{"disremember","disremembered","disremembering"},
"disreputability":{"disreputabilities","disreputability"},
"disreputableness":{"disreputableness","disreputablenesses"},
"disrepute":{"disrepute","disreputes"},
"disrespect":{"disrespect","disrespected","disrespecting","disrespects"},
"disrobe":{"disrobe","disrobed","disrobes","disrobing"},
"disroot":{"disroot","disrooted","disrooting"},
"disrupt":{"disrupt","disrupted","disrupting","disrupts"},
"disruption":{"disruption","disruptions"},
"dissatisfy":{"dissatisfied","dissatisfies","dissatisfy","dissatisfying"},
"dissect":{"dissect","dissected","dissecting","dissects"},
"dissection":{"dissection","dissections"},
"disseize":{"disseize","disseized","disseizing"},
"dissemble":{"dissemble","dissembled","dissembles","dissembling"},
"dissembler":{"dissembler","dissemblers"},
"dissembling":{"dissembling","dissemblings"},
"disseminate":{"disseminate","disseminated","disseminates","disseminating"},
"dissemination":{"dissemination","disseminations"},
"disseminator":{"disseminator","disseminators"},
"dissension":{"dissension","dissensions"},
"dissent":{"dissent","dissented","dissenting","dissents"},
"dissenter":{"dissenter","dissenters"},
"dissert":{"dissert","disserted","disserting"},
"dissertate":{"dissertate","dissertated","dissertating"},
"dissertation":{"dissertation","dissertations"},
"disserve":{"disserve","disserved","disserving"},
"disservice":{"disservice","disservices"},
"dissever":{"dissever","dissevered","dissevering","dissevers"},
"dissident":{"dissident","dissidents"},
"dissimilarity":{"dissimilarities","dissimilarity"},
"dissimilate":{"dissimilate","dissimilated","dissimilating"},
"dissimilation":{"dissimilation","dissimilations"},
"dissimilitude":{"dissimilitude","dissimilitudes"},
"dissimulate":{"dissimulate","dissimulated","dissimulating"},
"dissimulation":{"dissimulation","dissimulations"},
"dissipate":{"dissipate","dissipated","dissipates","dissipating"},
"dissipation":{"dissipation","dissipations"},
"dissociate":{"dissociate","dissociated","dissociates","dissociating"},
"dissociation":{"dissociation","dissociations"},
"dissolubility":{"dissolubilities","dissolubility"},
"dissoluteness":{"dissoluteness","dissolutenesses"},
"dissolution":{"dissolution","dissolutions"},
"dissolve":{"dissolve","dissolved","dissolves","dissolving"},
"dissolvent":{"dissolvent","dissolvents"},
"dissolver":{"dissolver","dissolvers"},
"dissonance":{"dissonance","dissonances"},
"dissuade":{"dissuade","dissuaded","dissuades","dissuading"},
"dissyllable":{"dissyllable","dissyllables"},
"dissymmetry":{"dissymmetries","dissymmetry"},
"distaff":{"distaff","distaffs"},
"distain":{"distain","distained","distaining"},
"distance":{"distance","distanced","distances","distancing"},
"distaste":{"distaste","distasted","distastes","distasting"},
"distastefulness":{"distastefulness","distastefulnesses"},
"distemper":{"distemper","distempered","distempering","distempers"},
"distend":{"distend","distended","distending","distends"},
"distension":{"distension","distensions"},
"distention":{"distention","distentions"},
"distich":{"distich","distiches"},
"distil":{"distil","distilled","distilling","distils"},
"distill":{"distill","distilled","distilling","distills"},
"distillate":{"distillate","distillates"},
"distillation":{"distillation","distillations"},
"distillery":{"distilleries","distillery"},
"distillment":{"distillment","distillments"},
"distinction":{"distinction","distinctions"},
"distinctiveness":{"distinctiveness","distinctivenesses"},
"distinctness":{"distinctness","distinctnesses"},
"distinguish":{"distinguish","distinguished","distinguishes","distinguishing"},
"distort":{"distort","distorted","distorting","distorts"},
"distortion":{"distortion","distortions"},
"distract":{"distract","distracted","distracting","distracts"},
"distraction":{"distraction","distractions"},
"distrain":{"distrain","distrained","distraining"},
"distraint":{"distraint","distraints"},
"distress":{"distress","distressed","distresses","distressing"},
"distressfulness":{"distressfulness","distressfulnesses"},
"distributary":{"distributaries","distributary"},
"distribute":{"distribute","distributed","distributes","distributing"},
"distributer":{"distributer","distributers"},
"distribution":{"distribution","distributions"},
"distributor":{"distributor","distributors"},
"district":{"district","districted","districting","districts"},
"distrust":{"distrust","distrusted","distrusting","distrusts"},
"distrustfulness":{"distrustfulness","distrustfulnesses"},
"disturb":{"disturb","disturbed","disturbing","disturbs"},
"disturbance":{"disturbance","disturbances"},
"disulfiram":{"disulfiram","disulfirams"},
"disunite":{"disunite","disunited","disunites","disuniting"},
"disunity":{"disunities","disunity"},
"disuse":{"disuse","disused","disuses","disusing"},
"disvalue":{"disvalue","disvalued","disvaluing"},
"disyllable":{"disyllable","disyllables"},
"dit":{"dit","dits"},
"dita":{"dita","ditas"},
"ditch":{"ditch","ditched","ditches","ditching"},
"ditchmoss":{"ditchmoss","ditchmosses"},
"dither":{"dither","dithered","dithering","dithers"},
"dittany":{"dittanies","dittany"},
"ditto":{"ditto","dittoed","dittoing","dittos"},
"dittography":{"dittographies","dittography"},
"ditty":{"ditties","ditty"},
"diuretic":{"diuretic","diuretics"},
"diuril":{"diuril","diurils"},
"diva":{"diva","divas","dive"},
"divagate":{"divagate","divagated","divagates","divagating"},
"divagation":{"divagation","divagations"},
"divan":{"divan","divans"},
"divaricate":{"divaricate","divaricated","divaricating"},
"dive":{"dive","dived","dives","diving","dove"},
"diver":{"diver","divers"},
"diverge":{"diverge","diverged","diverges","diverging"},
"divergence":{"divergence","divergences"},
"divergency":{"divergencies","divergency"},
"diverseness":{"diverseness","diversenesses"},
"diversify":{"diversified","diversifies","diversify","diversifying"},
"diversion":{"diversion","diversions"},
"diversionist":{"diversionist","diversionists"},
"diversity":{"diversities","diversity"},
"divert":{"divert","diverted","diverting","diverts"},
"diverticulum":{"diverticula","diverticulum"},
"divertimento":{"divertimenti","divertimento","divertimentos"},
"divest":{"divest","divested","divesting","divests"},
"divi-divi":{"divi-divi","divi-divis"},
"divide":{"divide","divided","divides","dividing"},
"dividend":{"dividend","dividends"},
"divider":{"divider","dividers"},
"divination":{"divination","divinations"},
"divine":{"divine","divined","diviner","divines","divinest","divining"},
"diving":{"diving","divings"},
"divinity":{"divinities","divinity"},
"division":{"division","divisions"},
"divisor":{"divisor","divisors"},
"divorce":{"divorce","divorced","divorces","divorcing"},
"divorcee":{"divorcee","divorcees"},
"divorcement":{"divorcement","divorcements"},
"divulgate":{"divulgate","divulgated","divulgating"},
"divulge":{"divulge","divulged","divulges","divulging"},
"divulgement":{"divulgement","divulgements"},
"divulgence":{"divulgence","divulgences"},
"divvy":{"divvied","divvies","divvy","divvying"},
"diwan":{"diwan","diwans"},
"dixie":{"dixie","dixies"},
"dixiecrats":{"dixiecrats","dixiecratses"},
"dixieland":{"dixieland","dixielands"},
"dizen":{"dizen","dizened","dizening","dizens"},
"dizziness":{"dizziness","dizzinesses"},
"dizzy":{"dizzied","dizzier","dizzies","dizziest","dizzy","dizzying"},
"dj":{"dj","djs"},
"djakarta":{"djakarta","djakartas"},
"djibouti":{"djibouti","djiboutis"},
"djinni":{"djinn","djinni","djinnis"},
"djinny":{"djinnies","djinny"},
"dkg":{"dkg","dkgs"},
"dkl":{"dkl","dkls"},
"dkm":{"dkm","dkms"},
"dl":{"dl","dls"},
"dle":{"dle","dles"},
"dm":{"dm","dms"},
"dmd":{"dmd","dmds"},
"dmus":{"dmus","dmuses"},
"dna":{"dna","dnas"},
"do":{"did","do","doing","done","dos"},
"do-gooder":{"do-gooder","do-gooders"},
"do-nothing":{"do-nothing","do-nothings"},
"dobbin":{"dobbin","dobbins"},
"dobby":{"dobbies","dobby"},
"doberman":{"doberman","dobermen"},
"dobro":{"dobro","dobros"},
"dobson":{"dobson","dobsons"},
"dobsonfly":{"dobsonflies","dobsonfly"},
"doc":{"doc","docs"},
"dock":{"dock","docked","docking","docks"},
"dock-walloper":{"dock-walloper","dock-wallopers"},
"dockage":{"dockage","dockages"},
"docker":{"docker","dockers"},
"docket":{"docket","docketed","docketing","dockets"},
"dockhand":{"dockhand","dockhands"},
"docking":{"docking","dockings"},
"doctor":{"doctor","doctored","doctoring","doctors"},
"doctorate":{"doctorate","doctorates"},
"doctorfish":{"doctorfish","doctorfishes"},
"doctrinaire":{"doctrinaire","doctrinaires"},
"doctrine":{"doctrine","doctrines"},
"docudrama":{"docudrama","docudramas"},
"document":{"document","documented","documenting","documents"},
"documentary":{"documentaries","documentary"},
"documentation":{"documentation","documentations"},
"dod":{"dod","dods"},
"dodder":{"dodder","doddered","doddering","dodders"},
"dodecahedron":{"dodecahedra","dodecahedron","dodecahedrons"},
"dodge":{"dodge","dodged","dodges","dodging"},
"dodgem":{"dodgem","dodgems"},
"dodger":{"dodger","dodgers"},
"dodging":{"dodging","dodgings"},
"dodgson":{"dodgson","dodgsons"},
"dodgy":{"dodgier","dodgiest","dodgy"},
"dodo":{"dodo","dodoes","dodos"},
"doe":{"doe","does"},
"doer":{"doer","doers"},
"doff":{"doff","doffed","doffing","doffs"},
"dog":{"dog","dogged","dogging","dogs"},
"dog-ear":{"dog-ear","dogeared","dogearing"},
"dogberry":{"dogberries","dogberry"},
"dogey":{"dogey","dogeys"},
"dogfight":{"digfought","dogfight","dogfighting","dogfought"},
"dogfish":{"dogfish","dogfishes"},
"doggedness":{"doggedness","doggednesses"},
"doggerel":{"doggerel","doggerels"},
"doggery":{"doggeries","doggery"},
"doggie":{"doggie","doggies"},
"doggone":{"doggone","doggoned","doggoner","doggonest","doggoning"},
"doggy":{"doggier","doggies","doggiest","doggy"},
"doghouse":{"doghouse","doghouses"},
"dogie":{"dogie","dogies"},
"dogiron":{"dogiron","dogirons"},
"dogleg":{"dogleg","doglegged","doglegging","doglegs"},
"dogma":{"dogma","dogmas","dogmata"},
"dogmatism":{"dogmatism","dogmatisms"},
"dogmatist":{"dogmatist","dogmatists"},
"dogmatize":{"dogmatize","dogmatized","dogmatizing"},
"dogsbody":{"dogsbodies","dogsbody"},
"dogshit":{"dogshit","dogshits"},
"dogsled":{"dogsled","dogsleds"},
"dogtooth":{"dogteeth","dogtooth"},
"dogwood":{"dogwood","dogwoods"},
"dogy":{"dogies","dogy"},
"doh":{"doh","dohs"},
"doha":{"doha","dohas"},
"dohickey":{"dohickey","dohickeys"},
"doily":{"doilies","doily"},
"doing":{"doing","doings"},
"dojigger":{"dojigger","dojiggers"},
"dojo":{"dojo","dojos"},
"doldrums":{"doldrums","doldrumses"},
"dole":{"dole","doled","doles","doling"},
"dolibid":{"dolibid","dolibids"},
"dolichonyx":{"dolichonyx","dolichonyxes"},
"dolichos":{"dolichos","dolichoses"},
"dolichotis":{"dolichotis","dolichotises"},
"doliolidae":{"doliolidae","doliolidaes"},
"doll":{"doll","dolled","dolling","dolls"},
"dollar":{"dollar","dollars"},
"dollarfish":{"dollarfish","dollarfishes"},
"dollhouse":{"dollhouse","dollhouses"},
"dolly":{"dollied","dollies","dolly","dollying"},
"dolman":{"dolman","dolmans","dolmen"},
"dolmas":{"dolmas","dolmases"},
"dolmen":{"dolmen","dolmens"},
"dolomitize":{"dolomitize","dolomitized","dolomitizing"},
"dolor":{"dolor","dolors"},
"dolour":{"dolour","dolours"},
"dolphin":{"dolphin","dolphins"},
"dolphinfish":{"dolphinfish","dolphinfishes"},
"dolt":{"dolt","dolts"},
"domain":{"domain","domains"},
"dome":{"dome","domed","domes","doming"},
"domestic":{"domestic","domestics"},
"domesticate":{"domesticate","domesticated","domesticates","domesticating"},
"domestication":{"domestication","domestications"},
"domesticity":{"domesticities","domesticity"},
"domicile":{"domicile","domiciled","domiciles","domiciling"},
"domiciliation":{"domiciliation","domiciliations"},
"dominance":{"dominance","dominances"},
"dominant":{"dominant","dominants"},
"dominate":{"dominate","dominated","dominates","dominating"},
"domination":{"domination","dominations"},
"dominator":{"dominator","dominators"},
"domine":{"domine","domines"},
"dominee":{"dominee","dominees"},
"domineer":{"domineer","domineered","domineering","domineers"},
"domineeringness":{"domineeringness","domineeringnesses"},
"dominican":{"dominican","dominicans"},
"dominick":{"dominick","dominicks"},
"dominie":{"dominie","dominies"},
"dominion":{"dominion","dominions"},
"dominique":{"dominique","dominiques"},
"domino":{"diminos","domino","dominoes","dominos"},
"dominoes":{"dominoes","dominoeses"},
"dominos":{"dominos","dominoses"},
"dominus":{"dominus","dominuses"},
"don":{"don","donned","donning","dons"},
"dona":{"dona","donas"},
"donate":{"donate","donated","donating"},
"donation":{"donation","donations"},
"donator":{"donator","donators"},
"donbas":{"donbas","donbases"},
"donbass":{"donbass","donbasses"},
"donee":{"donee","donees"},
"donetsk":{"donetsk","donetsks"},
"donjon":{"donjon","donjons"},
"donkey":{"donkey","donkeys"},
"donkeywork":{"donkeywork","donkeyworks"},
"donne":{"donne","donnes"},
"donor":{"donor","donors"},
"donut":{"donut","donuts"},
"doob":{"doob","doobs"},
"doodad":{"doodad","doodads"},
"doodia":{"doodia","doodias"},
"doodle":{"doodle","doodled","doodling"},
"doodlebug":{"doodlebug","doodlebugs"},
"doofus":{"doofus","doofuses"},
"doohickey":{"doohickey","doohickeys"},
"doom":{"doom","doomed","dooming","dooms"},
"doomed":{"doomed","doomeds"},
"doomsday":{"doomsday","doomsdays"},
"door":{"door","doors"},
"doorbell":{"doorbell","doorbells"},
"doorcase":{"doorcase","doorcases"},
"doorframe":{"doorframe","doorframes"},
"doorhandle":{"doorhandle","doorhandles"},
"doorjamb":{"doorjamb","doorjambs"},
"doorkeeper":{"doorkeeper","doorkeepers"},
"doorknob":{"doorknob","doorknobs"},
"doorknocker":{"doorknocker","doorknockers"},
"doorman":{"doorman","doormen"},
"doormat":{"doormat","doormats"},
"doorpost":{"doorpost","doorposts"},
"doorsill":{"doorsill","doorsills"},
"doorstep":{"doorstep","doorsteps"},
"doorstop":{"doorstop","doorstops"},
"doorstopper":{"doorstopper","doorstoppers"},
"doorway":{"doorway","doorways"},
"dooryard":{"dooryard","dooryards"},
"dopamine":{"dopamine","dopamines"},
"dopastat":{"dopastat","dopastats"},
"dope":{"dope","doped","dopes","doping"},
"dopey":{"dopey","dopier","dopiest"},
"doppelzentner":{"doppelzentner","doppelzentners"},
"dork":{"dork","dorks"},
"dorm":{"dorm","dorms"},
"dormancy":{"dormancies","dormancy"},
"dormer":{"dormer","dormers"},
"dormitory":{"dormitories","dormitory"},
"dormouse":{"dormice","dormouse"},
"doronicum":{"doronicum","doronicums"},
"dorotheanthus":{"dorotheanthus","dorotheanthuses"},
"dorsum":{"dorsa","dorsum","dorsums"},
"dory":{"dories","dory"},
"dorylinae":{"dorylinae","dorylinaes"},
"doryopteris":{"doryopteris","doryopterises"},
"dos":{"dos","doses"},
"dosage":{"dosage","dosages"},
"dose":{"dose","dosed","doses","dosing"},
"dosemeter":{"dosemeter","dosemeters"},
"dosimeter":{"dosimeter","dosimeters"},
"doss":{"doss","dossed","dosses","dossing"},
"dosser":{"dosser","dossers"},
"dosshouse":{"dosshouse","dosshouses"},
"dostoevski":{"dostoevski","dostoevskis"},
"dostoevsky":{"dostoevskies","dostoevsky"},
"dostoievski":{"dostoievski","dostoievskis"},
"dostoyevski":{"dostoyevski","dostoyevskis"},
"dostoyevsky":{"dostoyevskies","dostoyevsky"},
"dot":{"dot","dots","dotted","dotting"},
"dotage":{"dotage","dotages"},
"dotard":{"dotard","dotards"},
"dote":{"dote","doted","doting"},
"dotrel":{"dotrel","dotrels"},
"dotterel":{"dotterel","dotterels"},
"dotty":{"dottier","dottiest","dotty"},
"double":{"double","doubled","doubles","doubling"},
"double-cross":{"double-cross","double-crossed","double-crossing"},
"double-crosser":{"double-crosser","double-crossers"},
"double-crossing":{"double-crossing","double-crossings"},
"double-dealer":{"double-dealer","double-dealers"},
"double-dealing":{"double-dealing","double-dealings"},
"double-decker":{"double-decker","double-deckers"},
"double-prop":{"double-prop","double-props"},
"double-quick":{"double-quick","double-quicked","double-quicking"},
"double-tongue":{"double-tongue","double-tongued","double-tongues","double-tonguing"},
"doubleheader":{"doubleheader","doubleheaders"},
"doublet":{"doublet","doublets"},
"doubleton":{"doubleton","doubletons"},
"doubling":{"doubling","doublings"},
"doubt":{"doubt","doubted","doubting","doubts"},
"doubter":{"doubter","doubters"},
"doubtfulness":{"doubtfulness","doubtfulnesses"},
"douche":{"douche","douched","douches","douching"},
"dough":{"dough","doughs"},
"doughnut":{"doughnut","doughnuts"},
"doughty":{"doughtier","doughtiest","doughty"},
"doughy":{"doughier","doughiest","doughy"},
"doura":{"doura","douras"},
"dourah":{"dourah","dourahs"},
"douroucouli":{"douroucouli","douroucoulis"},
"douse":{"douse","doused","douses","dousing","dowsed","dowsing"},
"dousing":{"dousing","dousings"},
"dove":{"dove","doves"},
"dovecote":{"dovecote","dovecotes"},
"dovekie":{"dovekie","dovekies"},
"dover":{"dover","dovers"},
"dovetail":{"dovetail","dovetailed","dovetailing","dovetails"},
"dovyalis":{"dovyalis","dovyalises"},
"dow":{"dought","dow","dowed","dowing","dows"},
"dowager":{"dowager","dowagers"},
"dowdiness":{"dowdiness","dowdinesses"},
"dowdy":{"dowdier","dowdies","dowdiest","dowdy"},
"dowel":{"dowel","doweled","doweling","dowelled","dowelling","dowels"},
"dower":{"dower","dowered","dowering","dowers"},
"dowery":{"doweries","dowery"},
"dowie":{"dowie","dowier","dowiest"},
"down":{"down","downed","downing","downs"},
"downcast":{"downcast","downcasts"},
"downer":{"downer","downers"},
"downfall":{"downfall","downfalls"},
"downgrade":{"downgrade","downgraded","downgrades","downgrading"},
"downheartedness":{"downheartedness","downheartednesses"},
"downhill":{"downhill","downhills"},
"downiness":{"downiness","downinesses"},
"downplay":{"downplay","downplayed","downplaying"},
"downpour":{"downpour","downpours"},
"downrightness":{"downrightness","downrightnesses"},
"downshift":{"downshift","downshifted","downshifting","downshifts"},
"downsize":{"downsize","downsized","downsizing"},
"downsizing":{"downsizing","downsizings"},
"downslope":{"downslope","downslopes"},
"downswing":{"downswing","downswings"},
"downtown":{"downtown","downtowns"},
"downturn":{"downturn","downturns"},
"downy":{"downier","downiest","downy"},
"dowry":{"dowries","dowry"},
"dowse":{"dowse","dowsed","dowsing"},
"dowser":{"dowser","dowsers"},
"dowy":{"dowier","dowiest","dowy"},
"doxepin":{"doxepin","doxepins"},
"doxology":{"doxologies","doxology"},
"doxy":{"doxies","doxy"},
"doxycycline":{"doxycycline","doxycyclines"},
"doyen":{"doyen","doyens"},
"doyley":{"doyley","doyleys"},
"doyly":{"doylies","doyly"},
"doze":{"doze","dozed","dozes","dozing"},
"dozen":{"dozen","dozens"},
"dozens":{"dozens","dozenses"},
"dozer":{"dozer","dozers"},
"dozy":{"dozier","doziest","dozy"},
"dp":{"dp","dps"},
"dph":{"dph","dphs"},
"drab":{"drab","drabbed","drabber","drabbest","drabbing","drabs"},
"drabble":{"drabble","drabbled","drabbling"},
"drabness":{"drabness","drabnesses"},
"dracaena":{"dracaena","dracaenas"},
"dracaenaceae":{"dracaenaceae","dracaenaceaes"},
"dracenaceae":{"dracenaceae","dracenaceaes"},
"drachm":{"drachm","drachms"},
"drachma":{"drachma","drachmae","drachmas"},
"draco":{"draco","dracos"},
"dracocephalum":{"dracocephalum","dracocephalums"},
"dracula":{"dracula","draculas"},
"dracunculidae":{"dracunculidae","dracunculidaes"},
"dracunculus":{"dracunculus","dracunculuses"},
"draft":{"draft","drafted","drafting","drafts"},
"draftee":{"draftee","draftees"},
"drafting":{"drafting","draftings"},
"draftsman":{"draftsman","draftsmen"},
"draftsmanship":{"draftsmanship","draftsmanships"},
"draftsperson":{"draftsperson","draftspersons"},
"drafty":{"draftier","draftiest","drafty"},
"drag":{"drag","dragged","dragging","drags"},
"draggle":{"draggle","draggled","draggling"},
"draggy":{"draggier","draggiest","draggy"},
"dragnet":{"dragnet","dragnets"},
"dragoman":{"dragoman","dragomans","dragomen"},
"dragon":{"dragon","dragons"},
"dragonfly":{"dragonflies","dragonfly"},
"dragonhead":{"dragonhead","dragonheads"},
"dragoon":{"dragoon","dragooned","dragooning","dragoons"},
"drain":{"drain","drained","draining","drains"},
"drainage":{"drainage","drainages"},
"drainboard":{"drainboard","drainboards"},
"drainpipe":{"drainpipe","drainpipes"},
"drake":{"drake","drakes"},
"dram":{"dram","drams"},
"drama":{"drama","dramas"},
"dramamine":{"dramamine","dramamines"},
"dramatics":{"dramatics","dramaticses"},
"dramatisation":{"dramatisation","dramatisations"},
"dramatist":{"dramatist","dramatists"},
"dramatization":{"dramatization","dramatizations"},
"dramatize":{"dramatize","dramatized","dramatizes","dramatizing"},
"dramaturgy":{"dramaturgies","dramaturgy"},
"drape":{"drape","draped","drapes","draping"},
"drapery":{"draperies","drapery"},
"drat":{"drat","dratted","dratting"},
"draught":{"draught","draughted","draughting","draughts"},
"draughts":{"draughts","draughtses"},
"draughtsman":{"draughtsman","draughtsmen"},
"draughty":{"draughtier","draughtiest","draughty"},
"dravidian":{"dravidian","dravidians"},
"dravidic":{"dravidic","dravidics"},
"draw":{"draw","drawing","drawn","draws","drew"},
"drawback":{"drawback","drawbacks"},
"drawbridge":{"drawbridge","drawbridges"},
"drawer":{"drawer","drawers"},
"drawerful":{"drawerful","drawerfuls"},
"drawers":{"drawers","drawerses"},
"drawing":{"drawing","drawings"},
"drawknife":{"drawknife","drawknives"},
"drawl":{"drawl","drawled","drawling","drawls"},
"drawshave":{"drawshave","drawshaves"},
"drawstring":{"drawstring","drawstrings"},
"dray":{"dray","drayed","draying","drays"},
"drayhorse":{"drayhorse","drayhorses"},
"dread":{"dread","dreaded","dreading","dreads"},
"dreadfulness":{"dreadfulness","dreadfulnesses"},
"dreadnaught":{"dreadnaught","dreadnaughts"},
"dreadnought":{"dreadnought","dreadnoughts"},
"dream":{"dream","dreamed","dreaming","dreams","dreamt"},
"dreamer":{"dreamer","dreamers"},
"dreaminess":{"dreaminess","dreaminesses"},
"dreaming":{"dreaming","dreamings"},
"dreamland":{"dreamland","dreamlands"},
"dreamworld":{"dreamworld","dreamworlds"},
"dreamy":{"dreamier","dreamiest","dreamy"},
"dreariness":{"dreariness","drearinesses"},
"dreary":{"drearier","dreariest","dreary"},
"dredge":{"dredge","dredged","dredges","dredging"},
"dree":{"dree","dreed","dreeing","drees"},
"dreggy":{"dreggier","dreggiest","dreggy"},
"dregs":{"dregs","dregses"},
"dreissena":{"dreissena","dreissenas"},
"drench":{"drench","drenched","drenches","drenching"},
"drenching":{"drenching","drenchings"},
"drepanididae":{"drepanididae","drepanididaes"},
"drepanis":{"drepanis","drepanises"},
"dress":{"dress","dressed","dresses","dressing"},
"dresser":{"dresser","dressers"},
"dressing":{"dressing","dressings"},
"dressmaker":{"dressmaker","dressmakers"},
"dressy":{"dressier","dressiest","dressy"},
"dreyfus":{"dreyfus","dreyfuses"},
"dribble":{"dribble","dribbled","dribbles","dribbling"},
"dribbling":{"dribbling","dribblings"},
"driblet":{"driblet","driblets"},
"drier":{"drier","driers"},
"drift":{"drift","drifted","drifting","drifts"},
"drifter":{"drifter","drifters"},
"drill":{"drill","drilled","drilling","drills"},
"drilling":{"drilling","drillings"},
"drimys":{"drimys","drimyses"},
"drink":{"drank","drink","drinking","drinks","drunk","drunken"},
"drinkable":{"drinkable","drinkables"},
"drinker":{"drinker","drinkers"},
"drinking":{"drinking","drinkings"},
"drip":{"drip","dripped","dripping","drips"},
"drip-dry":{"drip-dried","drip-dry","drip-drying"},
"dripping":{"dripping","drippings"},
"drippings":{"drippings","drippingses"},
"drippy":{"drippier","drippiest","drippy"},
"drive":{"drive","driven","drives","driving","drove"},
"drivel":{"drivel","driveled","driveling","drivelled","drivelling","drivels"},
"driveller":{"driveller","drivellers"},
"driver":{"driver","drivers"},
"driveway":{"driveway","driveways"},
"driving":{"driving","drivings"},
"drizzle":{"drizzle","drizzled","drizzles","drizzling"},
"drogue":{"drogue","drogues"},
"droit":{"droit","droits"},
"droll":{"droll","drolled","droller","drollest","drolling","drolls"},
"drollery":{"drolleries","drollery"},
"dromaeosauridae":{"dromaeosauridae","dromaeosauridaes"},
"dromaius":{"dromaius","dromaiuses"},
"dromedary":{"dromedaries","dromedary"},
"dromos":{"dromoi","dromos"},
"drone":{"drone","droned","drones","droning"},
"drongo":{"drongo","drongos"},
"droning":{"droning","dronings"},
"drool":{"drool","drooled","drooling","drools"},
"droop":{"droop","drooped","drooping","droops"},
"droopy":{"droopier","droopiest","droopy"},
"drop":{"drop","dropped","dropping","drops"},
"drop-off":{"drop-off","drop-offs"},
"dropline":{"dropline","droplines"},
"dropper":{"dropper","droppers"},
"droppings":{"droppings","droppingses"},
"dropsy":{"dropsies","dropsy"},
"drosera":{"drosera","droseras"},
"droseraceae":{"droseraceae","droseraceaes"},
"droshky":{"droshkies","droshky"},
"drosky":{"droskies","drosky"},
"drosophila":{"drosophila","drosophilae","drosophilas"},
"drosophilidae":{"drosophilidae","drosophilidaes"},
"drosophyllum":{"drosophyllum","drosophyllums"},
"dross":{"dross","drosses"},
"drossy":{"drossier","drossiest","drossy"},
"drought":{"drought","droughts"},
"droughty":{"droughtier","droughtiest","droughty"},
"drove":{"drove","droves"},
"drover":{"drover","drovers"},
"drown":{"drown","drowned","drowning","drowns"},
"drowse":{"drowse","drowsed","drowses","drowsing"},
"drowsiness":{"drowsiness","drowsinesses"},
"drowsy":{"drowsier","drowsiest","drowsy"},
"drub":{"drub","drubbed","drubbing","drubs"},
"drubbing":{"drubbing","drubbings"},
"drudge":{"drudge","drudged","drudges","drudging"},
"drudgery":{"drudgeries","drudgery"},
"drug":{"drug","drugged","drugging","drugs"},
"drugging":{"drugging","druggings"},
"druggist":{"druggist","druggists"},
"drugstore":{"drugstore","drugstores"},
"drum":{"drum","drummed","drumming","drums"},
"drumbeat":{"drumbeat","drumbeats"},
"drumfire":{"drumfire","drumfires"},
"drumfish":{"drumfish","drumfishes"},
"drumhead":{"drumhead","drumheads"},
"drummer":{"drummer","drummers"},
"drumming":{"drumming","drummings"},
"drumstick":{"drumstick","drumsticks"},
"drunk":{"drunk","drunker","drunkest","drunks"},
"drunkard":{"drunkard","drunkards"},
"drunkenness":{"drunkenness","drunkennesses"},
"drupe":{"drupe","drupes"},
"druthers":{"druthers","drutherses"},
"dry":{"dried","drier","dries","driest","dry","drying"},
"dry-clean":{"dry-clean","dry-cleaned","dry-cleaning"},
"dry-nurse":{"dry-nurse","dry-nursed","dry-nursing"},
"dryad":{"dryad","dryades","dryads"},
"dryadella":{"dryadella","dryadellas"},
"dryas":{"dryas","dryases"},
"dryer":{"dryer","dryers"},
"drygoods":{"drygoods","drygoodses"},
"drymarchon":{"drymarchon","drymarchons"},
"drymoglossum":{"drymoglossum","drymoglossums"},
"drynaria":{"drynaria","drynarias"},
"dryness":{"dryness","drynesses"},
"dryopithecus":{"dryopithecus","dryopithecuses"},
"dryopteridaceae":{"dryopteridaceae","dryopteridaceaes"},
"dryopteris":{"dryopteris","dryopterises"},
"ds":{"ds","dses"},
"duad":{"duad","duads"},
"dual":{"dual","duals"},
"duala":{"duala","dualas"},
"duality":{"dualities","duality"},
"dub":{"dub","dubbed","dubbing","dubs"},
"dubiety":{"dubieties","dubiety"},
"dubiosity":{"dubiosities","dubiosity"},
"dubiousness":{"dubiousness","dubiousnesses"},
"dublin":{"dublin","dublins"},
"duce":{"duce","duces","duci"},
"duchess":{"duchess","duchesses"},
"duchy":{"duchies","duchy"},
"duck":{"duck","ducked","ducking","ducks"},
"duckbill":{"duckbill","duckbills"},
"ducking":{"ducking","duckings"},
"ducky":{"duckier","duckies","duckiest","ducky"},
"duct":{"duct","ducts"},
"ductule":{"ductule","ductules"},
"ductulus":{"ductulus","ductuluses"},
"dud":{"dud","duds"},
"dude":{"dude","duded","dudes","duding"},
"dudgeon":{"dudgeon","dudgeons"},
"duds":{"duds","dudses"},
"due":{"due","dues"},
"duel":{"duel","dueled","dueling","duelled","duelling","duels"},
"dueler":{"dueler","duelers"},
"duelist":{"duelist","duelists"},
"dueller":{"dueller","duellers"},
"duellist":{"duellist","duellists"},
"duello":{"duello","duellos"},
"duenna":{"duenna","duennas"},
"duet":{"duet","duets"},
"duette":{"duette","duettes"},
"duffel":{"duffel","duffels"},
"duffle":{"duffle","duffles"},
"dug":{"dug","dugs"},
"dugong":{"dugong","dugongs"},
"dugongidae":{"dugongidae","dugongidaes"},
"dugout":{"dugout","dugouts"},
"duiker":{"duiker","duikers"},
"duke":{"duke","dukes"},
"dukedom":{"dukedom","dukedoms"},
"dulcify":{"dulcified","dulcifies","dulcify","dulcifying"},
"dulcinea":{"dulcinea","dulcineas"},
"dull":{"dull","dulled","duller","dullest","dulling"},
"dullard":{"dullard","dullards"},
"dullness":{"dullness","dullnesses"},
"dulness":{"dulness","dulnesses"},
"dulse":{"dulse","dulses"},
"dumb":{"dumb","dumber","dumbest"},
"dumbbell":{"dumbbell","dumbbells"},
"dumbfound":{"dumbfound","dumbfounded","dumbfounding","dumbfounds"},
"dumbness":{"dumbness","dumbnesses"},
"dumbwaiter":{"dumbwaiter","dumbwaiters"},
"dumdum":{"dumdum","dumdums"},
"dumetella":{"dumetella","dumetellas"},
"dumfound":{"dumfound","dumfounded","dumfounding"},
"dummy":{"dummied","dummies","dummy","dummying"},
"dump":{"dump","dumped","dumping","dumps"},
"dumper":{"dumper","dumpers"},
"dumpiness":{"dumpiness","dumpinesses"},
"dumpling":{"dumpling","dumplings"},
"dumplings":{"dumplings","dumplingses"},
"dumps":{"dumps","dumpses"},
"dumpy":{"dumpier","dumpiest","dumpy"},
"dumuzi":{"dumuzi","dumuzis"},
"dun":{"dun","dunned","dunning","duns"},
"dunce":{"dunce","dunces"},
"dunderhead":{"dunderhead","dunderheads"},
"dune":{"dune","dunes"},
"dung":{"dung","dunged","dunging","dungs"},
"dungaree":{"dungaree","dungarees"},
"dungeon":{"dungeon","dungeoned","dungeoning","dungeons"},
"dunghill":{"dunghill","dunghills"},
"dunk":{"dunk","dunked","dunking","dunks"},
"dunkard":{"dunkard","dunkards"},
"dunker":{"dunker","dunkers"},
"dunkerque":{"dunkerque","dunkerques"},
"dunkers":{"dunkers","dunkerses"},
"dunkirk":{"dunkirk","dunkirks"},
"dunlin":{"dunlin","dunlins"},
"dunnock":{"dunnock","dunnocks"},
"dunny":{"dunnies","dunny"},
"duo":{"duo","duos"},
"duodecimo":{"duodecimo","duodecimos"},
"duodenum":{"duodena","duodenum","duodenums","duona","duonas"},
"duologue":{"duologue","duologues"},
"duomo":{"duomi","duomo","duomos"},
"duopoly":{"duopolies","duopoly"},
"dup":{"dup","dupped","dupping","dups"},
"dupe":{"dupe","duped","dupes","duping"},
"dupery":{"duperies","dupery"},
"duplex":{"duplex","duplexes"},
"duplicability":{"duplicabilities","duplicability"},
"duplicate":{"duplicate","duplicated","duplicates","duplicating"},
"duplicating":{"duplicating","duplicatings"},
"duplication":{"duplication","duplications"},
"duplicator":{"duplicator","duplicators"},
"duplicity":{"duplicities","duplicity"},
"dupondius":{"dupondii","dupondius"},
"duppy":{"duppies","duppy"},
"dura":{"dura","duras"},
"durability":{"durabilities","durability"},
"durable":{"durable","durables"},
"durables":{"durables","durableses"},
"durabolin":{"durabolin","durabolins"},
"duramen":{"duramen","duramens"},
"duration":{"duration","durations"},
"durative":{"durative","duratives"},
"durham":{"durham","durhams"},
"durian":{"durian","durians"},
"durio":{"durio","durios"},
"durion":{"durion","durions"},
"durmast":{"durmast","durmasts"},
"duro":{"duro","duros"},
"durra":{"durra","durras"},
"durum":{"durum","durums"},
"dusanbe":{"dusanbe","dusanbes"},
"dushanbe":{"dushanbe","dushanbes"},
"dusicyon":{"dusicyon","dusicyons"},
"dusk":{"dusk","dusked","dusking","dusks"},
"duskiness":{"duskiness","duskinesses"},
"dusky":{"duskier","duskiest","dusky"},
"dust":{"dust","dusted","dusting","dusts"},
"dustbin":{"dustbin","dustbins"},
"dustcart":{"dustcart","dustcarts"},
"dustcloth":{"dustcloth","dustcloths"},
"duster":{"duster","dusters"},
"dustman":{"dustman","dustmen"},
"dustmop":{"dustmop","dustmops"},
"dustpan":{"dustpan","dustpans"},
"dustpanful":{"dustpanful","dustpanfuls"},
"dustrag":{"dustrag","dustrags"},
"dustup":{"dustup","dustups"},
"dusty":{"dustier","dustiest","dusty"},
"dutchman":{"dutchman","dutchmen"},
"duty":{"duties","duty"},
"duumvir":{"duumvir","duumviri","duumvirs"},
"duvet":{"duvet","duvets"},
"dux":{"duces","dux","duxes"},
"dwarf":{"dwarf","dwarfed","dwarfing","dwarfs","dwarves"},
"dwarfism":{"dwarfism","dwarfisms"},
"dweeb":{"dweeb","dweebs"},
"dwell":{"dwell","dwelled","dwelling","dwells","dwelt"},
"dweller":{"dweller","dwellers"},
"dwelling":{"dwelling","dwellings"},
"dwindle":{"dwindle","dwindled","dwindles","dwindling"},
"dwindling":{"dwindling","dwindlings"},
"dy":{"dies","dy"},
"dyad":{"dyad","dyads"},
"dyak":{"dyak","dyaks"},
"dyarchy":{"dyarchies","dyarchy"},
"dyaus":{"dyaus","dyauses"},
"dyaus-pitar":{"dyaus-pitar","dyaus-pitars"},
"dybbuk":{"dybbuk","dybbuks"},
"dye":{"dye","dyed","dyeing","dyes"},
"dyestuff":{"dyestuff","dyestuffs"},
"dyeweed":{"dyeweed","dyeweeds"},
"dying":{"dying","dyings"},
"dyirbal":{"dyirbal","dyirbals"},
"dyke":{"dyke","dykes"},
"dynamic":{"dynamic","dynamics"},
"dynamics":{"dynamics","dynamicses"},
"dynamism":{"dynamism","dynamisms"},
"dynamite":{"dynamite","dynamited","dynamiting"},
"dynamiter":{"dynamiter","dynamiters"},
"dynamitist":{"dynamitist","dynamitists"},
"dynamo":{"dynamo","dynamos"},
"dynasty":{"dynasties","dynasty"},
"dysdercus":{"dysdercus","dysdercuses"},
"dysgenics":{"dysgenics","dysgenicses"},
"dyspepsia":{"dyspepsia","dyspepsias"},
"dysprosium":{"dysprosium","dysprosiums"},
"dytiscidae":{"dytiscidae","dytiscidaes"},
"dyula":{"dyula","dyulas"},
"dyushambe":{"dyushambe","dyushambes"},
"dziggetai":{"dziggetai","dziggetais"},
"dzo":{"dzo","dzos"},
"e":{"e","es"},
"e-mail":{"e-mail","e-mails"},
"eacles":{"eacles","eacleses"},
"eager":{"eager","eagerer","eagerest","eagers"},
"eagerness":{"eagerness","eagernesses"},
"eagle":{"eagle","eagles"},
"eagre":{"eagre","eagres"},
"ealdorman":{"ealdorman","ealdormen"},
"ear":{"ear","ears"},
"ear-shell":{"ear-shell","ear-shells"},
"earache":{"earache","earaches"},
"eardrop":{"eardrop","eardrops"},
"eardrum":{"eardrum","eardrums"},
"earflap":{"earflap","earflaps"},
"earful":{"earful","earfuls"},
"earl":{"earl","earls"},
"earlap":{"earlap","earlaps"},
"earldom":{"earldom","earldoms"},
"early":{"earlier","earliest","early"},
"earmark":{"earmark","earmarked","earmarking","earmarks"},
"earn":{"earn","earned","earning","earns"},
"earner":{"earner","earners"},
"earnestness":{"earnestness","earnestnesses"},
"earnings":{"earnings","earningses"},
"earphone":{"earphone","earphones"},
"earpiece":{"earpiece","earpieces"},
"earreach":{"earreach","earreaches"},
"earring":{"earring","earrings"},
"earshot":{"earshot","earshots"},
"earth":{"earth","earthed","earthing","earths"},
"earth-ball":{"earth-ball","earth-balls"},
"earth-closet":{"earth-closet","earth-closets"},
"earthball":{"earthball","earthballs"},
"earthing":{"earthing","earthings"},
"earthling":{"earthling","earthlings"},
"earthly":{"earthlier","earthliest","earthly"},
"earthman":{"earthman","earthmen"},
"earthnut":{"earthnut","earthnuts"},
"earthquake":{"earthquake","earthquakes"},
"earthworm":{"earthworm","earthworms"},
"earthy":{"earthier","earthiest","earthy"},
"earwax":{"earwax","earwaxes"},
"earwig":{"earwig","earwigged","earwigging"},
"ease":{"ease","eased","eases","easing"},
"easel":{"easel","easels"},
"easiness":{"easiness","easinesses"},
"easing":{"easing","easings"},
"east":{"east","easts"},
"easter":{"easter","easters"},
"easterly":{"easterlies","easterly"},
"eastern":{"eastern","easterns"},
"easy":{"easied","easier","easies","easiest","easy","easying"},
"eat":{"ate","eat","eaten","eating","eats"},
"eatable":{"eatable","eatables"},
"eatage":{"eatage","eatages"},
"eater":{"eater","eaters"},
"eatery":{"eateries","eatery"},
"eating":{"eating","eatings"},
"eats":{"eats","eatses"},
"eavesdrop":{"eavesdrop","eavesdropped","eavesdropping","eavesdrops"},
"eavesdropper":{"eavesdropper","eavesdroppers"},
"ebb":{"ebb","ebbed","ebbing","ebbs"},
"ebbing":{"ebbing","ebbings"},
"ebenaceae":{"ebenaceae","ebenaceaes"},
"ebenales":{"ebenales","ebenaleses"},
"ebn":{"ebn","ebns"},
"ebonics":{"ebonics","ebonicses"},
"ebonite":{"ebonite","ebonites"},
"ebonize":{"ebonize","ebonized","ebonizing"},
"ebony":{"ebonies","ebony"},
"ebro":{"ebro","ebros"},
"ebs":{"ebs","ebses"},
"ebullience":{"ebullience","ebulliences"},
"eburophyton":{"eburophyton","eburophytons"},
"ecballium":{"ecballium","ecballiums"},
"ecc":{"ecc","eccs"},
"eccentric":{"eccentric","eccentrics"},
"eccentricity":{"eccentricities","eccentricity"},
"ecchymosis":{"ecchymoses","ecchymosis"},
"ecclesia":{"ecclesia","ecclesiae"},
"ecclesiastic":{"ecclesiastic","ecclesiastics"},
"eccm":{"eccm","eccms"},
"ecdysiast":{"ecdysiast","ecdysiasts"},
"ecdysis":{"ecdyses","ecdysis"},
"ecesis":{"eceses","ecesis"},
"ecg":{"ecg","ecgs"},
"echelon":{"echelon","echeloned","echeloning"},
"echeneididae":{"echeneididae","echeneididaes"},
"echeneis":{"echeneis","echeneises"},
"echidna":{"echidna","echidnae","echidnas"},
"echidnophaga":{"echidnophaga","echidnophagas"},
"echinacea":{"echinacea","echinaceas"},
"echinocactus":{"echinocactus","echinocactuses"},
"echinocereus":{"echinocereus","echinocereuses"},
"echinochloa":{"echinochloa","echinochloas"},
"echinodermata":{"echinodermata","echinodermatas"},
"echinoidea":{"echinoidea","echinoideas"},
"echinops":{"echinops","echinopses"},
"echinus":{"echini","echinus"},
"echium":{"echium","echiums"},
"echo":{"echo","echoed","echoes","echoing"},
"echolocation":{"echolocation","echolocations"},
"eclaircissement":{"eclaircissement","eclaircissements"},
"eclat":{"eclat","eclats"},
"eclectic":{"eclectic","eclectics"},
"eclecticism":{"eclecticism","eclecticisms"},
"eclecticist":{"eclecticist","eclecticists"},
"eclipse":{"eclipse","eclipsed","eclipses","eclipsing"},
"eclipsis":{"eclipses","eclipsis"},
"eclogue":{"eclogue","eclogues"},
"ecm":{"ecm","ecms"},
"ecologist":{"ecologist","ecologists"},
"ecology":{"ecologies","ecology"},
"economics":{"economics","economicses"},
"economiser":{"economiser","economisers"},
"economist":{"economist","economists"},
"economize":{"economize","economized","economizes","economizing"},
"economizer":{"economizer","economizers"},
"economy":{"economies","economy"},
"ecosoc":{"ecosoc","ecosocs"},
"ecphonesis":{"ecphoneses","ecphonesis"},
"ecrevisse":{"ecrevisse","ecrevisses"},
"ecru":{"ecru","ecrus"},
"ecstasy":{"ecstasies","ecstasy"},
"ect":{"ect","ects"},
"ectoblast":{"ectoblast","ectoblasts"},
"ectoderm":{"ectoderm","ectoderms"},
"ectomorphy":{"ectomorphies","ectomorphy"},
"ectoparasite":{"ectoparasite","ectoparasites"},
"ectopistes":{"ectopistes","ectopisteses"},
"ectoprocta":{"ectoprocta","ectoproctas"},
"ectozoa":{"ectozoa","ectozoas"},
"ectozoon":{"ectozoon","ectozoons"},
"ecuadoran":{"ecuadoran","ecuadorans"},
"ecuadorian":{"ecuadorian","ecuadorians"},
"ecumenicalism":{"ecumenicalism","ecumenicalisms"},
"ecumenicism":{"ecumenicism","ecumenicisms"},
"ecumenism":{"ecumenism","ecumenisms"},
"edacity":{"edacities","edacity"},
"edam":{"edam","edams"},
"edaphosauridae":{"edaphosauridae","edaphosauridaes"},
"edd":{"edd","edds"},
"edda":{"edda","eddas"},
"eddington":{"eddington","eddingtons"},
"eddo":{"eddo","eddoes"},
"eddy":{"eddied","eddies","eddy","eddying"},
"edelweiss":{"edelweiss","edelweisses"},
"edema":{"edema","edemas","edemata"},
"eden":{"eden","edens"},
"edentata":{"edentata","edentatas"},
"edge":{"edge","edged","edges","edging"},
"edginess":{"edginess","edginesses"},
"edging":{"edging","edgings"},
"edgy":{"edgier","edgiest","edgy"},
"edibility":{"edibilities","edibility"},
"edible":{"edible","edibles"},
"edibleness":{"edibleness","ediblenesses"},
"edict":{"edict","edicts"},
"edification":{"edification","edifications"},
"edifice":{"edifice","edifices"},
"edify":{"edified","edifies","edify","edifying"},
"edirne":{"edirne","edirnes"},
"edison":{"edison","edisons"},
"edit":{"edit","edited","editing","edits"},
"editing":{"editing","editings"},
"edition":{"edition","editions"},
"editor":{"editor","editors"},
"editorial":{"editorial","editorials"},
"editorialist":{"editorialist","editorialists"},
"editorialize":{"editorialize","editorialized","editorializing"},
"edo":{"edo","edos"},
"edp":{"edp","edps"},
"educate":{"educate","educated","educates","educating"},
"educatee":{"educatee","educatees"},
"education":{"education","educations"},
"educationalist":{"educationalist","educationalists"},
"educationist":{"educationist","educationists"},
"educator":{"educator","educators"},
"educe":{"educe","educed","educes","educing"},
"edward":{"edward","edwards"},
"ee":{"ee","ees"},
"eec":{"eec","eecs"},
"eeg":{"eeg","eegs"},
"eel":{"eel","eels"},
"eelgrass":{"eelgrass","eelgrasses"},
"eelpout":{"eelpout","eelpouts"},
"eerie":{"eerie","eerier","eeriest"},
"eeriness":{"eeriness","eerinesses"},
"eery":{"eerier","eeriest","eery"},
"efface":{"efface","effaced","effaces","effacing"},
"effacement":{"effacement","effacements"},
"effect":{"effect","effected","effecting","effects"},
"effective":{"effective","effectives"},
"effectiveness":{"effectiveness","effectivenesses"},
"effectivity":{"effectivities","effectivity"},
"effects":{"effects","effectses"},
"effectuality":{"effectualities","effectuality"},
"effectualness":{"effectualness","effectualnesses"},
"effectuate":{"effectuate","effectuated","effectuates","effectuating"},
"effectuation":{"effectuation","effectuations"},
"effeminacy":{"effeminacies","effeminacy"},
"effeminateness":{"effeminateness","effeminatenesses"},
"effendi":{"effendi","effendis"},
"effervesce":{"effervesce","effervesced","effervesces","effervescing"},
"effervescence":{"effervescence","effervescences"},
"efficaciousness":{"efficaciousness","efficaciousnesses"},
"efficacy":{"efficacies","efficacy"},
"efficiency":{"efficiencies","efficiency"},
"effigy":{"effigies","effigy"},
"effloresce":{"effloresce","effloresced","effloresces","efflorescing"},
"efflorescence":{"efflorescence","efflorescences"},
"effluence":{"effluence","effluences"},
"effluent":{"effluent","effluents"},
"effluvium":{"effluvia","effluvium","effluviums"},
"efflux":{"efflux","effluxes"},
"effort":{"effort","efforts"},
"effrontery":{"effronteries","effrontery"},
"effulgence":{"effulgence","effulgences"},
"effuse":{"effuse","effused","effuses","effusing"},
"effusion":{"effusion","effusions"},
"effusiveness":{"effusiveness","effusivenesses"},
"efik":{"efik","efiks"},
"egalitarian":{"egalitarian","egalitarians"},
"egalitarianism":{"egalitarianism","egalitarianisms"},
"egeria":{"egeria","egerias"},
"egest":{"egest","egested","egesting","egests"},
"egg":{"egg","egged","egging","eggs"},
"egg-and-anchor":{"egg-and-anchor","egg-and-anchors"},
"egg-and-dart":{"egg-and-dart","egg-and-darts"},
"egg-and-tongue":{"egg-and-tongue","egg-and-tongues"},
"eggar":{"eggar","eggars"},
"eggbeater":{"eggbeater","eggbeaters"},
"eggcup":{"eggcup","eggcups"},
"egger":{"egger","eggers"},
"eggfruit":{"eggfruit","eggfruits"},
"eggplant":{"eggplant","eggplants"},
"eggs":{"eggs","eggses"},
"eggshell":{"eggshell","eggshells"},
"eggwhisk":{"eggwhisk","eggwhisks"},
"egis":{"egis","egises"},
"eglantine":{"eglantine","eglantines"},
"ego":{"ego","egos"},
"ego-trip":{"ego-trip","ego-tripped","ego-tripping","ego-trips"},
"egocentric":{"egocentric","egocentrics"},
"egocentrism":{"egocentrism","egocentrisms"},
"egoism":{"egoism","egoisms"},
"egoist":{"egoist","egoists"},
"egotism":{"egotism","egotisms"},
"egotist":{"egotist","egotists"},
"egress":{"egress","egresses"},
"egression":{"egression","egressions"},
"egretta":{"egretta","egrettas"},
"egypt":{"egypt","egypts"},
"ehf":{"ehf","ehfs"},
"eichhornia":{"eichhornia","eichhornias"},
"eider":{"eider","eiders"},
"eiderdown":{"eiderdown","eiderdowns"},
"eidolon":{"eidola","eidolon","eidolons"},
"eigenfrequency":{"eicies","eigenfrequency"},
"eight":{"eight","eights"},
"eighteen":{"eighteen","eighteens"},
"eighteenmo":{"eighteenmo","eighteenmos"},
"eighteenth":{"eighteenth","eighteenths"},
"eighter":{"eighter","eighters"},
"eighth":{"eighth","eighths"},
"eighties":{"eighties","eightieses"},
"eightsome":{"eightsome","eightsomes"},
"eightvo":{"eightvo","eightvos"},
"eighty":{"eighties","eighty"},
"eimeria":{"eimeria","eimerias"},
"eimeriidae":{"eimeriidae","eimeriidaes"},
"einstein":{"einstein","einsteins"},
"einsteinium":{"einsteinium","einsteiniums"},
"eira":{"eira","eiras"},
"eire":{"eire","eires"},
"eisegesis":{"eisegeses","eisegesis"},
"eisenhower":{"eisenhower","eisenhowers"},
"eisteddfod":{"eisteddfod","eisteddfodau","eisteddfods"},
"ejaculate":{"ejaculate","ejaculated","ejaculates","ejaculating"},
"ejaculation":{"ejaculation","ejaculations"},
"eject":{"eject","ejected","ejecting","ejects"},
"ejection":{"ejection","ejections"},
"ejector":{"ejector","ejectors"},
"eke":{"eke","eked","eking"},
"ekg":{"ekg","ekgs"},
"el":{"el","els"},
"elaborate":{"elaborate","elaborated","elaborates","elaborating"},
"elaborateness":{"elaborateness","elaboratenesses"},
"elaboration":{"elaboration","elaborations"},
"elaeagnaceae":{"elaeagnaceae","elaeagnaceaes"},
"elaeagnus":{"elaeagnus","elaeagnuses"},
"elaeis":{"elaeis","elaeises"},
"elaeocarpaceae":{"elaeocarpaceae","elaeocarpaceaes"},
"elaeocarpus":{"elaeocarpus","elaeocarpuses"},
"elagatis":{"elagatis","elagatises"},
"elamite":{"elamite","elamites"},
"elamitic":{"elamitic","elamitics"},
"elan":{"elan","elans"},
"eland":{"eland","elands"},
"elanoides":{"elanoides","elanoideses"},
"elanus":{"elanus","elanuses"},
"elaphe":{"elaphe","elaphes"},
"elaphure":{"elaphure","elaphures"},
"elaphurus":{"elaphurus","elaphuruses"},
"elapid":{"elapid","elapids"},
"elapidae":{"elapidae","elapidaes"},
"elapse":{"elapse","elapsed","elapses","elapsing"},
"elasmobranch":{"elasmobranch","elasmobranches"},
"elasmobranchii":{"elasmobranchii","elasmobranchiis"},
"elastance":{"elastance","elastances"},
"elastic":{"elastic","elastics"},
"elasticize":{"elasticize","elasticized","elasticizing"},
"elate":{"elate","elated","elates","elating"},
"elater":{"elater","elaters"},
"elaterid":{"elaterid","elaterids"},
"elateridae":{"elateridae","elateridaes"},
"elation":{"elation","elations"},
"elavil":{"elavil","elavils"},
"elbe":{"elbe","elbes"},
"elbow":{"elbow","elbowed","elbowing","elbows"},
"elder":{"elder","elders"},
"elderberry":{"elderberries","elderberry"},
"eldest":{"eldest","eldests"},
"eldorado":{"eldorado","eldorados"},
"elecampane":{"elecampane","elecampanes"},
"elect":{"elect","elected","electing","elects"},
"election":{"election","elections"},
"electioneer":{"electioneer","electioneered","electioneering"},
"electioneering":{"electioneering","electioneerings"},
"elector":{"elector","electors"},
"electorate":{"electorate","electorates"},
"electric":{"electric","electrics"},
"electrician":{"electrician","electricians"},
"electricity":{"electricities","electricity"},
"electrify":{"electrified","electrifies","electrify","electrifying"},
"electro":{"electro","electros"},
"electrocardiogram":{"electrocardiogram","electrocardiograms"},
"electrocardiograph":{"electrocardiograph","electrocardiographs"},
"electrocardiography":{"electrocardiographies","electrocardiography"},
"electrocautery":{"electrocauteries","electrocautery"},
"electrocute":{"electrocute","electrocuted","electrocutes","electrocuting"},
"electrocution":{"electrocution","electrocutions"},
"electrodeposit":{"electrodeposit","electrodeposited","electrodepositing"},
"electrodialysis":{"electrodialyses","electrodialysis"},
"electroencephalogram":{"electroencephalogram","electroencephalograms"},
"electroform":{"electroform","electroformed","electroforming"},
"electrolytic":{"electrolytic","electrolytics"},
"electrolyze":{"electrolyze","electrolyzed","electrolyzing"},
"electromagnetics":{"electromagnetics","electromagneticses"},
"electromagnetism":{"electromagnetism","electromagnetisms"},
"electron":{"electron","electrons"},
"electrophoresis":{"electrophoreses","electrophoresis"},
"electrophoridae":{"electrophoridae","electrophoridaes"},
"electrophorus":{"electrophori","electrophorus","electrophoruses"},
"electroplate":{"electroplate","electroplated","electroplating"},
"electroshock":{"electroshock","electroshocks"},
"electrotype":{"electrotype","electrotyped","electrotyping"},
"electuary":{"electuaries","electuary"},
"elegance":{"elegance","elegances"},
"elegancy":{"elegancies","elegancy"},
"elegize":{"elegize","elegized","elegizing"},
"elegy":{"elegies","elegy"},
"element":{"element","elements"},
"elemental":{"elemental","elementals"},
"elemi":{"elemi","elemis"},
"elenchus":{"elenchi","elenchus"},
"eleocharis":{"eleocharis","eleocharises"},
"eleotridae":{"eleotridae","eleotridaes"},
"elephant":{"elephant","elephants"},
"elephant-tusk":{"elephant-tusk","elephant-tusks"},
"elephantidae":{"elephantidae","elephantidaes"},
"elephantopus":{"elephantopus","elephantopuses"},
"elephas":{"elephas","elephases"},
"elettaria":{"elettaria","elettarias"},
"eleusine":{"eleusine","eleusines"},
"eleutherodactylus":{"eleutherodactylus","eleutherodactyluses"},
"elevate":{"elevate","elevated","elevates","elevating"},
"elevation":{"elevation","elevations"},
"elevator":{"elevator","elevators"},
"eleven":{"eleven","elevens"},
"eleven-plus":{"eleven-plus","eleven-pluses"},
"eleventh":{"eleventh","elevenths"},
"elf":{"elf","elves"},
"elicit":{"elicit","elicited","eliciting","elicits"},
"elicitation":{"elicitation","elicitations"},
"elide":{"elide","elided","elides","eliding"},
"eliminate":{"eliminate","eliminated","eliminates","eliminating"},
"elimination":{"elimination","eliminations"},
"elint":{"elint","elints"},
"elinvar":{"elinvar","elinvars"},
"eliomys":{"eliomys","eliomyses"},
"elizabeth":{"elizabeth","elizabeths"},
"elk":{"elk","elks"},
"elkhound":{"elkhound","elkhounds"},
"elkwood":{"elkwood","elkwoods"},
"ellas":{"ellas","ellases"},
"ellipse":{"ellipse","ellipses"},
"ellipsis":{"ellipses","ellipsis"},
"ellipticity":{"ellipticities","ellipticity"},
"ellul":{"ellul","elluls"},
"elm":{"elm","elms"},
"elmwood":{"elmwood","elmwoods"},
"elodea":{"elodea","elodeas"},
"eloign":{"eloign","eloigned","eloigning"},
"elongate":{"elongate","elongated","elongates","elongating"},
"elongation":{"elongation","elongations"},
"elope":{"elope","eloped","elopes","eloping"},
"elopement":{"elopement","elopements"},
"elopidae":{"elopidae","elopidaes"},
"elops":{"elops","elopses"},
"eloquence":{"eloquence","eloquences"},
"elsass":{"elsass","elsasses"},
"elucidate":{"elucidate","elucidated","elucidates","elucidating"},
"elucidation":{"elucidation","elucidations"},
"elude":{"elude","eluded","eludes","eluding"},
"eluding":{"eluding","eludings"},
"elul":{"elul","eluls"},
"elusion":{"elusion","elusions"},
"eluviate":{"eluviate","eluviated","eluviates","eluviating"},
"eluvium":{"eluvia","eluvium"},
"elymus":{"elymus","elymuses"},
"elysium":{"elysium","elysiums"},
"elytron":{"elytra","elytron","elytrons"},
"elytrum":{"elytra","elytrum"},
"em":{"em","ems"},
"emaciate":{"emaciate","emaciated","emaciates","emaciating"},
"emaciation":{"emaciation","emaciations"},
"email":{"email","emails"},
"emanate":{"emanate","emanated","emanates","emanating"},
"emanation":{"emanation","emanations"},
"emancipate":{"emancipate","emancipated","emancipates","emancipating"},
"emancipation":{"emancipation","emancipations"},
"emancipationist":{"emancipationist","emancipationists"},
"emancipator":{"emancipator","emancipators"},
"emasculate":{"emasculate","emasculated","emasculates","emasculating"},
"emasculation":{"emasculation","emasculations"},
"embalm":{"embalm","embalmed","embalming"},
"embank":{"embank","embanked","embanking"},
"embankment":{"embankment","embankments"},
"embargo":{"embargo","embargoed","embargoes","embargoing"},
"embark":{"embark","embarked","embarking","embarks"},
"embarkation":{"embarkation","embarkations"},
"embarkment":{"embarkment","embarkments"},
"embarrass":{"embarrass","embarrassed","embarrasses","embarrassing"},
"embarrassment":{"embarrassment","embarrassments"},
"embassador":{"embassador","embassadors"},
"embassy":{"embassies","embassy"},
"embattle":{"embattle","embattled","embattling"},
"embay":{"embay","embayed","embaying"},
"embed":{"embed","embedded","embedding","embeds"},
"embellish":{"embellish","embellished","embellishes","embellishing"},
"embellishment":{"embellishment","embellishments"},
"ember":{"ember","embers"},
"emberiza":{"emberiza","emberizas"},
"emberizidae":{"emberizidae","emberizidaes"},
"embezzle":{"embezzle","embezzled","embezzles","embezzling"},
"embezzlement":{"embezzlement","embezzlements"},
"embezzler":{"embezzler","embezzlers"},
"embiodea":{"embiodea","embiodeas"},
"embioptera":{"embioptera","embiopteras"},
"embiotocidae":{"embiotocidae","embiotocidaes"},
"embitter":{"embitter","embittered","embittering","embitters"},
"emblaze":{"emblaze","emblazed","emblazing"},
"emblazon":{"emblazon","emblazoned","emblazoning","emblazons"},
"emblem":{"emblem","emblemed","embleming","emblems"},
"emblematize":{"emblematize","emblematized","emblematizing"},
"embodiment":{"embodiment","embodiments"},
"embody":{"embodied","embodies","embody","embodying"},
"embolden":{"embolden","emboldened","emboldening","emboldens"},
"embolectomy":{"embolectomies","embolectomy"},
"embolism":{"embolism","embolisms"},
"embolus":{"emboli","embolus"},
"emboly":{"embolies","emboly"},
"embonpoint":{"embonpoint","embonpoints"},
"embosom":{"embosom","embosomed","embosoming"},
"emboss":{"emboss","embossed","embosses","embossing"},
"embossment":{"embossment","embossments"},
"embothrium":{"embothrium","embothriums"},
"embouchure":{"embouchure","embouchures"},
"embowel":{"embowel","emboweled","emboweling","embowelled","embowelling"},
"embower":{"embower","embowered","embowering","embowers"},
"embrace":{"embrace","embraced","embraces","embracing"},
"embracery":{"embraceries","embracery"},
"embracing":{"embracing","embracings"},
"embrangle":{"embrangle","embrangled","embrangles","embrangling"},
"embrasure":{"embrasure","embrasures"},
"embrectomy":{"embrectomies","embrectomy"},
"embrittle":{"embrittle","embrittled","embrittling"},
"embrocate":{"embrocate","embrocated","embrocating"},
"embrocation":{"embrocation","embrocations"},
"embroider":{"embroider","embroidered","embroidering","embroiders"},
"embroidery":{"embroideries","embroidery"},
"embroil":{"embroil","embroiled","embroiling","embroils"},
"embroilment":{"embroilment","embroilments"},
"embrown":{"embrown","embrowned","embrowning"},
"embrue":{"embrue","embrued","embrues","embruing"},
"embryectomy":{"embryectomies","embryectomy"},
"embryo":{"embryo","embryos"},
"embryology":{"embryologies","embryology"},
"embus":{"embus","embused","embuses","embusing","embussed","embusses","embussing"},
"embusque":{"embusque","embusques"},
"emcee":{"emcee","emceed","emceeing","emcees"},
"emeer":{"emeer","emeers"},
"emend":{"emend","emended","emending"},
"emendate":{"emendate","emendated","emendating"},
"emerald":{"emerald","emeralds"},
"emerge":{"emerge","emerged","emerges","emerging"},
"emergence":{"emergence","emergences"},
"emergency":{"emergencies","emergency"},
"emersion":{"emersion","emersions"},
"emeside":{"emeside","emesides"},
"emetic":{"emetic","emetics"},
"emf":{"emf","emfs"},
"emigrant":{"emigrant","emigrants"},
"emigrate":{"emigrate","emigrated","emigrating"},
"emigration":{"emigration","emigrations"},
"emigre":{"emigre","emigres"},
"emigree":{"emigree","emigrees"},
"emilia":{"emilia","emilias"},
"eminence":{"eminence","eminences"},
"eminency":{"eminencies","eminency"},
"emir":{"emir","emirs"},
"emissary":{"emissaries","emissary"},
"emission":{"emission","emissions"},
"emit":{"emit","emits","emitted","emitting"},
"emitter":{"emitter","emitters"},
"emmanthe":{"emmanthe","emmanthes"},
"emmental":{"emmental","emmentals"},
"emmentaler":{"emmentaler","emmentalers"},
"emmenthal":{"emmenthal","emmenthals"},
"emmenthaler":{"emmenthaler","emmenthalers"},
"emmer":{"emmer","emmers"},
"emmet":{"emmet","emmets"},
"emmy":{"emmies","emmy","emmys"},
"emollient":{"emollient","emollients"},
"emote":{"emote","emoted","emoting"},
"emotion":{"emotion","emotions"},
"emotionalism":{"emotionalism","emotionalisms"},
"emotionality":{"emotionalities","emotionality"},
"emotionalize":{"emotionalize","emotionalized","emotionalizing"},
"emotionlessness":{"emotionlessness","emotionlessnesses"},
"empanel":{"empanel","empaneled","empaneling","empanelled","empanelling","empanels"},
"empathize":{"empathize","empathized","empathizes","empathizing"},
"empennage":{"empennage","empennages"},
"emperor":{"emperor","emperors"},
"empetraceae":{"empetraceae","empetraceaes"},
"empetrum":{"empetrum","empetrums"},
"emphasis":{"emphases","emphasis"},
"emphasize":{"emphasize","emphasized","emphasizes","emphasizing"},
"emphasizing":{"emphasizing","emphasizings"},
"emphysema":{"emphysema","emphysemas"},
"empire":{"empire","empires"},
"empiricism":{"empiricism","empiricisms"},
"empirin":{"empirin","empirins"},
"emplace":{"emplace","emplaced","emplacing"},
"emplacement":{"emplacement","emplacements"},
"emplane":{"emplane","emplaned","emplanes","emplaning"},
"employ":{"employ","employed","employing","employs"},
"employee":{"employee","employees"},
"employer":{"employer","employers"},
"employment":{"employment","employments"},
"empoison":{"empoison","empoisoned","empoisoning"},
"emporium":{"emporia","emporium","emporiums"},
"empower":{"empower","empowered","empowering","empowers"},
"empowerment":{"empowerment","empowerments"},
"empress":{"empress","empresses"},
"empressement":{"empressement","empressements"},
"emptiness":{"emptiness","emptinesses"},
"emptor":{"emptor","emptors"},
"empty":{"emptied","emptier","empties","emptiest","empty","emptying"},
"emptying":{"emptying","emptyings"},
"empurple":{"empurple","empurpled","empurples","empurpling"},
"empurpled":{"empurpled","empurpleds"},
"empyrean":{"empyrean","empyreans"},
"emu":{"emu","emus"},
"emulate":{"emulate","emulated","emulates","emulating"},
"emulsify":{"emulsified","emulsifies","emulsify","emulsifying"},
"emulsion":{"emulsion","emulsions"},
"emunctory":{"emunctories","emunctory"},
"emydidae":{"emydidae","emydidaes"},
"en":{"en","ens"},
"en-lil":{"en-lil","en-lils"},
"enable":{"enable","enabled","enabling"},
"enact":{"enact","enacted","enacting","enacts"},
"enactment":{"enactment","enactments"},
"enamel":{"enamel","enameled","enameling","enamelled","enamelling","enamels"},
"enamor":{"enamor","enamored","enamoring","enamors"},
"enamoredness":{"enamoredness","enamorednesses"},
"enantiomer":{"enantiomer","enantiomers"},
"enantiomorph":{"enantiomorph","enantiomorphs"},
"enantiomorphism":{"enantiomorphism","enantiomorphisms"},
"enarthrosis":{"enarthroses","enarthrosis"},
"enate":{"enate","enates"},
"enation":{"enation","enations"},
"encage":{"encage","encaged","encaging"},
"encamp":{"encamp","encamped","encamping","encamps"},
"encampment":{"encampment","encampments"},
"encapsulate":{"encapsulate","encapsulated","encapsulating"},
"encapsule":{"encapsule","encapsuled","encapsuling"},
"encase":{"encase","encased","encases","encasing"},
"encasement":{"encasement","encasements"},
"encelia":{"encelia","encelias"},
"enceliopsis":{"enceliopses","enceliopsis"},
"encephalogram":{"encephalogram","encephalograms"},
"encephaloma":{"encephaloma","encephalomas","encephalomata"},
"encephalon":{"encephala","encephalon","encephalons"},
"enchain":{"enchain","enchained","enchaining"},
"enchant":{"enchant","enchanted","enchanting","enchants"},
"enchantment":{"enchantment","enchantments"},
"enchantress":{"enchantress","enchantresses"},
"enchase":{"enchase","enchased","enchasing"},
"enchilada":{"enchilada","enchiladas"},
"enchiridion":{"enchiridia","enchiridion","enchiridions"},
"enchondroma":{"enchondroma","enchondromas","enchondromata"},
"encina":{"encina","encinas"},
"encipher":{"encipher","enciphered","enciphering","enciphers"},
"encircle":{"encircle","encircled","encircles","encircling"},
"encirclement":{"encirclement","encirclements"},
"enclasp":{"enclasp","enclasped","enclasping"},
"enclose":{"enclose","enclosed","encloses","enclosing"},
"enclosing":{"enclosing","enclosings"},
"enclosure":{"enclosure","enclosures"},
"encode":{"encode","encoded","encodes","encoding"},
"encoding":{"encoding","encodings"},
"encomium":{"encomia","encomium","encomiums"},
"encompass":{"encompass","encompassed","encompasses","encompassing"},
"encore":{"encore","encored","encores","encoring"},
"encounter":{"encounter","encountered","encountering","encounters"},
"encourage":{"encourage","encouraged","encourages","encouraging"},
"encouragement":{"encouragement","encouragements"},
"encrimson":{"encrimson","encrimsoned","encrimsoning"},
"encroach":{"encroach","encroached","encroaches","encroaching"},
"encroacher":{"encroacher","encroachers"},
"encroachment":{"encroachment","encroachments"},
"encrust":{"encrust","encrusted","encrusting","encrusts"},
"encrustation":{"encrustation","encrustations"},
"encrypt":{"encrypt","encrypted","encrypting","encrypts"},
"encryption":{"encryption","encryptions"},
"enculturate":{"enculturate","enculturated","enculturating"},
"encumber":{"encumber","encumbered","encumbering","encumbers"},
"encumbrance":{"encumbrance","encumbrances"},
"encyclia":{"encyclia","encyclias"},
"encyclical":{"encyclical","encyclicals"},
"encyclopaedia":{"encyclopaedia","encyclopaedias"},
"encyclopedia":{"encyclopedia","encyclopedias"},
"encyclopedist":{"encyclopedist","encyclopedists"},
"encyst":{"encyst","encysted","encysting"},
"end":{"end","ended","ending","ends"},
"endaemonism":{"endaemonism","endaemonisms"},
"endamage":{"endamage","endamaged","endamaging"},
"endameba":{"endameba","endamebae","endamebas"},
"endamoeba":{"endamoeba","endamoebas"},
"endamoebidae":{"endamoebidae","endamoebidaes"},
"endanger":{"endanger","endangered","endangering","endangers"},
"endear":{"endear","endeared","endearing"},
"endearment":{"endearment","endearments"},
"endeavor":{"endeavor","endeavored","endeavoring","endeavors"},
"endeavour":{"endeavour","endeavoured","endeavouring","endeavours"},
"endemism":{"endemism","endemisms"},
"ending":{"ending","endings"},
"endive":{"endive","endives"},
"endoblast":{"endoblast","endoblasts"},
"endocardium":{"endocardia","endocardium"},
"endocranium":{"endocrania","endocranium"},
"endoderm":{"endoderm","endoderms"},
"endodontia":{"endodontia","endodontias"},
"endodontics":{"endodontics","endodonticses"},
"endogamy":{"endogamies","endogamy"},
"endometriosis":{"endometrioses","endometriosis"},
"endometritis":{"endometritis","endometritises"},
"endometrium":{"endometria","endometritria","endometrium"},
"endomorphy":{"endomorphies","endomorphy"},
"endomycetales":{"endomycetales","endomycetaleses"},
"endoparasite":{"endoparasite","endoparasites"},
"endoprocta":{"endoprocta","endoproctas"},
"endorse":{"endorse","endorsed","endorses","endorsing"},
"endorsement":{"endorsement","endorsements"},
"endorser":{"endorser","endorsers"},
"endosteum":{"endostea","endosteum"},
"endostosis":{"endostoses","endostosis"},
"endothecium":{"endothecia","endothecicia","endothecium"},
"endothelioma":{"endothelioma","endotheliomata"},
"endothelium":{"endothelia","endothelilia","endothelium"},
"endow":{"endow","endowed","endowing","endows"},
"endowment":{"endowment","endowments"},
"endozoa":{"endozoa","endozoas"},
"endozoan":{"endozoan","endozoans"},
"endpoint":{"endpoint","endpoints"},
"endue":{"endue","endued","endues","enduing"},
"endurance":{"endurance","endurances"},
"endure":{"endure","endured","endures","enduring"},
"enduringness":{"enduringness","enduringnesses"},
"ene":{"ene","enes"},
"enema":{"enema","enemas","enemata"},
"enemy":{"enemies","enemy"},
"energid":{"energid","energids"},
"energize":{"energize","energized","energizes","energizing"},
"energizing":{"energizing","energizings"},
"energy":{"energies","energy"},
"enervate":{"enervate","enervated","enervates","enervating"},
"enervation":{"enervation","enervations"},
"enets":{"enets","enetses"},
"enface":{"enface","enfaced","enfacing"},
"enfeeble":{"enfeeble","enfeebled","enfeebles","enfeebling"},
"enfeeblement":{"enfeeblement","enfeeblements"},
"enfeoff":{"enfeoff","enfeoffed","enfeoffing"},
"enfetter":{"enfetter","enfettered","enfettering"},
"enfilade":{"enfilade","enfiladed","enfilading"},
"enflurane":{"enflurane","enfluranes"},
"enfold":{"enfold","enfolded","enfolding","enfolds"},
"enfolding":{"enfolding","enfoldings"},
"enforce":{"enforce","enforced","enforces","enforcing"},
"enforcer":{"enforcer","enforcers"},
"enfranchise":{"enfranchise","enfranchised","enfranchises","enfranchising"},
"enfranchisement":{"enfranchisement","enfranchisements"},
"engage":{"engage","engaged","engages","engaging"},
"engagement":{"engagement","engagements"},
"engarland":{"engarland","engarlanded","engarlanding","engarlands"},
"engels":{"engels","engelses"},
"engender":{"engender","engendered","engendering","engenders"},
"engine":{"engine","engines"},
"engineer":{"engineer","engineered","engineering","engineers"},
"engineering":{"engineering","engineerings"},
"enginery":{"engineries","enginery"},
"engird":{"engird","engirded","engirding","engirt"},
"engirdle":{"engirdle","engirdled","engirdles","engirdling"},
"english":{"english","englishes"},
"english-gothic":{"english-gothic","english-gothics"},
"english-weed":{"english-weed","english-weeds"},
"englishman":{"englishman","englishmen"},
"englishwoman":{"englishwoman","englishwomen"},
"englut":{"englut","engluts","englutted","englutting"},
"engorge":{"engorge","engorged","engorges","engorging"},
"engraft":{"engraft","engrafted","engrafting","engrafts"},
"engrail":{"engrail","engrailed","engrailing"},
"engrain":{"engrain","engrained","engraining"},
"engram":{"engram","engrams"},
"engraulidae":{"engraulidae","engraulidaes"},
"engraulis":{"engraulis","engraulises"},
"engrave":{"engrave","engraved","engraves","engraving"},
"engraver":{"engraver","engravers"},
"engraving":{"engraving","engravings"},
"engross":{"engross","engrossed","engrosses","engrossing"},
"engrossment":{"engrossment","engrossments"},
"engulf":{"engulf","engulfed","engulfing","engulfs"},
"enhance":{"enhance","enhanced","enhances","enhancing"},
"enhancement":{"enhancement","enhancements"},
"enhydra":{"enhydra","enhydras"},
"enigma":{"enigma","enigmas","enigmata"},
"enisle":{"enisle","enisled","enisling"},
"enjambment":{"enjambment","enjambments"},
"enjoin":{"enjoin","enjoined","enjoining","enjoins"},
"enjoining":{"enjoining","enjoinings"},
"enjoinment":{"enjoinment","enjoinments"},
"enjoy":{"enjoy","enjoyed","enjoying","enjoys"},
"enjoyer":{"enjoyer","enjoyers"},
"enjoyment":{"enjoyment","enjoyments"},
"enkindle":{"enkindle","enkindled","enkindles","enkindling"},
"enlace":{"enlace","enlaced","enlaces","enlacing"},
"enlarge":{"enlarge","enlarged","enlarges","enlarging"},
"enlargement":{"enlargement","enlargements"},
"enlarger":{"enlarger","enlargers"},
"enlighten":{"enlighten","enlightened","enlightening","enlightens"},
"enlightened":{"enlightened","enlighteneds"},
"enlightenment":{"enlightenment","enlightenments"},
"enlil":{"enlil","enlils"},
"enlist":{"enlist","enlisted","enlisting","enlists"},
"enlistee":{"enlistee","enlistees"},
"enlisting":{"enlisting","enlistings"},
"enlistment":{"enlistment","enlistments"},
"enliven":{"enliven","enlivened","enlivening","enlivens"},
"enmesh":{"enmesh","enmeshed","enmeshes","enmeshing"},
"enmity":{"enmities","enmity"},
"ennead":{"ennead","enneads"},
"enneahedron":{"enneahedra","enneahedron","enneahedrons"},
"ennoble":{"ennoble","ennobled","ennobles","ennobling"},
"ennui":{"ennui","ennuis"},
"enologist":{"enologist","enologists"},
"enology":{"enologies","enology"},
"enormity":{"enormities","enormity"},
"enormousness":{"enormousness","enormousnesses"},
"enough":{"enough","enoughs"},
"enounce":{"enounce","enounced","enounces","enouncing"},
"enplane":{"enplane","enplaned","enplanes","enplaning"},
"enquire":{"enquire","enquired","enquires","enquiring"},
"enquirer":{"enquirer","enquirers"},
"enquiry":{"enquiries","enquiry"},
"enrage":{"enrage","enraged","enraging"},
"enragement":{"enragement","enragements"},
"enrapture":{"enrapture","enraptured","enraptures","enrapturing"},
"enregister":{"enregister","enregistered","enregistering"},
"enrich":{"enrich","enriched","enriching"},
"enrichment":{"enrichment","enrichments"},
"enrobe":{"enrobe","enrobed","enrobing"},
"enrol":{"enrol","enrolled","enrolling","enrols"},
"enroll":{"enroll","enrolled","enrolling","enrolls"},
"enrollment":{"enrollment","enrollments"},
"enrolment":{"enrolment","enrolments"},
"enroot":{"enroot","enrooted","enrooting"},
"ens":{"ens","entia"},
"ensconce":{"ensconce","ensconced","ensconces","ensconcing"},
"ensemble":{"ensemble","ensembles"},
"ensete":{"ensete","ensetes"},
"enshrine":{"enshrine","enshrined","enshrines","enshrining"},
"enshroud":{"enshroud","enshrouded","enshrouding","enshrouds"},
"ensign":{"ensign","ensigns"},
"ensilage":{"ensilage","ensilaged","ensilages","ensilaging"},
"ensile":{"ensile","ensiled","ensiling"},
"ensis":{"enses","ensis"},
"ensky":{"enskied","ensky","enskyed","enskying"},
"enslave":{"enslave","enslaved","enslaving"},
"enslavement":{"enslavement","enslavements"},
"enslaving":{"enslaving","enslavings"},
"ensnare":{"ensnare","ensnared","ensnares","ensnaring"},
"ensorcel":{"ensorcel","ensorceled","ensorceling"},
"ensoul":{"ensoul","ensouled","ensouling"},
"ensphere":{"ensphere","ensphered","ensphering"},
"ensue":{"ensue","ensued","ensues","ensuing"},
"ensure":{"ensure","ensured","ensures","ensuring"},
"entail":{"entail","entailed","entailing","entails"},
"entailment":{"entailment","entailments"},
"entameba":{"entameba","entamebae","entamebas"},
"entamoeba":{"entamoeba","entamoebae","entamoebas"},
"entandrophragma":{"entandrophragma","entandrophragmas"},
"entangle":{"entangle","entangled","entangles","entangling"},
"entanglement":{"entanglement","entanglements"},
"entasis":{"entases","entasis"},
"entelechy":{"entelechies","entelechy"},
"entellus":{"entellus","entelluses"},
"entente":{"entente","ententes"},
"enter":{"enter","entered","entering","enters"},
"enterics":{"enterics","entericses"},
"entering":{"entering","enterings"},
"enterobacteria":{"enterobacteria","enterobacterias"},
"enterobacteriaceae":{"enterobacteriaceae","enterobacteriaceaes"},
"enterobius":{"enterobius","enterobiuses"},
"enterolobium":{"enterolobium","enterolobiums"},
"enteron":{"enteron","entertera"},
"enterostomy":{"enterostomies","enterostomy"},
"enterotomy":{"enterotomies","enterotomy"},
"enterovirus":{"enterovirus","enteroviviruses"},
"enterprise":{"enterprise","enterprises"},
"enterpriser":{"enterpriser","enterprisers"},
"enterprisingness":{"enterprisingness","enterprisingnesses"},
"entertain":{"entertain","entertained","entertaining","entertains"},
"entertainment":{"entertainment","entertainments"},
"enthalpy":{"enthalpies","enthalpy"},
"enthral":{"enthral","enthralled","enthralling","enthrals"},
"enthrall":{"enthrall","enthralled","enthralling","enthralls"},
"enthrallment":{"enthrallment","enthrallments"},
"enthrone":{"enthrone","enthroned","enthrones","enthroning"},
"enthronement":{"enthronement","enthronements"},
"enthronization":{"enthronization","enthronizations"},
"enthuse":{"enthuse","enthused","enthusing"},
"enthusiasm":{"enthusiasm","enthusiasms"},
"enthusiast":{"enthusiast","enthusiasts"},
"entice":{"entice","enticed","entices","enticing"},
"enticement":{"enticement","enticements"},
"entire":{"entire","entires"},
"entireness":{"entireness","entirenesses"},
"entirety":{"entireties","entirety"},
"entitle":{"entitle","entitled","entitles","entitling"},
"entity":{"entities","entity"},
"entoblast":{"entoblast","entoblasts"},
"entoderm":{"entoderm","entoderms"},
"entoil":{"entoil","entoiled","entoiling"},
"entoloma":{"entoloma","entolomas"},
"entolomataceae":{"entolomataceae","entolomataceaes"},
"entomb":{"entomb","entombed","entombing","entombs"},
"entombment":{"entombment","entombments"},
"entomologist":{"entomologist","entomologists"},
"entomophthora":{"entomophthora","entomophthoras"},
"entomophthoraceae":{"entomophthoraceae","entomophthoraceaes"},
"entomophthorales":{"entomophthorales","entomophthoraleses"},
"entomostraca":{"entomostraca","entomostracas"},
"entoparasite":{"entoparasite","entoparasites"},
"entoprocta":{"entoprocta","entoproctas"},
"entourage":{"entourage","entourages"},
"entozoa":{"entozoa","entozoas"},
"entozoan":{"entozoan","entozoans","entozozoa"},
"entozoon":{"entozoon","entozoons","entozozoa"},
"entrails":{"entrails","entrailses"},
"entrain":{"entrain","entrained","entraining","entrains"},
"entrammel":{"entrammel","entrammelled","entrammelling","entrammels"},
"entrance":{"entrance","entranced","entrances","entrancing"},
"entrancement":{"entrancement","entrancements"},
"entranceway":{"entranceway","entranceways"},
"entrant":{"entrant","entrants"},
"entrap":{"entrap","entrapped","entrapping","entraps"},
"entreat":{"entreat","entreated","entreating","entreats"},
"entreaty":{"entreaties","entreaty"},
"entrechat":{"entrechat","entrechats"},
"entree":{"entree","entrees"},
"entrench":{"entrench","entrenched","entrenches","entrenching"},
"entrenchment":{"entrenchment","entrenchments"},
"entrepot":{"entrepot","entrepots"},
"entrepreneur":{"entrepreneur","entrepreneurs"},
"entropy":{"entropies","entropy"},
"entrust":{"entrust","entrusted","entrusting","entrusts"},
"entry":{"entries","entry"},
"entryway":{"entryway","entryways"},
"entsi":{"entsi","entsis"},
"entsy":{"entsies","entsy"},
"entwine":{"entwine","entwined","entwines","entwining"},
"entwist":{"entwist","entwisted","entwisting"},
"enucleate":{"enucleate","enucleated","enucleating"},
"enuki":{"enuki","enukis"},
"enumerate":{"enumerate","enumerated","enumerates","enumerating"},
"enumeration":{"enumeration","enumerations"},
"enunciate":{"enunciate","enunciated","enunciates","enunciating"},
"enunciation":{"enunciation","enunciations"},
"enure":{"enure","enured","enuring"},
"enuresis":{"enureses","enuresis"},
"envelop":{"envelop","enveloped","enveloping","envelops"},
"envelope":{"envelope","envelopes"},
"enveloping":{"enveloping","envelopings"},
"envelopment":{"envelopment","envelopments"},
"envenom":{"envenom","envenomed","envenoming","envenoms"},
"enviousness":{"enviousness","enviousnesses"},
"environ":{"environ","environed","environing","environs"},
"environment":{"environment","environments"},
"environmentalist":{"environmentalist","environmentalists"},
"environs":{"environs","environses"},
"envisage":{"envisage","envisaged","envisages","envisaging"},
"envision":{"envision","envisioned","envisioning","envisions"},
"envisioning":{"envisioning","envisionings"},
"envoi":{"envoi","envois"},
"envoy":{"envoy","envoys"},
"envy":{"envied","envies","envy","envying"},
"enwind":{"enwind","enwinding","enwinds","enwound"},
"enwomb":{"enwomb","enwombed","enwombing"},
"enwrap":{"enwrap","enwrapped","enwrapping","enwraps"},
"enwreathe":{"enwreathe","enwreathed","enwreathing"},
"eocene":{"eocene","eocenes"},
"eohippus":{"eohippus","eohippuses"},
"eolian":{"eolian","eolians"},
"eolic":{"eolic","eolics"},
"eon":{"eon","eons"},
"eosin":{"eosin","eosins"},
"eosinophil":{"eosinophil","eosinophils"},
"eosinophile":{"eosinophile","eosinophiles"},
"epa":{"epa","epas"},
"epacridaceae":{"epacridaceae","epacridaceaes"},
"epanaphora":{"epanaphora","epanaphoras"},
"eparchate":{"eparchate","eparchates"},
"eparchy":{"eparchies","eparchy"},
"epaulet":{"epaulet","epaulets"},
"epaulette":{"epaulette","epaulettes"},
"epencephalon":{"epencephala","epencephalon"},
"epenthesis":{"epentheses","epenthesis"},
"epexegesis":{"epexegeses","epexegesis"},
"epha":{"epha","ephas"},
"ephah":{"ephah","ephahs"},
"ephebus":{"ephebi","ephebus"},
"ephedra":{"ephedra","ephedras"},
"ephedraceae":{"ephedraceae","ephedraceaes"},
"ephemera":{"ephemera","ephemerae","ephemeras"},
"ephemerality":{"ephemeralities","ephemerality"},
"ephemeralness":{"ephemeralness","ephemeralnesses"},
"ephemerid":{"ephemerid","ephemerids"},
"ephemerida":{"ephemerida","ephemeridas"},
"ephemeridae":{"ephemeridae","ephemeridaes"},
"ephemeris":{"ephemerides","ephemeris"},
"ephemeron":{"ephemera","ephemerera","ephemererons","ephemeron","ephemerons"},
"ephemeroptera":{"ephemeroptera","ephemeropteras"},
"ephemeropteran":{"ephemeropteran","ephemeropterans"},
"ephestia":{"ephestia","ephestias"},
"ephippidae":{"ephippidae","ephippidaes"},
"ephippiorhynchus":{"ephippiorhynchus","ephippiorhynchuses"},
"ephor":{"ephor","ephori","ephors"},
"epiboly":{"epibolies","epiboly"},
"epic":{"epic","epics"},
"epicalyx":{"epicalyx","epicalyxes"},
"epicanthus":{"epicanthi","epicanthus"},
"epicardium":{"epicardia","epicardium"},
"epicarp":{"epicarp","epicarps"},
"epicedium":{"epicedidia","epicedium"},
"epicenter":{"epicenter","epicenters"},
"epicentre":{"epicentre","epicentres"},
"epicine":{"epicine","epicines"},
"epiclesis":{"epicleses","epiclesis"},
"epicranium":{"epicrania","epicranium"},
"epicure":{"epicure","epicures"},
"epicurean":{"epicurean","epicureans"},
"epidemic":{"epidemic","epidemics"},
"epidendrum":{"epidendrum","epidendrums"},
"epidermis":{"epidermis","epidermises"},
"epididymis":{"epididydidymides","epididymides","epididymis"},
"epidural":{"epidural","epidurals"},
"epigaea":{"epigaea","epigaeas"},
"epigastrium":{"epigastria","epigastrium"},
"epiglottis":{"epiglottides","epiglottis","epiglottises"},
"epigon":{"epigon","epigons"},
"epigone":{"epigone","epigones"},
"epigram":{"epigram","epigrams"},
"epigrammatize":{"epigrammatize","epigrammatized","epigrammatizing"},
"epilachna":{"epilachna","epilachnas"},
"epilate":{"epilate","epilated","epilates","epilating"},
"epilimnion":{"epilimnia","epilimnion"},
"epilobium":{"epilobium","epilobiums"},
"epilog":{"epilog","epilogs"},
"epilogue":{"epilogue","epilogues"},
"epimedium":{"epimedium","epimediums"},
"epimysium":{"epimysia","epimysium"},
"epinasty":{"epinasties","epinasty"},
"epinephelus":{"epinephelus","epinepheluses"},
"epinephrin":{"epinephrin","epinephrins"},
"epinephrine":{"epinephrine","epinephrines"},
"epineurium":{"epineuria","epineurium"},
"epipactis":{"epipactis","epipactises"},
"epiphany":{"epiphanies","epiphany"},
"epiphenomenon":{"epiphenomena","epiphenomenon","epiphenomna"},
"epiphora":{"epiphora","epiphoras"},
"epiphyllum":{"epiphyllum","epiphyllums"},
"epiphysis":{"epiphyses","epiphysis"},
"epiphyte":{"epiphyte","epiphytes"},
"epipremnum":{"epipremnum","epipremnums"},
"episcopacy":{"episcopacies","episcopacy"},
"episiotomy":{"episiotomies","episiotomy"},
"episode":{"episode","episodes"},
"episperm":{"episperm","episperms"},
"epistasis":{"epistases","epistasis"},
"epistaxis":{"epistaxes","epistaxis"},
"episternum":{"episterna","episternum"},
"epistle":{"epistle","epistles"},
"epistrophe":{"epistrophe","epistrophes"},
"epitaph":{"epitaph","epitaphs"},
"epitasis":{"epitases","epitasis"},
"epitaxy":{"epitaxies","epitaxy"},
"epithalamium":{"epithalamia","epithalamium","epithalamiums"},
"epithelioma":{"epithelioma","epitheliomas","epitheliomata"},
"epithelium":{"epithelia","epithelilia","epitheliliums","epithelium","epitheliums"},
"epithet":{"epithet","epithets"},
"epitome":{"epitome","epitomes"},
"epitomize":{"epitomize","epitomized","epitomizes","epitomizing"},
"epitrichium":{"epitrichium","epitrichiums"},
"epizoa":{"epizoa","epizoas"},
"epizoon":{"epizoa","epizoon","epizoons"},
"epoch":{"epoch","epoches"},
"epos":{"epos","eposes"},
"epoxy":{"epoxies","epoxy"},
"eprom":{"eprom","eproms"},
"eptesicus":{"eptesicus","eptesicuses"},
"epyllion":{"epyllilia","epyllion"},
"eq":{"eq","eqs"},
"equal":{"equal","equaled","equaling","equalled","equalling","equals"},
"equaliser":{"equaliser","equalisers"},
"equalitarian":{"equalitarian","equalitarians"},
"equalitarianism":{"equalitarianism","equalitarianisms"},
"equality":{"equalities","equality"},
"equalization":{"equalization","equalizations"},
"equalize":{"equalize","equalized","equalizes","equalizing"},
"equalizer":{"equalizer","equalizers"},
"equanil":{"equanil","equanils"},
"equanimity":{"equanimities","equanimity"},
"equate":{"equate","equated","equates","equating"},
"equating":{"equating","equatings"},
"equation":{"equation","equations"},
"equerry":{"equerries","equerry"},
"equestrian":{"equestrian","equestrians"},
"equetus":{"equetus","equetuses"},
"equid":{"equid","equids"},
"equidae":{"equidae","equidaes"},
"equilibrate":{"equilibrate","equilibrated","equilibrates","equilibrating"},
"equilibrium":{"equilibrium","equilibriums"},
"equilisation":{"equilisation","equilisations"},
"equine":{"equine","equines"},
"equinoctial":{"equinoctial","equinoctials"},
"equinox":{"equinox","equinoxes"},
"equip":{"equip","equipped","equipping","equips"},
"equipage":{"equipage","equipages"},
"equipoise":{"equipoise","equipoised","equipoises","equipoising"},
"equiponderate":{"equiponderate","equiponderated","equiponderating"},
"equipping":{"equipping","equippings"},
"equisetaceae":{"equisetaceae","equisetaceaes"},
"equisetales":{"equisetales","equisetaleses"},
"equisetatae":{"equisetatae","equisetataes"},
"equisetum":{"equiseta","equisetum","equisetums"},
"equitation":{"equitation","equitations"},
"equity":{"equities","equity"},
"equivalence":{"equivalence","equivalences"},
"equivalent":{"equivalent","equivalents"},
"equivocalness":{"equivocalness","equivocalnesses"},
"equivocate":{"equivocate","equivocated","equivocates","equivocating"},
"equivocation":{"equivocation","equivocations"},
"equus":{"equus","equuses"},
"er":{"er","ers"},
"era":{"era","eras"},
"eradiate":{"eradiate","eradiated","eradiating"},
"eradicate":{"eradicate","eradicated","eradicates","eradicating"},
"eradication":{"eradication","eradications"},
"eradicator":{"eradicator","eradicators"},
"eragrostis":{"eragrostis","eragrostises"},
"eranthis":{"eranthis","eranthises"},
"erase":{"erase","erased","erases","erasing"},
"eraser":{"eraser","erasers"},
"erasmus":{"erasmus","erasmuses"},
"erastianism":{"erastianism","erastianisms"},
"erasure":{"erasure","erasures"},
"erbium":{"erbium","erbiums"},
"erect":{"erect","erected","erecting","erects"},
"erecting":{"erecting","erectings"},
"erection":{"erection","erections"},
"erectness":{"erectness","erectnesses"},
"erector":{"erector","erectors"},
"eresh-kigal":{"eresh-kigal","eresh-kigals"},
"ereshkigal":{"ereshkigal","ereshkigals"},
"ereshkigel":{"ereshkigel","ereshkigels"},
"erethizon":{"erethizon","erethizons"},
"erethizontidae":{"erethizontidae","erethizontidaes"},
"eretmochelys":{"eretmochelys","eretmochelyses"},
"erg":{"areg","erg","ergs"},
"ergatocracy":{"ergatocracies","ergatocracy"},
"ergocalciferol":{"ergocalciferol","ergocalciferols"},
"ergonomics":{"ergonomics","ergonomicses"},
"ergot":{"ergot","ergots"},
"erianthus":{"erianthus","erianthuses"},
"erica":{"erica","ericas"},
"ericaceae":{"ericaceae","ericaceaes"},
"ericales":{"ericales","ericaleses"},
"erie":{"erie","eries"},
"erigeron":{"erigeron","erigerons"},
"erignathus":{"erignathus","erignathuses"},
"erinaceidae":{"erinaceidae","erinaceidaes"},
"erinaceus":{"erinaceus","erinaceuses"},
"eringo":{"eringo","eringos"},
"erinyes":{"erinyes","erinyeses"},
"eriobotrya":{"eriobotrya","eriobotryas"},
"eriocaulaceae":{"eriocaulaceae","eriocaulaceaes"},
"eriocaulon":{"eriocaulon","eriocaulons"},
"eriodictyon":{"eriodictyon","eriodictyons"},
"eriophorum":{"eriophorum","eriophorums"},
"eriophyllum":{"eriophyllum","eriophyllums"},
"eriosoma":{"eriosoma","eriosomas"},
"erithacus":{"erithacus","erithacuses"},
"erivan":{"erivan","erivans"},
"ermine":{"ermine","ermines"},
"ern":{"ern","erns"},
"erne":{"erne","ernes"},
"erode":{"erode","eroded","erodes","eroding"},
"eroding":{"eroding","erodings"},
"erodium":{"erodium","erodiums"},
"erolia":{"erolia","erolias"},
"erosion":{"erosion","erosions"},
"eroticism":{"eroticism","eroticisms"},
"eroticize":{"eroticize","eroticized","eroticizing"},
"erotism":{"erotism","erotisms"},
"err":{"err","erred","erring","errs"},
"errancy":{"errancies","errancy"},
"errand":{"errand","errands"},
"errantry":{"errantries","errantry"},
"erratum":{"errata","erratum"},
"erroneousness":{"erroneousness","erroneousnesses"},
"error":{"error","errors"},
"erse":{"erse","erses"},
"ert":{"ert","erts"},
"eruca":{"eruca","erucas"},
"eruct":{"eruct","eructed","eructing","eructs"},
"eructate":{"eructate","eructated","eructating"},
"eructation":{"eructation","eructations"},
"eruditeness":{"eruditeness","eruditenesses"},
"erudition":{"erudition","eruditions"},
"erupt":{"erupt","erupted","erupting","erupts"},
"eruption":{"eruption","eruptions"},
"eryngium":{"eryngium","eryngiums"},
"eryngo":{"eryngo","eryngos"},
"erysimum":{"erysimum","erysimums"},
"erysiphaceae":{"erysiphaceae","erysiphaceaes"},
"erysiphales":{"erysiphales","erysiphaleses"},
"erysiphe":{"erysiphe","erysiphes"},
"erythrina":{"erythrina","erythrinas"},
"erythrocebus":{"erythrocebus","erythrocebuses"},
"erythrocyte":{"erythrocyte","erythrocytes"},
"erythrocytolysin":{"erythrocytolysin","erythrocytolysins"},
"erythrolysin":{"erythrolysin","erythrolysins"},
"erythronium":{"erythronium","erythroniums"},
"erythroxylaceae":{"erythroxylaceae","erythroxylaceaes"},
"erythroxylon":{"erythroxylon","erythroxylons"},
"erythroxylum":{"erythroxylum","erythroxylums"},
"es":{"es","eses"},
"escalade":{"escalade","escaladed","escalading"},
"escalate":{"escalate","escalated","escalates","escalating"},
"escalation":{"escalation","escalations"},
"escalator":{"escalator","escalators"},
"escallop":{"escallop","escalloped","escalloping"},
"escapade":{"escapade","escapades"},
"escape":{"escape","escaped","escapes","escaping"},
"escapism":{"escapism","escapisms"},
"escapist":{"escapist","escapists"},
"escapologist":{"escapologist","escapologists"},
"escargot":{"escargot","escargots"},
"escarole":{"escarole","escaroles"},
"escarp":{"escarp","escarps"},
"escarpment":{"escarpment","escarpments"},
"eschalot":{"eschalot","eschalots"},
"escheat":{"escheat","escheated","escheating"},
"eschew":{"eschew","eschewed","eschewing","eschews"},
"eschrichtiidae":{"eschrichtiidae","eschrichtiidaes"},
"eschrichtius":{"eschrichtius","eschrichtiuses"},
"eschscholtzia":{"eschscholtzia","eschscholtzias"},
"escolar":{"escolar","escolars"},
"escort":{"escort","escorted","escorting","escorts"},
"escritoire":{"escritoire","escritoires"},
"escudo":{"escudo","escudos"},
"escutcheon":{"escutcheon","escutcheons"},
"ese":{"ese","eses"},
"esidrix":{"esidrix","esidrixes"},
"eskimo":{"eskimo","eskimos"},
"eskimo-aleut":{"eskimo-aleut","eskimo-aleuts"},
"esky":{"eskies","esky"},
"esm":{"esm","esms"},
"esocidae":{"esocidae","esocidaes"},
"esop":{"esop","esops"},
"esophagus":{"esophagi","esophagus","esophaguses","oesophagi"},
"esox":{"esox","esoxes"},
"esp":{"esp","esps"},
"espana":{"espana","espanas"},
"espanole":{"espanole","espanoles"},
"esparcet":{"esparcet","esparcets"},
"esparto":{"esparto","espartos","grass"},
"espial":{"espial","espials"},
"espousal":{"espousal","espousals"},
"espouse":{"espouse","espoused","espouses","espousing"},
"espresso":{"espresso","espressos"},
"espy":{"espied","espies","espy","espying"},
"esq":{"esq","esqs"},
"esquimau":{"esquimau","esquimaus"},
"esquire":{"esquire","esquired","esquires","esquiring"},
"esr":{"esr","esrs"},
"essay":{"essay","essayed","essaying","essays"},
"essayist":{"essayist","essayists"},
"essence":{"essence","essences"},
"essential":{"essential","essentials"},
"essentiality":{"essentialities","essentiality"},
"essentialize":{"essentialize","essentialized","essentializing"},
"essentialness":{"essentialness","essentialnesses"},
"essonite":{"essonite","essonites"},
"est":{"est","ests"},
"establish":{"establish","established","establishes","establishing"},
"establishment":{"establishment","establishments"},
"establishmentarian":{"establishmentarian","establishmentarians"},
"estaminet":{"estaminet","estaminets"},
"estancia":{"estancia","estancias"},
"estate":{"estate","estates"},
"esteem":{"esteem","esteemed","esteeming","esteems"},
"esterify":{"esterified","esterifies","esterify","esterifying"},
"esthete":{"esthete","esthetes"},
"esthetic":{"esthetic","esthetics"},
"esthetician":{"esthetician","estheticians"},
"esthetics":{"esthetics","estheticses"},
"esthonia":{"esthonia","esthonias"},
"esthonian":{"esthonian","esthonians"},
"estimate":{"estimate","estimated","estimates","estimating"},
"estimation":{"estimation","estimations"},
"estimator":{"estimator","estimators"},
"estivate":{"estivate","estivated","estivates","estivating"},
"estivation":{"estivation","estivations"},
"estonia":{"estonia","estonias"},
"estonian":{"estonian","estonians"},
"estop":{"estop","estopped","estopping","estops"},
"estragon":{"estragon","estragons"},
"estrange":{"estrange","estranged","estranges","estranging"},
"estrangement":{"estrangement","estrangements"},
"estrilda":{"estrilda","estrildas"},
"estrogen":{"estrogen","estrogens"},
"estrone":{"estrone","estrones"},
"estrus":{"estrus","estruses"},
"estuary":{"estuaries","estuary"},
"esurience":{"esurience","esuriences"},
"etamin":{"etamin","etamins"},
"etamine":{"etamine","etamines"},
"etch":{"etch","etched","etching"},
"etching":{"etching","etchings"},
"eternalize":{"eternalize","eternalized","eternalizes","eternalizing"},
"eternity":{"eternities","eternity"},
"eternize":{"eternize","eternized","eternizes","eternizing"},
"ethanamide":{"ethanamide","ethanamides"},
"ethanediol":{"ethanediol","ethanediols"},
"ethanol":{"ethanol","ethanols"},
"ethene":{"ethene","ethenes"},
"ether":{"ether","ethers"},
"etherealize":{"etherealize","etherealized","etherealizing"},
"etherify":{"etherified","etherifies","etherify","etherifying"},
"etherize":{"etherize","etherized","etherizing"},
"ethic":{"ethic","ethics"},
"ethics":{"ethics","ethicses"},
"ethiopia":{"ethiopia","ethiopias"},
"ethnography":{"ethnographies","ethnography"},
"ethnos":{"ethnos","ethnoses"},
"ethosuximide":{"ethosuximide","ethosuximides"},
"ethoxyethane":{"ethoxyethane","ethoxyethanes"},
"ethrane":{"ethrane","ethranes"},
"ethyl":{"ethyl","ethyls"},
"ethylate":{"ethylate","ethylated","ethylating"},
"ethylene":{"ethylene","ethylenes"},
"ethyne":{"ethyne","ethynes"},
"etiolate":{"etiolate","etiolated","etiolating"},
"etiologist":{"etiologist","etiologists"},
"etiology":{"etiologies","etiology"},
"etna":{"etna","etnas"},
"etodolac":{"etodolac","etodolacs"},
"etropus":{"etropus","etropuses"},
"etui":{"etui","etuis"},
"etymologize":{"etymologize","etymologized","etymologizing"},
"etymologizing":{"etymologizing","etymologizings"},
"etymology":{"etymologies","etymology"},
"etymon":{"etyma","etymon","etymons"},
"eu":{"eu","eus"},
"euarctos":{"euarctos","euarctoses"},
"euascomycetes":{"euascomycetes","euascomyceteses"},
"eubacteria":{"eubacteria","eubacterias"},
"eubacteriales":{"eubacteriales","eubacterialeses"},
"eubacterium":{"eubacterium","eubacteriums"},
"eubryales":{"eubryales","eubryaleses"},
"eucalypt":{"eucalypt","eucalypts"},
"eucalyptus":{"eucalypti","eucalyptus","eucalyptuses"},
"eucarya":{"eucarya","eucaryas"},
"eucaryote":{"eucaryote","eucaryotes"},
"eucharist":{"eucharist","eucharists"},
"euchre":{"euchre","euchred","euchres","euchring"},
"eucinostomus":{"eucinostomus","eucinostomuses"},
"eudaemon":{"eudaemon","eudaemons"},
"eudemon":{"eudemon","eudemons"},
"eudemonism":{"eudemonism","eudemonisms"},
"euderma":{"euderma","eudermas"},
"eudyptes":{"eudyptes","eudypteses"},
"eugenia":{"eugenia","eugenias"},
"euglena":{"euglena","euglenas"},
"euglenaceae":{"euglenaceae","euglenaceaes"},
"euglenid":{"euglenid","euglenids"},
"euglenoid":{"euglenoid","euglenoids"},
"euglenophyceae":{"euglenophyceae","euglenophyceaes"},
"euglenophyta":{"euglenophyta","euglenophytas"},
"euglenophyte":{"euglenophyte","euglenophytes"},
"eukaryote":{"eukaryote","eukaryotes"},
"eulachan":{"eulachan","eulachans"},
"eulachon":{"eulachon","eulachons"},
"eulogist":{"eulogist","eulogists"},
"eulogium":{"eulogia","eulogium","eulogiums"},
"eulogize":{"eulogize","eulogized","eulogizes","eulogizing"},
"eulogy":{"eulogies","eulogy"},
"eumeces":{"eumeces","eumeceses"},
"eumenes":{"eumenes","eumeneses"},
"eumenides":{"eumenides","eumenideses"},
"eumetopias":{"eumetopias","eumetopiases"},
"eumops":{"eumops","eumopses"},
"eumycetes":{"eumycetes","eumyceteses"},
"eumycota":{"eumycota","eumycotas"},
"eunectes":{"eunectes","eunecteses"},
"eunuch":{"eunuch","eunuches"},
"euonymus":{"euonymus","euonymuses"},
"eupatorium":{"eupatorium","eupatoriums"},
"eupatrid":{"eupatrid","eupatridae","eupatrids"},
"euphagus":{"euphagus","euphaguses"},
"euphausiacea":{"euphausiacea","euphausiaceas"},
"euphemize":{"euphemize","euphemized","euphemizing"},
"euphony":{"euphonies","euphony"},
"euphorbia":{"euphorbia","euphorbias"},
"euphorbiaceae":{"euphorbiaceae","euphorbiaceaes"},
"euphorbium":{"euphorbium","euphorbiums"},
"euphractus":{"euphractus","euphractuses"},
"euphrasy":{"euphrasies","euphrasy"},
"euphrates":{"euphrates","euphrateses"},
"euplectella":{"euplectella","euplectellas"},
"euproctis":{"euproctis","euproctises"},
"eureka":{"eureka","eurekas"},
"eurhythmics":{"eurhythmics","eurhythmicses"},
"euripus":{"euripi","euripus"},
"euro":{"euro","euros"},
"euronithopod":{"euronithopod","euronithopods"},
"euronithopoda":{"euronithopoda","euronithopodas"},
"europeanize":{"europeanize","europeanized","europeanizing"},
"europium":{"europium","europiums"},
"eurotiales":{"eurotiales","eurotialeses"},
"eurotium":{"eurotium","eurotiums"},
"euryale":{"euryale","euryales"},
"euryalida":{"euryalida","euryalidas"},
"eurylaimi":{"eurylaimi","eurylaimis"},
"eurylaimidae":{"eurylaimidae","eurylaimidaes"},
"eurypterida":{"eurypterida","eurypteridas"},
"eurythmics":{"eurythmics","eurythmicses"},
"eustoma":{"eustoma","eustomas"},
"eutamias":{"eutamias","eutamiases"},
"euterpe":{"euterpe","euterpes"},
"euthanasia":{"euthanasia","euthanasias"},
"eutheria":{"eutheria","eutherias"},
"eutherian":{"eutherian","eutherians"},
"euthynnus":{"euthynnus","euthynnuses"},
"ev":{"ev","evs"},
"evacuate":{"evacuate","evacuated","evacuates","evacuating"},
"evacuation":{"evacuation","evacuations"},
"evade":{"evade","evaded","evades","evading"},
"evaginate":{"evaginate","evaginated","evaginating"},
"evaluate":{"evaluate","evaluated","evaluates","evaluating"},
"evaluation":{"evaluation","evaluations"},
"evaluator":{"evaluator","evaluators"},
"evanesce":{"evanesce","evanesced","evanesces","evanescing"},
"evanescence":{"evanescence","evanescences"},
"evangel":{"evangel","evangels"},
"evangelical":{"evangelical","evangelicals"},
"evangelism":{"evangelism","evangelisms"},
"evangelist":{"evangelist","evangelists"},
"evangelize":{"evangelize","evangelized","evangelizing"},
"evaporate":{"evaporate","evaporated","evaporates","evaporating"},
"evaporation":{"evaporation","evaporations"},
"evaporometer":{"evaporometer","evaporometers"},
"evasion":{"evasion","evasions"},
"evasiveness":{"evasiveness","evasivenesses"},
"eve":{"eve","eves"},
"even":{"even","evened","evening","evens"},
"evenfall":{"evenfall","evenfalls"},
"evening":{"evening","evenings"},
"evening-snow":{"evening-snow","evening-snows"},
"eveningwear":{"eveningwear","eveningwears"},
"evenk":{"evenk","evenks"},
"evenki":{"evenki","evenkis"},
"evenness":{"evenness","evennesses"},
"evensong":{"evensong","evensongs"},
"event":{"event","events"},
"eventide":{"eventide","eventides"},
"eventuality":{"eventualities","eventuality"},
"eventuate":{"eventuate","eventuated","eventuating"},
"everest":{"everest","everests"},
"evergreen":{"evergreen","evergreens"},
"everlasting":{"everlasting","everlastings"},
"eversion":{"eversion","eversions"},
"evert":{"evert","everted","everting"},
"everting":{"everting","evertings"},
"everydayness":{"everydayness","everydaynesses"},
"evict":{"evict","evicted","evicting","evicts"},
"eviction":{"eviction","evictions"},
"evidence":{"evidence","evidenced","evidences","evidencing"},
"evil":{"evil","eviler","evilest","evils"},
"evildoer":{"evildoer","evildoers"},
"evildoing":{"evildoing","evildoings"},
"evilness":{"evilness","evilnesses"},
"evince":{"evince","evinced","evinces","evincing"},
"eviscerate":{"eviscerate","eviscerated","eviscerates","eviscerating"},
"evocation":{"evocation","evocations"},
"evoke":{"evoke","evoked","evokes","evoking"},
"evolution":{"evolution","evolutions"},
"evolutionist":{"evolutionist","evolutionists"},
"evolve":{"evolve","evolved","evolves","evolving"},
"ew":{"ew","ews"},
"ewe":{"ewe","ewes"},
"ewenki":{"ewenki","ewenkis"},
"ewer":{"ewer","ewers"},
"ex":{"ex","exes"},
"ex-husband":{"ex-husband","ex-husbands"},
"ex-serviceman":{"ex-serviceman","ex-servicemen"},
"exacerbate":{"exacerbate","exacerbated","exacerbates","exacerbating"},
"exacerbation":{"exacerbation","exacerbations"},
"exact":{"exact","exacted","exacting","exacts"},
"exacta":{"exacta","exactas"},
"exactitude":{"exactitude","exactitudes"},
"exactness":{"exactness","exactnesses"},
"exacum":{"exacum","exacums"},
"exaeretodon":{"exaeretodon","exaeretodons"},
"exaggerate":{"exaggerate","exaggerated","exaggerates","exaggerating"},
"exaggeration":{"exaggeration","exaggerations"},
"exaggerator":{"exaggerator","exaggerators"},
"exalt":{"exalt","exalted","exalting","exalts"},
"exaltation":{"exaltation","exaltations"},
"exam":{"exam","exams"},
"examen":{"examen","examens"},
"examination":{"examination","examinations"},
"examine":{"examine","examined","examines","examining"},
"examinee":{"examinee","examinees"},
"examiner":{"examiner","examiners"},
"example":{"example","examples"},
"exanthem":{"exanthem","exanthems"},
"exanthema":{"exanthema","exanthemas","exanthemata"},
"exarchate":{"exarchate","exarchates"},
"exarchy":{"exarchies","exarchy"},
"exasperate":{"exasperate","exasperated","exasperates","exasperating"},
"exasperation":{"exasperation","exasperations"},
"excavate":{"excavate","excavated","excavates","excavating"},
"excavation":{"excavation","excavations"},
"excavator":{"excavator","excavators"},
"exceed":{"exceed","exceeded","exceeding","exceeds"},
"excel":{"excel","excelled","excelling","excels"},
"excellence":{"excellence","excellences"},
"excellency":{"excellencies","excellency"},
"excelsior":{"excelsior","excelsiors"},
"except":{"except","excepted","excepting","excepts"},
"exception":{"exception","exceptions"},
"excerpt":{"excerpt","excerpted","excerpting","excerpts"},
"excess":{"excess","excesses"},
"excessiveness":{"excessiveness","excessivenesses"},
"exchange":{"exchange","exchanged","exchanges","exchanging"},
"exchangeability":{"exchangeabilities","exchangeability"},
"exchanger":{"exchanger","exchangers"},
"exchequer":{"exchequer","exchequers"},
"excide":{"excide","excided","exciding"},
"excise":{"excise","excised","excises","excising"},
"exciseman":{"exciseman","excisemen"},
"excision":{"excision","excisions"},
"excitability":{"excitabilities","excitability"},
"excitableness":{"excitableness","excitablenesses"},
"excitation":{"excitation","excitations"},
"excite":{"excite","excited","excites","exciting"},
"excitement":{"excitement","excitements"},
"exclaim":{"exclaim","exclaimed","exclaiming","exclaims"},
"exclaiming":{"exclaiming","exclaimings"},
"exclamation":{"exclamation","exclamations"},
"exclude":{"exclude","excluded","excludes","excluding"},
"exclusion":{"exclusion","exclusions"},
"exclusive":{"exclusive","exclusives"},
"exclusiveness":{"exclusiveness","exclusivenesses"},
"excogitate":{"excogitate","excogitated","excogitates","excogitating"},
"excogitation":{"excogitation","excogitations"},
"excommunicate":{"excommunicate","excommunicated","excommunicates","excommunicating"},
"excommunication":{"excommunication","excommunications"},
"excoriate":{"excoriate","excoriated","excoriates","excoriating"},
"excoriation":{"excoriation","excoriations"},
"excrement":{"excrement","excrements"},
"excrescence":{"excrescence","excrescences"},
"excrescency":{"excrescencies","excrescency"},
"excreta":{"excreta","excretas"},
"excrete":{"excrete","excreted","excretes","excreting"},
"excreting":{"excreting","excretings"},
"excretion":{"excretion","excretions"},
"excruciate":{"excruciate","excruciated","excruciates","excruciating"},
"excruciation":{"excruciation","excruciations"},
"exculpate":{"exculpate","exculpated","exculpates","exculpating"},
"excursion":{"excursion","excursions"},
"excursionist":{"excursionist","excursionists"},
"excursus":{"excursus","excursuses"},
"excuse":{"excuse","excused","excuses","excusing"},
"execrate":{"execrate","execrated","execrates","execrating"},
"execration":{"execration","execrations"},
"execute":{"execute","executed","executes","executing"},
"executing":{"executing","executings"},
"execution":{"execution","executions"},
"executioner":{"executioner","executioners"},
"executive":{"executive","executives"},
"executor":{"executor","executors"},
"executrix":{"executrices","executrix","executrixes"},
"exegesis":{"exegeses","exegesis"},
"exemplar":{"exemplar","exemplars"},
"exemplification":{"exemplification","exemplifications"},
"exemplify":{"exemplified","exemplifies","exemplify","exemplifying"},
"exemplum":{"exempla","exemplum"},
"exempt":{"exempt","exempted","exempting","exempts"},
"exemption":{"exemption","exemptions"},
"exenterate":{"exenterate","exenterated","exenterating"},
"exercise":{"exercise","exercised","exercises","exercising"},
"exerciser":{"exerciser","exercisers"},
"exercising":{"exercising","exercisings"},
"exercycle":{"exercycle","exercycles"},
"exert":{"exert","exerted","exerting","exerts"},
"exertion":{"exertion","exertions"},
"exfoliate":{"exfoliate","exfoliated","exfoliating"},
"exhalation":{"exhalation","exhalations"},
"exhale":{"exhale","exhaled","exhales","exhaling"},
"exhaust":{"exhaust","exhausted","exhausting","exhausts"},
"exhaustion":{"exhaustion","exhaustions"},
"exhibit":{"exhibit","exhibited","exhibiting","exhibits"},
"exhibition":{"exhibition","exhibitions"},
"exhibitioner":{"exhibitioner","exhibitioners"},
"exhibitionism":{"exhibitionism","exhibitionisms"},
"exhibitionist":{"exhibitionist","exhibitionists"},
"exhibitor":{"exhibitor","exhibitors"},
"exhilarate":{"exhilarate","exhilarated","exhilarates","exhilarating"},
"exhilaration":{"exhilaration","exhilarations"},
"exhort":{"exhort","exhorted","exhorting","exhorts"},
"exhortation":{"exhortation","exhortations"},
"exhumation":{"exhumation","exhumations"},
"exhume":{"exhume","exhumed","exhumes","exhuming"},
"exigence":{"exigence","exigences"},
"exigency":{"exigencies","exigency"},
"exiguity":{"exiguities","exiguity"},
"exile":{"exile","exiled","exiles","exiling"},
"exist":{"exist","existed","existing","exists"},
"existence":{"existence","existences"},
"existentialism":{"existentialism","existentialisms"},
"exit":{"exit","exited","exiting","exits"},
"exocarp":{"exocarp","exocarps"},
"exocoetidae":{"exocoetidae","exocoetidaes"},
"exocycloida":{"exocycloida","exocycloidas"},
"exodontia":{"exodontia","exodontias"},
"exodontics":{"exodontics","exodonticses"},
"exodus":{"exodus","exoduses"},
"exogamy":{"exogamies","exogamy"},
"exonerate":{"exonerate","exonerated","exonerates","exonerating"},
"exoneration":{"exoneration","exonerations"},
"exopterygota":{"exopterygota","exopterygotas"},
"exorbitance":{"exorbitance","exorbitances"},
"exorcise":{"exorcise","exorcised","exorcises","exorcising"},
"exorciser":{"exorciser","exorcisers"},
"exorcist":{"exorcist","exorcists"},
"exorcize":{"exorcize","exorcized","exorcizes","exorcizing"},
"exordium":{"exordia","exordium","exordiums"},
"exostosis":{"exostoses","exostosis"},
"exoticism":{"exoticism","exoticisms"},
"exoticness":{"exoticness","exoticnesses"},
"exotism":{"exotism","exotisms"},
"expand":{"expand","expanded","expanding","expands"},
"expander":{"expander","expanders"},
"expanse":{"expanse","expanses"},
"expansion":{"expansion","expansions"},
"expansiveness":{"expansiveness","expansivenesses"},
"expansivity":{"expansivities","expansivity"},
"expatiate":{"expatiate","expatiated","expatiates","expatiating"},
"expatriate":{"expatriate","expatriated","expatriates","expatriating"},
"expatriation":{"expatriation","expatriations"},
"expect":{"expect","expected","expecting","expects"},
"expectancy":{"expectancies","expectancy"},
"expectant":{"expectant","expectants"},
"expectation":{"expectation","expectations"},
"expectedness":{"expectedness","expectednesses"},
"expectorate":{"expectorate","expectorated","expectorates","expectorating"},
"expectoration":{"expectoration","expectorations"},
"expedience":{"expedience","expediences"},
"expediency":{"expediencies","expediency"},
"expedient":{"expedient","expedients"},
"expedite":{"expedite","expedited","expedites","expediting"},
"expedition":{"expedition","expeditions"},
"expeditiousness":{"expeditiousness","expeditiousnesses"},
"expel":{"expel","expelled","expelling","expels"},
"expelling":{"expelling","expellings"},
"expend":{"expend","expended","expending","expends"},
"expender":{"expender","expenders"},
"expending":{"expending","expendings"},
"expenditure":{"expenditure","expenditures"},
"expense":{"expense","expenses"},
"experience":{"experience","experienced","experiences","experiencing"},
"experiment":{"experiment","experimented","experimenting","experiments"},
"experimentalist":{"experimentalist","experimentalists"},
"experimentation":{"experimentation","experimentations"},
"experimenter":{"experimenter","experimenters"},
"expert":{"expert","experts"},
"expertise":{"expertise","expertises"},
"expertize":{"expertize","expertized","expertizing"},
"expertness":{"expertness","expertnesses"},
"expiate":{"expiate","expiated","expiates","expiating"},
"expiation":{"expiation","expiations"},
"expiration":{"expiration","expirations"},
"expire":{"expire","expired","expires","expiring"},
"expiry":{"expiries","expiry"},
"explain":{"explain","explained","explaining","explains"},
"explanandum":{"explananda","explanandum"},
"explanation":{"explanation","explanations"},
"explant":{"explant","explanted","explanting","explants"},
"expletive":{"expletive","expletives"},
"explicate":{"explicate","explicated","explicates","explicating"},
"explode":{"explode","exploded","explodes","exploding"},
"exploit":{"exploit","exploited","exploiting","exploits"},
"exploitation":{"exploitation","exploitations"},
"exploiter":{"exploiter","exploiters"},
"exploration":{"exploration","explorations"},
"explore":{"explore","explored","explores","exploring"},
"explorer":{"explorer","explorers"},
"explosion":{"explosion","explosions"},
"explosive":{"explosive","explosives"},
"expo":{"expo","expos"},
"exponent":{"exponent","exponents"},
"exponential":{"exponential","exponentials"},
"exponentiation":{"exponentiation","exponentiations"},
"export":{"export","exported","exporting","exports"},
"exportation":{"exportation","exportations"},
"exporter":{"exporter","exporters"},
"exporting":{"exporting","exportings"},
"expose":{"expose","exposed","exposes","exposing"},
"exposition":{"exposition","expositions"},
"expositor":{"expositor","expositors"},
"expostulate":{"expostulate","expostulated","expostulating"},
"expostulation":{"expostulation","expostulations"},
"exposure":{"exposure","exposures"},
"expound":{"expound","expounded","expounding","expounds"},
"expounding":{"expounding","expoundings"},
"express":{"express","expressed","expresses","expressing"},
"expressage":{"expressage","expressages"},
"expression":{"expression","expressions"},
"expressman":{"expressman","expressmen"},
"expressway":{"expressway","expressways"},
"expropriate":{"expropriate","expropriated","expropriates","expropriating"},
"expulsion":{"expulsion","expulsions"},
"expunction":{"expunction","expunctions"},
"expunge":{"expunge","expunged","expunges","expunging"},
"expunging":{"expunging","expungings"},
"expurgate":{"expurgate","expurgated","expurgates","expurgating"},
"expurgation":{"expurgation","expurgations"},
"exquisite":{"exquisite","exquisites"},
"exsanguinate":{"exsanguinate","exsanguinated","exsanguinating"},
"exscind":{"exscind","exscinded","exscinding"},
"exsert":{"exsert","exserted","exserting"},
"exsiccate":{"exsiccate","exsiccated","exsiccating"},
"extemporisation":{"extemporisation","extemporisations"},
"extemporization":{"extemporization","extemporizations"},
"extemporize":{"extemporize","extemporized","extemporizes","extemporizing"},
"extend":{"extend","extended","extending","extends"},
"extension":{"extension","extensions"},
"extensor":{"extensor","extensors"},
"extent":{"extent","extents"},
"extenuate":{"extenuate","extenuated","extenuates","extenuating"},
"extenuation":{"extenuation","extenuations"},
"exterior":{"exterior","exteriors"},
"exteriorisation":{"exteriorisation","exteriorisations"},
"exteriorization":{"exteriorization","exteriorizations"},
"exteriorize":{"exteriorize","exteriorized","exteriorizes","exteriorizing"},
"exterminate":{"exterminate","exterminated","exterminates","exterminating"},
"extermination":{"extermination","exterminations"},
"exterminator":{"exterminator","exterminators"},
"extern":{"extern","externs"},
"external":{"external","externals"},
"externalisation":{"externalisation","externalisations"},
"externality":{"externalities","externality"},
"externalization":{"externalization","externalizations"},
"externalize":{"externalize","externalized","externalizes","externalizing"},
"extinction":{"extinction","extinctions"},
"extinguish":{"extinguish","extinguished","extinguishes","extinguishing"},
"extinguisher":{"extinguisher","extinguishers"},
"extinguishing":{"extinguishing","extinguishings"},
"extirpate":{"extirpate","extirpated","extirpates","extirpating"},
"extirpation":{"extirpation","extirpations"},
"extol":{"extol","extolled","extolling","extols"},
"extoll":{"extoll","extolled","extolling","extolls"},
"extoller":{"extoller","extollers"},
"extort":{"extort","extorted","extorting","extorts"},
"extortion":{"extortion","extortions"},
"extortioner":{"extortioner","extortioners"},
"extortionist":{"extortionist","extortionists"},
"extra":{"extra","extras"},
"extract":{"extract","extracted","extracting","extracts"},
"extraction":{"extraction","extractions"},
"extractor":{"extractor","extractors"},
"extradite":{"extradite","extradited","extradites","extraditing"},
"extrados":{"extrados","extradoses"},
"extrapolate":{"extrapolate","extrapolated","extrapolates","extrapolating"},
"extrasystole":{"extrasystole","extrasystoles"},
"extraterrestrial":{"extraterrestrial","extraterrestrials"},
"extravagance":{"extravagance","extravagances"},
"extravaganza":{"extravaganza","extravaganzas"},
"extravagate":{"extravagate","extravagated","extravagating"},
"extravasate":{"extravasate","extravasated","extravasating"},
"extravert":{"extravert","extraverts"},
"extreme":{"extreme","extremer","extremes","extremest"},
"extremist":{"extremist","extremists"},
"extremity":{"extremities","extremity"},
"extremum":{"extremum","extremums"},
"extricate":{"extricate","extricated","extricates","extricating"},
"extrication":{"extrication","extrications"},
"extrovert":{"extrovert","extroverts"},
"extrude":{"extrude","extruded","extrudes","extruding"},
"extrusion":{"extrusion","extrusions"},
"exuberance":{"exuberance","exuberances"},
"exuberate":{"exuberate","exuberated","exuberating"},
"exudation":{"exudation","exudations"},
"exude":{"exude","exuded","exudes","exuding"},
"exult":{"exult","exulted","exulting","exults"},
"exultation":{"exultation","exultations"},
"exwife":{"exwife","exwives"},
"eye":{"eye","eyed","eyeing","eyes","eying"},
"eye-lotion":{"eye-lotion","eye-lotions"},
"eyeball":{"eyeball","eyeballed","eyeballing","eyeballs"},
"eyebath":{"eyebath","eyebaths"},
"eyebrow":{"eyebrow","eyebrows"},
"eyecup":{"eyecup","eyecups"},
"eyeful":{"eyeful","eyefuls"},
"eyeglass":{"eyeglass","eyeglasses"},
"eyeglasses":{"eyeglasses","eyeglasseses"},
"eyelash":{"eyelash","eyelashes"},
"eyelet":{"eyelet","eyelets"},
"eyelid":{"eyelid","eyelids"},
"eyepatch":{"eyepatch","eyepatches"},
"eyepiece":{"eyepiece","eyepieces"},
"eyeshade":{"eyeshade","eyeshades"},
"eyeshot":{"eyeshot","eyeshots"},
"eyesight":{"eyesight","eyesights"},
"eyesore":{"eyesore","eyesores"},
"eyespot":{"eyespot","eyespots"},
"eyestrain":{"eyestrain","eyestrains"},
"eyetooth":{"eyeteeth","eyetooth","eyetooths"},
"eyewash":{"eyewash","eyewashes"},
"eyra":{"eyra","eyras"},
"eyrie":{"eyrie","eyries"},
"eyrir":{"eyrir","eyrirs"},
"eyry":{"eyries","eyry"},
"ezo":{"ezo","ezos"},
"ezo-yama-hagi":{"ezo-yama-hagi","ezo-yama-hagis"},
"f":{"f","fs"},
"fabaceae":{"fabaceae","fabaceaes"},
"fabiana":{"fabiana","fabianas"},
"fable":{"fable","fabled","fables","fabling"},
"fabliau":{"fabliau","fabliaux"},
"fabric":{"fabric","fabrics"},
"fabricate":{"fabricate","fabricated","fabricates","fabricating"},
"fabrication":{"fabrication","fabrications"},
"fabricator":{"fabricator","fabricators"},
"facade":{"facade","facades"},
"face":{"face","faced","faces","facing"},
"face-cloth":{"face-cloth","face-cloths"},
"face-harden":{"face-harden","face-hardened","face-hardening"},
"face-lift":{"face-lift","face-lifted","face-lifting","face-lifts"},
"facecloth":{"facecloth","facecloths"},
"facet":{"facet","faceted","faceting","facets","facetted","facetting"},
"facia":{"facia","facias"},
"facial":{"facial","facials"},
"facilitate":{"facilitate","facilitated","facilitates","facilitating"},
"facility":{"facilities","facility"},
"facing":{"facing","facings"},
"facsimile":{"facsimile","facsimiled","facsimiles","facsimiling"},
"fact":{"fact","facts"},
"faction":{"faction","factions"},
"factor":{"factor","factored","factoring","factors"},
"factoring":{"factoring","factorings"},
"factorisation":{"factorisation","factorisations"},
"factorization":{"factorization","factorizations"},
"factory":{"factories","factory"},
"factuality":{"factualities","factuality"},
"factualness":{"factualness","factualnesses"},
"facula":{"facula","faculae"},
"faculty":{"faculties","faculty"},
"fad":{"fad","fads"},
"fade":{"fade","faded","fades","fading"},
"fadeout":{"fadeout","fadeouts"},
"fading":{"fading","fadings"},
"fado":{"fado","fados"},
"faeces":{"faeces","faeceses"},
"faerie":{"faerie","faeries"},
"faeroes":{"faeroes","faeroeses"},
"faeroese":{"faeroese","faeroeses"},
"faery":{"faeries","faery"},
"fag":{"fag","fagged","fagging","fags"},
"fagaceae":{"fagaceae","fagaceaes"},
"fagales":{"fagales","fagaleses"},
"faggot":{"faggot","faggoted","faggoting","faggots"},
"fagopyrum":{"fagopyrum","fagopyrums"},
"fagot":{"fagot","fagoted","fagoting","fagots"},
"fagus":{"fagus","faguses"},
"fail":{"fail","failed","failing","fails"},
"failing":{"failing","failings"},
"failure":{"failure","failures"},
"faineance":{"faineance","faineances"},
"faineant":{"faineant","faineants"},
"faint":{"faint","fainted","fainter","faintest","fainting","faints"},
"faintness":{"faintness","faintnesses"},
"fair":{"fair","fairer","fairest","fairs"},
"fair-maids-of-france":{"fair-maids-of-france","fair-maids-of-frances"},
"fair-mindedness":{"fair-mindedness","fair-mindednesses"},
"fair-trade":{"fair-trade","fair-traded","fair-trading"},
"fairness":{"fairness","fairnesses"},
"fairy":{"fairies","fairy"},
"fairy-slipper":{"fairy-slipper","fairy-slippers"},
"fairyland":{"fairyland","fairylands"},
"fairytale":{"fairytale","fairytales"},
"faith":{"faith","faiths"},
"faithful":{"faithful","faithfuls"},
"faithfulness":{"faithfulness","faithfulnesses"},
"faithlessness":{"faithlessness","faithlessnesses"},
"fake":{"fake","faked","fakes","faking"},
"fakeer":{"fakeer","fakeers"},
"faker":{"faker","fakers"},
"fakery":{"fakeries","fakery"},
"fakir":{"fakir","fakirs"},
"falafel":{"falafel","falafels"},
"falcatifolium":{"falcatifolium","falcatifoliums"},
"falco":{"falco","falcos"},
"falcon":{"falcon","falcons"},
"falcon-gentil":{"falcon-gentil","falcon-gentils"},
"falcon-gentle":{"falcon-gentle","falcon-gentles"},
"falconer":{"falconer","falconers"},
"falconidae":{"falconidae","falconidaes"},
"falconiformes":{"falconiformes","falconiformeses"},
"falderal":{"falderal","falderals"},
"fall":{"fall","fallen","falling","falls","fell"},
"fallacy":{"fallacies","fallacy"},
"fallal":{"fallal","fallals"},
"fallback":{"fallback","fallbacks"},
"fallfish":{"fallfish","fallfishes"},
"falling":{"falling","fallings"},
"falling-out":{"falling-out","falling-outs","fallings-out"},
"falloff":{"falloff","falloffs"},
"fallout":{"fallout","fallouts"},
"falls":{"falls","fallses"},
"false":{"false","falser","falsest"},
"falsehood":{"falsehood","falsehoods"},
"falseness":{"falseness","falsenesses"},
"falsetto":{"falsetto","falsettos"},
"falsification":{"falsification","falsifications"},
"falsify":{"falsified","falsifies","falsify","falsifying"},
"falsifying":{"falsifying","falsifyings"},
"falsity":{"falsities","falsity"},
"falstaff":{"falstaff","falstaffs"},
"falter":{"falter","faltered","faltering","falters"},
"faltering":{"faltering","falterings"},
"fame":{"fame","famed","fames","faming"},
"familiar":{"familiar","familiars"},
"familiarity":{"familiarities","familiarity"},
"familiarize":{"familiarize","familiarized","familiarizes","familiarizing"},
"family":{"families","family"},
"famine":{"famine","famines"},
"famish":{"famish","famished","famishing"},
"famishment":{"famishment","famishments"},
"famotidine":{"famotidine","famotidines"},
"famulus":{"famuli","famulus"},
"fan":{"fan","fanned","fanning","fans"},
"fanaloka":{"fanaloka","fanalokas"},
"fanatic":{"fanatic","fanatics"},
"fanaticism":{"fanaticism","fanaticisms"},
"fanaticize":{"fanaticize","fanaticized","fanaticizing"},
"fancier":{"fancier","fanciers"},
"fancify":{"fancified","fancify","fancifying"},
"fancy":{"fancied","fancier","fancies","fanciest","fancy","fancying"},
"fancywork":{"fancywork","fancyworks"},
"fandango":{"fandango","fandangos"},
"fane":{"fane","fanes"},
"fanfare":{"fanfare","fanfares"},
"fang":{"fang","fangs"},
"fanlight":{"fanlight","fanlights"},
"fanny":{"fannies","fanny"},
"fantan":{"fantan","fantans"},
"fantasia":{"fantasia","fantasias"},
"fantasize":{"fantasize","fantasized","fantasizing"},
"fantast":{"fantast","fantasts"},
"fantastical":{"fantastical","fantasticals"},
"fantasticate":{"fantasticate","fantasticated","fantasticating"},
"fantasy":{"fantasies","fantasy"},
"fanti":{"fanti","fantis"},
"fanweed":{"fanweed","fanweeds"},
"fanwort":{"fanwort","fanworts"},
"fao":{"fao","faos"},
"faqir":{"faqir","faqirs"},
"faquir":{"faquir","faquirs"},
"far":{"far","farther","farthest","further","furthest"},
"farad":{"farad","farads"},
"faraday":{"faraday","faradays"},
"farawayness":{"farawayness","farawaynesses"},
"farce":{"farce","farced","farces","farcing"},
"farcy":{"farcies","farcy"},
"fard":{"fard","farded","farding"},
"fare":{"fare","fared","fares","faring"},
"farewell":{"farewell","farewells"},
"farkleberry":{"farkleberries","farkleberry"},
"farm":{"farm","farmed","farming","farms"},
"farmer":{"farmer","farmers"},
"farmer-general":{"farmer-general","farmers-general"},
"farmhand":{"farmhand","farmhands"},
"farmhouse":{"farmhouse","farmhouses"},
"farming":{"farming","farmings"},
"farmland":{"farmland","farmlands"},
"farmplace":{"farmplace","farmplaces"},
"farmstead":{"farmstead","farmsteads"},
"farmyard":{"farmyard","farmyards"},
"farness":{"farness","farnesses"},
"faroes":{"faroes","faroeses"},
"faroese":{"faroese","faroeses"},
"farrago":{"farrago","farragoes"},
"farrier":{"farrier","farriers"},
"farriery":{"farrieries","farriery"},
"farrow":{"farrow","farrowed","farrowing","farrows"},
"farrowing":{"farrowing","farrowings"},
"farsi":{"farsi","farsis"},
"farsightedness":{"farsightedness","farsightednesses"},
"fart":{"fart","farted","farting","farts"},
"farther":{"far","farther","farthest","further","furthest"},
"farthing":{"farthing","farthings"},
"farting":{"farting","fartings"},
"fascia":{"fascia","fasciae","fascias"},
"fascicle":{"fascicle","fascicles"},
"fascicule":{"fascicule","fascicules"},
"fasciculus":{"fasciculi","fasciculus"},
"fascinate":{"fascinate","fascinated","fascinates","fascinating"},
"fascination":{"fascination","fascinations"},
"fasciola":{"fasciola","fasciolas"},
"fasciolidae":{"fasciolidae","fasciolidaes"},
"fascista":{"fascista","fascisti"},
"fashion":{"fashion","fashioned","fashioning","fashions"},
"fashioning":{"fashioning","fashionings"},
"fashionmonger":{"fashionmonger","fashionmongers"},
"fasiculus":{"fasiculus","fasiculuses"},
"fast":{"fast","faster","fastest","fasts"},
"fast-talk":{"fast-talk","fast-talked","fast-talking"},
"fastball":{"fastball","fastballs"},
"fasten":{"fasten","fastened","fastening","fastens"},
"fastener":{"fastener","fasteners"},
"fastening":{"fastening","fastenings"},
"fastigium":{"fastigia","fastigium","fastigiums"},
"fasting":{"fasting","fastings"},
"fastness":{"fastness","fastnesses"},
"fat":{"fat","fats","fatted","fatter","fattest","fatting"},
"fatalist":{"fatalist","fatalists"},
"fatality":{"fatalities","fatality"},
"fate":{"fate","fated","fates","fating"},
"fates":{"fates","fateses"},
"fathead":{"fathead","fatheads"},
"father":{"father","fathered","fathering","fathers"},
"father-god":{"father-god","father-gods"},
"father-in-law":{"father-in-law","fathers-in-law"},
"fatherhood":{"fatherhood","fatherhoods"},
"fatherland":{"fatherland","fatherlands"},
"fatherliness":{"fatherliness","fatherlinesses"},
"fathom":{"fathom","fathomed","fathoming","fathoms"},
"fathometer":{"fathometer","fathometers"},
"fatigue":{"fatigue","fatigued","fatigues","fatiguing"},
"fatism":{"fatism","fatisms"},
"fatness":{"fatness","fatnesses"},
"fatso":{"fatso","fatsoes","fatsos"},
"fatten":{"fatten","fattened","fattening","fattens"},
"fattiness":{"fattiness","fattinesses"},
"fattism":{"fattism","fattisms"},
"fatty":{"fattier","fatties","fattiest","fatty"},
"fatuity":{"fatuities","fatuity"},
"fatuousness":{"fatuousness","fatuousnesses"},
"faucet":{"faucet","faucets"},
"faulkner":{"faulkner","faulkners"},
"fault":{"fault","faulted","faulting","faults"},
"faultfinder":{"faultfinder","faultfinders"},
"faultfinding":{"faultfinding","faultfindings"},
"faultiness":{"faultiness","faultinesses"},
"faulty":{"faultier","faultiest","faulty"},
"fauna":{"fauna","faunae","faunas"},
"faust":{"faust","fausts"},
"faustus":{"faustus","faustuses"},
"fauteuil":{"fauteuil","fauteuils"},
"favela":{"favela","favelas"},
"favor":{"favor","favored","favoring","favors"},
"favorableness":{"favorableness","favorablenesses"},
"favorite":{"favorite","favorites"},
"favoritism":{"favoritism","favoritisms"},
"favour":{"favour","favoured","favouring","favours"},
"favourableness":{"favourableness","favourablenesses"},
"favourite":{"favourite","favourites"},
"favouritism":{"favouritism","favouritisms"},
"favus":{"favus","favuses"},
"fawn":{"fawn","fawned","fawning","fawns"},
"fawner":{"fawner","fawners"},
"fax":{"fax","faxes"},
"faze":{"faze","fazed","fazes","fazing"},
"fbi":{"fbi","fbis"},
"fdic":{"fdic","fdics"},
"fdr":{"fdr","fdrs"},
"fe":{"fe","fes"},
"fealty":{"fealties","fealty"},
"fear":{"fear","feared","fearing","fears"},
"fearfulness":{"fearfulness","fearfulnesses"},
"fearlessness":{"fearlessness","fearlessnesses"},
"feasibility":{"feasibilities","feasibility"},
"feasibleness":{"feasibleness","feasiblenesses"},
"feast":{"feast","feasted","feasting","feasts"},
"feasting":{"feasting","feastings"},
"feat":{"feat","feats"},
"feather":{"feather","feathered","feathering","feathers"},
"featherbed":{"featherbed","featherbeds"},
"featheredge":{"featheredge","featheredged","featheredging"},
"featheriness":{"featheriness","featherinesses"},
"feathering":{"feathering","featherings"},
"featherstitch":{"featherstitch","featherstitched","featherstitching"},
"feathertop":{"feathertop","feathertops"},
"feature":{"feature","featured","features","featuring"},
"feb":{"feb","febs"},
"febricity":{"febricities","febricity"},
"febrifuge":{"febrifuge","febrifuges"},
"february":{"februaries","february"},
"feces":{"feces","feceses"},
"fecula":{"fecula","feculae"},
"fecundate":{"fecundate","fecundated","fecundating"},
"fecundation":{"fecundation","fecundations"},
"fecundity":{"fecundities","fecundity"},
"fed":{"fed","feds"},
"fedayee":{"fedayee","fedayeen"},
"federacy":{"federacies","federacy"},
"federal":{"federal","federals"},
"federalisation":{"federalisation","federalisations"},
"federalist":{"federalist","federalists"},
"federalization":{"federalization","federalizations"},
"federalize":{"federalize","federalized","federalizes","federalizing"},
"federate":{"federate","federated","federates","federating"},
"federation":{"federation","federations"},
"federita":{"federita","federitas"},
"fedora":{"fedora","fedoras"},
"fee":{"fee","feed","feeing","fees"},
"feeble":{"feeble","feebler","feeblest"},
"feebleness":{"feebleness","feeblenesses"},
"feed":{"fed","feed","feeding","feeds"},
"feedbag":{"feedbag","feedbags"},
"feeder":{"feeder","feeders"},
"feeding":{"feeding","feedings"},
"feel":{"feel","feeling","feels","felt"},
"feeler":{"feeler","feelers"},
"feeling":{"feeling","feelings"},
"feign":{"feign","feigned","feigning","feigns"},
"feigning":{"feigning","feignings"},
"feijoa":{"feijoa","feijoas"},
"feint":{"feint","feinted","feinting"},
"feisty":{"feistier","feistiest","feisty"},
"felafel":{"felafel","felafels"},
"feldene":{"feldene","feldenes"},
"feldspar":{"feldspar","feldspars"},
"felicia":{"felicia","felicias"},
"felicitate":{"felicitate","felicitated","felicitates","felicitating"},
"felicitation":{"felicitation","felicitations"},
"felicitousness":{"felicitousness","felicitousnesses"},
"felicity":{"felicities","felicity"},
"felid":{"felid","felids"},
"felidae":{"felidae","felidaes"},
"feline":{"feline","felines"},
"felis":{"felis","felises"},
"fell":{"fell","felled","felling","fells"},
"fella":{"fella","fellas"},
"fellah":{"fellah","fellaheen","fellahin","fellahs"},
"fellatio":{"fellatio","fellatios"},
"fellation":{"fellation","fellations"},
"felloe":{"felloe","felloes"},
"fellow":{"fellow","fellows"},
"fellowman":{"fellowman","fellowmen"},
"fellowship":{"fellowship","fellowships"},
"felly":{"fellies","felly"},
"felo-de-se":{"felo-de-se","felo-de-ses","felones-de-se"},
"felon":{"felon","felons"},
"felonry":{"felonries","felonry"},
"felony":{"felonies","felony"},
"felo_de_se":{"felones_de_se","felos_de_se","felo_de_se"},
"felspar":{"felspar","felspars"},
"felt":{"felt","felted","felting","felts"},
"felucca":{"felucca","feluccas"},
"felwort":{"felwort","felworts"},
"female":{"female","females"},
"femaleness":{"femaleness","femalenesses"},
"feminineness":{"feminineness","femininenesses"},
"feminism":{"feminism","feminisms"},
"feminist":{"feminist","feminists"},
"feminize":{"feminize","feminized","feminizing"},
"femoris":{"femoris","femorises"},
"femtometer":{"femtometer","femtometers"},
"femtometre":{"femtometre","femtometres"},
"femur":{"femora","femur","femurs"},
"fen":{"fen","fens"},
"fence":{"fence","fenced","fences","fencing"},
"fencer":{"fencer","fencers"},
"fencing":{"fencing","fencings"},
"fend":{"fend","fended","fending"},
"fender":{"fender","fenders"},
"fenestella":{"fenestella","fenestellas"},
"fenestra":{"fenestra","fenestrae"},
"fengtien":{"fengtien","fengtiens"},
"fennel":{"fennel","fennels"},
"fennic":{"fennic","fennics"},
"fenny":{"fennier","fenniest","fenny"},
"fenugreek":{"fenugreek","fenugreeks"},
"fenusa":{"fenusa","fenusas"},
"feoff":{"feoff","feoffed","feoffing","feoffs"},
"fer-de-lance":{"fer-de-lance","fer-de-lances"},
"feretory":{"feretories","feretory"},
"feria":{"feria","feriae","ferias"},
"ferity":{"ferities","ferity"},
"fermat":{"fermat","fermats"},
"fermata":{"fermata","fermatas","fermate"},
"ferment":{"ferment","fermented","fermenting","ferments"},
"fermentation":{"fermentation","fermentations"},
"fermenting":{"fermenting","fermentings"},
"fermentologist":{"fermentologist","fermentologists"},
"fermi":{"fermi","fermis"},
"fermium":{"fermium","fermiums"},
"fern":{"fern","ferns"},
"fernery":{"ferneries","fernery"},
"ferocactus":{"ferocactus","ferocactuses"},
"ferociousness":{"ferociousness","ferociousnesses"},
"ferocity":{"ferocities","ferocity"},
"ferret":{"ferret","ferreted","ferreting","ferrets"},
"ferroconcrete":{"ferroconcrete","ferroconcretes"},
"ferrule":{"ferrule","ferruled","ferrules","ferruling"},
"ferry":{"ferried","ferries","ferry","ferrying"},
"ferryboat":{"ferryboat","ferryboats"},
"ferrying":{"ferrying","ferryings"},
"ferryman":{"ferryman","ferrymen"},
"fertilisation":{"fertilisation","fertilisations"},
"fertility":{"fertilities","fertility"},
"fertilization":{"fertilization","fertilizations"},
"fertilize":{"fertilize","fertilized","fertilizes","fertilizing"},
"ferula":{"ferula","ferulae","ferulas"},
"ferule":{"ferule","feruled","feruling"},
"fervency":{"fervencies","fervency"},
"fervidness":{"fervidness","fervidnesses"},
"fervor":{"fervor","fervors"},
"fervour":{"fervour","fervours"},
"fescue":{"fescue","fescues"},
"fess":{"fess","fesses"},
"fesse":{"fesse","fesses"},
"fester":{"fester","festered","festering","festers"},
"festering":{"festering","festerings"},
"festinate":{"festinate","festinated","festinating"},
"festival":{"festival","festivals"},
"festivity":{"festivities","festivity"},
"festoon":{"festoon","festooned","festooning","festoons"},
"festschrift":{"festschrift","festschriften","festschrifts"},
"festuca":{"festuca","festucas"},
"fetch":{"fetch","fetched","fetches","fetching"},
"fete":{"fete","feted","fetes","feting"},
"feterita":{"feterita","feteritas"},
"fetial":{"fetial","fetiales"},
"fetich":{"fetich","fetiches"},
"fetichism":{"fetichism","fetichisms"},
"feticide":{"feticide","feticides"},
"fetish":{"fetish","fetishes"},
"fetishism":{"fetishism","fetishisms"},
"fetishize":{"fetishize","fetishized","fetishizing"},
"fetlock":{"fetlock","fetlocks"},
"fetor":{"fetor","fetors"},
"fetter":{"fetter","fettered","fettering","fetters"},
"fetterbush":{"fetterbush","fetterbushes"},
"fettuccine":{"fettuccine","fettuccines"},
"fettuccini":{"fettuccini","fettuccinis"},
"fetus":{"fetus","fetuses"},
"feud":{"feud","feuded","feuding","feuds"},
"feudalism":{"feudalism","feudalisms"},
"feudalist":{"feudalist","feudalists"},
"feudality":{"feudalities","feudality"},
"feudalize":{"feudalize","feudalized","feudalizing"},
"feudatory":{"feudatories","feudatory"},
"feuilleton":{"feuilleton","feuilletons"},
"fever":{"fever","fevered","fevering","fevers"},
"feverfew":{"feverfew","feverfews"},
"feverishness":{"feverishness","feverishnesses"},
"feverroot":{"feverroot","feverroots"},
"few":{"few","fewer","fewest"},
"fez":{"fez","fezs","fezzes"},
"fha":{"fha","fhas"},
"fhlmc":{"fhlmc","fhlmcs"},
"fiance":{"fiance","fiances"},
"fiancee":{"fiancee","fiancees"},
"fiasco":{"fiasco","fiascoes","fiascos"},
"fiat":{"fiat","fiats"},
"fib":{"fib","fibbed","fibbing","fibs"},
"fibber":{"fibber","fibbers"},
"fibbing":{"fibbing","fibbings"},
"fiber":{"fiber","fibers"},
"fiberboard":{"fiberboard","fiberboards"},
"fiberglass":{"fiberglass","fiberglasses"},
"fibre":{"fibre","fibres"},
"fibreboard":{"fibreboard","fibreboards"},
"fibreglass":{"fibreglass","fibreglasses"},
"fibril":{"fibril","fibrils"},
"fibrilla":{"fibrilla","fibrillae"},
"fibrinase":{"fibrinase","fibrinases"},
"fibrinolysin":{"fibrinolysin","fibrinolysins"},
"fibrinolysis":{"fibrinolyses","fibrinolysis"},
"fibroadenoma":{"fibroadenoma","fibroadenomas","fibroadenomata"},
"fibroma":{"fibroma","fibromas","fibromata"},
"fibula":{"fibula","fibulae","fibulas"},
"fickleness":{"fickleness","ficklenesses"},
"fico":{"fico","ficoes"},
"fiction":{"fiction","fictions"},
"fictionalisation":{"fictionalisation","fictionalisations"},
"fictionalization":{"fictionalization","fictionalizations"},
"fictionalize":{"fictionalize","fictionalized","fictionalizes","fictionalizing"},
"ficus":{"ficus","ficuses"},
"fiddle":{"fiddle","fiddled","fiddles","fiddling"},
"fiddle-faddle":{"fiddle-faddle","fiddle-faddled","fiddle-faddles","fiddle-faddling"},
"fiddlehead":{"fiddlehead","fiddleheads"},
"fiddleneck":{"fiddleneck","fiddlenecks"},
"fiddler":{"fiddler","fiddlers"},
"fiddlestick":{"fiddlestick","fiddlesticks"},
"fiddly":{"fiddlier","fiddliest","fiddly"},
"fideicommissary":{"fideicommissaries","fideicommissary"},
"fideicommissum":{"fideicommissa","fideicommissum"},
"fidelity":{"fedelities","fidelities","fidelity"},
"fidget":{"fidget","fidgeted","fidgeting","fidgets"},
"fidgetiness":{"fidgetiness","fidgetinesses"},
"fiduciary":{"fiduciaries","fiduciary"},
"fief":{"fief","fiefs","fieves"},
"field":{"field","fielded","fielding","fields"},
"field-strip":{"field-strip","field-stripped","field-stripping","field-stript"},
"field-test":{"field-test","field-tested","field-testing"},
"fielder":{"fielder","fielders"},
"fieldfare":{"fieldfare","fieldfares"},
"fieldhand":{"fieldhand","fieldhands"},
"fieldmouse":{"fieldmice","fieldmouse"},
"fieldsman":{"fieldsman","fieldsmen"},
"fiend":{"fiend","fiends"},
"fierce":{"fierce","fiercer","fiercest"},
"fierceness":{"fierceness","fiercenesses"},
"fieriness":{"fieriness","fierinesses"},
"fiery":{"fierier","fieriest","fiery"},
"fiesta":{"fiesta","fiestas"},
"fife":{"fife","fifed","fifes","fifing"},
"fifer":{"fifer","fifers"},
"fifteen":{"fifteen","fifteens"},
"fifteenth":{"fifteenth","fifteenths"},
"fifth":{"fifth","fifths"},
"fifties":{"fifties","fiftieses"},
"fifty":{"fifties","fifty"},
"fig":{"fig","figged","figging","figs"},
"fig.":{"fig.","figs."},
"figeater":{"figeater","figeaters"},
"fight":{"fight","fighting","fights","fought"},
"fighter":{"fighter","fighters"},
"fighting":{"fighting","fightings"},
"figure":{"figure","figured","figures","figuring"},
"figurehead":{"figurehead","figureheads"},
"figurer":{"figurer","figurers"},
"figurine":{"figurine","figurines"},
"figuring":{"figuring","figurings"},
"fijis":{"fijis","fijises"},
"fil":{"fil","fils"},
"filago":{"filago","filagos"},
"filagree":{"filagree","filagreed","filagreeing","filagrees"},
"filament":{"filament","filaments"},
"filaree":{"filaree","filarees"},
"filaria":{"filaria","filariae","filarias"},
"filariidae":{"filariidae","filariidaes"},
"filbert":{"filbert","filberts"},
"filch":{"filch","filched","filches","filching"},
"file":{"file","filed","files","filing"},
"filefish":{"filefish","filefishes"},
"filer":{"filer","filers"},
"filet":{"filet","filets"},
"filiation":{"filiation","filiations"},
"filibuster":{"filibuster","filibustered","filibustering","filibusters"},
"filibusterer":{"filibusterer","filibusterers"},
"filicales":{"filicales","filicaleses"},
"filicinae":{"filicinae","filicinaes"},
"filicopsida":{"filicopsida","filicopsidas"},
"filigree":{"filigree","filigreed","filigreeing","filigrees"},
"filing":{"filing","filings"},
"filipino":{"filipino","filipinos"},
"fill":{"fill","filled","filling","fills"},
"fill-in":{"fill-in","fill-ins"},
"fillagree":{"fillagree","fillagrees"},
"fille":{"fille","filles"},
"filler":{"filler","fillers"},
"fillet":{"fillet","filleted","filleting","fillets"},
"filling":{"filling","fillings"},
"fillip":{"fillip","filliped","filliping","fillips"},
"fillmore":{"fillmore","fillmores"},
"filly":{"fillies","filly"},
"fill_up":{"filled_up","fill_up"},
"film":{"film","filmed","filming","films"},
"filming":{"filming","filmings"},
"filmy":{"filmier","filmiest","filmy"},
"filter":{"filter","filtered","filtering","filters"},
"filth":{"filth","filths"},
"filthiness":{"filthiness","filthinesses"},
"filthy":{"filthier","filthiest","filthy"},
"filtrate":{"filtrate","filtrated","filtrates","filtrating"},
"filum":{"fila","filum","filums"},
"fimbria":{"fimbria","fimbriae"},
"fin":{"fin","finned","finning","fins"},
"finagle":{"finagle","finagled","finagles","finagling"},
"final":{"final","finals"},
"finale":{"finale","finales"},
"finalisation":{"finalisation","finalisations"},
"finality":{"finalities","finality"},
"finalization":{"finalization","finalizations"},
"finalize":{"finalize","finalized","finalizes","finalizing"},
"finance":{"finance","financed","finances","financing"},
"finances":{"finances","financeses"},
"financier":{"financier","financiers"},
"financing":{"financing","financings"},
"finback":{"finback","finbacks"},
"find":{"find","finding","finds","found"},
"finder":{"finder","finders"},
"finding":{"finding","findings"},
"fine":{"fine","fined","finer","fines","finest","fining"},
"fine-draw":{"fine-draw","fine-drawing","fine-drawn","fine-draws","fine-drew"},
"fine-tune":{"fine-tune","fine-tuned","fine-tunes","fine-tuning"},
"fineness":{"fineness","finenesses"},
"finery":{"fineries","finery"},
"finesse":{"finesse","finessed","finesses","finessing"},
"finfoot":{"finfoot","finfoots"},
"finger":{"finger","fingered","fingering","fingers"},
"fingerboard":{"fingerboard","fingerboards"},
"fingerbreadth":{"fingerbreadth","fingerbreadths"},
"fingerflower":{"fingerflower","fingerflowers"},
"fingermark":{"fingermark","fingermarks"},
"fingernail":{"fingernail","fingernails"},
"fingerpost":{"fingerpost","fingerposts"},
"fingerprint":{"fingerprint","fingerprinted","fingerprinting","fingerprints"},
"fingerroot":{"fingerroot","fingerroots"},
"fingerstall":{"fingerstall","fingerstalls"},
"fingertip":{"fingertip","fingertips"},
"fingo":{"fingo","fingos"},
"finicky":{"finickier","finickiest","finicky"},
"fining":{"fining","finings"},
"finis":{"finis","finises"},
"finish":{"finish","finished","finishes","finishing"},
"finisher":{"finisher","finishers"},
"finishing":{"finishing","finishings"},
"finiteness":{"finiteness","finitenesses"},
"finitude":{"finitude","finitudes"},
"fink":{"fink","finks"},
"finland":{"finland","finlands"},
"finnan":{"finnan","finnans"},
"finnic":{"finnic","finnics"},
"finnish":{"finnish","finnishes"},
"finno-ugrian":{"finno-ugrian","finno-ugrians"},
"finno-ugric":{"finno-ugric","finno-ugrics"},
"finny":{"finnier","finniest","finny"},
"finocchio":{"finocchio","finocchios"},
"finochio":{"finochio","finochios"},
"fins":{"fins","finses"},
"fiord":{"fiord","fiords"},
"fioritura":{"fioritura","fioriture"},
"fir":{"fir","firs"},
"fire":{"fire","fired","fires","firing"},
"fire-cure":{"fire-cure","fire-cured","fire-curing"},
"fire-eater":{"fire-eater","fire-eaters"},
"fire-on-the-mountain":{"fire-on-the-mountain","fire-on-the-mountains"},
"fire-raising":{"fire-raising","fire-raisings"},
"fire-swallower":{"fire-swallower","fire-swallowers"},
"fire-worship":{"fire-worship","fire-worships"},
"firearm":{"firearm","firearms"},
"fireball":{"fireball","fireballs"},
"firebird":{"firebird","firebirds"},
"firebrand":{"firebrand","firebrands"},
"firebrat":{"firebrat","firebrats"},
"firebreak":{"firebreak","firebreaks"},
"firebug":{"firebug","firebugs"},
"firebush":{"firebush","firebushes"},
"firecracker":{"firecracker","firecrackers"},
"firedog":{"firedog","firedogs"},
"firedrake":{"firedrake","firedrakes"},
"firefly":{"fireflies","firefly"},
"fireguard":{"fireguard","fireguards"},
"firehouse":{"firehouse","firehouses"},
"firelock":{"firelock","firelocks"},
"fireman":{"fireman","firemen"},
"firenze":{"firenze","firenzes"},
"fireplace":{"fireplace","fireplaces"},
"fireplug":{"fireplug","fireplugs"},
"fireproof":{"fireproof","fireproofed","fireproofing"},
"fireroom":{"fireroom","firerooms"},
"fireside":{"fireside","firesides"},
"firethorn":{"firethorn","firethorns"},
"firetrap":{"firetrap","firetraps"},
"fireweed":{"fireweed","fireweeds"},
"firewheel":{"firewheel","firewheels"},
"firework":{"firework","fireworks"},
"firing":{"firing","firings"},
"firm":{"firm","firmed","firmer","firmest","firming","firms"},
"firmament":{"firmament","firmaments"},
"firman":{"firman","firmans"},
"firmiana":{"firmiana","firmianas"},
"firmness":{"firmness","firmnesses"},
"firry":{"firrier","firriest","firry"},
"first":{"first","firsts"},
"firstborn":{"firstborn","firstborns"},
"fish":{"fish","fished","fishes","fishing"},
"fish-worship":{"fish-worship","fish-worships"},
"fisher":{"fisher","fishers"},
"fisherman":{"fisherman","fishermen"},
"fishery":{"fisheries","fishery"},
"fishgig":{"fishgig","fishgigs"},
"fishmonger":{"fishmonger","fishmongers"},
"fishnet":{"fishnet","fishnets"},
"fishtail":{"fishtail","fishtailed","fishtailing"},
"fishwife":{"fishwife","fishwives"},
"fishworm":{"fishworm","fishworms"},
"fishy":{"fishier","fishiest","fishy"},
"fission":{"fission","fissions"},
"fissiped":{"fissiped","fissipeds"},
"fissure":{"fissure","fissures"},
"fissurella":{"fissurella","fissurellas"},
"fissurellidae":{"fissurellidae","fissurellidaes"},
"fist":{"fist","fisted","fisting","fists"},
"fistfight":{"fistfight","fistfights"},
"fistful":{"fistful","fistfuls"},
"fisticuff":{"fisticuff","fisticuffs"},
"fisticuffs":{"fisticuffs","fisticuffses"},
"fistula":{"fistula","fistulae","fistulas"},
"fistularia":{"fistularia","fistularias"},
"fistulariidae":{"fistulariidae","fistulariidaes"},
"fistulina":{"fistulina","fistulinas"},
"fistulinaceae":{"fistulinaceae","fistulinaceaes"},
"fit":{"fit","fits","fitted","fitter","fittest","fitting"},
"fitch":{"fitch","fitches"},
"fitfulness":{"fitfulness","fitfulnesses"},
"fitness":{"fitness","fitnesses"},
"fitting":{"fitting","fittings"},
"fittingness":{"fittingness","fittingnesses"},
"five":{"five","fives"},
"five-finger":{"five-finger","five-fingers"},
"five-hitter":{"five-hitter","five-hitters"},
"five-spot":{"five-spot","five-spots"},
"fiver":{"fiver","fivers"},
"fivesome":{"fivesome","fivesomes"},
"fix":{"fix","fixed","fixes","fixing"},
"fixate":{"fixate","fixated","fixates","fixating"},
"fixation":{"fixation","fixations"},
"fixedness":{"fixedness","fixednesses"},
"fixer":{"fixer","fixers"},
"fixing":{"fixing","fixings"},
"fixity":{"fixities","fixity"},
"fixture":{"fixture","fixtures"},
"fizgig":{"fizgig","fizgigs"},
"fizz":{"fizz","fizzed","fizzing","fizzs"},
"fizzle":{"fizzle","fizzled","fizzles","fizzling"},
"fizzy":{"fizzier","fizziest","fizzy"},
"fjord":{"fjord","fjords"},
"flabbergast":{"flabbergast","flabbergasted","flabbergasting","flabbergasts"},
"flabbiness":{"flabbiness","flabbinesses"},
"flabby":{"flabbier","flabbiest","flabby"},
"flabellum":{"flabella","flabellum"},
"flaccidity":{"flaccidities","flaccidity"},
"flacourtia":{"flacourtia","flacourtias"},
"flacourtiaceae":{"flacourtiaceae","flacourtiaceaes"},
"flag":{"flag","flagged","flagging","flags"},
"flag-waver":{"flag-waver","flag-wavers"},
"flagellata":{"flagellata","flagellatas"},
"flagellate":{"flagellate","flagellated","flagellates","flagellating"},
"flagellation":{"flagellation","flagellations"},
"flagellum":{"flagella","flagellum","flagellums"},
"flageolet":{"flageolet","flageolets"},
"flagfish":{"flagfish","flagfishes"},
"flaggy":{"flaggier","flaggiest","flaggy"},
"flagman":{"flagman","flagmen"},
"flagon":{"flagon","flagons"},
"flagpole":{"flagpole","flagpoles"},
"flagroot":{"flagroot","flagroots"},
"flagstaff":{"flagstaff","flagstaffs","flagstaves"},
"flagstone":{"flagstone","flagstones"},
"flail":{"flail","flailed","flailing","flails"},
"flair":{"flair","flairs"},
"flak":{"flak","flaks"},
"flake":{"flake","flaked","flakes","flaking"},
"flakiness":{"flakiness","flakinesses"},
"flaky":{"flakier","flakiest","flaky"},
"flam":{"flam","flammed","flamming","flams"},
"flambe":{"flambe","flambed","flambeed","flambees","flambes","flambing"},
"flambeau":{"flambeau","flambeaus","flambeaux"},
"flamboyance":{"flamboyance","flamboyances"},
"flamboyant":{"flamboyant","flamboyants"},
"flame":{"flame","flamed","flames","flaming"},
"flamefish":{"flamefish","flamefishes"},
"flameflower":{"flameflower","flameflowers"},
"flamen":{"flamen","flamens","flamines"},
"flamenco":{"flamenco","flamencos"},
"flaming":{"flaming","flamings"},
"flamingo":{"flamingo","flamingoes","flamingos"},
"flaminius":{"flaminius","flaminiuses"},
"flammulina":{"flammulina","flammulinas"},
"flamy":{"flamier","flamiest","flamy"},
"flange":{"flange","flanges"},
"flank":{"flank","flanked","flanking","flanks"},
"flannel":{"flannel","flanneled","flanneling","flannelled","flannelling","flannels"},
"flannelbush":{"flannelbush","flannelbushes"},
"flannelcake":{"flannelcake","flannelcakes"},
"flap":{"flap","flapped","flapping","flaps"},
"flapcake":{"flapcake","flapcakes"},
"flapjack":{"flapjack","flapjacks"},
"flapping":{"flapping","flappings"},
"flaps":{"flaps","flapses"},
"flare":{"flare","flared","flares","flaring"},
"flare-up":{"flare-up","flare-ups"},
"flash":{"flash","flashed","flashes","flashing"},
"flashbulb":{"flashbulb","flashbulbs"},
"flasher":{"flasher","flashers"},
"flashgun":{"flashgun","flashguns"},
"flashiness":{"flashiness","flashinesses"},
"flashing":{"flashing","flashings"},
"flashlight":{"flashlight","flashlights"},
"flashy":{"flashier","flashiest","flashy"},
"flask":{"flask","flasks"},
"flaskful":{"flaskful","flaskfuls"},
"flat":{"flat","flats","flatted","flatter","flattest","flatting"},
"flatboat":{"flatboat","flatboats"},
"flatcar":{"flatcar","flatcars"},
"flatfish":{"flatfish","flatfishes"},
"flatfoot":{"flatfeet","flatfoot","flatfoots"},
"flathead":{"flathead","flatheads"},
"flatness":{"flatness","flatnesses"},
"flatten":{"flatten","flattened","flattening","flattens"},
"flatter":{"flatter","flattered","flattering","flatters"},
"flatterer":{"flatterer","flatterers"},
"flattery":{"flatteries","flattery"},
"flattop":{"flattop","flattops"},
"flatulence":{"flatulence","flatulences"},
"flatulency":{"flatulencies","flatulency"},
"flatus":{"flatus","flatuses"},
"flatware":{"flatware","flatwares"},
"flatwork":{"flatwork","flatworks"},
"flatworm":{"flatworm","flatworms"},
"flaunt":{"flaunt","flaunted","flaunting","flaunts"},
"flaunting":{"flaunting","flauntings"},
"flaunty":{"flauntier","flauntiest","flaunty"},
"flautist":{"flautist","flautists"},
"flavor":{"flavor","flavored","flavoring","flavors"},
"flavorer":{"flavorer","flavorers"},
"flavoring":{"flavoring","flavorings"},
"flavorlessness":{"flavorlessness","flavorlessnesses"},
"flavorsomeness":{"flavorsomeness","flavorsomenesses"},
"flavour":{"flavour","flavoured","flavouring","flavours"},
"flavourer":{"flavourer","flavourers"},
"flavouring":{"flavouring","flavourings"},
"flaw":{"flaw","flawed","flawing","flaws"},
"flawlessness":{"flawlessness","flawlessnesses"},
"flaxseed":{"flaxseed","flaxseeds"},
"flay":{"flay","flayed","flaying"},
"flea":{"flea","fleas"},
"fleabane":{"fleabane","fleabanes"},
"fleawort":{"fleawort","fleaworts"},
"fleck":{"fleck","flecks"},
"flection":{"flection","flections"},
"fledge":{"fledge","fledged","fledges","fledging"},
"fledgeling":{"fledgeling","fledgelings"},
"fledgling":{"fledgling","fledglings"},
"fledgy":{"fledgier","fledgiest","fledgy"},
"flee":{"fled","flee","fleeing","flees"},
"fleece":{"fleece","fleeced","fleeces","fleecing"},
"fleecy":{"fleecier","fleeciest","fleecy"},
"fleer":{"fleer","fleered","fleering"},
"fleet":{"fleet","fleeted","fleeter","fleetest","fleeting","fleets"},
"fleetingness":{"fleetingness","fleetingnesses"},
"flemish":{"flemish","flemishes"},
"flench":{"flench","flenched","flenches","flenching"},
"flense":{"flense","flensed","flenses","flensing"},
"flesh":{"flesh","fleshed","fleshes","fleshing"},
"fleshiness":{"fleshiness","fleshinesses"},
"fleshly":{"fleshlier","fleshliest","fleshly"},
"fleshy":{"fleshier","fleshiest","fleshy"},
"fletch":{"fletch","fletched","fletching"},
"fleur-de-lis":{"fleur-de-lis","fleur-de-lises","fleurs-de-lis"},
"fleur-de-lys":{"fleur-de-lys","fleur-de-lyses"},
"flex":{"flex","flexed","flexes","flexing"},
"flexibility":{"flexibilities","flexibility"},
"flexibleness":{"flexibleness","flexiblenesses"},
"flexion":{"flexion","flexions"},
"flexor":{"flexor","flexors"},
"flexure":{"flexure","flexures"},
"flibbertigibbet":{"flibbertigibbet","flibbertigibbets"},
"flic":{"flic","flics"},
"flick":{"flick","flicked","flicking","flicks"},
"flicker":{"flicker","flickered","flickering","flickers"},
"flickertail":{"flickertail","flickertails"},
"flier":{"flier","fliers"},
"flight":{"flight","flighted","flighting","flights"},
"flight-test":{"flight-test","flight-tested","flight-testing"},
"flightiness":{"flightiness","flightinesses"},
"flighty":{"flightier","flightiest","flighty"},
"flight_of_stairs":{"flights_of_stairs","flight_of_stairs"},
"flimflam":{"flimflam","flimflammed","flimflamming","flimflams"},
"flimsiness":{"flimsiness","flimsinesses"},
"flimsy":{"flimsier","flimsies","flimsiest","flimsy"},
"flinch":{"flinch","flinched","flinches","flinching"},
"flinders":{"flinders","flinderses"},
"flindersia":{"flindersia","flindersias"},
"flindosa":{"flindosa","flindosas"},
"flindosy":{"flindosies","flindosy"},
"fling":{"fling","flinging","flings","flung"},
"flint":{"flint","flints"},
"flintlock":{"flintlock","flintlocks"},
"flinty":{"flintier","flintiest","flinty"},
"flip":{"flip","flipped","flipper","flippest","flipping","flips"},
"flip-flop":{"flip-flop","flip-flopped","flip-flopping","flip-flops"},
"flippancy":{"flippancies","flippancy"},
"flipper":{"flipper","flippers"},
"flippers":{"flippers","flipperses"},
"flirt":{"flirt","flirted","flirting","flirts"},
"flirtation":{"flirtation","flirtations"},
"flirting":{"flirting","flirtings"},
"flit":{"flit","flits","flitted","flitting"},
"flitch":{"flitch","flitches"},
"flitter":{"flitter","flittered","flittering","flitters"},
"flittermouse":{"flittermice","flittermouse"},
"float":{"float","floated","floating","floats"},
"floatation":{"floatation","floatations"},
"floater":{"floater","floaters"},
"floating-moss":{"floating-moss","floating-mosses"},
"floatplane":{"floatplane","floatplanes"},
"floaty":{"floatier","floatiest","floaty"},
"floc":{"floc","flocs"},
"flocculate":{"flocculate","flocculated","flocculating"},
"floccule":{"floccule","floccules"},
"flocculus":{"flocculi","flocculus"},
"floccus":{"flocci","floccus"},
"flock":{"flock","flocked","flocking","flocks"},
"flocky":{"flockier","flockiest","flocky"},
"flodden":{"flodden","floddens"},
"floe":{"floe","floes"},
"flog":{"flog","flogged","flogging","flogs"},
"flogging":{"flogging","floggings"},
"flood":{"flood","flooded","flooding","floods"},
"floodgate":{"floodgate","floodgates"},
"flooding":{"flooding","floodings"},
"floodlight":{"floodlight","floodlighted","floodlighting","floodlights","floodlit"},
"floor":{"floor","floored","flooring","floors"},
"floorboard":{"floorboard","floorboards"},
"floorcover":{"floorcover","floorcovers"},
"flooring":{"flooring","floorings"},
"floorshow":{"floorshow","floorshows"},
"floorwalker":{"floorwalker","floorwalkers"},
"floosie":{"floosie","floosies"},
"floozie":{"floozie","floozies"},
"floozy":{"floozies","floozy"},
"flop":{"flop","flopped","flopping","flops"},
"flophouse":{"flophouse","flophouses"},
"flopping":{"flopping","floppings"},
"floppy":{"floppier","floppies","floppiest","floppy"},
"flora":{"flora","florae","floras"},
"floreat":{"floreant.","floreat"},
"florence":{"florence","florences"},
"floriculture":{"floriculture","floricultures"},
"florida":{"florida","floridas"},
"floridness":{"floridness","floridnesses"},
"florilegium":{"florilegia","florilegium","florilegiums"},
"florin":{"florin","florins"},
"florist":{"florist","florists"},
"floss":{"floss","flossed","flosses","flossing"},
"flossy":{"flossier","flossiest","flossy"},
"flotation":{"flotation","flotations"},
"flotsam":{"flotsam","flotsams"},
"flounce":{"flounce","flounced","flounces","flouncing"},
"flounder":{"flounder","floundered","floundering","flounders"},
"flour":{"flour","floured","flouring"},
"flourish":{"flourish","flourished","flourishes","flourishing"},
"flout":{"flout","flouted","flouting","flouts"},
"flow":{"flow","flowed","flowing","flows"},
"flower":{"flower","flowered","flowering","flowers"},
"flower-de-luce":{"flower-de-luce","flowers-de-luce"},
"flower-of-an-hour":{"flower-of-an-hour","flower-of-an-hours"},
"flowerbed":{"flowerbed","flowerbeds"},
"flowering":{"flowering","flowerings"},
"flowerpot":{"flowerpot","flowerpots"},
"flowers-of-an-hour":{"flowers-of-an-hour","flowers-of-an-hours"},
"flowery":{"flowerier","floweriest","flowery"},
"flowing":{"flowing","flowings"},
"flu":{"flu","flus"},
"flub":{"flub","flubbed","flubbing","flubs"},
"fluctuate":{"fluctuate","fluctuated","fluctuates","fluctuating"},
"fluctuation":{"fluctuation","fluctuations"},
"flue":{"flue","flues"},
"fluegelhorn":{"fluegelhorn","fluegelhorns"},
"fluency":{"fluencies","fluency"},
"fluff":{"fluff","fluffed","fluffing","fluffs"},
"fluffiness":{"fluffiness","fluffinesses"},
"fluffy":{"fluffier","fluffiest","fluffy"},
"flugelhorn":{"flugelhorn","flugelhorns"},
"fluid":{"fluid","fluids"},
"fluidity":{"fluidities","fluidity"},
"fluidize":{"fluidize","fluidized","fluidizing"},
"fluidness":{"fluidness","fluidnesses"},
"fluidounce":{"fluidounce","fluidounces"},
"fluidram":{"fluidram","fluidrams"},
"fluke":{"fluke","flukes"},
"fluky":{"flukier","flukiest","fluky"},
"flume":{"flume","flumes"},
"flummery":{"flummeries","flummery"},
"flummox":{"flummox","flummoxed","flummoxes","flummoxing"},
"flump":{"flump","flumped","flumping","flumps"},
"flunk":{"flunk","flunked","flunking","flunks"},
"flunkey":{"flunkey","flunkeys"},
"flunky":{"flunkies","flunky"},
"fluor":{"fluor","fluors"},
"fluoresce":{"fluoresce","fluoresced","fluorescing"},
"fluorescein":{"fluorescein","fluoresceins"},
"fluoresceine":{"fluoresceine","fluoresceines"},
"fluoridate":{"fluoridate","fluoridated","fluoridates","fluoridating"},
"fluoridation":{"fluoridation","fluoridations"},
"fluoridization":{"fluoridization","fluoridizations"},
"fluoridize":{"fluoridize","fluoridized","fluoridizes","fluoridizing"},
"fluorinate":{"fluorinate","fluorinated","fluorinating"},
"fluorine":{"fluorine","fluorines"},
"fluorite":{"fluorite","fluorites"},
"fluoroscope":{"fluoroscope","fluoroscopes"},
"fluorspar":{"fluorspar","fluorspars"},
"fluoxetine":{"fluoxetine","fluoxetines"},
"flurbiprofen":{"flurbiprofen","flurbiprofens"},
"flurry":{"flurried","flurries","flurry","flurrying"},
"flush":{"flush","flushed","flusher","flushes","flushest","flushing"},
"fluster":{"fluster","flustered","flustering","flusters"},
"flute":{"flute","fluted","flutes","fluting"},
"fluting":{"fluting","flutings"},
"flutist":{"flutist","flutists"},
"flutter":{"flutter","fluttered","fluttering","flutters"},
"fluttering":{"fluttering","flutterings"},
"fluty":{"flutier","flutiest","fluty"},
"flux":{"flux","fluxed","fluxes","fluxing"},
"fluxion":{"fluxion","fluxions"},
"fly":{"flew","flies","flown","fly","flying"},
"fly-fish":{"fly-fish","fly-fished","fly-fishing"},
"flyblow":{"flyblew","flyblow","flyblowing","flyblown","flyblows"},
"flybridge":{"flybridge","flybridges"},
"flyby":{"flybies","flyby","flybys"},
"flycatcher":{"flycatcher","flycatchers"},
"flyer":{"flyer","flyers"},
"flying":{"flying","flyings"},
"flyleaf":{"flyleaf","flyleaves"},
"flyman":{"flyman","flymen"},
"flyover":{"flyover","flyovers"},
"flypast":{"flypast","flypasts"},
"flyspeck":{"flyspeck","flyspecked","flyspecking"},
"flyswat":{"flyswat","flyswats"},
"flyswatter":{"flyswatter","flyswatters"},
"flyway":{"flyway","flyways"},
"fm":{"fm","fms"},
"fnma":{"fnma","fnmas"},
"foal":{"foal","foaled","foaling"},
"foam":{"foam","foamed","foaming","foams"},
"foamflower":{"foamflower","foamflowers"},
"foamy":{"foamier","foamiest","foamy"},
"fob":{"fob","fobs"},
"focalisation":{"focalisation","focalisations"},
"focalization":{"focalization","focalizations"},
"focalize":{"focalize","focalized","focalizing"},
"focus":{"foci","focus","focused","focuses","focusing","focussed","focussing"},
"focusing":{"focusing","focusings"},
"focussing":{"focussing","focussings"},
"foe":{"foe","foes"},
"foehn":{"foehn","foehns"},
"foeman":{"foeman","foemen"},
"foeniculum":{"foeniculum","foeniculums"},
"foetor":{"foetor","foetors"},
"foetus":{"foetus","foetuses"},
"fog":{"fog","fogged","fogging","fogs"},
"fogey":{"fogey","fogeys"},
"fogginess":{"fogginess","fogginesses"},
"foggy":{"foggier","foggiest","foggy"},
"foghorn":{"foghorn","foghorns"},
"fogsignal":{"fogsignal","fogsignals"},
"fogy":{"fogies","fogy"},
"fohn":{"fohn","fohns"},
"foible":{"foible","foibles"},
"foil":{"foil","foiled","foiling","foils"},
"foiling":{"foiling","foilings"},
"foilsman":{"foilsman","foilsmen"},
"foin":{"foin","foined","foining"},
"foist":{"foist","foisted","foisting"},
"folacin":{"folacin","folacins"},
"folate":{"folate","folates"},
"fold":{"fold","folded","folding","folds"},
"folder":{"folder","folders"},
"folderol":{"folderol","folderols"},
"folding":{"folding","foldings"},
"foliage":{"foliage","foliages"},
"foliate":{"foliate","foliated","foliates","foliating"},
"foliation":{"foliation","foliations"},
"folio":{"folio","folios"},
"folium":{"folia","folium","foliums"},
"folk":{"folk","folks"},
"folksy":{"folksier","folksiest","folksy"},
"folky":{"folkier","folkiest","folky"},
"follow":{"follow","followed","following","follows"},
"follow-up":{"follow-up","follow-ups"},
"follower":{"follower","followers"},
"followers":{"followers","followerses"},
"following":{"following","followings"},
"folly":{"follies","folly"},
"foment":{"foment","fomented","fomenting","foments"},
"fomentation":{"fomentation","fomentations"},
"fomenter":{"fomenter","fomenters"},
"fomes":{"fomes","fomeses"},
"fomor":{"fomor","fomors"},
"fomorian":{"fomorian","fomorians"},
"fond":{"fond","fonder","fondest"},
"fondle":{"fondle","fondled","fondles","fondling"},
"fondling":{"fondling","fondlings"},
"fondness":{"fondness","fondnesses"},
"fondu":{"fondu","fondus"},
"fondue":{"fondue","fondues"},
"font":{"font","fonts"},
"fontanel":{"fontanel","fontanels"},
"fontanelle":{"fontanelle","fontanelles"},
"fontenoy":{"fontenoy","fontenoys"},
"food":{"food","foods"},
"foodstuff":{"foodstuff","foodstuffs"},
"fool":{"fool","fooled","fooling","fools"},
"foolery":{"fooleries","foolery"},
"foolhardiness":{"foolhardiness","foolhardinesses"},
"foolhardy":{"foolhardier","foolhardiest","foolhardy"},
"foolishness":{"foolishness","foolishnesses"},
"foot":{"feet","foot","footed","footing"},
"foot-lambert":{"foot-lambert","foot-lamberts"},
"football":{"football","footballs"},
"footballer":{"footballer","footballers"},
"footbridge":{"footbridge","footbridges"},
"footcloth":{"footcloth","footcloths"},
"footer":{"footer","footers"},
"footfall":{"footfall","footfalls"},
"footgear":{"footgear","footgears"},
"foothill":{"foothill","foothills"},
"foothold":{"foothold","footholds"},
"footing":{"footing","footings"},
"footle":{"footle","footled","footles","footling"},
"footlight":{"footlight","footlights"},
"footlights":{"footlights","footlightses"},
"footlocker":{"footlocker","footlockers"},
"footman":{"footman","footmen"},
"footmark":{"footmark","footmarks"},
"footnote":{"footnote","footnoted","footnotes","footnoting"},
"footpath":{"footpath","footpaths"},
"footprint":{"footprint","footprints"},
"footrace":{"footrace","footraces"},
"footrest":{"footrest","footrests"},
"footslog":{"footslog","footslogged","footslogging","footslogs"},
"footslogger":{"footslogger","footsloggers"},
"footstall":{"footstall","footstalls"},
"footstep":{"footstep","footsteps"},
"footsteps-of-spring":{"footsteps-of-spring","footsteps-of-springs"},
"footstool":{"footstool","footstools"},
"footwear":{"footwear","footwears"},
"foozle":{"foozle","foozled","foozling"},
"fop":{"fop","fops"},
"foppery":{"fopperies","foppery"},
"forage":{"forage","foraged","forages","foraging"},
"foraging":{"foraging","foragings"},
"foram":{"foram","forams"},
"foramen":{"foramen","foramens","foramina","foraramens","foraramina"},
"foraminifer":{"foraminifer","foraminifers"},
"foraminifera":{"foraminifera","foraminiferas"},
"foray":{"foray","forayed","foraying","forays"},
"forbear":{"forbear","forbearing","forbears","forbore","forborne"},
"forbearance":{"forbearance","forbearances"},
"forbid":{"forbad","forbade","forbid","forbidden","forbidding","forbids"},
"forbiddance":{"forbiddance","forbiddances"},
"forbidding":{"forbidding","forbiddings"},
"force":{"force","forced","forces","forcing"},
"force-feed":{"force-fed","force-feed","force-feeding","force-feeds"},
"forcefulness":{"forcefulness","forcefulnesses"},
"forcemeat":{"forcemeat","forcemeats"},
"forceps":{"forceps","forcipes"},
"ford":{"ford","forded","fording","fords"},
"fording":{"fording","fordings"},
"fordo":{"fordid","fordo","fordoes","fordoing","fordone"},
"fore":{"fore","fores"},
"forearm":{"forearm","forearmed","forearming","forearms"},
"forebear":{"forebear","forebears"},
"forebode":{"forebode","foreboded","forebodes","foreboding"},
"foreboding":{"foreboding","forebodings"},
"forebrain":{"forebrain","forebrains"},
"forecast":{"forecast","forecasted","forecasting","forecasts"},
"forecaster":{"forecaster","forecasters"},
"forecasting":{"forecasting","forecastings"},
"forecastle":{"forecastle","forecastles"},
"foreclose":{"foreclose","foreclosed","forecloses","foreclosing"},
"foredo":{"foredid","foredo","foredoes","foredoing","foredone"},
"foredoom":{"foredoom","foredoomed","foredooming"},
"forefather":{"forefather","forefathers"},
"forefeel":{"forefeel","forefeeling","forefelt"},
"forefighter":{"forefighter","forefighters"},
"forefinger":{"forefinger","forefingers"},
"forefoot":{"forefeet","forefoot"},
"forefront":{"forefront","forefronts"},
"foregather":{"foregather","foregathered","foregathering","foregathers"},
"forego":{"forego","foregoes","foregoing","foregone","forewent"},
"foreground":{"foreground","foregrounded","foregrounding","foregrounds"},
"foregrounding":{"foregrounding","foregroundings"},
"forehand":{"forehand","forehands"},
"forehead":{"forehead","foreheads"},
"foreigner":{"foreigner","foreigners"},
"foreignness":{"foreignness","foreignnesses"},
"forejudge":{"forejudge","forejudged","forejudging"},
"foreknow":{"foreknew","foreknow","foreknowing","foreknown","foreknows"},
"foreknowledge":{"foreknowledge","foreknowledges"},
"forelady":{"foreladies","forelady"},
"foreland":{"foreland","forelands"},
"forelock":{"forelock","forelocks"},
"foreman":{"foreman","foremen"},
"foremilk":{"foremilk","foremilks"},
"forename":{"forename","forenames"},
"forenoon":{"forenoon","forenoons"},
"foreordain":{"foreordain","foreordained","foreordaining","foreordains"},
"foreordination":{"foreordination","foreordinations"},
"forepart":{"forepart","foreparts"},
"foreplay":{"foreplay","foreplays"},
"forereach":{"forereach","forereached","forereaching"},
"forerun":{"foreran","forerun","forerunning","foreruns"},
"forerunner":{"forerunner","forerunners"},
"foresee":{"foresaw","foresee","foreseeing","foreseen","foresees"},
"foreshadow":{"foreshadow","foreshadowed","foreshadowing","foreshadows"},
"foreshadowing":{"foreshadowing","foreshadowings"},
"foreshorten":{"foreshorten","foreshortened","foreshortening","foreshortens"},
"foreshow":{"foreshow","foreshowed","foreshowing","foreshown","foreshows"},
"foresight":{"foresight","foresights"},
"foresightedness":{"foresightedness","foresightednesses"},
"foresightfulness":{"foresightfulness","foresightfulnesses"},
"foreskin":{"foreskin","foreskins"},
"forespeak":{"forespeak","forespeaking","forespeaks","forespoke","forespoken"},
"forest":{"forest","forested","foresting","forests"},
"forestage":{"forestage","forestages"},
"forestall":{"forestall","forestalled","forestalling","forestalls"},
"forestalling":{"forestalling","forestallings"},
"forester":{"forester","foresters"},
"foretaste":{"foretaste","foretasted","foretasting"},
"foretell":{"foretell","foretelling","foretells","foretold"},
"foretelling":{"foretelling","foretellings"},
"forethought":{"forethought","forethoughts"},
"foretoken":{"foretoken","foretokened","foretokening"},
"foretooth":{"foreteeth","foretooth"},
"foretop":{"foretop","foretops"},
"forever":{"forever","forevers"},
"forewarn":{"forewarn","forewarned","forewarning"},
"forewarning":{"forewarning","forewarnings"},
"forewoman":{"forewoman","forewomen"},
"foreword":{"foreword","forewords"},
"forfeit":{"forfeit","forfeited","forfeiting","forfeits"},
"forfeiter":{"forfeiter","forfeiters"},
"forfeiture":{"forfeiture","forfeitures"},
"forfend":{"forfend","forfended","forfending"},
"forficula":{"forficula","forficulas"},
"forficulidae":{"forficulidae","forficulidaes"},
"forgather":{"forgather","forgathered","forgathering","forgathers"},
"forge":{"forge","forged","forges","forging"},
"forger":{"forger","forgers"},
"forgery":{"forgeries","forgery"},
"forget":{"forget","forgets","forgetting","forgot","forgotten"},
"forget-me-not":{"forget-me-not","forget-me-nots"},
"forgive":{"forgave","forgive","forgiven","forgives","forgiving"},
"forgiveness":{"forgiveness","forgivenesses"},
"forgivingness":{"forgivingness","forgivingnesses"},
"forgo":{"forgo","forgoes","forgoing","forgone","forwent"},
"forgoing":{"forgoing","forgoings"},
"fork":{"fork","forked","forking","forks"},
"forkful":{"forkful","forkfuls","forksful"},
"forking":{"forking","forkings"},
"forky":{"forkier","forkiest","forky"},
"forlornness":{"forlornness","forlornnesses"},
"form":{"form","formed","forming","forms"},
"formaldehyde":{"formaldehyde","formaldehydes"},
"formalin":{"formalin","formalins"},
"formalisation":{"formalisation","formalisations"},
"formalities":{"formalities","formalitieses"},
"formality":{"formalities","formality"},
"formalization":{"formalization","formalizations"},
"formalize":{"formalize","formalized","formalizes","formalizing"},
"formalness":{"formalness","formalnesses"},
"formalwear":{"formalwear","formalwears"},
"format":{"format","formats"},
"formation":{"formation","formations"},
"formatting":{"formatting","formattings"},
"formica":{"formica","formicas"},
"formicariidae":{"formicariidae","formicariidaes"},
"formicarium":{"formicaria","formicarium"},
"formicarius":{"formicarius","formicariuses"},
"formicary":{"formicaries","formicary"},
"formicidae":{"formicidae","formicidaes"},
"formidability":{"formidabilities","formidability"},
"formol":{"formol","formols"},
"formosa":{"formosa","formosas"},
"formula":{"formula","formulae","formulas"},
"formularising":{"formularising","formularisings"},
"formularize":{"formularize","formularized","formularizes","formularizing"},
"formularizing":{"formularizing","formularizings"},
"formulary":{"formularies","formulary"},
"formulate":{"formulate","formulated","formulates","formulating"},
"formulation":{"formulation","formulations"},
"formulize":{"formulize","formulized","formulizing"},
"fornicate":{"fornicate","fornicated","fornicating"},
"fornication":{"fornication","fornications"},
"fornicator":{"fornicator","fornicators"},
"fornicatress":{"fornicatress","fornicatresses"},
"fornix":{"fornices","fornix"},
"forsake":{"forsake","forsaken","forsakes","forsaking","forsook"},
"forsaking":{"forsaking","forsakings"},
"forspeak":{"forspeak","forspeaking","forspeaks","forspoke","forspoken"},
"forswear":{"forswear","forswearing","forswears","forswore","forsworn"},
"forswearing":{"forswearing","forswearings"},
"forsythia":{"forsythia","forsythias"},
"fort":{"fort","forted","forting","forts"},
"fort-lamy":{"fort-lamies","fort-lamy"},
"fortaz":{"fortaz","fortazs"},
"forte":{"forte","fortes"},
"forte-piano":{"forte-piano","forte-pianos"},
"forthcomingness":{"forthcomingness","forthcomingnesses"},
"forthright":{"forthright","forthrights"},
"forthrightness":{"forthrightness","forthrightnesses"},
"forties":{"forties","fortieses"},
"fortification":{"fortification","fortifications"},
"fortifier":{"fortifier","fortifiers"},
"fortify":{"fortified","fortifies","fortify","fortifying"},
"fortis":{"fortes","fortis"},
"fortissimo":{"fortissimi","fortissimo","fortissimos"},
"fortnight":{"fortnight","fortnights"},
"fortnightly":{"fortnightlies","fortnightly"},
"fortress":{"fortress","fortresses"},
"fortuity":{"fortuities","fortuity"},
"fortune":{"fortune","fortuned","fortunes","fortuning"},
"fortunella":{"fortunella","fortunellas"},
"forty":{"forties","forty"},
"forum":{"forum","forums"},
"forward":{"forward","forwarded","forwarding","forwards"},
"forwarding":{"forwarding","forwardings"},
"forwardness":{"forwardness","forwardnesses"},
"fossa":{"fossa","fossae","fossas"},
"fosse":{"fosse","fosses"},
"fossick":{"fossick","fossicked","fossicking"},
"fossil":{"fossil","fossils"},
"fossilist":{"fossilist","fossilists"},
"fossilize":{"fossilize","fossilized","fossilizing"},
"fossilology":{"fossilologies","fossilology"},
"foster":{"foster","fostered","fostering","fosters"},
"fosterage":{"fosterage","fosterages"},
"fostering":{"fostering","fosterings"},
"fothergilla":{"fothergilla","fothergillas"},
"fots":{"fots","fotses"},
"foul":{"foul","fouled","fouler","foulest","fouling","fouls"},
"foul-up":{"foul-up","foul-ups"},
"foulmart":{"foulmart","foulmarts"},
"foulness":{"foulness","foulnesses"},
"foumart":{"foumart","foumarts"},
"found":{"found","founded","founding","founds"},
"foundation":{"foundation","foundations"},
"founder":{"founder","foundered","foundering","founders"},
"foundering":{"foundering","founderings"},
"founding":{"founding","foundings"},
"foundling":{"foundling","foundlings"},
"foundry":{"foundries","foundry"},
"fount":{"fount","founts"},
"fountain":{"fountain","fountains"},
"fountainhead":{"fountainhead","fountainheads"},
"fountainpen":{"fountainpen","fountainpens"},
"fouquieria":{"fouquieria","fouquierias"},
"fouquieriaceae":{"fouquieriaceae","fouquieriaceaes"},
"four":{"four","fours"},
"four-flush":{"four-flush","four-flushed","four-flushing"},
"four-hitter":{"four-hitter","four-hitters"},
"four-in-hand":{"four-in-hand","four-in-hands"},
"fourpence":{"fourpence","fourpences"},
"fourscore":{"fourscore","fourscores"},
"foursome":{"foursome","foursomes"},
"foursquare":{"foursquare","foursquares"},
"fourteen":{"fourteen","fourteens"},
"fourteenth":{"fourteenth","fourteenths"},
"fourth":{"fourth","fourths"},
"fovea":{"fovea","foveae","foveas"},
"foveola":{"foveola","foveolae"},
"fowl":{"fowl","fowled","fowling","fowls"},
"fox":{"fox","foxed","foxes","foxing"},
"fox-trot":{"fox-trot","fox-trotted","fox-trotting"},
"foxberry":{"foxberries","foxberry"},
"foxglove":{"foxglove","foxgloves"},
"foxhole":{"foxhole","foxholes"},
"foxhunt":{"foxhunt","foxhunts"},
"foxiness":{"foxiness","foxinesses"},
"foxtail":{"foxtail","foxtails"},
"foxtrot":{"foxtrot","foxtrots","foxtrotted","foxtrotting"},
"foxy":{"foxier","foxiest","foxy"},
"foyer":{"foyer","foyers"},
"fr":{"fr","frs"},
"fracas":{"fracas","fracases"},
"fraction":{"fraction","fractioned","fractioning","fractions"},
"fractionalize":{"fractionalize","fractionalized","fractionalizing"},
"fractionate":{"fractionate","fractionated","fractionating"},
"fractionation":{"fractionation","fractionations"},
"fractiousness":{"fractiousness","fractiousnesses"},
"fractocumulus":{"fractocumuli","fractocumulus"},
"fractostratus":{"fractostrati","fractostratus"},
"fracture":{"fracture","fractured","fractures","fracturing"},
"fradicin":{"fradicin","fradicins"},
"fraenum":{"fraena","fraenum","fraenums"},
"frag":{"frag","fragged","fragging","frags"},
"fragaria":{"fragaria","fragarias"},
"fragility":{"fragilities","fragility"},
"fragment":{"fragment","fragmented","fragmenting","fragments"},
"fragmentation":{"fragmentation","fragmentations"},
"fragmentize":{"fragmentize","fragmentized","fragmentizes","fragmentizing"},
"fragrance":{"fragrance","fragrances"},
"fragrancy":{"fragrancies","fragrancy"},
"frail":{"frail","frailer","frailest","frails"},
"frailness":{"frailness","frailnesses"},
"frailty":{"frailties","frailty"},
"frambesia":{"frambesia","frambesias"},
"framboesia":{"framboesia","framboesias"},
"framboise":{"framboise","framboises"},
"frame":{"frame","framed","frames","framing"},
"frame-up":{"frame-up","frame-ups"},
"framework":{"framework","frameworks"},
"framing":{"framing","framings"},
"franc":{"franc","francs"},
"franchise":{"franchise","franchised","franchises","franchising"},
"franciscan":{"franciscan","franciscans"},
"francium":{"francium","franciums"},
"francoa":{"francoa","francoas"},
"francophil":{"francophil","francophils"},
"francophile":{"francophile","francophiles"},
"frangipani":{"frangipani","frangipanis"},
"frangipanni":{"frangipanni","frangipannis"},
"frank":{"frank","franked","franker","frankest","franking","franks"},
"frankfort":{"frankfort","frankforts"},
"frankfurt":{"frankfurt","frankfurts"},
"frankfurter":{"frankfurter","frankfurters"},
"frankincense":{"frankincense","frankincenses"},
"frankliniella":{"frankliniella","frankliniellas"},
"frankness":{"frankness","franknesses"},
"frap":{"frap","frapped","frapping","fraps"},
"frappe":{"frappe","frappes"},
"frasera":{"frasera","fraseras"},
"frat":{"frat","frats"},
"fratchy":{"fratchier","fratchiest","fratchy"},
"fratercula":{"fratercula","fraterculas"},
"fraternisation":{"fraternisation","fraternisations"},
"fraternity":{"fraternities","fraternity"},
"fraternization":{"fraternization","fraternizations"},
"fraternize":{"fraternize","fraternized","fraternizing"},
"frau":{"frau","frauen","fraus"},
"fraud":{"fraud","frauds"},
"fraudulence":{"fraudulence","fraudulences"},
"fraulein":{"fraulein","frauleins"},
"fraxinella":{"fraxinella","fraxinellas"},
"fraxinus":{"fraxinus","fraxinuses"},
"fray":{"fray","frayed","fraying","frays"},
"frazzle":{"frazzle","frazzled","frazzles","frazzling"},
"freak":{"freak","freaked","freaking","freaks"},
"freakishness":{"freakishness","freakishnesses"},
"freaky":{"freakier","freakiest","freaky"},
"freckle":{"freckle","freckled","freckles","freckling"},
"freckly":{"frecklier","freckliest","freckly"},
"fredericksburg":{"fredericksburg","fredericksburgs"},
"free":{"free","freed","freeing","freer","frees","freest"},
"free-for-all":{"free-for-all","free-for-alls"},
"free-lance":{"free-lance","free-lanced","free-lancing"},
"freeboot":{"freeboot","freebooted","freebooting"},
"freebooter":{"freebooter","freebooters"},
"freedman":{"freedman","freedmen"},
"freedom":{"freedom","freedoms"},
"freedwoman":{"freedwoman","freedwomen"},
"freeing":{"freeing","freeings"},
"freelance":{"freelance","freelances"},
"freeloader":{"freeloader","freeloaders"},
"freeman":{"freeman","freemen"},
"freemason":{"freemason","freemasons"},
"freemasonry":{"freemasonries","freemasonry"},
"freesia":{"freesia","freesias"},
"freetail":{"freetail","freetails"},
"freethinker":{"freethinker","freethinkers"},
"freethinking":{"freethinking","freethinkings"},
"freetown":{"freetown","freetowns"},
"freeway":{"freeway","freeways"},
"freewheel":{"freewheel","freewheeled","freewheeling","freewheels"},
"freewheeler":{"freewheeler","freewheelers"},
"freewoman":{"freewoman","freewomen"},
"freeze":{"freeze","freezes","freezing","froze","frozen"},
"freeze-dry":{"freeze-dried","freeze-dries","freeze-dry","freeze-drying"},
"freezer":{"freezer","freezers"},
"freezing":{"freezing","freezings"},
"fregata":{"fregata","fregatas"},
"fregatidae":{"fregatidae","fregatidaes"},
"freight":{"freight","freighted","freighting","freights"},
"freightage":{"freightage","freightages"},
"freighter":{"freighter","freighters"},
"fremontia":{"fremontia","fremontias"},
"fremontodendron":{"fremontodendron","fremontodendrons"},
"french":{"french","frenches"},
"french-fry":{"french-fried","french-fries","french-fry","french-frying"},
"french-kiss":{"french-kiss","french-kissed","french-kissing"},
"frenchify":{"frenchified","frenchifies","frenchify","frenchifying"},
"frenchman":{"frenchman","frenchmen"},
"frenchwoman":{"frenchwoman","frenchwomen"},
"frenchy":{"frenchier","frenchies","frenchiest","frenchy"},
"frenulum":{"frenula","frenulum"},
"frenum":{"frena","frenum","frenums"},
"frenzy":{"frenzied","frenzies","frenzy","frenzying"},
"frequence":{"frequence","frequences"},
"frequency":{"frequencies","frequency"},
"frequent":{"frequent","frequented","frequenting","frequents"},
"frequenter":{"frequenter","frequenters"},
"fresco":{"fresco","frescoes","frescos"},
"fresh":{"fresh","fresher","freshest"},
"freshen":{"freshen","freshened","freshening","freshens"},
"fresher":{"fresher","freshers"},
"freshet":{"freshet","freshets"},
"freshman":{"freshman","freshmen"},
"freshness":{"freshness","freshnesses"},
"fress":{"fress","fressed","fresses","fressing"},
"fret":{"fret","frets","fretted","fretting"},
"fretfulness":{"fretfulness","fretfulnesses"},
"fretsaw":{"fretsaw","fretsaws"},
"fretty":{"frettier","frettiest","fretty"},
"fretwork":{"fretwork","fretworks"},
"freud":{"freud","freuds"},
"frey":{"frey","freys"},
"freya":{"freya","freyas"},
"freyja":{"freyja","freyjas"},
"freyr":{"freyr","freyrs"},
"frg":{"frg","frgs"},
"fri":{"fri","fris"},
"friability":{"friabilities","friability"},
"friar":{"friar","friars"},
"friary":{"friaries","friary"},
"fribble":{"fribble","fribbled","fribbling"},
"fricandeau":{"fricandeau","fricandeaus","fricandeaux"},
"fricando":{"fricando","fricandoes"},
"fricassee":{"fricassee","fricasseed","fricasseeing","fricassees"},
"fricative":{"fricative","fricatives"},
"friction":{"friction","frictions"},
"friday":{"friday","fridays"},
"fridge":{"fridge","fridges"},
"friend":{"friend","friended","friending","friends"},
"friendly":{"friendlier","friendlies","friendliest","friendly"},
"friendship":{"friendship","friendships"},
"frier":{"frier","friers"},
"fries":{"fries","frieses"},
"friesian":{"friesian","friesians"},
"frieze":{"frieze","friezes"},
"frig":{"frig","frigged","frigging","frigs"},
"frigate":{"frigate","frigates"},
"frigg":{"frigg","friggs"},
"frigga":{"frigga","friggas"},
"fright":{"fright","frighted","frighting","frights"},
"frighten":{"frighten","frightened","frightening","frightens"},
"frightening":{"frightening","frightenings"},
"frigidity":{"frigidities","frigidity"},
"frigorie":{"frigorie","frigories"},
"frijol":{"frijol","frijoles","frijols"},
"frijole":{"frijole","frijoles"},
"frijolillo":{"frijolillo","frijolillos"},
"frijolito":{"frijolito","frijolitos"},
"frill":{"frill","frills"},
"frills":{"frills","frillses"},
"fringe":{"fringe","fringed","fringes","fringing"},
"fringepod":{"fringepod","fringepods"},
"fringilla":{"fringilla","fringillas"},
"fringillidae":{"fringillidae","fringillidaes"},
"frippery":{"fripperies","frippery"},
"frisk":{"frisk","frisked","frisking","frisks"},
"friskiness":{"friskiness","friskinesses"},
"frisking":{"frisking","friskings"},
"frisky":{"friskier","friskiest","frisky"},
"frisson":{"frisson","frissons"},
"frit":{"frit","frits","fritted","fritting"},
"fritillaria":{"fritillaria","fritillarias"},
"fritillary":{"fritillaries","fritillary"},
"fritt":{"fritt","fritted","fritting","fritts"},
"fritter":{"fritter","frittered","frittering","fritters"},
"frivol":{"frivol","frivoled","frivoling","frivolled","frivolling","frivols"},
"frivolity":{"frivolities","frivolity"},
"frivolousness":{"frivolousness","frivolousnesses"},
"frizz":{"frizz","frizzed","frizzing","frizzs"},
"frizzle":{"frizzle","frizzled","frizzles","frizzling"},
"frizzly":{"frizzlier","frizzliest","frizzly"},
"frizzy":{"frizzier","frizziest","frizzy"},
"frock":{"frock","frocks"},
"froelichia":{"froelichia","froelichias"},
"frog":{"frog","frogs"},
"frogbit":{"frogbit","frogbits"},
"frogeye":{"frogeye","frogeyes"},
"frogfish":{"frogfish","frogfishes"},
"froggy":{"froggies","froggy"},
"frogman":{"frogman","frogmen"},
"frogs":{"frogs","frogses"},
"frolic":{"frolic","frolicked","frolicking","frolics"},
"frolicsomeness":{"frolicsomeness","frolicsomenesses"},
"frons":{"frons","frontes"},
"front":{"front","fronted","fronting","fronts"},
"front-runner":{"front-runner","front-runners"},
"frontage":{"frontage","frontages"},
"frontal":{"frontal","frontals"},
"frontier":{"frontier","frontiers"},
"frontiersman":{"frontiersman","frontiersmen"},
"frontlet":{"frontlet","frontlets"},
"frontstall":{"frontstall","frontstalls"},
"frost":{"frost","frosted","frosting","frosts"},
"frostbite":{"frostbit","frostbite","frostbites","frostbiting","frostbitten"},
"frostiness":{"frostiness","frostinesses"},
"frosting":{"frosting","frostings"},
"frostweed":{"frostweed","frostweeds"},
"frostwort":{"frostwort","frostworts"},
"frosty":{"frostier","frostiest","frosty"},
"froth":{"froth","frothed","frothing","froths"},
"frothiness":{"frothiness","frothinesses"},
"frothy":{"frothier","frothiest","frothy"},
"frouzy":{"frouzier","frouziest","frouzy"},
"frown":{"frown","frowned","frowning","frowns"},
"frowsty":{"frowstier","frowstiest","frowsty"},
"frowsy":{"frowsier","frowsiest","frowsy"},
"frowzy":{"frowzier","frowziest","frowzy"},
"frozen":{"freezing","froze","frozen"},
"fructify":{"fructified","fructifies","fructify","fructifying"},
"fructose":{"fructose","fructoses"},
"frugality":{"frugalities","frugality"},
"frugalness":{"frugalness","frugalnesses"},
"fruit":{"fruit","fruited","fruiting","fruits"},
"fruitcake":{"fruitcake","fruitcakes"},
"fruitfulness":{"fruitfulness","fruitfulnesses"},
"fruition":{"fruition","fruitions"},
"fruitlessness":{"fruitlessness","fruitlessnesses"},
"fruity":{"fruitier","fruitiest","fruity"},
"frump":{"frump","frumps"},
"frumpy":{"frumpier","frumpiest","frumpy"},
"frunze":{"frunze","frunzes"},
"frustrate":{"frustrate","frustrated","frustrates","frustrating"},
"frustrating":{"frustrating","frustratings"},
"frustration":{"frustration","frustrations"},
"frustum":{"frusta","frustum","frustums"},
"fry":{"fried","fries","fry","frying"},
"fryer":{"fryer","fryers"},
"frying":{"frying","fryings"},
"frypan":{"frypan","frypans"},
"fsb":{"fsb","fsbs"},
"fsh":{"fsh","fshes"},
"ft":{"ft","fts"},
"ft-l":{"ft-l","ft-ls"},
"fthm":{"fthm","fthms"},
"ftp":{"ftp","ftps"},
"fubsy":{"fubsier","fubsiest","fubsy"},
"fucaceae":{"fucaceae","fucaceaes"},
"fucales":{"fucales","fucaleses"},
"fuchsia":{"fuchsia","fuchsias"},
"fuck":{"fuck","fucked","fucking","fucks"},
"fuckhead":{"fuckhead","fuckheads"},
"fucking":{"fucking","fuckings"},
"fuckup":{"fuckup","fuckups"},
"fucoid":{"fucoid","fucoids"},
"fucus":{"fuci","fucus","fucuses"},
"fuddle":{"fuddle","fuddled","fuddles","fuddling"},
"fuddy-duddy":{"fuddy-duddies","fuddy-duddy"},
"fudge":{"fudge","fudged","fudges","fudging"},
"fuel":{"fuel","fueled","fueling","fuelled","fuelling","fuels"},
"fueling":{"fueling","fuelings"},
"fug":{"fug","fugged","fugging"},
"fugaciousness":{"fugaciousness","fugaciousnesses"},
"fugacity":{"fugacities","fugacity"},
"fugio":{"fugio","fugios"},
"fugitive":{"fugitive","fugitives"},
"fugle":{"fugle","fugled","fugling"},
"fugleman":{"fugleman","fuglemen"},
"fugu":{"fugu","fugus"},
"fuji":{"fuji","fujis"},
"fuji-san":{"fuji-san","fuji-sans"},
"fujiyama":{"fujiyama","fujiyamas"},
"fukien":{"fukien","fukiens"},
"fukkianese":{"fukkianese","fukkianeses"},
"fula":{"fula","fulas"},
"fulah":{"fulah","fulahs"},
"fulani":{"fulani","fulanis"},
"fulcrum":{"fulcra","fulcrum","fulcrums"},
"fulfil":{"fulfil","fulfilled","fulfilling","fulfils"},
"fulfill":{"fulfill","fulfilled","fulfilling","fulfills"},
"fulfillment":{"fulfillment","fulfillments"},
"fulfilment":{"fulfilment","fulfilments"},
"fulgoridae":{"fulgoridae","fulgoridaes"},
"fulgurate":{"fulgurate","fulgurated","fulgurating"},
"fulica":{"fulica","fulicas"},
"full":{"full","fulled","fuller","fullest","fulling"},
"full-of-the-moon":{"full-of-the-moon","full-of-the-moons"},
"fullness":{"fullness","fullnesses"},
"fulmar":{"fulmar","fulmars"},
"fulmarus":{"fulmarus","fulmaruses"},
"fulminate":{"fulminate","fulminated","fulminates","fulminating"},
"fulmination":{"fulmination","fulminations"},
"fulsomeness":{"fulsomeness","fulsomenesses"},
"fulton":{"fulton","fultons"},
"fumaria":{"fumaria","fumarias"},
"fumariaceae":{"fumariaceae","fumariaceaes"},
"fumatorium":{"fumatoria","fumatorium","fumatoriums"},
"fumatory":{"fumatories","fumatory"},
"fumble":{"fumble","fumbled","fumbles","fumbling"},
"fumbler":{"fumbler","fumblers"},
"fume":{"fume","fumed","fumes","fuming"},
"fumeroot":{"fumeroot","fumeroots"},
"fumes":{"fumes","fumeses"},
"fumewort":{"fumewort","fumeworts"},
"fumigate":{"fumigate","fumigated","fumigates","fumigating"},
"fumitory":{"fumitories","fumitory"},
"fumy":{"fumier","fumiest","fumy"},
"fun":{"fun","funned","funner","funnest","funning","funs"},
"function":{"function","functioned","functioning","functions"},
"functionary":{"functionaries","functionary"},
"functioning":{"functioning","functionings"},
"fund":{"fund","funded","funding","funds"},
"fundament":{"fundament","fundaments"},
"fundamental":{"fundamental","fundamentals"},
"fundamentals":{"fundamentals","fundamentalses"},
"funding":{"funding","fundings"},
"funds":{"funds","fundses"},
"fundulus":{"fundulus","funduluses"},
"fundus":{"fundi","fundus"},
"funeral":{"funeral","funerals"},
"funeral-residence":{"funeral-residence","funeral-residences"},
"funfair":{"funfair","funfairs"},
"fungi":{"fungi","fungis"},
"fungia":{"fungia","fungias"},
"fungo":{"fungo","fungoes"},
"fungus":{"fungi","fungus","funguses"},
"funicle":{"funicle","funicles"},
"funicular":{"funicular","funiculars"},
"funiculus":{"funiculus","funiculuses"},
"funk":{"funk","funked","funking","funks"},
"funka":{"funka","funkas"},
"funkaceae":{"funkaceae","funkaceaes"},
"funky":{"funkier","funkiest","funky"},
"funnel":{"funnel","funneled","funneling","funnelled","funnelling","funnels"},
"funniness":{"funniness","funninesses"},
"funny":{"funnier","funnies","funniest","funny"},
"funnyman":{"funnyman","funnymen"},
"fur":{"fur","furred","furring","furs"},
"furan":{"furan","furans"},
"furane":{"furane","furanes"},
"furbelow":{"furbelow","furbelowed","furbelowing","furbelows"},
"furbish":{"furbish","furbished","furbishes","furbishing"},
"furcate":{"furcate","furcated","furcating"},
"furcation":{"furcation","furcations"},
"furcula":{"furcula","furculae"},
"furculum":{"furcula","furculum"},
"furfur":{"furfur","furfures"},
"furfural":{"furfural","furfurals"},
"furfuraldehyde":{"furfuraldehyde","furfuraldehydes"},
"furfuran":{"furfuran","furfurans"},
"furies":{"furies","furieses"},
"furiousness":{"furiousness","furiousnesses"},
"furl":{"furl","furled","furling","furls"},
"furlong":{"furlong","furlongs"},
"furlough":{"furlough","furloughed","furloughing","furloughs"},
"furnace":{"furnace","furnaces"},
"furnariidae":{"furnariidae","furnariidaes"},
"furnarius":{"furnarius","furnariuses"},
"furnish":{"furnish","furnished","furnishes","furnishing"},
"furnishings":{"furnishings","furnishingses"},
"furniture":{"furniture","furnitures"},
"furor":{"furor","furors"},
"furore":{"furore","furores"},
"furrier":{"furrier","furriers"},
"furriery":{"furrieries","furriery"},
"furring":{"furring","furrings"},
"furrow":{"furrow","furrowed","furrowing","furrows"},
"furry":{"furrier","furriest","furry"},
"further":{"further","furthered","furthering","furthers"},
"furtherance":{"furtherance","furtherances"},
"furtiveness":{"furtiveness","furtivenesses"},
"furuncle":{"furuncle","furuncles"},
"fury":{"furies","fury"},
"furze":{"furze","furzes"},
"fusain":{"fusain","fusains"},
"fusanus":{"fusanus","fusanuses"},
"fuscoboletinus":{"fuscoboletinus","fuscoboletinuses"},
"fuse":{"fuse","fused","fuses","fusing"},
"fusee":{"fusee","fusees"},
"fusillade":{"fusillade","fusilladed","fusillades","fusillading"},
"fusion":{"fusion","fusions"},
"fusionist":{"fusionist","fusionists"},
"fuss":{"fuss","fussed","fusses","fussing"},
"fuss-budget":{"fuss-budget","fuss-budgets"},
"fussiness":{"fussiness","fussinesses"},
"fusspot":{"fusspot","fusspots"},
"fussy":{"fussier","fussiest","fussy"},
"fustian":{"fustian","fustians"},
"fustigate":{"fustigate","fustigated","fustigating"},
"fusty":{"fustier","fustiest","fusty"},
"futility":{"futilities","futility"},
"future":{"future","futures"},
"futurist":{"futurist","futurists"},
"futurity":{"futurities","futurity"},
"fuze":{"fuze","fuzes"},
"fuzee":{"fuzee","fuzees"},
"fuzz":{"fuzz","fuzzed","fuzzes","fuzzing","fuzzs"},
"fuzziness":{"fuzziness","fuzzinesses"},
"fuzzy":{"fuzzier","fuzziest","fuzzy"},
"fuzzy-wuzzy":{"fuzzy-wuzzies","fuzzy-wuzzy"},
"g":{"g","gs"},
"g-jo":{"g-jo","g-jos"},
"g-man":{"g-man","g-men"},
"g-string":{"g-string","g-strings"},
"ga":{"ga","gas"},
"gab":{"gab","gabbed","gabbing","gabs"},
"gaba":{"gaba","gabas"},
"gabardine":{"gabardine","gabardines"},
"gabble":{"gabble","gabbled","gabbles","gabbling"},
"gabbro":{"gabbro","gabbros"},
"gabby":{"gabbier","gabbiest","gabby"},
"gaberdine":{"gaberdine","gaberdines"},
"gabfest":{"gabfest","gabfests"},
"gable":{"gable","gables"},
"gabon":{"gabon","gabons"},
"gaborone":{"gaborone","gaborones"},
"gabun":{"gabun","gabuns"},
"gaby":{"gabies","gaby"},
"gad":{"gad","gadded","gadding","gads"},
"gadabout":{"gadabout","gadabouts"},
"gadfly":{"gadflies","gadfly"},
"gadget":{"gadget","gadgets"},
"gadidae":{"gadidae","gadidaes"},
"gadiformes":{"gadiformes","gadiformeses"},
"gadoid":{"gadoid","gadoids"},
"gadolinite":{"gadolinite","gadolinites"},
"gadolinium":{"gadolinium","gadoliniums"},
"gadus":{"gadus","gaduses"},
"gadwall":{"gadwall","gadwalls"},
"gaea":{"gaea","gaeas"},
"gaelic":{"gaelic","gaelics"},
"gaff":{"gaff","gaffed","gaffing"},
"gaffe":{"gaffe","gaffes"},
"gaffer":{"gaffer","gaffers"},
"gaffsail":{"gaffsail","gaffsails"},
"gag":{"gag","gagged","gagging","gags"},
"gage":{"gage","gaged","gages","gaging"},
"gaggle":{"gaggle","gaggled","gaggling"},
"gagman":{"gagman","gagmen"},
"gagster":{"gagster","gagsters"},
"gagwriter":{"gagwriter","gagwriters"},
"gaia":{"gaia","gaias"},
"gaiety":{"gaieties","gaiety"},
"gain":{"gain","gained","gaining","gains"},
"gainer":{"gainer","gainers"},
"gainsay":{"gainsaid","gainsay","gainsaying","gainsays"},
"gainsborough":{"gainsborough","gainsboroughs"},
"gait":{"gait","gaits"},
"gaiter":{"gaiter","gaiters"},
"gal":{"gal","gals"},
"gala":{"gala","galas"},
"galactose":{"galactose","galactoses"},
"galago":{"galago","galagos"},
"galahad":{"galahad","galahads"},
"galangal":{"galangal","galangals"},
"galapagos":{"galapagos","galapagoses"},
"galavant":{"galavant","galavanted","galavanting"},
"galax":{"galax","galaxes"},
"galaxy":{"galaxies","galaxy"},
"galbanum":{"galbanum","galbanums"},
"galbulidae":{"galbulidae","galbulidaes"},
"gale":{"gale","gales"},
"galea":{"galea","galeae"},
"galega":{"galega","galegas"},
"galeocerdo":{"galeocerdo","galeocerdos"},
"galeopsis":{"galeopses","galeopsis"},
"galeorhinus":{"galeorhinus","galeorhinuses"},
"galeras":{"galeras","galerases"},
"galere":{"galere","galeres"},
"galibi":{"galibi","galibis"},
"galilean":{"galilean","galileans"},
"galileo":{"galileo","galileos"},
"galingale":{"galingale","galingales"},
"galium":{"galium","galiums"},
"gall":{"gall","galled","galling","galls"},
"galla":{"galla","gallas"},
"gallant":{"gallant","gallanted","gallanting","gallants"},
"gallantry":{"gallantries","gallantry"},
"gallberry":{"gallberries","gallberry"},
"galleria":{"galleria","gallerias"},
"gallery":{"galleries","gallery"},
"galley":{"galley","galleys"},
"gallfly":{"gallflies","gallfly"},
"gallia":{"gallia","gallias"},
"gallicize":{"gallicize","gallicized","gallicizing"},
"galliformes":{"galliformes","galliformeses"},
"gallimaufry":{"gallimaufries","gallimaufry"},
"gallina":{"gallina","gallinas"},
"gallinaceon":{"gallinaceon","gallinaceons"},
"gallinago":{"gallinago","gallinagos"},
"gallinula":{"gallinula","gallinulas"},
"gallinule":{"gallinule","gallinules"},
"gallirallus":{"gallirallus","galliralluses"},
"gallium":{"gallium","galliums"},
"gallivant":{"gallivant","gallivanted","gallivanting","gallivants"},
"gallon":{"gallon","gallons"},
"gallop":{"gallop","galloped","galloping","gallops"},
"gallous":{"gallous","gallouses"},
"gallows":{"gallows","gallowses"},
"gallowstree":{"gallowstree","gallowstrees"},
"gallstone":{"gallstone","gallstones"},
"gallus":{"gallus","galluses"},
"gally":{"gallied","gally","gallying"},
"galop":{"galop","galoped","galoping","galops"},
"galosh":{"galosh","galoshes"},
"galumph":{"galumph","galumphed","galumphing"},
"galvanism":{"galvanism","galvanisms"},
"galvanize":{"galvanize","galvanized","galvanizes","galvanizing"},
"galvanizing":{"galvanizing","galvanizings"},
"galvo":{"galvo","galvos"},
"gam":{"gam","gammed","gamming","gams"},
"gambade":{"gambade","gambades"},
"gambado":{"gambado","gambadoes","gambados"},
"gambelia":{"gambelia","gambelias"},
"gambia":{"gambia","gambias"},
"gambit":{"gambit","gambits"},
"gamble":{"gamble","gambled","gambles","gambling"},
"gambler":{"gambler","gamblers"},
"gambling":{"gambling","gamblings"},
"gamboge":{"gamboge","gamboges"},
"gambol":{"gambol","gamboled","gamboling","gambolled","gambolling","gambols"},
"gambrel":{"gambrel","gambrels"},
"gambusia":{"gambusia","gambusias"},
"game":{"game","gamed","gamer","games","gamest","gaming"},
"gameboard":{"gameboard","gameboards"},
"gamecock":{"gamecock","gamecocks"},
"gamekeeper":{"gamekeeper","gamekeepers"},
"gameness":{"gameness","gamenesses"},
"games-master":{"games-master","games-masters"},
"games-mistress":{"games-mistress","games-mistresses"},
"gametangium":{"gametangia","gametangium"},
"gamin":{"gamin","gamins"},
"gaminess":{"gaminess","gaminesses"},
"gaming":{"gaming","gamings"},
"gamma":{"gamma","gammas"},
"gammadion":{"gammadidia","gammadion"},
"gammon":{"gammon","gammons"},
"gammy":{"gammier","gammiest","gammy"},
"gamp":{"gamp","gamps"},
"gamy":{"gamier","gamiest","gamy"},
"gan":{"gan","ganned","ganning","gans"},
"ganapati":{"ganapati","ganapatis"},
"ganda":{"ganda","gandas"},
"gander":{"gander","ganders"},
"gandhi":{"gandhi","gandhis"},
"ganesa":{"ganesa","ganesas"},
"ganesh":{"ganesh","ganeshes"},
"ganesha":{"ganesha","ganeshas"},
"gang":{"gang","ganged","ganging","gangs"},
"gangboard":{"gangboard","gangboards"},
"gangdom":{"gangdom","gangdoms"},
"ganges":{"ganges","gangeses"},
"gangland":{"gangland","ganglands"},
"gangle":{"gangle","gangled","gangling"},
"ganglion":{"ganglia","gangliglia","gangliglions","ganglion","ganglions"},
"gangly":{"ganglier","gangliest","gangly"},
"gangplank":{"gangplank","gangplanks"},
"gangrene":{"gangrene","gangrened","gangrenes","gangrening"},
"gangster":{"gangster","gangsters"},
"gangway":{"gangway","gangways"},
"ganja":{"ganja","ganjas"},
"ganoid":{"ganoid","ganoids"},
"ganoidei":{"ganoidei","ganoideis"},
"ganoin":{"ganoin","ganoins"},
"ganoine":{"ganoine","ganoines"},
"gansu":{"gansu","gansus"},
"gantry":{"gantries","gantry"},
"gaol":{"gaol","gaoled","gaoling","gaols"},
"gaolbird":{"gaolbird","gaolbirds"},
"gaolbreak":{"gaolbreak","gaolbreaks"},
"gaoler":{"gaoler","gaolers"},
"gap":{"gap","gapped","gapping","gaps"},
"gape":{"gape","gaped","gapes","gaping"},
"gar":{"gar","gars"},
"garage":{"garage","garaged","garages","garaging"},
"garageman":{"garageman","garagemen"},
"garambulla":{"garambulla","garambullas"},
"garand":{"garand","garands"},
"garb":{"garb","garbed","garbing","garbs"},
"garbage":{"garbage","garbages"},
"garbageman":{"garbageman","garbagemen"},
"garbanzo":{"garbanzo","garbanzos"},
"garble":{"garble","garbled","garbles","garbling"},
"garbo":{"garbo","garbos"},
"garboard":{"garboard","garboards"},
"garboil":{"garboil","garboils"},
"garcinia":{"garcinia","garcinias"},
"garcon":{"garcon","garcons"},
"garden":{"garden","gardened","gardening","gardens"},
"gardener":{"gardener","gardeners"},
"gardenia":{"gardenia","gardenias"},
"gardening":{"gardening","gardenings"},
"garfield":{"garfield","garfields"},
"garfish":{"garfish","garfishes"},
"garganey":{"garganey","garganeys"},
"garget":{"garget","gargets"},
"gargle":{"gargle","gargled","gargles","gargling"},
"gari":{"gari","garis"},
"garibaldi":{"garibaldi","garibaldis"},
"garishness":{"garishness","garishnesses"},
"garland":{"garland","garlanded","garlanding","garlands"},
"garlic":{"garlic","garlics"},
"garment":{"garment","garmented","garmenting","garments"},
"garmentmaker":{"garmentmaker","garmentmakers"},
"garmentworker":{"garmentworker","garmentworkers"},
"garner":{"garner","garnered","garnering","garners"},
"garnet":{"garnet","garnets"},
"garnish":{"garnish","garnished","garnishes","garnishing"},
"garnishee":{"garnishee","garnisheed","garnisheeing","garnishees"},
"garnishment":{"garnishment","garnishments"},
"garotte":{"garotte","garottes"},
"garpike":{"garpike","garpikes"},
"garret":{"garret","garrets"},
"garrison":{"garrison","garrisoned","garrisoning","garrisons"},
"garrote":{"garrote","garrotes"},
"garroter":{"garroter","garroters"},
"garrotte":{"garrotte","garrottes"},
"garrotter":{"garrotter","garrotters"},
"garrulinae":{"garrulinae","garrulinaes"},
"garrulity":{"garrulities","garrulity"},
"garrulousness":{"garrulousness","garrulousnesses"},
"garrulus":{"garrulus","garruluses"},
"garter":{"garter","garters"},
"gas":{"gas","gases","gassed","gassing"},
"gasbag":{"gasbag","gasbags"},
"gascogne":{"gascogne","gascognes"},
"gasconade":{"gasconade","gasconaded","gasconades","gasconading"},
"gascony":{"gasconies","gascony"},
"gash":{"gash","gashed","gashes","gashing"},
"gashouse":{"gashouse","gashouses"},
"gasify":{"gasified","gasifies","gasify","gasifying"},
"gasman":{"gasman","gasmen"},
"gasmask":{"gasmask","gasmasks"},
"gasolene":{"gasolene","gasolenes"},
"gasoline":{"gasoline","gasolines"},
"gasometer":{"gasometer","gasometers"},
"gasp":{"gasp","gasped","gasping","gasps"},
"gassy":{"gassier","gassiest","gassy"},
"gast":{"gast","gasted","gasting"},
"gasteromycete":{"gasteromycete","gasteromycetes"},
"gasteromycetes":{"gasteromycetes","gasteromyceteses"},
"gasterophilidae":{"gasterophilidae","gasterophilidaes"},
"gasterophilus":{"gasterophilus","gasterophiluses"},
"gasteropoda":{"gasteropoda","gasteropodas"},
"gasterosteidae":{"gasterosteidae","gasterosteidaes"},
"gasterosteus":{"gasterosteus","gasterosteuses"},
"gastralgia":{"gastralgia","gastralgias"},
"gastrectomy":{"gastrectomies","gastrectomy"},
"gastroboletus":{"gastroboletus","gastroboletuses"},
"gastrocnemius":{"gastrocnemius","gastrocnemiuses"},
"gastrocybe":{"gastrocybe","gastrocybes"},
"gastroenteritis":{"gastroenteritis","gastroenteritises"},
"gastroenterostomy":{"gastroenterostomies","gastroenterostomy"},
"gastrolobium":{"gastrolobium","gastrolobiums"},
"gastromycete":{"gastromycete","gastromycetes"},
"gastromycetes":{"gastromycetes","gastromyceteses"},
"gastronome":{"gastronome","gastronomes"},
"gastrophryne":{"gastrophryne","gastrophrynes"},
"gastropod":{"gastropod","gastropods"},
"gastropoda":{"gastropoda","gastropodas"},
"gastroscopy":{"gastroscopies","gastroscopy"},
"gastrostomy":{"gastrostomies","gastrostomy"},
"gastrotomy":{"gastrotomies","gastrotomy"},
"gastrula":{"gastrula","gastrulae","gastrulas"},
"gat":{"gat","gats"},
"gate":{"gate","gated","gates","gating"},
"gateau":{"gateau","gateaux"},
"gatecrasher":{"gatecrasher","gatecrashers"},
"gatehouse":{"gatehouse","gatehouses"},
"gatekeeper":{"gatekeeper","gatekeepers"},
"gateway":{"gateway","gateways"},
"gather":{"gather","gathered","gathering","gathers"},
"gatherer":{"gatherer","gatherers"},
"gathering":{"gathering","gatherings"},
"gatt":{"gatt","gatts"},
"gaucheness":{"gaucheness","gauchenesses"},
"gaucherie":{"gaucherie","gaucheries"},
"gaucho":{"gaucho","gauchos"},
"gaud":{"gaud","gauds"},
"gaudery":{"gauderies","gaudery"},
"gaudiness":{"gaudiness","gaudinesses"},
"gaudy":{"gaudier","gaudies","gaudiest","gaudy"},
"gauffer":{"gauffer","gauffers"},
"gauge":{"gauge","gauged","gauges","gauging"},
"gauguin":{"gauguin","gauguins"},
"gaul":{"gaul","gauls"},
"gaultheria":{"gaultheria","gaultherias"},
"gaunt":{"gaunt","gaunter","gauntest"},
"gauntlet":{"gauntlet","gauntlets"},
"gauntlets":{"gauntlets","gauntletses"},
"gauntness":{"gauntness","gauntnesses"},
"gauntry":{"gauntries","gauntry"},
"gaur":{"gaur","gaurs"},
"gauss":{"gauss","gausses"},
"gaussmeter":{"gaussmeter","gaussmeters"},
"gautama":{"gautama","gautamas"},
"gauze":{"gauze","gauzes"},
"gauzy":{"gauzier","gauziest","gauzy"},
"gavel":{"gavel","gavels"},
"gavia":{"gavia","gavias"},
"gavial":{"gavial","gavials"},
"gavialidae":{"gavialidae","gavialidaes"},
"gavialis":{"gavialis","gavialises"},
"gavidae":{"gavidae","gavidaes"},
"gaviiformes":{"gaviiformes","gaviiformeses"},
"gawain":{"gawain","gawains"},
"gawk":{"gawk","gawked","gawking","gawks"},
"gawkiness":{"gawkiness","gawkinesses"},
"gawky":{"gawkier","gawkiest","gawky"},
"gawp":{"gawp","gawped","gawping","gawps"},
"gay":{"gay","gayer","gayest","gays"},
"gayal":{"gayal","gayals"},
"gayety":{"gayeties","gayety"},
"gayfeather":{"gayfeather","gayfeathers"},
"gaylussacia":{"gaylussacia","gaylussacias"},
"gayness":{"gayness","gaynesses"},
"gaywings":{"gaywings","gaywingses"},
"gaze":{"gaze","gazed","gazes","gazing"},
"gazebo":{"gazebo","gazeboes","gazebos"},
"gazella":{"gazella","gazellas"},
"gazelle":{"gazelle","gazelles"},
"gazer":{"gazer","gazers"},
"gazette":{"gazette","gazetted","gazetting"},
"gb":{"gb","gbs"},
"gc":{"gc","gcs"},
"gd":{"gd","gds"},
"gdansk":{"gdansk","gdansks"},
"gdp":{"gdp","gdps"},
"ge":{"ge","ges"},
"gean":{"gean","geans"},
"gear":{"gear","geared","gearing","gears"},
"gearbox":{"gearbox","gearboxes"},
"gearing":{"gearing","gearings"},
"gears":{"gears","gearses"},
"gearshift":{"gearshift","gearshifts"},
"gearstick":{"gearstick","gearsticks"},
"geartrain":{"geartrain","geartrains"},
"geastraceae":{"geastraceae","geastraceaes"},
"geastrum":{"geastrum","geastrums"},
"geb":{"geb","gebs"},
"gecko":{"gecko","geckoes","geckos"},
"gee":{"gee","gees"},
"geek":{"geek","geeks"},
"geezer":{"geezer","geezers"},
"gegenschein":{"gegenschein","gegenscheins"},
"gehenna":{"gehenna","gehennas"},
"geiger":{"geiger","geigers"},
"geisha":{"geisha","geishas"},
"gekkonidae":{"gekkonidae","gekkonidaes"},
"gel":{"gel","gelled","gelling","gels"},
"gelatin":{"gelatin","gelatins"},
"gelatine":{"gelatine","gelatines"},
"gelatinousness":{"gelatinousness","gelatinousnesses"},
"geld":{"geld","gelded","gelding","gelds","gelt"},
"gelechia":{"gelechia","gelechias"},
"gelechiid":{"gelechiid","gelechiids"},
"gelechiidae":{"gelechiidae","gelechiidaes"},
"gelidity":{"gelidities","gelidity"},
"gelignite":{"gelignite","gelignites"},
"gelly":{"gellies","gelly"},
"gelsemium":{"gelsemium","gelsemiums"},
"gelt":{"gelt","gelts"},
"gem":{"gem","gemmed","gemming","gems"},
"gemeinschaft":{"gemeinschaft","gemeinschaften"},
"geminate":{"geminate","geminated","geminating"},
"gemini":{"gemini","geminis"},
"gemma":{"gemma","gemmae"},
"gemmate":{"gemmate","gemmated","gemmating"},
"gemmy":{"gemmier","gemmiest","gemmy"},
"gemonil":{"gemonil","gemonils"},
"gempylidae":{"gempylidae","gempylidaes"},
"gempylus":{"gempylus","gempyluses"},
"gemsbok":{"gemsbok","gemsboks"},
"gemsbuck":{"gemsbuck","gemsbucks"},
"gemstone":{"gemstone","gemstones"},
"gen-up":{"gen-up","genned-up","genning-up","gens-up"},
"gendarme":{"gendarme","gendarmes"},
"gendarmerie":{"gendarmerie","gendarmeries"},
"gendarmery":{"gendarmeries","gendarmery"},
"gender":{"gender","gendered","gendering","genders"},
"gene-splicing":{"gene-splicing","gene-splicings"},
"genealogy":{"genealogies","genealogy"},
"general":{"general","generals"},
"generalissimo":{"generalissimo","generalissimos"},
"generalist":{"generalist","generalists"},
"generality":{"generalities","generality"},
"generalization":{"generalization","generalizations"},
"generalize":{"generalize","generalized","generalizes","generalizing"},
"generate":{"generate","generated","generates","generating"},
"generation":{"generation","generations"},
"generator":{"generator","generators"},
"generatrix":{"generatrices","generatrix"},
"generosity":{"generosities","generosity"},
"generousness":{"generousness","generousnesses"},
"genesis":{"geneses","genesis","genesises"},
"genet":{"genet","genets"},
"genetics":{"genetics","geneticses"},
"genetta":{"genetta","genettas"},
"geneva":{"geneva","genevas"},
"genevan":{"genevan","genevans"},
"geneve":{"geneve","geneves"},
"geniality":{"genialities","geniality"},
"genie":{"genie","genii"},
"genip":{"genip","genips"},
"genipap":{"genipap","genipaps"},
"genista":{"genista","genistas"},
"genitalia":{"genitalia","genitalias"},
"genitals":{"genitals","genitalses"},
"genitive":{"genitive","genitives"},
"genius":{"genii","genius","geniuses"},
"genoa":{"genoa","genoas"},
"genocide":{"genocide","genocides"},
"genotype":{"genotype","genotypes"},
"genova":{"genova","genovas"},
"genre":{"genre","genres"},
"genro":{"genro","genros"},
"gens":{"gens","genses","gentes"},
"gent":{"gent","gents"},
"genteelness":{"genteelness","genteelnesses"},
"gentiana":{"gentiana","gentianas"},
"gentianaceae":{"gentianaceae","gentianaceaes"},
"gentianales":{"gentianales","gentianaleses"},
"gentianella":{"gentianella","gentianellas"},
"gentianopsis":{"gentianopses","gentianopsis"},
"gentile":{"gentile","gentiles"},
"gentility":{"gentilities","gentility"},
"gentle":{"gentle","gentled","gentler","gentles","gentlest","gentling"},
"gentleman":{"gentleman","gentlemen"},
"gentleman-at-arms":{"gentleman-at-arms","gentlemen-at-arms"},
"gentleman-farmer":{"gentleman-farmer","gentlemen-farmers"},
"gentleness":{"gentleness","gentlenesses"},
"gentlewoman":{"gentlewoman","gentlewomen"},
"gentry":{"gentries","gentry"},
"genu":{"genu","genua","genus"},
"genuflect":{"genuflect","genuflected","genuflecting","genuflects"},
"genuflection":{"genuflection","genuflections"},
"genuflexion":{"genuflexion","genuflexions"},
"genuineness":{"genuineness","genuinenesses"},
"genus":{"genera","genus","genuses"},
"genus-fenusa":{"genus-fenusa","genus-fenusas"},
"genus-megapodius":{"genus-megapodius","genus-megapodiuses"},
"genus-milvus":{"genus-milvus","genus-milvuses"},
"genyonemus":{"genyonemus","genyonemuses"},
"geochelone":{"geochelone","geochelones"},
"geococcyx":{"geococcyx","geococcyxes"},
"geodesic":{"geodesic","geodesics"},
"geoffroea":{"geoffroea","geoffroeas"},
"geoglossaceae":{"geoglossaceae","geoglossaceaes"},
"geoglossum":{"geoglossum","geoglossums"},
"geographics":{"geographics","geographicses"},
"geography":{"geographies","geography"},
"geologist":{"geologist","geologists"},
"geologize":{"geologize","geologized","geologizing"},
"geology":{"geologies","geology"},
"geometer":{"geometer","geometers"},
"geometrician":{"geometrician","geometricians"},
"geometrid":{"geometrid","geometrids"},
"geometridae":{"geometridae","geometridaes"},
"geometrize":{"geometrize","geometrized","geometrizing"},
"geomorphology":{"geomorphologies","geomorphology"},
"geomyidae":{"geomyidae","geomyidaes"},
"geomys":{"geomys","geomyses"},
"geophilidae":{"geophilidae","geophilidaes"},
"geophilomorpha":{"geophilomorpha","geophilomorphas"},
"geophilus":{"geophilus","geophiluses"},
"geophysicist":{"geophysicist","geophysicists"},
"geophysics":{"geophysics","geophysicses"},
"george":{"george","georges"},
"georgetown":{"georgetown","georgetowns"},
"georgia":{"georgia","georgias"},
"geosphere":{"geosphere","geospheres"},
"geothlypis":{"geothlypis","geothlypises"},
"geraniaceae":{"geraniaceae","geraniaceaes"},
"geraniales":{"geraniales","geranialeses"},
"geranium":{"geranium","geraniums"},
"gerbera":{"gerbera","gerberas"},
"gerbil":{"gerbil","gerbils"},
"gerbille":{"gerbille","gerbilles"},
"gerbillinae":{"gerbillinae","gerbillinaes"},
"gerbillus":{"gerbillus","gerbilluses"},
"gerea":{"gerea","gereas"},
"gerenuk":{"gerenuk","gerenuks"},
"gerfalcon":{"gerfalcon","gerfalcons"},
"geriatrician":{"geriatrician","geriatricians"},
"geriatrics":{"geriatrics","geriatricses"},
"germ":{"germ","germed","germing","germs"},
"german":{"german","germen"},
"germanic":{"germanic","germanics"},
"germanium":{"germanium","germaniums"},
"germanize":{"germanize","germanized","germanizing"},
"germany":{"germanies","germany"},
"germen":{"germen","germens","germina"},
"germicide":{"germicide","germicides"},
"germinate":{"germinate","germinated","germinates","germinating"},
"germination":{"germination","germinations"},
"germy":{"germier","germiest","germy"},
"gerontocracy":{"gerontocracies","gerontocracy"},
"gerontologist":{"gerontologist","gerontologists"},
"gerontology":{"gerontologies","gerontology"},
"gerreidae":{"gerreidae","gerreidaes"},
"gerres":{"gerres","gerreses"},
"gerrhonotus":{"gerrhonotus","gerrhonotuses"},
"gerridae":{"gerridae","gerridaes"},
"gerrididae":{"gerrididae","gerrididaes"},
"gerris":{"gerris","gerrises"},
"gerrymander":{"gerrymander","gerrymandered","gerrymandering"},
"gerund":{"gerund","gerunds"},
"gesellschaft":{"gesellschaft","gesellschaften"},
"gesneriaceae":{"gesneriaceae","gesneriaceaes"},
"gesso":{"gesso","gessoes"},
"gestalt":{"gestalt","gestalten","gestalts"},
"gestate":{"gestate","gestated","gestates","gestating"},
"gestation":{"gestation","gestations"},
"gesticulate":{"gesticulate","gesticulated","gesticulates","gesticulating"},
"gesticulation":{"gesticulation","gesticulations"},
"gesture":{"gesture","gestured","gestures","gesturing"},
"get":{"get","gets","getting","got","gotten"},
"get-up-and-go":{"get-up-and-go","get-up-and-gos"},
"geta":{"geta","getas"},
"getaway":{"getaway","getaways"},
"getting":{"getting","gettings"},
"gettysburg":{"gettysburg","gettysburgs"},
"getup":{"getup","getups"},
"get_lost":{"gets_lost","getting_lost","get_lost","gotten_lost","got_lost"},
"get_started":{"gets_started","getting_started","get_started","got_started"},
"geum":{"geum","geums"},
"gewgaw":{"gewgaw","gewgaws"},
"ghana":{"ghana","ghanas"},
"gharri":{"gharri","gharries"},
"gharry":{"gharries","gharry"},
"ghastliness":{"ghastliness","ghastlinesses"},
"ghastly":{"ghastlier","ghastliest","ghastly"},
"ghatti":{"ghatti","ghattis"},
"ghazi":{"ghazi","ghazis"},
"gheg":{"gheg","ghegs"},
"ghetto":{"ghetto","ghettoes","ghettos"},
"ghettoize":{"ghettoize","ghettoized","ghettoizing"},
"ghillie":{"ghillie","ghillies"},
"ghost":{"ghost","ghosted","ghosting","ghosts"},
"ghostfish":{"ghostfish","ghostfishes"},
"ghostliness":{"ghostliness","ghostlinesses"},
"ghostly":{"ghostlier","ghostliest","ghostly"},
"ghostwrite":{"ghostwrite","ghostwrites","ghostwriting","ghostwritten","ghostwrote"},
"ghostwriter":{"ghostwriter","ghostwriters"},
"ghoul":{"ghoul","ghouls"},
"ghq":{"ghq","ghqs"},
"ghz":{"ghz","ghzs"},
"gi":{"gi","gis"},
"giant":{"giant","giants"},
"giantism":{"giantism","giantisms"},
"gib":{"gib","gibbed","gibbing","gibs"},
"gibber":{"gibber","gibbered","gibbering","gibbers"},
"gibberish":{"gibberish","gibberishes"},
"gibbet":{"gibbet","gibbeted","gibbeting","gibbets"},
"gibbon":{"gibbon","gibbons"},
"gibbosity":{"gibbosities","gibbosity"},
"gibbousness":{"gibbousness","gibbousnesses"},
"gibe":{"gibe","gibed","gibes","gibing"},
"giblet":{"giblet","giblets"},
"giblets":{"giblets","gibletses"},
"gibraltar":{"gibraltar","gibraltars"},
"giddiness":{"giddiness","giddinesses"},
"giddy":{"giddied","giddier","giddies","giddiest","giddy","giddying"},
"gidgee":{"gidgee","gidgees"},
"gift":{"gift","gifted","gifting","gifts"},
"gift-wrap":{"gift-wrap","gift-wrapped","gift-wrapping"},
"giftwrap":{"giftwrap","giftwrapped","giftwrapping","giftwraps"},
"gig":{"gig","gigged","gigging","gigs"},
"gigabyte":{"gigabyte","gigabytes"},
"gigacycle":{"gigacycle","gigacycles"},
"gigahertz":{"gigahertz","gigahertzs"},
"gigantism":{"gigantism","gigantisms"},
"gigantomachia":{"gigantomachia","gigantomachias"},
"gigantomachy":{"gigantomachies","gigantomachy"},
"gigartinaceae":{"gigartinaceae","gigartinaceaes"},
"giggle":{"giggle","giggled","giggles","giggling"},
"gigolo":{"gigolo","gigolos"},
"gigot":{"gigot","gigots"},
"gila":{"gila","gilas"},
"gilbert":{"gilbert","gilberts"},
"gild":{"gild","gilded","gilding","gilds","gilt"},
"gilding":{"gilding","gildings"},
"gildsman":{"gildsman","gildsmen"},
"gildswoman":{"gildswoman","gildswomen"},
"gill":{"gill","gilled","gilling","gills"},
"gill-over-the-ground":{"gill-over-the-ground","gill-over-the-grounds"},
"gillie":{"gillie","gillies"},
"gillyflower":{"gillyflower","gillyflowers"},
"gilt":{"gilt","gilts"},
"gimcrackery":{"gimcrackeries","gimcrackery"},
"gimcracks":{"gimcracks","gimcrackses"},
"gimlet":{"gimlet","gimleted","gimleting","gimlets"},
"gimmick":{"gimmick","gimmicks"},
"gimp":{"gimp","gimps"},
"gimpiness":{"gimpiness","gimpinesses"},
"gin":{"gin","ginned","ginning","gins"},
"ginep":{"ginep","gineps"},
"ginger":{"ginger","gingered","gingering","gingers"},
"gingerroot":{"gingerroot","gingerroots"},
"gingiva":{"gingiva","gingivae","gingivas"},
"gingko":{"gingko","gingkoes"},
"ginglymostoma":{"ginglymostoma","ginglymostomas"},
"ginglymus":{"ginglymi","ginglymus","ginglymuses"},
"ginkgo":{"ginkgo","ginkgoes","ginkgos"},
"ginkgoaceae":{"ginkgoaceae","ginkgoaceaes"},
"ginkgoales":{"ginkgoales","ginkgoaleses"},
"ginkgophyta":{"ginkgophyta","ginkgophytas"},
"ginkgophytina":{"ginkgophytina","ginkgophytinas"},
"ginkgopsida":{"ginkgopsida","ginkgopsidas"},
"ginmill":{"ginmill","ginmills"},
"ginseng":{"ginseng","ginsengs"},
"ginzo":{"ginzo","ginzoes"},
"gip":{"gip","gipped","gipping","gips"},
"gippo":{"gippo","gippoes"},
"gippy":{"gippies","gippy"},
"gipsy":{"gipsies","gipsy"},
"gipsywort":{"gipsywort","gipsyworts"},
"giraffa":{"giraffa","giraffas"},
"giraffe":{"giraffe","giraffes"},
"giraffidae":{"giraffidae","giraffidaes"},
"girandola":{"girandola","girandolas"},
"girandole":{"girandole","girandoles"},
"girasol":{"girasol","girasols"},
"gird":{"gird","girded","girding","girds","girt"},
"girder":{"girder","girders"},
"girdle":{"girdle","girdled","girdles","girdling"},
"girl":{"girl","girls"},
"girlfriend":{"girlfriend","girlfriends"},
"girlhood":{"girlhood","girlhoods"},
"giro":{"giro","giros"},
"girth":{"girth","girthed","girthing","girths"},
"gismo":{"gismo","gismos"},
"gist":{"gist","gists"},
"give":{"gave","give","given","gives","giving"},
"give-and-take":{"give-and-take","give-and-takes"},
"giveaway":{"giveaway","giveaways"},
"given":{"given","givens"},
"giver":{"giver","givers"},
"giving":{"giving","givings"},
"giza":{"giza","gizas"},
"gizmo":{"gizmo","gizmos"},
"gizzard":{"gizzard","gizzards"},
"glabella":{"glabella","glabellae"},
"glace":{"glace","glaceed","glaceing","glaces"},
"glaciate":{"glaciate","glaciated","glaciating"},
"glacier":{"glacier","glaciers"},
"glacis":{"glacis","glacises"},
"glad":{"glad","gladded","gladder","gladdest","gladding"},
"glad-hand":{"glad-hand","glad-handed","glad-handing"},
"gladden":{"gladden","gladdened","gladdening","gladdens"},
"gladdon":{"gladdon","gladdons"},
"glade":{"glade","glades"},
"gladfulness":{"gladfulness","gladfulnesses"},
"gladiator":{"gladiator","gladiators"},
"gladiola":{"gladiola","gladiolas"},
"gladiolus":{"gladioli","gladiolus","gladioluses"},
"gladness":{"gladness","gladnesses"},
"gladsomeness":{"gladsomeness","gladsomenesses"},
"gladstone":{"gladstone","gladstones"},
"glair":{"glair","glaired","glairing"},
"glairy":{"glairier","glairiest","glairy"},
"glamor":{"glamor","glamors"},
"glamorize":{"glamorize","glamorized","glamorizes","glamorizing"},
"glamour":{"glamour","glamoured","glamouring","glamours"},
"glance":{"glance","glanced","glances","glancing"},
"gland":{"gland","glands"},
"glans":{"glandes","glans"},
"glare":{"glare","glared","glares","glaring"},
"glareola":{"glareola","glareolas"},
"glareole":{"glareole","glareoles"},
"glareolidae":{"glareolidae","glareolidaes"},
"glary":{"glarier","glariest","glary"},
"glass":{"glass","glassed","glasses","glassing"},
"glasscutter":{"glasscutter","glasscutters"},
"glassful":{"glassful","glassfuls"},
"glasshouse":{"glasshouse","glasshouses"},
"glassman":{"glassman","glassmen"},
"glassware":{"glassware","glasswares"},
"glasswork":{"glasswork","glassworks"},
"glassworker":{"glassworker","glassworkers"},
"glasswort":{"glasswort","glassworts"},
"glassy":{"glassier","glassiest","glassy"},
"glaucium":{"glaucium","glauciums"},
"glaucomys":{"glaucomys","glaucomyses"},
"glaux":{"glaux","glauxes"},
"glaze":{"glaze","glazed","glazes","glazing"},
"glazer":{"glazer","glazers"},
"glazier":{"glazier","glaziers"},
"gleam":{"gleam","gleamed","gleaming","gleams"},
"gleaming":{"gleaming","gleamings"},
"gleamy":{"gleamier","gleamiest","gleamy"},
"glean":{"glean","gleaned","gleaning","gleans"},
"gleba":{"gleba","glebae"},
"glechoma":{"glechoma","glechomas"},
"gleditsia":{"gleditsia","gleditsias"},
"glee":{"glee","glees"},
"gleefulness":{"gleefulness","gleefulnesses"},
"gleeman":{"gleeman","gleemen"},
"gleet":{"gleet","gleeted","gleeting","gleets"},
"gleichenia":{"gleichenia","gleichenias"},
"gleicheniaceae":{"gleicheniaceae","gleicheniaceaes"},
"glen":{"glen","glens"},
"glengarry":{"glengarries","glengarry"},
"glenn":{"glenn","glenns"},
"glia":{"glia","glias"},
"glib":{"glib","glibber","glibbest"},
"glibness":{"glibness","glibnesses"},
"glide":{"glide","glided","glides","gliding"},
"glider":{"glider","gliders"},
"gliding":{"gliding","glidings"},
"glimmer":{"glimmer","glimmered","glimmering","glimmers"},
"glimpse":{"glimpse","glimpsed","glimpses","glimpsing"},
"glint":{"glint","glinted","glinting","glints"},
"glioma":{"glioma","gliomas","gliomata"},
"gliridae":{"gliridae","gliridaes"},
"glis":{"glis","glises"},
"glissade":{"glissade","glissaded","glissading"},
"glissando":{"glissandi","glissando","glissandos"},
"glisten":{"glisten","glistened","glistening","glistens"},
"glister":{"glister","glistered","glistering","glisters"},
"glitch":{"glitch","glitches"},
"glitter":{"glitter","glittered","glittering","glitters"},
"glitz":{"glitz","glitzs"},
"gloaming":{"gloaming","gloamings"},
"gloat":{"gloat","gloated","gloating","gloats"},
"gloating":{"gloating","gloatings"},
"glob":{"glob","globs"},
"globalize":{"globalize","globalized","globalizing"},
"globe":{"globe","globed","globes","globing"},
"globefish":{"globefish","globefishes"},
"globeflower":{"globeflower","globeflowers"},
"globetrot":{"globetrot","globetrots","globetrotted","globetrotting"},
"globetrotter":{"globetrotter","globetrotters"},
"globicephala":{"globicephala","globicephalas"},
"globigerina":{"globigerina","globigerinae","globigerinas"},
"globigerinidae":{"globigerinidae","globigerinidaes"},
"globosity":{"globosities","globosity"},
"globularness":{"globularness","globularnesses"},
"glochidium":{"glochidchidia","glochidium"},
"glockenspiel":{"glockenspiel","glockenspiels"},
"glom":{"glom","glommed","glomming","gloms"},
"glomerulus":{"glomeruli","glomerulus"},
"gloom":{"gloom","gloomed","glooming","glooms"},
"gloominess":{"gloominess","gloominesses"},
"gloomy":{"gloomier","gloomiest","gloomy"},
"glop":{"glop","glopped","glopping","glops"},
"glorification":{"glorification","glorifications"},
"glorify":{"glorified","glorifies","glorify","glorifying"},
"gloriosa":{"gloriosa","gloriosas"},
"glory":{"gloried","glories","glory","glorying"},
"gloss":{"gloss","glossed","glosses","glossing"},
"glossa":{"glossa","glossae","glossas"},
"glossary":{"glossaries","glossary"},
"glossectomy":{"glossectomies","glossectomy"},
"glossina":{"glossina","glossinas"},
"glossiness":{"glossiness","glossinesses"},
"glossinidae":{"glossinidae","glossinidaes"},
"glossodia":{"glossodia","glossodias"},
"glossopsitta":{"glossopsitta","glossopsittas"},
"glossy":{"glossier","glossies","glossiest","glossy"},
"glottis":{"glottides","glottis","glottises"},
"glove":{"glove","gloved","gloves","gloving"},
"gloves":{"gloves","gloveses"},
"glow":{"glow","glowed","glowing","glows"},
"glower":{"glower","glowered","glowering","glowers"},
"glowing":{"glowing","glowings"},
"gloze":{"gloze","glozed","glozing"},
"glucinium":{"glucinium","gluciniums"},
"glue":{"glue","glued","glues","gluing"},
"gluey":{"gluey","gluier","gluiest"},
"glueyness":{"glueyness","glueynesses"},
"gluiness":{"gluiness","gluinesses"},
"glum":{"glum","glummer","glummest"},
"glumness":{"glumness","glumnesses"},
"glut":{"glut","gluts","glutted","glutting"},
"glutaeus":{"glutaei","glutaeus"},
"gluteus":{"glutei","gluteus","gluteuses"},
"glutinosity":{"glutinosities","glutinosity"},
"glutinousness":{"glutinousness","glutinousnesses"},
"glutton":{"glutton","gluttons"},
"gluttony":{"gluttonies","gluttony"},
"glyburide":{"glyburide","glyburides"},
"glyceraldehyde":{"glyceraldehyde","glyceraldehydes"},
"glyceria":{"glyceria","glycerias"},
"glycerin":{"glycerin","glycerins"},
"glycerine":{"glycerine","glycerines"},
"glycerite":{"glycerite","glycerites"},
"glycerogel":{"glycerogel","glycerogels"},
"glycerogelatin":{"glycerogelatin","glycerogelatins"},
"glycerol":{"glycerol","glycerols"},
"glycerole":{"glycerole","glyceroles"},
"glycine":{"glycine","glycines"},
"glycogen":{"glycogen","glycogens"},
"glycol":{"glycol","glycols"},
"glycyrrhiza":{"glycyrrhiza","glycyrrhizas"},
"glyoxaline":{"glyoxaline","glyoxalines"},
"glyptics":{"glyptics","glypticses"},
"glyptography":{"glyptographies","glyptography"},
"gm":{"gm","gms"},
"gmt":{"gmt","gmts"},
"gnaphalium":{"gnaphalium","gnaphaliums"},
"gnar":{"gnar","gnarred","gnarring"},
"gnarl":{"gnarl","gnarls"},
"gnash":{"gnash","gnashed","gnashing"},
"gnat":{"gnat","gnats"},
"gnathostomata":{"gnathostomata","gnathostomatas"},
"gnaw":{"gnaw","gnawed","gnawing","gnawn","gnaws"},
"gnawer":{"gnawer","gnawers"},
"gnawing":{"gnawing","gnawings"},
"gnetaceae":{"gnetaceae","gnetaceaes"},
"gnetales":{"gnetales","gnetaleses"},
"gnetophyta":{"gnetophyta","gnetophytas"},
"gnetophytina":{"gnetophytina","gnetophytinas"},
"gnetopsida":{"gnetopsida","gnetopsidas"},
"gnetum":{"gnetum","gnetums"},
"gnome":{"gnome","gnomes"},
"gnosis":{"gnoses","gnosis"},
"gnp":{"gnp","gnps"},
"gnu":{"gnu","gnus"},
"go":{"go","goes","going","gone","gos","went"},
"go-ahead":{"go-ahead","go-aheads"},
"go-around":{"go-around","go-arounds"},
"go-between":{"go-between","go-betweens"},
"go-cart":{"go-cart","go-carts"},
"go-getter":{"go-getter","go-getters"},
"goad":{"goad","goaded","goading","goads"},
"goading":{"goading","goadings"},
"goal":{"goal","goaled","goaling","goals"},
"goalie":{"goalie","goalies"},
"goalkeeper":{"goalkeeper","goalkeepers"},
"goaltender":{"goaltender","goaltenders"},
"goat":{"goat","goats"},
"goatfish":{"goatfish","goatfishes"},
"goatherd":{"goatherd","goatherds"},
"goatherder":{"goatherder","goatherders"},
"goatsbeard":{"goatsbeard","goatsbeards"},
"goatsfoot":{"goatsfeet","goatsfoot"},
"goatsucker":{"goatsucker","goatsuckers"},
"gob":{"gob","gobs"},
"gobble":{"gobble","gobbled","gobbles","gobbling"},
"gobbler":{"gobbler","gobblers"},
"gobi":{"gobi","gobis"},
"gobiesocidae":{"gobiesocidae","gobiesocidaes"},
"gobiesox":{"gobiesox","gobiesoxes"},
"gobiidae":{"gobiidae","gobiidaes"},
"gobio":{"gobio","gobios"},
"goblet":{"goblet","goblets"},
"goblin":{"goblin","goblins"},
"gobo":{"gobo","goboes","gobos"},
"gobs":{"gobs","gobses"},
"goby":{"gobies","goby"},
"god":{"god","gods"},
"godchild":{"godchild","godchildren"},
"goddess":{"goddess","goddesses"},
"godfather":{"godfather","godfathers"},
"godhead":{"godhead","godheads"},
"godiva":{"godiva","godivas"},
"godlessness":{"godlessness","godlessnesses"},
"godly":{"godlier","godliest","godly"},
"godmother":{"godmother","godmothers"},
"godsend":{"godsend","godsends"},
"goer":{"goer","goers"},
"goeteborg":{"goeteborg","goeteborgs"},
"goethe":{"goethe","goethes"},
"goethite":{"goethite","goethites"},
"goffer":{"goffer","goffered","goffering","goffers"},
"goggle":{"goggle","goggled","goggles","goggling"},
"goggle-eye":{"goggle-eye","goggle-eyes"},
"goidelic":{"goidelic","goidelics"},
"going":{"going","goings"},
"going-over":{"going-over","going-overs","goings-over"},
"goiter":{"goiter","goiters"},
"goitre":{"goitre","goitres"},
"gold":{"gold","golds"},
"goldbrick":{"goldbrick","goldbricked","goldbricking","goldbricks"},
"goldbricking":{"goldbricking","goldbrickings"},
"goldcrest":{"goldcrest","goldcrests"},
"goldcup":{"goldcup","goldcups"},
"goldeneye":{"goldeneye","goldeneyes"},
"goldenseal":{"goldenseal","goldenseals"},
"goldeye":{"goldeye","goldeyes"},
"goldfields":{"goldfields","goldfieldses"},
"goldfinch":{"goldfinch","goldfinches"},
"goldfish":{"goldfish","goldfishes"},
"goldilocks":{"goldilocks","goldilockses"},
"goldmine":{"goldmine","goldmines"},
"goldsmith":{"goldsmith","goldsmiths"},
"goldthread":{"goldthread","goldthreads"},
"goldworker":{"goldworker","goldworkers"},
"golem":{"golem","golems"},
"golf":{"golf","golfed","golfing","golfs"},
"golfcart":{"golfcart","golfcarts"},
"golfclub":{"golfclub","golfclubs"},
"golfer":{"golfer","golfers"},
"golgotha":{"golgotha","golgothas"},
"goliath":{"goliath","goliaths"},
"golliwog":{"golliwog","golliwogs"},
"golliwogg":{"golliwogg","golliwoggs"},
"golly":{"gollied","gollies","golly","gollying"},
"golosh":{"golosh","goloshes"},
"gombo":{"gombo","gombos"},
"gomorrah":{"gomorrah","gomorrahs"},
"gomorrha":{"gomorrha","gomorrhas"},
"gomphosis":{"gomphoses","gomphosis"},
"gomphotheriidae":{"gomphotheriidae","gomphotheriidaes"},
"gomphotherium":{"gomphotherium","gomphotheriums"},
"gomphrena":{"gomphrena","gomphrenas"},
"gomuti":{"gomuti","gomutis"},
"gonad":{"gonad","gonads"},
"gonadotropin":{"gonadotropin","gonadotropins"},
"gondola":{"gondola","gondolas"},
"gondolier":{"gondolier","gondoliers"},
"gondoliere":{"gondoliere","gondolieres"},
"gong":{"gong","gongs"},
"gonidium":{"gonidiia","gonidium"},
"gonion":{"goninia","gonion"},
"goniopteris":{"goniopteris","goniopterises"},
"gonococcus":{"gonococci","gonococcus","gonococcuses"},
"gonorhynchidae":{"gonorhynchidae","gonorhynchidaes"},
"gonorhynchus":{"gonorhynchus","gonorhynchuses"},
"gonorrhea":{"gonorrhea","gonorrheas"},
"gonorrhoea":{"gonorrhoea","gonorrhoeas"},
"goo":{"goo","goos"},
"goober":{"goober","goobers"},
"good":{"best","better","good","goods"},
"good-by":{"good-bies","good-by","good-bys"},
"good-bye":{"good-bye","good-byes"},
"good-for-naught":{"good-for-naught","good-for-naughts"},
"good-for-nothing":{"good-for-nothing","good-for-nothings"},
"good-humoredness":{"good-humoredness","good-humorednesses"},
"good-king-henry":{"good-king-henries","good-king-henry"},
"good-neighborliness":{"good-neighborliness","good-neighborlinesses"},
"good-neighbourliness":{"good-neighbourliness","good-neighbourlinesses"},
"good-temperedness":{"good-temperedness","good-temperednesses"},
"goodby":{"goodbies","goodby"},
"goodbye":{"goodbye","goodbyes"},
"goodly":{"goodlier","goodliest","goodly"},
"goodman":{"goodman","goodmen"},
"goodness":{"goodness","goodnesses"},
"goodwife":{"goodwife","goodwives"},
"goodwill":{"goodwill","goodwills"},
"goody":{"goodies","goody"},
"goody-goody":{"goody-goodies","goody-goody"},
"goodyera":{"goodyera","goodyeras"},
"gooey":{"gooey","gooier","gooiest"},
"goof":{"goof","goofed","goofing","goofs","gooves"},
"goof-off":{"goof-off","goof-offs"},
"goofy":{"goofier","goofiest","goofy"},
"googly":{"googlies","googly"},
"gook":{"gook","gooks"},
"goon":{"goon","goons"},
"gooney":{"gooney","gooneys"},
"goonie":{"goonie","goonies"},
"goony":{"goonies","goony"},
"goosander":{"goosander","goosanders"},
"goose":{"geese","goose","gooses"},
"goose-step":{"goose-step","goose-stepped","goose-stepping","goose-steps"},
"goose-tansy":{"goose-tansies","goose-tansy"},
"gooseberry":{"gooseberries","gooseberry"},
"goosefish":{"goosefish","goosefishes"},
"gooseflesh":{"gooseflesh","goosefleshes"},
"goosefoot":{"goosefoot","goosefoots"},
"goosy":{"goosier","goosiest","goosy"},
"gop":{"gop","gops"},
"gopher":{"gopher","gophers"},
"gopherus":{"gopherus","gopheruses"},
"gopherwood":{"gopherwood","gopherwoods"},
"goral":{"goral","gorals"},
"gore":{"gore","gored","gores","goring"},
"gorge":{"gorge","gorged","gorges","gorging"},
"gorgerin":{"gorgerin","gorgerins"},
"gorgonacea":{"gorgonacea","gorgonaceas"},
"gorgoneion":{"gorgoneineia","gorgoneion"},
"gorgoniacea":{"gorgoniacea","gorgoniaceas"},
"gorgonian":{"gorgonian","gorgonians"},
"gorgonize":{"gorgonize","gorgonized","gorgonizing"},
"gorgonocephalus":{"gorgonocephalus","gorgonocephaluses"},
"gorilla":{"gorilla","gorillas"},
"gorki":{"gorki","gorkis"},
"gorkiy":{"gorkiy","gorkiys"},
"gorky":{"gorkies","gorky"},
"gormandize":{"gormandize","gormandized","gormandizes","gormandizing"},
"gorse":{"gorse","gorses"},
"gory":{"gorier","goriest","gory"},
"gosan-chiku":{"gosan-chiku","gosan-chikus"},
"goshawk":{"goshawk","goshawks"},
"gosmore":{"gosmore","gosmores"},
"gospel":{"gospel","gospels"},
"gospeler":{"gospeler","gospelers"},
"gospeller":{"gospeller","gospellers"},
"gospels":{"gospels","gospelses"},
"gospodin":{"gospodin","gospopoda"},
"gossamer":{"gossamer","gossamers"},
"gossip":{"gossip","gossiped","gossiping","gossips"},
"gossiper":{"gossiper","gossipers"},
"gossiping":{"gossiping","gossipings"},
"gossipmongering":{"gossipmongering","gossipmongerings"},
"gossypium":{"gossypium","gossypiums"},
"goteborg":{"goteborg","goteborgs"},
"goth":{"goth","goths"},
"gothenburg":{"gothenburg","gothenburgs"},
"gothic":{"gothic","gothics"},
"gothite":{"gothite","gothites"},
"gotterdammerung":{"gotterdammerung","gotterdammerungs"},
"gouda":{"gouda","goudas"},
"gouge":{"gouge","gouged","gouges","gouging"},
"gouger":{"gouger","gougers"},
"goujon":{"goujon","goujons"},
"goulash":{"goulash","goulashes"},
"gourami":{"gourami","gouramis"},
"gourd":{"gourd","gourds"},
"gourde":{"gourde","gourdes"},
"gourmand":{"gourmand","gourmands"},
"gourmet":{"gourmet","gourmets"},
"gout":{"gout","gouts"},
"govern":{"govern","governed","governing","governs"},
"governance":{"governance","governances"},
"governess":{"governess","governesses"},
"governing":{"governing","governings"},
"government":{"government","governments"},
"governor":{"governor","governors"},
"governor_general":{"governors_general","governor_general","governor_generals"},
"gown":{"gown","gowned","gowning","gowns"},
"gownsman":{"gownsman","gownsmen"},
"goy":{"goy","goyim","goys"},
"go_deep":{"goes_deep","going_deep","gone_deep","go_deep","went_deep"},
"gp":{"gp","gps"},
"grab":{"grab","grabbed","grabbing","grabs"},
"grabber":{"grabber","grabbers"},
"grabble":{"grabble","grabbled","grabbling"},
"grabby":{"grabbier","grabbiest","grabby"},
"grace":{"grace","graced","graces","gracing"},
"gracelessness":{"gracelessness","gracelessnesses"},
"gracilariid":{"gracilariid","gracilariids"},
"gracilariidae":{"gracilariidae","gracilariidaes"},
"gracility":{"gracilities","gracility"},
"gracillariidae":{"gracillariidae","gracillariidaes"},
"gracioso":{"gracioso","graciosos"},
"graciousness":{"graciousness","graciousnesses"},
"grackle":{"grackle","grackles"},
"gracula":{"gracula","graculas"},
"grad":{"grad","grads"},
"gradate":{"gradate","gradated","gradating"},
"gradation":{"gradation","gradations"},
"grade":{"grade","graded","grades","grading"},
"gradely":{"gradelier","gradeliest","gradely"},
"gradient":{"gradient","gradients"},
"grading":{"grading","gradings"},
"graduality":{"gradualities","graduality"},
"gradualness":{"gradualness","gradualnesses"},
"graduate":{"graduate","graduated","graduates","graduating"},
"graduation":{"graduation","graduations"},
"gradus":{"gradus","graduses"},
"graecophile":{"graecophile","graecophiles"},
"graf":{"graf","grafen"},
"graffiti":{"graffiti","graffitis"},
"graffito":{"graffiti","graffito"},
"graft":{"graft","grafted","grafting","grafts"},
"grafting":{"grafting","graftings"},
"graham":{"graham","grahams"},
"grail":{"grail","grails"},
"grain":{"grain","grained","graining","grains"},
"graininess":{"graininess","graininesses"},
"graining":{"graining","grainings"},
"grainy":{"grainier","grainiest","grainy"},
"gram":{"gram","grams"},
"grama":{"grama","gramas"},
"graminaceae":{"graminaceae","graminaceaes"},
"graminales":{"graminales","graminaleses"},
"gramineae":{"gramineae","gramineaes"},
"gramma":{"gramma","grammas"},
"grammar":{"grammar","grammars"},
"grammarian":{"grammarian","grammarians"},
"grammatolatry":{"grammatolatries","grammatolatry"},
"grammatophyllum":{"grammatophyllum","grammatophyllums"},
"gramme":{"gramme","grammes"},
"grammy":{"grammies","grammy","grammys"},
"gramophone":{"gramophone","gramophones"},
"gramps":{"gramps","grampses"},
"grampus":{"grampus","grampuses"},
"granadilla":{"granadilla","granadillas"},
"granadillo":{"granadillo","granadillos"},
"granary":{"granaries","granary"},
"grand":{"grand","grander","grandest","grands"},
"grandad":{"grandad","grandads"},
"grandaunt":{"grandaunt","grandaunts"},
"grandchild":{"grandchild","grandchildren"},
"granddad":{"granddad","granddads"},
"granddaddy":{"granddaddies","granddaddy"},
"granddaughter":{"granddaughter","granddaughters"},
"grandee":{"grandee","grandees"},
"grandeur":{"grandeur","grandeurs"},
"grandfather":{"grandfather","grandfathered","grandfathering","grandfathers"},
"grandiloquence":{"grandiloquence","grandiloquences"},
"grandiosity":{"grandiosities","grandiosity"},
"grandma":{"grandma","grandmas"},
"grandmother":{"grandmother","grandmothers"},
"grandnephew":{"grandnephew","grandnephews"},
"grandness":{"grandness","grandnesses"},
"grandniece":{"grandniece","grandnieces"},
"grandpa":{"grandpa","grandpas"},
"grandparent":{"grandparent","grandparents"},
"grandson":{"grandson","grandsons"},
"grandstand":{"grandstand","grandstanded","grandstanding","grandstands"},
"granduncle":{"granduncle","granduncles"},
"grange":{"grange","granges"},
"granger":{"granger","grangers"},
"granicus":{"granicus","granicuses"},
"grannie":{"grannie","grannies"},
"granny":{"grannies","granny"},
"grant":{"grant","granted","granting","grants"},
"grant-in-aid":{"grant-in-aid","grants-in-aid"},
"granularity":{"granularities","granularity"},
"granulate":{"granulate","granulated","granulates","granulating"},
"granulation":{"granulation","granulations"},
"granulocytopenia":{"granulocytopenia","granulocytopenias"},
"granuloma":{"granuloma","granulomas","granulomata"},
"granum":{"grana","granum"},
"grape":{"grape","grapes"},
"grapefruit":{"grapefruit","grapefruits"},
"grapevine":{"grapevine","grapevines"},
"graph":{"graph","graphed","graphing","graphs"},
"grapheme":{"grapheme","graphemes"},
"graphics":{"graphics","graphicses"},
"graphite":{"graphite","graphites"},
"graphologist":{"graphologist","graphologists"},
"grapnel":{"grapnel","grapnels"},
"grapple":{"grapple","grappled","grapples","grappling"},
"grappler":{"grappler","grapplers"},
"grappling":{"grappling","grapplings"},
"graptophyllum":{"graptophyllum","graptophyllums"},
"grasp":{"grasp","grasped","grasping","grasps"},
"grasping":{"grasping","graspings"},
"grass":{"grass","grassed","grasses","grassing"},
"grass-of-parnassus":{"grass-of-parnassus","grass-of-parnassuses"},
"grassfinch":{"grassfinch","grassfinches"},
"grasshopper":{"grasshopper","grasshoppered","grasshoppering","grasshoppers"},
"grassy":{"grassier","grassiest","grassy"},
"grate":{"grate","grated","grates","grating"},
"gratefulness":{"gratefulness","gratefulnesses"},
"grater":{"grater","graters"},
"graticule":{"graticule","graticules"},
"gratification":{"gratification","gratifications"},
"gratify":{"gratified","gratifies","gratify","gratifying"},
"grating":{"grating","gratings"},
"gratuity":{"gratuities","gratuity"},
"gratulate":{"gratulate","gratulated","gratulating"},
"gravamen":{"gravamen","gravamina","gravavamina"},
"grave":{"grave","graved","graven","graver","graves","gravest","graving"},
"gravel":{"gravel","graveled","graveling","gravelled","gravelling","gravels"},
"gravelweed":{"gravelweed","gravelweeds"},
"graveness":{"graveness","gravenesses"},
"graverobber":{"graverobber","graverobbers"},
"gravestone":{"gravestone","gravestones"},
"graveyard":{"graveyard","graveyards"},
"gravida":{"gravida","gravidae","gravidas"},
"gravidity":{"gravidities","gravidity"},
"gravidness":{"gravidness","gravidnesses"},
"gravimeter":{"gravimeter","gravimeters"},
"gravimetry":{"gravimetries","gravimetry"},
"gravitate":{"gravitate","gravitated","gravitating"},
"gravitation":{"gravitation","gravitations"},
"gravity":{"gravities","gravity"},
"gravure":{"gravure","gravures"},
"gravy":{"gravies","gravy"},
"gray":{"gray","grayed","grayer","grayest","graying","grays"},
"grayback":{"grayback","graybacks"},
"graybeard":{"graybeard","graybeards"},
"grayhen":{"grayhen","grayhens"},
"graylag":{"graylag","graylags"},
"grayling":{"grayling","graylings"},
"grayness":{"grayness","graynesses"},
"graze":{"graze","grazed","grazes","grazing"},
"grazer":{"grazer","grazers"},
"grazing":{"grazing","grazings"},
"grease":{"grease","greased","greases","greasing"},
"grease-gun":{"grease-gun","grease-guns"},
"greaseball":{"greaseball","greaseballs"},
"greaser":{"greaser","greasers"},
"greasewood":{"greasewood","greasewoods"},
"greasiness":{"greasiness","greasinesses"},
"greasy":{"greasier","greasiest","greasy"},
"great":{"great","greater","greatest","greats"},
"great-aunt":{"great-aunt","great-aunts"},
"great-grandchild":{"great-grandchild","great-grandchildren"},
"great-nephew":{"great-nephew","great-nephews"},
"great-niece":{"great-niece","great-nieces"},
"great-uncle":{"great-uncle","great-uncles"},
"greatcoat":{"greatcoat","greatcoats"},
"greaten":{"greaten","greatened","greatening"},
"greatness":{"greatness","greatnesses"},
"greave":{"greave","greaves"},
"greaves":{"greaves","greaveses"},
"gree":{"gree","greed","greeing","grees"},
"greece":{"greece","greeces"},
"greed":{"greed","greeds"},
"greediness":{"greediness","greedinesses"},
"greedy":{"greedier","greediest","greedy"},
"greegree":{"greegree","greegrees"},
"greek":{"greek","greeks"},
"green":{"green","greened","greener","greenest","greening","greens"},
"green-blindness":{"green-blindness","green-blindnesses"},
"greenback":{"greenback","greenbacks"},
"greenbelt":{"greenbelt","greenbelts"},
"greenbottle":{"greenbottle","greenbottles"},
"greenbrier":{"greenbrier","greenbriers"},
"greenery":{"greeneries","greenery"},
"greenfly":{"greenflies","greenfly"},
"greengage":{"greengage","greengages"},
"greengrocer":{"greengrocer","greengrocers"},
"greengrocery":{"greengroceries","greengrocery"},
"greenhood":{"greenhood","greenhoods"},
"greenhorn":{"greenhorn","greenhorns"},
"greenhouse":{"greenhouse","greenhouses"},
"greening":{"greening","greenings"},
"greenland":{"greenland","greenlands"},
"greenmarket":{"greenmarket","greenmarkets"},
"greenness":{"greenness","greennesses"},
"greenockite":{"greenockite","greenockites"},
"greens":{"greens","greenses"},
"greenshank":{"greenshank","greenshanks"},
"greensickness":{"greensickness","greensicknesses"},
"greensward":{"greensward","greenswards"},
"greenway":{"greenway","greenways"},
"greenweed":{"greenweed","greenweeds"},
"greenwing":{"greenwing","greenwings"},
"greet":{"greet","greeted","greeting","greets"},
"greeting":{"greeting","greetings"},
"gregarinida":{"gregarinida","gregarinidas"},
"gregory":{"gregories","gregory"},
"gremlin":{"gremlin","gremlins"},
"grenadier":{"grenadier","grenadiers"},
"gres-gris":{"gres-gris","gres-grises"},
"grewia":{"grewia","grewias"},
"grey":{"grey","greyed","greyer","greyest","greying","greys"},
"greybeard":{"greybeard","greybeards"},
"greyhound":{"greyhound","greyhounds"},
"greylag":{"greylag","greylags"},
"greyness":{"greyness","greynesses"},
"gri-gri":{"gri-gri","gri-gris"},
"grias":{"grias","griases"},
"grid":{"grid","grids"},
"griddle":{"griddle","griddled","griddling"},
"griddlecake":{"griddlecake","griddlecakes"},
"gride":{"gride","grided","griding"},
"gridiron":{"gridiron","gridirons"},
"grief":{"grief","griefs","grieves"},
"grievance":{"grievance","grievances"},
"grieve":{"grieve","grieved","grieves","grieving"},
"griever":{"griever","grievers"},
"griffin":{"griffin","griffins"},
"griffon":{"griffon","griffons"},
"grift":{"grift","grifted","grifting"},
"grigri":{"grigri","grigris"},
"grikwa":{"grikwa","grikwas"},
"grill":{"grill","grilled","grilling","grills"},
"grille":{"grille","grilles"},
"grilling":{"grilling","grillings"},
"grillroom":{"grillroom","grillrooms"},
"grillwork":{"grillwork","grillworks"},
"grilse":{"grilse","grilses"},
"grim":{"grim","grimmer","grimmest"},
"grimace":{"grimace","grimaced","grimaces","grimacing"},
"grime":{"grime","grimed","grimes","griming"},
"griminess":{"griminess","griminesses"},
"grimm":{"grimm","grimms"},
"grimness":{"grimness","grimnesses"},
"grimy":{"grimier","grimiest","grimy"},
"grin":{"grin","grinned","grinning","grins"},
"grind":{"grind","grinding","grinds","ground","grounds"},
"grindelia":{"grindelia","grindelias"},
"grinder":{"grinder","grinders"},
"grindery":{"grinderies","grindery"},
"grinding":{"grinding","grindings"},
"grindle":{"grindle","grindles"},
"grindstone":{"grindstone","grindstones"},
"gringo":{"gringo","gringos"},
"grinning":{"grinning","grinnings"},
"grip":{"grip","gripped","gripping","grips"},
"gripe":{"gripe","griped","gripes","griping"},
"grippe":{"grippe","grippes"},
"griqua":{"griqua","griquas"},
"gris-gris":{"grig-gris","gris-gris"},
"griselinia":{"griselinia","griselinias"},
"grisly":{"grislier","grislies","grisliest","grisly"},
"grison":{"grison","grisons"},
"gristle":{"gristle","gristles"},
"gristly":{"gristlier","gristliest","gristly"},
"grit":{"grit","grits","gritted","gritting"},
"gritrock":{"gritrock","gritrocks"},
"grits":{"grits","gritses"},
"gritstone":{"gritstone","gritstones"},
"gritty":{"grittier","grittiest","gritty"},
"grivet":{"grivet","grivets"},
"grizzle":{"grizzle","grizzled","grizzles","grizzling"},
"grizzly":{"grizzlier","grizzlies","grizzliest","grizzly"},
"groan":{"groan","groaned","groaning","groans"},
"groat":{"groat","groats"},
"grocery":{"groceries","grocery"},
"groenlandia":{"groenlandia","groenlandias"},
"grogginess":{"grogginess","grogginesses"},
"groggy":{"groggier","groggiest","groggy"},
"groin":{"groin","groined","groining","groins"},
"grommet":{"grommet","grommets"},
"gromwell":{"gromwell","gromwells"},
"groom":{"groom","groomed","grooming","grooms"},
"groom-to-be":{"groom-to-be","groom-to-bes"},
"grooming":{"grooming","groomings"},
"groomsman":{"groomsman","groomsmen"},
"groove":{"groove","grooved","grooves","grooving"},
"grooving":{"grooving","groovings"},
"groovy":{"groovier","grooviest","groovy"},
"grope":{"grope","groped","gropes","groping"},
"gropius":{"gropius","gropiuses"},
"grosbeak":{"grosbeak","grosbeaks"},
"gross":{"gross","grossed","grosser","grosses","grossest","grossing"},
"grossbeak":{"grossbeak","grossbeaks"},
"grossness":{"grossness","grossnesses"},
"grossulariaceae":{"grossulariaceae","grossulariaceaes"},
"grosz":{"grosz","groszy"},
"grot":{"grot","grots"},
"grotesque":{"grotesque","grotesques"},
"grotesqueness":{"grotesqueness","grotesquenesses"},
"grotesquerie":{"grotesquerie","grotesqueries"},
"grotesquery":{"grotesqueries","grotesquery"},
"grotto":{"grotto","grottoes","grottos"},
"grotty":{"grottier","grottiest","grotty"},
"grouch":{"grouch","grouched","grouches","grouching"},
"grouchy":{"grouchier","grouchiest","grouchy"},
"ground":{"ground","grounded","grounding","grounds"},
"ground-shaker":{"ground-shaker","ground-shakers"},
"groundberry":{"groundberries","groundberry"},
"groundbreaking":{"groundbreaking","groundbreakings"},
"groundcover":{"groundcover","groundcovers"},
"grounder":{"grounder","grounders"},
"groundfish":{"groundfish","groundfishes"},
"groundhog":{"groundhog","groundhogs"},
"grounding":{"grounding","groundings"},
"groundnut":{"groundnut","groundnuts"},
"grounds":{"grounds","groundses"},
"groundsel":{"groundsel","groundsels"},
"groundsheet":{"groundsheet","groundsheets"},
"groundskeeper":{"groundskeeper","groundskeepers"},
"groundsman":{"groundsman","groundsmen"},
"groundwork":{"groundwork","groundworks"},
"group":{"group","grouped","grouping","groups"},
"grouper":{"grouper","groupers"},
"grouping":{"grouping","groupings"},
"grouse":{"grouse","groused","grouses","grousing"},
"grouseberry":{"grouseberries","grouseberry"},
"grout":{"grout","grouted","grouting"},
"grouty":{"groutier","groutiest","grouty"},
"grove":{"grove","groves"},
"grovel":{"grovel","groveled","groveling","grovelled","grovelling","grovels"},
"groveller":{"groveller","grovellers"},
"grow":{"grew","grow","growing","grown","grows"},
"grower":{"grower","growers"},
"growing":{"growing","growings"},
"growl":{"growl","growled","growling","growls"},
"growling":{"growling","growlings"},
"grown-up":{"grown-up","grown-ups"},
"grownup":{"grownup","grownups"},
"growth":{"growth","growths"},
"groyne":{"groyne","groynes"},
"grub":{"grub","grubbed","grubbing","grubs"},
"grubbiness":{"grubbiness","grubbinesses"},
"grubby":{"grubbier","grubbies","grubbiest","grubby"},
"grubstake":{"grubstake","grubstaked","grubstaking"},
"grudge":{"grudge","grudged","grudges","grudging"},
"gruesomeness":{"gruesomeness","gruesomenesses"},
"gruff":{"gruff","gruffer","gruffest"},
"gruffness":{"gruffness","gruffnesses"},
"grugru":{"grugru","grugrus"},
"gruidae":{"gruidae","gruidaes"},
"gruiformes":{"gruiformes","gruiformeses"},
"grumble":{"grumble","grumbled","grumbles","grumbling"},
"grumbler":{"grumbler","grumblers"},
"grumbling":{"grumbling","grumblings"},
"grump":{"grump","grumped","grumping","grumps"},
"grumpiness":{"grumpiness","grumpinesses"},
"grumpy":{"grumpier","grumpiest","grumpy"},
"grundyism":{"grundyism","grundyisms"},
"grunt":{"grunt","grunted","grunting","grunts"},
"grus":{"grus","gruses"},
"gryllidae":{"gryllidae","gryllidaes"},
"gryoplane":{"gryoplane","gryoplanes"},
"gryphon":{"gryphon","gryphons"},
"guacharo":{"guacharo","guacharos"},
"guaco":{"guaco","guacos"},
"guadalcanal":{"guadalcanal","guadalcanals"},
"guaiac":{"guaiac","guaiacs"},
"guaiacum":{"guaiacum","guaiacums"},
"guaira":{"guaira","guairas"},
"guama":{"guama","guamas"},
"guanabana":{"guanabana","guanabanas"},
"guanaco":{"guanaco","guanacos"},
"guangzhou":{"guangzhou","guangzhous"},
"guano":{"guano","guanos"},
"guar":{"guar","guars"},
"guarani":{"guarani","guaranis"},
"guarantee":{"guarantee","guaranteed","guaranteeing","guarantees"},
"guarantor":{"guarantor","guarantors"},
"guaranty":{"guarantied","guaranties","guaranty","guarantying"},
"guard":{"guard","guarded","guarding","guards"},
"guardhouse":{"guardhouse","guardhouses"},
"guardian":{"guardian","guardians"},
"guardianship":{"guardianship","guardianships"},
"guarding":{"guarding","guardings"},
"guardrail":{"guardrail","guardrails"},
"guardsman":{"guardsman","guardsmen"},
"guava":{"guava","guavas"},
"guayule":{"guayule","guayules"},
"gubbins":{"gubbins","gubbinses"},
"guck":{"guck","gucks"},
"gudgeon":{"gudgeon","gudgeons"},
"guenevere":{"guenevere","gueneveres"},
"guenon":{"guenon","guenons"},
"guerdon":{"guerdon","guerdoned","guerdoning"},
"guereza":{"guereza","guerezas"},
"guerilla":{"guerilla","guerillas"},
"guernsey":{"guernsey","guernseys"},
"guerrilla":{"guerrilla","guerrillas"},
"guess":{"guess","guessed","guesses","guessing"},
"guessing":{"guessing","guessings"},
"guesstimate":{"guesstimate","guesstimated","guesstimates","guesstimating"},
"guesswork":{"guesswork","guessworks"},
"guest":{"guest","guested","guesting","guests"},
"guesthouse":{"guesthouse","guesthouses"},
"guestimate":{"guestimate","guestimates"},
"guevina":{"guevina","guevinas"},
"guff":{"guff","guffs"},
"guffaw":{"guffaw","guffawed","guffawing","guffaws"},
"guggle":{"guggle","guggled","guggles","guggling"},
"gui":{"gui","guis"},
"guib":{"guib","guibs"},
"guidance":{"guidance","guidances"},
"guide":{"guide","guided","guides","guiding"},
"guidebook":{"guidebook","guidebooks"},
"guideline":{"guideline","guidelines"},
"guidepost":{"guidepost","guideposts"},
"guiding":{"guiding","guidings"},
"guild":{"guild","guilds"},
"guilde":{"guilde","guilder","guilders"},
"guilder":{"guilder","guilders"},
"guildsman":{"guildsman","guildsmen"},
"guile":{"guile","guiles"},
"guillotine":{"guillotine","guillotined","guillotines","guillotining"},
"guilt":{"guilt","guilts"},
"guiltiness":{"guiltiness","guiltinesses"},
"guiltlessness":{"guiltlessness","guiltlessnesses"},
"guilty":{"guiltier","guiltiest","guilty"},
"guine-bissau":{"guine-bissau","guine-bissaus"},
"guinea":{"guinea","guineas"},
"guinea-bissau":{"guinea-bissau","guinea-bissaus"},
"guinevere":{"guinevere","guineveres"},
"guipure":{"guipure","guipures"},
"guise":{"guise","guises"},
"guitar":{"guitar","guitars"},
"guitarfish":{"guitarfish","guitarfishes"},
"guitarist":{"guitarist","guitarists"},
"gujarat":{"gujarat","gujarats"},
"gujarati":{"gujarati","gujaratis"},
"gujerat":{"gujerat","gujerats"},
"gujerati":{"gujerati","gujeratis"},
"gula":{"gula","gulas"},
"gulch":{"gulch","gulches"},
"gulden":{"gulden","guldens"},
"gulf":{"gulf","gulfed","gulfing","gulfs"},
"gulfweed":{"gulfweed","gulfweeds"},
"gull":{"gull","gulled","gulling","gulls"},
"gullah":{"gullah","gullahs"},
"gullet":{"gullet","gullets"},
"gullibility":{"gullibilities","gullibility"},
"gully":{"gullied","gullies","gully","gullying"},
"gulo":{"gulo","gulos"},
"gulp":{"gulp","gulped","gulping","gulps"},
"gulping":{"gulping","gulpings"},
"gulyas":{"gulyas","gulyases"},
"gum":{"gum","gummed","gumming","gums"},
"gumbo":{"gumbo","gumbos"},
"gumbo-limbo":{"gumbo-limbo","gumbo-limbos"},
"gumma":{"gumma","gummas","gummata"},
"gumminess":{"gumminess","gumminesses"},
"gumming":{"gumming","gummings"},
"gummosis":{"gummoses","gummosis"},
"gummy":{"gummier","gummiest","gummy"},
"gumption":{"gumption","gumptions"},
"gumshield":{"gumshield","gumshields"},
"gumshoe":{"gumshoe","gumshoed","gumshoeing","gumshoes"},
"gumweed":{"gumweed","gumweeds"},
"gumwood":{"gumwood","gumwoods"},
"gun":{"gun","gunned","gunning","guns"},
"gunboat":{"gunboat","gunboats"},
"gunfight":{"gunfight","gunfights"},
"gunfire":{"gunfire","gunfires"},
"gunk":{"gunk","gunks"},
"gunlock":{"gunlock","gunlocks"},
"gunman":{"gunman","gunmen"},
"gunnel":{"gunnel","gunnels"},
"gunner":{"gunner","gunners"},
"gunny":{"gunnies","gunny"},
"gunnysack":{"gunnysack","gunnysacks"},
"gunplay":{"gunplay","gunplays"},
"gunpoint":{"gunpoint","gunpoints"},
"gunpowder":{"gunpowder","gunpowders"},
"gunrunner":{"gunrunner","gunrunners"},
"gunshot":{"gunshot","gunshots"},
"gunslinger":{"gunslinger","gunslingers"},
"gunstock":{"gunstock","gunstocks"},
"gunwale":{"gunwale","gunwales"},
"guppy":{"guppies","guppy"},
"gur":{"gur","gurs"},
"gurgle":{"gurgle","gurgled","gurgles","gurgling"},
"gurkha":{"gurkha","gurkhas"},
"gurnar":{"gurnar","gurnard"},
"gurnard":{"gurnard","gurnards"},
"gurnet":{"gurnet","gurnets"},
"guru":{"guru","gurus"},
"gush":{"gush","gushed","gushes","gushing"},
"gusher":{"gusher","gushers"},
"gushy":{"gushier","gushiest","gushy"},
"gusset":{"gusset","gussets"},
"gussy":{"gussied","gussy","gussying"},
"gust":{"gust","gusted","gusting","gusts"},
"gustation":{"gustation","gustations"},
"gusto":{"gusto","gustoes"},
"gusty":{"gustier","gustiest","gusty"},
"gut":{"gut","guts","gutted","gutting"},
"gutierrezia":{"gutierrezia","gutierrezias"},
"guts":{"guts","gutses"},
"gutsiness":{"gutsiness","gutsinesses"},
"gutsy":{"gutsier","gutsiest","gutsy"},
"gutta":{"gutta","guttae"},
"gutter":{"gutter","guttered","guttering","gutters"},
"guttersnipe":{"guttersnipe","guttersnipes"},
"guttiferae":{"guttiferae","guttiferaes"},
"guttiferales":{"guttiferales","guttiferaleses"},
"guttural":{"guttural","gutturals"},
"gutturalize":{"gutturalize","gutturalized","gutturalizing"},
"gutty":{"guttier","gutties","guttiest","gutty"},
"guy":{"guy","guyed","guying","guys"},
"guyana":{"guyana","guyanas"},
"guzzle":{"guzzle","guzzled","guzzling"},
"guzzling":{"guzzling","guzzlings"},
"gym":{"gym","gyms"},
"gymkhana":{"gymkhana","gymkhanas"},
"gymnadenia":{"gymnadenia","gymnadenias"},
"gymnadeniopsis":{"gymnadeniopses","gymnadeniopsis"},
"gymnasium":{"gymnasia","gymnasium","gymnasiums"},
"gymnelis":{"gymnelis","gymnelises"},
"gymnocalycium":{"gymnocalycium","gymnocalyciums"},
"gymnocarpium":{"gymnocarpium","gymnocarpiums"},
"gymnocladus":{"gymnocladus","gymnocladuses"},
"gymnogyps":{"gymnogyps","gymnogypses"},
"gymnomycota":{"gymnomycota","gymnomycotas"},
"gymnophiona":{"gymnophiona","gymnophionas"},
"gymnopilus":{"gymnopilus","gymnopiluses"},
"gymnorhina":{"gymnorhina","gymnorhinas"},
"gymnospermae":{"gymnospermae","gymnospermaes"},
"gymnospermophyta":{"gymnospermophyta","gymnospermophytas"},
"gymnosporangium":{"gymnosporangium","gymnosporangiums"},
"gymnura":{"gymnura","gymnuras"},
"gynaeceum":{"gynaecea","gynaeceum"},
"gynaecium":{"gynaecia","gynaecium"},
"gynaecocracy":{"gynaecocracies","gynaecocracy"},
"gynaecologist":{"gynaecologist","gynaecologists"},
"gynaecology":{"gynaecologies","gynaecology"},
"gynaeolatry":{"gynaeolatries","gynaeolatry"},
"gynandromorph":{"gynandromorph","gynandromorphs"},
"gynarchy":{"gynarchies","gynarchy"},
"gynecium":{"gynecea","gynecia","gynecium"},
"gynecocracy":{"gynaecocracies","gynecocracies","gynecocracy"},
"gynecologist":{"gynecologist","gynecologists"},
"gynecology":{"gynecologies","gynecology"},
"gyneolatry":{"gyneolatries","gyneolatry"},
"gynoecium":{"gynoecia","gynoecium","gynoeciums"},
"gynura":{"gynura","gynuras"},
"gyp":{"gyp","gypped","gypping","gyps"},
"gypaetus":{"gypaetus","gypaetuses"},
"gyps":{"gyps","gypses"},
"gypsophila":{"gypsophila","gypsophilas"},
"gypsy":{"gypsies","gypsy"},
"gypsyweed":{"gypsyweed","gypsyweeds"},
"gypsywort":{"gypsywort","gypsyworts"},
"gyrate":{"gyrate","gyrated","gyrates","gyrating"},
"gyration":{"gyration","gyrations"},
"gyre":{"gyre","gyres"},
"gyrfalcon":{"gyrfalcon","gyrfalcons"},
"gyrinidae":{"gyrinidae","gyrinidaes"},
"gyro":{"gyro","gyros"},
"gyroscope":{"gyroscope","gyroscopes"},
"gyrus":{"gyri","gyrus","gyruses"},
"gyve":{"gyve","gyved","gyving"},
"h":{"h","hs"},
"h-bomb":{"h-bomb","h-bombs"},
"h2o":{"h2o","h2os"},
"ha":{"ha","has"},
"ha'penny":{"ha'pennies","ha'penny"},
"ha-ha":{"ha-ha","ha-has"},
"haastia":{"haastia","haastias"},
"habanera":{"habanera","habaneras"},
"habanero":{"habanero","habaneros"},
"habenaria":{"habenaria","habenarias"},
"haberdasher":{"haberdasher","haberdashers"},
"haberdashery":{"haberdasheries","haberdashery"},
"habiliment":{"habiliment","habiliments"},
"habilitate":{"habilitate","habilitated","habilitates","habilitating"},
"habit":{"habit","habits"},
"habitant":{"habitant","habitants"},
"habitat":{"habitat","habitats"},
"habitation":{"habitation","habitations"},
"habituate":{"habituate","habituated","habituates","habituating"},
"habitue":{"habitue","habitues"},
"habsburg":{"habsburg","habsburgs"},
"hacek":{"hacek","haceks"},
"hachure":{"hachure","hachures"},
"hacienda":{"hacienda","haciendas"},
"hack":{"hack","hacked","hacking","hacks"},
"hackamore":{"hackamore","hackamores"},
"hackberry":{"hackberries","hackberry"},
"hackbut":{"hackbut","hackbuts"},
"hackdriver":{"hackdriver","hackdrivers"},
"hackee":{"hackee","hackees"},
"hackelia":{"hackelia","hackelias"},
"hacker":{"hacker","hackers"},
"hackle":{"hackle","hackled","hackles","hackling"},
"hackles":{"hackles","hackleses"},
"hackman":{"hackman","hackmen"},
"hackmatack":{"hackmatack","hackmatacks"},
"hackney":{"hackney","hackneyed","hackneying","hackneys"},
"hacksaw":{"hacksaw","hacksaws"},
"haddock":{"haddock","haddocks"},
"hades":{"hades","hadeses"},
"hadj":{"hadj","hadjs"},
"hadji":{"hadji","hadjis"},
"hadrosaur":{"hadrosaur","hadrosaurs"},
"hadrosauridae":{"hadrosauridae","hadrosauridaes"},
"hadrosaurus":{"hadrosaurus","hadrosauruses"},
"haecceity":{"haecceities","haecceity"},
"haem":{"haem","haems"},
"haemangioma":{"haemangioma","haemangiomas"},
"haemanthus":{"haemanthus","haemanthuses"},
"haematite":{"haematite","haematites"},
"haematobia":{"haematobia","haematobias"},
"haematologist":{"haematologist","haematologists"},
"haematology":{"haematologies","haematology"},
"haematolysis":{"haematolyses","haematolysis"},
"haematoma":{"haematoma","haematomas"},
"haematopodidae":{"haematopodidae","haematopodidaes"},
"haematopus":{"haematopus","haematopuses"},
"haematoxylon":{"haematoxylon","haematoxylons"},
"haematoxylum":{"haematoxylum","haematoxylums"},
"haematozoon":{"haematozoon","haematozozoa"},
"haemodialysis":{"haemodialyses","haemodialysis"},
"haemodoraceae":{"haemodoraceae","haemodoraceaes"},
"haemodorum":{"haemodorum","haemodorums"},
"haemoglobin":{"haemoglobin","haemoglobins"},
"haemoglobinopathy":{"haemoglobinopathies","haemoglobinopathy"},
"haemolysis":{"haemolyses","haemolysis"},
"haemophile":{"haemophile","haemophiles"},
"haemophilia":{"haemophilia","haemophilias"},
"haemophiliac":{"haemophiliac","haemophiliacs"},
"haemopis":{"haemopis","haemopises"},
"haemoproteidae":{"haemoproteidae","haemoproteidaes"},
"haemoproteus":{"haemoproteus","haemoproteuses"},
"haemoptysis":{"haemoptyses","haemoptysis"},
"haemorrhage":{"haemorrhage","haemorrhages"},
"haemorrhoidectomy":{"haemorrhoidectomies","haemorrhoidectomy"},
"haemosporidia":{"haemosporidia","haemosporidias"},
"haemostat":{"haemostat","haemostats"},
"haemulidae":{"haemulidae","haemulidaes"},
"haemulon":{"haemulon","haemulons"},
"haeres":{"haeredes","haeres"},
"hafnium":{"hafnium","hafniums"},
"haft":{"haft","hafted","hafting","hafts"},
"haftarah":{"haftarah","haftarahs","haftaroth"},
"hag":{"hag","hags"},
"hagbut":{"hagbut","hagbuts"},
"hagfish":{"hagfish","hagfishes"},
"haggada":{"haggada","haggadas","haggadoth"},
"haggadah":{"haggadah","haggadahs","haggadas"},
"haggard":{"haggard","haggards"},
"haggle":{"haggle","haggled","haggles","haggling"},
"haggling":{"haggling","hagglings"},
"hagiarchy":{"hagiarchies","hagiarchy"},
"hagiocracy":{"hagiocracies","hagiocracy"},
"hagiographa":{"hagiographa","hagiographas"},
"hagiography":{"hagiographies","hagiography"},
"hagiolatry":{"hagiolatries","hagiolatry"},
"hagiology":{"hagiologies","hagiology"},
"hahnium":{"hahnium","hahniums"},
"haida":{"haida","haidas"},
"hail":{"hail","hailed","hailing","hails"},
"hailstone":{"hailstone","hailstones"},
"hair":{"hair","hairs"},
"hairball":{"hairball","hairballs"},
"hairbreadth":{"hairbreadth","hairbreadths"},
"haircloth":{"haircloth","haircloths"},
"hairdo":{"hairdo","hairdos"},
"hairdresser":{"hairdresser","hairdressers"},
"hairdressing":{"hairdressing","hairdressings"},
"hairlessness":{"hairlessness","hairlessnesses"},
"hairpiece":{"hairpiece","hairpieces"},
"hairsplitting":{"hairsplitting","hairsplittings"},
"hairstreak":{"hairstreak","hairstreaks"},
"hairstylist":{"hairstylist","hairstylists"},
"hairtail":{"hairtail","hairtails"},
"hairtonic":{"hairtonic","hairtonics"},
"hairy":{"hairier","hairiest","hairy"},
"haiti":{"haiti","haitis"},
"haj":{"haj","hajs"},
"haji":{"haji","hajis"},
"hajj":{"hajj","hajjs"},
"hajji":{"hajji","hajjis"},
"hake":{"hake","hakes"},
"hakea":{"hakea","hakeas"},
"hakka":{"hakka","hakkas"},
"halal":{"halal","halalled","halalling","halals"},
"haldea":{"haldea","haldeas"},
"hale":{"hale","haled","haler","halest","haling"},
"haleness":{"haleness","halenesses"},
"halenia":{"halenia","halenias"},
"haler":{"haler","halers","haleru"},
"halesia":{"halesia","halesias"},
"half":{"half","halves"},
"half-breed":{"half-breed","half-breeds"},
"half-brother":{"half-brother","half-brothers"},
"half-hour":{"half-hour","half-hours"},
"half-life":{"half-life","half-lives"},
"half-mast":{"half-mast","half-masted","half-masting"},
"half-moon":{"half-moon","half-moons"},
"half-pint":{"half-pint","half-pints"},
"half-slip":{"half-slip","half-slips"},
"half-sole":{"half-sole","half-soled","half-soles","half-soling"},
"half-truth":{"half-truth","half-truths"},
"half-wit":{"half-wit","half-wits"},
"halfback":{"halfback","halfbacks"},
"halfpenny":{"halfpence","halfpennies","halfpenny"},
"halfpennyworth":{"halfpennyworth","halfpennyworths"},
"halftone":{"halftone","halftones"},
"halfway":{"halfway","halfways"},
"haliaeetus":{"haliaeetus","haliaeetuses"},
"halibut":{"halibut","halibuts"},
"halicoeres":{"halicoeres","halicoereses"},
"halictidae":{"halictidae","halictidaes"},
"halimodendron":{"halimodendron","halimodendrons"},
"haliotidae":{"haliotidae","haliotidaes"},
"haliotis":{"haliotis","haliotises"},
"halite":{"halite","halites"},
"hall":{"hall","halls"},
"hallah":{"hallah","hallahs"},
"halliard":{"halliard","halliards"},
"hallmark":{"hallmark","hallmarked","hallmarking","hallmarks"},
"hallo":{"hallo","halloed","halloing","hallos"},
"halloa":{"halloa","halloaed","halloaing","halloas"},
"halloo":{"halloo","hallooed","hallooing","halloos"},
"hallow":{"hallow","hallowed","hallowing","hallows"},
"halloween":{"halloween","halloweens"},
"hallowmas":{"hallowmas","hallowmases"},
"hallowmass":{"hallowmass","hallowmasses"},
"hallucinate":{"hallucinate","hallucinated","hallucinating"},
"hallucinogen":{"hallucinogen","hallucinogens"},
"hallux":{"halluces","hallux"},
"hallway":{"hallway","hallways"},
"halm":{"halm","halms"},
"halo":{"halo","haloed","haloes","haloing","halos"},
"halobacter":{"halobacter","halobacters"},
"halobacteria":{"halobacteria","halobacterias"},
"halobacterium":{"halobacterium","halobacteriums"},
"halocarpus":{"halocarpus","halocarpuses"},
"halogenate":{"halogenate","halogenated","halogenates","halogenating"},
"halogeton":{"halogeton","halogetons"},
"haloragaceae":{"haloragaceae","haloragaceaes"},
"haloragidaceae":{"haloragidaceae","haloragidaceaes"},
"halt":{"halt","halted","halting","halts"},
"halter":{"halter","haltered","halteres","haltering","halters"},
"haltere":{"haltere","halteres"},
"halve":{"halve","halved","halving"},
"halyard":{"halyard","halyards"},
"ham":{"ham","hammed","hamming","hams"},
"hamadryad":{"hamadryad","hamadryades","hamadryads"},
"hamamelidaceae":{"hamamelidaceae","hamamelidaceaes"},
"hamamelidae":{"hamamelidae","hamamelidaes"},
"hamamelidanthum":{"hamamelidanthum","hamamelidanthums"},
"hamamelidoxylon":{"hamamelidoxylon","hamamelidoxylons"},
"hamamelis":{"hamamelis","hamamelises"},
"hamamelites":{"hamamelites","hamameliteses"},
"hamate":{"hamate","hamates"},
"hamburger":{"hamburger","hamburgers"},
"haminoea":{"haminoea","haminoeas"},
"hamitic":{"hamitic","hamitics"},
"hamito-semitic":{"hamito-semitic","hamito-semitics"},
"hamlet":{"hamlet","hamlets"},
"hammer":{"hammer","hammered","hammering","hammers"},
"hammerhead":{"hammerhead","hammerheads"},
"hammering":{"hammering","hammerings"},
"hamming":{"hamming","hammings"},
"hammock":{"hammock","hammocks"},
"hammy":{"hammier","hammiest","hammy"},
"hamper":{"hamper","hampered","hampering","hampers"},
"hampshire":{"hampshire","hampshires"},
"hamstring":{"hamstring","hamstringing","hamstrings","hamstrung"},
"hamulus":{"hamuli","hamulus"},
"hand":{"hand","handed","handing","hands"},
"hand-knit":{"hand-knit","hand-knits","hand-knitted","hand-knitting"},
"handbag":{"handbag","handbags"},
"handbasin":{"handbasin","handbasins"},
"handbasket":{"handbasket","handbaskets"},
"handbill":{"handbill","handbills"},
"handbook":{"handbook","handbooks"},
"handbreath":{"handbreath","handbreaths"},
"handcart":{"handcart","handcarts"},
"handclasp":{"handclasp","handclasps"},
"handcraft":{"handcraft","handcrafted","handcrafting","handcrafts"},
"handcuff":{"handcuff","handcuffed","handcuffing","handcuffs"},
"handcuffs":{"handcuffs","handcuffses"},
"handedness":{"handedness","handednesses"},
"handel":{"handel","handels"},
"handfeed":{"handfed","handfeed","handfeeding","handfeeds"},
"handful":{"handful","handfuls"},
"handgrip":{"handgrip","handgrips"},
"handgun":{"handgun","handguns"},
"handicap":{"handicap","handicapped","handicapping","handicaps"},
"handicraft":{"handicraft","handicrafts"},
"handicraftsman":{"handicraftsman","handicraftsmen"},
"handiness":{"handiness","handinesses"},
"handiwork":{"handiwork","handiworks"},
"handkerchief":{"handkerchief","handkerchiefs","handkerchieves"},
"handle":{"handle","handled","handles","handling"},
"handle-bars":{"handle-bars","handle-barses"},
"handlebar":{"handlebar","handlebars"},
"handler":{"handler","handlers"},
"handline":{"handline","handlines"},
"handling":{"handling","handlings"},
"handlock":{"handlock","handlocks"},
"handmaid":{"handmaid","handmaids"},
"handmaiden":{"handmaiden","handmaidens"},
"handout":{"handout","handouts"},
"handpick":{"handpick","handpicked","handpicking","handpicks"},
"handrail":{"handrail","handrails"},
"hands":{"hands","handses"},
"handsaw":{"handsaw","handsaws"},
"handsbreadth":{"handsbreadth","handsbreadths"},
"handsel":{"handsel","handseled","handseling","handselled","handselling","handsels"},
"handset":{"handset","handsets"},
"handshake":{"handshake","handshakes"},
"handshaking":{"handshaking","handshakings"},
"handsome":{"handsome","handsomer","handsomest"},
"handsomeness":{"handsomeness","handsomenesses"},
"handstamp":{"handstamp","handstamps"},
"handwork":{"handwork","handworks"},
"handwriting":{"handwriting","handwritings"},
"handy":{"handier","handiest","handy"},
"handyman":{"handyman","handymen"},
"hang":{"hang","hanged","hanging","hangs","hung"},
"hang-up":{"hang-up","hang-ups"},
"hangar":{"hangar","hangars"},
"hangbird":{"hangbird","hangbirds"},
"hangchow":{"hangchow","hangchows"},
"hanger-on":{"hanger-on","hanger-ons","hangers-on"},
"hanging":{"hanging","hangings"},
"hangman":{"hangman","hangmen"},
"hangnail":{"hangnail","hangnails"},
"hangout":{"hangout","hangouts"},
"hangover":{"hangover","hangovers"},
"hangzhou":{"hangzhou","hangzhous"},
"hani":{"hani","hanis"},
"hanker":{"hanker","hankered","hankering","hankers"},
"hankering":{"hankering","hankerings"},
"hankey":{"hankey","hankeys"},
"hankie":{"hankie","hankies"},
"hanky":{"hankies","hanky"},
"hannover":{"hannover","hannovers"},
"hanoi":{"hanoi","hanois"},
"hanover":{"hanover","hanovers"},
"hansel":{"hansel","hanseled","hanseling","hanselled","hanselling","hansels"},
"hansom":{"hansom","hansoms"},
"hanukah":{"hanukah","hanukahs"},
"hanukkah":{"hanukkah","hanukkahs"},
"hanuman":{"hanuman","hanumen"},
"haole":{"haole","haoles"},
"haoma":{"haoma","haomas"},
"hap":{"hap","happed","happing","haps"},
"haphazardness":{"haphazardness","haphazardnesses"},
"haphtarah":{"haphtarah","haphtarahs","haphtarot","haphtaroth","haphtatarahs","haphtataroth"},
"haplography":{"haplographies","haplography"},
"haplopappus":{"haplopappus","haplopappuses"},
"haplosporidia":{"haplosporidia","haplosporidias"},
"happen":{"happen","happened","happening","happens"},
"happening":{"happening","happenings"},
"happenstance":{"happenstance","happenstances"},
"happiness":{"happiness","happinesses"},
"happy":{"happier","happiest","happy"},
"hapsburg":{"hapsburg","hapsburgs"},
"harakiri":{"harakiri","harakiris"},
"harangue":{"harangue","harangued","harangues","haranguing"},
"harare":{"harare","harares"},
"harass":{"harass","harassed","harasses","harassing"},
"harassment":{"harassment","harassments"},
"harbinger":{"harbinger","harbingered","harbingering","harbingers"},
"harbor":{"harbor","harbored","harboring","harbors"},
"harborage":{"harborage","harborages"},
"harbour":{"harbour","harboured","harbouring","harbours"},
"harbourage":{"harbourage","harbourages"},
"hard":{"hard","harder","hardest"},
"hard-on":{"hard-on","hard-ons"},
"hardback":{"hardback","hardbacks"},
"hardboard":{"hardboard","hardboards"},
"hardcover":{"hardcover","hardcovers"},
"harden":{"harden","hardened","hardening","hardens"},
"hardenbergia":{"hardenbergia","hardenbergias"},
"hardening":{"hardening","hardenings"},
"hardheads":{"hardheads","hardheadses"},
"hardheartedness":{"hardheartedness","hardheartednesses"},
"hardihood":{"hardihood","hardihoods"},
"hardiness":{"hardiness","hardinesses"},
"harding":{"harding","hardings"},
"hardinggrass":{"hardinggrass","hardinggrasses"},
"hardness":{"hardness","hardnesses"},
"hardpan":{"hardpan","hardpans"},
"hardship":{"hardship","hardships"},
"hardtack":{"hardtack","hardtacks"},
"hardware":{"hardware","hardwares"},
"hardwareman":{"hardwareman","hardwaremen"},
"hardwood":{"hardwood","hardwoods"},
"hardy":{"hardier","hardies","hardiest","hardy"},
"hare":{"hare","hares"},
"harebell":{"harebell","harebells"},
"hareem":{"hareem","hareems"},
"harelip":{"harelip","harelips"},
"harem":{"harem","harems"},
"haricot":{"haricot","haricots"},
"harikari":{"harikari","harikaris"},
"hark":{"hark","harked","harking","harks"},
"harken":{"harken","harkened","harkening","harkens"},
"harlequin-snake":{"harlequin-snake","harlequin-snakes"},
"harlequinade":{"harlequinade","harlequinades"},
"harlot":{"harlot","harlots"},
"harlotry":{"harlotries","harlotry"},
"harm":{"harm","harmed","harming","harms"},
"harmfulness":{"harmfulness","harmfulnesses"},
"harmonica":{"harmonica","harmonicas"},
"harmoniousness":{"harmoniousness","harmoniousnesses"},
"harmonisation":{"harmonisation","harmonisations"},
"harmonium":{"harmonium","harmoniums"},
"harmonization":{"harmonization","harmonizations"},
"harmonize":{"harmonize","harmonized","harmonizes","harmonizing"},
"harmony":{"harmonies","harmony"},
"harness":{"harness","harnessed","harnesses","harnessing"},
"harp":{"harp","harped","harping","harps"},
"harper":{"harper","harpers"},
"harpia":{"harpia","harpias"},
"harpist":{"harpist","harpists"},
"harpoon":{"harpoon","harpooned","harpooning"},
"harpooneer":{"harpooneer","harpooneers"},
"harpooner":{"harpooner","harpooners"},
"harpulla":{"harpulla","harpullas"},
"harpy":{"harpies","harpy"},
"harquebus":{"harquebus","harquebuses"},
"harrisburg":{"harrisburg","harrisburgs"},
"harrisia":{"harrisia","harrisias"},
"harrison":{"harrison","harrisons"},
"harrow":{"harrow","harrowed","harrowing","harrows"},
"harrumph":{"harrumph","harrumphed","hurrumphing"},
"harry":{"harried","harries","harry","harrying"},
"harsh":{"harsh","harsher","harshest"},
"harshen":{"harshen","harshened","harshening"},
"harshness":{"harshness","harshnesses"},
"hart":{"hart","harts"},
"hartebeest":{"hartebeest","hartebeests"},
"hartford":{"hartford","hartfords"},
"harum-scarum":{"harum-scarum","harum-scarums"},
"haruspex":{"haruspex","haruspices"},
"harvard":{"harvard","harvards"},
"harvest":{"harvest","harvested","harvesting","harvests"},
"harvest-lice":{"harvest-lice","harvest-lices"},
"harvester":{"harvester","harvesters"},
"harvestfish":{"harvestfish","harvestfishes"},
"harvesting":{"harvesting","harvestings"},
"harvestman":{"harvestman","harvestmen"},
"has-been":{"has-been","has-beens"},
"hash":{"hash","hashed","hashes","hashing"},
"hashish":{"hashish","hashishes"},
"hashmark":{"hashmark","hashmarks"},
"hasp":{"hasp","hasped","hasping"},
"hassle":{"hassle","hassles"},
"hassock":{"hassock","hassocks"},
"haste":{"haste","hasted","hastes","hasting"},
"hasten":{"hasten","hastened","hastening","hastens"},
"hastening":{"hastening","hastenings"},
"hastiness":{"hastiness","hastinesses"},
"hastings":{"hastings","hastingses"},
"hasty":{"hastier","hastiest","hasty"},
"hat":{"hat","hats","hatted","hatting"},
"hatch":{"hatch","hatched","hatches","hatching"},
"hatchel":{"hatchel","hatcheled","hatcheling","hatchelled","hatchelling","hatchels"},
"hatchery":{"hatcheries","hatchery"},
"hatchet":{"hatchet","hatchets"},
"hatching":{"hatching","hatchings"},
"hatchway":{"hatchway","hatchways"},
"hate":{"hate","hated","hates","hating"},
"hatefulness":{"hatefulness","hatefulnesses"},
"hatful":{"hatful","hatfuls"},
"hatiora":{"hatiora","hatioras"},
"hatmaker":{"hatmaker","hatmakers"},
"hatrack":{"hatrack","hatracks"},
"hatred":{"hatred","hatreds"},
"hatter":{"hatter","hatters"},
"hauberk":{"hauberk","hauberks"},
"haughtiness":{"haughtiness","haughtinesses"},
"haughty":{"haughtier","haughtiest","haughty"},
"haul":{"haul","hauled","hauling","hauls"},
"haulage":{"haulage","haulages"},
"hauler":{"hauler","haulers"},
"haulier":{"haulier","hauliers"},
"hauling":{"hauling","haulings"},
"haulm":{"haulm","haulms"},
"haunch":{"haunch","haunches"},
"haunt":{"haunt","haunted","haunting","haunts"},
"hausa":{"hausa","hausas"},
"hausen":{"hausen","hausens"},
"haussa":{"haussa","haussas"},
"haustellum":{"haustella","haustellum"},
"haustorium":{"haustoria","haustorium"},
"hautbois":{"hautbois","hautboises"},
"hautboy":{"hautboy","hautboys"},
"haute-normandie":{"haute-normandie","haute-normandies"},
"havana":{"havana","havanas"},
"have":{"had","have","has","having","‘ve"},
"have-not":{"have-not","have-nots"},
"haven":{"haven","havened","havening","havens"},
"haver":{"haver","havered","havering"},
"haversack":{"haversack","haversacks"},
"have_a_feeling":{"had_a_feeling","has_a_feeling","have_a_feeling","having_a_feeling"},
"have_left":{"had_left","has_left","have_left","having_left"},
"have_the_feeling":{"had_the_feeling","has_the_feeling","have_the_feeling","having_the_feeling"},
"havoc":{"havoc","havocs"},
"haw":{"haw","hawed","hawing","haws"},
"haw-haw":{"haw-haw","haw-haws"},
"hawaii":{"hawaii","hawaiis"},
"hawfinch":{"hawfinch","hawfinches"},
"hawk":{"hawk","hawked","hawking","hawks"},
"hawkbill":{"hawkbill","hawkbills"},
"hawker":{"hawker","hawkers"},
"hawking":{"hawking","hawkings"},
"hawkmoth":{"hawkmoth","hawkmoths"},
"hawksbill":{"hawksbill","hawksbills"},
"hawkshaw":{"hawkshaw","hawkshaws"},
"hawse":{"hawse","hawses"},
"hawsehole":{"hawsehole","hawseholes"},
"hawsepipe":{"hawsepipe","hawsepipes"},
"hawthorn":{"hawthorn","hawthorns"},
"hay":{"hay","hayed","haying"},
"hay-scented":{"hay-scented","hay-scenteds"},
"hayastan":{"hayastan","hayastans"},
"haydn":{"haydn","haydns"},
"hayes":{"hayes","hayeses"},
"hayfield":{"hayfield","hayfields"},
"haying":{"haying","hayings"},
"hayloft":{"hayloft","haylofts"},
"haymaker":{"haymaker","haymakers"},
"hayrack":{"hayrack","hayracks"},
"hayrick":{"hayrick","hayricks"},
"hayrig":{"hayrig","hayrigs"},
"hayseed":{"hayseed","hayseeds"},
"haystack":{"haystack","haystacks"},
"hayti":{"hayti","haytis"},
"hazan":{"hazan","hazans"},
"hazard":{"hazard","hazarded","hazarding","hazards"},
"hazardia":{"hazardia","hazardias"},
"hazarding":{"hazarding","hazardings"},
"hazardousness":{"hazardousness","hazardousnesses"},
"haze":{"haze","hazed","hazes","hazing"},
"hazel":{"hazel","hazels"},
"hazelnut":{"hazelnut","hazelnuts"},
"hazelwood":{"hazelwood","hazelwoods"},
"haziness":{"haziness","hazinesses"},
"hazy":{"hazier","haziest","hazy"},
"hazzan":{"hazzan","hazzanim","hazzans"},
"hdl":{"hdl","hdls"},
"he":{"he","hes"},
"he-goat":{"he-goat","he-goats"},
"he-huckleberry":{"he-huckleberries","he-huckleberry"},
"he-man":{"he-man","he-men"},
"head":{"head","headed","heading","heads"},
"head-shrinker":{"head-shrinker","head-shrinkers"},
"headache":{"headache","headaches"},
"headcount":{"headcount","headcounts"},
"headcounter":{"headcounter","headcounters"},
"headdress":{"headdress","headdresses"},
"header":{"header","headers"},
"headfish":{"headfish","headfishes"},
"headgear":{"headgear","headgears"},
"headhunter":{"headhunter","headhunters"},
"heading":{"heading","headings"},
"headlamp":{"headlamp","headlamps"},
"headland":{"headland","headlands"},
"headlight":{"headlight","headlights"},
"headline":{"headline","headlined","headlines","headlining"},
"headliner":{"headliner","headliners"},
"headman":{"headman","headmen"},
"headmaster":{"headmaster","headmasters"},
"headphone":{"headphone","headphones"},
"headpiece":{"headpiece","headpieces"},
"headpin":{"headpin","headpins"},
"headquarters":{"headquarters"},
"headrest":{"headrest","headrests"},
"headroom":{"headroom","headrooms"},
"headshake":{"headshake","headshakes"},
"headshaking":{"headshaking","headshakings"},
"headsman":{"headsman","headsmen"},
"headspring":{"headspring","headsprings"},
"headstall":{"headstall","headstalls"},
"headstone":{"headstone","headstones"},
"headway":{"headway","headways"},
"heady":{"headier","headiest","heady"},
"heal":{"heal","healed","healing","heals"},
"healer":{"healer","healers"},
"healthiness":{"healthiness","healthinesses"},
"healthy":{"healthier","healthiest","healthy"},
"heap":{"heap","heaped","heaping","heaps"},
"heaps":{"heaps","heapses"},
"hear":{"hear","heard","hearing","hears"},
"hearer":{"hearer","hearers"},
"hearing":{"hearing","hearings"},
"hearken":{"hearken","hearkened","hearkening","hearkens"},
"hearsay":{"hearsay","hearsays"},
"heart":{"heart","hearts"},
"heartache":{"heartache","heartaches"},
"heartbeat":{"heartbeat","heartbeats"},
"heartbreak":{"heartbreak","heartbreaks"},
"heartburn":{"heartburn","heartburns"},
"hearten":{"hearten","heartened","heartening","heartens"},
"hearth":{"hearth","hearths"},
"hearthstone":{"hearthstone","hearthstones"},
"heartiness":{"heartiness","heartinesses"},
"heartleaf":{"heartleaf","heartleaves"},
"heartlessness":{"heartlessness","heartlessnesses"},
"hearts":{"hearts","heartses"},
"heartsease":{"heartsease","heartseases"},
"heartseed":{"heartseed","heartseeds"},
"heartsickness":{"heartsickness","heartsicknesses"},
"heartwood":{"heartwood","heartwoods"},
"hearty":{"heartier","hearties","heartiest","hearty"},
"heat":{"heat","heated","heating","heats"},
"heater":{"heater","heaters"},
"heath":{"heath","heaths"},
"heathberry":{"heathberries","heathberry"},
"heathen":{"heathen","heathens"},
"heathenism":{"heathenism","heathenisms"},
"heather":{"heather","heathers"},
"heathfowl":{"heathfowl","heathfowls"},
"heathland":{"heathland","heathlands"},
"heating":{"heating","heatings"},
"heave":{"heave","heaved","heaves","heaving","hove"},
"heave-ho":{"heave-ho","heave-hos"},
"heaven":{"heaven","heavens"},
"heavens":{"heavens","heavenses"},
"heaves":{"heaves","heaveses"},
"heaviness":{"heaviness","heavinesses"},
"heaving":{"heaving","heavings"},
"heavy":{"heavier","heavies","heaviest","heavy"},
"heavyweight":{"heavyweight","heavyweights"},
"hebdomad":{"hebdomad","hebdomads"},
"hebephrenia":{"hebephrenia","hebephrenias"},
"hebetate":{"hebetate","hebetated","hebetating"},
"hebraism":{"hebraism","hebraisms"},
"hebraize":{"hebraize","hebraized","hebraizing"},
"hebrew":{"hebrew","hebrews"},
"hebrews":{"hebrews","hebrewses"},
"hebrides":{"hebrides","hebrideses"},
"heckelphone":{"heckelphone","heckelphones"},
"heckle":{"heckle","heckled","heckles","heckling"},
"heckler":{"heckler","hecklers"},
"heckling":{"heckling","hecklings"},
"hectocotylus":{"hectocotyli","hectocotylus"},
"hectogram":{"hectogram","hectograms"},
"hectograph":{"hectograph","hectographed","hectographing","hectographs"},
"hectoliter":{"hectoliter","hectoliters"},
"hectolitre":{"hectolitre","hectolitres"},
"hectometer":{"hectometer","hectometers"},
"hectometre":{"hectometre","hectometres"},
"hector":{"hector","hectored","hectoring","hectors"},
"hedeoma":{"hedeoma","hedeomas"},
"heder":{"hadarim","heder"},
"hedera":{"hedera","hederas"},
"hedge":{"hedge","hedged","hedges","hedging"},
"hedgehog":{"hedgehog","hedgehogs"},
"hedgehop":{"hedgehop","hedgehopped","hedgehopping","hedgehops"},
"hedgerow":{"hedgerow","hedgerows"},
"hedging":{"hedging","hedgings"},
"hedgy":{"hedgier","hedgiest","hedgy"},
"hediondilla":{"hediondilla","hediondillas"},
"hedonist":{"hedonist","hedonists"},
"hedysarum":{"hedysarum","hedysarums"},
"hee-haw":{"hee-haw","hee-haws"},
"heed":{"heed","heeded","heeding","heeds"},
"heedfulness":{"heedfulness","heedfulnesses"},
"heedlessness":{"heedlessness","heedlessnesses"},
"heehaw":{"heehaw","heehawed","heehawing"},
"heel":{"heel","heeled","heeling","heels"},
"heelbone":{"heelbone","heelbones"},
"heft":{"heft","hefted","hefting","hefts"},
"heftiness":{"heftiness","heftinesses"},
"hefty":{"heftier","heftiest","hefty"},
"hegel":{"hegel","hegels"},
"hegemony":{"hegemonies","hegemony"},
"hegira":{"hegira","hegiras"},
"heifer":{"heifer","heifers"},
"height":{"height","heights"},
"heighten":{"heighten","heightened","heightening","heightens"},
"heights":{"heights","heightses"},
"heimdal":{"heimdal","heimdals"},
"heimdall":{"heimdall","heimdalls"},
"heimdallr":{"heimdallr","heimdallrs"},
"heinousness":{"heinousness","heinousnesses"},
"heir":{"heir","heirs"},
"heir-at-law":{"heir-at-law","heirs-at-law"},
"heiress":{"heiress","heiresses"},
"heirloom":{"heirloom","heirlooms"},
"heist":{"heist","heisted","heisting","heists"},
"hejira":{"hejira","hejiras"},
"hel":{"hel","hels"},
"hela":{"hela","helas"},
"heldentenor":{"heldentenor","heldentetenore"},
"helen":{"helen","helens"},
"helena":{"helena","helenas"},
"helenium":{"helenium","heleniums"},
"heleodytes":{"heleodytes","heleodyteses"},
"heliamphora":{"heliamphora","heliamphoras"},
"helianthemum":{"helianthemum","helianthemums"},
"helianthus":{"helianthus","helianthuses"},
"helichrysum":{"helichrysum","helichrysums"},
"helicidae":{"helicidae","helicidaes"},
"helicon":{"helicon","helicons"},
"helicopter":{"helicopter","helicoptered","helicoptering","helicopters"},
"helicteres":{"helicteres","helictereses"},
"helilift":{"helilift","helilifted","helilifting"},
"heliograph":{"heliograph","heliographed","heliographing"},
"heliogravure":{"heliogravure","heliogravures"},
"heliolatry":{"heliolatries","heliolatry"},
"heliopsis":{"heliopses","heliopsis"},
"heliothis":{"heliothis","heliothises"},
"heliotrope":{"heliotrope","heliotropes"},
"heliotype":{"heliotype","heliotypes"},
"heliozoa":{"heliozoa","heliozoas"},
"helipterum":{"helipterum","helipterums"},
"helium":{"helium","heliums"},
"helix":{"helices","helix","helixes"},
"hell":{"hell","hells"},
"hell-kite":{"hell-kite","hell-kites"},
"hell-rooster":{"hell-rooster","hell-roosters"},
"hellbender":{"hellbender","hellbenders"},
"hellcat":{"hellcat","hellcats"},
"hellebore":{"hellebore","hellebores"},
"helleborine":{"helleborine","helleborines"},
"helleborus":{"helleborus","helleboruses"},
"hellene":{"hellene","hellenes"},
"hellenic":{"hellenic","hellenics"},
"heller":{"heller","hellers"},
"helleri":{"helleri","helleris"},
"hellespont":{"hellespont","hellesponts"},
"hellfire":{"hellfire","hellfires"},
"hellgrammiate":{"hellgrammiate","hellgrammiates"},
"hellion":{"hellion","hellions"},
"hello":{"hello","helloed","helloing","hellos"},
"helm":{"helm","helmed","helming","helms"},
"helmet":{"helmet","helmets"},
"helmetflower":{"helmetflower","helmetflowers"},
"helmholtz":{"helmholtz","helmholtzs"},
"helminth":{"helminth","helminths"},
"helminthic":{"helminthic","helminthics"},
"helminthostachys":{"helminthostachys","helminthostachyses"},
"helmsman":{"helmsman","helmsmen"},
"heloderma":{"heloderma","helodermas"},
"helodermatidae":{"helodermatidae","helodermatidaes"},
"helot":{"helot","helots"},
"helotiaceae":{"helotiaceae","helotiaceaes"},
"helotiales":{"helotiales","helotialeses"},
"helotium":{"helotium","helotiums"},
"help":{"help","helped","helping","helps"},
"helper":{"helper","helpers"},
"helpfulness":{"helpfulness","helpfulnesses"},
"helping":{"helping","helpings"},
"helplessness":{"helplessness","helplessnesses"},
"helpmate":{"helpmate","helpmates"},
"helpmeet":{"helpmeet","helpmeets"},
"helsingfors":{"helsingfors","helsingforses"},
"helsinki":{"helsinki","helsinkis"},
"helve":{"helve","helves"},
"helvellaceae":{"helvellaceae","helvellaceaes"},
"helvetica":{"helvetica","helveticas"},
"helxine":{"helxine","helxines"},
"hem":{"hem","hemmed","hemming","hems"},
"hemachatus":{"hemachatus","hemachatuses"},
"hemagglutinate":{"hemagglutinate","hemagglutinated","hemagglutinating"},
"hemangioma":{"hemangioma","hemangiomas","hemangiomata"},
"hematite":{"hematite","hematites"},
"hematocyst":{"hematocyst","hematocysts"},
"hematologist":{"hematologist","hematologists"},
"hematology":{"hematologies","hematology"},
"hematolysis":{"hematolyses","hematolysis"},
"hematoma":{"hematoma","hematomas","hematomata"},
"hematozoon":{"hematozoon","hematozozoa"},
"heme":{"heme","hemes"},
"hemelytron":{"hemelytra","hemelytron"},
"hemeralopia":{"hemeralopia","hemeralopias"},
"hemerobiid":{"hemerobiid","hemerobiids"},
"hemerobiidae":{"hemerobiidae","hemerobiidaes"},
"hemerocallidaceae":{"hemerocallidaceae","hemerocallidaceaes"},
"hemerocallis":{"hemerocallis","hemerocallises"},
"hemiascomycetes":{"hemiascomycetes","hemiascomyceteses"},
"hemicrania":{"hemicrania","hemicranias"},
"hemicycle":{"hemicycle","hemicycles"},
"hemidemisemiquaver":{"hemidemisemiquaver","hemidemisemiquavers"},
"hemielytron":{"hemielytra","hemielytron"},
"hemiepiphyte":{"hemiepiphyte","hemiepiphytes"},
"hemigalus":{"hemigalus","hemigaluses"},
"hemigrammus":{"hemigrammus","hemigrammuses"},
"hemimetabola":{"hemimetabola","hemimetabolas"},
"hemimorphite":{"hemimorphite","hemimorphites"},
"hemingway":{"hemingway","hemingways"},
"hemipode":{"hemipode","hemipodes"},
"hemiprocnidae":{"hemiprocnidae","hemiprocnidaes"},
"hemiptera":{"hemiptera","hemipteras"},
"hemipteran":{"hemipteran","hemipterans"},
"hemipteron":{"hemipteron","hemipterons"},
"hemipteronatus":{"hemipteronatus","hemipteronatuses"},
"hemiramphidae":{"hemiramphidae","hemiramphidaes"},
"hemisect":{"hemisect","hemisected","hemisecting"},
"hemisphere":{"hemisphere","hemispheres"},
"hemitripterus":{"hemitripterus","hemitripteruses"},
"hemlock":{"hemlock","hemlocks"},
"hemodialysis":{"hemodialyses","hemodialysis"},
"hemodialyzer":{"hemodialyzer","hemodialyzers"},
"hemoglobin":{"hemoglobin","hemoglobins"},
"hemoglobinopathy":{"hemoglobinopathies","hemoglobinopathy"},
"hemolysin":{"hemolysin","hemolysins"},
"hemolysis":{"hemolyses","hemolysis"},
"hemophile":{"hemophile","hemophiles"},
"hemophilia":{"hemophilia","hemophilias"},
"hemophiliac":{"hemophiliac","hemophiliacs"},
"hemoptysis":{"hemoptyses","hemoptysis"},
"hemorrhage":{"hemorrhage","hemorrhages"},
"hemorrhoid":{"hemorrhoid","hemorrhoids"},
"hemorrhoidectomy":{"hemorrhoidectomies","hemorrhoidectomy"},
"hemostat":{"hemostat","hemostats"},
"hemp":{"hemp","hemps"},
"hemstitch":{"hemstitch","hemstitched","hemstitches","hemstitching"},
"hemstitching":{"hemstitching","hemstitchings"},
"hen":{"hen","hens"},
"hen-and-chickens":{"hen-and-chickens","hens-and-chickens"},
"hen-of-the-woods":{"hen-of-the-woods","hen-of-the-woodses"},
"henbane":{"henbane","henbanes"},
"henbit":{"henbit","henbits"},
"henchman":{"henchman","henchmen"},
"hencoop":{"hencoop","hencoops"},
"hendecahedron":{"hendecahedra","hendecahedron","hendecahedrons"},
"henhouse":{"henhouse","henhouses"},
"henna":{"henna","hennas"},
"hennery":{"henneries","hennery"},
"henpeck":{"henpeck","henpecked","henpecking"},
"henry":{"henries","henry","henrys"},
"hent":{"hent","henting"},
"henyard":{"henyard","henyards"},
"hep":{"hep","hepper","heppest"},
"hepatectomy":{"hepatectomies","hepatectomy"},
"hepatica":{"hepatica","hepaticas"},
"hepaticae":{"hepaticae","hepaticaes"},
"hepaticopsida":{"hepaticopsida","hepaticopsidas"},
"hepatoflavin":{"hepatoflavin","hepatoflavins"},
"hephaestus":{"hephaestus","hephaestuses"},
"hephaistos":{"hephaistos","hephaistoses"},
"heptad":{"heptad","heptads"},
"heptarchy":{"heptarchies","heptarchy"},
"hera":{"hera","heras"},
"heracles":{"heracles","heracleses"},
"heracleum":{"heracleum","heracleums"},
"heraclid":{"heraclid","heraclidae"},
"herakles":{"herakles","herakleses"},
"heraklid":{"heraklid","heraklidae"},
"herald":{"herald","heralded","heralding","heralds"},
"heraldry":{"heraldries","heraldry"},
"herb":{"herb","herbs"},
"herbage":{"herbage","herbages"},
"herbalist":{"herbalist","herbalists"},
"herbarium":{"herbariia","herbarium","herbariumia","herbariums"},
"herbicide":{"herbicide","herbicides"},
"herby":{"herbier","herbiest","herby"},
"hercules":{"hercules","herculeses"},
"hercules-club":{"hercules-club","hercules-clubs"},
"herd":{"herd","herded","herding","herds"},
"herder":{"herder","herders"},
"herdsman":{"herdsman","herdsmen"},
"here":{"here","heres"},
"hereafter":{"hereafter","hereafters"},
"heredity":{"heredities","heredity"},
"hereford":{"hereford","herefords"},
"herero":{"herero","heros"},
"heres":{"heredes","heres"},
"heresy":{"heresies","heresy"},
"heretic":{"heretic","heretics"},
"heritage":{"heritage","heritages"},
"heritiera":{"heritiera","heritieras"},
"heritor":{"heritor","heritors"},
"herm":{"herm","herms"},
"herma":{"herma","hermae","hermai"},
"hermann":{"hermann","hermanns"},
"hermannia":{"hermannia","hermannias"},
"hermaphrodite":{"hermaphrodite","hermaphrodites"},
"hermaphroditism":{"hermaphroditism","hermaphroditisms"},
"hermissenda":{"hermissenda","hermissendas"},
"hermit":{"hermit","hermits"},
"hermitage":{"hermitage","hermitages"},
"hernaria":{"hernaria","hernarias"},
"hernia":{"hernia","herniae","hernias"},
"herniate":{"herniate","herniated","herniating"},
"herniation":{"herniation","herniations"},
"herniorrhaphy":{"herniorrhaphies","herniorrhaphy"},
"hero":{"hero","heroes"},
"hero-worship":{"hero-worship","hero-worshiped","hero-worshiping","hero-worships"},
"herod":{"herod","herods"},
"heroin":{"heroin","heroins"},
"heroine":{"heroine","heroines"},
"heroism":{"heroism","heroisms"},
"heron":{"heron","herons"},
"heronry":{"heronries","heronry"},
"herpes":{"herpes","herpeses"},
"herpestes":{"herpestes","herpesteses"},
"herr":{"herr","herren"},
"herrenvolk":{"herrenvolk","herrenvolks"},
"herrerasaur":{"herrerasaur","herrerasaurs"},
"herrerasaurus":{"herrerasaurus","herrerasauruses"},
"herring":{"herring","herrings"},
"hertha":{"hertha","herthas"},
"hertz":{"hertz","hertzs"},
"hesitance":{"hesitance","hesitances"},
"hesitancy":{"hesitancies","hesitancy"},
"hesitate":{"hesitate","hesitated","hesitates","hesitating"},
"hesitater":{"hesitater","hesitaters"},
"hesitation":{"hesitation","hesitations"},
"hesitator":{"hesitator","hesitators"},
"hesperides":{"hesperides","hesperideses"},
"hesperidium":{"hesperidia","hesperidium"},
"hesperiphona":{"hesperiphona","hesperiphonas"},
"hesperis":{"hesperis","hesperises"},
"hessian":{"hessian","hessians"},
"hessonite":{"hessonite","hessonites"},
"hetaera":{"hetaera","hetaerae"},
"hetaira":{"hetaira","hetairai"},
"heteranthera":{"heteranthera","heterantheras"},
"heterobasidiomycetes":{"heterobasidiomycetes","heterobasidiomyceteses"},
"heterocephalus":{"heterocephalus","heterocephaluses"},
"heterodon":{"heterodon","heterodons"},
"heterodoxy":{"heterodoxies","heterodoxy"},
"heterogeneity":{"heterogeneities","heterogeneity"},
"heterogeneousness":{"heterogeneousness","heterogeneousnesses"},
"heterogenesis":{"heterogeneses","heterogenesis"},
"heterograft":{"heterograft","heterografts"},
"heterokontae":{"heterokontae","heterokontaes"},
"heterokontophyta":{"heterokontophyta","heterokontophytas"},
"heteromeles":{"heteromeles","heteromeleses"},
"heteromyidae":{"heteromyidae","heteromyidaes"},
"heteroplasty":{"heteroplasties","heteroplasty"},
"heteroptera":{"heteroptera","heteropteras"},
"heteroscelus":{"heteroscelus","heterosceluses"},
"heterosexual":{"heterosexual","heterosexuals"},
"heterosexualism":{"heterosexualism","heterosexualisms"},
"heterosexuality":{"heterosexualities","heterosexuality"},
"heterosomata":{"heterosomata","heterosomatas"},
"heterostraci":{"heterostraci","heterostracis"},
"heterotheca":{"heterotheca","heterothecas"},
"heterotrichales":{"heterotrichales","heterotrichaleses"},
"hetman":{"hetman","hetmans"},
"heuchera":{"heuchera","heucheras"},
"heuristic":{"heuristic","heuristics"},
"hevea":{"hevea","heveas"},
"hew":{"hew","hewed","hewing","hewn","hews"},
"hex":{"hex","hexed","hexes","hexing"},
"hexad":{"hexad","hexads"},
"hexagrammidae":{"hexagrammidae","hexagrammidaes"},
"hexagrammos":{"hexagrammos","hexagrammoses"},
"hexahedron":{"hexahedra","hexahedron","hexahedrons"},
"hexalectris":{"hexalectris","hexalectrises"},
"hexamita":{"hexamita","hexamitas"},
"hexanchidae":{"hexanchidae","hexanchidaes"},
"hexanchus":{"hexanchus","hexanchuses"},
"hexapla":{"hexapla","hexaplas"},
"hexapoda":{"hexapoda","hexapodas"},
"hexapody":{"hexapodies","hexapody"},
"hexenbesen":{"hexenbesen","hexenbesens"},
"heyday":{"heyday","heydays"},
"hf":{"hf","hfs"},
"hg":{"hg","hgs"},
"hi":{"hi","his"},
"hi-fi":{"hi-fi","hi-fis"},
"hiatus":{"hiatus","hiatuses"},
"hibachi":{"hibachi","hibachis"},
"hibbertia":{"hibbertia","hibbertias"},
"hibernacle":{"hibernacle","hibernacles"},
"hibernaculum":{"hibernacula","hibernaculum"},
"hibernate":{"hibernate","hibernated","hibernates","hibernating"},
"hibernia":{"hibernia","hibernias"},
"hibiscus":{"hibiscus","hibiscuses"},
"hiccough":{"hiccough","hiccoughed","hiccoughing","hiccoughs"},
"hiccup":{"hicccupped","hiccup","hiccuped","hiccuping","hiccupped","hiccupping","hiccups"},
"hick":{"hick","hicks"},
"hickey":{"hickey","hickeys"},
"hickory":{"hickories","hickory"},
"hidalgo":{"hidalgo","hidalgos"},
"hidatsa":{"hidatsa","hidatsas"},
"hide":{"hid","hidden","hide","hides","hiding"},
"hide-and-seek":{"hide-and-seek","hide-and-seeks"},
"hideaway":{"hideaway","hideaways"},
"hideout":{"hideout","hideouts"},
"hiding":{"hiding","hidings"},
"hidrosis":{"hidroses","hidrosis"},
"hie":{"hie","hied","hieing","hying"},
"hieracium":{"hieracium","hieraciums"},
"hieracosphinx":{"hieracosphinges","hieracosphinx","hieracosphinxes"},
"hierarch":{"hierarch","hierarches"},
"hierarchy":{"hierarchies","hierarchy"},
"hieratic":{"hieratic","hieratics"},
"hierocracy":{"hierocracies","hierocracy"},
"hieroglyph":{"hieroglyph","hieroglyphs"},
"hieroglyphic":{"hieroglyphic","hieroglyphics"},
"hierolatry":{"hierolatries","hierolatry"},
"hierology":{"hierologies","hierology"},
"hieron":{"hiera","hieron"},
"hierurgy":{"hierurgies","hierurgy"},
"higgle":{"higgle","higgled","higgles","higgling"},
"high":{"high","higher","highest","highs"},
"high-hat":{"high-hat","high-hats","high-hatted","high-hatting"},
"high-low-jack":{"high-low-jack","high-low-jacks"},
"high-mindedness":{"high-mindedness","high-mindednesses"},
"high-muck-a-muck":{"high-muck-a-muck","high-muck-a-mucks"},
"high-pressure":{"high-pressure","high-pressured","high-pressuring"},
"high-rise":{"high-rise","high-rises"},
"high-spiritedness":{"high-spiritedness","high-spiritednesses"},
"high-tech":{"high-tech","high-teches"},
"high-up":{"high-up","high-ups"},
"highboy":{"highboy","highboys"},
"highchair":{"highchair","highchairs"},
"higher-up":{"higher-up","higher-ups"},
"highflier":{"highflier","highfliers"},
"highflyer":{"highflyer","highflyers"},
"highjack":{"highjack","highjacked","highjacking","highjacks"},
"highjacker":{"highjacker","highjackers"},
"highjacking":{"highjacking","highjackings"},
"highland":{"highland","highlands"},
"highlight":{"highlight","highlighted","highlighting","highlights"},
"highlighting":{"highlighting","highlightings"},
"highness":{"highness","highnesses"},
"highroad":{"highroad","highroads"},
"highschool":{"highschool","highschools"},
"hightail":{"hightail","hightailed","hightailing"},
"highwater":{"highwater","highwaters"},
"highway":{"highway","highways"},
"highwayman":{"highwayman","highwaymen"},
"higi":{"higi","higis"},
"hijack":{"hijack","hijacked","hijacking","hijacks"},
"hijacker":{"hijacker","hijackers"},
"hijacking":{"hijacking","hijackings"},
"hijinks":{"hijinks","hijinkses"},
"hike":{"hike","hiked","hikes","hiking"},
"hilarity":{"hilarities","hilarity"},
"hill":{"hill","hilled","hilling","hills"},
"hillbilly":{"hillbillies","hillbilly"},
"hillock":{"hillock","hillocks"},
"hillside":{"hillside","hillsides"},
"hilltop":{"hilltop","hilltops"},
"hilly":{"hillier","hilliest","hilly"},
"hilt":{"hilt","hilts"},
"hilum":{"hila","hilum","hilums"},
"hilus":{"hilus","hiluses"},
"himalayas":{"himalayas","himalayases"},
"himantoglossum":{"himantoglossum","himantoglossums"},
"himantopus":{"himantopus","himantopuses"},
"himation":{"himatia","himation"},
"hind":{"hind","hinder","hinds"},
"hindbrain":{"hindbrain","hindbrains"},
"hinder":{"hinder","hindered","hindering","hinders"},
"hindoo":{"hindoo","hindoos"},
"hindooism":{"hindooism","hindooisms"},
"hindoostani":{"hindoostani","hindoostanis"},
"hindostani":{"hindostani","hindostanis"},
"hindquarters":{"hindquarters","hindquarterses"},
"hindrance":{"hindrance","hindrances"},
"hindu":{"hindu","hindus"},
"hinduism":{"hinduism","hinduisms"},
"hindustani":{"hindustani","hindustanis"},
"hinge":{"hinge","hinged","hinges","hinging"},
"hinny":{"hinnied","hinnies","hinny","hinnying"},
"hint":{"hint","hinted","hinting","hints"},
"hinterland":{"hinterland","hinterlands"},
"hip":{"hip","hipped","hipping","hips"},
"hipbone":{"hipbone","hipbones"},
"hipflask":{"hipflask","hipflasks"},
"hippeastrum":{"hippeastrum","hippeastrums"},
"hippie":{"hippie","hippies"},
"hippo":{"hippo","hippos"},
"hippobosca":{"hippobosca","hippoboscas"},
"hippoboscid":{"hippoboscid","hippoboscids"},
"hippoboscidae":{"hippoboscidae","hippoboscidaes"},
"hippocampus":{"hippocampi","hippocampus","hippocampuses"},
"hippocastanaceae":{"hippocastanaceae","hippocastanaceaes"},
"hippocrepis":{"hippocrepis","hippocrepises"},
"hippodamia":{"hippodamia","hippodamias"},
"hippoglossoides":{"hippoglossoides","hippoglossoideses"},
"hippoglossus":{"hippoglossus","hippoglossuses"},
"hippopotamidae":{"hippopotamidae","hippopotamidaes"},
"hippopotamus":{"hippopotami","hippopotamus","hippopotamuses"},
"hipposideridae":{"hipposideridae","hipposideridaes"},
"hipposideros":{"hipposideros","hipposideroses"},
"hippotragus":{"hippotragus","hippotraguses"},
"hippy":{"hippies","hippy"},
"hipsurus":{"hipsurus","hipsuruses"},
"hire":{"hire","hired","hires","hiring"},
"hire-purchase":{"hire-purchase","hire-purchases"},
"hireling":{"hireling","hirelings"},
"hirer":{"hirer","hirers"},
"hiring":{"hiring","hirings"},
"hirsuteness":{"hirsuteness","hirsutenesses"},
"hirsutism":{"hirsutism","hirsutisms"},
"hirudinea":{"hirudinea","hirudineas"},
"hirudinean":{"hirudinean","hirudineans"},
"hirudinidae":{"hirudinidae","hirudinidaes"},
"hirudo":{"hirudo","hirudos"},
"hirundinidae":{"hirundinidae","hirundinidaes"},
"hirundo":{"hirundo","hirundos"},
"hispanic":{"hispanic","hispanics"},
"hispanicize":{"hispanicize","hispanicized","hispanicizing"},
"hispaniola":{"hispaniola","hispaniolas"},
"hiss":{"hiss","hissed","hisses","hissing"},
"hissing":{"hissing","hissings"},
"historian":{"historian","historians"},
"historiographer":{"historiographer","historiographers"},
"historiography":{"historiographies","historiography"},
"history":{"histories","history"},
"histrion":{"histrion","histrions"},
"histrionics":{"histrionics","histrionicses"},
"hit":{"hit","hits","hitted","hitting"},
"hitch":{"hitch","hitched","hitches","hitching"},
"hitchhike":{"hitchhike","hitchhiked","hitchhikes","hitchhiking"},
"hitchrack":{"hitchrack","hitchracks"},
"hitler":{"hitler","hitlers"},
"hitter":{"hitter","hitters"},
"hitting":{"hitting","hittings"},
"hiv":{"hiv","hivs"},
"hive":{"hive","hived","hives","hiving"},
"hives":{"hives","hiveses"},
"hl":{"hl","hls"},
"hm":{"hm","hms"},
"hmo":{"hmo","hmos"},
"hn":{"hn","hns"},
"ho":{"ho","hos"},
"hoactzin":{"hoactzin","hoactzins"},
"hoagie":{"hoagie","hoagies"},
"hoagy":{"hoagies","hoagy"},
"hoar":{"hoar","hoars"},
"hoard":{"hoard","hoarded","hoarding","hoards"},
"hoarder":{"hoarder","hoarders"},
"hoarding":{"hoarding","hoardings"},
"hoarfrost":{"hoarfrost","hoarfrosts"},
"hoariness":{"hoariness","hoarinesses"},
"hoarse":{"hoarse","hoarser","hoarsest"},
"hoarsen":{"hoarsen","hoarsened","hoarsening"},
"hoarseness":{"hoarseness","hoarsenesses"},
"hoary":{"hoarier","hoariest","hoary"},
"hoatzin":{"hoatzin","hoatzins"},
"hoax":{"hoax","hoaxed","hoaxes","hoaxing"},
"hoaxer":{"hoaxer","hoaxers"},
"hob":{"hob","hobs"},
"hobble":{"hobble","hobbled","hobbles","hobbling"},
"hobby":{"hobbies","hobby"},
"hobbyhorse":{"hobbyhorse","hobbyhorses"},
"hobgoblin":{"hobgoblin","hobgoblins"},
"hobnob":{"hobnob","hobnobbed","hobnobbing","hobnobs"},
"hobo":{"hobo","hoboes","hobos"},
"hock":{"hock","hocked","hocking","hocks"},
"hockey":{"hockey","hockeys"},
"hocus":{"hocus","hocused","hocuses","hocusing","hocussed","hocussing"},
"hocus-pocus":{"hocus-pocus","hocus-pocused","hocus-pocuses","hocus-pocusing","hocus-pocussed","hocus-pocussing"},
"hoder":{"hoder","hoders"},
"hodgepodge":{"hodgepodge","hodgepodges"},
"hodman":{"hodman","hodmen"},
"hodometer":{"hodometer","hodometers"},
"hodr":{"hodr","hodrs"},
"hoe":{"hoe","hoed","hoeing","hoes"},
"hog":{"hog","hogged","hogging","hogs"},
"hogchoker":{"hogchoker","hogchokers"},
"hogfish":{"hogfish","hogfishes"},
"hogg":{"hogg","hoggs"},
"hogget":{"hogget","hoggets"},
"hoggishness":{"hoggishness","hoggishnesses"},
"hogtie":{"hogtie","hogtied","hogties","hogtying"},
"hogwash":{"hogwash","hogwashes"},
"hogweed":{"hogweed","hogweeds"},
"hohenlinden":{"hohenlinden","hohenlindens"},
"hoheria":{"hoheria","hoherias"},
"hoist":{"hoist","hoisted","hoisting","hoists"},
"hoka":{"hoka","hokas"},
"hokan":{"hokan","hokans"},
"hokkaido":{"hokkaido","hokkaidos"},
"hokkianese":{"hokkianese","hokkianeses"},
"holarrhena":{"holarrhena","holarrhenas"},
"holbrookia":{"holbrookia","holbrookias"},
"holcus":{"holcus","holcuses"},
"hold":{"held","hold","holding","holds"},
"holdall":{"holdall","holdalls"},
"holder":{"holder","holders"},
"holdfast":{"holdfast","holdfasts"},
"holding":{"holding","holdings"},
"holdover":{"holdover","holdovers"},
"holdup":{"holdup","holdups"},
"hole":{"hole","holed","holes","holing"},
"holibut":{"holibut","holibuts"},
"holiday":{"holiday","holidayed","holidaying","holidays"},
"holidaymaker":{"holidaymaker","holidaymakers"},
"holiness":{"holiness","holinesses"},
"holla":{"holla","hollas"},
"holland":{"holland","hollands"},
"hollander":{"hollander","hollanders"},
"hollands":{"hollands","hollandses"},
"holler":{"holler","hollered","hollering","hollers"},
"hollering":{"hollering","hollerings"},
"hollo":{"hollo","hollos"},
"holloa":{"holloa","holloas"},
"hollow":{"hollow","hollowed","hollower","hollowest","hollowing","hollows"},
"hollow-back":{"hollow-back","hollow-backs"},
"holloware":{"holloware","hollowares"},
"hollowware":{"hollowware","hollowwares"},
"holly":{"hollies","holly"},
"hollygrape":{"hollygrape","hollygrapes"},
"hollyhock":{"hollyhock","hollyhocks"},
"hollywood":{"hollywood","hollywoods"},
"holmes":{"holmes","holmeses"},
"holmium":{"holmium","holmiums"},
"holocene":{"holocene","holocenes"},
"holocentridae":{"holocentridae","holocentridaes"},
"holocentrus":{"holocentrus","holocentruses"},
"holocephali":{"holocephali","holocephalis"},
"holograph":{"holograph","holographs"},
"holonym":{"holonym","holonyms"},
"holonymy":{"holonymies","holonymy"},
"holothuria":{"holothuria","holothurias"},
"holothurian":{"holothurian","holothurians"},
"holothuridae":{"holothuridae","holothuridaes"},
"holothuroidea":{"holothuroidea","holothuroideas"},
"holotype":{"holotype","holotypes"},
"holstein":{"holstein","holsteins"},
"holstein-friesian":{"holstein-friesian","holstein-friesians"},
"holster":{"holster","holsters"},
"holy":{"holier","holies","holiest","holy"},
"holystone":{"holystone","holystoned","holystones","holystoning"},
"homage":{"homage","homages"},
"homaridae":{"homaridae","homaridaes"},
"homarus":{"homarus","homaruses"},
"hombre":{"hombre","hombres"},
"homburg":{"homburg","homburgs"},
"home":{"home","homed","homes","homing"},
"homebody":{"homebodies","homebody"},
"homebuilder":{"homebuilder","homebuilders"},
"homecoming":{"homecoming","homecomings"},
"homeland":{"homeland","homelands"},
"homeless":{"homeless","homelesses"},
"homeliness":{"homeliness","homelinesses"},
"homely":{"homelier","homeliest","homely"},
"homemaker":{"homemaker","homemakers"},
"homeopath":{"homeopath","homeopaths"},
"homeopathy":{"homeopathies","homeopathy"},
"homeowner":{"homeowner","homeowners"},
"homer":{"homer","homers"},
"homestead":{"homestead","homesteads"},
"homesteader":{"homesteader","homesteaders"},
"homework":{"homework","homeworks"},
"homey":{"homeier","homeiest","homey"},
"homicide":{"homicide","homicides"},
"homily":{"homilies","homily"},
"hominidae":{"hominidae","hominidaes"},
"hominoidea":{"hominoidea","hominoideas"},
"homo":{"homo","homos"},
"homobasidiomycetes":{"homobasidiomycetes","homobasidiomyceteses"},
"homoeopath":{"homoeopath","homoeopaths"},
"homoeopathy":{"homoeopathies","homoeopathy"},
"homoeroticism":{"homoeroticism","homoeroticisms"},
"homogeneity":{"homogeneities","homogeneity"},
"homogeneousness":{"homogeneousness","homogeneousnesses"},
"homogenisation":{"homogenisation","homogenisations"},
"homogenization":{"homogenization","homogenizations"},
"homogenize":{"homogenize","homogenized","homogenizing"},
"homograft":{"homograft","homografts"},
"homogyne":{"homogyne","homogynes"},
"homologize":{"homologize","homologized","homologizing"},
"homology":{"homologies","homology"},
"homona":{"homona","homonas"},
"homoptera":{"homoptera","homopteras"},
"homopteran":{"homopteran","homopterans"},
"homosexual":{"homosexual","homosexuals"},
"homosexualism":{"homosexualism","homosexualisms"},
"homosexuality":{"homosexualities","homosexuality"},
"homunculus":{"homunculi","homunculus"},
"homy":{"homier","homiest","homy"},
"honcho":{"honcho","honchos"},
"hondo":{"hondo","hondos"},
"hone":{"hone","honed","hones","honing"},
"honestness":{"honestness","honestnesses"},
"honesty":{"honesties","honesty"},
"honey":{"honey","honeyed","honeying","honeys","honied"},
"honeybee":{"honeybee","honeybees"},
"honeybells":{"honeybells","honeybellses"},
"honeycomb":{"honeycomb","honeycombed","honeycombing","honeycombs"},
"honeycreeper":{"honeycreeper","honeycreepers"},
"honeydew":{"honeydew","honeydews"},
"honeyflower":{"honeyflower","honeyflowers"},
"honeymoon":{"honeymoon","honeymooned","honeymooning","honeymoons"},
"honeymooner":{"honeymooner","honeymooners"},
"honeypot":{"honeypot","honeypots"},
"honeysucker":{"honeysucker","honeysuckers"},
"honeysuckle":{"honeysuckle","honeysuckles"},
"honk":{"honk","honked","honking","honks"},
"honker":{"honker","honkers"},
"honky":{"honkies","honky"},
"honky-tonk":{"honky-tonk","honky-tonks"},
"honkytonk":{"honkytonk","honkytonks"},
"honolulu":{"honolulu","honolulus"},
"honor":{"honor","honored","honoring","honors"},
"honorableness":{"honorableness","honorablenesses"},
"honorarium":{"honoraria","honorariia","honorarium","honorariums"},
"honoring":{"honoring","honorings"},
"honour":{"honour","honoured","honouring","honours"},
"honourableness":{"honourableness","honourablenesses"},
"honours":{"honours","honourses"},
"honshu":{"honshu","honshus"},
"hoo-ha":{"hoo-ha","hoo-has"},
"hooch":{"hooch","hooches"},
"hood":{"hood","hooded","hooding","hoods"},
"hoodlum":{"hoodlum","hoodlums"},
"hoodoo":{"hoodoo","hoodooed","hoodooing","hoodoos"},
"hoodooism":{"hoodooism","hoodooisms"},
"hoodwink":{"hoodwink","hoodwinked","hoodwinking","hoodwinks"},
"hooey":{"hooey","hooeys"},
"hoof":{"hoof","hoofed","hoofing","hoofs","hooves"},
"hoofing":{"hoofing","hoofings"},
"hoofmark":{"hoofmark","hoofmarks"},
"hoofprint":{"hoofprint","hoofprints"},
"hook":{"hook","hooked","hooking","hooks"},
"hookah":{"hookah","hookahs"},
"hooker":{"hooker","hookers"},
"hooknose":{"hooknose","hooknoses"},
"hookup":{"hookup","hookups"},
"hooky":{"hookies","hooky"},
"hooligan":{"hooligan","hooligans"},
"hooliganism":{"hooliganism","hooliganisms"},
"hoop":{"hoop","hooped","hooping","hoops"},
"hoopla":{"hoopla","hooplas"},
"hoopoe":{"hoopoe","hoopoes"},
"hoopoo":{"hoopoo","hoopoos"},
"hoopskirt":{"hoopskirt","hoopskirts"},
"hooray":{"hooray","hoorayed","hooraying"},
"hoosegow":{"hoosegow","hoosegows"},
"hoosgow":{"hoosgow","hoosgows"},
"hoosier":{"hoosier","hoosiers"},
"hoot":{"hoot","hooted","hooting","hoots"},
"hootch":{"hootch","hootches"},
"hootchy-kootchy":{"hootchy-kootchies","hootchy-kootchy"},
"hootenanny":{"hootenannies","hootenanny"},
"hooter":{"hooter","hooters"},
"hootnanny":{"hootnannies","hootnanny"},
"hoover":{"hoover","hoovers"},
"hop":{"hop","hopped","hopping","hops"},
"hop-picker":{"hop-picker","hop-pickers"},
"hope":{"hope","hoped","hopes","hoping"},
"hopeful":{"hopeful","hopefuls"},
"hopi":{"hopi","hopis"},
"hopper":{"hopper","hoppers"},
"hopple":{"hopple","hoppled","hoppling"},
"hops":{"hops","hopses"},
"hopsack":{"hopsack","hopsacks"},
"hopsacking":{"hopsacking","hopsackings"},
"horde":{"horde","hordes"},
"hordeolum":{"hordeola","hordeolum","hordeolums"},
"hordeum":{"hordeum","hordeums"},
"horizon":{"horizon","horizons"},
"hormone":{"hormone","hormones"},
"horn":{"horn","horned","horning","horns"},
"horneophyton":{"horneophyton","horneophytons"},
"hornet":{"hornet","hornets"},
"hornfels":{"hornfels","hornfelses"},
"horniness":{"horniness","horninesses"},
"hornpipe":{"hornpipe","hornpipes"},
"hornpout":{"hornpout","hornpouts"},
"hornstone":{"hornstone","hornstones"},
"hornswoggle":{"hornswoggle","hornswoggled","hornswoggling"},
"horny":{"hornier","horniest","horny"},
"horologer":{"horologer","horologers"},
"horologist":{"horologist","horologists"},
"horologium":{"horologia","horologium"},
"horoscope":{"horoscope","horoscopes"},
"horoscopy":{"horoscopies","horoscopy"},
"horridness":{"horridness","horridnesses"},
"horrify":{"horrified","horrifies","horrify","horrifying"},
"horror":{"horror","horrors"},
"horse":{"horse","horsed","horses","horsing"},
"horseback":{"horseback","horsebacks"},
"horsebean":{"horsebean","horsebeans"},
"horsebrier":{"horsebrier","horsebriers"},
"horsefish":{"horsefish","horsefishes"},
"horseflesh":{"horseflesh","horsefleshes"},
"horsefly":{"horseflies","horsefly"},
"horsehead":{"horsehead","horseheads"},
"horselaugh":{"horselaugh","horselaughs"},
"horseman":{"horseman","horsemen"},
"horsemeat":{"horsemeat","horsemeats"},
"horsemint":{"horsemint","horsemints"},
"horsepower":{"horsepower","horsepowers"},
"horseradish":{"horseradish","horseradishes"},
"horseshit":{"horseshit","horseshits"},
"horseshoe":{"horseshoe","horseshoed","horseshoeing","horseshoes"},
"horseshoer":{"horseshoer","horseshoers"},
"horseshoes":{"horseshoes","horseshoeses"},
"horseweed":{"horseweed","horseweeds"},
"horsewhip":{"horsewhip","horsewhipped","horsewhipping","horsewhips"},
"horsewoman":{"horsewoman","horsewomen"},
"horsey":{"horsey","horsier","horsiest"},
"horsy":{"horsier","horsiest","horsy"},
"hors_d'oeuvre":{"hors_d'oeuvre","hors_d'oeuvres"},
"hortensia":{"hortensia","hortensias"},
"horticulture":{"horticulture","horticultures"},
"hosanna":{"hosanna","hosannas"},
"hose":{"hose","hosed","hoses","hosing"},
"hosepipe":{"hosepipe","hosepipes"},
"hospital":{"hospital","hospitals"},
"hospitalisation":{"hospitalisation","hospitalisations"},
"hospitality":{"hospitalities","hospitality"},
"hospitalization":{"hospitalization","hospitalizations"},
"hospitalize":{"hospitalize","hospitalized","hospitalizing"},
"host":{"host","hosted","hosting","hosts"},
"hosta":{"hosta","hostas"},
"hostaceae":{"hostaceae","hostaceaes"},
"hostage":{"hostage","hostages"},
"hostel":{"hostel","hostels"},
"hosteller":{"hosteller","hostellers"},
"hostelry":{"hostelries","hostelry"},
"hostess":{"hostess","hostessed","hostesses","hostessing"},
"hostility":{"hostilities","hostility"},
"hostler":{"hostler","hostlers"},
"hot":{"hot","hotted","hotter","hottest","hotting"},
"hotbed":{"hotbed","hotbeds"},
"hotcake":{"hotcake","hotcakes"},
"hotchpotch":{"hotchpotch","hotchpotches"},
"hotdog":{"hotdog","hotdogs"},
"hotei-chiku":{"hotei-chiku","hotei-chikus"},
"hotel":{"hotel","hotels"},
"hotel-casino":{"hotel-casino","hotel-casinos"},
"hotelier":{"hotelier","hoteliers"},
"hotelkeeper":{"hotelkeeper","hotelkeepers"},
"hotelman":{"hotelman","hotelmen"},
"hotfoot":{"hotfoot","hotfooted","hotfooting","hotfoots"},
"hoth":{"hoth","hoths"},
"hothead":{"hothead","hotheads"},
"hothouse":{"hothouse","hothouses"},
"hothr":{"hothr","hothrs"},
"hotness":{"hotness","hotnesses"},
"hotplate":{"hotplate","hotplates"},
"hotshot":{"hotshot","hotshots"},
"hottentot":{"hottentot","hottentots"},
"hottonia":{"hottonia","hottonias"},
"houhere":{"houhere","houheres"},
"hound":{"hound","hounded","hounding","hounds"},
"hour":{"hour","hours"},
"hourglass":{"hourglass","hourglasses"},
"houri":{"houri","houris"},
"house":{"house","housed","houses","housing"},
"housebreak":{"housebreak","housebreaking","housebroke","housebroken"},
"housebreaker":{"housebreaker","housebreakers"},
"housebreaking":{"housebreaking","housebreakings"},
"housebuilder":{"housebuilder","housebuilders"},
"houseclean":{"houseclean","housecleaned","housecleaning","housecleans"},
"housecoat":{"housecoat","housecoats"},
"housefly":{"houseflies","housefly"},
"houseful":{"houseful","housefuls"},
"houseguest":{"houseguest","houseguests"},
"household":{"household","households"},
"householder":{"householder","householders"},
"housekeep":{"housekeep","housekeeping","housekept"},
"housekeeper":{"housekeeper","housekeepers"},
"housekeeping":{"housekeeping","housekeepings"},
"housel":{"housel","houseled","houseling","houselled","houselling","housels"},
"housemaid":{"housemaid","housemaids"},
"houseman":{"houseman","housemen"},
"housetop":{"housetop","housetops"},
"housewife":{"housewife","housewives"},
"housework":{"housework","houseworks"},
"housewrecker":{"housewrecker","housewreckers"},
"housing":{"housing","housings"},
"housings":{"housings","housingses"},
"houttuynia":{"houttuynia","houttuynias"},
"hovea":{"hovea","hoveas"},
"hovel":{"hovel","hovels"},
"hover":{"hover","hovered","hovering","hovers"},
"how":{"how","hows"},
"how-do-you-do":{"how-do-you-do","how-do-you-dos"},
"howdy":{"howdies","howdy"},
"howitzer":{"howitzer","howitzers"},
"howl":{"howl","howled","howling","howls"},
"howler":{"howler","howlers"},
"howling":{"howling","howlings"},
"hoy":{"hoy","hoys"},
"hoyden":{"hoyden","hoydens"},
"hoydenism":{"hoydenism","hoydenisms"},
"hp":{"hp","hps"},
"hq":{"hq","hqs"},
"hr":{"hr","hrs"},
"hs1":{"hs1","hs1s"},
"hs2":{"hs2","hs2s"},
"hsian":{"hsian","hsians"},
"htlv-1":{"htlv-1","htlv-1s"},
"html":{"html","htmls"},
"http":{"http","https"},
"hualapai":{"hualapai","hualapais"},
"hualpai":{"hualpai","hualpais"},
"huamachil":{"huamachil","huamachils"},
"huarache":{"huarache","huaraches"},
"huaraches":{"huaraches","huaracheses"},
"hub":{"hub","hubs"},
"hubble-bubble":{"hubble-bubble","hubble-bubbles"},
"hubbub":{"hubbub","hubbubs"},
"hubby":{"hubbies","hubby"},
"huck":{"huck","hucks"},
"huckaback":{"huckaback","huckabacks"},
"huckleberry":{"huckleberries","huckleberry"},
"huckster":{"huckster","huckstered","huckstering","hucksters"},
"hud":{"hud","huds"},
"huddle":{"huddle","huddled","huddles","huddling"},
"hudson":{"hudson","hudsons"},
"hudsonia":{"hudsonia","hudsonias"},
"hue":{"hue","hued","hueing","hues"},
"huff":{"huff","huffed","huffing","huffs"},
"huffing":{"huffing","huffings"},
"huffishness":{"huffishness","huffishnesses"},
"huffy":{"huffier","huffiest","huffy"},
"hug":{"hug","hugged","hugging","hugs"},
"huge":{"huge","huger","hugest"},
"hugger-mugger":{"hugger-mugger","hugger-muggered","hugger-muggering","hugger-muggers"},
"huggermugger":{"huggermugger","huggermuggered","huggermuggering","huggermuggers"},
"hugging":{"hugging","huggings"},
"hugo":{"hugo","hugos"},
"hugueninia":{"hugueninia","hugueninias"},
"huisache":{"huisache","huisaches"},
"huitre":{"huitre","huitres"},
"hula":{"hula","hulas"},
"hula-hula":{"hula-hula","hula-hulas"},
"hulk":{"hulk","hulked","hulking","hulks"},
"hull":{"hull","hulled","hulling","hulls"},
"hullaballoo":{"hullaballoo","hullaballoos"},
"hullabaloo":{"hullabaloo","hullabaloos"},
"hullo":{"hullo","hullos"},
"hulsea":{"hulsea","hulseas"},
"hum":{"hum","hummed","humming","hums"},
"human":{"human","humans","humen"},
"humanisation":{"humanisation","humanisations"},
"humanism":{"humanism","humanisms"},
"humanitarian":{"humanitarian","humanitarians"},
"humanitarianism":{"humanitarianism","humanitarianisms"},
"humanities":{"humanities","humanitieses"},
"humanity":{"humanities","humanity"},
"humanization":{"humanization","humanizations"},
"humanize":{"humanize","humanized","humanizes","humanizing"},
"humankind":{"humankind","humankinds"},
"humanness":{"humanness","humannesses"},
"humanoid":{"humanoid","humanoids"},
"humble":{"humble","humbled","humbler","humblest","humbling"},
"humblebee":{"humblebee","humblebees"},
"humbleness":{"humbleness","humblenesses"},
"humbling":{"humbling","humblings"},
"humbug":{"humbug","humbugged","humbugging","humbugs"},
"humerus":{"humeri","humermeri","humerus"},
"humidify":{"humidified","humidifies","humidify","humidifying"},
"humidity":{"humidities","humidity"},
"humidness":{"humidness","humidnesses"},
"humiliate":{"humiliate","humiliated","humiliates","humiliating"},
"humiliation":{"humiliation","humiliations"},
"humility":{"humilities","humility"},
"hummer":{"hummer","hummers"},
"humming":{"humming","hummings"},
"hummock":{"hummock","hummocks"},
"humor":{"humor","humored","humoring","humors"},
"humoring":{"humoring","humorings"},
"humorist":{"humorist","humorists"},
"humorousness":{"humorousness","humorousnesses"},
"humour":{"humour","humoured","humouring","humours"},
"humourist":{"humourist","humourists"},
"hump":{"hump","humped","humping","humps"},
"humpback":{"humpback","humpbacks"},
"humph":{"humph","humphed","humphing"},
"humpy":{"humpier","humpies","humpiest","humpy"},
"humulus":{"humulus","humuluses"},
"hun":{"hun","huns"},
"hunch":{"hunch","hunched","hunches","hunching"},
"hunchback":{"hunchback","hunchbacks"},
"hundred":{"hundred","hundreds"},
"hundred-percenter":{"hundred-percenter","hundred-percenters"},
"hundredth":{"hundredth","hundredths"},
"hundredweight":{"hundredweight","hundredweights"},
"hungarian":{"hungarian","hungarians"},
"hungary":{"hungaries","hungary"},
"hunger":{"hunger","hungered","hungering","hungers"},
"hungriness":{"hungriness","hungrinesses"},
"hungry":{"hungrier","hungriest","hungry"},
"hunk":{"hunk","hunks"},
"hunker":{"hunker","hunkered","hunkering"},
"hunnemannia":{"hunnemannia","hunnemannias"},
"hunt":{"hunt","hunted","hunting","hunts"},
"hunter":{"hunter","hunters"},
"hunting":{"hunting","huntings"},
"huntsman":{"huntsman","huntsmen"},
"hurdle":{"hurdle","hurdled","hurdles","hurdling"},
"hurdler":{"hurdler","hurdlers"},
"hurdles":{"hurdles","hurdleses"},
"hurdling":{"hurdling","hurdlings"},
"hurdy-gurdy":{"hurdy-gurdies","hurdy-gurdy"},
"hurl":{"hurl","hurled","hurling","hurls"},
"hurler":{"hurler","hurlers"},
"hurley":{"hurley","hurleys"},
"hurly-burly":{"hurly-burlies","hurly-burly"},
"huron":{"huron","hurons"},
"hurrah":{"hurrah","hurrahed","hurrahing","hurrahs"},
"hurray":{"hurray","hurrayed","hurraying","hurrays"},
"hurricane":{"hurricane","hurricanes"},
"hurriedness":{"hurriedness","hurriednesses"},
"hurry":{"hurried","hurries","hurry","hurrying"},
"hurry-skurry":{"hurry-skurried","hurry-skurries","hurry-skurry","hurry-skurrying"},
"hurrying":{"hurrying","hurryings"},
"hurt":{"hurt","hurted","hurting","hurts"},
"hurting":{"hurting","hurtings"},
"hurtle":{"hurtle","hurtled","hurtles","hurtling"},
"husband":{"husband","husbanded","husbanding","husbands"},
"husbandman":{"husbandman","husbandmen"},
"husbandry":{"husbandries","husbandry"},
"hush":{"hush","hushed","hushes","hushing"},
"husk":{"husk","husked","husking","husks"},
"huskiness":{"huskiness","huskinesses"},
"husking":{"husking","huskings"},
"husky":{"huskier","huskies","huskiest","husky"},
"hussy":{"hussies","hussy"},
"hustle":{"hustle","hustled","hustles","hustling"},
"hustler":{"hustler","hustlers"},
"hut":{"hut","huts","hutted","hutting"},
"hutch":{"hutch","hutches"},
"hutu":{"hutu","hutus"},
"hutzpa":{"hutzpa","hutzpas"},
"huxley":{"huxley","huxleys"},
"hyacinth":{"hyacinth","hyacinths"},
"hyacinthaceae":{"hyacinthaceae","hyacinthaceaes"},
"hyacinthoides":{"hyacinthoides","hyacinthoideses"},
"hyaena":{"hyaena","hyaenas"},
"hyaenidae":{"hyaenidae","hyaenidaes"},
"hyalin":{"hyalin","hyalins"},
"hyaline":{"hyaline","hyalines"},
"hyalinize":{"hyalinize","hyalinized","hyalinizing"},
"hyalophora":{"hyalophora","hyalophoras"},
"hyalosperma":{"hyalosperma","hyalospermas"},
"hyalospongiae":{"hyalospongiae","hyalospongiaes"},
"hybrid":{"hybrid","hybrids"},
"hybridisation":{"hybridisation","hybridisations"},
"hybridist":{"hybridist","hybridists"},
"hybridization":{"hybridization","hybridizations"},
"hybridize":{"hybridize","hybridized","hybridizes","hybridizing"},
"hybridizing":{"hybridizing","hybridizings"},
"hydnaceae":{"hydnaceae","hydnaceaes"},
"hydnocarpus":{"hydnocarpus","hydnocarpuses"},
"hydnum":{"hydnum","hydnums"},
"hydra":{"hydra","hydrae","hydras"},
"hydrangea":{"hydrangea","hydrangeas"},
"hydrangeaceae":{"hydrangeaceae","hydrangeaceaes"},
"hydrant":{"hydrant","hydrants"},
"hydrastis":{"hydrastis","hydrastises"},
"hydrate":{"hydrate","hydrated","hydrating"},
"hydraulics":{"hydraulics","hydraulicses"},
"hydrilla":{"hydrilla","hydrillas"},
"hydro":{"hydro","hydros"},
"hydrobates":{"hydrobates","hydrobateses"},
"hydrobatidae":{"hydrobatidae","hydrobatidaes"},
"hydrocephalus":{"hydrocephalus","hydrocephaluses"},
"hydrocephaly":{"hydrocephalies","hydrocephaly"},
"hydrocharidaceae":{"hydrocharidaceae","hydrocharidaceaes"},
"hydrocharis":{"hydrocharis","hydrocharises"},
"hydrocharitaceae":{"hydrocharitaceae","hydrocharitaceaes"},
"hydrochlorothiazide":{"hydrochlorothiazide","hydrochlorothiazides"},
"hydrochoeridae":{"hydrochoeridae","hydrochoeridaes"},
"hydrochoerus":{"hydrochoerus","hydrochoeruses"},
"hydrocortisone":{"hydrocortisone","hydrocortisones"},
"hydrodamalis":{"hydrodamalis","hydrodamalises"},
"hydrodiuril":{"hydrodiuril","hydrodiurils"},
"hydrodynamics":{"hydrodynamics","hydrodynamicses"},
"hydrofoil":{"hydrofoil","hydrofoils"},
"hydrogen":{"hydrogen","hydrogens"},
"hydrogenate":{"hydrogenate","hydrogenated","hydrogenating"},
"hydroid":{"hydroid","hydroids"},
"hydrokinetics":{"hydrokinetics","hydrokineticses"},
"hydrolith":{"hydrolith","hydroliths"},
"hydrolysis":{"hydrolyses","hydrolysis"},
"hydrolyze":{"hydrolyze","hydrolyzed","hydrolyzes","hydrolyzing"},
"hydromantes":{"hydromantes","hydromanteses"},
"hydromedusa":{"hydromedusa","hydromedusae","hydromedusas"},
"hydrometer":{"hydrometer","hydrometers"},
"hydrometry":{"hydrometries","hydrometry"},
"hydromyinae":{"hydromyinae","hydromyinaes"},
"hydromys":{"hydromys","hydromyses"},
"hydropathy":{"hydropathies","hydropathy"},
"hydrophidae":{"hydrophidae","hydrophidaes"},
"hydrophobia":{"hydrophobia","hydrophobias"},
"hydrophyllaceae":{"hydrophyllaceae","hydrophyllaceaes"},
"hydrophyllum":{"hydrophyllum","hydrophyllums"},
"hydrophyte":{"hydrophyte","hydrophytes"},
"hydroplane":{"hydroplane","hydroplanes"},
"hydroponics":{"hydroponics","hydroponicses"},
"hydrotherapy":{"hydrotherapies","hydrotherapy"},
"hydroxide":{"hydroxide","hydroxides"},
"hydroxybenzene":{"hydroxybenzene","hydroxybenzenes"},
"hydroxyl":{"hydroxyl","hydroxyls"},
"hydroxytetracycline":{"hydroxytetracycline","hydroxytetracyclines"},
"hydrozoa":{"hydrozoa","hydrozoas"},
"hydrozoan":{"hydrozoan","hydrozoans"},
"hyemoschus":{"hyemoschus","hyemoschuses"},
"hyena":{"hyena","hyenas"},
"hygiene":{"hygiene","hygienes"},
"hygienics":{"hygienics","hygienicses"},
"hygrocybe":{"hygrocybe","hygrocybes"},
"hygrophoraceae":{"hygrophoraceae","hygrophoraceaes"},
"hygrophorus":{"hygrophorus","hygrophoruses"},
"hygrotrama":{"hygrotrama","hygrotramas"},
"hyla":{"hyla","hylas"},
"hylactophryne":{"hylactophryne","hylactophrynes"},
"hylidae":{"hylidae","hylidaes"},
"hylobates":{"hylobates","hylobateses"},
"hylobatidae":{"hylobatidae","hylobatidaes"},
"hylocereus":{"hylocereus","hylocereuses"},
"hylocichla":{"hylocichla","hylocichlas"},
"hylophylax":{"hylophylax","hylophylaxes"},
"hymen":{"hymen","hymens"},
"hymenaea":{"hymenaea","hymenaeas"},
"hymenium":{"hymenia","hymenium","hynia","hyniums"},
"hymenogastrales":{"hymenogastrales","hymenogastraleses"},
"hymenomycetes":{"hymenomycetes","hymenomyceteses"},
"hymenophyllaceae":{"hymenophyllaceae","hymenophyllaceaes"},
"hymenophyllum":{"hymenophyllum","hymenophyllums"},
"hymenoptera":{"hymenoptera","hymenopteras"},
"hymenopteran":{"hymenopteran","hymenopterans"},
"hymenopteron":{"hymenopteron","hymenopterons"},
"hymn":{"hymn","hymned","hymning","hymns"},
"hymnal":{"hymnal","hymnals"},
"hymnary":{"hymnaries","hymnary"},
"hymnbook":{"hymnbook","hymnbooks"},
"hymnenopter":{"hymnenopter","hymnenopters"},
"hymnody":{"hymnodies","hymnody"},
"hynerpeton":{"hynerpeton","hynerpetons"},
"hyoid":{"hyoid","hyoids"},
"hyoscine":{"hyoscine","hyoscines"},
"hyoscyamus":{"hyoscyamus","hyoscyamuses"},
"hypanthium":{"hypanthia","hypanthium"},
"hype":{"hype","hyped","hypes","hyping"},
"hypentelium":{"hypentelium","hypenteliums"},
"hyperadrenalism":{"hyperadrenalism","hyperadrenalisms"},
"hyperadrenocorticism":{"hyperadrenocorticism","hyperadrenocorticisms"},
"hyperaemia":{"hyperaemia","hyperaemias"},
"hyperaldosteronism":{"hyperaldosteronism","hyperaldosteronisms"},
"hyperbola":{"hyperbola","hyperbolas"},
"hyperbole":{"hyperbole","hyperboles"},
"hyperbolize":{"hyperbolize","hyperbolized","hyperbolizes","hyperbolizing"},
"hypercapnia":{"hypercapnia","hypercapnias"},
"hypercarbia":{"hypercarbia","hypercarbias"},
"hyperemia":{"hyperemia","hyperemias"},
"hypericaceae":{"hypericaceae","hypericaceaes"},
"hypericales":{"hypericales","hypericaleses"},
"hypericum":{"hypericum","hypericums"},
"hyperlipaemia":{"hyperlipaemia","hyperlipaemias"},
"hyperlipemia":{"hyperlipemia","hyperlipemias"},
"hyperlipidaemia":{"hyperlipidaemia","hyperlipidaemias"},
"hyperlipidemia":{"hyperlipidemia","hyperlipidemias"},
"hypermastigina":{"hypermastigina","hypermastiginas"},
"hypermedia":{"hypermedia","hypermedias"},
"hypermenorrhea":{"hypermenorrhea","hypermenorrheas"},
"hypermetropia":{"hypermetropia","hypermetropias"},
"hypermetropy":{"hypermetropies","hypermetropy"},
"hypernym":{"hypernym","hypernyms"},
"hypernymy":{"hypernymies","hypernymy"},
"hyperoartia":{"hyperoartia","hyperoartias"},
"hyperodontidae":{"hyperodontidae","hyperodontidaes"},
"hyperoglyphe":{"hyperoglyphe","hyperoglyphes"},
"hyperoodon":{"hyperoodon","hyperoodons"},
"hyperopia":{"hyperopia","hyperopias"},
"hyperostosis":{"hyperostoses","hyperostosis"},
"hyperotreta":{"hyperotreta","hyperotretas"},
"hyperpiesia":{"hyperpiesia","hyperpiesias"},
"hyperpiesis":{"hyperpieses","hyperpiesis"},
"hypertensin":{"hypertensin","hypertensins"},
"hypertension":{"hypertension","hypertensions"},
"hyperthermia":{"hyperthermia","hyperthermias"},
"hyperthermy":{"hyperthermies","hyperthermy"},
"hyperthyroidism":{"hyperthyroidism","hyperthyroidisms"},
"hypertrophy":{"hypertrophied","hypertrophies","hypertrophy","hypertrophying"},
"hypervelocity":{"hypervelocities","hypervelocity"},
"hypha":{"hypha","hyphae"},
"hyphantria":{"hyphantria","hyphantrias"},
"hyphen":{"hyphen","hyphened","hyphening","hyphens"},
"hyphenate":{"hyphenate","hyphenated","hyphenates","hyphenating"},
"hyphenation":{"hyphenation","hyphenations"},
"hypnosis":{"hypnoses","hypnosis"},
"hypnotic":{"hypnotic","hypnotics"},
"hypnotism":{"hypnotism","hypnotisms"},
"hypnotist":{"hypnotist","hypnotists"},
"hypnotize":{"hypnotize","hypnotized","hypnotizes","hypnotizing"},
"hypnotizer":{"hypnotizer","hypnotizers"},
"hypo":{"hypo","hypos"},
"hypoadrenalism":{"hypoadrenalism","hypoadrenalisms"},
"hypoadrenocorticism":{"hypoadrenocorticism","hypoadrenocorticisms"},
"hypoblast":{"hypoblast","hypoblasts"},
"hypocapnia":{"hypocapnia","hypocapnias"},
"hypochaeris":{"hypochaeris","hypochaerises"},
"hypochoeris":{"hypochoeris","hypochoerises"},
"hypochondria":{"hypochondria","hypochondrias"},
"hypochondriasis":{"hypochondriases","hypochondriasis"},
"hypochondrium":{"hypochondria","hypochondrium"},
"hypocreaceae":{"hypocreaceae","hypocreaceaes"},
"hypocreales":{"hypocreales","hypocrealeses"},
"hypocrisy":{"hypocrisies","hypocrisy"},
"hypocrite":{"hypocrite","hypocrites"},
"hypoderma":{"hypoderma","hypodermas"},
"hypodermatidae":{"hypodermatidae","hypodermatidaes"},
"hypodermic":{"hypodermic","hypodermics"},
"hypogastrium":{"hypogastria","hypogastrium"},
"hypogeum":{"hypogea","hypogeum"},
"hypoglossal":{"hypoglossal","hypoglossals"},
"hyponym":{"hyponym","hyponyms"},
"hyponymy":{"hyponymies","hyponymy"},
"hypopachus":{"hypopachus","hypopachuses"},
"hypophysectomy":{"hypophysectomies","hypophysectomy"},
"hypophysis":{"hypophyses","hypophysis"},
"hypopitys":{"hypopitys","hypopityses"},
"hyposensitize":{"hyposensitize","hyposensitized","hyposensitizing"},
"hypostasis":{"hypostases","hypostasis"},
"hypostasize":{"hypostasize","hypostasized","hypostasizing"},
"hypostatisation":{"hypostatisation","hypostatisations"},
"hypostatization":{"hypostatization","hypostatizations"},
"hypothalamus":{"hypothalami","hypothalamus"},
"hypothecate":{"hypothecate","hypothecated","hypothecates","hypothecating"},
"hypothesis":{"hypotheses","hypothesis"},
"hypothesize":{"hypothesize","hypothesized","hypothesizes","hypothesizing"},
"hypovitaminosis":{"hypovitaminoses","hypovitaminosis"},
"hypoxidaceae":{"hypoxidaceae","hypoxidaceaes"},
"hypoxis":{"hypoxes","hypoxis"},
"hypsiglena":{"hypsiglena","hypsiglenas"},
"hypsiprymnodon":{"hypsiprymnodon","hypsiprymnodons"},
"hyracoidea":{"hyracoidea","hyracoideas"},
"hyracotherium":{"hyracotherium","hyracotheriums"},
"hyrax":{"hyraces","hyrax","hyraxes"},
"hyssop":{"hyssop","hyssops"},
"hyssopus":{"hyssopus","hyssopuses"},
"hysterectomize":{"hysterectomize","hysterectomized","hysterectomizing"},
"hysterectomy":{"hysterectomies","hysterectomy"},
"hysteria":{"hysteria","hysterias"},
"hysteric":{"hysteric","hysterics"},
"hysterotomy":{"hysterotomies","hysterotomy"},
"hystricidae":{"hystricidae","hystricidaes"},
"hystricomorpha":{"hystricomorpha","hystricomorphas"},
"hz":{"hz","hzs"},
"i":{"i","is"},
"i.o.u.":{"i.o.u.","ious"},
"iaa":{"iaa","iaas"},
"iaea":{"iaea","iaeas"},
"iamb":{"iamb","iambs"},
"iambus":{"iambi","iambus","iambuses"},
"iberia":{"iberia","iberias"},
"iberis":{"iberis","iberises"},
"ibex":{"ibex","ibexes","ibices"},
"ibibio":{"ibibio","ibibios"},
"ibis":{"ibis","ibises"},
"ibo":{"ibo","ibos"},
"ibrd":{"ibrd","ibrds"},
"ibsen":{"ibsen","ibsens"},
"ibuprofen":{"ibuprofen","ibuprofens"},
"icaco":{"icaco","icacos"},
"icao":{"icao","icaos"},
"icbm":{"icbm","icbms"},
"ice":{"ice","iced","ices","icing"},
"iceberg":{"iceberg","icebergs"},
"iceboat":{"iceboat","iceboats"},
"icebox":{"icebox","iceboxes"},
"icebreaker":{"icebreaker","icebreakers"},
"icecream":{"icecream","icecreams"},
"icehouse":{"icehouse","icehouses"},
"iceman":{"iceman","icemen"},
"icepick":{"icepick","icepicks"},
"ichneumon":{"ichneumon","ichneumons"},
"ichneumonidae":{"ichneumonidae","ichneumonidaes"},
"ichor":{"ichor","ichors"},
"ichthyolatry":{"ichthyolatries","ichthyolatry"},
"ichthyosaur":{"ichthyosaur","ichthyosaurs","ichthyosauruses"},
"ichthyosauria":{"ichthyosauria","ichthyosaurias"},
"ichthyosauridae":{"ichthyosauridae","ichthyosauridaes"},
"ichthyosaurus":{"ichthyosauri","ichthyosaurus","ichthyosauruses"},
"icicle":{"icicle","icicles"},
"iciness":{"iciness","icinesses"},
"icing":{"icing","icings"},
"icky":{"ickier","ickiest","icky"},
"icon":{"icon","icons"},
"iconoclast":{"iconoclast","iconoclasts"},
"iconography":{"iconographies","iconography"},
"iconostasis":{"iconostases","iconostasis"},
"icosahedron":{"icosahedra","icosahedron","icosahedrons"},
"ictalurus":{"ictalurus","ictaluruses"},
"icteria":{"icteria","icterias"},
"icteridae":{"icteridae","icteridaes"},
"icterus":{"icterus","icteruses"},
"ictiobus":{"ictiobus","ictiobuses"},
"ictodosauria":{"ictodosauria","ictodosaurias"},
"ictonyx":{"ictonyx","ictonyxes"},
"ictus":{"ictus","ictuses"},
"icy":{"icier","iciest","icy"},
"id":{"id","ids"},
"ida":{"ida","idas"},
"idaho":{"idaho","idahos"},
"idea":{"idea","ideas"},
"ideal":{"ideal","ideals"},
"idealisation":{"idealisation","idealisations"},
"idealism":{"idealism","idealisms"},
"idealist":{"idealist","idealists"},
"ideality":{"idealities","ideality"},
"idealization":{"idealization","idealizations"},
"idealize":{"idealize","idealized","idealizes","idealizing"},
"ideate":{"ideate","ideated","ideates","ideating"},
"ideatum":{"ideata","ideatum"},
"ideefixe":{"ideefixe","ideesfixes"},
"identicalness":{"identicalness","identicalnesses"},
"identification":{"identification","identifications"},
"identify":{"identified","identifies","identify","identifying"},
"identikit":{"identikit","identikits"},
"identity":{"identities","identity"},
"ideogram":{"ideogram","ideograms"},
"ideograph":{"ideograph","ideographs"},
"ideologist":{"ideologist","ideologists"},
"ideologue":{"ideologue","ideologues"},
"ideology":{"ideologies","ideology"},
"idesia":{"idesia","idesias"},
"idiocy":{"idiocies","idiocy"},
"idiolatry":{"idiolatries","idiolatry"},
"idiom":{"idiom","idioms"},
"idiopathy":{"idiopathies","idiopathy"},
"idiosyncrasy":{"idiosyncrasies","idiosyncrasy"},
"idiot":{"idiot","idiots"},
"idle":{"idle","idled","idler","idlest","idling"},
"idleness":{"idleness","idlenesses"},
"idler":{"idler","idlers"},
"idling":{"idling","idlings"},
"idocrase":{"idocrase","idocrases"},
"idol":{"idol","idols"},
"idolater":{"idolater","idolaters"},
"idolatry":{"idolatries","idolatry"},
"idolisation":{"idolisation","idolisations"},
"idolization":{"idolization","idolizations"},
"idolize":{"idolize","idolized","idolizes","idolizing"},
"idp":{"idp","idps"},
"idun":{"idun","iduns"},
"idyl":{"idyl","idyls"},
"idyll":{"idyll","idylls"},
"if":{"if","ifs"},
"ifc":{"ifc","ifcs"},
"iffy":{"iffier","iffiest","iffy"},
"ig":{"ig","igs"},
"igbo":{"ibo","igbo","igbos"},
"igloo":{"igloo","igloos"},
"iglu":{"iglu","iglus"},
"ignite":{"ignite","ignited","ignites","igniting"},
"igniter":{"igniter","igniters"},
"ignition":{"ignition","ignitions"},
"ignitor":{"ignitor","ignitors"},
"ignominiousness":{"ignominiousness","ignominiousnesses"},
"ignominy":{"ignominies","ignominy"},
"ignoramus":{"ignoramus","ignoramuses"},
"ignorantness":{"ignorantness","ignorantnesses"},
"ignore":{"ignore","ignored","ignores","ignoring"},
"igorot":{"igorot","igorots"},
"igorrote":{"igorrorote","igorrote","igorrotes"},
"iguana":{"iguana","iguanas"},
"iguania":{"iguania","iguanias"},
"iguanid":{"iguanid","iguanids"},
"iguanidae":{"iguanidae","iguanidaes"},
"iguanodontidae":{"iguanodontidae","iguanodontidaes"},
"iguassu":{"iguassu","iguassus"},
"iguazu":{"iguazu","iguazus"},
"ii":{"ii","iis"},
"iii":{"iii","iiis"},
"ike":{"ike","ikes"},
"ikon":{"ikon","ikons"},
"ilama":{"ilama","ilamas"},
"ilang-ilang":{"ilang-ilang","ilang-ilangs"},
"ileostomy":{"ileostomies","ileostomy"},
"ileum":{"ilea","ileum"},
"ilex":{"ilex","ilexes"},
"iliamna":{"iliamna","iliamnas"},
"ilion":{"ilion","ilions"},
"ilium":{"ilia","ilium","iliums"},
"ill":{"ill","ills","worse","worst"},
"ill-breeding":{"ill-breeding","ill-breedings"},
"ill-treat":{"ill-treat","ill-treated","ill-treating","ill-treats"},
"ill-treatment":{"ill-treatment","ill-treatments"},
"ill-usage":{"ill-usage","ill-usages"},
"ill-use":{"ill-use","ill-used","ill-uses","ill-using"},
"illation":{"illation","illations"},
"illecebrum":{"illecebrum","illecebrums"},
"illegal":{"illegal","illegals"},
"illegality":{"illegalities","illegality"},
"illegalize":{"illegalize","illegalized","illegalizes","illegalizing"},
"illegitimacy":{"illegitimacies","illegitimacy"},
"illegitimate":{"illegitimate","illegitimates"},
"illicium":{"illicium","illiciums"},
"illinois":{"illinois","illinoises"},
"illiteracy":{"illiteracies","illiteracy"},
"illiterate":{"illiterate","illiterates"},
"illness":{"illness","illnesses"},
"illogic":{"illogic","illogics"},
"illogicality":{"illogicalities","illogicality"},
"illogicalness":{"illogicalness","illogicalnesses"},
"illume":{"illume","illumed","illumes","illuming"},
"illuminance":{"illuminance","illuminances"},
"illuminate":{"illuminate","illuminated","illuminates","illuminating"},
"illumination":{"illumination","illuminations"},
"illumine":{"illumine","illumined","illumines","illumining"},
"illusion":{"illusion","illusions"},
"illusionist":{"illusionist","illusionists"},
"illustrate":{"illustrate","illustrated","illustrates","illustrating"},
"illustration":{"illustration","illustrations"},
"illustrator":{"illustrator","illustrators"},
"illuviate":{"illuviate","illuviated","illuviating"},
"ilo":{"ilo","ilos"},
"ilocano":{"ilocano","ilocanos"},
"image":{"image","imaged","images","imaging"},
"imagery":{"imageries","imagery"},
"imagination":{"imagination","imaginations"},
"imaginativeness":{"imaginativeness","imaginativenesses"},
"imagine":{"imagine","imagined","imagines","imagining"},
"imaging":{"imaging","imagings"},
"imago":{"imagines","imago","imagoes","imagos"},
"imam":{"imam","imams"},
"imaum":{"imaum","imaums"},
"imavate":{"imavate","imavates"},
"imbalance":{"imbalance","imbalances"},
"imbauba":{"imbauba","imbaubas"},
"imbecile":{"imbecile","imbeciles"},
"imbecility":{"imbecilities","imbecility"},
"imbed":{"imbed","imbedded","imbedding","imbeds"},
"imbibe":{"imbibe","imbibed","imbibes","imbibing"},
"imbiber":{"imbiber","imbibers"},
"imbibing":{"imbibing","imbibings"},
"imbibition":{"imbibition","imbibitions"},
"imbrication":{"imbrication","imbrications"},
"imbroglio":{"imbroglio","imbroglios"},
"imbrue":{"imbrue","imbrued","imbrues","imbruing"},
"imbrute":{"imbrute","imbruted","imbruting"},
"imbue":{"imbue","imbued","imbues","imbuing"},
"imf":{"imf","imfs"},
"imidazole":{"imidazole","imidazoles"},
"iminazole":{"iminazole","iminazoles"},
"imipramine":{"imipramine","imipramines"},
"imitate":{"imitate","imitated","imitates","imitating"},
"imitation":{"imitation","imitations"},
"imitator":{"imitator","imitators"},
"immaculateness":{"immaculateness","immaculatenesses"},
"immanence":{"immanence","immanences"},
"immanency":{"immanencies","immanency"},
"immateriality":{"immaterialities","immateriality"},
"immaterialize":{"immaterialize","immaterialized","immaterializes","immaterializing"},
"immatureness":{"immatureness","immaturenesses"},
"immaturity":{"immaturities","immaturity"},
"immediacy":{"immediacies","immediacy"},
"immediateness":{"immediateness","immediatenesses"},
"immenseness":{"immenseness","immensenesses"},
"immensity":{"immensities","immensity"},
"immerge":{"immerge","immerged","immerging"},
"immerse":{"immerse","immersed","immerses","immersing"},
"immersion":{"immersion","immersions"},
"immigrant":{"immigrant","immigrants"},
"immigrate":{"immigrate","immigrated","immigrating"},
"immigration":{"immigration","immigrations"},
"imminence":{"imminence","imminences"},
"imminency":{"imminencies","imminency"},
"immingle":{"immingle","immingled","immingles","immingling"},
"immix":{"immix","immixed","immixing","immixt"},
"immobilisation":{"immobilisation","immobilisations"},
"immobility":{"immobilities","immobility"},
"immobilization":{"immobilization","immobilizations"},
"immobilize":{"immobilize","immobilized","immobilizes","immobilizing"},
"immobilizing":{"immobilizing","immobilizings"},
"immoderateness":{"immoderateness","immoderatenesses"},
"immoderation":{"immoderation","immoderations"},
"immodesty":{"immodesties","immodesty"},
"immolate":{"immolate","immolated","immolating"},
"immorality":{"immoralities","immorality"},
"immoralize":{"immoralize","immoralized","immoralizing"},
"immortal":{"immortal","immortals"},
"immortalize":{"immortalize","immortalized","immortalizes","immortalizing"},
"immortelle":{"immortelle","immortelles"},
"immovability":{"immovabilities","immovability"},
"immovable":{"immovable","immovables"},
"immovableness":{"immovableness","immovablenesses"},
"immunisation":{"immunisation","immunisations"},
"immunity":{"immunities","immunity"},
"immunization":{"immunization","immunizations"},
"immunize":{"immunize","immunized","immunizes","immunizing"},
"immunochemistry":{"immunochemistries","immunochemistry"},
"immunoglobulin":{"immunoglobulin","immunoglobulins"},
"immunologist":{"immunologist","immunologists"},
"immunology":{"immunologies","immunology"},
"immunosuppressant":{"immunosuppressant","immunosuppressants"},
"immure":{"immure","immured","immures","immuring"},
"immurement":{"immurement","immurements"},
"immutability":{"immutabilities","immutability"},
"immutableness":{"immutableness","immutablenesses"},
"imo":{"imo","imos"},
"imp":{"imp","imped","imping","imps"},
"impact":{"impact","impacted","impacting","impacts"},
"impaction":{"impaction","impactions"},
"impair":{"impair","impaired","impairing","impairs"},
"impairment":{"impairment","impairments"},
"impala":{"impala","impalas"},
"impale":{"impale","impaled","impales","impaling"},
"impalpability":{"impalpabilities","impalpability"},
"impanel":{"impanel","impaneled","impaneling","impanelled","impanelling","impanells","impanels"},
"imparadise":{"imparadise","imparadised","imparadising"},
"imparity":{"imparities","imparity"},
"impart":{"impart","imparted","imparting","imparts"},
"impartation":{"impartation","impartations"},
"impartiality":{"impartialities","impartiality"},
"imparting":{"imparting","impartings"},
"impasse":{"impasse","impasses"},
"impassion":{"impassion","impassioned","impassioning"},
"impassiveness":{"impassiveness","impassivenesses"},
"impassivity":{"impassivities","impassivity"},
"impaste":{"impaste","impasted","impastes","impasting"},
"impatience":{"impatience","impatiences"},
"impawn":{"impawn","impawned","impawning"},
"impeach":{"impeach","impeached","impeaches","impeaching"},
"impeachability":{"impeachabilities","impeachability"},
"impeachment":{"impeachment","impeachments"},
"impearl":{"impearl","impearled","impearling"},
"impecuniousness":{"impecuniousness","impecuniousnesses"},
"impedance":{"impedance","impedances"},
"impede":{"impede","impeded","impedes","impeding"},
"impediment":{"impediment","impedimenta","impediments"},
"impedimenta":{"impedimenta","impedimentas"},
"impel":{"impel","impelled","impelling","impels"},
"impeller":{"impeller","impellers"},
"impend":{"impend","impended","impending"},
"impendence":{"impendence","impendences"},
"impendency":{"impendencies","impendency"},
"impenetrability":{"impenetrabilities","impenetrability"},
"impenetrableness":{"impenetrableness","impenetrablenesses"},
"impenitence":{"impenitence","impenitences"},
"impenitency":{"impenitencies","impenitency"},
"imperative":{"imperative","imperatives"},
"imperativeness":{"imperativeness","imperativenesses"},
"imperfect":{"imperfect","imperfects"},
"imperfectability":{"imperfectabilities","imperfectability"},
"imperfectibility":{"imperfectibilities","imperfectibility"},
"imperfection":{"imperfection","imperfections"},
"imperfective":{"imperfective","imperfectives"},
"imperfectness":{"imperfectness","imperfectnesses"},
"imperial":{"imperial","imperials"},
"imperil":{"imperil","imperiled","imperiling","imperilled","imperilling"},
"imperiousness":{"imperiousness","imperiousnesses"},
"imperishability":{"imperishabilities","imperishability"},
"imperishingness":{"imperishingness","imperishingnesses"},
"imperium":{"imperia","imperiria","imperium","imperiums"},
"impermanence":{"impermanence","impermanences"},
"impermanency":{"impermanencies","impermanency"},
"impermeability":{"impermeabilities","impermeability"},
"impermeableness":{"impermeableness","impermeablenesses"},
"impersonal":{"impersonal","impersonals"},
"impersonalize":{"impersonalize","impersonalized","impersonalizing"},
"impersonate":{"impersonate","impersonated","impersonates","impersonating"},
"impersonation":{"impersonation","impersonations"},
"impersonator":{"impersonator","impersonators"},
"impertinence":{"impertinence","impertinences"},
"impertinency":{"impertinencies","impertinency"},
"imperturbability":{"imperturbabilities","imperturbability"},
"imperturbableness":{"imperturbableness","imperturbablenesses"},
"imperviousness":{"imperviousness","imperviousnesses"},
"impetrate":{"impetrate","impetrated","impetrating"},
"impetuosity":{"impetuosities","impetuosity"},
"impetuousness":{"impetuousness","impetuousnesses"},
"impetus":{"impetus","impetuses"},
"impi":{"impi","impies"},
"impiety":{"impieties","impiety"},
"impinge":{"impinge","impinged","impinges","impinging"},
"impingement":{"impingement","impingements"},
"impinging":{"impinging","impingings"},
"impiousness":{"impiousness","impiousnesses"},
"impishness":{"impishness","impishnesses"},
"implant":{"implant","implanted","implanting","implants"},
"implausibility":{"implausibilities","implausibility"},
"implausibleness":{"implausibleness","implausiblenesses"},
"implead":{"implead","impleaded","impleading","impled"},
"implement":{"implement","implemented","implementing","implements"},
"implementation":{"implementation","implementations"},
"implicate":{"implicate","implicated","implicates","implicating"},
"implicating":{"implicating","implicatings"},
"implication":{"implication","implications"},
"implode":{"implode","imploded","implodes","imploding"},
"implore":{"implore","implored","implores","imploring"},
"imply":{"implied","implies","imply","implying"},
"impolicy":{"impolicies","impolicy"},
"impone":{"impone","imponed","imponing"},
"import":{"import","imported","importing","imports"},
"importance":{"importance","importances"},
"importation":{"importation","importations"},
"importing":{"importing","importings"},
"importune":{"importune","importuned","importunes","importuning"},
"importunity":{"importunities","importunity"},
"impose":{"impose","imposed","imposes","imposing"},
"imposition":{"imposition","impositions"},
"impossibility":{"impossibilities","impossibility"},
"impossibleness":{"impossibleness","impossiblenesses"},
"impost":{"impost","imposts"},
"imposter":{"imposter","imposters"},
"impostor":{"impostor","impostors"},
"imposture":{"imposture","impostures"},
"impotence":{"impotence","impotences"},
"impotency":{"impotencies","impotency"},
"impound":{"impound","impounded","impounding","impounds"},
"impounding":{"impounding","impoundings"},
"impoundment":{"impoundment","impoundments"},
"impoverish":{"impoverish","impoverished","impoverishes","impoverishing"},
"impoverishment":{"impoverishment","impoverishments"},
"impracticability":{"impracticabilities","impracticability"},
"impracticableness":{"impracticableness","impracticablenesses"},
"imprecate":{"imprecate","imprecated","imprecates","imprecating"},
"imprecation":{"imprecation","imprecations"},
"impreciseness":{"impreciseness","imprecisenesses"},
"imprecision":{"imprecision","imprecisions"},
"impregnability":{"impregnabilities","impregnability"},
"impregnate":{"impregnate","impregnated","impregnates","impregnating"},
"impregnation":{"impregnation","impregnations"},
"impresa":{"impresa","impresas","imprese"},
"impresario":{"impresario","impresarios"},
"impress":{"impress","impressed","impresses","impressing"},
"impression":{"impression","impressions"},
"impressiveness":{"impressiveness","impressivenesses"},
"impressment":{"impressment","impressments"},
"imprimatur":{"imprimatur","imprimaturs"},
"imprint":{"imprint","imprinted","imprinting","imprints"},
"imprison":{"imprison","imprisoned","imprisoning","imprisons"},
"imprisonment":{"imprisonment","imprisonments"},
"improbability":{"improbabilities","improbability"},
"improbableness":{"improbableness","improbablenesses"},
"improbity":{"improbities","improbity"},
"impromptu":{"impromptu","impromptus"},
"improperness":{"improperness","impropernesses"},
"impropriety":{"improprieties","impropriety"},
"improve":{"improve","improved","improves","improving"},
"improvement":{"improvement","improvements"},
"improver":{"improver","improvers"},
"improvidence":{"improvidence","improvidences"},
"improvisation":{"improvisation","improvisations"},
"improvise":{"improvise","improvised","improvises","improvising"},
"imprudence":{"imprudence","imprudences"},
"impudence":{"impudence","impudences"},
"impugn":{"impugn","impugned","impugning"},
"impuissance":{"impuissance","impuissances"},
"impulse":{"impulse","impulses"},
"impulsion":{"impulsion","impulsions"},
"impunity":{"impunities","impunity"},
"impureness":{"impureness","impurenesses"},
"impurity":{"impurities","impurity"},
"impute":{"impute","imputed","imputes","imputing"},
"imuran":{"imuran","imurans"},
"in":{"in","ins"},
"in-basket":{"in-basket","in-baskets"},
"in-law":{"in-law","in-laws"},
"in-migrate":{"in-migrate","in-migrated","in-migrating"},
"in-migration":{"in-migration","in-migrations"},
"in-tray":{"in-tray","in-trays"},
"inability":{"inabilities","inability"},
"inaccessibility":{"inaccessibilities","inaccessibility"},
"inaccuracy":{"inaccuracies","inaccuracy"},
"inachis":{"inachis","inachises"},
"inaction":{"inaction","inactions"},
"inactivate":{"inactivate","inactivated","inactivates","inactivating"},
"inactivation":{"inactivation","inactivations"},
"inactiveness":{"inactiveness","inactivenesses"},
"inactivity":{"inactivities","inactivity"},
"inadequacy":{"inadequacies","inadequacy"},
"inadequateness":{"inadequateness","inadequatenesses"},
"inadvertence":{"inadvertence","inadvertences"},
"inadvertency":{"inadvertencies","inadvertency"},
"inamorata":{"inamorata","inamoratas"},
"inamorato":{"inamorato","inamoratos"},
"inanimateness":{"inanimateness","inanimatenesses"},
"inanition":{"inanition","inanitions"},
"inanity":{"inanities","inanity"},
"inappositeness":{"inappositeness","inappositenesses"},
"inappropriateness":{"inappropriateness","inappropriatenesses"},
"inaptness":{"inaptness","inaptnesses"},
"inarch":{"inarch","inarched","inarching"},
"inattentiveness":{"inattentiveness","inattentivenesses"},
"inaudibility":{"inaudibilities","inaudibility"},
"inaudibleness":{"inaudibleness","inaudiblenesses"},
"inaugural":{"inaugural","inaugurals"},
"inaugurate":{"inaugurate","inaugurated","inaugurates","inaugurating"},
"inauguration":{"inauguration","inaugurations"},
"inauspiciousness":{"inauspiciousness","inauspiciousnesses"},
"inbreathe":{"inbreathe","inbreathed","inbreathing"},
"inbreed":{"inbred","inbreed","inbreeding","inbreeds"},
"inca":{"inca","incas"},
"incalescence":{"incalescence","incalescences"},
"incandesce":{"incandesce","incandesced","incandescing"},
"incandescence":{"incandescence","incandescences"},
"incapability":{"incapabilities","incapability"},
"incapableness":{"incapableness","incapablenesses"},
"incapacitate":{"incapacitate","incapacitated","incapacitates","incapacitating"},
"incapacity":{"incapacities","incapacity"},
"incarcerate":{"incarcerate","incarcerated","incarcerates","incarcerating"},
"incarceration":{"incarceration","incarcerations"},
"incarnadine":{"incarnadine","incarnadined","incarnadining"},
"incarnate":{"incarnate","incarnated","incarnates","incarnating"},
"incarnation":{"incarnation","incarnations"},
"incase":{"incase","incased","incasing"},
"incasement":{"incasement","incasements"},
"incaution":{"incaution","incautions"},
"incautiousness":{"incautiousness","incautiousnesses"},
"incendiarism":{"incendiarism","incendiarisms"},
"incendiary":{"incendiaries","incendiary"},
"incense":{"incense","incensed","incenses","incensing"},
"incensory":{"incensories","incensory"},
"incentive":{"incentive","incentives"},
"incept":{"incept","incepted","incepting"},
"inception":{"inception","inceptions"},
"incertitude":{"incertitude","incertitudes"},
"incessancy":{"incessancies","incessancy"},
"incessantness":{"incessantness","incessantnesses"},
"inch":{"inch","inched","inches","inching"},
"inchworm":{"inchworm","inchworms"},
"incidence":{"incidence","incidences"},
"incident":{"incident","incidents"},
"incidental":{"incidental","incidentals"},
"incienso":{"incienso","inciensos"},
"incinerate":{"incinerate","incinerated","incinerates","incinerating"},
"incipience":{"incipience","incipiences"},
"incipiency":{"incipiencies","incipiency"},
"incise":{"incise","incised","incising"},
"incision":{"incision","incisions"},
"incisiveness":{"incisiveness","incisivenesses"},
"incitation":{"incitation","incitations"},
"incite":{"incite","incited","incites","inciting"},
"incitement":{"incitement","incitements"},
"inciter":{"inciter","inciters"},
"incivility":{"incivilities","incivility"},
"inclemency":{"inclemencies","inclemency"},
"inclementness":{"inclementness","inclementnesses"},
"inclination":{"inclination","inclinations"},
"incline":{"incline","inclined","inclines","inclining"},
"inclining":{"inclining","inclinings"},
"inclinometer":{"inclinometer","inclinometers"},
"inclose":{"inclose","inclosed","incloses","inclosing"},
"inclosure":{"inclosure","inclosures"},
"include":{"include","included","includes","including"},
"inclusion":{"inclusion","inclusions"},
"incognita":{"incognita","incognitas"},
"incognito":{"incognito","incognitos"},
"incoherence":{"incoherence","incoherences"},
"incoherency":{"incoherencies","incoherency"},
"income":{"income","incomes"},
"incoming":{"incoming","incomings"},
"incommode":{"incommode","incommoded","incommodes","incommoding"},
"incommodiousness":{"incommodiousness","incommodiousnesses"},
"incommodity":{"incommodities","incommodity"},
"incompatibility":{"incompatibilities","incompatibility"},
"incompatible":{"incompatible","incompatibles"},
"incompetence":{"incompetence","incompetences"},
"incompetency":{"incompetencies","incompetency"},
"incompetent":{"incompetent","incompetents"},
"inconceivability":{"inconceivabilities","inconceivability"},
"inconceivableness":{"inconceivableness","inconceivablenesses"},
"incongruity":{"incongruities","incongruity"},
"incongruousness":{"incongruousness","incongruousnesses"},
"inconsiderateness":{"inconsiderateness","inconsideratenesses"},
"inconsideration":{"inconsideration","inconsiderations"},
"inconsistency":{"inconsistencies","inconsistency"},
"inconstancy":{"inconstancies","inconstancy"},
"incontinence":{"incontinence","incontinences"},
"incontinency":{"incontinencies","incontinency"},
"incontrovertibility":{"incontrovertibilities","incontrovertibility"},
"incontrovertibleness":{"incontrovertibleness","incontrovertiblenesses"},
"inconvenience":{"inconvenience","inconvenienced","inconveniences","inconveniencing"},
"incorporate":{"incorporate","incorporated","incorporates","incorporating"},
"incorporation":{"incorporation","incorporations"},
"incorporeality":{"incorporealities","incorporeality"},
"incorrectness":{"incorrectness","incorrectnesses"},
"incorruption":{"incorruption","incorruptions"},
"incorruptness":{"incorruptness","incorruptnesses"},
"increase":{"increase","increased","increases","increasing"},
"increaser":{"increaser","increasers"},
"incredibility":{"incredibilities","incredibility"},
"incredibleness":{"incredibleness","incrediblenesses"},
"incredulity":{"incredulities","incredulity"},
"increment":{"increment","increments"},
"incriminate":{"incriminate","incriminated","incriminates","incriminating"},
"incrimination":{"incrimination","incriminations"},
"incrust":{"incrust","incrusted","incrusting"},
"incrustation":{"incrustation","incrustations"},
"incubate":{"incubate","incubated","incubates","incubating"},
"incubation":{"incubation","incubations"},
"incubator":{"incubator","incubators"},
"incubus":{"incubi","incubus","incubuses"},
"inculcate":{"inculcate","inculcated","inculcates","inculcating"},
"inculcation":{"inculcation","inculcations"},
"inculpability":{"inculpabilities","inculpability"},
"inculpableness":{"inculpableness","inculpablenesses"},
"inculpate":{"inculpate","inculpated","inculpates","inculpating"},
"inculpation":{"inculpation","inculpations"},
"incumbency":{"incumbencies","incumbency"},
"incumbent":{"incumbent","incumbents"},
"incumber":{"incumber","incumbered","incumbering"},
"incumbrance":{"incumbrance","incumbrances"},
"incur":{"incur","incurred","incurring","incurs"},
"incurability":{"incurabilities","incurability"},
"incurable":{"incurable","incurables"},
"incurableness":{"incurableness","incurablenesses"},
"incursion":{"incursion","incursions"},
"incurvate":{"incurvate","incurvated","incurvating"},
"incus":{"incudes","incus","incuses"},
"indaba":{"indaba","indabas"},
"indebtedness":{"indebtedness","indebtednesses"},
"indecency":{"indecencies","indecency"},
"indecision":{"indecision","indecisions"},
"indecisiveness":{"indecisiveness","indecisivenesses"},
"indecorousness":{"indecorousness","indecorousnesses"},
"indecorum":{"indecorum","indecorums"},
"indefatigability":{"indefatigabilities","indefatigability"},
"indefatigableness":{"indefatigableness","indefatigablenesses"},
"indefiniteness":{"indefiniteness","indefinitenesses"},
"indefinity":{"indefinities","indefinity"},
"indelicacy":{"indelicacies","indelicacy"},
"indemnification":{"indemnification","indemnifications"},
"indemnify":{"indemnified","indemnifies","indemnify","indemnifying"},
"indemnity":{"indemnities","indemnity"},
"indent":{"indent","indented","indenting","indents"},
"indentation":{"indentation","indentations"},
"indenture":{"indenture","indentured","indentures","indenturing"},
"independence":{"independence","independences"},
"independency":{"independencies","independency"},
"independent":{"independent","independents"},
"inderal":{"inderal","inderals"},
"indeterminancy":{"indeterminancies","indeterminancy"},
"indeterminateness":{"indeterminateness","indeterminatenesses"},
"indetermination":{"indetermination","indeterminations"},
"index":{"index","indexed","indexes","indexing","indices"},
"india":{"india","indias"},
"indiaman":{"indiaman","indiamen"},
"indian":{"indian","indians"},
"indiana":{"indiana","indianas"},
"indianan":{"indianan","indianans"},
"indianapolis":{"indianapolis","indianapolises"},
"indic":{"indic","indics"},
"indicant":{"indicant","indicants"},
"indicate":{"indicate","indicated","indicates","indicating"},
"indicating":{"indicating","indicatings"},
"indication":{"indication","indications"},
"indicative":{"indicative","indicatives"},
"indicator":{"indicator","indicators"},
"indicatoridae":{"indicatoridae","indicatoridaes"},
"indict":{"indict","indicted","indicting"},
"indictability":{"indictabilities","indictability"},
"indictment":{"indictment","indictments"},
"indifference":{"indifference","indifferences"},
"indigence":{"indigence","indigences"},
"indigenousness":{"indigenousness","indigenousnesses"},
"indigestibility":{"indigestibilities","indigestibility"},
"indigestibleness":{"indigestibleness","indigestiblenesses"},
"indigestion":{"indigestion","indigestions"},
"indignation":{"indignation","indignations"},
"indignity":{"indignities","indignity"},
"indigo":{"indigo","indigoes","indigos"},
"indigofera":{"indigofera","indigoferas"},
"indigotin":{"indigotin","indigotins"},
"indiscipline":{"indiscipline","indisciplines"},
"indiscreetness":{"indiscreetness","indiscreetnesses"},
"indiscretion":{"indiscretion","indiscretions"},
"indispensability":{"indispensabilities","indispensability"},
"indispensable":{"indispensable","indispensables"},
"indispensableness":{"indispensableness","indispensablenesses"},
"indispose":{"indispose","indisposed","indisposes","indisposing"},
"indisposition":{"indisposition","indispositions"},
"indisputability":{"indisputabilities","indisputability"},
"indistinctness":{"indistinctness","indistinctnesses"},
"indistinguishability":{"indistinguishabilities","indistinguishability"},
"indite":{"indite","indited","indites","inditing"},
"indium":{"indium","indiums"},
"individual":{"individual","individuals"},
"individualism":{"individualism","individualisms"},
"individuality":{"individualities","individuality"},
"individualization":{"individualization","individualizations"},
"individualize":{"individualize","individualized","individualizes","individualizing"},
"individuate":{"individuate","individuated","individuating"},
"individuation":{"individuation","individuations"},
"indo-aryan":{"indo-aryan","indo-aryans"},
"indo-european":{"indo-european","indo-europeans"},
"indo-hittite":{"indo-hittite","indo-hittites"},
"indo-iranian":{"indo-iranian","indo-iranians"},
"indocin":{"indocin","indocins"},
"indoctrinate":{"indoctrinate","indoctrinated","indoctrinating"},
"indolence":{"indolence","indolences"},
"indomethacin":{"indomethacin","indomethacins"},
"indomitability":{"indomitabilities","indomitability"},
"indonesia":{"indonesia","indonesias"},
"indonesian":{"indonesian","indonesians"},
"indorse":{"indorse","indorsed","indorses","indorsing"},
"indri":{"indri","indris"},
"indriidae":{"indriidae","indriidaes"},
"indris":{"indris","indrises"},
"indubitability":{"indubitabilities","indubitability"},
"induce":{"induce","induced","induces","inducing"},
"inducement":{"inducement","inducements"},
"inducer":{"inducer","inducers"},
"inducing":{"inducing","inducings"},
"induct":{"induct","inducted","inducting","inducts"},
"inductance":{"inductance","inductances"},
"induction":{"induction","inductions"},
"indue":{"indue","indued","indues","induing"},
"indulge":{"indulge","indulged","indulges","indulging"},
"indulgence":{"indulgence","indulgences"},
"indulgency":{"indulgencies","indulgency"},
"indulging":{"indulging","indulgings"},
"indurate":{"indurate","indurated","indurating"},
"induration":{"induration","indurations"},
"indus":{"indus","induses"},
"indusium":{"indusia","indusium"},
"industrial":{"industrial","industrials"},
"industrialisation":{"industrialisation","industrialisations"},
"industrialist":{"industrialist","industrialists"},
"industrialization":{"industrialization","industrializations"},
"industrialize":{"industrialize","industrialized","industrializes","industrializing"},
"industriousness":{"industriousness","industriousnesses"},
"industry":{"industries","industry"},
"indwell":{"indwell","indwelling","indwells","indwelt"},
"inebriant":{"inebriant","inebriants"},
"inebriate":{"inebriate","inebriated","inebriates","inebriating"},
"inebriation":{"inebriation","inebriations"},
"inebriety":{"inebrieties","inebriety"},
"ineffectiveness":{"ineffectiveness","ineffectivenesses"},
"ineffectuality":{"ineffectualities","ineffectuality"},
"ineffectualness":{"ineffectualness","ineffectualnesses"},
"inefficaciousness":{"inefficaciousness","inefficaciousnesses"},
"inefficacy":{"inefficacies","inefficacy"},
"inefficiency":{"inefficiencies","inefficiency"},
"ineptitude":{"ineptitude","ineptitudes"},
"ineptness":{"ineptness","ineptnesses"},
"inequality":{"inequalities","inequality"},
"inequity":{"inequities","inequity"},
"inertia":{"inertia","inertias"},
"inessential":{"inessential","inessentials"},
"inevitability":{"inevitabilities","inevitability"},
"inevitableness":{"inevitableness","inevitablenesses"},
"inexactitude":{"inexactitude","inexactitudes"},
"inexactness":{"inexactness","inexactnesses"},
"inexorability":{"inexorabilities","inexorability"},
"inexorableness":{"inexorableness","inexorablenesses"},
"inexpedience":{"inexpedience","inexpediences"},
"inexpediency":{"inexpediencies","inexpediency"},
"infallible":{"infallible","infallibles"},
"infamy":{"infamies","infamy"},
"infancy":{"infancies","infancy"},
"infant":{"infant","infants"},
"infanta":{"infanta","infantas"},
"infante":{"infante","infantes"},
"infantry":{"infantries","infantry"},
"infantryman":{"infantryman","infantrymen"},
"infarct":{"infarct","infarcts"},
"infarction":{"infarction","infarctions"},
"infatuate":{"infatuate","infatuated","infatuating"},
"infatuation":{"infatuation","infatuations"},
"infeasibility":{"infeasibilities","infeasibility"},
"infect":{"infect","infected","infecting","infects"},
"infection":{"infection","infections"},
"infelicity":{"infelicities","infelicity"},
"infer":{"infer","inferred","inferring","infers"},
"inference":{"inference","inferences"},
"inferior":{"inferior","inferiors"},
"inferiority":{"inferiorities","inferiority"},
"inferno":{"inferno","infernos"},
"infertility":{"infertilities","infertility"},
"infest":{"infest","infested","infesting","infests"},
"infestation":{"infestation","infestations"},
"infidel":{"infidel","infidels"},
"infidelity":{"infidelities","infidelity"},
"infield":{"infield","infields"},
"infiltrate":{"infiltrate","infiltrated","infiltrates","infiltrating"},
"infiniteness":{"infiniteness","infinitenesses"},
"infinitesimal":{"infinitesimal","infinitesimals"},
"infinitive":{"infinitive","infinitives"},
"infinitude":{"infinitude","infinitudes"},
"infinity":{"infinities","infinity"},
"infirmary":{"infirmaries","infirmary"},
"infirmity":{"infirmities","infirmity"},
"infix":{"infix","infixed","infixes","infixing"},
"inflame":{"inflame","inflamed","inflames","inflaming"},
"inflaming":{"inflaming","inflamings"},
"inflammable":{"inflammable","inflammables"},
"inflammation":{"inflammation","inflammations"},
"inflate":{"inflate","inflated","inflates","inflating"},
"inflater":{"inflater","inflaters"},
"inflation":{"inflation","inflations"},
"inflator":{"inflator","inflators"},
"inflect":{"inflect","inflected","inflecting","inflects"},
"inflection":{"inflection","inflections"},
"inflexibility":{"inflexibilities","inflexibility"},
"inflexibleness":{"inflexibleness","inflexiblenesses"},
"inflexion":{"inflexion","inflexions"},
"inflict":{"inflict","inflicted","inflicting","inflicts"},
"infliction":{"infliction","inflictions"},
"inflorescence":{"inflorescence","inflorescences"},
"inflow":{"inflow","inflows"},
"influence":{"influence","influenced","influences","influencing"},
"influenza":{"influenza","influenzas"},
"influx":{"influx","influxes"},
"info":{"info","infos"},
"infold":{"infold","infolded","infolding"},
"infolding":{"infolding","infoldings"},
"inform":{"inform","informed","informing"},
"informality":{"informalities","informality"},
"informant":{"informant","informants"},
"information":{"information","informations"},
"informer":{"informer","informers"},
"informing":{"informing","informings"},
"infotainment":{"infotainment","infotainments"},
"infract":{"infract","infracted","infracting","infracts"},
"infraction":{"infraction","infractions"},
"infrared":{"infrared","infrareds"},
"infrastructure":{"infrastructure","infrastructures"},
"infrequency":{"infrequencies","infrequency"},
"infrigidation":{"infrigidation","infrigidations"},
"infringe":{"infringe","infringed","infringes","infringing"},
"infringement":{"infringement","infringements"},
"infundibulum":{"infundibula","infundibulum"},
"infuriate":{"infuriate","infuriated","infuriates","infuriating"},
"infuriation":{"infuriation","infuriations"},
"infuse":{"infuse","infused","infuses","infusing"},
"infusion":{"infusion","infusions"},
"infusoria":{"infusoria","infusorias"},
"ingather":{"ingather","ingathered","ingathering","ingathers"},
"ingathering":{"ingathering","ingatherings"},
"ingeniousness":{"ingeniousness","ingeniousnesses"},
"ingenuity":{"ingenuities","ingenuity"},
"ingenuousness":{"ingenuousness","ingenuousnesses"},
"inger":{"inger","ingers"},
"ingerman":{"ingerman","ingermen"},
"ingest":{"ingest","ingested","ingesting","ingests"},
"ingestion":{"ingestion","ingestions"},
"inglenook":{"inglenook","inglenooks"},
"ingot":{"ingot","ingots"},
"ingraft":{"ingraft","ingrafted","ingrafting","ingrafts"},
"ingrain":{"ingrain","ingrained","ingraining","ingrains"},
"ingraining":{"ingraining","ingrainings"},
"ingrate":{"ingrate","ingrates"},
"ingratiate":{"ingratiate","ingratiated","ingratiating"},
"ingratitude":{"ingratitude","ingratitudes"},
"ingredient":{"ingredient","ingredients"},
"ingress":{"ingress","ingresses"},
"ingrian":{"ingrian","ingrians"},
"ingroup":{"ingroup","ingroups"},
"ingulf":{"ingulf","ingulfed","ingulfing","ingulfs"},
"ingurgitate":{"ingurgitate","ingurgitated","ingurgitates","ingurgitating"},
"ingush":{"ingush","ingushes"},
"inhabit":{"inhabit","inhabited","inhabiting","inhabits"},
"inhabitancy":{"inhabitancies","inhabitancy"},
"inhabitant":{"inhabitant","inhabitants"},
"inhabitation":{"inhabitation","inhabitations"},
"inhalation":{"inhalation","inhalations"},
"inhalator":{"inhalator","inhalators"},
"inhale":{"inhale","inhaled","inhales","inhaling"},
"inhaler":{"inhaler","inhalers"},
"inharmoniousness":{"inharmoniousness","inharmoniousnesses"},
"inhere":{"inhere","inhered","inhering"},
"inherence":{"inherence","inherences"},
"inherency":{"inherencies","inherency"},
"inherit":{"inherit","inherited","inheriting","inherits"},
"inheritance":{"inheritance","inheritances"},
"inheritor":{"inheritor","inheritors"},
"inheritress":{"inheritress","inheritresses"},
"inheritrix":{"inheritrix","inheritrixes"},
"inhibit":{"inhibit","inhibited","inhibiting","inhibits"},
"inhibition":{"inhibition","inhibitions"},
"inhumaneness":{"inhumaneness","inhumanenesses"},
"inhumanity":{"inhumanities","inhumanity"},
"inhumation":{"inhumation","inhumations"},
"inhume":{"inhume","inhumed","inhuming"},
"iniquity":{"iniquities","iniquity"},
"initial":{"initial","initialed","initialing","initialled","initialling","initials"},
"initialization":{"initialization","initializations"},
"initiate":{"initiate","initiated","initiates","initiating"},
"initiation":{"initiation","initiations"},
"initiative":{"initiative","initiatives"},
"initiator":{"initiator","initiators"},
"inject":{"inject","injected","injecting","injects"},
"injectant":{"injectant","injectants"},
"injection":{"injection","injections"},
"injudiciousness":{"injudiciousness","injudiciousnesses"},
"injun":{"injun","injuns"},
"injunction":{"injunction","injunctions"},
"injure":{"injure","injured","injures","injuring"},
"injuriousness":{"injuriousness","injuriousnesses"},
"injury":{"injuries","injury"},
"injustice":{"injustice","injustices"},
"ink":{"ink","inked","inking"},
"inkberry":{"inkberries","inkberry"},
"inkling":{"inkling","inklings"},
"inkpad":{"inkpad","inkpads"},
"inkpot":{"inkpot","inkpots"},
"inky":{"inkier","inkiest","inky"},
"inlander":{"inlander","inlanders"},
"inlay":{"inlaid","inlay","inlaying","inlays"},
"inlet":{"inlet","inlets","inletting"},
"inmarriage":{"inmarriage","inmarriages"},
"inmate":{"inmate","inmates"},
"inn":{"inn","inns"},
"innards":{"innards","innardses"},
"innersole":{"innersole","innersoles"},
"innervate":{"innervate","innervated","innervating"},
"innerve":{"innerve","innerved","innerving"},
"inning":{"inning","innings"},
"innkeeper":{"innkeeper","innkeepers"},
"innocence":{"innocence","innocences"},
"innocency":{"innocencies","innocency"},
"innocense":{"innocense","innocenses"},
"innocent":{"innocent","innocents"},
"innovate":{"innovate","innovated","innovates","innovating"},
"innovation":{"innovation","innovations"},
"innovator":{"innovator","innovators"},
"innuendo":{"innuendo","innuendoes","innuendos"},
"innumerableness":{"innumerableness","innumerablenesses"},
"inocor":{"inocor","inocors"},
"inoculant":{"inoculant","inoculants"},
"inoculate":{"inoculate","inoculated","inoculates","inoculating"},
"inoculating":{"inoculating","inoculatings"},
"inoculation":{"inoculation","inoculations"},
"inoculum":{"inocula","inoculum"},
"inopportuneness":{"inopportuneness","inopportunenesses"},
"inordinateness":{"inordinateness","inordinatenesses"},
"inosculate":{"inosculate","inosculated","inosculating"},
"inosculation":{"inosculation","inosculations"},
"inpatient":{"inpatient","inpatients"},
"inpour":{"inpour","inpoured","inpouring","inpours"},
"inpouring":{"inpouring","inpourings"},
"input":{"input","inputs","inputted","inputting"},
"inquest":{"inquest","inquests"},
"inquietude":{"inquietude","inquietudes"},
"inquire":{"inquire","inquired","inquires","inquiring"},
"inquirer":{"inquirer","inquirers"},
"inquiring":{"inquiring","inquirings"},
"inquiry":{"inquiries","inquiry"},
"inquisition":{"inquisition","inquisitions"},
"inquisitiveness":{"inquisitiveness","inquisitivenesses"},
"inquisitor":{"inquisitor","inquisitors"},
"inquisitor-general":{"inquisitor-general","inquisitors-general"},
"inroad":{"inroad","inroads"},
"inrush":{"inrush","inrushes"},
"insalubriousness":{"insalubriousness","insalubriousnesses"},
"insalubrity":{"insalubrities","insalubrity"},
"insaneness":{"insaneness","insanenesses"},
"insanity":{"insanities","insanity"},
"inscribe":{"inscribe","inscribed","inscribes","inscribing"},
"inscription":{"inscription","inscriptions"},
"inscrutability":{"inscrutabilities","inscrutability"},
"insect":{"insect","insects"},
"insecta":{"insecta","insectas"},
"insectarium":{"insectaria","insectarium","insectariums"},
"insectary":{"insectaries","insectary"},
"insecticide":{"insecticide","insecticides"},
"insectifuge":{"insectifuge","insectifuges"},
"insectivora":{"insectivora","insectivoras"},
"insecurity":{"insecurities","insecurity"},
"inseminate":{"inseminate","inseminated","inseminates","inseminating"},
"insensibility":{"insensibilities","insensibility"},
"insensitiveness":{"insensitiveness","insensitivenesses"},
"insensitivity":{"insensitivities","insensitivity"},
"inseparable":{"inseparable","inseparables"},
"insert":{"insert","inserted","inserting","inserts"},
"insertion":{"insertion","insertions"},
"inset":{"inset","insets","insetting"},
"inside":{"inside","insides"},
"insight":{"insight","insights"},
"insightfulness":{"insightfulness","insightfulnesses"},
"insignia":{"insignia","insignias"},
"insignificancy":{"insignificancies","insignificancy"},
"insincerity":{"insincerities","insincerity"},
"insinuate":{"insinuate","insinuated","insinuates","insinuating"},
"insinuation":{"insinuation","insinuations"},
"insipidity":{"insipidities","insipidity"},
"insipidness":{"insipidness","insipidnesses"},
"insist":{"insist","insisted","insisting","insists"},
"insistence":{"insistence","insistences"},
"insistency":{"insistencies","insistency"},
"insisting":{"insisting","insistings"},
"insnare":{"insnare","insnared","insnares","insnaring"},
"insolate":{"insolate","insolated","insolating"},
"insolation":{"insolation","insolations"},
"insole":{"insole","insoles"},
"insolence":{"insolence","insolences"},
"insolubilize":{"insolubilize","insolubilized","insolubilizing"},
"insolvent":{"insolvent","insolvents"},
"insomniac":{"insomniac","insomniacs"},
"insouciance":{"insouciance","insouciances"},
"inspan":{"inspan","inspanned","inspanning","inspans"},
"inspect":{"inspect","inspected","inspecting","inspects"},
"inspection":{"inspection","inspections"},
"inspector":{"inspector","inspectors"},
"inspiration":{"inspiration","inspirations"},
"inspire":{"inspire","inspired","inspires","inspiring"},
"inspirit":{"inspirit","inspirited","inspiriting","inspirits"},
"inspissate":{"inspissate","inspissated","inspissating"},
"inspissation":{"inspissation","inspissations"},
"instability":{"instabilities","instability"},
"instal":{"instal","installed","installing","instals"},
"install":{"install","installed","installing","installs"},
"installation":{"installation","installations"},
"installing":{"installing","installings"},
"installment":{"installment","installments"},
"instalment":{"instalment","instalments"},
"instance":{"instance","instanced","instances","instancing"},
"instancy":{"instancies","instancy"},
"instant":{"instant","instants"},
"instantaneousness":{"instantaneousness","instantaneousnesses"},
"instantize":{"instantize","instantized","instantizing"},
"instar":{"instar","instarred","instarring"},
"instate":{"instate","instated","instating"},
"instauration":{"instauration","instaurations"},
"instigant":{"instigant","instigants"},
"instigate":{"instigate","instigated","instigates","instigating"},
"instigation":{"instigation","instigations"},
"instigator":{"instigator","instigators"},
"instil":{"instil","instilled","instilling","instils"},
"instill":{"instill","instilled","instilling"},
"instillation":{"instillation","instillations"},
"instilling":{"instilling","instillings"},
"instillment":{"instillment","instillments"},
"instilment":{"instilment","instilments"},
"instinct":{"instinct","instincts"},
"institute":{"institute","instituted","institutes","instituting"},
"institution":{"institution","institutions"},
"institutionalize":{"institutionalize","institutionalized","institutionalizes","institutionalizing"},
"instruct":{"instruct","instructed","instructing","instructs"},
"instruction":{"instruction","instructions"},
"instructions":{"instructions","instructionses"},
"instructor":{"instructor","instructors"},
"instrument":{"instrument","instrumented","instrumenting","instruments"},
"instrumental":{"instrumental","instrumentals"},
"instrumentalist":{"instrumentalist","instrumentalists"},
"instrumentality":{"instrumentalities","instrumentality"},
"instrumentation":{"instrumentation","instrumentations"},
"insubordination":{"insubordination","insubordinations"},
"insufficiency":{"insufficiencies","insufficiency"},
"insufflate":{"insufflate","insufflated","insufflating","insuffllated"},
"insula":{"insula","insulae"},
"insulant":{"insulant","insulants"},
"insularism":{"insularism","insularisms"},
"insularity":{"insularities","insularity"},
"insulate":{"insulate","insulated","insulates","insulating"},
"insulation":{"insulation","insulations"},
"insulator":{"insulator","insulators"},
"insult":{"insult","insulted","insulting","insults"},
"insurance":{"insurance","insurances"},
"insure":{"insure","insured","insures","insuring"},
"insurer":{"insurer","insurers"},
"insurgency":{"insurgencies","insurgency"},
"insurgent":{"insurgent","insurgents"},
"insurrection":{"insurrection","insurrections"},
"insurrectionary":{"insurrectionaries","insurrectionary"},
"insurrectionist":{"insurrectionist","insurrectionists"},
"intaglio":{"intagli","intaglio","intaglioed","intaglioing","intaglios"},
"intake":{"intake","intakes"},
"intangibility":{"intangibilities","intangibility"},
"intangible":{"intangible","intangibles"},
"intangibleness":{"intangibleness","intangiblenesses"},
"integer":{"integer","integers"},
"integral":{"integral","integrals"},
"integrate":{"integrate","integrated","integrates","integrating"},
"integrating":{"integrating","integratings"},
"integration":{"integration","integrations"},
"integrator":{"integrator","integrators"},
"integrity":{"integrities","integrity"},
"intellect":{"intellect","intellects"},
"intellection":{"intellection","intellections"},
"intellectual":{"intellectual","intellectuals"},
"intellectualize":{"intellectualize","intellectualized","intellectualizing"},
"intelligence":{"intelligence","intelligences"},
"intelligentsia":{"intelligentsia","intelligentsias"},
"intelligibility":{"intelligibilities","intelligibility"},
"intemperance":{"intemperance","intemperances"},
"intemperateness":{"intemperateness","intemperatenesses"},
"intend":{"intend","intended","intending","intends"},
"intendancy":{"intendancies","intendancy"},
"intenerate":{"intenerate","intenerated","intenerating"},
"intensifier":{"intensifier","intensifiers"},
"intensify":{"intensified","intensifies","intensify","intensifying"},
"intension":{"intension","intensions"},
"intensity":{"intensities","intensity"},
"intensive":{"intensive","intensives"},
"intensiveness":{"intensiveness","intensivenesses"},
"intent":{"intent","intents"},
"intention":{"intention","intentions"},
"intentness":{"intentness","intentnesses"},
"inter":{"inter","interred","interring","inters"},
"interact":{"interact","interacted","interacting"},
"interaction":{"interaction","interactions"},
"interbrain":{"interbrain","interbrains"},
"interbreed":{"interbred","interbreed","interbreeding","interbreeds"},
"interbreeding":{"interbreeding","interbreedings"},
"intercalate":{"intercalate","intercalated","intercalating"},
"intercalation":{"intercalation","intercalations"},
"intercede":{"intercede","interceded","intercedes","interceding"},
"intercept":{"intercept","intercepted","intercepting","intercepts"},
"intercession":{"intercession","intercessions"},
"interchange":{"interchange","interchanged","interchanges","interchanging"},
"interchangeability":{"interchangeabilities","interchangeability"},
"interchangeableness":{"interchangeableness","interchangeablenesses"},
"intercom":{"intercom","intercoms"},
"intercommunicate":{"intercommunicate","intercommunicated","intercommunicates","intercommunicating"},
"intercommunity":{"intercommunities","intercommunity"},
"interconnect":{"interconnect","interconnected","interconnecting","interconnects"},
"interconnectedness":{"interconnectedness","interconnectednesses"},
"interconnection":{"interconnection","interconnections"},
"intercostal":{"intercostal","intercostals"},
"intercourse":{"intercourse","intercourses"},
"intercrop":{"intercrop","intercropped","intercropping","intercrops"},
"intercross":{"intercross","intercrossed","intercrossing"},
"intercut":{"intercut","intercuts","intercutting"},
"interdependence":{"interdependence","interdependences"},
"interdependency":{"interdependencies","interdependency"},
"interdict":{"interdict","interdicted","interdicting","interdicts"},
"interdiction":{"interdiction","interdictions"},
"interdigitate":{"interdigitate","interdigitated","interdigitating"},
"interest":{"interest","interested","interesting","interests"},
"interestingness":{"interestingness","interestingnesses"},
"interface":{"interface","interfaces"},
"interfere":{"interfere","interfered","interferes","interfering"},
"interference":{"interference","interferences"},
"interfering":{"interfering","interferings"},
"interfold":{"interfold","interfolded","interfolding"},
"interfuse":{"interfuse","interfused","interfusing"},
"intergrade":{"intergrade","intergraded","intergrading"},
"interim":{"interim","interims"},
"interior":{"interior","interiors"},
"interiorize":{"interiorize","interiorized","interiorizes","interiorizing"},
"interject":{"interject","interjected","interjecting","interjects"},
"interjection":{"interjection","interjections"},
"interknit":{"interknit","interknitted","interknitting"},
"interlace":{"interlace","interlaced","interlaces","interlacing"},
"interlaminate":{"interlaminate","interlaminated","interlaminating"},
"interlanguage":{"interlanguage","interlanguages"},
"interlap":{"interlap","interlapped","interlapping","interlaps"},
"interlard":{"interlard","interlarded","interlarding","interlards"},
"interlay":{"interlaid","interlay","interlaying","interlays"},
"interleaf":{"interleaf","interleaves"},
"interleave":{"interleave","interleaved","interleaving"},
"interline":{"interline","interlined","interlining"},
"interlingua":{"interlingua","interlinguas"},
"interlink":{"interlink","interlinked","interlinking","interlinks"},
"interlock":{"interlock","interlocked","interlocking","interlocks"},
"interlocking":{"interlocking","interlockings"},
"interlocutor":{"interlocutor","interlocutors"},
"interlope":{"interlope","interloped","interloping"},
"interloper":{"interloper","interlopers"},
"interlude":{"interlude","interludes"},
"intermarriage":{"intermarriage","intermarriages"},
"intermarry":{"intermarried","intermarries","intermarry","intermarrying"},
"intermeddle":{"intermeddle","intermeddled","intermeddling"},
"intermediary":{"intermediaries","intermediary"},
"intermediate":{"intermediate","intermediated","intermediates","intermediating"},
"intermediation":{"intermediation","intermediations"},
"intermediator":{"intermediator","intermediators"},
"interment":{"interment","interments"},
"intermezzo":{"intermezzi","intermezzo","intermezzos"},
"intermingle":{"intermingle","intermingled","intermingles","intermingling"},
"intermission":{"intermission","intermissions"},
"intermit":{"intermit","intermits","intermitted","intermitting"},
"intermittence":{"intermittence","intermittences"},
"intermittency":{"intermittencies","intermittency"},
"intermix":{"intermix","intermixed","intermixes","intermixing"},
"intermixture":{"intermixture","intermixtures"},
"intern":{"intern","interned","interning","interns"},
"internal":{"internal","internals"},
"internalization":{"internalization","internalizations"},
"internalize":{"internalize","internalized","internalizes","internalizing"},
"international":{"international","internationals"},
"internationalisation":{"internationalisation","internationalisations"},
"internationalism":{"internationalism","internationalisms"},
"internationality":{"internationalities","internationality"},
"internationalization":{"internationalization","internationalizations"},
"internationalize":{"internationalize","internationalized","internationalizes","internationalizing"},
"interne":{"interne","internes"},
"internet":{"internet","internets"},
"internist":{"internist","internists"},
"internment":{"internment","internments"},
"internuncio":{"internuncio","internuncios"},
"interpellate":{"interpellate","interpellated","interpellating"},
"interpenetrate":{"interpenetrate","interpenetrated","interpenetrates","interpenetrating"},
"interplay":{"interplay","interplayed","interplaying"},
"interplead":{"interplead","interpleaded","interpleading","interpleads","interpled"},
"interpolate":{"interpolate","interpolated","interpolates","interpolating"},
"interpolation":{"interpolation","interpolations"},
"interpose":{"interpose","interposed","interposes","interposing"},
"interposition":{"interposition","interpositions"},
"interpret":{"interpret","interpreted","interpreting","interprets"},
"interpretation":{"interpretation","interpretations"},
"interpreter":{"interpreter","interpreters"},
"interpreting":{"interpreting","interpretings"},
"interregnum":{"interregna","interregnum","interregnums"},
"interrelate":{"interrelate","interrelated","interrelates","interrelating"},
"interrelatedness":{"interrelatedness","interrelatednesses"},
"interrelation":{"interrelation","interrelations"},
"interrelationship":{"interrelationship","interrelationships"},
"interrex":{"interreges","interrex"},
"interrogate":{"interrogate","interrogated","interrogates","interrogating"},
"interrogation":{"interrogation","interrogations"},
"interrogative":{"interrogative","interrogatives"},
"interrogator":{"interrogator","interrogators"},
"interrogatory":{"interrogatories","interrogatory"},
"interrupt":{"interrupt","interrupted","interrupting","interrupts"},
"interruption":{"interruption","interruptions"},
"intersect":{"intersect","intersected","intersecting","intersects"},
"intersection":{"intersection","intersections"},
"interspace":{"interspace","interspaced","interspacing"},
"interspersal":{"interspersal","interspersals"},
"intersperse":{"intersperse","interspersed","intersperses","interspersing"},
"interspersion":{"interspersion","interspersions"},
"interstate":{"interstate","interstates"},
"interstice":{"interstice","interstices"},
"interstratify":{"interstratified","interstratifies","interstratify","interstratifying"},
"intertangle":{"intertangle","intertangled","intertangling"},
"intertwine":{"intertwine","intertwined","intertwines","intertwining"},
"intertwist":{"intertwist","intertwisted","intertwisting"},
"interval":{"interval","intervals"},
"intervene":{"intervene","intervened","intervenes","intervening"},
"intervention":{"intervention","interventions"},
"interventionist":{"interventionist","interventionists"},
"interview":{"interview","interviewed","interviewing","interviews"},
"intervolve":{"intervolve","intervolved","intervolving"},
"interweave":{"interweave","interweaved","interweaves","interweaving","interwove","interwoven"},
"interwork":{"interwork","interworked","interworking","interwrought"},
"intestine":{"intestine","intestines"},
"intima":{"intima","intimae"},
"intimacy":{"intimacies","intimacy"},
"intimate":{"intimate","intimated","intimates","intimating"},
"intimation":{"intimation","intimations"},
"intimidate":{"intimidate","intimidated","intimidates","intimidating"},
"intimidation":{"intimidation","intimidations"},
"intonate":{"intonate","intonated","intonates","intonating"},
"intonation":{"intonation","intonations"},
"intone":{"intone","intoned","intones","intoning"},
"intoxicant":{"intoxicant","intoxicants"},
"intoxicate":{"intoxicate","intoxicated","intoxicates","intoxicating"},
"intoxication":{"intoxication","intoxications"},
"intractability":{"intractabilities","intractability"},
"intractableness":{"intractableness","intractablenesses"},
"intrados":{"intrados","intradoses"},
"intransigence":{"intransigence","intransigences"},
"intransigency":{"intransigencies","intransigency"},
"intransitiveness":{"intransitiveness","intransitivenesses"},
"intransitivity":{"intransitivities","intransitivity"},
"intrench":{"intrench","intrenched","intrenches","intrenching"},
"intrenchment":{"intrenchment","intrenchments"},
"intrepidity":{"intrepidities","intrepidity"},
"intricacy":{"intricacies","intricacy"},
"intrigue":{"intrigue","intrigued","intrigues","intriguing"},
"intro":{"intro","intros"},
"introduce":{"introduce","introduced","introduces","introducing"},
"introducer":{"introducer","introducers"},
"introduction":{"introduction","introductions"},
"intromission":{"intromission","intromissions"},
"intromit":{"intromit","intromits","intromitted","intromitting"},
"intropin":{"intropin","intropins"},
"introspect":{"introspect","introspected","introspecting"},
"introspection":{"introspection","introspections"},
"introvert":{"introvert","introverted","introverting","introverts"},
"intrude":{"intrude","intruded","intrudes","intruding"},
"intruder":{"intruder","intruders"},
"intrusion":{"intrusion","intrusions"},
"intrusiveness":{"intrusiveness","intrusivenesses"},
"intrust":{"intrust","intrusted","intrusting","intrusts"},
"intubate":{"intubate","intubated","intubating"},
"intuit":{"intuit","intuited","intuiting"},
"intuition":{"intuition","intuitions"},
"intumesce":{"intumesce","intumesced","intumescing"},
"intumescence":{"intumescence","intumescences"},
"intumescency":{"intumescencies","intumescency"},
"intussuscept":{"intussuscept","intussuscepted","intussuscepting"},
"intussusception":{"intussusception","intussusceptions"},
"inuit":{"inuit","inuits"},
"inunction":{"inunction","inunctions"},
"inundate":{"inundate","inundated","inundates","inundating"},
"inundation":{"inundation","inundations"},
"inure":{"inure","inured","inures","inuring"},
"inurn":{"inurn","inurned","inurning","inurns"},
"inutility":{"inutilities","inutility"},
"invade":{"invade","invaded","invades","invading"},
"invader":{"invader","invaders"},
"invaginate":{"invaginate","invaginated","invaginates","invaginating"},
"invagination":{"invagination","invaginations"},
"invalid":{"invalid","invalided","invaliding","invalids"},
"invalidate":{"invalidate","invalidated","invalidates","invalidating"},
"invalidation":{"invalidation","invalidations"},
"invalidity":{"invalidities","invalidity"},
"invalidness":{"invalidness","invalidnesses"},
"invaluableness":{"invaluableness","invaluablenesses"},
"invariability":{"invariabilities","invariability"},
"invariable":{"invariable","invariables"},
"invariableness":{"invariableness","invariablenesses"},
"invariance":{"invariance","invariances"},
"invasion":{"invasion","invasions"},
"invective":{"invective","invectives"},
"inveigh":{"inveigh","inveighed","inveighing","inveighs"},
"inveigle":{"inveigle","inveigled","inveigles","inveigling"},
"invent":{"invent","invented","inventing","invents"},
"invention":{"invention","inventions"},
"inventiveness":{"inventiveness","inventivenesses"},
"inventor":{"inventor","inventors"},
"inventory":{"inventoried","inventories","inventory","inventorying"},
"inventorying":{"inventorying","inventoryings"},
"inveracity":{"inveracities","inveracity"},
"inverse":{"inverse","inverses"},
"inversion":{"inversion","inversions"},
"invert":{"invert","inverted","inverting","inverts"},
"invest":{"invest","invested","investing","invests"},
"investigate":{"investigate","investigated","investigates","investigating"},
"investigating":{"investigating","investigatings"},
"investigation":{"investigation","investigations"},
"investigator":{"investigator","investigators"},
"investing":{"investing","investings"},
"investiture":{"investiture","investitures"},
"investment":{"investment","investments"},
"investor":{"investor","investors"},
"invidia":{"invidia","invidias"},
"invigorate":{"invigorate","invigorated","invigorates","invigorating"},
"invigoration":{"invigoration","invigorations"},
"invincibility":{"invincibilities","invincibility"},
"invisibility":{"invisibilities","invisibility"},
"invisible":{"invisible","invisibles"},
"invisibleness":{"invisibleness","invisiblenesses"},
"invitation":{"invitation","invitations"},
"invite":{"invite","invited","invites","inviting"},
"invitee":{"invitee","invitees"},
"invocate":{"invocate","invocated","invocating"},
"invocation":{"invocation","invocations"},
"invoice":{"invoice","invoiced","invoices","invoicing"},
"invoke":{"invoke","invoked","invokes","invoking"},
"involucel":{"involucel","involucels"},
"involucellum":{"involucella","involucellum"},
"involucre":{"involucre","involucres"},
"involucrum":{"involucra","involucrum"},
"involution":{"involution","involutions"},
"involve":{"involve","involved","involves","involving"},
"involvement":{"involvement","involvements"},
"invulnerability":{"invulnerabilities","invulnerability"},
"inward":{"inward","inwards"},
"inwardness":{"inwardness","inwardnesses"},
"inweave":{"inweave","inweaved","inweaves","inweaving","inwove","inwoven"},
"inwrap":{"inwrap","inwrapped","inwrapping","inwraps"},
"iodin":{"iodin","iodins"},
"iodine":{"iodine","iodines"},
"iodize":{"iodize","iodized","iodizes","iodizing"},
"iodoform":{"iodoform","iodoforms"},
"iodoprotein":{"iodoprotein","iodoproteins"},
"ionize":{"ionize","ionized","ionizing"},
"iota":{"iota","iotas"},
"iou":{"iou","ious"},
"iowa":{"iowa","iowas"},
"ioway":{"ioway","ioways"},
"ipidae":{"ipidae","ipidaes"},
"ipo":{"ipo","ipos"},
"ipomoea":{"ipomoea","ipomoeas"},
"ipsus":{"ipsus","ipsuses"},
"iq":{"iq","iqs"},
"ir":{"ir","irs"},
"ira":{"ira","iras"},
"irak":{"irak","iraks"},
"iraki":{"iraki","irakis"},
"iran":{"iran","irans"},
"irani":{"irani","iranis"},
"iranian":{"iranian","iranians"},
"iraq":{"iraq","iraqs"},
"iraqi":{"irakis","iraqi","iraqis"},
"irascibility":{"irascibilities","irascibility"},
"ire":{"ire","ires"},
"ireland":{"ireland","irelands"},
"irelander":{"irelander","irelanders"},
"irena":{"irena","irenas"},
"irenidae":{"irenidae","irenidaes"},
"iresine":{"iresine","iresines"},
"iridaceae":{"iridaceae","iridaceaes"},
"iridectomy":{"iridectomies","iridectomy"},
"iridescence":{"iridescence","iridescences"},
"iridium":{"iridium","iridiums"},
"iridoprocne":{"iridoprocne","iridoprocnes"},
"iridotomy":{"iridotomies","iridotomy"},
"iris":{"irides","iris","irises"},
"irish":{"irish","irishes"},
"irishman":{"irishman","irishmen"},
"irishwoman":{"irishwoman","irishwomen"},
"irk":{"irk","irked","irking","irks"},
"iron":{"iron","ironed","ironing","irons"},
"iron-gray":{"iron-gray","iron-grays"},
"iron-grey":{"iron-grey","iron-greys"},
"ironist":{"ironist","ironists"},
"ironmonger":{"ironmonger","ironmongers"},
"ironmongery":{"ironmongeries","ironmongery"},
"irons":{"irons","ironses"},
"irontree":{"irontree","irontrees"},
"ironware":{"ironware","ironwares"},
"ironweed":{"ironweed","ironweeds"},
"ironwood":{"ironwood","ironwoods"},
"irony":{"ironies","irony"},
"iroquoian":{"iroquoian","iroquoians"},
"iroquois":{"iroquois","iroquoises"},
"irradiate":{"irradiate","irradiated","irradiates","irradiating"},
"irradiation":{"irradiation","irradiations"},
"irrationality":{"irrationalities","irrationality"},
"irreality":{"irrealities","irreality"},
"irreconcilable":{"irreconcilable","irreconcilables"},
"irredenta":{"irredenta","irredentas"},
"irredentism":{"irredentism","irredentisms"},
"irredentist":{"irredentist","irredentists"},
"irregular":{"irregular","irregulars"},
"irregularity":{"irregularities","irregularity"},
"irrelevance":{"irrelevance","irrelevances"},
"irrelevancy":{"irrelevancies","irrelevancy"},
"irreligion":{"irreligion","irreligions"},
"irreligionist":{"irreligionist","irreligionists"},
"irreligiousness":{"irreligiousness","irreligiousnesses"},
"irrepressibility":{"irrepressibilities","irrepressibility"},
"irresoluteness":{"irresoluteness","irresolutenesses"},
"irresolution":{"irresolution","irresolutions"},
"irresponsibility":{"irresponsibilities","irresponsibility"},
"irresponsible":{"irresponsible","irresponsibles"},
"irresponsibleness":{"irresponsibleness","irresponsiblenesses"},
"irreverence":{"irreverence","irreverences"},
"irridenta":{"irridenta","irridentas"},
"irridentism":{"irridentism","irridentisms"},
"irridentist":{"irridentist","irridentists"},
"irrigate":{"irrigate","irrigated","irrigates","irrigating"},
"irritability":{"irritabilities","irritability"},
"irritant":{"irritant","irritants"},
"irritate":{"irritate","irritated","irritates","irritating"},
"irritation":{"irritation","irritations"},
"irrupt":{"irrupt","irrupted","irrupting","irrupts"},
"irs":{"irs","irses"},
"irtish":{"irtish","irtishes"},
"irtysh":{"irtysh","irtyshes"},
"irvingia":{"irvingia","irvingias"},
"isarithm":{"isarithm","isarithms"},
"isatis":{"isatis","isatises"},
"ischigualastia":{"ischigualastia","ischigualastias"},
"ischium":{"ischia","ischium","ischiums"},
"isere":{"isere","iseres"},
"ishtar":{"ishtar","ishtars"},
"isinglass":{"isinglass","isinglasses"},
"iskcon":{"iskcon","iskcons"},
"islam":{"islam","islams"},
"islamabad":{"islamabad","islamabads"},
"islamism":{"islamism","islamisms"},
"islamize":{"islamize","islamized","islamizing"},
"island":{"island","islanded","islanding","islands"},
"island-dweller":{"island-dweller","island-dwellers"},
"islander":{"islander","islanders"},
"islay":{"islay","islays"},
"isle":{"isle","isles"},
"islet":{"islet","islets"},
"ism":{"ism","isms"},
"isocarboxazid":{"isocarboxazid","isocarboxazids"},
"isocracy":{"isocracies","isocracy"},
"isoetaceae":{"isoetaceae","isoetaceaes"},
"isoetales":{"isoetales","isoetaleses"},
"isoetes":{"isoetes","isoeteses"},
"isogone":{"isogone","isogones"},
"isogram":{"isogram","isograms"},
"isolate":{"isolate","isolated","isolates","isolating"},
"isolation":{"isolation","isolations"},
"isolationist":{"isolationist","isolationists"},
"isopleth":{"isopleth","isopleths"},
"isopoda":{"isopoda","isopodas"},
"isopropanol":{"isopropanol","isopropanols"},
"isoptera":{"isoptera","isopteras"},
"isoptin":{"isoptin","isoptins"},
"isopyrum":{"isopyrum","isopyrums"},
"isospondyli":{"isospondyli","isospondylis"},
"israel":{"israel","israels"},
"israeli":{"israeli","israelis"},
"israelites":{"israelites","israeliteses"},
"issei":{"issei","isseis"},
"issuance":{"issuance","issuances"},
"issue":{"issue","issued","issues","issuing"},
"issuer":{"issuer","issuers"},
"issuing":{"issuing","issuings"},
"issus":{"issus","issuses"},
"istanbul":{"istanbul","istanbuls"},
"isthmus":{"isthmi","isthmus","isthmuses"},
"istiophoridae":{"istiophoridae","istiophoridaes"},
"istiophorus":{"istiophorus","istiophoruses"},
"isuridae":{"isuridae","isuridaes"},
"isurus":{"isurus","isuruses"},
"italia":{"italia","italias"},
"italianize":{"italianize","italianized","italianizing"},
"italic":{"italic","italics"},
"italicize":{"italicize","italicized","italicizing"},
"italy":{"italies","italy"},
"itch":{"itch","itched","itches","itching"},
"itching":{"itching","itchings"},
"itchy":{"itchier","itchiest","itchy"},
"item":{"item","items"},
"itemisation":{"itemisation","itemisations"},
"itemization":{"itemization","itemizations"},
"itemize":{"itemize","itemized","itemizes","itemizing"},
"iterate":{"iterate","iterated","iterates","iterating"},
"iteration":{"iteration","iterations"},
"ithunn":{"ithunn","ithunns"},
"itinerant":{"itinerant","itinerants"},
"itinerary":{"itineraries","itinerary"},
"itinerate":{"itinerate","itinerated","itinerating"},
"iv":{"iv","ivs"},
"iva":{"iva","ivas"},
"ivory":{"ivories","ivory"},
"ivorybill":{"ivorybill","ivorybills"},
"ivry":{"ivries","ivry"},
"ivy":{"ivies","ivy"},
"iwo":{"iwo","iwos"},
"ix":{"ix","ixes"},
"ixia":{"ixia","ixias"},
"ixobrychus":{"ixobrychus","ixobrychuses"},
"ixodes":{"ixodes","ixodeses"},
"ixodid":{"ixodid","ixodids"},
"ixodidae":{"ixodidae","ixodidaes"},
"iyar":{"iyar","iyars"},
"iyyar":{"iyyar","iyyars"},
"j":{"j","js"},
"jab":{"jab","jabbed","jabbing","jabs"},
"jabber":{"jabber","jabbered","jabbering","jabbers"},
"jabberer":{"jabberer","jabberers"},
"jabbering":{"jabbering","jabberings"},
"jabberwocky":{"jabberwockies","jabberwocky"},
"jabbing":{"jabbing","jabbings"},
"jabiru":{"jabiru","jabirus"},
"jaboncillo":{"jaboncillo","jaboncillos"},
"jaborandi":{"jaborandi","jaborandis"},
"jaboticaba":{"jaboticaba","jaboticabas"},
"jacal":{"jacal","jacales","jacals"},
"jacana":{"jacana","jacanas"},
"jacaranda":{"jacaranda","jacarandas"},
"jacinth":{"jacinth","jacinths"},
"jack":{"jack","jacked","jacking","jacks"},
"jack-a-lantern":{"jack-a-lantern","jack-a-lanterns"},
"jack-by-the-hedge":{"jack-by-the-hedge","jack-by-the-hedges"},
"jack-in-a-box":{"jack-in-a-box","jack-in-a-boxes"},
"jack-in-the-box":{"jack-in-the-box","jack-in-the-boxes","jacks-in-the-box"},
"jack-in-the-pulpit":{"jack-in-the-pulpit","jack-in-the-pulpits"},
"jack-o-lantern":{"jack-o-lantern","jack-o-lanterns"},
"jack-of-all-trades":{"jack-of-all-trades","jacks-of-all-trades"},
"jack-tar":{"jack-tar","jack-tars"},
"jackal":{"jackal","jackals"},
"jackanapes":{"jackanapes","jackanapeses"},
"jackaroo":{"jackaroo","jackeroos"},
"jackass":{"jackass","jackasses"},
"jackboot":{"jackboot","jackboots"},
"jackdaw":{"jackdaw","jackdaws"},
"jackeroo":{"jackeroo","jackeroos"},
"jacket":{"jacket","jacketed","jacketing","jackets"},
"jackfish":{"jackfish","jackfishes"},
"jackfruit":{"jackfruit","jackfruits"},
"jackhammer":{"jackhammer","jackhammers"},
"jackknife":{"jackknife","jackknifed","jackknifing","jackknives"},
"jackknife-fish":{"jackknife-fish","jackknife-fishes"},
"jackpot":{"jackpot","jackpots"},
"jacks":{"jacks","jackses"},
"jackscrew":{"jackscrew","jackscrews"},
"jacksmelt":{"jacksmelt","jacksmelts"},
"jacksnipe":{"jacksnipe","jacksnipes"},
"jackson":{"jackson","jacksons"},
"jacksonia":{"jacksonia","jacksonias"},
"jackstones":{"jackstones","jackstoneses"},
"jackstraw":{"jackstraw","jackstraws"},
"jackstraws":{"jackstraws","jackstrawses"},
"jacobus":{"jacobus","jacobuses"},
"jacquinia":{"jacquinia","jacquinias"},
"jactation":{"jactation","jactations"},
"jactitation":{"jactitation","jactitations"},
"jaculus":{"jaculus","jaculuses"},
"jade":{"jade","jaded","jades","jading"},
"jadestone":{"jadestone","jadestones"},
"jaffa":{"jaffa","jaffas"},
"jag":{"jag","jagged","jagging","jags"},
"jagannath":{"jagannath","jagannaths"},
"jagannatha":{"jagannatha","jagannathas"},
"jagatai":{"jagatai","jagatais"},
"jagganath":{"jagganath","jagganaths"},
"jaggary":{"jaggaries","jaggary"},
"jaggery":{"jaggeries","jaggery"},
"jagghery":{"jaggheries","jagghery"},
"jaggy":{"jaggier","jaggiest","jaggy"},
"jaghatai":{"jaghatai","jaghatais"},
"jagua":{"jagua","jaguas"},
"jaguar":{"jaguar","jaguars"},
"jaguarondi":{"jaguarondi","jaguarondis"},
"jaguarundi":{"jaguarundi","jaguarundis"},
"jahvey":{"jahvey","jahveys"},
"jahweh":{"jahweh","jahwehs"},
"jail":{"jail","jailed","jailing","jails"},
"jailbird":{"jailbird","jailbirds"},
"jailbreak":{"jailbreak","jailbreaks"},
"jailer":{"jailer","jailers"},
"jailhouse":{"jailhouse","jailhouses"},
"jailing":{"jailing","jailings"},
"jailor":{"jailor","jailors"},
"jak":{"jak","jaks"},
"jakarta":{"jakarta","jakartas"},
"jakes":{"jakes","jakeses"},
"jalapeno":{"jalapeno","jalapenos"},
"jaloppy":{"jaloppies","jaloppy"},
"jalopy":{"jalopies","jalopy"},
"jalousie":{"jalousie","jalousies"},
"jam":{"jam","jammed","jamming","jams"},
"jam-pack":{"jam-pack","jam-packed","jam-packing"},
"jambart":{"jambart","jambarts"},
"jambeau":{"jambeau","jambeaus","jambeaux"},
"jamber":{"jamber","jambers"},
"jamberry":{"jamberries","jamberry"},
"jambon":{"jambon","jambons"},
"jamboree":{"jamboree","jamborees"},
"jambos":{"jambos","jamboses"},
"jambosa":{"jambosa","jambosas"},
"james":{"james","jameses"},
"jamesonia":{"jamesonia","jamesonias"},
"jamjar":{"jamjar","jamjars"},
"jamming":{"jamming","jammings"},
"jammy":{"jammier","jammiest","jammy"},
"jampot":{"jampot","jampots"},
"jan":{"jan","jans"},
"jangle":{"jangle","jangled","jangles","jangling"},
"janissary":{"janissaries","janissary"},
"janitor":{"janitor","janitors"},
"janizary":{"janizaries","janizary"},
"jansen":{"jansen","jansens"},
"january":{"januaries","january"},
"jap":{"jap","japs"},
"japan":{"japan","japanned","japanning","japans"},
"japanese":{"japanese","japaneses"},
"jape":{"jape","japed","japes","japing"},
"japonica":{"japonica","japonicas"},
"jar":{"jar","jarred","jarring","jars"},
"jarful":{"jarful","jarfuls"},
"jargon":{"jargon","jargoned","jargoning","jargons"},
"jargonize":{"jargonize","jargonized","jargonizing"},
"jargoon":{"jargoon","jargoons"},
"jasminum":{"jasminum","jasminums"},
"jassidae":{"jassidae","jassidaes"},
"jat":{"jat","jats"},
"jato":{"jato","jatos"},
"jatropha":{"jatropha","jatrophas"},
"jaundice":{"jaundice","jaundiced","jaundices","jaundicing"},
"jaunt":{"jaunt","jaunted","jaunting","jaunts"},
"jauntiness":{"jauntiness","jauntinesses"},
"jaunty":{"jauntier","jauntiest","jaunty"},
"java":{"java","javas"},
"javanthropus":{"javanthropus","javanthropuses"},
"javelin":{"javelin","javelins"},
"javelina":{"javelina","javelinas"},
"jaw":{"jaw","jawed","jawing","jaws"},
"jawbone":{"jawbone","jawbones"},
"jaws":{"jaws","jawses"},
"jay":{"jay","jays"},
"jaybird":{"jaybird","jaybirds"},
"jaywalk":{"jaywalk","jaywalked","jaywalking"},
"jazz":{"jazz","jazzed","jazzing","jazzs"},
"jazzman":{"jazzman","jazzmen"},
"jazzy":{"jazzier","jazziest","jazzy"},
"jealousy":{"jealousies","jealousy"},
"jean":{"jean","jeans"},
"jeep":{"jeep","jeeps"},
"jeer":{"jeer","jeered","jeering","jeers"},
"jeering":{"jeering","jeerings"},
"jefferson":{"jefferson","jeffersons"},
"jehad":{"jehad","jehads"},
"jehovah":{"jehovah","jehovahs"},
"jehu":{"jehu","jehus"},
"jejuneness":{"jejuneness","jejunenesses"},
"jejunity":{"jejunities","jejunity"},
"jell":{"jell","jelled","jelling","jells"},
"jellify":{"jellified","jellifies","jellify","jellifying"},
"jelly":{"jellied","jellies","jelly","jellying"},
"jellyfish":{"jellyfish","jellyfishes"},
"jellyleaf":{"jellyleaf","jellyleaves"},
"jemmy":{"jemmies","jemmy"},
"jena":{"jena","jenas"},
"jennet":{"jennet","jennets"},
"jenny":{"jennies","jenny"},
"jeopard":{"jeopard","jeoparded","jeoparding"},
"jeopardize":{"jeopardize","jeopardized","jeopardizes","jeopardizing"},
"jeopardy":{"jeopardies","jeopardy"},
"jequerity":{"jequerities","jequerity"},
"jequirity":{"jequirities","jequirity"},
"jerboa":{"jerboa","jerboas"},
"jerevan":{"jerevan","jerevans"},
"jerez":{"jerez","jerezs"},
"jerk":{"jerk","jerked","jerking","jerks"},
"jerkin":{"jerkin","jerkins"},
"jerkiness":{"jerkiness","jerkinesses"},
"jerking":{"jerking","jerkings"},
"jerky":{"jerkier","jerkies","jerkiest","jerky"},
"jerry":{"jerries","jerry"},
"jerry-build":{"jerry-build","jerry-building","jerry-builds","jerry-built"},
"jersey":{"jersey","jerseys"},
"jerusalem":{"jerusalem","jerusalems"},
"jessamine":{"jessamine","jessamines"},
"jest":{"jest","jested","jesting","jests"},
"jester":{"jester","jesters"},
"jesuitism":{"jesuitism","jesuitisms"},
"jesuitry":{"jesuitries","jesuitry"},
"jesus":{"jesus","jesuses"},
"jet":{"jet","jets","jetted","jetting"},
"jets":{"jets","jetses"},
"jetsam":{"jetsam","jetsams"},
"jettison":{"jettison","jettisoned","jettisoning"},
"jetty":{"jetties","jetty"},
"jew":{"jew","jewed","jewing","jews"},
"jew-baiter":{"jew-baiter","jew-baiters"},
"jewbush":{"jewbush","jewbushes"},
"jewel":{"jewel","jeweled","jeweling","jewelled","jewelling","jewels"},
"jeweler":{"jeweler","jewelers"},
"jewelfish":{"jewelfish","jewelfishes"},
"jeweller":{"jeweller","jewellers"},
"jewellery":{"jewelleries","jewellery"},
"jewelry":{"jewelries","jewelry"},
"jewels-of-opar":{"jewels-of-opar","jewels-of-opars"},
"jewelweed":{"jewelweed","jewelweeds"},
"jewfish":{"jewfish","jewfishes"},
"jewry":{"jewries","jewry"},
"jib":{"jib","jibbed","jibbing","jibs"},
"jibe":{"jibe","jibed","jibes","jibing"},
"jiff":{"jiff","jiffs"},
"jiffy":{"jiffies","jiffy"},
"jig":{"jig","jigged","jigging","jigs"},
"jigaboo":{"jigaboo","jigaboos"},
"jigger":{"jigger","jiggered","jiggering","jiggers"},
"jiggermast":{"jiggermast","jiggermasts"},
"jiggery-pokery":{"jiggery-pokeries","jiggery-pokery"},
"jiggle":{"jiggle","jiggled","jiggles","jiggling"},
"jigsaw":{"jigsaw","jigsaws"},
"jihad":{"jihad","jihads"},
"jillion":{"jillion","jillions"},
"jillions":{"jillions","jillionses"},
"jilt":{"jilt","jilted","jilting"},
"jim-crow":{"jim-crow","jim-crowed","jim-crowing"},
"jimdandy":{"jimdandies","jimdandy"},
"jimhickey":{"jimhickey","jimhickeys"},
"jimmies":{"jimmies","jimmieses"},
"jimmy":{"jimmied","jimmies","jimmy","jimmying"},
"jimpsonweed":{"jimpsonweed","jimpsonweeds"},
"jimsonweed":{"jimsonweed","jimsonweeds"},
"jinghpaw":{"jinghpaw","jinghpaws"},
"jinghpo":{"jinghpo","jinghpos"},
"jingle":{"jingle","jingled","jingles","jingling"},
"jingo":{"jingo","jingoes"},
"jingoism":{"jingoism","jingoisms"},
"jingoist":{"jingoist","jingoists"},
"jink":{"jink","jinked","jinking"},
"jinks":{"jinks","jinkses"},
"jinnee":{"jinnee","jinnees"},
"jinni":{"jinn","jinni","jinnis"},
"jinrikisha":{"jinrikisha","jinrikishas"},
"jinx":{"jinx","jinxes"},
"jipijapa":{"jipijapa","jipijapas"},
"jiqui":{"jiqui","jiquis"},
"jirrbal":{"jirrbal","jirrbals"},
"jitney":{"jitney","jitneys"},
"jitter":{"jitter","jittered","jittering","jitters"},
"jitterbug":{"jitterbug","jitterbugged","jitterbugging","jitterbugs"},
"jitteriness":{"jitteriness","jitterinesses"},
"jitters":{"jitters","jitterses"},
"jittery":{"jitterier","jitteriest","jittery"},
"jiujitsu":{"jiujitsu","jiujitsus"},
"jivaro":{"jivaro","jivaros"},
"jive":{"jive","jived","jives","jiving"},
"jnr":{"jnr","jnrs"},
"jo":{"jo","joes"},
"job":{"job","jobbed","jobbing","jobs"},
"job-hop":{"job-hop","job-hopped","job-hopping","job-hops"},
"jobber":{"jobber","jobbers"},
"jock":{"jock","jocks"},
"jockey":{"jockey","jockeyed","jockeying","jockeys"},
"jocko":{"jocko","jockos"},
"jockstrap":{"jockstrap","jockstraps"},
"jocoseness":{"jocoseness","jocosenesses"},
"jocosity":{"jocosities","jocosity"},
"jocote":{"jocote","jocotes"},
"jocularity":{"jocularities","jocularity"},
"jocundity":{"jocundities","jocundity"},
"jodphur":{"jodphur","jodphurs"},
"joe":{"joe","joes"},
"joewood":{"joewood","joewoods"},
"joey":{"joey","joeys"},
"jog":{"jog","jogged","jogging","jogs"},
"jog-trot":{"jog-trot","jog-trots","jog-trotted","jog-trotting"},
"joggle":{"joggle","joggled","joggles","joggling"},
"john":{"john","johns"},
"johnny":{"johnnies","johnny"},
"johnny-jump-up":{"johnny-jump-up","johnny-jump-ups"},
"johnnycake":{"johnnycake","johnnycakes"},
"johnson":{"johnson","johnsons"},
"join":{"join","joined","joining","joins"},
"joinery":{"joineries","joinery"},
"joining":{"joining","joinings"},
"joint":{"joint","jointed","jointing","joints"},
"jointer":{"jointer","jointers"},
"jointworm":{"jointworm","jointworms"},
"join_battle":{"joined_batted","joining_battle","joins_battle","join_battle"},
"joke":{"joke","joked","jokes","joking"},
"joker":{"joker","jokers"},
"jokester":{"jokester","jokesters"},
"jollification":{"jollification","jollifications"},
"jollify":{"jollified","jollifies","jollify","jollifying"},
"jollity":{"jollities","jollity"},
"jolly":{"jollied","jollier","jollies","jolliest","jolly","jollying"},
"jolt":{"jolt","jolted","jolting","jolts"},
"jolty":{"joltier","joltiest","jolty"},
"jonah":{"jonah","jonahs"},
"jongleur":{"jongleur","jongleurs"},
"jonquil":{"jonquil","jonquils"},
"joppa":{"joppa","joppas"},
"jordan":{"jordan","jordans"},
"jordanella":{"jordanella","jordanellas"},
"josh":{"josh","joshed","joshing"},
"joshua":{"joshua","joshuas"},
"jostle":{"jostle","jostled","jostles","jostling"},
"jostling":{"jostling","jostlings"},
"josue":{"josue","josues"},
"jot":{"jot","jots","jotted","jotting"},
"jotter":{"jotter","jotters"},
"jotting":{"jotting","jottings"},
"jotun":{"jotun","jotuns"},
"jotunn":{"jotunn","jotunns"},
"joule":{"joule","joules"},
"jounce":{"jounce","jounced","jounces","jouncing"},
"jouncy":{"jouncier","jounciest","jouncy"},
"journal":{"journal","journals"},
"journalism":{"journalism","journalisms"},
"journalist":{"journalist","journalists"},
"journalize":{"journalize","journalized","journalizing"},
"journey":{"journey","journeyed","journeying","journeys"},
"journeyer":{"journeyer","journeyers"},
"journeying":{"journeying","journeyings"},
"journeyman":{"journeyman","journeymen"},
"journo":{"journo","journos"},
"joust":{"joust","jousted","jousting","jousts"},
"jove":{"jove","joves"},
"joviality":{"jovialities","joviality"},
"jowl":{"jowl","jowls"},
"jowly":{"jowlier","jowliest","jowly"},
"joy":{"joy","joyed","joying","joys"},
"joy-ride":{"joy-ridden","joy-ride","joy-rides","joy-riding","joy-rode"},
"joyfulness":{"joyfulness","joyfulnesses"},
"joyousness":{"joyousness","joyousnesses"},
"joypop":{"joypop","joypopped","joypopping","joypops"},
"joystick":{"joystick","joysticks"},
"jr":{"jr","jrs"},
"juarez":{"juarez","juarezs"},
"jubilance":{"jubilance","jubilances"},
"jubilancy":{"jubilancies","jubilancy"},
"jubilate":{"jubilate","jubilated","jubilates","jubilating"},
"jubilation":{"jubilation","jubilations"},
"jubilee":{"jubilee","jubilees"},
"judaism":{"judaism","judaisms"},
"judaize":{"judaize","judaized","judaizes","judaizing"},
"judas":{"judas","judases"},
"judder":{"judder","juddered","juddering","judders"},
"judge":{"judge","judged","judges","judging"},
"judgement":{"judgement","judgements"},
"judgeship":{"judgeship","judgeships"},
"judge_advocate_general":{"judge_advocates_general","judge_advocate_general","judge_advocate_generals"},
"judging":{"judging","judgings"},
"judgment":{"judgment","judgments"},
"judgship":{"judgship","judgships"},
"judicatory":{"judicatories","judicatory"},
"judicature":{"judicature","judicatures"},
"judiciary":{"judiciaries","judiciary"},
"judiciousness":{"judiciousness","judiciousnesses"},
"judo":{"judo","judos"},
"judy":{"judies","judy"},
"jug":{"jug","jugged","jugging","jugs"},
"jugful":{"jugful","jugfuls"},
"juggernaut":{"juggernaut","juggernauts"},
"juggle":{"juggle","juggled","juggles","juggling"},
"juggling":{"juggling","jugglings"},
"juglandaceae":{"juglandaceae","juglandaceaes"},
"juglandales":{"juglandales","juglandaleses"},
"juglans":{"juglans","juglanses"},
"jugoslav":{"jugoslav","jugoslavs"},
"jugoslavia":{"jugoslavia","jugoslavias"},
"jugoslavian":{"jugoslavian","jugoslavians"},
"jugular":{"jugular","jugulars"},
"juice":{"juice","juiced","juices","juicing"},
"juicer":{"juicer","juicers"},
"juiciness":{"juiciness","juicinesses"},
"juicy":{"juicier","juiciest","juicy"},
"jujitsu":{"jujitsu","jujitsus"},
"juju":{"juju","jujus"},
"jujube":{"jujube","jujubes"},
"jukebox":{"jukebox","jukeboxes"},
"julep":{"julep","juleps"},
"july":{"julies","july"},
"jumbal":{"jumbal","jumbals"},
"jumble":{"jumble","jumbled","jumbles","jumbling"},
"jumbo":{"jumbo","jumbos"},
"jument":{"jument","juments"},
"jump":{"jump","jumped","jumping","jumps"},
"jump-start":{"jump-start","jump-started","jump-starting"},
"jumper":{"jumper","jumpers"},
"jumpiness":{"jumpiness","jumpinesses"},
"jumping":{"jumping","jumpings"},
"jumpsuit":{"jumpsuit","jumpsuits"},
"jumpy":{"jumpier","jumpiest","jumpy"},
"jump_off":{"jumped_off","jumping_off","jumps_off","jump_off"},
"juncaceae":{"juncaceae","juncaceaes"},
"juncaginaceae":{"juncaginaceae","juncaginaceaes"},
"junco":{"junco","juncoes","juncos"},
"junction":{"junction","junctions"},
"juncture":{"juncture","junctures"},
"juncus":{"juncus","juncuses"},
"juneau":{"juneau","juneaus"},
"juneberry":{"juneberries","juneberry"},
"jung":{"jung","jungs"},
"jungermanniaceae":{"jungermanniaceae","jungermanniaceaes"},
"jungermanniales":{"jungermanniales","jungermannialeses"},
"jungle":{"jungle","jungles"},
"junior":{"junior","juniors"},
"juniper":{"juniper","junipers"},
"juniperus":{"juniperus","juniperuses"},
"junk":{"junk","junked","junking","junks"},
"junket":{"junket","junketed","junketing","junkets"},
"junkie":{"junkie","junkies"},
"junkman":{"junkman","junkmen"},
"junky":{"junkier","junkies","junkiest","junky"},
"junta":{"junta","juntas"},
"junto":{"junto","juntos"},
"jupati":{"jupati","jupatis"},
"jupaty":{"jupaties","jupaty"},
"jupiter":{"jupiter","jupiters"},
"jurassic":{"jurassic","jurassics"},
"jurisdiction":{"jurisdiction","jurisdictions"},
"jurisprudence":{"jurisprudence","jurisprudences"},
"jurist":{"jurist","jurists"},
"juror":{"juror","jurors"},
"jury":{"juries","jury"},
"juryman":{"juryman","jurymen"},
"jurywoman":{"jurywoman","jurywomen"},
"jus":{"jura","jus"},
"justice":{"justice","justices"},
"justiciar":{"justiciar","justiciars"},
"justiciary":{"justiciaries","justiciary"},
"justifier":{"justifier","justifiers"},
"justify":{"justified","justifies","justify","justifying"},
"justle":{"justle","justled","justling"},
"justness":{"justness","justnesses"},
"jut":{"jut","juts","jutted","jutting"},
"jutish":{"jutish","jutishes"},
"jutting":{"jutting","juttings"},
"jutty":{"juttied","jutties","jutty","juttying"},
"juvenile":{"juvenile","juveniles"},
"juvenility":{"juvenilities","juvenility"},
"juxtapose":{"juxtapose","juxtaposed","juxtaposing"},
"jynx":{"jynx","jynxes"},
"k":{"k","ks"},
"k-meson":{"k-meson","k-mesons"},
"kabala":{"kabala","kabalas"},
"kabbala":{"kabbala","kabbalas"},
"kabbalah":{"kabbalah","kabbalahs"},
"kabob":{"kabob","kabobs"},
"kabolin":{"kabolin","kabolins"},
"kabul":{"kabul","kabuls"},
"kabyle":{"kabyle","kabyles"},
"kachin":{"kachin","kachins"},
"kachinic":{"kachinic","kachinics"},
"kadai":{"kadai","kadais"},
"kaddish":{"kaddish","kaddishim"},
"kadi":{"kadi","kadis"},
"kaffir":{"kaffir","kaffirs"},
"kafir":{"kafir","kafirs"},
"kafka":{"kafka","kafkas"},
"kaftan":{"kaftan","kaftans"},
"kahikatea":{"kahikatea","kahikateas"},
"kahoolawe":{"kahoolawe","kahoolawes"},
"kail":{"kail","kails"},
"kainogenesis":{"kainogeneses","kainogenesis"},
"kaka":{"kaka","kakas"},
"kakapo":{"kakapo","kakapos"},
"kakatoe":{"kakatoe","kakatoes"},
"kakemono":{"kakemono","kakemonos"},
"kaki":{"kaki","kakis"},
"kala-azar":{"kala-azar","kala-azars"},
"kalahari":{"kalahari","kalaharis"},
"kalantas":{"kalantas","kalantases"},
"kalapooia":{"kalapooia","kalapooias"},
"kalapooian":{"kalapooian","kalapooians"},
"kalapuya":{"kalapuya","kalapuyas"},
"kalapuyan":{"kalapuyan","kalapuyans"},
"kale":{"kale","kales"},
"kali":{"kali","kalis"},
"kalian":{"kalian","kalians"},
"kalif":{"kalif","kalifs"},
"kalimantan":{"kalimantan","kalimantans"},
"kaliph":{"kaliph","kaliphs"},
"kalka":{"kalka","kalkas"},
"kalmuc":{"kalmuc","kalmuck","kalmucks"},
"kalmuck":{"kalmuck","kalmucks"},
"kalmyk":{"kalmyk","kalmyks"},
"kalotermes":{"kalotermes","kalotermeses"},
"kalotermitidae":{"kalotermitidae","kalotermitidaes"},
"kalumpang":{"kalumpang","kalumpangs"},
"kam-tai":{"kam-tai","kam-tais"},
"kamala":{"kamala","kamalas"},
"kampala":{"kampala","kampalas"},
"kampong":{"kampong","kampongs"},
"kampuchea":{"kampuchea","kampucheas"},
"kampuchean":{"kampuchean","kampucheans"},
"kana":{"kana","kanas"},
"kanaf":{"kanaf","kanafs"},
"kanarese":{"kanarese","kanareses"},
"kanawha":{"kanawha","kanawhas"},
"kanchanjanga":{"kanchanjanga","kanchanjangas"},
"kanchenjunga":{"kanchenjunga","kanchenjungas"},
"kanchil":{"kanchil","kanchils"},
"kangaroo":{"kangaroo","kangaroos"},
"kanji":{"kanji","kanjis"},
"kannada":{"kannada","kannadas"},
"kansa":{"kansa","kansas"},
"kansas":{"kansas","kansases"},
"kansu":{"kansu","kansus"},
"kant":{"kant","kants"},
"kanuri":{"kanuri","kanuris"},
"kaolin":{"kaolin","kaolins"},
"kaoline":{"kaoline","kaolines"},
"kaolinize":{"kaolinize","kaolinized","kaolinizes","kaolinizing"},
"kaon":{"kaon","kaons"},
"kapellmeister":{"kapellmeister","kapellmeisters"},
"kapok":{"kapok","kapoks"},
"kappa":{"kappa","kappas"},
"kappa-meson":{"kappa-meson","kappa-mesons"},
"kapsiki":{"kapsiki","kapsikis"},
"kapuka":{"kapuka","kapukas"},
"kara-kalpak":{"kara-kalpak","kara-kalpaks"},
"karabiner":{"karabiner","karabiners"},
"karakoram":{"karakoram","karakorams"},
"karakul":{"karakul","karakuls"},
"karat":{"karat","karats"},
"karelian":{"karelian","karelians"},
"karen":{"karen","karens"},
"karenic":{"karenic","karenics"},
"karoo":{"karoo","karoos"},
"karroo":{"karroo","karroos"},
"kartikeya":{"kartikeya","kartikeyas"},
"karttikeya":{"karttikeya","karttikeyas"},
"karyoplasm":{"karyoplasm","karyoplasms"},
"kashmir":{"kashmir","kashmirs"},
"kashmiri":{"kashmiri","kashmiris"},
"kassite":{"kassite","kassites"},
"katabasis":{"katabases","katabasis"},
"katabolism":{"katabolism","katabolisms"},
"katar":{"katar","katars"},
"katari":{"katari","kataris"},
"katharsis":{"katharses","katharsis"},
"kathmandu":{"kathmandu","kathmandus"},
"katmandu":{"katmandu","katmandus"},
"katsuwonidae":{"katsuwonidae","katsuwonidaes"},
"katsuwonus":{"katsuwonus","katsuwonuses"},
"kauai":{"kauai","kauais"},
"kaunas":{"kaunas","kaunases"},
"kauri":{"kauri","kauris"},
"kaury":{"kauries","kaury"},
"kava":{"kava","kavas"},
"kavakava":{"kavakava","kavakavas"},
"kawaka":{"kawaka","kawakas"},
"kayo":{"kayo","kayoed","kayoing","kayos"},
"kazak":{"kazak","kazaks"},
"kazakh":{"kazakh","kazakhs"},
"kazakhstan":{"kazakhstan","kazakhstans"},
"kazakstan":{"kazakstan","kazakstans"},
"kazoo":{"kazoo","kazoos"},
"kb":{"kb","kbs"},
"kc":{"kc","kcs"},
"kea":{"kea","keas"},
"keb":{"keb","kebs"},
"kebab":{"kebab","kebabs"},
"keck":{"keck","kecked","kecking"},
"kedge":{"kedge","kedged","kedging"},
"keek":{"keek","keeked","keeking"},
"keel":{"keel","keeled","keeling","keels"},
"keelhaul":{"keelhaul","keelhauled","keelhauling"},
"keen":{"keen","keened","keener","keenest","keening"},
"keenness":{"keenness","keennesses"},
"keep":{"keep","keeping","keeps","kept"},
"keeper":{"keeper","keepers"},
"keeping":{"keeping","keepings"},
"keepsake":{"keepsake","keepsakes"},
"keeshond":{"keeshond","keeshonden","keeshonds"},
"keflex":{"keflex","keflexes"},
"keftab":{"keftab","keftabs"},
"keg":{"keg","kegs"},
"kegful":{"kegful","kegfuls"},
"keister":{"keister","keisters"},
"kelpie":{"kelpie","kelpies"},
"kelpwort":{"kelpwort","kelpworts"},
"kelt":{"kelt","kelts"},
"kelvin":{"kelvin","kelvins"},
"ken":{"ken","kenned","kenning","kens","kent"},
"kenaf":{"kenaf","kenafs"},
"kennedia":{"kennedia","kennedias"},
"kennedy":{"kennedies","kennedy"},
"kennedya":{"kennedya","kennedyas"},
"kennel":{"kennel","kenneled","kenneling","kennelled","kennelling","kennels"},
"keno":{"keno","kenos"},
"kenogenesis":{"kenogeneses","kenogenesis"},
"kentan":{"kentan","kentans"},
"kentish":{"kentish","kentishes"},
"kentucky":{"kentuckies","kentucky"},
"kenyapithecus":{"kenyapithecus","kenyapithecuses"},
"kepi":{"kepi","kepis"},
"kepler":{"kepler","keplers"},
"keratectomy":{"keratectomies","keratectomy"},
"keratin":{"keratin","keratins"},
"keratinize":{"keratinize","keratinized","keratinizing"},
"keratoplasty":{"keratoplasties","keratoplasty"},
"keratosis":{"keratoses","keratosis"},
"kerb":{"kerb","kerbs"},
"kerbstone":{"kerbstone","kerbstones"},
"kerchief":{"kerchief","kerchiefs","kerchieves"},
"kern":{"kern","kerned","kerning","kerns"},
"kernel":{"kernel","kerneled","kerneling","kernelled","kernelling","kernels"},
"kerosene":{"kerosene","kerosenes"},
"kerosine":{"kerosine","kerosines"},
"kerry":{"kerries","kerry"},
"kerugma":{"kerugma","kerugmas"},
"kerygma":{"kerygma","kerygmas"},
"kestrel":{"kestrel","kestrels"},
"ketchup":{"ketchup","ketchups"},
"ketembilla":{"ketembilla","ketembillas"},
"ketoaciduria":{"ketoaciduria","ketoacidurias"},
"ketonemia":{"ketonemia","ketonemias"},
"ketonuria":{"ketonuria","ketonurias"},
"ketoprofen":{"ketoprofen","ketoprofens"},
"ketorolac":{"ketorolac","ketorolacs"},
"ketosis":{"ketoses","ketosis"},
"kettle":{"kettle","kettles"},
"kettledrum":{"kettledrum","kettledrums"},
"kettleful":{"kettleful","kettlefuls"},
"keurboom":{"keurboom","keurbooms"},
"key":{"key","keyed","keying","keys"},
"keyboard":{"keyboard","keyboarded","keyboarding","keyboards"},
"keynes":{"keynes","keyneses"},
"keynote":{"keynote","keynoted","keynotes","keynoting"},
"keypunch":{"keypunch","keypunched","keypunching"},
"keystone":{"keystone","keystones"},
"kg":{"kg","kgs"},
"khaki":{"khaki","khakis"},
"khalif":{"khalif","khalifs"},
"khalka":{"khalka","khalkas"},
"khalkha":{"khalkha","khalkhas"},
"khan":{"khan","khans"},
"khanty":{"khanties","khanty"},
"khartoum":{"khartoum","khartoums"},
"khaya":{"khaya","khayas"},
"khesari":{"khesari","khesaris"},
"khirghiz":{"khirghiz","khirghizs"},
"khmer":{"khmer","khmers"},
"khoikhoi":{"khoikhoi","khoikhois"},
"khoikhoin":{"khoikhoin","khoikhoins"},
"khoisan":{"khoisan","khoisans"},
"khz":{"khz","khzs"},
"kiaat":{"kiaat","kiaats"},
"kiang":{"kiang","kiangs"},
"kibble":{"kibble","kibbled","kibbles","kibbling"},
"kibbutz":{"kibbutz","kibbutzim"},
"kibei":{"kebei","kebeis","kibei"},
"kibitz":{"kibitz","kibitzed","kibitzing","kibitzs"},
"kibitzer":{"kibitzer","kibitzers"},
"kichaga":{"kichaga","kichagas"},
"kick":{"kick","kicked","kicking","kicks"},
"kickapoo":{"kickapoo","kickapoos"},
"kicking":{"kicking","kickings"},
"kickoff":{"kickoff","kickoffs"},
"kickshaw":{"kickshaw","kickshaws"},
"kicksorter":{"kicksorter","kicksorters"},
"kid":{"kid","kidded","kidding","kids"},
"kidd":{"kidd","kidds"},
"kiddie":{"kiddie","kiddies"},
"kiddo":{"kiddo","kiddoes"},
"kidnap":{"kidnap","kidnaped","kidnaping","kidnapped","kidnapping","kidnaps"},
"kidnaper":{"kidnaper","kidnapers"},
"kidnapper":{"kidnapper","kidnappers"},
"kidney":{"kidney","kidneys"},
"kidskin":{"kidskin","kidskins"},
"kieselguhr":{"kieselguhr","kieselguhrs"},
"kiev":{"kiev","kievs"},
"kigali":{"kigali","kigalis"},
"kiggelaria":{"kiggelaria","kiggelarias"},
"kikuyu":{"kikuyu","kikuyus"},
"kildeer":{"kildeer","kildeers"},
"kiley":{"kiley","kileys"},
"kilimanjaro":{"kilimanjaro","kilimanjaros"},
"kiliwa":{"kiliwa","kiliwas"},
"kiliwi":{"kiliwi","kiliwis"},
"kill":{"kill","killed","killing","kills"},
"killdeer":{"killdeer","killdeers"},
"killer":{"killer","killers"},
"killifish":{"killifish","killifishes"},
"killing":{"killing","killings"},
"killjoy":{"killjoy","killjoys"},
"kiln":{"kiln","kilned","kilning","kilns"},
"kilo":{"kilo","kilos"},
"kilobyte":{"kilobyte","kilobytes"},
"kilocalorie":{"kilocalorie","kilocalories"},
"kilocycle":{"kilocycle","kilocycles"},
"kilogram":{"kilogram","kilograms"},
"kilohertz":{"kilohertz","kilohertzes","kilohertzs"},
"kiloliter":{"kiloliter","kiloliters"},
"kilolitre":{"kilolitre","kilolitres"},
"kilometer":{"kilometer","kilometers"},
"kilometre":{"kilometre","kilometres"},
"kilovolt":{"kilovolt","kilovolts"},
"kilowatt":{"kilowatt","kilowatts"},
"kilt":{"kilt","kilted","kilting"},
"kimono":{"kimono","kimonos"},
"kin":{"kin","kins"},
"kinaesthesia":{"kinaesthesia","kinaesthesias"},
"kinaesthesis":{"kinaestheses","kinaesthesis"},
"kinchinjunga":{"kinchinjunga","kinchinjungas"},
"kind":{"kind","kinder","kindest","kinds"},
"kindergarten":{"kindergarten","kindergartens"},
"kindle":{"kindle","kindled","kindles","kindling"},
"kindliness":{"kindliness","kindlinesses"},
"kindling":{"kindling","kindlings"},
"kindly":{"kindlier","kindliest","kindly"},
"kindness":{"kindness","kindnesses"},
"kindred":{"kindred","kindreds"},
"kine":{"kine","kines"},
"kinescope":{"kinescope","kinescopes"},
"kinesthesia":{"kinesthesia","kinesthesias"},
"kinesthesis":{"kinestheses","kinesthesis"},
"kinesthetics":{"kinesthetics","kinestheticses"},
"kinetics":{"kinetics","kineticses"},
"kinfolk":{"kinfolk","kinfolks"},
"king":{"king","kinged","kinging","kings"},
"king-of-arms":{"king-of-arms","kings-of-arms"},
"kingbird":{"kingbird","kingbirds"},
"kingbolt":{"kingbolt","kingbolts"},
"kingcup":{"kingcup","kingcups"},
"kingdom":{"kingdom","kingdoms"},
"kingfish":{"kingfish","kingfishes"},
"kingfisher":{"kingfisher","kingfishers"},
"kingly":{"kinglier","kingliest","kingly"},
"kingpin":{"kingpin","kingpins"},
"kingsnake":{"kingsnake","kingsnakes"},
"kingston":{"kingston","kingstons"},
"kingwood":{"kingwood","kingwoods"},
"kink":{"kink","kinked","kinking","kinks"},
"kinkajou":{"kinkajou","kinkajous"},
"kinky":{"kinkier","kinkiest","kinky"},
"kino":{"kino","kinos"},
"kinosternidae":{"kinosternidae","kinosternidaes"},
"kinosternon":{"kinosternon","kinosternons"},
"kinsfolk":{"kinsfolk","kinsfolks"},
"kinshasa":{"kinshasa","kinshasas"},
"kinship":{"kinship","kinships"},
"kinsman":{"kinsman","kinsmen"},
"kinsperson":{"kinsperson","kinspersons"},
"kinswoman":{"kinswoman","kinswomen"},
"kiosk":{"kiosk","kiosks"},
"kiowa":{"kiowa","kiowas"},
"kip":{"kip","kipped","kipping","kips"},
"kipling":{"kipling","kiplings"},
"kipper":{"kipper","kippered","kippering","kippers"},
"kirghiz":{"kirghiz","kirghizes","kirghizs"},
"kirghizia":{"kirghizia","kirghizias"},
"kirghizstan":{"kirghizstan","kirghizstans"},
"kirgiz":{"kirgiz","kirgizs"},
"kirgizia":{"kirgizia","kirgizias"},
"kirgizstan":{"kirgizstan","kirgizstans"},
"kirk":{"kirk","kirks"},
"kirkia":{"kirkia","kirkias"},
"kirkman":{"kirkman","kirkmen"},
"kishinev":{"kishinev","kishinevs"},
"kishke":{"kishke","kishkes"},
"kislev":{"kislev","kislevs"},
"kismat":{"kismat","kismats"},
"kismet":{"kismet","kismets"},
"kiss":{"kiss","kissed","kisses","kissing"},
"kiss-me-over-the-garden-gate":{"kiss-me-over-the-garden-gate","kiss-me-over-the-garden-gates"},
"kisser":{"kisser","kissers"},
"kissing":{"kissing","kissings"},
"kit":{"kit","kits","kitted","kitting"},
"kitambilla":{"kitambilla","kitambillas"},
"kitbag":{"kitbag","kitbags"},
"kitchen":{"kitchen","kitchens"},
"kite":{"kite","kited","kites","kiting"},
"kitembilla":{"kitembilla","kitembillas"},
"kitten":{"kitten","kittened","kittening","kittens"},
"kittle":{"kittle","kittler","kittlest"},
"kittul":{"kittul","kittuls"},
"kitty":{"kitties","kitty"},
"kitty-cat":{"kitty-cat","kitty-cats"},
"kitul":{"kitul","kituls"},
"kiwi":{"kiwi","kiwis"},
"kkk":{"kkk","kkks"},
"klamath":{"klamath","klamaths"},
"klan":{"klan","klans"},
"klansman":{"klansman","klansmen"},
"klavier":{"klavier","klaviers"},
"klaxon":{"klaxon","klaxons"},
"kleenex":{"kleenex","kleenexes"},
"klick":{"klick","klicks"},
"klootchman":{"klootchman","klootchmans","klootchmen"},
"klutz":{"klutz","klutzs"},
"km":{"km","kms"},
"km/h":{"km/h","km/hs"},
"knack":{"knack","knacks"},
"knackwurst":{"knackwurst","knackwursts"},
"knap":{"knap","knapped","knapping","knaps"},
"knapsack":{"knapsack","knapsacks"},
"knave":{"knave","knaves"},
"knavery":{"knaveries","knavery"},
"knawe":{"knawe","knawes"},
"knawel":{"knawel","knawels"},
"knead":{"knead","kneaded","kneading","kneads"},
"knee":{"knee","kneed","kneeing","knees"},
"kneecap":{"kneecap","kneecaps"},
"kneel":{"kneel","kneeled","kneeling","kneels","knelt"},
"kneeling":{"kneeling","kneelings"},
"kneepan":{"kneepan","kneepans"},
"knell":{"knell","knelled","knelling","knells"},
"knesset":{"knesset","knessets"},
"knesseth":{"knesseth","knesseths"},
"knickerbockers":{"knickerbockers","knickerbockerses"},
"knickers":{"knickers","knickerses"},
"knickknack":{"knickknack","knickknacks"},
"knickknackery":{"knickknackeries","knickknackery"},
"knickknacks":{"knickknacks","knickknackses"},
"knife":{"knife","knifed","knifing","knives"},
"knight":{"knight","knighted","knighting","knights"},
"knight-errant":{"knight-errant","knights-errant"},
"knight-errantry":{"knight-errantries","knight-errantry"},
"knighthood":{"knighthood","knighthoods"},
"knightia":{"knightia","knightias"},
"knightly":{"knightlier","knightliest","knightly"},
"knight_bachelor":{"knights_bachelor","knights_bachelors","knight_bachelor"},
"knight_templar":{"knights_templar","knights_templars","knight_templar"},
"kniphofia":{"kniphofia","kniphofias"},
"knit":{"knit","knits","knitted","knitting"},
"knitting":{"knitting","knittings"},
"knitwork":{"knitwork","knitworks"},
"knob":{"knob","knobs"},
"knobby":{"knobbier","knobbiest","knobby"},
"knobkerrie":{"knobkerrie","knobkerries"},
"knobkerry":{"knobkerries","knobkerry"},
"knock":{"knock","knocked","knocking","knocks"},
"knock-knee":{"knock-knee","knock-knees"},
"knocker":{"knocker","knockers"},
"knocking":{"knocking","knockings"},
"knockout":{"knockout","knockouts"},
"knockwurst":{"knockwurst","knockwursts"},
"knoll":{"knoll","knolled","knolling","knolls"},
"knot":{"knot","knots","knotted","knotting"},
"knotgrass":{"knotgrass","knotgrasses"},
"knottiness":{"knottiness","knottinesses"},
"knotty":{"knottier","knottiest","knotty"},
"knout":{"knout","knouted","knouting"},
"know":{"knew","know","knowing","known","knows"},
"know-all":{"know-all","know-alls"},
"know-it-all":{"know-it-all","know-it-alls"},
"knowingness":{"knowingness","knowingnesses"},
"knowledge":{"knowledge","knowledges"},
"knuckle":{"knuckle","knuckled","knuckles","knuckling"},
"knuckleball":{"knuckleball","knuckleballs"},
"knucklebones":{"knucklebones","knuckleboneses"},
"knucklehead":{"knucklehead","knuckleheads"},
"knuckler":{"knuckler","knucklers"},
"knuckles":{"knuckles","knuckleses"},
"knucks":{"knucks","knuckses"},
"knurly":{"knurlier","knurliest","knurly"},
"ko":{"ko","kos"},
"koala":{"koala","koalas"},
"koan":{"koan","koans"},
"kob":{"kob","kobs"},
"kobenhavn":{"kobenhavn","kobenhavns"},
"kobo":{"kobo","kobos"},
"kobus":{"kobus","kobuses"},
"kochia":{"kochia","kochias"},
"kodiak":{"kodiak","kodiaks"},
"koellia":{"koellia","koellias"},
"kogia":{"kogia","kogias"},
"kohlrabi":{"kohlrabi","kohlrabies","kohlrabis"},
"koine":{"koine","koines"},
"kok-saghyz":{"kok-saghyz","kok-saghyzs"},
"kok-sagyz":{"kok-sagyz","kok-sagyzs"},
"kokka":{"kokka","kokkas"},
"kola":{"kola","kolas"},
"kolinsky":{"kolinskies","kolinsky"},
"kolkhoz":{"kolkhoz","kolkhozes","kolkhozy"},
"kolkwitzia":{"kolkwitzia","kolkwitzias"},
"koln":{"koln","kolns"},
"kolo":{"kolo","kolos"},
"komi":{"komi","komis"},
"konakri":{"konakri","konakris"},
"kondo":{"kondo","kondos"},
"kongo":{"kongo","kongos"},
"konini":{"konini","koninis"},
"koodoo":{"koodoo","koodoos"},
"kook":{"kook","kooks"},
"kookaburra":{"kookaburra","kookaburras"},
"kooky":{"kookier","kookiest","kooky"},
"kopeck":{"kopeck","kopecks"},
"kopek":{"kopek","kopeks"},
"kopje":{"kopje","kopjes"},
"koppie":{"koppie","koppies"},
"kor":{"kor","kors"},
"koran":{"koran","korans"},
"kore":{"kore","kores"},
"korea":{"korea","koreas"},
"korinthos":{"korinthos","korinthoses"},
"koruna":{"korun","koruna","korunas"},
"kos":{"kos","koses"},
"kosteletzya":{"kosteletzya","kosteletzyas"},
"kota":{"kota","kotas"},
"kotar":{"kotar","kotars"},
"koto":{"koto","kotos"},
"kotow":{"kotow","kotows"},
"koudou":{"koudou","koudous"},
"koumiss":{"koumiss","koumisses"},
"kovna":{"kovna","kovnas"},
"kovno":{"kovno","kovnos"},
"koweit":{"koweit","koweits"},
"kowhai":{"kowhai","kowhais"},
"kowtow":{"kowtow","kowtowed","kowtowing","kowtows"},
"kph":{"kph","kphs"},
"kr":{"kr","krs"},
"kraal":{"kraal","kraaled","kraaling"},
"kraft":{"kraft","krafts"},
"krakatao":{"krakatao","krakataos"},
"krakatau":{"krakatau","krakataus"},
"krakatoa":{"krakatoa","krakatoas"},
"krakau":{"krakau","krakaus"},
"krakow":{"krakow","krakows"},
"kraut":{"kraut","krauts"},
"krauthead":{"krauthead","krautheads"},
"krio":{"krio","krios"},
"krona":{"krona","kronas","kronor"},
"krone":{"krone","kroner","krones"},
"kroon":{"kroon","krooni","kroons"},
"krubi":{"krubi","krubis"},
"krummhorn":{"krummhorn","krummhorns"},
"krypterophaneron":{"krypterophaneron","krypterophanerons"},
"krypton":{"krypton","kryptons"},
"ku":{"ku","kus"},
"ku-chiku":{"ku-chiku","ku-chikus"},
"kuangchou":{"kuangchou","kuangchous"},
"kuchean":{"kuchean","kucheans"},
"kudos":{"kudos","kudoses"},
"kudu":{"kudu","kudus"},
"kudzu":{"kudzu","kudzus"},
"kuenlun":{"kuenlun","kuenluns"},
"kukenaam":{"kukenaam","kukenaams"},
"kuki":{"kuki","kukis"},
"kuki-chin":{"kuki-chin","kuki-chins"},
"kukri":{"kukri","kukris"},
"kumis":{"kumis","kumises"},
"kumquat":{"kumquat","kumquats"},
"kunlun":{"kunlun","kunluns"},
"kura":{"kura","kuras"},
"kurakkan":{"kurakkan","kurakkans"},
"kurchatovium":{"kurchatovium","kurchatoviums"},
"kurchee":{"kurchee","kurchees"},
"kurchi":{"kurchi","kurchis"},
"kuri-chiku":{"kuri-chiku","kuri-chikus"},
"kuroshio":{"kuroshio","kuroshios"},
"kurrajong":{"kurrajong","kurrajongs"},
"kurrat":{"kurrat","kurrats"},
"kuru":{"kuru","kurus"},
"kutch":{"kutch","kutches"},
"kuwait":{"kuwait","kuwaits"},
"kv":{"kv","kvs"},
"kvetch":{"kvetch","kvetched","kvetches","kvetching"},
"kw":{"kw","kws"},
"kw-hr":{"kw-hr","kw-hrs"},
"kwacha":{"kwacha","kwachas"},
"kwai":{"kwai","kwais"},
"kwakiutl":{"kwakiutl","kwakiutls"},
"kwan-yin":{"kwan-yin","kwan-yins"},
"kwangchow":{"kwangchow","kwangchows"},
"kwanza":{"kwanza","kwanzas"},
"kwanzaa":{"kwanzaa","kwanzaas"},
"kweek":{"kweek","kweeks"},
"kylie":{"kylie","kylies"},
"kylix":{"kylikes","kylix"},
"kymograph":{"kymograph","kymographs"},
"kyo-chiku":{"kyo-chiku","kyo-chikus"},
"kyphosidae":{"kyphosidae","kyphosidaes"},
"kyphosis":{"kyphoses","kyphosis"},
"kyphosus":{"kyphosus","kyphosuses"},
"kyrgystan":{"kyrgystan","kyrgystans"},
"l":{"l","ls"},
"l-p":{"l-p","l-ps"},
"la":{"la","las"},
"laager":{"laager","laagered","laagering","laagers"},
"lab":{"lab","labs"},
"labarum":{"labara","labarum"},
"labdanum":{"labdanum","labdanums"},
"label":{"label","labeled","labeling","labelled","labelling","labels"},
"labellum":{"labella","labellum"},
"labial":{"labial","labials"},
"labialize":{"labialize","labialized","labializes","labializing"},
"labiatae":{"labiatae","labiataes"},
"labium":{"labia","labium"},
"lablab":{"lablab","lablabs"},
"labor":{"labor","labored","laboring","labors"},
"laboratory":{"laboratories","laboratory"},
"laborer":{"laborer","laborers"},
"laboriousness":{"laboriousness","laboriousnesses"},
"labour":{"labour","laboured","labouring","labours"},
"labourer":{"labourer","labourers"},
"labridae":{"labridae","labridaes"},
"labrocyte":{"labrocyte","labrocytes"},
"labrum":{"labra","labrum"},
"laburnum":{"laburnum","laburnums"},
"labyrinth":{"labyrinth","labyrinths"},
"labyrinthitis":{"labyrinthitis","labyrinthitises"},
"labyrinthodonta":{"labyrinthodonta","labyrinthodontas"},
"labyrinthodontia":{"labyrinthodontia","labyrinthodontias"},
"laccopetalum":{"laccopetalum","laccopetalums"},
"lace":{"lace","laced","laces","lacing"},
"lacebark":{"lacebark","lacebarks"},
"lacepod":{"lacepod","lacepods"},
"lacerate":{"lacerate","lacerated","lacerating"},
"lacerta":{"lacerta","lacertas"},
"lacertid":{"lacertid","lacertids"},
"lacertidae":{"lacertidae","lacertidaes"},
"lacertilia":{"lacertilia","lacertilias"},
"lacewing":{"lacewing","lacewings"},
"lacewood":{"lacewood","lacewoods"},
"lachnolaimus":{"lachnolaimus","lachnolaimuses"},
"lachrymation":{"lachrymation","lachrymations"},
"lachrymatory":{"lachrymatories","lachrymatory"},
"lacing":{"lacing","lacings"},
"lack":{"lack","lacked","lacking","lacks"},
"lackey":{"lackey","lackeys"},
"laconicism":{"laconicism","laconicisms"},
"laconism":{"laconism","laconisms"},
"lacquer":{"lacquer","lacquered","lacquering"},
"lacrimation":{"lacrimation","lacrimations"},
"lacrimator":{"lacrimator","lacrimators"},
"lactarius":{"lactarius","lactariuses"},
"lactate":{"lactate","lactated","lactates","lactating"},
"lactobacillaceae":{"lactobacillaceae","lactobacillaceaes"},
"lactobacillus":{"lactobacilli","lactobacillus"},
"lactobacteriaceae":{"lactobacteriaceae","lactobacteriaceaes"},
"lactoflavin":{"lactoflavin","lactoflavins"},
"lactophrys":{"lactophrys","lactophryses"},
"lactose":{"lactose","lactoses"},
"lactuca":{"lactuca","lactucas"},
"lacuna":{"lacuna","lacunae","lacunas"},
"lacunar":{"lacunar","lacunaria","lacunars"},
"lacy":{"lacier","laciest","lacy"},
"lad":{"lad","lads"},
"ladanum":{"ladanum","ladanums"},
"ladder":{"ladder","laddered","laddering","ladders"},
"ladder-back":{"ladder-back","ladder-backs"},
"laddie":{"laddie","laddies"},
"lade":{"lade","laded","laden","lades","lading"},
"ladify":{"ladify","ladyfied","ladyfies","ladyfying"},
"lading":{"lading","ladings"},
"ladino":{"ladino","ladinos"},
"ladle":{"ladle","ladled","ladles","ladling"},
"lady":{"ladies","lady"},
"lady-in-waiting":{"ladies-in-waiting","lady-in-waiting"},
"lady-of-the-night":{"lady-of-the-night","lady-of-the-nights"},
"lady-slipper":{"lady-slipper","lady-slippers"},
"ladybeetle":{"ladybeetle","ladybeetles"},
"ladybird":{"ladybird","ladybirds"},
"ladybug":{"ladybug","ladybugs"},
"ladyfish":{"ladyfish","ladyfishes"},
"ladyship":{"ladyship","ladyships"},
"laevulose":{"laevulose","laevuloses"},
"lag":{"lag","lagged","lagging","lags"},
"lagan":{"lagan","lagans"},
"lagarostrobus":{"lagarostrobus","lagarostrobuses"},
"lagenaria":{"lagenaria","lagenarias"},
"lagend":{"lagend","lagends"},
"lagenophera":{"lagenophera","lagenopheras"},
"lager":{"lager","lagers"},
"lagerstroemia":{"lagerstroemia","lagerstroemias"},
"laggard":{"laggard","laggards"},
"lagidium":{"lagidium","lagidiums"},
"lagodon":{"lagodon","lagodons"},
"lagomorph":{"lagomorph","lagomorphs"},
"lagomorpha":{"lagomorpha","lagomorphas"},
"lagoon":{"lagoon","lagoons"},
"lagopus":{"lagopus","lagopuses"},
"lagorchestes":{"lagorchestes","lagorchesteses"},
"lagos":{"lagos","lagoses"},
"lagostomus":{"lagostomus","lagostomuses"},
"lagothrix":{"lagothrix","lagothrixes"},
"laguna":{"laguna","lagunas"},
"laguncularia":{"laguncularia","laguncularias"},
"lagune":{"lagune","lagunes"},
"lah":{"lah","lahs"},
"laicize":{"laicize","laicized","laicizes","laicizing"},
"lair":{"lair","laired","lairing","lairs"},
"lairy":{"lairier","lairiest","lairy"},
"laity":{"laities","laity"},
"lake":{"lake","lakes"},
"lakelet":{"lakelet","lakelets"},
"lakeshore":{"lakeshore","lakeshores"},
"lakeside":{"lakeside","lakesides"},
"lakh":{"lakh","lakhs"},
"laky":{"lakier","lakiest","laky"},
"lallans":{"lallans","lallanses"},
"lally":{"lallies","lally"},
"lallygag":{"lallygag","lallygagged","lallygagging","lallygags"},
"lam":{"lam","lammed","lamming","lams"},
"lama":{"lama","lamas"},
"lamarck":{"lamarck","lamarcks"},
"lamasery":{"lamaseries","lamasery"},
"lamb":{"lamb","lambed","lambing","lambs"},
"lambaste":{"lambaste","lambasted","lambastes","lambasting"},
"lambda":{"lambda","lambdas"},
"lambency":{"lambencies","lambency"},
"lambert":{"lambert","lamberts"},
"lambertia":{"lambertia","lambertias"},
"lambis":{"lambis","lambises"},
"lambkill":{"lambkill","lambkills"},
"lambskin":{"lambskin","lambskins"},
"lame":{"lame","lamed","lamer","lamest","laming"},
"lamella":{"lamella","lamellae","lamellas"},
"lamellibranch":{"lamellibranch","lamellibranches"},
"lamellibranchia":{"lamellibranchia","lamellibranchias"},
"lamellicornia":{"lamellicornia","lamellicornias"},
"lameness":{"lameness","lamenesses"},
"lament":{"lament","lamented","lamenting","laments"},
"lamentation":{"lamentation","lamentations"},
"lamenter":{"lamenter","lamenters"},
"lamia":{"lamia","lamiae","lamias"},
"lamiaceae":{"lamiaceae","lamiaceaes"},
"lamina":{"lamina","laminae","laminas"},
"laminaria":{"laminaria","laminarias"},
"laminariaceae":{"laminariaceae","laminariaceaes"},
"laminariales":{"laminariales","laminarialeses"},
"laminate":{"laminate","laminated","laminating"},
"laminectomy":{"laminectomies","laminectomy"},
"laminitis":{"laminitis","laminitises"},
"lamium":{"lamium","lamiums"},
"lammas":{"lammas","lammases"},
"lammergeier":{"lammergeier","lammergeiers"},
"lammergeyer":{"lammergeyer","lammergeyers"},
"lamna":{"lamna","lamnas"},
"lamnidae":{"lamnidae","lamnidaes"},
"lamp":{"lamp","lamps"},
"lampblack":{"lampblack","lampblacks"},
"lampoon":{"lampoon","lampooned","lampooning","lampoons"},
"lampooner":{"lampooner","lampooners"},
"lamprey":{"lamprey","lampreys"},
"lampridae":{"lampridae","lampridaes"},
"lampris":{"lampris","lamprises"},
"lampropeltis":{"lampropeltis","lampropeltises"},
"lampshade":{"lampshade","lampshades"},
"lampshell":{"lampshell","lampshells"},
"lampyridae":{"lampyridae","lampyridaes"},
"lan":{"lan","lans"},
"lanai":{"lanai","lanais"},
"lancaster":{"lancaster","lancasters"},
"lance":{"lance","lanced","lances","lancing"},
"lancelet":{"lancelet","lancelets"},
"lancelot":{"lancelot","lancelots"},
"lancet":{"lancet","lancets"},
"lancetfish":{"lancetfish","lancetfishes"},
"lancewood":{"lancewood","lancewoods"},
"lanchou":{"lanchou","lanchous"},
"lanchow":{"lanchow","lanchows"},
"lancinate":{"lancinate","lancinated","lancinating"},
"land":{"land","landed","landing","lands"},
"landholder":{"landholder","landholders"},
"landing":{"landing","landings"},
"landlady":{"landladies","landlady"},
"landlord":{"landlord","landlords"},
"landlubber":{"landlubber","landlubbers"},
"landman":{"landman","landmen"},
"landmark":{"landmark","landmarks"},
"landowner":{"landowner","landowners"},
"landrover":{"landrover","landrovers"},
"landscape":{"landscape","landscaped","landscapes","landscaping"},
"landscaping":{"landscaping","landscapings"},
"landslide":{"landslide","landslides"},
"landslip":{"landslip","landslips"},
"landsmal":{"landsmal","landsmals"},
"landsman":{"landsman","landsmen"},
"lane":{"lane","lanes"},
"langobard":{"langobard","langobards"},
"langouste":{"langouste","langoustes"},
"langoustine":{"langoustine","langoustines"},
"langsat":{"langsat","langsats"},
"langset":{"langset","langsets"},
"langside":{"langside","langsides"},
"langsyne":{"langsyne","langsynes"},
"language":{"language","languages"},
"languish":{"languish","languished","languishes","languishing"},
"languor":{"languor","languors"},
"laniard":{"laniard","laniards"},
"laniary":{"laniaries","laniary"},
"laniidae":{"laniidae","laniidaes"},
"lanius":{"lanius","laniuses"},
"lank":{"lank","lanker","lankest"},
"lanky":{"lankier","lankiest","lanky"},
"lanolin":{"lanolin","lanolins"},
"lansa":{"lansa","lansas"},
"lansat":{"lansat","lansats"},
"lanseh":{"lanseh","lansehs"},
"lanset":{"lanset","lansets"},
"lansing":{"lansing","lansings"},
"lantern":{"lantern","lanterns"},
"lanternfly":{"lanternflies","lanternfly"},
"lanthanide":{"lanthanide","lanthanides"},
"lanthanon":{"lanthanon","lanthanons"},
"lanthanotidae":{"lanthanotidae","lanthanotidaes"},
"lanthanotus":{"lanthanotus","lanthanotuses"},
"lanthanum":{"lanthanum","lanthanums"},
"lanugo":{"lanugo","lanugos"},
"lanyard":{"lanyard","lanyards"},
"lanzhou":{"lanzhou","lanzhous"},
"lao":{"lao","laos"},
"lao-tse":{"lao-tse","lao-tses"},
"lao-tzu":{"lao-tzu","lao-tzus"},
"laotian":{"laotian","laotians"},
"laozi":{"laozi","laozis"},
"lap":{"lap","lapped","lapping","laps"},
"laparotomy":{"laparotomies","laparotomy"},
"lapful":{"lapful","lapfuls"},
"lapidarist":{"lapidarist","lapidarists"},
"lapidary":{"lapidaries","lapidary"},
"lapidate":{"lapidate","lapidated","lapidates","lapidating"},
"lapidify":{"lapidified","lapidifies","lapidify","lapidifying"},
"lapidist":{"lapidist","lapidists"},
"lapillus":{"lapilli","lapillus"},
"lapin":{"lapin","lapins"},
"lapith":{"lapith","lapithae","lapiths"},
"lapland":{"lapland","laplands"},
"laportea":{"laportea","laporteas"},
"lapp":{"lapp","lapps"},
"lappet":{"lappet","lappets"},
"lappic":{"lappic","lappics"},
"lapping":{"lapping","lappings"},
"lappish":{"lappish","lappishes"},
"lappland":{"lappland","lapplands"},
"lapplander":{"lapplander","lapplanders"},
"lappula":{"lappula","lappulas"},
"lapse":{"lapse","lapsed","lapses","lapsing"},
"lapsing":{"lapsing","lapsings"},
"laptop":{"laptop","laptops"},
"lapwing":{"lapwing","lapwings"},
"lar":{"lar","lares"},
"larboard":{"larboard","larboards"},
"larcener":{"larcener","larceners"},
"larcenist":{"larcenist","larcenists"},
"larcenous":{"larcenous","larcenouses"},
"larceny":{"larcenies","larceny"},
"larch":{"larch","larches"},
"lard":{"lard","larded","larding","lards"},
"larder":{"larder","larders"},
"lardizabala":{"lardizabala","lardizabalas"},
"lardizabalaceae":{"lardizabalaceae","lardizabalaceaes"},
"lardy":{"lardier","lardiest","lardy"},
"large":{"large","larger","largest"},
"largemouth":{"largemouth","largemouths"},
"largeness":{"largeness","largenesses"},
"largess":{"largess","largesses"},
"largesse":{"largesse","largesses"},
"larghetto":{"larghetto","larghettos"},
"largo":{"largo","largos"},
"lari":{"lari","laris"},
"lariat":{"lariat","lariats"},
"laricariidae":{"laricariidae","laricariidaes"},
"laridae":{"laridae","laridaes"},
"larix":{"larix","larixes"},
"lark":{"lark","larked","larking","larks"},
"larrea":{"larrea","larreas"},
"larrup":{"larrup","larruped","larruping","larrups"},
"larus":{"larus","laruses"},
"larva":{"larva","larvae","larvas"},
"larvacea":{"larvacea","larvaceas"},
"laryngectomy":{"laryngectomies","laryngectomy"},
"laryngotomy":{"laryngotomies","laryngotomy"},
"larynx":{"larynges","larynx","larynxes"},
"lasagna":{"lasagna","lasagnas"},
"lasagne":{"lasagne","lasagnes"},
"lasciviousness":{"lasciviousness","lasciviousnesses"},
"lase":{"lase","lased","lasing"},
"laser":{"laser","lasers"},
"lash":{"lash","lashed","lashes","lashing"},
"lash-up":{"lash-up","lash-ups"},
"lashing":{"lashing","lashings"},
"lashings":{"lashings","lashingses"},
"lasiocampa":{"lasiocampa","lasiocampas"},
"lasiocampid":{"lasiocampid","lasiocampids"},
"lasiocampidae":{"lasiocampidae","lasiocampidaes"},
"lasiurus":{"lasiurus","lasiuruses"},
"lass":{"lass","lasses"},
"lassa":{"lassa","lassas"},
"lassie":{"lassie","lassies"},
"lassitude":{"lassitude","lassitudes"},
"lasso":{"lasso","lassoed","lassoes","lassoing","lassos"},
"last":{"last","lasted","lasting","lasts"},
"lasthenia":{"lasthenia","lasthenias"},
"lastingness":{"lastingness","lastingnesses"},
"lastreopsis":{"lastreopses","lastreopsis"},
"lat":{"lat","lats"},
"latch":{"latch","latched","latches","latching"},
"latchkey":{"latchkey","latchkeys"},
"late":{"last","late","later","latest","latter"},
"lateen":{"lateen","lateens"},
"laten":{"laten","latened","latening"},
"latency":{"latencies","latency"},
"lateral":{"lateral","lateraled","lateraling","laterals"},
"laterality":{"lateralities","laterality"},
"latex":{"latex","latexes","latices"},
"lath":{"lath","lathed","lathing","laths"},
"lathe":{"lathe","lathed","lathes","lathing"},
"lathee":{"lathee","lathees"},
"lather":{"lather","lathered","lathering","lathers"},
"lathi":{"lathi","lathis"},
"lathy":{"lathier","lathiest","lathy"},
"lathyrus":{"lathyrus","lathyruses"},
"latifundium":{"latifundia","latifundium"},
"latigo":{"latigo","latigoes","latigos"},
"latimeria":{"latimeria","latimerias"},
"latimeridae":{"latimeridae","latimeridaes"},
"latino":{"latino","latinos"},
"latitude":{"latitude","latitudes"},
"latium":{"latium","latiums"},
"latke":{"latke","latkes"},
"latona":{"latona","latonas"},
"latria":{"latria","latrias"},
"latrodectus":{"latrodectus","latrodectuses"},
"lattice":{"lattice","latticed","lattices","latticing"},
"latticework":{"latticework","latticeworks"},
"latvian":{"latvian","latvians"},
"laud":{"laud","lauded","lauding","lauds"},
"laudanum":{"laudanum","laudanums"},
"laudator":{"laudator","laudators"},
"lauder":{"lauder","lauders"},
"laugh":{"laugh","laughed","laughing","laughs"},
"laugher":{"laugher","laughers"},
"laughingstock":{"laughingstock","laughingstocks"},
"laughter":{"laughter","laughters"},
"lauhala":{"lauhala","lauhalas"},
"launce":{"launce","launces"},
"launch":{"launch","launched","launches","launching"},
"launcher":{"launcher","launchers"},
"launching":{"launching","launchings"},
"launchpad":{"launchpad","launchpads"},
"launder":{"launder","laundered","laundering","launders"},
"laundress":{"laundress","laundresses"},
"laundry":{"laundries","laundry"},
"laundryman":{"laundryman","laundrymen"},
"laundrywoman":{"laundrywoman","laundrywomen"},
"lauraceae":{"lauraceae","lauraceaes"},
"laurel":{"laurel","laureled","laureling","laurelled","laurelling","laurels"},
"laurel-tree":{"laurel-tree","laurel-trees"},
"laurels":{"laurels","laurelses"},
"laurelwood":{"laurelwood","laurelwoods"},
"laurus":{"laurus","lauruses"},
"lav":{"lav","lavs"},
"lavabo":{"lavabo","lavaboes"},
"lavalier":{"lavalier","lavaliers"},
"lavaliere":{"lavaliere","lavalieres"},
"lavalliere":{"lavalliere","lavallieres"},
"lavandula":{"lavandula","lavandulas"},
"lavatera":{"lavatera","lavateras"},
"lavation":{"lavation","lavations"},
"lavatory":{"lavatories","lavatory"},
"lave":{"lave","laved","laves","laving"},
"lavender":{"lavender","lavendered","lavendering"},
"laver":{"laver","lavers"},
"lavish":{"lavish","lavished","lavishes","lavishing"},
"lavishness":{"lavishness","lavishnesses"},
"law":{"law","laws"},
"law-breaking":{"law-breaking","law-breakings"},
"law-makers":{"law-makers","law-makerses"},
"lawbreaker":{"lawbreaker","lawbreakers"},
"lawgiver":{"lawgiver","lawgivers"},
"lawlessness":{"lawlessness","lawlessnesses"},
"lawmaker":{"lawmaker","lawmakers"},
"lawmaking":{"lawmaking","lawmakings"},
"lawman":{"lawman","lawmen"},
"lawn":{"lawn","lawns"},
"lawrencium":{"lawrencium","lawrenciums"},
"laws":{"laws","lawses"},
"lawsuit":{"lawsuit","lawsuits"},
"lawyer":{"lawyer","lawyers"},
"lawyerbush":{"lawyerbush","lawyerbushes"},
"lax":{"lax","laxer","laxest"},
"laxative":{"laxative","laxatives"},
"laxity":{"laxities","laxity"},
"laxness":{"laxness","laxnesses"},
"lay":{"laid","lay","laying","lays"},
"layabout":{"layabout","layabouts"},
"layby":{"laybies","layby"},
"layer":{"layer","layered","layering","layers"},
"layia":{"layia","layias"},
"laying":{"laying","layings"},
"layman":{"layman","laymen"},
"layout":{"layout","layouts"},
"layover":{"layover","layovers"},
"layperson":{"layperson","laypersons"},
"laywoman":{"laywoman","laywomen"},
"lazar":{"lazar","lazars"},
"lazaret":{"lazaret","lazarets"},
"lazarette":{"lazarette","lazarettes"},
"lazaretto":{"lazaretto","lazarettos"},
"laze":{"laze","lazed","lazes","lazing"},
"laziness":{"laziness","lazinesses"},
"lazio":{"lazio","lazios"},
"lazuli":{"lazuli","lazulis"},
"lazuline":{"lazuline","lazulines"},
"lazy":{"lazier","laziest","lazy"},
"lb":{"lb","lbs"},
"lcd":{"lcd","lcds"},
"lcm":{"lcm","lcms"},
"ldl":{"ldl","ldls"},
"le":{"le","les"},
"lea":{"lea","leas"},
"leach":{"leach","leached","leaches","leaching"},
"leaching":{"leaching","leachings"},
"lead":{"lead","leading","leads","led"},
"lead-in":{"lead-in","lead-ins"},
"leader":{"leader","leaders"},
"leaders":{"leaders","leaderses"},
"leadership":{"leadership","leaderships"},
"leading":{"leading","leadings"},
"leadplant":{"leadplant","leadplants"},
"leadsman":{"leadsman","leadsmen"},
"leadwort":{"leadwort","leadworts"},
"leady":{"leadier","leadiest","leady"},
"leaf":{"leaf","leafed","leafing","leafs","leaves"},
"leaf-cutter":{"leaf-cutter","leaf-cutters"},
"leafage":{"leafage","leafages"},
"leafing":{"leafing","leafings"},
"leaflet":{"leaflet","leafleted","leafleting","leaflets","leafletted","leafletting"},
"leafminer":{"leafminer","leafminers"},
"leafroller":{"leafroller","leafrollers"},
"leafstalk":{"leafstalk","leafstalks"},
"leafy":{"leafier","leafiest","leafy"},
"league":{"league","leagued","leagues","leaguing"},
"leaguer":{"leaguer","leaguered","leaguering"},
"leak":{"leak","leaked","leaking","leaks"},
"leakage":{"leakage","leakages"},
"leakey":{"leakey","leakeys"},
"leaky":{"leakier","leakiest","leaky"},
"lean":{"lean","leaned","leaner","leanest","leaning","leans","leant"},
"lean-to":{"lean-to","lean-tos"},
"leaning":{"leaning","leanings"},
"leanness":{"leanness","leannesses"},
"leap":{"leap","leaped","leaping","leaps","leapt"},
"leapfrog":{"leapfrog","leapfrogged","leapfrogging","leapfrogs"},
"leaping":{"leaping","leapings"},
"lear":{"lear","lears"},
"learn":{"learn","learned","learning","learns","learnt"},
"learnedness":{"learnedness","learnednesses"},
"learner":{"learner","learners"},
"learning":{"learning","learnings"},
"leary":{"learier","leariest","leary"},
"lease":{"lease","leased","leases","leasing"},
"lease-lend":{"lease-lend","lease-lends"},
"leaseholder":{"leaseholder","leaseholders"},
"leash":{"leash","leashed","leashes","leashing"},
"leather":{"leather","leathered","leathering","leathers"},
"leatherback":{"leatherback","leatherbacks"},
"leatherette":{"leatherette","leatherettes"},
"leatherfish":{"leatherfish","leatherfishes"},
"leatherjack":{"leatherjack","leatherjacks"},
"leatherjacket":{"leatherjacket","leatherjackets"},
"leatherleaf":{"leatherleaf","leatherleaves"},
"leatherneck":{"leatherneck","leathernecks"},
"leatherwood":{"leatherwood","leatherwoods"},
"leave":{"leave","leaves","leaving","left"},
"leave-taking":{"leave-taking","leave-takings"},
"leaven":{"leaven","leavened","leavening","leavens"},
"leavening":{"leavening","leavenings"},
"leaver":{"leaver","leavers"},
"leave_undone":{"leaves_undone","leave_undone","leaving_undone","left_undone"},
"leaving":{"leaving","leavings"},
"leavy":{"leavier","leaviest","leavy"},
"lebensraum":{"lebensraum","lebensraums"},
"lebistes":{"lebistes","lebisteses"},
"lecanoraceae":{"lecanoraceae","lecanoraceaes"},
"leccinum":{"leccinum","leccinums"},
"lech":{"lech","leched","leching"},
"lechanorales":{"lechanorales","lechanoraleses"},
"lechatelierite":{"lechatelierite","lechatelierites"},
"lecher":{"lecher","lechers"},
"lecherousness":{"lecherousness","lecherousnesses"},
"lechery":{"lecheries","lechery"},
"lechwe":{"lechwe","lechwes"},
"lectern":{"lectern","lecterns"},
"lectionary":{"lectionaries","lectionary"},
"lector":{"lector","lectors"},
"lecture":{"lecture","lectured","lectures","lecturing"},
"lecturer":{"lecturer","lecturers"},
"lecturing":{"lecturing","lecturings"},
"lecythidaceae":{"lecythidaceae","lecythidaceaes"},
"lecythus":{"lecythi","lecythus"},
"led":{"led","leds"},
"ledge":{"ledge","ledges"},
"ledgeman":{"ledgeman","ledgemen"},
"ledger":{"ledger","ledgers"},
"ledum":{"ledum","ledums"},
"lee":{"lee","lees"},
"leech":{"leech","leeched","leeches","leeching"},
"leechee":{"leechee","leechees"},
"leek":{"leek","leeks"},
"leer":{"leer","leered","leering","leers"},
"leery":{"leerier","leeriest","leery"},
"leeward":{"leeward","leewards"},
"leeway":{"leeway","leeways"},
"left":{"left","lefter","leftest","lefts"},
"left-handedness":{"left-handedness","left-handednesses"},
"left-hander":{"left-hander","left-handers"},
"left-winger":{"left-winger","left-wingers"},
"leftfield":{"leftfield","leftfields"},
"leftist":{"leftist","leftists"},
"leftover":{"leftover","leftovers"},
"lefty":{"lefties","lefty"},
"leg":{"leg","legged","legging","legs"},
"leg-pull":{"leg-pull","leg-pulls"},
"leg-pulling":{"leg-pulling","leg-pullings"},
"legacy":{"legacies","legacy"},
"legalisation":{"legalisation","legalisations"},
"legalist":{"legalist","legalists"},
"legality":{"legalities","legality"},
"legalization":{"legalization","legalizations"},
"legalize":{"legalize","legalized","legalizes","legalizing"},
"legate":{"legate","legates"},
"legateship":{"legateship","legateships"},
"legation":{"legation","legations"},
"legato":{"legato","legatos"},
"legend":{"legend","legends"},
"legendary":{"legendaries","legendary"},
"legendize":{"legendize","legendized","legendizing"},
"leger":{"leger","legers"},
"legerdemain":{"legerdemain","legerdemains"},
"legerity":{"legerities","legerity"},
"legging":{"legging","leggings"},
"leggy":{"leggier","leggiest","leggy"},
"leghorn":{"leghorn","leghorns"},
"legibility":{"legibilities","legibility"},
"legin":{"legin","legins"},
"legion":{"legion","legions"},
"legionary":{"legionaries","legionary"},
"legionnaire":{"legionnaire","legionnaires"},
"legislate":{"legislate","legislated","legislates","legislating"},
"legislating":{"legislating","legislatings"},
"legislation":{"legislation","legislations"},
"legislative":{"legislative","legislatives"},
"legislator":{"legislator","legislators"},
"legislature":{"legislature","legislatures"},
"legitimacy":{"legitimacies","legitimacy"},
"legitimate":{"legitimate","legitimated","legitimates","legitimating"},
"legitimatize":{"legitimatize","legitimatized","legitimatizes","legitimatizing"},
"legitimize":{"legitimize","legitimized","legitimizes","legitimizing"},
"legman":{"legman","legmen"},
"legume":{"legume","legumes"},
"leguminosae":{"leguminosae","leguminosaes"},
"lehua":{"lehua","lehuas"},
"lei":{"lei","leis"},
"leibnitz":{"leibnitz","leibnitzs"},
"leibniz":{"leibniz","leibnizs"},
"leicester":{"leicester","leicesters"},
"leicestershire":{"leicestershire","leicestershires"},
"leiden":{"leiden","leidens"},
"leiopelma":{"leiopelma","leiopelmas"},
"leiopelmatidae":{"leiopelmatidae","leiopelmatidaes"},
"leiophyllum":{"leiophyllum","leiophyllums"},
"leipoa":{"leipoa","leipoas"},
"leister":{"leister","leistered","leistering"},
"leisure":{"leisure","leisures"},
"leitmotif":{"leitmotif","leitmotives"},
"leitmotiv":{"leitmotiv","leitmotivs"},
"leitneria":{"leitneria","leitnerias"},
"leitneriaceae":{"leitneriaceae","leitneriaceaes"},
"lek":{"lek","leke","leks"},
"lem":{"lem","lems"},
"lemaireocereus":{"lemaireocereus","lemaireocereuses"},
"lemanderin":{"lemanderin","lemanderins"},
"lemma":{"lemma","lemmas","lemmata"},
"lemmus":{"lemmus","lemmuses"},
"lemna":{"lemna","lemnas"},
"lemnaceae":{"lemnaceae","lemnaceaes"},
"lemniscus":{"lemnisci","lemniscus","lemniscuses"},
"lemnos":{"lemnos","lemnoses"},
"lemon":{"lemon","lemons"},
"lemonwood":{"lemonwood","lemonwoods"},
"lempira":{"lempira","lempiras"},
"lemuridae":{"lemuridae","lemuridaes"},
"lemuroidea":{"lemuroidea","lemuroideas"},
"lena":{"lena","lenas"},
"lend":{"lend","lending","lends","lent"},
"lend-lease":{"lend-lease","lend-leased","lend-leases","lend-leasing"},
"lender":{"lender","lenders"},
"length":{"length","lengths"},
"lengthen":{"lengthen","lengthened","lengthening"},
"lengthening":{"lengthening","lengthenings"},
"lengthiness":{"lengthiness","lengthinesses"},
"lengthman":{"lengthman","lengthmen"},
"lengthy":{"lengthier","lengthiest","lengthy"},
"lenience":{"lenience","leniences"},
"leniency":{"leniencies","leniency"},
"lenin":{"lenin","lenins"},
"leningrad":{"leningrad","leningrads"},
"leninism":{"leninism","leninisms"},
"lenis":{"lenes","lenis"},
"lenity":{"lenities","lenity"},
"lennoaceae":{"lennoaceae","lennoaceaes"},
"leno":{"leno","lenos"},
"lens":{"lens","lensed","lenses","lensing"},
"lent":{"lent","lents"},
"lententide":{"lententide","lententides"},
"lentibulariaceae":{"lentibulariaceae","lentibulariaceaes"},
"lentigo":{"lentigines","lentigo"},
"lentil":{"lentil","lentils"},
"lentinus":{"lentinus","lentinuses"},
"lento":{"lento","lentos"},
"leo":{"leo","leos"},
"leonardo":{"leonardo","leonardos"},
"leoncita":{"leoncita","leoncitas"},
"leonid":{"leonid","leonides","leonids"},
"leonotis":{"leonotis","leonotises"},
"leontocebus":{"leontocebus","leontocebuses"},
"leontodon":{"leontodon","leontodons"},
"leontopodium":{"leontopodium","leontopodiums"},
"leonurus":{"leonurus","leonuruses"},
"leopard":{"leopard","leopards"},
"leopardbane":{"leopardbane","leopardbanes"},
"leopoldville":{"leopoldville","leopoldvilles"},
"lepadidae":{"lepadidae","lepadidaes"},
"lepanto":{"lepanto","lepantos"},
"lepas":{"lepas","lepases"},
"lepcha":{"lepcha","lepchas"},
"lepechinia":{"lepechinia","lepechinias"},
"leper":{"leper","lepers"},
"lepidium":{"lepidium","lepidiums"},
"lepidobotryaceae":{"lepidobotryaceae","lepidobotryaceaes"},
"lepidochelys":{"lepidochelys","lepidochelyses"},
"lepidocybium":{"lepidocybium","lepidocybiums"},
"lepidodendraceae":{"lepidodendraceae","lepidodendraceaes"},
"lepidodendrales":{"lepidodendrales","lepidodendraleses"},
"lepidoptera":{"lepidoptera","lepidopteras"},
"lepidopteran":{"lepidopteran","lepidopterans"},
"lepidopterist":{"lepidopterist","lepidopterists"},
"lepidopteron":{"lepidoptera","lepidopteron","lepidopterons"},
"lepidosauria":{"lepidosauria","lepidosaurias"},
"lepidothamnus":{"lepidothamnus","lepidothamnuses"},
"lepiotaceae":{"lepiotaceae","lepiotaceaes"},
"lepisma":{"lepisma","lepismas"},
"lepismatidae":{"lepismatidae","lepismatidaes"},
"lepisosteidae":{"lepisosteidae","lepisosteidaes"},
"lepisosteus":{"lepisosteus","lepisosteuses"},
"lepomis":{"lepomis","lepomises"},
"leporid":{"leporid","leporids"},
"leporidae":{"leporidae","leporidaes"},
"leporide":{"leporide","leporides"},
"leppy":{"leppies","leppy"},
"leprosarium":{"leprosaria","leprosarium"},
"leprosy":{"leprosies","leprosy"},
"leptarrhena":{"leptarrhena","leptarrhenas"},
"leptinotarsa":{"leptinotarsa","leptinotarsas"},
"leptocephalus":{"leptocephali","leptocephalus"},
"leptodactylid":{"leptodactylid","leptodactylids"},
"leptodactylidae":{"leptodactylidae","leptodactylidaes"},
"leptodactylus":{"leptodactylus","leptodactyluses"},
"leptoglossus":{"leptoglossus","leptoglossuses"},
"lepton":{"lepta","lepton"},
"leptopteris":{"leptopteris","leptopterises"},
"leptoptilus":{"leptoptilus","leptoptiluses"},
"leptospirosis":{"leptospiroses","leptospirosis"},
"leptotyphlopidae":{"leptotyphlopidae","leptotyphlopidaes"},
"leptotyphlops":{"leptotyphlops","leptotyphlopses"},
"lepus":{"lepus","lepuses"},
"ler":{"ler","lers"},
"lesbian":{"lesbian","lesbians"},
"lesbianism":{"lesbianism","lesbianisms"},
"lesbos":{"lesbos","lesboses"},
"lesion":{"lesion","lesions"},
"lesotho":{"lesotho","lesothos"},
"lespedeza":{"lespedeza","lespedezas"},
"lesquerella":{"lesquerella","lesquerellas"},
"lessee":{"lessee","lessees"},
"lessen":{"lessen","lessened","lessening","lessens"},
"lessening":{"lessening","lessenings"},
"lesson":{"lesson","lessoned","lessoning","lessons"},
"lessor":{"lessor","lessors"},
"lesvos":{"lesvos","lesvoses"},
"let":{"let","lets","letting"},
"letdown":{"letdown","letdowns"},
"lethality":{"lethalities","lethality"},
"lethargy":{"lethargies","lethargy"},
"lethe":{"lethe","lethes"},
"leto":{"leto","letos"},
"letter":{"letter","lettered","lettering","letters"},
"letterhead":{"letterhead","letterheads"},
"lettering":{"lettering","letterings"},
"letterman":{"letterman","lettermen"},
"letterpress":{"letterpress","letterpresses"},
"letting":{"letting","lettings"},
"lettish":{"lettish","lettishes"},
"lettuce":{"lettuce","lettuces"},
"letup":{"letup","letups"},
"leu":{"lei","leu"},
"leucadendron":{"leucadendron","leucadendrons"},
"leucaena":{"leucaena","leucaenas"},
"leucanthemum":{"leucanthemum","leucanthemums"},
"leuciscus":{"leuciscus","leuciscuses"},
"leucocyte":{"leucocyte","leucocytes"},
"leucocytozoan":{"leucocytozoan","leucocytozoans"},
"leucocytozoon":{"leucocytozoon","leucocytozoons"},
"leucogenes":{"leucogenes","leucogeneses"},
"leucopenia":{"leucopenia","leucopenias"},
"leucorrhea":{"leucorrhea","leucorrheas"},
"leuctra":{"leuctra","leuctras"},
"leukaemia":{"leukaemia","leukaemias"},
"leukemia":{"leukemia","leukemias"},
"leukeran":{"leukeran","leukerans"},
"leukocyte":{"leukocyte","leukocytes"},
"leukopenia":{"leukopenia","leukopenias"},
"leukorrhea":{"leukorrhea","leukorrheas"},
"leukosis":{"leukoses","leukosis"},
"lev":{"lev","leva"},
"levant":{"levant","levanted","levanting"},
"levee":{"levee","leveed","leveeing","levees"},
"level":{"level","leveled","leveling","levelled","levelling","levels"},
"leveler":{"leveler","levelers"},
"leveling":{"leveling","levelings"},
"leveller":{"leveller","levellers"},
"lever":{"lever","levered","levering","levers"},
"leverage":{"leverage","leverages"},
"leveraging":{"leveraging","leveragings"},
"levi":{"levi","levis"},
"levigate":{"levigate","levigated","levigating"},
"levis":{"levis","levises"},
"levisticum":{"levisticum","levisticums"},
"levitate":{"levitate","levitated","levitates","levitating"},
"levity":{"levities","levity"},
"levulose":{"levulose","levuloses"},
"levy":{"levied","levies","levy","levying"},
"lewd":{"lewd","lewder","lewdest"},
"lewdness":{"lewdness","lewdnesses"},
"lewisia":{"lewisia","lewisias"},
"lex":{"leges","lex"},
"lexicographer":{"lexicographer","lexicographers"},
"lexicologist":{"lexicologist","lexicologists"},
"lexicon":{"lexica","lexicon","lexicons"},
"lexington":{"lexington","lexingtons"},
"ley":{"ley","leys"},
"leycesteria":{"leycesteria","leycesterias"},
"leyden":{"leyden","leydens"},
"leymus":{"leymus","leymuses"},
"leyte":{"leyte","leytes"},
"lf":{"lf","lfs"},
"lh":{"lh","lhs"},
"lhasa":{"lhasa","lhasas"},
"li":{"li","lis"},
"liability":{"liabilities","liability"},
"liaise":{"liaise","liaised","liaises","liaising"},
"liaison":{"liaison","liaisons"},
"liakoura":{"liakoura","liakouras"},
"liar":{"liar","liars"},
"liatris":{"liatris","liatrises"},
"libber":{"libber","libbers"},
"libel":{"libel","libeled","libeling","libelled","libelling","libels"},
"libeler":{"libeler","libelers"},
"liberal":{"liberal","liberals"},
"liberalisation":{"liberalisation","liberalisations"},
"liberality":{"liberalities","liberality"},
"liberalization":{"liberalization","liberalizations"},
"liberalize":{"liberalize","liberalized","liberalizing"},
"liberalness":{"liberalness","liberalnesses"},
"liberate":{"liberate","liberated","liberates","liberating"},
"liberation":{"liberation","liberations"},
"liberator":{"liberator","liberators"},
"libertine":{"libertine","libertines"},
"liberty":{"liberties","liberty"},
"libido":{"libido","libidos"},
"libocedrus":{"libocedrus","libocedruses"},
"libra":{"libra","librae","libras"},
"librarian":{"librarian","librarians"},
"library":{"libraries","library"},
"libretto":{"libretti","libretto","librettos"},
"libreville":{"libreville","librevilles"},
"librium":{"librium","libriums"},
"licence":{"licence","licenced","licences","licencing"},
"licencee":{"licencee","licencees"},
"license":{"license","licensed","licenses","licensing"},
"licensee":{"licensee","licensees"},
"licentiousness":{"licentiousness","licentiousnesses"},
"lichanura":{"lichanura","lichanuras"},
"lichee":{"lichee","lichees"},
"lichen":{"lichen","lichened","lichening"},
"lichenales":{"lichenales","lichenaleses"},
"lichenes":{"lichenes","licheneses"},
"lichgate":{"lichgate","lichgates"},
"lichi":{"lichi","lichis"},
"lick":{"lick","licked","licking","licks"},
"licking":{"licking","lickings"},
"licorice":{"licorice","licorices"},
"lid":{"lid","lids"},
"lido":{"lido","lidos"},
"lidocaine":{"lidocaine","lidocaines"},
"lie":{"lain","lay","lie","lied","lies","lying"},
"lie-abed":{"lie-abed","lie-abeds"},
"lied":{"lied","lieder"},
"liege":{"liege","lieges"},
"liegeman":{"liegeman","liegemen"},
"lien":{"lien","liens"},
"lietuva":{"lietuva","lietuvas"},
"lieu":{"lieu","lieus"},
"lieutenant":{"lieutenant","lieutenants"},
"life":{"life","lives"},
"life-of-man":{"life-of-man","life-of-men"},
"life-style":{"life-style","life-styles"},
"lifeboat":{"lifeboat","lifeboats"},
"lifeguard":{"lifeguard","lifeguarded","lifeguarding","lifeguards"},
"lifelessness":{"lifelessness","lifelessnesses"},
"lifeline":{"lifeline","lifelines"},
"lifesaver":{"lifesaver","lifesavers"},
"lifespan":{"lifespan","lifespans"},
"lifestyle":{"lifestyle","lifestyles"},
"lifetime":{"lifetime","lifetimes"},
"lift":{"lift","lifted","lifting","lifts"},
"liftboy":{"liftboy","liftboys"},
"lifter":{"lifter","lifters"},
"liftman":{"liftman","liftmen"},
"ligan":{"ligan","ligans"},
"ligate":{"ligate","ligated","ligating"},
"ligature":{"ligature","ligatured","ligatures","ligaturing"},
"light":{"light","lighted","lighter","lightest","lighting","lights","lit"},
"light-horseman":{"light-horseman","light-horsemen"},
"light-mindedness":{"light-mindedness","light-mindednesses"},
"light-of-love":{"light-of-love","light-of-loves"},
"lightbulb":{"lightbulb","lightbulbs"},
"lighten":{"lighten","lightened","lightening","lightens"},
"lightening":{"lightening","lightenings"},
"lighter":{"lighter","lightered","lightering","lighters"},
"lighterman":{"lighterman","lightermen"},
"lightheadedness":{"lightheadedness","lightheadednesses"},
"lightheartedness":{"lightheartedness","lightheartednesses"},
"lighthouse":{"lighthouse","lighthouses"},
"lighting":{"lighting","lightings"},
"lightlessness":{"lightlessness","lightlessnesses"},
"lightness":{"lightness","lightnesses"},
"lightning":{"lightning","lightninged"},
"lights-out":{"lights-out","lights-outs"},
"lightsomeness":{"lightsomeness","lightsomenesses"},
"lightweight":{"lightweight","lightweights"},
"lightwood":{"lightwood","lightwoods"},
"lignify":{"lignified","lignifies","lignify","lignifying"},
"lignite":{"lignite","lignites"},
"ligula":{"ligula","ligulae","ligulas"},
"ligularia":{"ligularia","ligularias"},
"ligustrum":{"ligustrum","ligustrums"},
"like":{"like","liked","liker","likes","likest","liking"},
"likelihood":{"likelihood","likelihoods"},
"likeliness":{"likeliness","likelinesses"},
"liken":{"liken","likened","likening","likens"},
"likeness":{"likeness","likenesses"},
"likuta":{"likuta","makuta"},
"lilac":{"lilac","lilacs"},
"lilangeni":{"emalangeni","lilangeni"},
"liliaceae":{"liliaceae","liliaceaes"},
"liliales":{"liliales","lilialeses"},
"liliidae":{"liliidae","liliidaes"},
"liliopsid":{"liliopsid","liliopsids"},
"liliopsida":{"liliopsida","liliopsidas"},
"lilium":{"lilium","liliums"},
"lilo":{"lilo","lilos"},
"lilt":{"lilt","lilted","lilting","lilts"},
"lily":{"lilies","lily"},
"lilyofthevalley":{"liliesofthevalley","lilyofthevalley"},
"lilyturf":{"lilyturf","lilyturfs","lilyturves"},
"lima":{"lima","limas"},
"limacidae":{"limacidae","limacidaes"},
"limanda":{"limanda","limandas"},
"limax":{"limax","limaxes"},
"limb":{"limb","limbed","limbing","limbs"},
"limber":{"limber","limbered","limbering","limbers"},
"limbo":{"limbo","limbos"},
"limbus":{"limbi","limbui","limbus"},
"lime":{"lime","limed","limes","liming"},
"limelight":{"limelight","limelighted","limelighting","limelights","limelit"},
"limen":{"limen","limens","limina"},
"limenitis":{"limenitis","limenitises"},
"limerick":{"limerick","limericks"},
"limes":{"limes","limites"},
"limey":{"limey","limeys"},
"limicolae":{"limicolae","limicolaes"},
"limit":{"limit","limited","limiting","limits"},
"limitation":{"limitation","limitations"},
"limited":{"limited","limiteds"},
"limiter":{"limiter","limiters"},
"limiting":{"limiting","limitings"},
"limitlessness":{"limitlessness","limitlessnesses"},
"limn":{"limn","limned","limning","limns"},
"limner":{"limner","limners"},
"limning":{"limning","limnings"},
"limnobium":{"limnobium","limnobiums"},
"limnocryptes":{"limnocryptes","limnocrypteses"},
"limnodromus":{"limnodromus","limnodromuses"},
"limnos":{"limnos","limnoses"},
"limo":{"limo","limos"},
"limonium":{"limonium","limoniums"},
"limosa":{"limosa","limosas"},
"limousine":{"limousine","limousines"},
"limp":{"limp","limped","limping","limps"},
"limpidity":{"limpidities","limpidity"},
"limping":{"limping","limpings"},
"limpkin":{"limpkin","limpkins"},
"limpness":{"limpness","limpnesses"},
"limpopo":{"limpopo","limpopos"},
"limulidae":{"limulidae","limulidaes"},
"limulus":{"limulus","limuluses"},
"limy":{"limier","limiest","limy"},
"linac":{"linac","linacs"},
"linaceae":{"linaceae","linaceaes"},
"linage":{"linage","linages"},
"linanthus":{"linanthus","linanthuses"},
"linaria":{"linaria","linarias"},
"linchpin":{"linchpin","linchpins"},
"lincoln":{"lincoln","lincolns"},
"linctus":{"linctus","linctuses"},
"linden":{"linden","lindens"},
"lindera":{"lindera","linderas"},
"lindheimera":{"lindheimera","lindheimeras"},
"lindy":{"lindies","lindy"},
"line":{"line","lined","lines","lining"},
"line-shooter":{"line-shooter","line-shooters"},
"line-shooting":{"line-shooting","line-shootings"},
"lineage":{"lineage","lineages"},
"lineament":{"lineament","lineaments"},
"linearity":{"linearities","linearity"},
"linebacker":{"linebacker","linebackers"},
"linecut":{"linecut","linecuts"},
"lineman":{"lineman","linemen"},
"linen":{"linen","linens"},
"liner":{"liner","liners"},
"linesman":{"linesman","linesmen"},
"lineup":{"lineup","lineups"},
"ling":{"ling","lings"},
"ling-pao":{"ling-pao","ling-paos"},
"lingberry":{"lingberries","lingberry"},
"lingcod":{"lingcod","lingcods"},
"lingenberry":{"lingenberries","lingenberry"},
"linger":{"linger","lingered","lingering","lingers"},
"lingerer":{"lingerer","lingerers"},
"lingering":{"lingering","lingerings"},
"lingo":{"lingo","lingoes"},
"lingonberry":{"lingonberries","lingonberry"},
"lingua":{"lingua","linguae","linguas"},
"lingua_franca":{"linguae_francae","lingua_franca","lingua_francas"},
"linguine":{"linguine","linguines"},
"linguini":{"linguini","linguinis"},
"linguist":{"linguist","linguists"},
"linguistics":{"linguistics","linguisticses"},
"liniment":{"liniment","liniments"},
"lining":{"lining","linings"},
"link":{"link","linked","linking","links"},
"linkboy":{"linkboy","linkboys"},
"linkman":{"linkman","linkmen"},
"links":{"links","linkses"},
"linksman":{"linksman","linksmen"},
"linkup":{"linkup","linkups"},
"linnaea":{"linnaea","linnaeas"},
"linnaeus":{"linnaeus","linnaeuses"},
"linnet":{"linnet","linnets"},
"lino":{"lino","linos"},
"linoleum":{"linoleum","linoleums"},
"linotype":{"linotype","linotyped","linotyping"},
"linseed":{"linseed","linseeds"},
"lintel":{"lintel","lintels"},
"linter":{"linter","linters"},
"linty":{"lintier","lintiest","linty"},
"liny":{"linier","liniest","liny"},
"liomys":{"liomys","liomyses"},
"lion":{"lion","lions"},
"lioness":{"lioness","lionesses"},
"lionfish":{"lionfish","lionfishes"},
"lionize":{"lionize","lionized","lionizes","lionizing"},
"liopelma":{"liopelma","liopelmas"},
"liopelmidae":{"liopelmidae","liopelmidaes"},
"lip":{"lip","lipped","lipping","lips"},
"lip-read":{"lip-read","lip-reading","lip-reads"},
"lip-sync":{"lip-sync","lip-synced","lip-syncing","lip-syncs"},
"liparidae":{"liparidae","liparidaes"},
"liparididae":{"liparididae","liparididaes"},
"liparis":{"liparis","liparises"},
"lipectomy":{"lipectomies","lipectomy"},
"lipfern":{"lipfern","lipferns"},
"lipid":{"lipid","lipids"},
"lipide":{"lipide","lipides"},
"lipoid":{"lipoid","lipoids"},
"lipoma":{"lipoma","lipomas","lipomata"},
"liposcelis":{"liposcelis","liposcelises"},
"lipotyphla":{"lipotyphla","lipotyphlas"},
"lippy":{"lippier","lippiest","lippy"},
"lipstick":{"lipstick","lipsticks"},
"liquate":{"liquate","liquated","liquating"},
"liquefy":{"liquefied","liquefies","liquefy","liquefying"},
"liqueur":{"liqueur","liqueurs"},
"liquid":{"liquid","liquids"},
"liquidambar":{"liquidambar","liquidambars"},
"liquidate":{"liquidate","liquidated","liquidates","liquidating"},
"liquidation":{"liquidation","liquidations"},
"liquidator":{"liquidator","liquidators"},
"liquidity":{"liquidities","liquidity"},
"liquidize":{"liquidize","liquidized","liquidizes","liquidizing"},
"liquidizer":{"liquidizer","liquidizers"},
"liquidness":{"liquidness","liquidnesses"},
"liquify":{"liquified","liquifies","liquify","liquifying"},
"liquor":{"liquor","liquored","liquoring","liquors"},
"liquorice":{"liquorice","liquorices"},
"lir":{"lir","lirs"},
"lira":{"lira","liras","lire"},
"liriodendron":{"liriodendron","liriodendrons"},
"liriope":{"liriope","liriopes"},
"lisboa":{"lisboa","lisboas"},
"lisbon":{"lisbon","lisbons"},
"lisinopril":{"lisinopril","lisinoprils"},
"lisp":{"lisp","lisped","lisping","lisps"},
"lissomeness":{"lissomeness","lissomenesses"},
"list":{"list","listed","listing","lists"},
"listen":{"listen","listened","listening","listens"},
"listener":{"listener","listeners"},
"listening":{"listening","listenings"},
"lister":{"lister","listers"},
"listera":{"listera","listeras"},
"listing":{"listing","listings"},
"listlessness":{"listlessness","listlessnesses"},
"lit":{"lit","litai","lits"},
"litany":{"litanies","litany"},
"litas":{"litai","litas","litu"},
"litchee":{"litchee","litchees"},
"litchi":{"litchi","litchis"},
"liter":{"liter","liters"},
"literal":{"literal","literals"},
"literalist":{"literalist","literalists"},
"literality":{"literalities","literality"},
"literalize":{"literalize","literalized","literalizing"},
"literate":{"literate","literates"},
"literature":{"literature","literatures"},
"lithane":{"lithane","lithanes"},
"lithe":{"lithe","lither","lithest"},
"litheness":{"litheness","lithenesses"},
"lithiasis":{"lithiases","lithiasis"},
"lithify":{"lithified","lithify","lithifying"},
"lithium":{"lithium","lithiums"},
"litho":{"litho","lithos"},
"lithocarpus":{"lithocarpus","lithocarpuses"},
"lithodidae":{"lithodidae","lithodidaes"},
"lithoglyptics":{"lithoglyptics","lithoglypticses"},
"lithograph":{"lithograph","lithographed","lithographing","lithographs"},
"lithonate":{"lithonate","lithonates"},
"lithophragma":{"lithophragma","lithophragmas"},
"lithophyte":{"lithophyte","lithophytes"},
"lithops":{"lithops","lithopses"},
"lithospermum":{"lithospermum","lithospermums"},
"lithosphere":{"lithosphere","lithospheres"},
"lithotomy":{"lithotomies","lithotomy"},
"lithotrity":{"lithotrities","lithotrity"},
"lithuania":{"lithuania","lithuanias"},
"litigant":{"litigant","litigants"},
"litigate":{"litigate","litigated","litigates","litigating"},
"litigator":{"litigator","litigators"},
"litmus":{"litmus","litmuses"},
"litocranius":{"litocranius","litocraniuses"},
"litoral":{"litoral","litorals"},
"litotes":{"litotes","litoteses"},
"litre":{"litre","litres"},
"litter":{"litter","littered","littering","litters"},
"litter-bearer":{"litter-bearer","litter-bearers"},
"litterateur":{"litterateur","litterateurs"},
"litterbasket":{"litterbasket","litterbaskets"},
"litterbin":{"litterbin","litterbins"},
"litterbug":{"litterbug","litterbugs"},
"litterer":{"litterer","litterers"},
"little":{"least","less","lesser","little","littler","littlest"},
"littleneck":{"littleneck","littlenecks"},
"littleness":{"littleness","littlenesses"},
"littoral":{"littoral","littorals"},
"littorina":{"littorina","littorinas"},
"littorinidae":{"littorinidae","littorinidaes"},
"liturgy":{"liturgies","liturgy"},
"live":{"live","lived","liver","livest","living"},
"live-and-die":{"live-and-die","live-and-dies"},
"live-bearer":{"live-bearer","live-bearers"},
"live-forever":{"live-forever","live-forevers"},
"livelihood":{"livelihood","livelihoods"},
"liveliness":{"liveliness","livelinesses"},
"livelong":{"livelong","livelongs"},
"lively":{"livelier","liveliest","lively"},
"liven":{"liven","livened","livening","livens"},
"liveness":{"liveness","livenesses"},
"liver":{"liver","livers"},
"liverleaf":{"liverleaf","liverleaves"},
"liverwurst":{"liverwurst","liverwursts"},
"livery":{"liveries","livery"},
"liveryman":{"liveryman","liverymen"},
"livestock":{"livestock","livestocks"},
"lividity":{"lividities","lividity"},
"lividness":{"lividness","lividnesses"},
"living":{"living","livings"},
"livingroom":{"livingroom","livingrooms"},
"livistona":{"livistona","livistonas"},
"lixiviate":{"lixiviate","lixiviated","lixiviating"},
"lixivium":{"lixiviia","lixivium","lixiviums"},
"liza":{"liza","lizas"},
"lizard":{"lizard","lizards"},
"lizardfish":{"lizardfish","lizardfishes"},
"llama":{"llama","llamas"},
"llano":{"llano","llanos"},
"llb":{"llb","llbs"},
"lld":{"lld","llds"},
"llm":{"llm","llms"},
"lm":{"lm","lms"},
"load":{"load","loaded","loading","loads"},
"loader":{"loader","loaders"},
"loading":{"loading","loadings"},
"loads":{"loads","loadses"},
"loadstar":{"loadstar","loadstars"},
"loadstone":{"loadstone","loadstones"},
"loaf":{"loaf","loafed","loafing","loaves"},
"loafer":{"loafer","loafers"},
"loafing":{"loafing","loafings"},
"loam":{"loam","loamed","loaming"},
"loan":{"loan","loaned","loaning","loans"},
"loanblend":{"loanblend","loanblends"},
"loaner":{"loaner","loaners"},
"loanword":{"loanword","loanwords"},
"loasaceae":{"loasaceae","loasaceaes"},
"loathe":{"loathe","loathed","loathes","loathing"},
"loathing":{"loathing","loathings"},
"loathsomeness":{"loathsomeness","loathsomenesses"},
"lob":{"lob","lobbed","lobbing","lobs"},
"lobata":{"lobata","lobatas"},
"lobby":{"lobbied","lobbies","lobby","lobbying"},
"lobe":{"lobe","lobes"},
"lobectomy":{"lobectomies","lobectomy"},
"lobefin":{"lobefin","lobefins"},
"lobelia":{"lobelia","lobelias"},
"lobeliaceae":{"lobeliaceae","lobeliaceaes"},
"lobipes":{"lobipes","lobipeses"},
"loblolly":{"loblollies","loblolly"},
"lobo":{"lobo","lobos"},
"lobotes":{"lobotes","loboteses"},
"lobotidae":{"lobotidae","lobotidaes"},
"lobotomize":{"lobotomize","lobotomized","lobotomizing"},
"lobotomy":{"lobotomies","lobotomy"},
"lobscouse":{"lobscouse","lobscouses"},
"lobscuse":{"lobscuse","lobscuses"},
"lobster":{"lobster","lobstered","lobstering","lobsters"},
"lobsterback":{"lobsterback","lobsterbacks"},
"lobsterman":{"lobsterman","lobstermen"},
"lobularia":{"lobularia","lobularias"},
"lobworm":{"lobworm","lobworms"},
"local":{"local","locals"},
"locale":{"locale","locales"},
"localisation":{"localisation","localisations"},
"localism":{"localism","localisms"},
"locality":{"localities","locality"},
"localization":{"localization","localizations"},
"localize":{"localize","localized","localizes","localizing"},
"locate":{"locate","located","locates","locating"},
"locating":{"locating","locatings"},
"location":{"location","locations"},
"locative":{"locative","locatives"},
"loch":{"loch","loches"},
"lock":{"lock","locked","locking","locks"},
"lockbox":{"lockbox","lockboxes"},
"locke":{"locke","lockes"},
"locker":{"locker","lockers"},
"locking":{"locking","lockings"},
"lockjaw":{"lockjaw","lockjaws"},
"lockkeeper":{"lockkeeper","lockkeepers"},
"lockman":{"lockman","lockmen"},
"lockmaster":{"lockmaster","lockmasters"},
"lockring":{"lockring","lockrings"},
"lockup":{"lockup","lockups"},
"loco":{"loco","locoed","locoing","locos"},
"locofoco":{"locofoco","locofocos"},
"locoism":{"locoism","locoisms"},
"locoman":{"locoman","locomen"},
"locomote":{"locomote","locomoted","locomotes","locomoting"},
"locomotion":{"locomotion","locomotions"},
"locomotive":{"locomotive","locomotives"},
"locoweed":{"locoweed","locoweeds"},
"locule":{"locule","locules"},
"loculus":{"loculi","loculus"},
"locum":{"locum","locums"},
"locus":{"loci","locus","locuses"},
"locust":{"locust","locusts"},
"locusta":{"locusta","locustas"},
"locustidae":{"locustidae","locustidaes"},
"locution":{"locution","locutions"},
"lode":{"lode","lodes"},
"lodestar":{"lodestar","lodestars"},
"lodestone":{"lodestone","lodestones"},
"lodge":{"lodge","lodged","lodges","lodging"},
"lodgement":{"lodgement","lodgements"},
"lodgepole":{"lodgepole","lodgepoles"},
"lodger":{"lodger","lodgers"},
"lodging":{"lodging","lodgings"},
"lodgings":{"lodgings","lodgingses"},
"lodgment":{"lodgment","lodgments"},
"lodine":{"lodine","lodines"},
"lofortyx":{"lofortyx","lofortyxes"},
"loft":{"loft","lofted","lofting","lofts"},
"loftiness":{"loftiness","loftinesses"},
"lofty":{"loftier","loftiest","lofty"},
"log":{"log","logged","logging","logs"},
"logagraphia":{"logagraphia","logagraphias"},
"logan":{"logan","logans"},
"loganberry":{"loganberries","loganberry"},
"logania":{"logania","loganias"},
"loganiaceae":{"loganiaceae","loganiaceaes"},
"logarithm":{"logarithm","logarithms"},
"loge":{"loge","loges"},
"loggerhead":{"loggerhead","loggerheads"},
"loggia":{"loggia","loggias","loggie"},
"logginess":{"logginess","logginesses"},
"logic":{"logic","logics"},
"logicality":{"logicalities","logicality"},
"logicalness":{"logicalness","logicalnesses"},
"logician":{"logician","logicians"},
"loginess":{"loginess","loginesses"},
"logion":{"logia","logion","logions"},
"logistician":{"logistician","logisticians"},
"logo":{"logo","logos"},
"logogram":{"logogram","logograms"},
"logograph":{"logograph","logographs"},
"logomach":{"logomach","logomaches"},
"logomachist":{"logomachist","logomachists"},
"logomachy":{"logomachies","logomachy"},
"logomania":{"logomania","logomanias"},
"logorrhea":{"logorrhea","logorrheas"},
"logos":{"logos","logoses"},
"logotype":{"logotype","logotypes"},
"logroll":{"logroll","logrolled","logrolling"},
"logrolling":{"logrolling","logrollings"},
"logwood":{"logwood","logwoods"},
"logy":{"logier","logiest","logy"},
"lohan":{"lohan","lohans"},
"loin":{"loin","loins"},
"loincloth":{"loincloth","loincloths"},
"loins":{"loins","loinses"},
"loir":{"loir","loirs"},
"loire":{"loire","loires"},
"loiseleuria":{"loiseleuria","loiseleurias"},
"loiter":{"loiter","loitered","loitering","loiters"},
"loiterer":{"loiterer","loiterers"},
"lolium":{"lolium","loliums"},
"loll":{"loll","lolled","lolling","lolls"},
"lollipop":{"lollipop","lollipops"},
"lollop":{"lollop","lolloped","lolloping"},
"lolly":{"lollies","lolly"},
"lollygag":{"lollygag","lollygagged","lollygagging","lollygags"},
"lolo":{"lolo","lolos"},
"lolo-burmese":{"lolo-burmese","lolo-burmeses"},
"lomariopsidaceae":{"lomariopsidaceae","lomariopsidaceaes"},
"lombard":{"lombard","lombards"},
"lombardia":{"lombardia","lombardias"},
"lombardy":{"lombardies","lombardy"},
"lome":{"lome","lomes"},
"loment":{"loment","loments"},
"lomentum":{"lomenmenta","lomentum"},
"lomogramma":{"lomogramma","lomogrammas"},
"lonas":{"lonas","lonases"},
"lonchocarpus":{"lonchocarpus","lonchocarpuses"},
"london":{"london","londons"},
"loneliness":{"loneliness","lonelinesses"},
"lonely":{"lonelier","loneliest","lonely"},
"loner":{"loner","loners"},
"lonesomeness":{"lonesomeness","lonesomenesses"},
"long":{"long","longed","longer","longest","longing","longs"},
"long-distance":{"long-distance","long-distances"},
"long-sufferance":{"long-sufferance","long-sufferances"},
"long-suffering":{"long-suffering","long-sufferings"},
"long-windedness":{"long-windedness","long-windednesses"},
"longan":{"longan","longans"},
"longanberry":{"longanberries","longanberry"},
"longanimity":{"longanimities","longanimity"},
"longbeard":{"longbeard","longbeards"},
"longe":{"longe","longed","longeing"},
"longevity":{"longevities","longevity"},
"longfellow":{"longfellow","longfellows"},
"longhand":{"longhand","longhands"},
"longhorn":{"longhorn","longhorns"},
"longicorn":{"longicorn","longicorns"},
"longing":{"longing","longings"},
"longitude":{"longitude","longitudes"},
"longlegs":{"longlegs","longlegses"},
"longobard":{"longobard","longobardi","longobards"},
"longroot":{"longroot","longroots"},
"longshoreman":{"longshoreman","longshoremen"},
"longsightedness":{"longsightedness","longsightednesses"},
"longueur":{"longueur","longueurs"},
"longways":{"longways","longwayses"},
"longyi":{"longyi","longyis"},
"lonicera":{"lonicera","loniceras"},
"loniten":{"loniten","lonitens"},
"lontar":{"lontar","lontars"},
"loo":{"loo","loos"},
"looby":{"loobies","looby"},
"loofa":{"loofa","loofas"},
"loofah":{"loofah","loofahs"},
"look":{"look","looked","looking","looks"},
"look-over":{"look-over","look-overs"},
"lookdown":{"lookdown","lookdowns"},
"looker":{"looker","lookers"},
"looker-on":{"looker-on","looker-ons","lookers-on"},
"looking":{"looking","lookings"},
"lookingglass":{"lookingglass","lookingglasses"},
"lookout":{"lookout","lookouts"},
"lookup":{"lookup","lookups"},
"look_towards":{"looked_towards","looking_towards","looks_towards","look_towards"},
"loom":{"loom","loomed","looming","looms"},
"loon":{"loon","loons"},
"looney":{"looney","looneys"},
"loony":{"loonier","loonies","looniest","loony"},
"loop":{"loop","looped","looping","loops"},
"looper":{"looper","loopers"},
"loophole":{"loophole","loopholes"},
"loopy":{"loopier","loopiest","loopy"},
"loose":{"loose","loosed","looser","loosest","loosing"},
"loosen":{"loosen","loosened","loosening","loosens"},
"looseness":{"looseness","loosenesses"},
"loosening":{"loosening","loosenings"},
"loot":{"loot","looted","looting","loots"},
"looter":{"looter","looters"},
"looting":{"looting","lootings"},
"lop":{"lop","lopped","lopping","lops"},
"lope":{"lope","loped","lopes","loping"},
"lophiidae":{"lophiidae","lophiidaes"},
"lophius":{"lophius","lophiuses"},
"lophodytes":{"lophodytes","lophodyteses"},
"lopholatilus":{"lopholatilus","lopholatiluses"},
"lophophora":{"lophophora","lophophoras"},
"lophophorus":{"lophophorus","lophophoruses"},
"lophosoria":{"lophosoria","lophosorias"},
"lophosoriaceae":{"lophosoriaceae","lophosoriaceaes"},
"loppy":{"loppier","loppiest","loppy"},
"lopressor":{"lopressor","lopressors"},
"lopsidedness":{"lopsidedness","lopsidednesses"},
"loquaciousness":{"loquaciousness","loquaciousnesses"},
"loquacity":{"loquacities","loquacity"},
"loquat":{"loquat","loquats"},
"loranthaceae":{"loranthaceae","loranthaceaes"},
"loranthus":{"loranthus","loranthuses"},
"lord":{"lord","lorded","lording","lords"},
"lordliness":{"lordliness","lordlinesses"},
"lordly":{"lordlier","lordliest","lordly"},
"lordosis":{"lordoses","lordosis"},
"lords-and-ladies":{"lords-and-ladies","lords-and-ladieses"},
"lordship":{"lordship","lordships"},
"lore":{"lore","lores"},
"lorgnon":{"lorgnon","lorgnons"},
"lorica":{"lorica","loricae"},
"loricata":{"loricata","loricatas"},
"loriinae":{"loriinae","loriinaes"},
"loris":{"loris","lorises"},
"lorisidae":{"lorisidae","lorisidaes"},
"lorraine":{"lorraine","lorraines"},
"lorry":{"lorries","lorry"},
"lory":{"lories","lory"},
"lose":{"lose","loses","losing","lost"},
"loser":{"loser","losers"},
"losings":{"losings","losingses"},
"loss":{"loss","losses"},
"losses":{"losses","losseses"},
"lost":{"lost","losts"},
"lot":{"lot","lots","lotted","lotting"},
"lota":{"lota","lotas"},
"lothario":{"lothario","lotharios"},
"lothringen":{"lothringen","lothringens"},
"loti":{"loti","maloti"},
"lotion":{"lotion","lotions"},
"lots":{"lots","lotses"},
"lotte":{"lotte","lottes"},
"lottery":{"lotteries","lottery"},
"lotto":{"lotto","lottos"},
"lotus":{"lotus","lotuses"},
"loud":{"loud","louder","loudest"},
"loud-hailer":{"loud-hailer","loud-hailers"},
"louden":{"louden","loudened","loudening"},
"loudmouth":{"loudmouth","loudmouths"},
"loudness":{"loudness","loudnesses"},
"loudspeaker":{"loudspeaker","loudspeakers"},
"lough":{"lough","loughs"},
"louisiana":{"louisiana","louisianas"},
"louisianan":{"louisianan","louisianans"},
"louisianian":{"louisianian","louisianians"},
"lounge":{"lounge","lounged","lounges","lounging"},
"lounger":{"lounger","loungers"},
"loup":{"loup","louped","louping"},
"loup-garou":{"loup-garou","loups-garous"},
"loupe":{"loupe","loupes"},
"lour":{"lour","loured","louring","lours"},
"louse":{"lice","louse","loused","louses","lousing"},
"lousiness":{"lousiness","lousinesses"},
"lousy":{"lousier","lousiest","lousy"},
"lout":{"lout","louted","louting","louts"},
"louvar":{"louvar","louvars"},
"louver":{"louver","louvers"},
"louvre":{"louvre","louvres"},
"lovage":{"lovage","lovages"},
"lovastatin":{"lovastatin","lovastatins"},
"love":{"love","loved","loves","loving"},
"love-in-a-mist":{"love-in-a-mist","love-in-a-mists"},
"love-in-idleness":{"love-in-idleness","love-in-idlenesses"},
"love-in-winter":{"love-in-winter","love-in-winters"},
"love-lies-bleeding":{"love-lies-bleeding","love-lies-bleedings"},
"love-philter":{"love-philter","love-philters"},
"love-philtre":{"love-philtre","love-philtres"},
"love-potion":{"love-potion","love-potions"},
"lovebird":{"lovebird","lovebirds"},
"loveliness":{"loveliness","lovelinesses"},
"lovely":{"lovelier","lovelies","loveliest","lovely"},
"lovemaking":{"lovemaking","lovemakings"},
"lover":{"lover","lovers"},
"lovingness":{"lovingness","lovingnesses"},
"lovoa":{"lovoa","lovoas"},
"low":{"low","lowed","lower","lowest","lowing","lows"},
"low-down":{"low-down","low-downs"},
"low-spiritedness":{"low-spiritedness","low-spiritednesses"},
"lowan":{"lowan","lowans"},
"lowbrow":{"lowbrow","lowbrows"},
"lower":{"lower","lowered","lowering","lowers","lowest"},
"lower-normandy":{"lower-normandies","lower-normandy"},
"lowercase":{"lowercase","lowercased","lowercases","lowercasing"},
"lowerclassman":{"lowerclassman","lowerclassmen"},
"lowering":{"lowering","lowerings"},
"lowland":{"lowland","lowlands"},
"lowlander":{"lowlander","lowlanders"},
"lowlife":{"lowlife","lowlifes","lowlives"},
"lowly":{"lowlier","lowliest","lowly"},
"lox":{"lox","loxes"},
"loxia":{"loxia","loxias"},
"loxodonta":{"loxodonta","loxodontas"},
"loxodrome":{"loxodrome","loxodromes"},
"loxoma":{"loxoma","loxomas"},
"loxomataceae":{"loxomataceae","loxomataceaes"},
"loxostege":{"loxostege","loxosteges"},
"loyalist":{"loyalist","loyalists"},
"loyalty":{"loyalties","loyalty"},
"loyang":{"loyang","loyangs"},
"lozenge":{"lozenge","lozenges"},
"lp":{"lp","lps"},
"lpn":{"lpn","lpns"},
"lsd":{"lsd","lsds"},
"ltm":{"ltm","ltms"},
"lu":{"lu","lus"},
"luanda":{"luanda","luandas"},
"luau":{"luau","luaus"},
"luba":{"luba","luba."},
"lubber":{"lubber","lubbers"},
"lubricant":{"lubricant","lubricants"},
"lubricate":{"lubricate","lubricated","lubricates","lubricating"},
"lubricator":{"lubricator","lubricators"},
"lubricity":{"lubricities","lubricity"},
"lubritorium":{"lubritoria","lubritorium"},
"lucania":{"lucania","lucanias"},
"lucanidae":{"lucanidae","lucanidaes"},
"lucerne":{"lucerne","lucernes"},
"lucidity":{"lucidities","lucidity"},
"lucifer":{"lucifer","lucifers"},
"lucilia":{"lucilia","lucilias"},
"lucite":{"lucite","lucites"},
"luck":{"luck","lucked","lucking","lucks"},
"lucky":{"luckier","luckiest","lucky"},
"lucre":{"lucre","lucres"},
"lucubrate":{"lucubrate","lucubrated","lucubrating"},
"lufengpithecus":{"lufengpithecus","lufengpithecuses"},
"luff":{"luff","luffed","luffing","luffs"},
"luffa":{"luffa","luffas"},
"lug":{"lug","lugged","lugging","lugs"},
"luger":{"luger","lugers"},
"luggage":{"luggage","luggages"},
"lugsail":{"lugsail","lugsails"},
"lugubriousness":{"lugubriousness","lugubriousnesses"},
"lugworm":{"lugworm","lugworms"},
"luke":{"luke","lukes"},
"lukewarmness":{"lukewarmness","lukewarmnesses"},
"lull":{"lull","lulled","lulling","lulls"},
"lullaby":{"lullabied","lullabies","lullaby","lullabying"},
"lulu":{"lulu","lulus"},
"lumbago":{"lumbago","lumbagos"},
"lumber":{"lumber","lumbered","lumbering","lumbers"},
"lumberjack":{"lumberjack","lumberjacks"},
"lumberman":{"lumberman","lumbermen"},
"lumbermill":{"lumbermill","lumbermills"},
"lumberyard":{"lumberyard","lumberyards"},
"lumen":{"lumen","lumens","lumina"},
"luminal":{"luminal","luminals"},
"luminance":{"luminance","luminances"},
"luminary":{"luminaries","luminary"},
"luminesce":{"luminesce","luminesced","luminescing"},
"luminescence":{"luminescence","luminescences"},
"luminosity":{"luminosities","luminosity"},
"luminousness":{"luminousness","luminousnesses"},
"lummox":{"lummox","lummoxes"},
"lump":{"lump","lumped","lumping","lumps"},
"lumpenus":{"lumpenus","lumpenuses"},
"lumper":{"lumper","lumpers"},
"lumpfish":{"lumpfish","lumpfishes"},
"lumpy":{"lumpier","lumpiest","lumpy"},
"lunacy":{"lunacies","lunacy"},
"lunaria":{"lunaria","lunarias"},
"lunatic":{"lunatic","lunatics"},
"lunation":{"lunation","lunations"},
"lunch":{"lunch","lunched","lunches","lunching"},
"luncheon":{"luncheon","luncheons"},
"lunchroom":{"lunchroom","lunchrooms"},
"lunda":{"lunda","lundas"},
"lunette":{"lunette","lunettes"},
"lung":{"lung","lungs"},
"lunge":{"lunge","lunged","lunges","lunging"},
"lungen":{"lungen","lungens"},
"lunger":{"lunger","lungers"},
"lungfish":{"lungfish","lungfishes"},
"lungi":{"lungi","lungis"},
"lungyi":{"lungyi","lungyis"},
"lunkhead":{"lunkhead","lunkheads"},
"lunula":{"lunula","lunulae","lunulas"},
"lunule":{"lunule","lunules"},
"luny":{"lunier","lunies","luniest","luny"},
"luoyang":{"luoyang","luoyangs"},
"lupercalia":{"lupercalia","lupercalias"},
"lupin":{"lupin","lupins"},
"lupine":{"lupine","lupines"},
"lupinus":{"lupinus","lupinuses"},
"lurch":{"lurch","lurched","lurches","lurching"},
"lurcher":{"lurcher","lurchers"},
"lure":{"lure","lured","lures","luring"},
"luridness":{"luridness","luridnesses"},
"lurk":{"lurk","lurked","lurking","lurks"},
"lurker":{"lurker","lurkers"},
"lusaka":{"lusaka","lusakas"},
"lusatian":{"lusatian","lusatians"},
"luscinia":{"luscinia","luscinias"},
"lusciousness":{"lusciousness","lusciousnesses"},
"lush":{"lush","lushed","lusher","lushes","lushest","lushing"},
"lushness":{"lushness","lushnesses"},
"lust":{"lust","lusted","lusting","lusts"},
"luster":{"luster","lustered","lustering","lusters"},
"lusterlessness":{"lusterlessness","lusterlessnesses"},
"lustfulness":{"lustfulness","lustfulnesses"},
"lustiness":{"lustiness","lustinesses"},
"lustrate":{"lustrate","lustrated","lustrating"},
"lustre":{"lustre","lustres"},
"lustrum":{"lustra","lustrum","lustrums"},
"lusty":{"lustier","lustiest","lusty"},
"lutanist":{"lutanist","lutanists"},
"lute":{"lute","luted","lutes","luting"},
"lutecium":{"lutecium","luteciums"},
"lutefisk":{"lutefisk","lutefisks"},
"lutein":{"lutein","luteins"},
"luteinize":{"luteinize","luteinized","luteinizing"},
"lutenist":{"lutenist","lutenists"},
"lutetium":{"lutetium","lutetiums"},
"lutfisk":{"lutfisk","lutfisks"},
"luther":{"luther","luthers"},
"luting":{"luting","lutings"},
"lutist":{"lutist","lutists"},
"lutjanidae":{"lutjanidae","lutjanidaes"},
"lutjanus":{"lutjanus","lutjanuses"},
"lutra":{"lutra","lutras"},
"lutrinae":{"lutrinae","lutrinaes"},
"lutzen":{"lutzen","lutzens"},
"luvaridae":{"luvaridae","luvaridaes"},
"luvarus":{"luvarus","luvaruses"},
"luvian":{"luvian","luvians"},
"luwian":{"luwian","luwians"},
"lux":{"luces","lux","luxes"},
"luxate":{"luxate","luxated","luxating"},
"luxembourg":{"luxembourg","luxembourgs"},
"luxembourger":{"luxembourger","luxembourgers"},
"luxemburg":{"luxemburg","luxemburgs"},
"luxemburger":{"luxemburger","luxemburgers"},
"luxuria":{"luxuria","luxurias"},
"luxuriance":{"luxuriance","luxuriances"},
"luxuriate":{"luxuriate","luxuriated","luxuriates","luxuriating"},
"luxuriousness":{"luxuriousness","luxuriousnesses"},
"luxury":{"luxuries","luxury"},
"lw":{"lw","lws"},
"lwei":{"lwei","lweis"},
"lx":{"lx","lxes"},
"lxx":{"lxx","lxxes"},
"lxxx":{"lxxx","lxxxes"},
"lycaena":{"lycaena","lycaenas"},
"lycaenid":{"lycaenid","lycaenids"},
"lycaenidae":{"lycaenidae","lycaenidaes"},
"lycaeon":{"lycaeon","lycaeons"},
"lycanthrope":{"lycanthrope","lycanthropes"},
"lycee":{"lycee","lycees"},
"lyceum":{"lyceum","lyceums"},
"lychee":{"lychee","lychees"},
"lychgate":{"lychgate","lychgates"},
"lychnis":{"lychnis","lychnises"},
"lycium":{"lycium","lyciums"},
"lycoperdaceae":{"lycoperdaceae","lycoperdaceaes"},
"lycoperdales":{"lycoperdales","lycoperdaleses"},
"lycoperdon":{"lycoperdon","lycoperdons"},
"lycopersicon":{"lycopersicon","lycopersicons"},
"lycopersicum":{"lycopersicum","lycopersicums"},
"lycopod":{"lycopod","lycopods"},
"lycopodiaceae":{"lycopodiaceae","lycopodiaceaes"},
"lycopodiales":{"lycopodiales","lycopodialeses"},
"lycopodiate":{"lycopodiate","lycopodiates"},
"lycopodineae":{"lycopodineae","lycopodineaes"},
"lycopodium":{"lycopodium","lycopodiums"},
"lycopsida":{"lycopsida","lycopsidas"},
"lycopus":{"lycopus","lycopuses"},
"lycosa":{"lycosa","lycosas"},
"lycosidae":{"lycosidae","lycosidaes"},
"lygaeid":{"lygaeid","lygaeids"},
"lygaeidae":{"lygaeidae","lygaeidaes"},
"lyginopteridales":{"lyginopteridales","lyginopteridaleses"},
"lyginopteris":{"lyginopteris","lyginopterises"},
"lygodium":{"lygodium","lygodiums"},
"lygus":{"lygus","lyguses"},
"lying":{"lying","lyings"},
"lying-in":{"lying-in","lying-ins","lyings-in"},
"lymantria":{"lymantria","lymantrias"},
"lymantriid":{"lymantriid","lymantriids"},
"lymantriidae":{"lymantriidae","lymantriidaes"},
"lymphangioma":{"lymphangioma","lymphangiomas","lymphangiomata"},
"lymphangitis":{"lymphangitides","lymphangitis"},
"lymphocyte":{"lymphocyte","lymphocytes"},
"lymphogranuloma":{"lymphogranuloma","lymphogranulomas","lymphogranulomata"},
"lymphoma":{"lymphoma","lymphomas","lymphomata"},
"lymphomatosis":{"lymphomatosis","lymphomatosises"},
"lymphopoiesis":{"lymphopoieses","lymphopoiesis"},
"lynch":{"lynch","lynched","lynching"},
"lynchpin":{"lynchpin","lynchpins"},
"lynx":{"lynx","lynxes"},
"lyon":{"lyon","lyons"},
"lyonia":{"lyonia","lyonias"},
"lyons":{"lyons","lyonses"},
"lyophilize":{"lyophilize","lyophilized","lyophilizes","lyophilizing"},
"lyra":{"lyra","lyrae"},
"lyre":{"lyre","lyres"},
"lyreflower":{"lyreflower","lyreflowers"},
"lyric":{"lyric","lyrics"},
"lyricality":{"lyricalities","lyricality"},
"lyricism":{"lyricism","lyricisms"},
"lyricize":{"lyricize","lyricized","lyricizes","lyricizing"},
"lyrurus":{"lyrurus","lyruruses"},
"lyse":{"lyse","lysed","lyses","lysing"},
"lysichiton":{"lysichiton","lysichitons"},
"lysichitum":{"lysichitum","lysichitums"},
"lysiloma":{"lysiloma","lysilomas"},
"lysimachia":{"lysimachia","lysimachias"},
"lythraceae":{"lythraceae","lythraceaes"},
"lythrum":{"lythrum","lythrums"},
"lytta":{"lytta","lyttae","lyttas"},
"m":{"m","ms"},
"m-1":{"m-1","m-1s"},
"ma":{"ma","mas"},
"maar":{"maar","maare","maars"},
"mac":{"mac","macs"},
"macaca":{"macaca","macacas"},
"macaco":{"macaco","macacos"},
"macadam":{"macadam","macadams"},
"macadamia":{"macadamia","macadamias"},
"macadamize":{"macadamize","macadamized","macadamizes","macadamizing"},
"macamba":{"macamba","macambas"},
"macao":{"macao","macaos"},
"macaroni":{"macaroni","macaronies","macaronis"},
"macaronic":{"macaronic","macaronics"},
"macau":{"macau","macaus"},
"maccaroni":{"maccaroni","maccaronies","maccaronis"},
"mace":{"mace","maces"},
"macebearer":{"macebearer","macebearers"},
"macedon":{"macedon","macedons"},
"macedonia":{"macedonia","macedonias"},
"macer":{"macer","macers"},
"macerate":{"macerate","macerated","macerates","macerating"},
"maceration":{"maceration","macerations"},
"machaeranthera":{"machaeranthera","machaerantheras"},
"machete":{"machete","machetes"},
"machiavelli":{"machiavelli","machiavellis"},
"machicolate":{"machicolate","machicolated","machicolates","machicolating"},
"machilid":{"machilid","machilids"},
"machilidae":{"machilidae","machilidaes"},
"machinate":{"machinate","machinated","machinating"},
"machination":{"machination","machinations"},
"machinator":{"machinator","machinators"},
"machine":{"machine","machined","machines","machining"},
"machine-gun":{"machine-gun","machine-gunned","machine-gunning","machine-guns"},
"machinery":{"machineries","machinery"},
"machinist":{"machinist","machinists"},
"macho":{"macho","machos"},
"macho-man":{"macho-man","macho-men"},
"machzor":{"machzor","machzorim"},
"macintosh":{"macintosh","macintoshes"},
"mack":{"mack","macks"},
"mackenzie":{"mackenzie","mackenzies"},
"mackerel":{"mackerel","mackerels"},
"mackinaw":{"mackinaw","mackinaws"},
"mackintosh":{"mackintosh","mackintoshes"},
"macleaya":{"macleaya","macleayas"},
"maclura":{"maclura","macluras"},
"macon":{"macon","macons"},
"maconnais":{"maconnais","maconnaises"},
"macowanites":{"macowanites","macowaniteses"},
"macro":{"macro","macros"},
"macrocephalon":{"macrocephalon","macrocephalons"},
"macrocephaly":{"macrocephalies","macrocephaly"},
"macrocheira":{"macrocheira","macrocheiras"},
"macroclemys":{"macroclemys","macroclemyses"},
"macrocosm":{"macrocosm","macrocosms"},
"macrocyte":{"macrocyte","macrocytes"},
"macrodactylus":{"macrodactylus","macrodactyluses"},
"macrodantin":{"macrodantin","macrodantins"},
"macroglia":{"macroglia","macroglias"},
"macromolecule":{"macromolecule","macromolecules"},
"macronectes":{"macronectes","macronecteses"},
"macronucleus":{"macronuclei","macronucleus"},
"macropodidae":{"macropodidae","macropodidaes"},
"macropus":{"macropus","macropuses"},
"macrorhamphosidae":{"macrorhamphosidae","macrorhamphosidaes"},
"macrosporangium":{"macrosporangia","macrosporangium"},
"macrothelypteris":{"macrothelypteris","macrothelypterises"},
"macrotis":{"macrotis","macrotises"},
"macrotus":{"macrotus","macrotuses"},
"macrotyloma":{"macrotyloma","macrotylomas"},
"macrouridae":{"macrouridae","macrouridaes"},
"macrozoarces":{"macrozoarces","macrozoarceses"},
"macruridae":{"macruridae","macruridaes"},
"macula":{"macula","maculae","maculas"},
"maculation":{"maculation","maculations"},
"macule":{"macule","macules"},
"mad":{"mad","madded","madder","maddest","madding","mads"},
"madake":{"madake","madakes"},
"madam":{"madam","madams","mesdames"},
"madame":{"madame","madames","mesdames"},
"madcap":{"madcap","madcaps"},
"madden":{"madden","maddened","maddening","maddens"},
"madder":{"madder","madders"},
"madderwort":{"madderwort","madderworts"},
"madeira":{"madeira","madeiras"},
"mademoiselle":{"mademoiselle","mademoiselles","mesdemoiselles"},
"madhouse":{"madhouse","madhouses"},
"madia":{"madia","madias"},
"madison":{"madison","madisons"},
"madman":{"madman","madmen"},
"madnep":{"madnep","madneps"},
"madness":{"madness","madnesses"},
"madonna":{"madonna","madonnas"},
"madreporaria":{"madreporaria","madreporarias"},
"madrepore":{"madrepore","madrepores"},
"madrid":{"madrid","madrids"},
"madrona":{"madrona","madronas"},
"madrone":{"madrone","madrones"},
"madrono":{"madrono","madronos"},
"maduro":{"maduro","maduros"},
"madwoman":{"madwoman","madwomen"},
"madwort":{"madwort","madworts"},
"maeandra":{"maeandra","maeandras"},
"maelstrom":{"maelstrom","maelstroms"},
"maestro":{"maestri","maestro","maestros"},
"mafa":{"mafa","mafas"},
"maffia":{"maffia","maffias"},
"maffick":{"maffick","mafficked","mafficking"},
"mafia":{"mafia","mafias"},
"mafioso":{"mafiosi","mafioso","mafiosos"},
"mag":{"mag","mags"},
"magazine":{"magazine","magazines"},
"magellan":{"magellan","magellans"},
"magenta":{"magenta","magentas"},
"maggot":{"maggot","maggots"},
"magi":{"magi","magis"},
"magic":{"magic","magics"},
"magician":{"magician","magicians"},
"magicicada":{"magicicada","magicicadas"},
"magistery":{"magisteries","magistery"},
"magistracy":{"magistracies","magistracy"},
"magistrate":{"magistrate","magistrates"},
"magistrature":{"magistrature","magistratures"},
"magma":{"magma","magmas","magmata"},
"magnanimity":{"magnanimities","magnanimity"},
"magnanimousness":{"magnanimousness","magnanimousnesses"},
"magnate":{"magnate","magnates"},
"magnesia":{"magnesia","magnesias"},
"magnesium":{"magnesium","magnesiums"},
"magnet":{"magnet","magnets"},
"magnetics":{"magnetics","magneticses"},
"magnetisation":{"magnetisation","magnetisations"},
"magnetism":{"magnetism","magnetisms"},
"magnetite":{"magnetite","magnetites"},
"magnetization":{"magnetization","magnetizations"},
"magnetize":{"magnetize","magnetized","magnetizes","magnetizing"},
"magneto":{"magneto","magnetos"},
"magnetometer":{"magnetometer","magnetometers"},
"magnification":{"magnification","magnifications"},
"magnificence":{"magnificence","magnificences"},
"magnifico":{"magnifico","magnificoes"},
"magnify":{"magnified","magnifies","magnify","magnifying"},
"magniloquence":{"magniloquence","magniloquences"},
"magnitude":{"magnitude","magnitudes"},
"magnolia":{"magnolia","magnolias"},
"magnoliaceae":{"magnoliaceae","magnoliaceaes"},
"magnoliidae":{"magnoliidae","magnoliidaes"},
"magnoliophyta":{"magnoliophyta","magnoliophytas"},
"magnoliopsid":{"magnoliopsid","magnoliopsids"},
"magnoliopsida":{"magnoliopsida","magnoliopsidas"},
"magnum":{"magnum","magnums"},
"magpie":{"magpie","magpies"},
"maguey":{"maguey","magueys"},
"magus":{"magi","magus"},
"magyar":{"magyar","magyars"},
"magyarorszag":{"magyarorszag","magyarorszags"},
"mah-jongg":{"mah-jongg","mah-jonggs"},
"maha":{"maha","mahas"},
"mahabharata":{"mahabharata","mahabharatas"},
"mahabharatam":{"mahabharatam","mahabharatams"},
"mahabharatum":{"mahabharatum","mahabharatums"},
"mahagua":{"mahagua","mahaguas"},
"maharaja":{"maharaja","maharajas"},
"maharajah":{"maharajah","maharajahs"},
"maharanee":{"maharanee","maharanees"},
"maharani":{"maharani","maharanis"},
"mahatma":{"mahatma","mahatmas"},
"mahdi":{"mahdi","mahdis"},
"mahican":{"mahican","mahicans"},
"mahimahi":{"mahimahi","mahimahis"},
"mahjong":{"mahjong","mahjongs"},
"mahlstick":{"mahlstick","mahlsticks"},
"mahoe":{"mahoe","mahoes"},
"mahogany":{"mahoganies","mahogany"},
"mahomet":{"mahomet","mahomets"},
"mahonia":{"mahonia","mahonias"},
"mahound":{"mahound","mahounds"},
"mahratta":{"mahratta","mahrattas"},
"mahratti":{"mahratti","mahrattis"},
"mahuang":{"mahuang","mahuangs"},
"mahzor":{"mahzor","mahzorim"},
"maia":{"maia","maias"},
"maianthemum":{"maianthemum","maianthemums"},
"maid":{"maid","maids"},
"maiden":{"maiden","maidens"},
"maidenhair":{"maidenhair","maidenhairs"},
"maidenhead":{"maidenhead","maidenheads"},
"maidenhood":{"maidenhood","maidenhoods"},
"maidhood":{"maidhood","maidhoods"},
"maidservant":{"maidservant","maidservants"},
"maidu":{"maidu","maidus"},
"maiger":{"maiger","maigers"},
"maigre":{"maigre","maigres"},
"maikoa":{"maikoa","maikoas"},
"mail":{"mail","mailed","mailing","mails"},
"mailbag":{"mailbag","mailbags"},
"mailboat":{"mailboat","mailboats"},
"mailbox":{"mailbox","mailboxes"},
"mailing":{"mailing","mailings"},
"mailing-card":{"mailing-card","mailing-cards"},
"maillot":{"maillot","maillots"},
"mailman":{"mailman","mailmen"},
"maim":{"maim","maimed","maiming"},
"maimed":{"maimed","maimeds"},
"maiming":{"maiming","maimings"},
"main":{"main","mains"},
"maine":{"maine","maines"},
"mainer":{"mainer","mainers"},
"mainframe":{"mainframe","mainframes"},
"mainlander":{"mainlander","mainlanders"},
"mainline":{"mainline","mainlined","mainlining"},
"mainsheet":{"mainsheet","mainsheets"},
"mainstay":{"mainstay","mainstays"},
"maintain":{"maintain","maintained","maintaining","maintains"},
"maintenance":{"maintenance","maintenances"},
"maiolica":{"maiolica","maiolicas"},
"maize":{"maize","maizes"},
"maja":{"maja","majas"},
"majagua":{"majagua","majaguas"},
"majesty":{"majesties","majesty"},
"majidae":{"majidae","majidaes"},
"majolica":{"majolica","majolicas"},
"major":{"major","majored","majoring","majors"},
"major-domo":{"major-domo","major-domos"},
"majorana":{"majorana","majoranas"},
"majority":{"majorities","majority"},
"majors":{"majors","majorses"},
"major_axis":{"major-axes","major_axes","major_axis"},
"makaira":{"makaira","makairas"},
"make":{"made","make","makes","making"},
"make-believe":{"make-believe","make-believes"},
"make-do":{"make-do","make-dos"},
"make-peace":{"make-peace","make-peaces"},
"make-up":{"make-up","make-ups"},
"make-work":{"make-work","make-works"},
"maker":{"maker","makers"},
"makeshift":{"makeshift","makeshifts"},
"makeup":{"makeup","makeups"},
"makeweight":{"makeweight","makeweights"},
"makin":{"makin","makins"},
"making":{"making","makings"},
"mako":{"mako","makos"},
"makomako":{"makomako","makomakos"},
"mala":{"mala","malas"},
"malacanthidae":{"malacanthidae","malacanthidaes"},
"malacca":{"malacca","malaccas"},
"malaclemys":{"malaclemys","malaclemyses"},
"malaconotinae":{"malaconotinae","malaconotinaes"},
"malacopterygian":{"malacopterygian","malacopterygians"},
"malacopterygii":{"malacopterygii","malacopterygiis"},
"malacosoma":{"malacosoma","malacosomas"},
"malacostraca":{"malacostraca","malacostracas"},
"malacothamnus":{"malacothamnus","malacothamnuses"},
"maladminister":{"maladminister","maladministered","maladministering"},
"maladroitness":{"maladroitness","maladroitnesses"},
"malady":{"maladies","malady"},
"malagasy":{"malagasies","malagasy"},
"malaise":{"malaise","malaises"},
"malamute":{"malamute","malamutes"},
"malanga":{"malanga","malangas"},
"malaprop":{"malaprop","malaprops"},
"malapropism":{"malapropism","malapropisms"},
"malawi":{"malawi","malawis"},
"malaxis":{"malaxes","malaxis"},
"malaxis-unifolia":{"malaxis-unifolia","malaxis-unifolias"},
"malay":{"malay","malays"},
"malaya":{"malaya","malayas"},
"malayan":{"malayan","malayans"},
"malaysia":{"malaysia","malaysias"},
"malaysian":{"malaysian","malaysians"},
"malcolmia":{"malcolmia","malcolmias"},
"maldivan":{"maldivan","maldivans"},
"maldivian":{"maldivian","maldivians"},
"maldon":{"maldon","maldons"},
"male":{"male","males"},
"maleberry":{"maleberries","maleberry"},
"malecite":{"malecite","malecites"},
"malediction":{"malediction","maledictions"},
"malefactor":{"malefactor","malefactors"},
"maleficence":{"maleficence","maleficences"},
"malemute":{"malemute","malemutes"},
"maleness":{"maleness","malenesses"},
"maleo":{"maleo","maleos"},
"maleseet":{"maleseet","maleseets"},
"malevolence":{"malevolence","malevolences"},
"malevolency":{"malevolencies","malevolency"},
"malfeasance":{"malfeasance","malfeasances"},
"malformation":{"malformation","malformations"},
"malfunction":{"malfunction","malfunctioned","malfunctioning","malfunctions"},
"mali":{"mali","malis"},
"malice":{"malice","malices"},
"maliciousness":{"maliciousness","maliciousnesses"},
"malign":{"malign","maligned","maligning","maligns"},
"malignance":{"malignance","malignances"},
"malignancy":{"malignancies","malignancy"},
"malignant":{"malignant","malignants"},
"maligner":{"maligner","maligners"},
"malignity":{"malignities","malignity"},
"malignment":{"malignment","malignments"},
"malihini":{"malihini","malihinis"},
"malinger":{"malinger","malingered","malingering","malingers"},
"malingerer":{"malingerer","malingerers"},
"malingering":{"malingering","malingerings"},
"malinke":{"malinke","malinkes"},
"mall":{"mall","malls"},
"mallard":{"mallard","mallards"},
"malleability":{"malleabilities","malleability"},
"malleolus":{"malleoli","malleolus"},
"mallet":{"mallet","mallets"},
"malleus":{"mallei","malleus","malleuses"},
"mallophaga":{"mallophaga","mallophagas"},
"mallotus":{"mallotus","mallotuses"},
"malnourishment":{"malnourishment","malnourishments"},
"malodor":{"malodor","malodors"},
"malodorousness":{"malodorousness","malodorousnesses"},
"malodour":{"malodour","malodours"},
"malodourousness":{"malodourousness","malodourousnesses"},
"malonylurea":{"malonylurea","malonylureas"},
"malope":{"malope","malopes"},
"malopterurus":{"malopterurus","malopteruruses"},
"malosma":{"malosma","malosmas"},
"malpighia":{"malpighia","malpighias"},
"malpighiaceae":{"malpighiaceae","malpighiaceaes"},
"malposition":{"malposition","malpositions"},
"malpractice":{"malpractice","malpractices"},
"mals":{"mals","malses"},
"malt":{"malt","malted","malting","malts"},
"malted":{"malted","malteds"},
"maltese":{"maltese","malteses","matlese"},
"maltha":{"maltha","malthas"},
"malthus":{"malthus","malthuses"},
"malthusianism":{"malthusianism","malthusianisms"},
"maltman":{"maltman","maltmen"},
"maltose":{"maltose","maltoses"},
"maltreat":{"maltreat","maltreated","maltreating","maltreats"},
"maltreatment":{"maltreatment","maltreatments"},
"maltster":{"maltster","maltsters"},
"malty":{"maltier","maltiest","malty"},
"malus":{"malus","maluses"},
"malva":{"malva","malvas"},
"malvaceae":{"malvaceae","malvaceaes"},
"malvales":{"malvales","malvaleses"},
"malvastrum":{"malvastrum","malvastrums"},
"malvaviscus":{"malvaviscus","malvaviscuses"},
"mama":{"mama","mamas"},
"mamba":{"mamba","mambas"},
"mambo":{"mambo","mamboed","mamboing","mambos"},
"mamey":{"mamey","mameys"},
"mamilla":{"mamilla","mamillae","mamillas"},
"mamma":{"mamma","mammas"},
"mammal":{"mammal","mammals"},
"mammalia":{"mammalia","mammalias"},
"mammea":{"mammea","mammeas"},
"mammee":{"mammee","mammees"},
"mammilla":{"mamillae","mammilla","mammillas"},
"mammock":{"mammock","mammocked","mammocking"},
"mammoth":{"mammoth","mammoths"},
"mammut":{"mammut","mammuts"},
"mammuthus":{"mammuthus","mammuthuses"},
"mammutidae":{"mammutidae","mammutidaes"},
"mammy":{"mammies","mammy"},
"mamoncillo":{"mamoncillo","mamoncillos"},
"man":{"man","manned","manning","men"},
"man-about-town":{"man-about-town","man-about-towns"},
"man-at-arms":{"man-at-arms","men-at-arms"},
"man-child":{"man-child","man-children","men-children"},
"man-day":{"man-day","man-days"},
"man-eater":{"man-eater","man-eaters"},
"man-of-the-earth":{"man-of-the-earth","man-of-the-earths"},
"man-of-war":{"man-of-war","man-of-wars","men-of-war"},
"man-on-a-horse":{"man-on-a-horse","man-on-a-horses"},
"manacle":{"manacle","manacled","manacles","manacling"},
"manage":{"manage","managed","manages","managing"},
"manageability":{"manageabilities","manageability"},
"manageableness":{"manageableness","manageablenesses"},
"management":{"management","managements"},
"manager":{"manager","managers"},
"managing":{"managing","managings"},
"managua":{"managua","managuas"},
"manakin":{"manakin","manakins"},
"manama":{"manama","manamas"},
"manatee":{"manatee","manatees"},
"manawydan":{"manawydan","manawydans"},
"manawyddan":{"manawyddan","manawyddans"},
"manchu":{"manchu","manchus"},
"mandala":{"mandala","mandalas"},
"mandamus":{"mandamus","mandamuses"},
"mandan":{"mandan","mandans"},
"mandara":{"mandara","mandaras"},
"mandarin":{"mandarin","mandarins"},
"mandatary":{"mandataries","mandatary"},
"mandate":{"mandate","mandated","mandates","mandating"},
"mandatory":{"mandatories","mandatory"},
"mande":{"mande","mandes"},
"mandelamine":{"mandelamine","mandelamines"},
"mandevilla":{"mandevilla","mandevillas"},
"mandible":{"mandible","mandibles"},
"mandibula":{"mandibula","mandibulas"},
"mandingo":{"mandingo","mandingoes","mandingos"},
"mandioc":{"mandioc","mandiocs"},
"mandioca":{"mandioca","mandiocas"},
"mandragora":{"mandragora","mandragoras"},
"mandrake":{"mandrake","mandrakes"},
"mandrel":{"mandrel","mandrels"},
"mandril":{"mandril","mandrils"},
"mandrill":{"mandrill","mandrills"},
"mandrillus":{"mandrillus","mandrilluses"},
"manduca":{"manduca","manducas"},
"mane":{"mane","manes"},
"maneuver":{"maneuver","maneuvered","maneuvering","maneuvers"},
"maneuverability":{"maneuverabilities","maneuverability"},
"maneuverer":{"maneuverer","maneuverers"},
"maneuvering":{"maneuvering","maneuverings"},
"manfulness":{"manfulness","manfulnesses"},
"manganese":{"manganese","manganeses"},
"mangel-wurzel":{"mangel-wurzel","mangel-wurzels"},
"manger":{"manger","mangers"},
"mangifera":{"mangifera","mangiferas"},
"manginess":{"manginess","manginesses"},
"mangle":{"mangle","mangled","mangles","mangling"},
"mangler":{"mangler","manglers"},
"mango":{"mango","mangoes","mangos"},
"mangold":{"mangold","mangolds"},
"mangold-wurzel":{"mangold-wurzel","mangold-wurzels"},
"mangosteen":{"mangosteen","mangosteens"},
"mangrove":{"mangrove","mangroves"},
"mangy":{"mangier","mangiest","mangy"},
"manhandle":{"manhandle","manhandled","manhandling"},
"mania":{"mania","manias"},
"maniac":{"maniac","maniacs"},
"manicure":{"manicure","manicured","manicures","manicuring"},
"manidae":{"manidae","manidaes"},
"manifest":{"manifest","manifested","manifesting","manifests"},
"manifestation":{"manifestation","manifestations"},
"manifesto":{"manifesto","manifestoes","manifestos"},
"manifold":{"manifold","manifolded","manifolding","manifolds"},
"manihot":{"manihot","manihots"},
"manikin":{"manikin","manikins"},
"manila":{"manila","manilas"},
"manilkara":{"manilkara","manilkaras"},
"manilla":{"manilla","manillas"},
"maninke":{"maninke","maninkes"},
"manioc":{"manioc","maniocs"},
"manioca":{"manioca","maniocas"},
"manipulate":{"manipulate","manipulated","manipulates","manipulating"},
"manipulation":{"manipulation","manipulations"},
"manipulator":{"manipulator","manipulators"},
"maniraptora":{"maniraptora","maniraptoras"},
"manis":{"manis","manises"},
"manito":{"manito","manitos"},
"manitou":{"manitou","manitous"},
"manitu":{"manitu","manitus"},
"mankind":{"mankind","mankinds"},
"manky":{"mankier","mankiest","manky"},
"manliness":{"manliness","manlinesses"},
"manly":{"manlier","manliest","manly"},
"manna":{"manna","mannas"},
"mannequin":{"mannequin","mannequins"},
"manner":{"manner","manners"},
"mannerism":{"mannerism","mannerisms"},
"mannikin":{"mannikin","mannikins"},
"mannitol":{"mannitol","mannitols"},
"manoeuverability":{"manoeuverabilities","manoeuverability"},
"manoeuverer":{"manoeuverer","manoeuverers"},
"manoeuvering":{"manoeuvering","manoeuverings"},
"manoeuvre":{"manoeuvre","manoeuvred","manoeuvres","manoeuvring"},
"manor":{"manor","manors"},
"manpower":{"manpower","manpowers"},
"manroot":{"manroot","manroots"},
"mansard":{"mansard","mansards"},
"manse":{"manse","manses"},
"manservant":{"manservant","menservants"},
"mansi":{"mansi","mansis"},
"mansion":{"mansion","mansions"},
"manta":{"manta","mantas"},
"manteau":{"manteau","manteaus","manteaux"},
"manteidae":{"manteidae","manteidaes"},
"mantel":{"mantel","mantels"},
"mantelet":{"mantelet","mantelets"},
"mantelpiece":{"mantelpiece","mantelpieces"},
"mantelshelf":{"mantelshelf","mantelshelves"},
"manteodea":{"manteodea","manteodeas"},
"mantichora":{"mantichora","mantichoras"},
"manticora":{"manticora","manticoras"},
"manticore":{"manticore","manticores"},
"mantid":{"mantid","mantids"},
"mantidae":{"mantidae","mantidaes"},
"mantiger":{"mantiger","mantigers"},
"mantilla":{"mantilla","mantillas"},
"mantinea":{"mantinea","mantineas"},
"mantineia":{"mantineia","mantineias"},
"mantis":{"mantes","mantis","mantises"},
"mantispidae":{"mantispidae","mantispidaes"},
"mantissa":{"mantissa","mantissas"},
"mantle":{"mantle","mantled","mantles","mantling"},
"mantlepiece":{"mantlepiece","mantlepieces"},
"mantlet":{"mantlet","mantlets"},
"mantrap":{"mantrap","mantraps"},
"mantua":{"mantua","mantuas"},
"manual":{"manual","manuals"},
"manubrium":{"manubria","manubrium","manubriums"},
"manufactory":{"manufactories","manufactory"},
"manufacture":{"manufacture","manufactured","manufactures","manufacturing"},
"manufacturer":{"manufacturer","manufacturers"},
"manufacturing":{"manufacturing","manufacturings"},
"manul":{"manul","manuls"},
"manumit":{"manumit","manumits","manumitted","manumitting"},
"manumitter":{"manumitter","manumitters"},
"manure":{"manure","manured","manures","manuring"},
"manus":{"manus","manuses"},
"manuscript":{"manuscript","manuscripts"},
"manxman":{"manxman","manxmen"},
"many-sideness":{"many-sidedness","many-sideness"},
"manzanita":{"manzanita","manzanitas"},
"man_of_letters":{"man_of_letters","men_of_letters"},
"mao":{"mao","maos"},
"maoi":{"maoi","maois"},
"maori":{"maori","maoris"},
"map":{"map","mapped","mapping","maps"},
"maple":{"maple","maples"},
"mapmaking":{"mapmaking","mapmakings"},
"mapper":{"mapper","mappers"},
"mapping":{"mapping","mappings"},
"maputo":{"maputo","maputos"},
"mar":{"mar","marred","marring","mars"},
"mara":{"mara","maras"},
"marabou":{"marabou","marabous"},
"marabout":{"marabout","marabouts"},
"maraca":{"maraca","maracas"},
"maraco":{"maraco","maracos"},
"marang":{"marang","marangs"},
"marantaceae":{"marantaceae","marantaceaes"},
"marasca":{"marasca","marascas"},
"maraschino":{"maraschino","maraschinos"},
"marasmius":{"marasmius","marasmiuses"},
"maratha":{"maratha","marathas"},
"marathi":{"marathi","marathis"},
"marathon":{"marathon","marathons"},
"marathoner":{"marathoner","marathoners"},
"marattia":{"marattia","marattias"},
"marattiaceae":{"marattiaceae","marattiaceaes"},
"marattiales":{"marattiales","marattialeses"},
"maraud":{"maraud","marauded","marauding","marauds"},
"marauder":{"marauder","marauders"},
"marauding":{"marauding","maraudings"},
"maravedi":{"maravedi","maravedis"},
"maravilla":{"maravilla","maravillas"},
"marble":{"marble","marbled","marbles","marbling"},
"marblewood":{"marblewood","marblewoods"},
"marcel":{"marcel","marcelled","marcelling","marcels"},
"march":{"march","marched","marches","marching"},
"marchantia":{"marchantia","marchantias"},
"marchantiaceae":{"marchantiaceae","marchantiaceaes"},
"marchantiales":{"marchantiales","marchantialeses"},
"marche":{"marche","marches"},
"marcher":{"marcher","marchers"},
"marches":{"marches","marcheses"},
"marchesa":{"marchesa","marchese"},
"marchese":{"marchese","marchesi"},
"marching":{"marching","marchings"},
"marchioness":{"marchioness","marchionesses"},
"marchland":{"marchland","marchlands"},
"marchpane":{"marchpane","marchpanes"},
"marduk":{"marduk","marduks"},
"mare":{"mare","mares","maria"},
"maremma":{"maremma","maremme"},
"margarin":{"margarin","margarins"},
"margarine":{"margarine","margarines"},
"margarita":{"margarita","margaritas"},
"margate":{"margate","margates"},
"margay":{"margay","margays"},
"marge":{"marge","marges"},
"margin":{"margin","margined","margining","margins"},
"marginate":{"marginate","marginated","marginating"},
"marginocephalia":{"marginocephalia","marginocephalias"},
"marginocephalian":{"marginocephalian","marginocephalians"},
"margosa":{"margosa","margosas"},
"marguerite":{"marguerite","marguerites"},
"mari":{"mari","maris"},
"maria":{"maria","marias"},
"marianas":{"marianas","marianases"},
"marigold":{"marigold","marigolds"},
"marihuana":{"marihuana","marihuanas"},
"marijuana":{"marijuana","marijuanas"},
"marimba":{"marimba","marimbas"},
"marina":{"marina","marinas"},
"marinade":{"marinade","marinaded","marinades","marinading"},
"marinate":{"marinate","marinated","marinates","marinating"},
"marine":{"marine","marines"},
"mariner":{"mariner","mariners"},
"marionette":{"marionette","marionettes"},
"mariposa":{"mariposa","mariposas"},
"mariposan":{"mariposan","mariposans"},
"maritimes":{"maritimes","maritimeses"},
"marjoram":{"marjoram","marjorams"},
"mark":{"mark","marked","marking","marks"},
"marker":{"marker","markers"},
"market":{"market","marketed","marketing","markets"},
"marketing":{"marketing","marketings"},
"marketplace":{"marketplace","marketplaces"},
"markhoor":{"markhoor","markhoors"},
"markhor":{"markhor","markhors"},
"marking":{"marking","markings"},
"markka":{"markka","markkaa"},
"marksman":{"marksman","marksmen"},
"markweed":{"markweed","markweeds"},
"marl":{"marl","marled","marling"},
"marlberry":{"marlberries","marlberry"},
"marlin":{"marlin","marlins"},
"marlinespike":{"marlinespike","marlinespikes"},
"marlingspike":{"marlingspike","marlingspikes"},
"marlinspike":{"marlinspike","marlinspikes"},
"marmara":{"marmara","marmaras"},
"marmora":{"marmora","marmoras"},
"marmot":{"marmot","marmots"},
"marmota":{"marmota","marmotas"},
"maroc":{"maroc","marocs"},
"marocain":{"marocain","marocains"},
"maroon":{"maroon","marooned","marooning","maroons"},
"marplan":{"marplan","marplans"},
"marque":{"marque","marques"},
"marquee":{"marquee","marquees"},
"marquess":{"marquess","marquesses"},
"marqueterie":{"marqueterie","marqueteries"},
"marquetry":{"marquetries","marquetry"},
"marquis":{"marquis","marquises"},
"marquise":{"marquise","marquises"},
"marrano":{"marrano","marranos"},
"marri":{"marri","marris"},
"marriage":{"marriage","marriages"},
"married":{"married","marrieds"},
"marrow":{"marrow","marrows"},
"marrubium":{"marrubium","marrubiums"},
"marruecos":{"marruecos","marruecoses"},
"marry":{"married","marries","marry","marrying"},
"mars":{"mars","marses"},
"marsh":{"marsh","marshes"},
"marshal":{"marshal","marshaled","marshaling","marshalled","marshalling","marshals"},
"marshaling":{"marshaling","marshalings"},
"marshall":{"marshall","marshalls"},
"marshland":{"marshland","marshlands"},
"marshy":{"marshier","marshiest","marshy"},
"marsilea":{"marsilea","marsileas"},
"marsileaceae":{"marsileaceae","marsileaceaes"},
"marsupial":{"marsupial","marsupials"},
"marsupialia":{"marsupialia","marsupialias"},
"marsupium":{"marsupia","marsupium"},
"mart":{"mart","marts"},
"martagon":{"martagon","martagons"},
"marten":{"marten","martens"},
"martes":{"martes","marteses"},
"martinet":{"martinet","martinets"},
"martingale":{"martingale","martingales"},
"martini":{"martini","martinis"},
"martinmas":{"martinmas","martinmases"},
"martynia":{"martynia","martynias"},
"martyniaceae":{"martyniaceae","martyniaceaes"},
"martyr":{"martyr","martyred","martyring","martyrs"},
"martyrdom":{"martyrdom","martyrdoms"},
"martyrology":{"martyrologies","martyrology"},
"martyry":{"martyries","martyry"},
"marum":{"marum","marums"},
"marumi":{"marumi","marumis"},
"marupa":{"marupa","marupas"},
"marvel":{"marvel","marveled","marveling","marvelled","marvelling","marvels"},
"marvel-of-peru":{"marvel-of-peru","marvel-of-perus"},
"marx":{"marx","marxes"},
"marxism":{"marxism","marxisms"},
"marxism-leninism":{"marxism-leninism","marxism-leninisms"},
"marxist":{"marxist","marxists"},
"mary":{"maries","mary"},
"mary-jane":{"mary-jane","mary-janes"},
"maryland":{"maryland","marylands"},
"marzipan":{"marzipan","marzipans"},
"masai":{"masai","masais"},
"mascara":{"mascara","mascaraed","mascaraing"},
"mascot":{"mascot","mascots"},
"masculine":{"masculine","masculines"},
"masculinity":{"masculinities","masculinity"},
"masculinization":{"masculinization","masculinizations"},
"masculinize":{"masculinize","masculinized","masculinizing"},
"maseru":{"maseru","maserus"},
"mash":{"mash","mashed","mashes","mashing"},
"masher":{"masher","mashers"},
"mashhad":{"mashhad","mashhads"},
"mashie":{"mashie","mashies"},
"mashona":{"mashona","mashonas"},
"masjid":{"masjid","masjids"},
"mask":{"mask","masked","masking","masks"},
"maskalonge":{"maskalonge","maskalonges"},
"maskanonge":{"maskanonge","maskanonges"},
"masking":{"masking","maskings"},
"mason":{"mason","masoned","masoning","masons"},
"masonry":{"masonries","masonry"},
"masqat":{"masqat","masqats"},
"masque":{"masque","masques"},
"masquerade":{"masquerade","masqueraded","masquerades","masquerading"},
"mass":{"mass","massed","masses","massing"},
"mass-produce":{"mass-produce","mass-produced","mass-producing"},
"massachuset":{"massachuset","massachusets"},
"massachusetts":{"massachusetts","massachusettses"},
"massacre":{"massacre","massacred","massacres","massacring"},
"massage":{"massage","massaged","massages","massaging"},
"massagist":{"massagist","massagists"},
"massasauga":{"massasauga","massasaugas"},
"masse":{"masse","masses"},
"masses":{"masses","masseses"},
"masseur":{"masseur","masseurs"},
"masseuse":{"masseuse","masseuses"},
"massiveness":{"massiveness","massivenesses"},
"massy":{"massier","massiest","massy"},
"mast":{"mast","masted","masting","masts"},
"mastectomy":{"mastectomies","mastectomy"},
"master":{"master","mastered","mastering","masters"},
"master-at-arms":{"master-at-arms","masters-at-arms"},
"mastermind":{"mastermind","masterminded","masterminding","masterminds"},
"masterpiece":{"masterpiece","masterpieces"},
"mastery":{"masteries","mastery"},
"masticate":{"masticate","masticated","masticates","masticating"},
"mastication":{"mastication","mastications"},
"masticatory":{"masticatories","masticatory"},
"masticophis":{"masticophis","masticophises"},
"mastigomycota":{"mastigomycota","mastigomycotas"},
"mastigomycotina":{"mastigomycotina","mastigomycotinas"},
"mastigophora":{"mastigophora","mastigophoras"},
"mastigophoran":{"mastigophoran","mastigophorans"},
"mastigophore":{"mastigophore","mastigophores"},
"mastigoproctus":{"mastigoproctus","mastigoproctuses"},
"mastitis":{"mastitides","mastitis"},
"mastocyte":{"mastocyte","mastocytes"},
"mastodon":{"mastodon","mastodons"},
"mastodont":{"mastodont","mastodonts"},
"mastoid":{"mastoid","mastoids"},
"mastoidectomy":{"mastoidectomies","mastoidectomy"},
"mastotermes":{"mastotermes","mastotermeses"},
"mastotermitidae":{"mastotermitidae","mastotermitidaes"},
"masturbate":{"masturbate","masturbated","masturbates","masturbating"},
"masturbation":{"masturbation","masturbations"},
"masturbator":{"masturbator","masturbators"},
"mat":{"mat","mats","matted","matting"},
"matabele":{"matabele","matabeles"},
"matai":{"matai","matais"},
"matakam":{"matakam","matakams"},
"match":{"match","matched","matches","matching"},
"matchbush":{"matchbush","matchbushes"},
"matchet":{"matchet","matchets"},
"matchmaker":{"matchmaker","matchmakers"},
"matchweed":{"matchweed","matchweeds"},
"matchwood":{"matchwood","matchwoods"},
"mate":{"mate","mated","mates","mating"},
"mater":{"mater","maters","matres"},
"material":{"material","materials"},
"materialisation":{"materialisation","materialisations"},
"materialism":{"materialism","materialisms"},
"materialist":{"materialist","materialists"},
"materiality":{"materialities","materiality"},
"materialization":{"materialization","materializations"},
"materialize":{"materialize","materialized","materializes","materializing"},
"materiel":{"materiel","materiels"},
"maternity":{"maternities","maternity"},
"mates":{"mates","mateses"},
"math":{"math","maths"},
"mathematician":{"mathematician","mathematicians"},
"mathematics":{"mathematics","mathematicses"},
"maths":{"maths","mathses"},
"matinee":{"matinee","matinees"},
"mating":{"mating","matings"},
"matins":{"matins","matinses"},
"matman":{"matman","matmen"},
"matoaka":{"matoaka","matoakas"},
"matriarch":{"matriarch","matriarches"},
"matriarchate":{"matriarchate","matriarchates"},
"matriarchy":{"matriarchies","matriarchy"},
"matric":{"matric","matrics"},
"matricaria":{"matricaria","matricarias"},
"matriculate":{"matriculate","matriculated","matriculating"},
"matriculation":{"matriculation","matriculations"},
"matrikin":{"matrikin","matrikins"},
"matrilineage":{"matrilineage","matrilineages"},
"matriliny":{"matrilinies","matriliny"},
"matrimony":{"matrimonies","matrimony"},
"matrisib":{"matrisib","matrisibs"},
"matrix":{"matrices","matrix","matrixes"},
"matron":{"matron","matrons"},
"matronymic":{"matronymic","matronymics"},
"matt":{"matt","matts"},
"matte":{"matte","mattes"},
"matter":{"matter","mattered","mattering","matters"},
"matteuccia":{"matteuccia","matteuccias"},
"matthew":{"matthew","matthews"},
"matthiola":{"matthiola","matthiolas"},
"matting":{"matting","mattings"},
"mattress":{"mattress","mattresses"},
"maturate":{"maturate","maturated","maturates","maturating"},
"maturation":{"maturation","maturations"},
"mature":{"mature","matured","maturer","maturest","maturing"},
"maturement":{"maturement","maturements"},
"matureness":{"matureness","maturenesses"},
"maturing":{"maturing","maturings"},
"maturity":{"maturities","maturity"},
"matza":{"matza","matzas"},
"matzah":{"matzah","matzahs"},
"matzo":{"matzo","matzos","matzot","matzoth"},
"matzoh":{"matzoh","matzohs"},
"mau-mau":{"mau-mau","mau-maus"},
"mauby":{"maubies","mauby"},
"maui":{"maui","mauis"},
"maul":{"maul","mauled","mauling","mauls"},
"mauler":{"mauler","maulers"},
"maulstick":{"maulstick","maulsticks"},
"maunder":{"maunder","maundered","maundering","maunders"},
"maundy":{"maundies","maundy"},
"maungy":{"maungier","maungiest","maungy"},
"mauritania":{"mauritania","mauritanias"},
"mauritanie":{"mauritanie","mauritanies"},
"mausoleum":{"mausolea","mausoleum","mausoleums"},
"maven":{"maven","mavens"},
"maverick":{"maverick","mavericks"},
"mavis":{"mavis","mavises"},
"maw":{"maw","maws"},
"mawkishness":{"mawkishness","mawkishnesses"},
"maxi":{"maxi","maxis"},
"maxilla":{"maxilla","maxillae","maxillas"},
"maxillary":{"maxillaries","maxillary"},
"maxim":{"maxim","maxims"},
"maximisation":{"maximisation","maximisations"},
"maximization":{"maximization","maximizations"},
"maximize":{"maximize","maximized","maximizing"},
"maximum":{"maxima","maximum","maximums"},
"maxostoma":{"maxostoma","maxostomas"},
"maxwell":{"maxwell","maxwells"},
"may":{"may","mays","might"},
"maya":{"maya","mayas"},
"mayaca":{"mayaca","mayacas"},
"mayacaceae":{"mayacaceae","mayacaceaes"},
"mayan":{"mayan","mayans"},
"mayapple":{"mayapple","mayapples"},
"mayeng":{"mayeng","mayengs"},
"mayetiola":{"mayetiola","mayetiolas"},
"mayfish":{"mayfish","mayfishes"},
"mayflower":{"mayflower","mayflowers"},
"mayfly":{"mayflies","mayfly"},
"mayhaw":{"mayhaw","mayhaws"},
"mayhem":{"mayhem","mayhems"},
"mayonnaise":{"mayonnaise","mayonnaises"},
"mayor":{"mayor","mayors"},
"mayoralty":{"mayoralties","mayoralty"},
"maypop":{"maypop","maypops"},
"mayweed":{"mayweed","mayweeds"},
"mazama":{"mazama","mazamas"},
"mazdaism":{"mazdaism","mazdaisms"},
"maze":{"maze","mazed","mazes","mazing"},
"mazurka":{"mazurka","mazurkas"},
"mazy":{"mazier","maziest","mazy"},
"mazzard":{"mazzard","mazzards"},
"mb":{"mb","mbs"},
"mba":{"mba","mbas"},
"mbabane":{"mbabane","mbabanes"},
"mc":{"mc","mcs"},
"mcg":{"mcg","mcgs"},
"mckinley":{"mckinley","mckinleys"},
"md":{"md","mds"},
"mdiv":{"mdiv","mdivs"},
"mdma":{"mdma","mdmas"},
"meadow":{"meadow","meadows"},
"meadowgrass":{"meadowgrass","meadowgrasses"},
"meadowlark":{"meadowlark","meadowlarks"},
"meagerness":{"meagerness","meagernesses"},
"meagreness":{"meagreness","meagrenesses"},
"meal":{"meal","meals"},
"mealberry":{"mealberries","mealberry"},
"mealy":{"mealier","mealiest","mealy"},
"mealybug":{"mealybug","mealybugs"},
"mean":{"mean","meaner","meanest","meaning","means","meant"},
"meander":{"meander","meandered","meandering","meanders"},
"meanie":{"meanie","meanies"},
"meaning":{"meaning","meanings"},
"meaninglessness":{"meaninglessness","meaninglessnesses"},
"meanness":{"meanness","meannesses"},
"means":{"means"},
"meany":{"meanies","meany"},
"mearstone":{"mearstone","mearstones"},
"measles":{"measles","measleses"},
"measly":{"measlier","measliest","measly"},
"measurability":{"measurabilities","measurability"},
"measure":{"measure","measured","measures","measuring"},
"measurement":{"measurement","measurements"},
"measuring":{"measuring","measurings"},
"meat":{"meat","meats"},
"meatloaf":{"meatloaf","meatloaves"},
"meatman":{"meatman","meatmen"},
"meatus":{"meatus","meatuses"},
"meaty":{"meatier","meatiest","meaty"},
"mebaral":{"mebaral","mebarals"},
"mechanic":{"mechanic","mechanics"},
"mechanics":{"mechanics","mechanicses"},
"mechanisation":{"mechanisation","mechanisations"},
"mechanism":{"mechanism","mechanisms"},
"mechanization":{"mechanization","mechanizations"},
"mechanize":{"mechanize","mechanized","mechanizes","mechanizing"},
"mecholyl":{"mecholyl","mecholyls"},
"meclizine":{"meclizine","meclizines"},
"meclofenamate":{"meclofenamate","meclofenamates"},
"meclomen":{"meclomen","meclomens"},
"meconopsis":{"meconopses","meconopsis"},
"med":{"med","meds"},
"medal":{"medal","medals"},
"medalist":{"medalist","medalists"},
"medallion":{"medallion","medallions"},
"medallist":{"medallist","medallists"},
"meddle":{"meddle","meddled","meddles","meddling"},
"meddlesomeness":{"meddlesomeness","meddlesomenesses"},
"meddling":{"meddling","meddlings"},
"medfly":{"medflies","medfly"},
"media":{"media","medias"},
"mediacy":{"mediacies","mediacy"},
"median":{"median","medians"},
"mediastinum":{"mediastina","mediastinum"},
"mediate":{"mediate","mediated","mediates","mediating"},
"mediateness":{"mediateness","mediatenesses"},
"mediation":{"mediation","mediations"},
"mediator":{"mediator","mediators"},
"medic":{"medic","medics"},
"medicago":{"medicago","medicagos"},
"medical":{"medical","medicals"},
"medicament":{"medicament","medicaments"},
"medicate":{"medicate","medicated","medicates","medicating"},
"medication":{"medication","medications"},
"medicine":{"medicine","medicined","medicines","medicining"},
"medick":{"medick","medicks"},
"medico":{"medico","medicoes","medicos"},
"mediety":{"medieties","mediety"},
"medinilla":{"medinilla","medinillas"},
"mediocrity":{"mediocrities","mediocrity"},
"meditate":{"meditate","meditated","meditates","meditating"},
"meditation":{"meditation","meditations"},
"meditativeness":{"meditativeness","meditativenesses"},
"meditator":{"meditator","meditators"},
"mediterranean":{"mediterranean","mediterraneans"},
"medium":{"media","medium","mediums"},
"medlar":{"medlar","medlars"},
"medley":{"medley","medleys"},
"medroxyprogesterone":{"medroxyprogesterone","medroxyprogesterones"},
"medulla":{"medulla","medullae","medullas"},
"medulla_oblongata":{"medullae_oblongatae","medulla_oblongata","medulla_oblongatas"},
"medusa":{"medusa","medusas"},
"medusan":{"medusan","medusans"},
"meek":{"meek","meeker","meekest"},
"meerestone":{"meerestone","meerestones"},
"meerkat":{"meerkat","meerkats"},
"meerschaum":{"meerschaum","meerschaums"},
"meet":{"meet","meeting","meets","met"},
"meeting":{"meeting","meetings"},
"meetinghouse":{"meetinghouse","meetinghouses"},
"mefoxin":{"mefoxin","mefoxins"},
"meg":{"meg","megs"},
"megabat":{"megabat","megabats"},
"megabyte":{"megabyte","megabytes"},
"megacardia":{"megacardia","megacardias"},
"megacephaly":{"megacephalies","megacephaly"},
"megachile":{"megachile","megachiles"},
"megachilidae":{"megachilidae","megachilidaes"},
"megachiroptera":{"megachiroptera","megachiropteras"},
"megacycle":{"megacycle","megacycles"},
"megaderma":{"megaderma","megadermas"},
"megadermatidae":{"megadermatidae","megadermatidaes"},
"megaflops":{"megaflops","megaflopses"},
"megahertz":{"megahertz","megahertzs"},
"megalith":{"megalith","megaliths"},
"megalobatrachus":{"megalobatrachus","megalobatrachuses"},
"megalocardia":{"megalocardia","megalocardias"},
"megalocephaly":{"megalocephalies","megalocephaly"},
"megalocyte":{"megalocyte","megalocytes"},
"megalonychidae":{"megalonychidae","megalonychidaes"},
"megaloptera":{"megaloptera","megalopteras"},
"megalosaur":{"megalosaur","megalosaurs"},
"megalosauridae":{"megalosauridae","megalosauridaes"},
"megalosaurus":{"megalosaurus","megalosauruses"},
"megalp":{"megalp","megalps"},
"megaphone":{"megaphone","megaphoned","megaphoning"},
"megapode":{"megapode","megapodes"},
"megapodiidae":{"megapodiidae","megapodiidaes"},
"megapodius":{"megapodius","megapodiuses"},
"megaptera":{"megaptera","megapteras"},
"megaron":{"megara","megaron"},
"megasporangium":{"megasporangia","megasporangium"},
"megathere":{"megathere","megatheres"},
"megatherian":{"megatherian","megatherians"},
"megatheriid":{"megatheriid","megatheriids"},
"megatheriidae":{"megatheriidae","megatheriidaes"},
"megatherium":{"megatherium","megatheriums"},
"megillah":{"megillah","megillahs","megilloth"},
"megilp":{"megilp","megilps"},
"megrim":{"megrim","megrims"},
"megrims":{"megrims","megrimses"},
"mei":{"mei","meis"},
"meiny":{"meinies","meiny"},
"meiosis":{"meioses","meiosis"},
"meistersinger":{"meistersinger","meistersingers"},
"mekong":{"mekong","mekongs"},
"melaena":{"melaena","melaenas"},
"melamine":{"melamine","melamines"},
"melampodium":{"melampodium","melampodiums"},
"melampsora":{"melampsora","melampsoras"},
"melampsoraceae":{"melampsoraceae","melampsoraceaes"},
"melancholiac":{"melancholiac","melancholiacs"},
"melancholic":{"melancholic","melancholics"},
"melancholy":{"melancholies","melancholy"},
"melanerpes":{"melanerpes","melanerpeses"},
"melange":{"melange","melanges"},
"melanism":{"melanism","melanisms"},
"melanitta":{"melanitta","melanittas"},
"melanogrammus":{"melanogrammus","melanogrammuses"},
"melanoma":{"melanoma","melanomas"},
"melanoplus":{"melanoplus","melanopluses"},
"melanosis":{"melanoses","melanosis"},
"melanotis":{"melanotis","melanotises"},
"melanthiaceae":{"melanthiaceae","melanthiaceaes"},
"melasma":{"melasma","melasmas"},
"melastoma":{"melastoma","melastomas"},
"melastomaceae":{"melastomaceae","melastomaceaes"},
"melastomataceae":{"melastomataceae","melastomataceaes"},
"meld":{"meld","melded","melding","melds"},
"meleagrididae":{"meleagrididae","meleagrididaes"},
"meleagris":{"meleagris","meleagrises"},
"melee":{"melee","melees"},
"melena":{"melena","melenas"},
"meles":{"meles","meleses"},
"melia":{"melia","melias"},
"meliaceae":{"meliaceae","meliaceaes"},
"melicocca":{"melicocca","melicoccas"},
"melicoccus":{"melicoccus","melicoccuses"},
"melilot":{"melilot","melilots"},
"melilotus":{"melilotus","melilotuses"},
"melinae":{"melinae","melinaes"},
"meliorate":{"meliorate","meliorated","meliorates","meliorating"},
"melioration":{"melioration","meliorations"},
"meliorist":{"meliorist","meliorists"},
"meliphagidae":{"meliphagidae","meliphagidaes"},
"melisma":{"melisma","melismas","melismata"},
"melissa":{"melissa","melissas"},
"mellaril":{"mellaril","mellarils"},
"mellivora":{"mellivora","mellivoras"},
"mellow":{"mellow","mellowed","mellower","mellowest","mellowing"},
"mellowing":{"mellowing","mellowings"},
"mellowness":{"mellowness","mellownesses"},
"melocactus":{"melocactus","melocactuses"},
"melodiousness":{"melodiousness","melodiousnesses"},
"melodize":{"melodize","melodized","melodizing"},
"melodrama":{"melodrama","melodramas"},
"melodramatize":{"melodramatize","melodramatized","melodramatizing"},
"melody":{"melodies","melody"},
"melogale":{"melogale","melogales"},
"meloid":{"meloid","meloids"},
"meloidae":{"meloidae","meloidaes"},
"melolontha":{"melolontha","melolonthas"},
"melolonthidae":{"melolonthidae","melolonthidaes"},
"melon":{"melon","melons"},
"melophagus":{"melophagus","melophaguses"},
"melopsittacus":{"melopsittacus","melopsittacuses"},
"melosa":{"melosa","melosas"},
"melospiza":{"melospiza","melospizas"},
"melphalan":{"melphalan","melphalans"},
"melt":{"melt","melted","melting","melts"},
"melting":{"melting","meltings"},
"melursus":{"melursus","melursuses"},
"melville":{"melville","melvilles"},
"member":{"member","members"},
"membership":{"membership","memberships"},
"membracidae":{"membracidae","membracidaes"},
"membrane":{"membrane","membranes"},
"membranophone":{"membranophone","membranophones"},
"memento":{"memento","mementoes","mementos"},
"memo":{"memo","memos"},
"memoir":{"memoir","memoirs"},
"memorability":{"memorabilities","memorability"},
"memoranda":{"memoranda","memorandas"},
"memorandum":{"memoranda","memorandum","memorandums"},
"memorial":{"memorial","memorials"},
"memorialisation":{"memorialisation","memorialisations"},
"memorialization":{"memorialization","memorializations"},
"memorialize":{"memorialize","memorialized","memorializes","memorializing"},
"memorize":{"memorize","memorized","memorizes","memorizing"},
"memory":{"memories","memory"},
"men":{"men","mens"},
"menace":{"menace","menaced","menaces","menacing"},
"menadione":{"menadione","menadiones"},
"menage":{"menage","menages"},
"menagerie":{"menagerie","menageries"},
"mend":{"mend","mended","mending","mends"},
"mendacity":{"mendacities","mendacity"},
"mendel":{"mendel","mendels"},
"mendeleev":{"mendeleev","mendeleevs"},
"mendelevium":{"mendelevium","mendeleviums"},
"mendeleyev":{"mendeleyev","mendeleyevs"},
"mendelianism":{"mendelianism","mendelianisms"},
"mendelism":{"mendelism","mendelisms"},
"mender":{"mender","menders"},
"mendicancy":{"mendicancies","mendicancy"},
"mendicant":{"mendicant","mendicants"},
"mending":{"mending","mendings"},
"menhaden":{"menhaden","menhadens"},
"menial":{"menial","menials"},
"meninges":{"meninges","meningeses"},
"meningitis":{"meningitides","meningitis"},
"meningococcus":{"meningococci","meningococcus"},
"meninx":{"meninges","meninx","meninxes"},
"menippe":{"menippe","menippes"},
"meniscium":{"meniscium","menisciums"},
"meniscus":{"menisci","meniscus","meniscuses"},
"menispermaceae":{"menispermaceae","menispermaceaes"},
"menispermum":{"menispermum","menispermums"},
"menology":{"menologies","menology"},
"menominee":{"menominee","menominees"},
"menomini":{"menomini","menominis"},
"menopause":{"menopause","menopauses"},
"menopon":{"menopon","menopons"},
"menorrhagia":{"menorrhagia","menorrhagias"},
"menorrhea":{"menorrhea","menorrheas"},
"menotyphla":{"menotyphla","menotyphlas"},
"menses":{"menses","menseses"},
"menshevik":{"menshevik","mensheviki","mensheviks"},
"menstruate":{"menstruate","menstruated","menstruates","menstruating"},
"menstruation":{"menstruation","menstruations"},
"menstruum":{"menstrua","menstruum","menstruums"},
"mensuration":{"mensuration","mensurations"},
"mentality":{"mentalities","mentality"},
"mentation":{"mentation","mentations"},
"mentha":{"mentha","menthas"},
"menticirrhus":{"menticirrhus","menticirrhuses"},
"mention":{"mention","mentioned","mentioning","mentions"},
"mentor":{"mentor","mentors"},
"mentum":{"mentum","mentums"},
"mentzelia":{"mentzelia","mentzelias"},
"menu":{"menu","menus"},
"menura":{"menura","menuras"},
"menurae":{"menurae","menuraes"},
"menuridae":{"menuridae","menuridaes"},
"menyanthaceae":{"menyanthaceae","menyanthaceaes"},
"menyanthes":{"menyanthes","menyantheses"},
"menziesia":{"menziesia","menziesias"},
"meow":{"meow","meowed","meowing","meows"},
"mepacrine":{"mepacrine","mepacrines"},
"meperidine":{"meperidine","meperidines"},
"mephenytoin":{"mephenytoin","mephenytoins"},
"mephitinae":{"mephitinae","mephitinaes"},
"mephitis":{"mephitis","mephitises"},
"mephobarbital":{"mephobarbital","mephobarbitals"},
"meprin":{"meprin","meprins"},
"meprobamate":{"meprobamate","meprobamates"},
"meq":{"meq","meqs"},
"merbromine":{"merbromine","merbromines"},
"mercantilism":{"mercantilism","mercantilisms"},
"mercaptopurine":{"mercaptopurine","mercaptopurines"},
"mercenaria":{"mercenaria","mercenarias"},
"mercenary":{"mercenaries","mercenary"},
"mercerize":{"mercerize","mercerized","mercerizing"},
"mercery":{"merceries","mercery"},
"merchandise":{"merchandise","merchandised","merchandises","merchandising"},
"merchandiser":{"merchandiser","merchandisers"},
"merchandising":{"merchandising","merchandisings"},
"merchant":{"merchant","merchants"},
"merchantman":{"merchantman","merchantmen"},
"mercifulness":{"mercifulness","mercifulnesses"},
"mercilessness":{"mercilessness","mercilessnesses"},
"mercurate":{"mercurate","mercurated","mercurating"},
"mercurialis":{"mercurialis","mercurialises"},
"mercurochrome":{"mercurochrome","mercurochromes"},
"mercury":{"mercuries","mercury"},
"mercy":{"mercies","mercy"},
"mere":{"mere","meres"},
"merestone":{"merestone","merestones"},
"meretriciousness":{"meretriciousness","meretriciousnesses"},
"merganser":{"merganser","mergansers"},
"merge":{"merge","merged","merges","merging"},
"merger":{"merger","mergers"},
"merginae":{"merginae","merginaes"},
"merging":{"merging","mergings"},
"mergus":{"mergus","merguses"},
"meridian":{"meridian","meridians"},
"merino":{"merino","merinos"},
"meriones":{"meriones","merioneses"},
"merit":{"merit","merited","meriting","merits"},
"meritocracy":{"meritocracies","meritocracy"},
"meritoriousness":{"meritoriousness","meritoriousnesses"},
"merl":{"merl","merls"},
"merlangus":{"merlangus","merlanguses"},
"merle":{"merle","merles"},
"merlin":{"merlin","merlins"},
"merluccius":{"merluccius","merlucciuses"},
"mermaid":{"mermaid","mermaids"},
"merman":{"merman","mermen"},
"merodach":{"merodach","merodaches"},
"meronym":{"meronym","meronyms"},
"meronymy":{"meronymies","meronymy"},
"meropidae":{"meropidae","meropidaes"},
"merops":{"merops","meropses"},
"merostomata":{"merostomata","merostomatas"},
"merriment":{"merriment","merriments"},
"merriness":{"merriness","merrinesses"},
"merry":{"merrier","merriest","merry"},
"merry-go-round":{"merry-go-round","merry-go-rounds"},
"merrymaker":{"merrymaker","merrymakers"},
"merrymaking":{"merrymaking","merrymakings"},
"mertensia":{"mertensia","mertensias"},
"merthiolate":{"merthiolate","merthiolates"},
"meryta":{"meryta","merytas"},
"mesa":{"mesa","mesas"},
"mesantoin":{"mesantoin","mesantoins"},
"mescal":{"mescal","mescals"},
"mescaline":{"mescaline","mescalines"},
"mesembryanthemum":{"mesembryanthemum","mesembryanthemums"},
"mesencephalon":{"mesencephala","mesencephalon","mesencephalons"},
"mesenteron":{"mesentera","mesenteron","mesentertera"},
"mesentery":{"mesenteries","mesentery"},
"mesh":{"mesh","meshed","meshes","meshing"},
"meshed":{"meshed","mesheds"},
"meshing":{"meshing","meshings"},
"meshwork":{"meshwork","meshworks"},
"meshy":{"meshier","meshiest","meshy"},
"mesmerism":{"mesmerism","mesmerisms"},
"mesmerist":{"mesmerist","mesmerists"},
"mesmerize":{"mesmerize","mesmerized","mesmerizes","mesmerizing"},
"mesnalty":{"mesnalties","mesnalty"},
"mesoblast":{"mesoblast","mesoblasts"},
"mesocricetus":{"mesocricetus","mesocricetuses"},
"mesoderm":{"mesoderm","mesoderms"},
"mesomorphy":{"mesomorphies","mesomorphy"},
"meson":{"meson","mesons"},
"mesonephros":{"mesonephroi","mesonephros"},
"mesophyte":{"mesophyte","mesophytes"},
"mesothelium":{"mesothelia","mesothelium"},
"mesothorax":{"mesothoraces","mesothorax","mesothoraxes"},
"mesotron":{"mesotron","mesotrons"},
"mesozoic":{"mesozoic","mesozoics"},
"mespilus":{"mespilus","mespiluses"},
"mesquit":{"mesquit","mesquits"},
"mesquite":{"mesquite","mesquites"},
"mess":{"mess","messed","messes","messing"},
"mess-up":{"mess-up","mess-ups"},
"message":{"message","messages"},
"messenger":{"messenger","messengers"},
"messiah":{"messiah","messiahs"},
"messiness":{"messiness","messinesses"},
"messy":{"messier","messiest","messy"},
"mestiza":{"mestiza","mestizas"},
"mestizo":{"mestizo","mestizoes","mestizos"},
"mesua":{"mesua","mesuas"},
"metabolism":{"metabolism","metabolisms"},
"metabolize":{"metabolize","metabolized","metabolizing"},
"metacarpal":{"metacarpal","metacarpals"},
"metacarpus":{"metacarpi","metacarpus"},
"metagalaxy":{"metagalaxies","metagalaxy"},
"metagenesis":{"metageneses","metagenesis"},
"metal":{"metal","metaled","metaling","metalled","metalling","metals"},
"metalize":{"metalize","metalized","metalizing"},
"metallurgist":{"metallurgist","metallurgists"},
"metalwork":{"metalwork","metalworks"},
"metalworker":{"metalworker","metalworkers"},
"metalworking":{"metalworking","metalworkings"},
"metalworks":{"metalworks","metalworkses"},
"metamere":{"metamere","metameres"},
"metamorphose":{"metamorphose","metamorphosed","metamorphoses","metamorphosing"},
"metamorphosis":{"metamorphoses","metamorphosis"},
"metanephros":{"metanephroi","metanephros"},
"metaproterenol":{"metaproterenol","metaproterenols"},
"metasequoia":{"metasequoia","metasequoias"},
"metastasis":{"metastases","metastasis"},
"metastasize":{"metastasize","metastasized","metastasizing"},
"metatarsus":{"metatarsi","metatarsus"},
"metatheria":{"metatheria","metatherias"},
"metathesis":{"metatheses","metathesis"},
"metathesize":{"metathesize","metathesized","metathesizing"},
"metathorax":{"metathoraces","metathorax","metathoraxes"},
"metazoa":{"metazoa","metazoas"},
"mete":{"mete","meted","meting"},
"metempsychosis":{"metempsychoses","metempsychosis"},
"metencephalon":{"metencephala","metencephalon","metencephalons"},
"meteor":{"meteor","meteors"},
"meteorite":{"meteorite","meteorites"},
"meteorology":{"meteorologies","meteorology"},
"meter":{"meter","metered","metering","meters"},
"meth":{"meth","meths"},
"methacholine":{"methacholine","methacholines"},
"methadon":{"methadon","methadons"},
"methadone":{"methadone","methadones"},
"methamphetamine":{"methamphetamine","methamphetamines"},
"methanal":{"methanal","methanals"},
"methanol":{"methanol","methanols"},
"methaqualone":{"methaqualone","methaqualones"},
"metharbital":{"metharbital","metharbitals"},
"methedrine":{"methedrine","methedrines"},
"methenamine":{"methenamine","methenamines"},
"methinks":{"methinks","methought"},
"methocarbamol":{"methocarbamol","methocarbamols"},
"method":{"method","methods"},
"methodicalness":{"methodicalness","methodicalnesses"},
"methodists":{"methodists","methodistses"},
"methodize":{"methodize","methodized","methodizing"},
"methodology":{"methodologies","methodology"},
"methyl":{"methyl","methyls"},
"methylate":{"methylate","methylated","methylating"},
"methylbenzene":{"methylbenzene","methylbenzenes"},
"methyldopa":{"methyldopa","methyldopas"},
"methylenedioxymethamphetamine":{"methylenedioxymethamphetamine","methylenedioxymethamphetamines"},
"methylphenidate":{"methylphenidate","methylphenidates"},
"meticulosity":{"meticulosities","meticulosity"},
"meticulousness":{"meticulousness","meticulousnesses"},
"metier":{"metier","metiers"},
"metif":{"metif","metifs"},
"metonymy":{"metonymies","metonymy"},
"metoprolol":{"metoprolol","metoprolols"},
"metrazol":{"metrazol","metrazols"},
"metre":{"metre","metres"},
"metricate":{"metricate","metricated","metricating"},
"metrication":{"metrication","metrications"},
"metricize":{"metricize","metricized","metricizing"},
"metrification":{"metrification","metrifications"},
"metrify":{"metrified","metrifies","metrify","metrifying"},
"metritis":{"metritis","metritises"},
"metro":{"metro","metros"},
"metrology":{"metrologies","metrology"},
"metronymic":{"metronymic","metronymics"},
"metropolis":{"metropolis","metropolises"},
"metropolitan":{"metropolitan","metropolitans"},
"metroxylon":{"metroxylon","metroxylons"},
"mettle":{"mettle","mettles"},
"metycaine":{"metycaine","metycaines"},
"meuse":{"meuse","meuses"},
"meuse-argonne":{"meuse-argonne","meuse-argonnes"},
"mevacor":{"mevacor","mevacors"},
"mew":{"mew","mewed","mewing","mews"},
"mewl":{"mewl","mewled","mewling","mewls"},
"mexiletine":{"mexiletine","mexiletines"},
"mexitil":{"mexitil","mexitils"},
"mezcal":{"mezcal","mezcals"},
"mezereon":{"mezereon","mezereons"},
"mezuzah":{"mezuzah","mezuzahs","mezuzoth"},
"mezzanine":{"mezzanine","mezzanines"},
"mezzo":{"mezzo","mezzos"},
"mezzo-relievo":{"mezzo-relievo","mezzo-relievos"},
"mezzo-rilievo":{"mezzo-rilievo","mezzo-rilievos"},
"mezzo-soprano":{"mezzo-soprani","mezzo-soprano","mezzo-sopranos"},
"mezzotint":{"mezzotint","mezzotinted","mezzotinting"},
"mf":{"mf","mfs"},
"mfa":{"mfa","mfas"},
"mflops":{"mflops","mflopses"},
"mg":{"mg","mgs"},
"mho":{"mho","mhos"},
"mhz":{"mhz","mhzs"},
"mi":{"mi","mis"},
"miaou":{"miaou","miaous"},
"miaow":{"miaow","miaows"},
"miasma":{"miasma","miasmas","miasmata"},
"mica":{"mica","micas"},
"michaelmas":{"michaelmas","michaelmases"},
"michigan":{"michigan","michigans"},
"michigander":{"michigander","michiganders"},
"mick":{"mick","micks"},
"mickey":{"meckeys","mickey","mickeys"},
"mickle":{"mickle","mickles"},
"micmac":{"micmac","micmacs"},
"microanalysis":{"microanalyses","microanalysis"},
"microbar":{"microbar","microbars"},
"microbat":{"microbat","microbats"},
"microbe":{"microbe","microbes"},
"microcentrum":{"microcentrum","microcentrums"},
"microcephalus":{"microcephalus","microcephaluses"},
"microcephaly":{"microcephalies","microcephaly"},
"microchip":{"microchip","microchips"},
"microchiroptera":{"microchiroptera","microchiropteras"},
"microcircuit":{"microcircuit","microcircuits"},
"micrococcaceae":{"micrococcaceae","micrococcaceaes"},
"micrococcus":{"micrococci","micrococcus","micrococcuses"},
"microcomputer":{"microcomputer","microcomputers"},
"microcopy":{"microcopies","microcopy"},
"microdesmidae":{"microdesmidae","microdesmidaes"},
"microdipodops":{"microdipodops","microdipodopses"},
"microfauna":{"microfauna","microfaunae","microfaunas"},
"microfiche":{"microfiche","microfiches"},
"microfilm":{"microfilm","microfilmed","microfilming"},
"microflora":{"microflora","microflorae","microfloras"},
"microgram":{"microgram","micrograms"},
"microgramma":{"microgramma","microgrammas"},
"microgramma-piloselloides":{"microgramma-piloselloides","microgramma-piloselloideses"},
"microhylidae":{"microhylidae","microhylidaes"},
"micromeria":{"micromeria","micromerias"},
"micrometer":{"micrometer","micrometers"},
"micrometre":{"micrometre","micrometres"},
"micromicron":{"micromicron","micromicrons"},
"micromillimeter":{"micromillimeter","micromillimeters"},
"micromillimetre":{"micromillimetre","micromillimetres"},
"micromini":{"micromini","microminis"},
"microminiaturize":{"microminiaturize","microminiaturized","microminiaturizing"},
"micromyx":{"micromyx","micromyxes"},
"micron":{"micra","micron","microns"},
"micronase":{"micronase","micronases"},
"micronucleus":{"micronuclei","micronucleus","micronucleuses"},
"microphone":{"microphone","microphones"},
"micropogonias":{"micropogonias","micropogoniases"},
"micropterus":{"micropterus","micropteruses"},
"microscope":{"microscope","microscopes"},
"microseism":{"microseism","microseisms"},
"microsorium":{"microsorium","microsoriums"},
"microsporangium":{"microsoporangia","microsporangia","microsporangium"},
"microsporum":{"microsporum","microsporums"},
"microstomus":{"microstomus","microstomuses"},
"microstrobos":{"microstrobos","microstroboses"},
"microtomy":{"microtomies","microtomy"},
"microtus":{"microtus","microtuses"},
"microwave":{"microwave","microwaves"},
"micruroides":{"micruroides","micruroideses"},
"micrurus":{"micrurus","micruruses"},
"micteria":{"micteria","micterias"},
"micturate":{"micturate","micturated","micturates","micturating"},
"micturition":{"micturition","micturitions"},
"mid-eighties":{"mid-eighties","mid-eightieses"},
"mid-fifties":{"mid-fifties","mid-fiftieses"},
"mid-forties":{"mid-forties","mid-fortieses"},
"mid-nineties":{"mid-nineties","mid-ninetieses"},
"mid-seventies":{"mid-seventies","mid-seventieses"},
"mid-sixties":{"mid-sixties","mid-sixtieses"},
"mid-thirties":{"mid-thirties","mid-thirtieses"},
"mid-twenties":{"mid-twenties","mid-twentieses"},
"midbrain":{"midbrain","midbrains"},
"midday":{"midday","middays"},
"midden":{"midden","middens"},
"middle":{"middle","middled","middles","middling"},
"middlebreaker":{"middlebreaker","middlebreakers"},
"middleclass":{"middleclass","middleclasses"},
"middleman":{"middleman","middlemen"},
"middy":{"middies","middy"},
"midget":{"midget","midgets"},
"midi":{"midi","midis"},
"midinette":{"midinette","midinettes"},
"midiron":{"midiron","midirons"},
"midland":{"midland","midlands"},
"midline":{"midline","midlines"},
"midplane":{"midplane","midplanes"},
"midpoint":{"midpoint","midpoints"},
"midrash":{"midrash","midrashim"},
"midriff":{"midriff","midriffs"},
"midsection":{"midsection","midsections"},
"midshipman":{"midshipman","midshipmen"},
"midst":{"midst","midsts"},
"midsummer":{"midsummer","midsummers"},
"midsummer-men":{"midsummer-men","midsummer-mens"},
"midterm":{"midterm","midterms"},
"midwatch":{"midwatch","midwatches"},
"midway":{"midway","midways"},
"midwest":{"midwest","midwests"},
"midwife":{"midwife","midwives"},
"midwifery":{"midwiferies","midwifery"},
"mien":{"mien","miens"},
"mierkat":{"mierkat","mierkats"},
"miff":{"miff","miffed","miffing","miffs"},
"miffy":{"miffier","miffiest","miffy"},
"might":{"might","mights"},
"mightiness":{"mightiness","mightinesses"},
"mighty":{"mightier","mightiest","mighty"},
"mignonette":{"mignonette","mignonettes"},
"migraine":{"migraine","migraines"},
"migrate":{"migrate","migrated","migrating"},
"migration":{"migration","migrations"},
"mikado":{"mikado","mikados"},
"mikania":{"mikania","mikanias"},
"mike":{"mike","miked","mikes","miking"},
"mil":{"mil","mils"},
"milady":{"miladies","milady"},
"milage":{"milage","milages"},
"milan":{"milan","milans"},
"milano":{"milano","milanos"},
"milcher":{"milcher","milchers"},
"mild":{"mild","milder","mildest"},
"mildew":{"mildew","mildewed","mildewing","mildews"},
"mildness":{"mildness","mildnesses"},
"mile":{"mile","miles"},
"mileage":{"mileage","mileages"},
"mileometer":{"mileometer","mileometers"},
"milepost":{"milepost","mileposts"},
"milestone":{"milestone","milestones"},
"milfoil":{"milfoil","milfoils"},
"milieu":{"milieu","milieus","milieux"},
"militage_against":{"militage_against","militating_against"},
"militance":{"militance","militances"},
"militancy":{"militancies","militancy"},
"militant":{"militant","militants"},
"militarisation":{"militarisation","militarisations"},
"militarist":{"militarist","militarists"},
"militarization":{"militarization","militarizations"},
"militarize":{"militarize","militarized","militarizing"},
"military":{"militaries","military"},
"militate":{"militate","militated","militating"},
"militate_against":{"militated_against","militates_against","militate_against"},
"militia":{"militia","militias"},
"militiaman":{"militiaman","militiamen"},
"milium":{"milia","milium","miliums"},
"milk":{"milk","milked","milking","milks"},
"milkcap":{"milkcap","milkcaps"},
"milker":{"milker","milkers"},
"milkfish":{"milkfish","milkfishes"},
"milkmaid":{"milkmaid","milkmaids"},
"milkman":{"milkman","milkmen"},
"milkshake":{"milkshake","milkshakes"},
"milksop":{"milksop","milksops"},
"milkvetch":{"milkvetch","milkvetches"},
"milkweed":{"milkweed","milkweeds"},
"milky":{"milkier","milkiest","milky"},
"mill":{"mill","milled","milling","mills"},
"mill-hand":{"mill-hand","mill-hands"},
"millenarian":{"millenarian","millenarians"},
"millenarist":{"millenarist","millenarists"},
"millenary":{"millenaries","millenary"},
"millennium":{"millennia","millennium","millenniums"},
"millepede":{"millepede","millepedes"},
"miller":{"miller","millers"},
"millet":{"millet","millets"},
"milliampere":{"milliampere","milliamperes"},
"millicurie":{"millicurie","millicuries"},
"milliequivalent":{"milliequivalent","milliequivalents"},
"milligram":{"milligram","milligrams"},
"milliliter":{"milliliter","milliliters"},
"millilitre":{"millilitre","millilitres"},
"millimeter":{"millimeter","millimeters"},
"millimetre":{"millimetre","millimetres"},
"millimicron":{"millimicra","millimicron","millimicrons"},
"milliner":{"milliner","milliners"},
"millinery":{"millineries","millinery"},
"million":{"million","millions"},
"millionaire":{"millionaire","millionaires"},
"millions":{"millions","millionses"},
"millionth":{"millionth","millionths"},
"milliped":{"milliped","millipeds"},
"millipede":{"millipede","millipedes"},
"millisecond":{"millisecond","milliseconds"},
"millivolt":{"millivolt","millivolts"},
"millrace":{"millrace","millraces"},
"millrun":{"millrun","millruns"},
"millstone":{"millstone","millstones"},
"milo":{"milo","milos"},
"milometer":{"milometer","milometers"},
"milquetoast":{"milquetoast","milquetoasts"},
"milt":{"milt","milts"},
"miltomate":{"miltomate","miltomates"},
"miltonia":{"miltonia","miltonias"},
"miltown":{"miltown","miltowns"},
"milvus":{"milvus","milvuses"},
"mime":{"mime","mimed","mimes","miming"},
"mimeo":{"mimeo","mimeos"},
"mimeograph":{"mimeograph","mimeographed","mimeographing","mimeographs"},
"mimer":{"mimer","mimers"},
"mimic":{"mimic","mimicked","mimicking","mimics"},
"mimicker":{"mimicker","mimickers"},
"mimicry":{"mimicries","mimicry"},
"mimidae":{"mimidae","mimidaes"},
"mimosa":{"mimosa","mimosas"},
"mimosaceae":{"mimosaceae","mimosaceaes"},
"mimosoideae":{"mimosoideae","mimosoideaes"},
"mimus":{"mimus","mimuses"},
"min":{"min","mins"},
"mina":{"mina","minas"},
"minah":{"minah","minahs"},
"mince":{"mince","minced","minces","mincing"},
"mincer":{"mincer","mincers"},
"mind":{"mind","minded","minding","minds"},
"minden":{"minden","mindens"},
"minder":{"minder","minders"},
"mindfulness":{"mindfulness","mindfulnesses"},
"mindlessness":{"mindlessness","mindlessnesses"},
"mine":{"mine","mined","mines","mining"},
"minelaying":{"minelaying","minelayings"},
"miner":{"miner","miners"},
"mineral":{"mineral","minerals"},
"mineralize":{"mineralize","mineralized","mineralizing"},
"minestrone":{"minestrone","minestrones"},
"mineworker":{"mineworker","mineworkers"},
"minginess":{"minginess","minginesses"},
"mingle":{"mingle","mingled","mingles","mingling"},
"mingle-mangle":{"mingle-mangle","mingle-mangles"},
"mingy":{"mingier","mingiest","mingy"},
"mini":{"mini","minis"},
"miniature":{"miniature","miniatured","miniatures","miniaturing"},
"miniaturisation":{"miniaturisation","miniaturisations"},
"miniaturization":{"miniaturization","miniaturizations"},
"miniaturize":{"miniaturize","miniaturized","miniaturizes","miniaturizing"},
"minibar":{"minibar","minibars"},
"minibike":{"minibike","minibikes"},
"minify":{"minified","minifies","minify","minifying"},
"minim":{"minim","minims"},
"minimisation":{"minimisation","minimisations"},
"minimization":{"minimization","minimizations"},
"minimize":{"minimize","minimized","minimizes","minimizing"},
"minimizer":{"minimizer","minimizers"},
"minimum":{"minima","minimum","minimums"},
"mining":{"mining","minings"},
"minion":{"minion","minions"},
"miniskirt":{"miniskirt","miniskirts"},
"minister":{"minister","ministered","ministering","ministers"},
"ministerium":{"ministeria","ministerium"},
"ministration":{"ministration","ministrations"},
"ministry":{"ministries","ministry"},
"minium":{"minium","miniums"},
"mink":{"mink","minks"},
"minnesota":{"minnesota","minnesotas"},
"minniebush":{"minniebush","minniebushes"},
"minnow":{"minnow","minnows"},
"minocin":{"minocin","minocins"},
"minocycline":{"minocycline","minocyclines"},
"minor":{"minor","minored","minoring","minors"},
"minority":{"minorities","minority"},
"minors":{"minors","minorses"},
"minoxidil":{"minoxidil","minoxidils"},
"minsk":{"minsk","minsks"},
"minster":{"minster","minsters"},
"minstrel":{"minstrel","minstrels"},
"minstrelsy":{"minstrelsies","minstrelsy"},
"mint":{"mint","minted","minting","mints"},
"mintage":{"mintage","mintages"},
"minter":{"minter","minters"},
"minty":{"mintier","mintiest","minty"},
"minuartia":{"minuartia","minuartias"},
"minus":{"minus","minuses"},
"minute":{"minute","minuted","minutes","minuting"},
"minuteman":{"minuteman","minutemen"},
"minuteness":{"minuteness","minutenesses"},
"minutes":{"minutes","minuteses"},
"minutia":{"minutia","minutiae"},
"minx":{"minx","minxes"},
"minyan":{"minyan","minyanim","minyans"},
"miocene":{"miocene","miocenes"},
"miosis":{"mioses","miosis"},
"mips":{"mips","mipses"},
"mir":{"mir","miri"},
"mirabilis":{"mirabilis","mirabilises"},
"miracidium":{"miracidiia","miracidium"},
"miracle":{"miracle","miracles"},
"miracle-worship":{"miracle-worship","miracle-worships"},
"mirasol":{"mirasol","mirasols"},
"mire":{"mire","mired","mires","miring"},
"miri":{"miri","miris"},
"mirid":{"mirid","mirids"},
"miridae":{"miridae","miridaes"},
"mirish":{"mirish","mirishes"},
"mirky":{"mirkier","mirkiest","mirky"},
"miro":{"miro","miros"},
"mirounga":{"mirounga","miroungas"},
"mirror":{"mirror","mirrored","mirroring","mirrors"},
"mirth":{"mirth","mirths"},
"mirthfulness":{"mirthfulness","mirthfulnesses"},
"misadventure":{"misadventure","misadventures"},
"misally":{"misallied","misally","misallying"},
"misapplication":{"misapplication","misapplications"},
"misapply":{"misapplied","misapplies","misapply","misapplying"},
"misapprehend":{"misapprehend","misapprehended","misapprehending","misapprehends"},
"misapprehension":{"misapprehension","misapprehensions"},
"misappropriate":{"misappopriated","misappropriate","misappropriated","misappropriating"},
"misappropriation":{"misappropriation","misappropriations"},
"misbecome":{"misbecame","misbecome","misbecomes","misbecoming"},
"misbehave":{"misbehave","misbehaved","misbehaves","misbehaving"},
"misbehavior":{"misbehavior","misbehaviors"},
"misbehaviour":{"misbehaviour","misbehaviours"},
"misbeliever":{"misbeliever","misbelievers"},
"miscalculation":{"miscalculation","miscalculations"},
"miscall":{"miscall","miscalled","miscalling","miscalls"},
"miscarriage":{"miscarriage","miscarriages"},
"miscarry":{"miscarried","miscarries","miscarry","miscarrying"},
"miscast":{"miscast","miscasting","miscasts"},
"miscegenation":{"miscegenation","miscegenations"},
"miscellanea":{"miscellanea","miscellaneas"},
"miscellany":{"miscellanies","miscellany"},
"mischance":{"mischance","mischances"},
"mischief":{"mischief","mischiefs","mischieves"},
"mischief-maker":{"mischief-maker","mischief-makers"},
"mischief-making":{"mischief-making","mischief-makings"},
"mischievousness":{"mischievousness","mischievousnesses"},
"misconceive":{"misconceive","misconceived","misconceives","misconceiving"},
"misconduct":{"misconduct","misconducted","misconducting","misconducts"},
"misconstrual":{"misconstrual","misconstruals"},
"misconstruction":{"misconstruction","misconstructions"},
"misconstrue":{"misconstrue","misconstrued","misconstrues","misconstruing"},
"miscount":{"miscount","miscounted","miscounting"},
"miscreant":{"miscreant","miscreants"},
"miscreate":{"miscreate","miscreated","miscreating"},
"miscreation":{"miscreation","miscreations"},
"miscue":{"miscue","miscued","miscues","miscuing"},
"misdating":{"misdating","misdatings"},
"misdeal":{"misdeal","misdealing","misdeals","misdealt"},
"misdeed":{"misdeed","misdeeds"},
"misdemeanor":{"misdemeanor","misdemeanors"},
"misdemeanour":{"misdemeanour","misdemeanours"},
"misdirect":{"misdirect","misdirected","misdirecting","misdirects"},
"misdo":{"misdid","misdo","misdoing","misdone"},
"misdoing":{"misdoing","misdoings"},
"misdoubt":{"misdoubt","misdoubted","misdoubting"},
"misemploy":{"misemploy","misemployed","misemploying"},
"miser":{"miser","misers"},
"misery":{"miseries","misery"},
"misestimation":{"misestimation","misestimations"},
"misfire":{"misfire","misfired","misfires","misfiring"},
"misfit":{"misfit","misfits","misfitted","misfitting"},
"misfortune":{"misfortune","misfortunes"},
"misgive":{"misgave","misgive","misgiven","misgives","misgiving"},
"misgiving":{"misgiving","misgivings"},
"misgovernment":{"misgovernment","misgovernments"},
"misguide":{"misguide","misguided","misguides","misguiding"},
"mishandle":{"mishandle","mishandled","mishandles","mishandling"},
"mishap":{"mishap","mishaps"},
"mishear":{"mishear","misheard","mishearing","mishears"},
"mishit":{"mishit","mishits","mishitting"},
"mishna":{"mishna","mishnayoth"},
"mishnah":{"mishnah","mishnayoth"},
"misinform":{"misinform","misinformed","misinforming","misinforms"},
"misinterpret":{"misinterpret","misinterpreted","misinterpreting","misinterprets"},
"misinterpretation":{"misinterpretation","misinterpretations"},
"misjudge":{"misjuded","misjudge","misjudged","misjudging"},
"misknow":{"misknew","misknow","misknowing","misknown"},
"mislay":{"mislaid","mislay","mislaying","mislays"},
"mislead":{"mislead","misleading","misleads","misled"},
"mislike":{"mislike","misliked","misliking"},
"mismanage":{"mismanage","mismanaged","mismanages","mismanaging"},
"mismatch":{"mismatch","mismatched","mismatching"},
"misogamist":{"misogamist","misogamists"},
"misogynism":{"misogynism","misogynisms"},
"misogynist":{"misogynist","misogynists"},
"misogyny":{"misogynies","misogyny"},
"misorient":{"misorient","misoriented","misorienting"},
"mispickel":{"mispickel","mispickels"},
"misplace":{"misplace","misplaced","misplaces","misplacing"},
"misplacement":{"misplacement","misplacements"},
"misplay":{"misplay","misplayed","misplaying","misplays"},
"misplead":{"misplead","mispleaded","mispleading","mispleads","mispled"},
"misprint":{"misprint","misprinted","misprinting","misprints"},
"misprize":{"misprize","misprized","misprizing"},
"mispronounce":{"mispronounce","mispronounced","mispronouncing"},
"misquote":{"misquote","misquoted","misquoting"},
"misread":{"misread","misreading","misreads"},
"misreckoning":{"misreckoning","misreckonings"},
"misremember":{"misremember","misremembered","misremembering"},
"misreport":{"misreport","misreported","misreporting"},
"misrepresent":{"misrepresent","misrepresented","misrepresenting","misrepresents"},
"misrepresentation":{"misrepresentation","misrepresentations"},
"misrule":{"misrule","misruled","misrules","misruling"},
"miss":{"miss","missed","misses","missing"},
"missay":{"missaid","missay","missaying"},
"missend":{"missend","missending","missent"},
"missfire":{"missfire","missfires"},
"misshape":{"misshape","misshaped","misshapen","misshaping"},
"misshapenness":{"misshapenness","misshapennesses"},
"missile":{"missile","missiles"},
"missileman":{"missileman","missilemen"},
"mission":{"mission","missioned","missioning","missions"},
"missionary":{"missionaries","missionary"},
"missioner":{"missioner","missioners"},
"missionize":{"missionize","missionized","missionizing"},
"missis":{"misses","missis"},
"mississippi":{"mississippi","mississippis"},
"mississippian":{"mississippian","mississippians"},
"missive":{"missive","missives"},
"missouri":{"missouri","missouris"},
"misspell":{"misspell","misspelled","misspelling","misspells","misspelt"},
"misspend":{"misspend","misspending","misspends","misspent"},
"misstate":{"misstate","misstated","misstating"},
"misstep":{"misstep","missteps"},
"missus":{"missus","missuses"},
"missy":{"missies","missy"},
"mist":{"mist","misted","misting","mists"},
"mistake":{"mistake","mistaken","mistakes","mistaking","mistook"},
"mistaking":{"mistaking","mistakings"},
"mister":{"mister","mistered","mistering","misters"},
"mistflower":{"mistflower","mistflowers"},
"misthink":{"misthink","misthinking","misthought"},
"mistiming":{"mistiming","mistimings"},
"mistiness":{"mistiness","mistinesses"},
"mistletoe":{"mistletoe","mistletoes"},
"mistreat":{"mistreat","mistreated","mistreating","mistreats"},
"mistress":{"mistress","mistresses"},
"mistrust":{"mistrust","mistrusted","mistrusting","mistrusts"},
"misty":{"mistier","mistiest","misty"},
"misunderstand":{"misunderstand","misunderstanding","misunderstands","misunderstood"},
"misunderstanding":{"misunderstanding","misunderstandings"},
"misuse":{"misuse","misused","misuses","misusing"},
"misword":{"misword","misworded","miswording"},
"mitchella":{"mitchella","mitchellas"},
"mite":{"mite","mites"},
"mitella":{"mitella","mitellas"},
"miter":{"miter","mitered","mitering","miters"},
"miterwort":{"miterwort","miterworts"},
"mithan":{"mithan","mithans"},
"mithra":{"mithra","mithras"},
"mithracin":{"mithracin","mithracins"},
"mithraicism":{"mithraicism","mithraicisms"},
"mithraism":{"mithraism","mithraisms"},
"mithramycin":{"mithramycin","mithramycins"},
"mithras":{"mithras","mithrases"},
"mithridates":{"mithridates","mithridateses"},
"mitigate":{"mitigate","mitigated","mitigates","mitigating"},
"mitigation":{"mitigation","mitigations"},
"mitigator":{"mitigator","mitigators"},
"mitochondrion":{"mitochondria","mitochondrion","mitochondrions"},
"mitre":{"mitre","mitres"},
"mitrewort":{"mitrewort","mitreworts"},
"mitt":{"mitt","mitts"},
"mitten":{"mitten","mittens"},
"mittens":{"mittens","mittenses"},
"mittimus":{"mittimus","mittimuses"},
"mitzvah":{"mitzvah","mitzvahs","mitzvoth"},
"miwok":{"miwok","miwoks"},
"mix":{"mix","mixed","mixes","mixing"},
"mix-up":{"mix-up","mix-ups"},
"mixer":{"mixer","mixers"},
"mixing":{"mixing","mixings"},
"mixologist":{"mixologist","mixologists"},
"mixtec":{"mixtec","mixtecs"},
"mixture":{"mixture","mixtures"},
"mizen":{"mizen","mizens"},
"mizenmast":{"mizenmast","mizenmasts"},
"mizzen":{"mizzen","mizzens"},
"mizzenmast":{"mizzenmast","mizzenmasts"},
"mizzle":{"mizzle","mizzled","mizzles","mizzling"},
"ml":{"ml","mls"},
"mlitt":{"mlitt","mlitts"},
"mlle":{"mlle","mlles"},
"mls":{"mls","mlses"},
"mm":{"mm","mms"},
"mn":{"mn","mns"},
"mniaceae":{"mniaceae","mniaceaes"},
"mnium":{"mnium","mniums"},
"mo":{"mo","mos"},
"moa":{"moa","moas"},
"moan":{"moan","moaned","moaning","moans"},
"moaner":{"moaner","moaners"},
"moat":{"moat","moated","moating","moats"},
"mob":{"mob","mobbed","mobbing","mobs"},
"mobile":{"mobile","mobiles"},
"mobilisation":{"mobilisation","mobilisations"},
"mobilization":{"mobilization","mobilizations"},
"mobilize":{"mobilize","mobilized","mobilizes","mobilizing"},
"mobocracy":{"mobocracies","mobocracy"},
"mobster":{"mobster","mobsters"},
"mobula":{"mobula","mobulas"},
"mobulidae":{"mobulidae","mobulidaes"},
"mocambique":{"mocambique","mocambiques"},
"mocassin":{"mocassin","mocassins"},
"moccasin":{"moccasin","moccasins"},
"moccasins":{"moccasins","moccasinses"},
"mock":{"mock","mocked","mocking","mocks"},
"mocker":{"mocker","mockers"},
"mockernut":{"mockernut","mockernuts"},
"mockery":{"mockeries","mockery"},
"mockingbird":{"mockingbird","mockingbirds"},
"modality":{"modalities","modality"},
"mode":{"mode","modes"},
"model":{"model","modeled","modeling","modelled","modelling","models"},
"modeler":{"modeler","modelers"},
"modeling":{"modeling","modelings"},
"modeller":{"modeller","modellers"},
"modelling":{"modelling","modellings"},
"moderate":{"moderate","moderated","moderates","moderating"},
"moderateness":{"moderateness","moderatenesses"},
"moderation":{"moderation","moderations"},
"moderationist":{"moderationist","moderationists"},
"modern":{"modern","moderns"},
"modernisation":{"modernisation","modernisations"},
"modernism":{"modernism","modernisms"},
"modernity":{"modernities","modernity"},
"modernization":{"modernization","modernizations"},
"modernize":{"modernize","modernized","modernizes","modernizing"},
"modernizing":{"modernizing","modernizings"},
"modernness":{"modernness","modernnesses"},
"modest":{"modest"},
"modestness":{"modestness","modestnesses"},
"modesty":{"modesties","modesty"},
"modicum":{"modica","modicum","modicums"},
"modification":{"modification","modifications"},
"modifier":{"modifier","modifiers"},
"modify":{"modified","modifies","modify","modifying"},
"modiolus":{"modioli","modiolus"},
"modishness":{"modishness","modishnesses"},
"modiste":{"modiste","modistes"},
"modulate":{"modulate","modulated","modulates","modulating"},
"modulation":{"modulation","modulations"},
"module":{"module","modules"},
"modulus":{"moduli","modului","modulus"},
"modus":{"modi","modus"},
"moehringia":{"moehringia","moehringias"},
"mogadiscio":{"mogadiscio","mogadiscios"},
"moghul":{"moghul","moghuls"},
"mogul":{"mogul","moguls"},
"mohammadanism":{"mohammadanism","mohammadanisms"},
"mohammed":{"mohammed","mohammeds"},
"mohammedan":{"mohammedan","mohammedans"},
"mohammedanism":{"mohammedanism","mohammedanisms"},
"mohave":{"mohave","mohaves"},
"mohawk":{"mohawk","mohawks"},
"mohican":{"mohican","mohicans"},
"mohria":{"mohria","mohrias"},
"moiety":{"moieties","moiety"},
"moil":{"moil","moiled","moiling","moils"},
"moirae":{"moirae","moiraes"},
"moirai":{"moirai","moirais"},
"moire":{"moire","moires"},
"moist":{"moist","moister","moistest"},
"moisten":{"moisten","moistened","moistening","moistens"},
"moistening":{"moistening","moistenings"},
"moistness":{"moistness","moistnesses"},
"moisture":{"moisture","moistures"},
"moisturize":{"moisturize","moisturized","moisturizes","moisturizing"},
"mojave":{"mojave","mojaves"},
"mol":{"mol","mols"},
"mola":{"mola","molas"},
"molality":{"molalities","molality"},
"molar":{"molar","molars"},
"molarity":{"molarities","molarity"},
"mold":{"mold","molded","molding","molds"},
"moldavia":{"moldavia","moldavias"},
"moldboard":{"moldboard","moldboards"},
"molder":{"molder","moldered","moldering","molders"},
"moldiness":{"moldiness","moldinesses"},
"molding":{"molding","moldings"},
"moldova":{"moldova","moldovas"},
"moldy":{"moldier","moldiest","moldy"},
"mole":{"mole","moles"},
"molech":{"molech","moleches"},
"molecule":{"molecule","molecules"},
"molest":{"molest","molested","molesting","molests"},
"molestation":{"molestation","molestations"},
"molidae":{"molidae","molidaes"},
"moll":{"moll","molls"},
"mollah":{"mollah","mollahs"},
"molle":{"molle","molles"},
"mollie":{"mollie","mollies"},
"mollienesia":{"mollienesia","mollienesias"},
"mollification":{"mollification","mollifications"},
"mollify":{"mollified","mollifies","mollify","mollifying"},
"molluga":{"molluga","mollugas"},
"mollusc":{"mollusc","molluscs"},
"mollusca":{"mollusca","molluscas"},
"mollusk":{"mollusk","mollusks"},
"molly":{"mollies","molly"},
"mollycoddle":{"mollycoddle","mollycoddled","mollycoddles","mollycoddling"},
"moloch":{"moloch","moloches"},
"molokai":{"molokai","molokais"},
"molossidae":{"molossidae","molossidaes"},
"molothrus":{"molothrus","molothruses"},
"molotov":{"molotov","molotovs"},
"molt":{"molt","molted","molting","molts"},
"molting":{"molting","moltings"},
"molucella":{"molucella","molucellas"},
"molva":{"molva","molvas"},
"moly":{"molies","moly"},
"molybdenum":{"molybdenum","molybdenums"},
"mom":{"mom","moms"},
"mombin":{"mombin","mombins"},
"moment":{"moment","moments"},
"momentum":{"momenta","momentum","momentums"},
"momism":{"momism","momisms"},
"momma":{"momma","mommas"},
"mommy":{"mommies","mommy"},
"momordica":{"momordica","momordicas"},
"momos":{"momos","momoses"},
"momot":{"momot","momots"},
"momotidae":{"momotidae","momotidaes"},
"momotus":{"momotus","momotuses"},
"momus":{"momi","momus","momuses"},
"mon":{"mon","mons"},
"monad":{"monad","monades","monads"},
"monal":{"monal","monals"},
"monarch":{"monarch","monarches"},
"monarchist":{"monarchist","monarchists"},
"monarchy":{"monarchies","monarchy"},
"monarda":{"monarda","monardas"},
"monardella":{"monardella","monardellas"},
"monas":{"monades","monas","monases"},
"monastery":{"monasteries","monastery"},
"monastic":{"monastic","monastics"},
"monaul":{"monaul","monauls"},
"monday":{"monday","mondays"},
"monera":{"monera","moneras"},
"moneran":{"moneran","monerans"},
"moneron":{"moneron","monerons"},
"moneses":{"moneses","moneseses"},
"monetisation":{"monetisation","monetisations"},
"monetization":{"monetization","monetizations"},
"monetize":{"monetize","monetized","monetizing"},
"money":{"money","moneys","monies"},
"money-spinner":{"money-spinner","money-spinners"},
"moneylender":{"moneylender","moneylenders"},
"moneymaker":{"moneymaker","moneymakers"},
"moneyman":{"moneyman","moneymen"},
"moneywort":{"moneywort","moneyworts"},
"monger":{"monger","mongers"},
"mongo":{"mongo","mongos"},
"mongoe":{"mongoe","mongoes"},
"mongol":{"mongol","mongols"},
"mongolia":{"mongolia","mongolias"},
"mongolian":{"mongolian","mongolians"},
"mongolianism":{"mongolianism","mongolianisms"},
"mongolic":{"mongolic","mongolics"},
"mongolism":{"mongolism","mongolisms"},
"mongoose":{"mongeese","mongoose","mongooses"},
"mongrel":{"mongrel","mongrels"},
"mongrelize":{"mongrelize","mongrelized","mongrelizing"},
"moniker":{"moniker","monikers"},
"moniliaceae":{"moniliaceae","moniliaceaes"},
"moniliales":{"moniliales","monilialeses"},
"moniliasis":{"moniliases","moniliasis"},
"monition":{"monition","monitions"},
"monitor":{"monitor","monitored","monitoring","monitors"},
"monitory":{"monitories","monitory"},
"monk":{"monk","monks"},
"monkery":{"monkeries","monkery"},
"monkey":{"monkey","monkeyed","monkeying","monkeys"},
"monkeypod":{"monkeypod","monkeypods"},
"monkeywrench":{"monkeywrench","monkeywrenches"},
"monkfish":{"monkfish","monkfishes"},
"monkshood":{"monkshood","monkshoods"},
"mono":{"mono","monos"},
"monocanthidae":{"monocanthidae","monocanthidaes"},
"monocanthus":{"monocanthus","monocanthuses"},
"monocarp":{"monocarp","monocarps"},
"monochamus":{"monochamus","monochamuses"},
"monochasium":{"monochasia","monochasium"},
"monochrome":{"monochrome","monochromes"},
"monocle":{"monocle","monocles"},
"monocot":{"monocot","monocots"},
"monocotyledon":{"monocotyledon","monocotyledons"},
"monocotyledonae":{"monocotyledonae","monocotyledonaes"},
"monocotyledones":{"monocotyledones","monocotyledoneses"},
"monocracy":{"monocracies","monocracy"},
"monocycle":{"monocycle","monocycles"},
"monodon":{"monodon","monodons"},
"monodontidae":{"monodontidae","monodontidaes"},
"monodrama":{"monodrama","monodramas"},
"monody":{"monodies","monody"},
"monogamist":{"monogamist","monogamists"},
"monogamousness":{"monogamousness","monogamousnesses"},
"monogamy":{"monogamies","monogamy"},
"monogenesis":{"monogeneses","monogenesis"},
"monogram":{"monogram","monogrammed","monogramming","monograms"},
"monogynist":{"monogynist","monogynists"},
"monogyny":{"monogynies","monogyny"},
"monologue":{"monologue","monologues"},
"monomania":{"monomania","monomanias"},
"monomorium":{"monomorium","monomoriums"},
"mononucleosis":{"mononucleoses","mononucleosis"},
"monophobia":{"monophobia","monophobias"},
"monophony":{"monophonies","monophony"},
"monophthalmos":{"monophthalmos","monophthalmoses"},
"monopodium":{"monopodia","monopodium"},
"monopolisation":{"monopolisation","monopolisations"},
"monopolist":{"monopolist","monopolists"},
"monopolization":{"monopolization","monopolizations"},
"monopolize":{"monopolize","monopolized","monopolizing"},
"monopolizer":{"monopolizer","monopolizers"},
"monopoly":{"monopolies","monopoly"},
"monopsony":{"monopsonies","monopsony"},
"monopteron":{"monoptera","monopteron"},
"monopteros":{"monopteroi","monopteros"},
"monosaccharide":{"monosaccharide","monosaccharides"},
"monosaccharose":{"monosaccharose","monosaccharoses"},
"monosyllable":{"monosyllable","monosyllables"},
"monotone":{"monotone","monotones"},
"monotony":{"monotonies","monotony"},
"monotremata":{"monotremata","monotrematas"},
"monotreme":{"monotreme","monotremes"},
"monotropa":{"monotropa","monotropas"},
"monotropaceae":{"monotropaceae","monotropaceaes"},
"monroe":{"monroe","monroes"},
"monrovia":{"monrovia","monrovias"},
"mons":{"mons","monses"},
"monseigneur":{"messeigneurs","monseigneur"},
"monsieur":{"messieurs","monsieur"},
"monsignor":{"monsignor","monsignori","monsignors"},
"monster":{"monster","monsters"},
"monstera":{"monstera","monsteras"},
"monstrosity":{"monstrosities","monstrosity"},
"mont-de-piete":{"mont-de-piete","monts-de-piete"},
"montage":{"montage","montages"},
"montagnard":{"montagnard","montagnards"},
"montana":{"montana","montanas"},
"monte":{"monte","montes"},
"montero":{"montero","monteros"},
"montevideo":{"montevideo","montevideos"},
"montfort":{"montfort","montforts"},
"montgomery":{"montgomeries","montgomery"},
"month":{"month","months"},
"monthly":{"monthlies","monthly"},
"montia":{"montia","montias"},
"montpelier":{"montpelier","montpeliers"},
"monument":{"monument","monuments"},
"monumentalize":{"monumentalize","monumentalized","monumentalizing"},
"moo":{"moo","mooed","mooing","moos"},
"moo-cow":{"moo-cow","moo-cows"},
"mooch":{"mooch","mooched","mooches","mooching"},
"moocher":{"moocher","moochers"},
"mood":{"mood","moods"},
"moody":{"moodier","moodiest","moody"},
"moolah":{"moolah","moolahs"},
"moon":{"moon","mooned","mooning","moons"},
"moon-worship":{"moon-worship","moon-worships"},
"moonbeam":{"moonbeam","moonbeams"},
"mooncalf":{"mooncalf","mooncalves"},
"mooncurser":{"mooncurser","mooncursers"},
"mooneye":{"mooneye","mooneyes"},
"moonfish":{"moonfish","moonfishes"},
"moonflower":{"moonflower","moonflowers"},
"moonlight":{"moonlight","moonlighted","moonlighting","moonlights"},
"moonray":{"moonray","moonrays"},
"moonshine":{"moonshine","moonshines"},
"moonshiner":{"moonshiner","moonshiners"},
"moonwort":{"moonwort","moonworts"},
"moony":{"moonier","mooniest","moony"},
"moor":{"moor","moored","mooring","moors"},
"moorage":{"moorage","moorages"},
"moorberry":{"moorberries","moorberry"},
"moorbird":{"moorbird","moorbirds"},
"moorfowl":{"moorfowl","moorfowls"},
"moorgame":{"moorgame","moorgames"},
"moorhen":{"moorhen","moorhens"},
"mooring":{"mooring","moorings"},
"moorish":{"moorish","moorishes"},
"moorland":{"moorland","moorlands"},
"moorwort":{"moorwort","moorworts"},
"moose":{"moose","mooses"},
"moosewood":{"moosewood","moosewoods"},
"mop":{"mop","mopped","mopping","mops"},
"mopboard":{"mopboard","mopboards"},
"mope":{"mope","moped","mopes","moping"},
"mopery":{"moperies","mopery"},
"mopes":{"mopes","mopeses"},
"mopping":{"mopping","moppings"},
"mopy":{"mopier","mopiest","mopy"},
"moquelumnan":{"moquelumnan","moquelumnans"},
"mora":{"mora","morae","moras"},
"moraceae":{"moraceae","moraceaes"},
"moral":{"moral","morals"},
"morale":{"morale","morales"},
"moralist":{"moralist","moralists"},
"morality":{"moralities","morality"},
"moralize":{"moralize","moralized","moralizes","moralizing"},
"morals":{"morals","moralses"},
"morass":{"morass","morasses"},
"moratorium":{"moratoria","moratorium","moratoriums"},
"moray":{"moray","morays"},
"morbidity":{"morbidities","morbidity"},
"morbidness":{"morbidness","morbidnesses"},
"morbilli":{"morbilli","morbillis"},
"morceau":{"morceau","morceaux"},
"morchella":{"morchella","morchellas"},
"morchellaceae":{"morchellaceae","morchellaceaes"},
"mordant":{"mordant","mordanted","mordanting"},
"mordva":{"mordva","mordvas"},
"mordvin":{"mordvin","mordvins"},
"mordvinian":{"mordvinian","mordvinians"},
"morello":{"morello","morellos"},
"moresco":{"moresco","morescoes","morescos"},
"morgan":{"morgan","morgans"},
"morgue":{"morgue","morgues"},
"morion":{"morion","morions"},
"morisco":{"morisco","moriscoes","moriscos"},
"mormon":{"mormon","mormons"},
"mormons":{"mormons","mormonses"},
"morn":{"morn","morns"},
"morning":{"morning","mornings"},
"morning-glory":{"morning-glories","morning-glory"},
"moro":{"moro","moros"},
"morocco":{"morocco","moroccos"},
"moron":{"moron","morons"},
"morone":{"morone","morones"},
"moronity":{"moronities","moronity"},
"moroseness":{"moroseness","morosenesses"},
"morphallaxis":{"morphallaxes","morphallaxis","morphallaxlaxes"},
"morphia":{"morphia","morphias"},
"morphine":{"morphine","morphines"},
"morphology":{"morphologies","morphology"},
"morphosis":{"morphoses","morphosis"},
"morrigan":{"morrigan","morrigans"},
"morrigu":{"morrigu","morrigus"},
"morro":{"morro","morros"},
"morse":{"morse","morses"},
"morsel":{"morsel","morsels"},
"mortal":{"mortal","mortals"},
"mortality":{"mortalities","mortality"},
"mortar":{"mortar","mortared","mortaring","mortars"},
"mortgage":{"mortgage","mortgaged","mortgages","mortgaging"},
"mortice":{"mortice","morticed","mortices","morticing"},
"mortician":{"mortician","morticians"},
"mortification":{"mortification","mortifications"},
"mortify":{"mortified","mortifies","mortify","mortifying"},
"mortise":{"mortise","mortised","mortises","mortising"},
"mortmain":{"mortmain","mortmains"},
"mortuary":{"mortuaries","mortuary"},
"morula":{"morula","morulae","morulas"},
"morus":{"morus","moruses"},
"mosaic":{"mosaic","mosaicked","mosaicking","mosaics"},
"mosasaur":{"mosasaur","mosasaurs"},
"mosasaurus":{"mosasauri","mosasaurus"},
"moschus":{"moschus","moschuses"},
"moscow":{"moscow","moscows"},
"mosey":{"mosey","moseyed","moseying","moseys"},
"moshav":{"moshav","moshavim"},
"moslem":{"moslem","moslems"},
"mosotho":{"mosotho","mosothos"},
"mosque":{"mosque","mosques"},
"mosquito":{"mosquito","mosquitoes","mosquitos"},
"mosquitofish":{"mosquitofish","mosquitofishes"},
"moss":{"moss","mossed","mosses","mossing"},
"mossback":{"mossback","mossbacks"},
"mossi":{"mossi","mossis"},
"mossy":{"mossier","mossiest","mossy"},
"motacilla":{"motacilla","motacillas"},
"motacillidae":{"motacillidae","motacillidaes"},
"mote":{"mote","motes"},
"motel":{"motel","motels"},
"moth":{"moth","moths"},
"mothball":{"mothball","mothballed","mothballing","mothballs"},
"mother":{"mother","mothered","mothering","mothers"},
"mother-in-law":{"mother-in-law","mothers-in-law"},
"mother-of-pearl":{"mother-of-pearl","mother-of-pearls"},
"mother-of-thousands":{"mother-of-thousands","mother-of-thousandses"},
"motherfucker":{"motherfucker","motherfuckers"},
"motherhood":{"motherhood","motherhoods"},
"motherland":{"motherland","motherlands"},
"motherliness":{"motherliness","motherlinesses"},
"motherwort":{"motherwort","motherworts"},
"mother_superior":{"mothers_superior","mother_superior","mother_superiors"},
"mothproof":{"mothproof","mothproofed","mothproofing"},
"mothy":{"mothier","mothiest","mothy"},
"motif":{"motif","motifs","motives"},
"motion":{"motion","motioned","motioning","motions"},
"motionlessness":{"motionlessness","motionlessnesses"},
"motivate":{"motivate","motivated","motivates","motivating"},
"motivation":{"motivation","motivations"},
"motive":{"motive","motived","motives","motiving"},
"motivity":{"motivities","motivity"},
"motley":{"motley","motleys"},
"motmot":{"motmot","motmots"},
"motor":{"motor","motored","motoring","motors"},
"motorbike":{"motorbike","motorbikes"},
"motorboat":{"motorboat","motorboats"},
"motorbus":{"motorbus","motorbuses","motorbusses"},
"motorcar":{"motorcar","motorcars"},
"motorcoach":{"motorcoach","motorcoaches"},
"motorcycle":{"motorcycle","motorcycled","motorcycles","motorcycling"},
"motorcyclist":{"motorcyclist","motorcyclists"},
"motoring":{"motoring","motorings"},
"motorisation":{"motorisation","motorisations"},
"motorist":{"motorist","motorists"},
"motorization":{"motorization","motorizations"},
"motorize":{"motorize","motorized","motorizes","motorizing"},
"motorman":{"motorman","motormen"},
"motortruck":{"motortruck","motortrucks"},
"motorway":{"motorway","motorways"},
"motown":{"motown","motowns"},
"motrin":{"motrin","motrins"},
"mottle":{"mottle","mottled","mottles","mottling"},
"motto":{"motto","mottoes","mottos"},
"motu":{"motu","motus"},
"moue":{"moue","moues"},
"moufflon":{"moufflon","moufflons"},
"mouflon":{"mouflon","mouflons"},
"moujik":{"moujik","moujiks"},
"moukden":{"moukden","moukdens"},
"mould":{"mould","moulds"},
"mouldboard":{"mouldboard","mouldboards"},
"moulding":{"moulding","mouldings"},
"mouldy":{"mouldier","mouldiest","mouldy"},
"moult":{"moult","moulted","moulting","moults"},
"moulting":{"moulting","moultings"},
"mound":{"mound","mounded","mounding","mounds"},
"moundbird":{"moundbird","moundbirds"},
"mount":{"mount","mounted","mounting","mounts"},
"mountain":{"mountain","mountains"},
"mountaineer":{"mountaineer","mountaineered","mountaineering","mountaineers"},
"mountaineering":{"mountaineering","mountaineerings"},
"mountebank":{"mountebank","mountebanks"},
"mountie":{"mountie","mounties"},
"mounting":{"mounting","mountings"},
"mourn":{"mourn","mourned","mourning"},
"mourner":{"mourner","mourners"},
"mournfulness":{"mournfulness","mournfulnesses"},
"mourning":{"mourning","mournings"},
"mouse":{"mice","mouse","moused","mousing"},
"mousetrap":{"mousetrap","mousetrapped","mousetrapping","mousetraps"},
"mousey":{"mousey","mousier","mousiest"},
"mousse":{"mousse","mousses"},
"moustache":{"moustache","moustaches"},
"moustachio":{"moustachio","moustachios"},
"mousy":{"mousier","mousiest","mousy"},
"mouth":{"mouth","mouthed","mouthing","mouths"},
"mouthful":{"mouthful","mouthfuls"},
"mouthpiece":{"mouthpiece","mouthpieces"},
"mouthwash":{"mouthwash","mouthwashes"},
"mouthy":{"mouthier","mouthiest","mouthy"},
"mouton":{"mouton","moutons"},
"movability":{"movabilities","movability"},
"movable":{"movable","movables"},
"movableness":{"movableness","movablenesses"},
"move":{"move","moved","moves","moving"},
"moveable":{"moveable","moveables"},
"movement":{"movement","movements"},
"mover":{"mover","movers"},
"movie":{"movie","movies"},
"moviegoer":{"moviegoer","moviegoers"},
"moving":{"moving","movings"},
"mow":{"mow","mowed","mowing","mown","mows"},
"mower":{"mower","mowers"},
"mozambique":{"mozambique","mozambiques"},
"mozart":{"mozart","mozarts"},
"mp":{"mp","mps"},
"mph":{"mph","mphs"},
"mr":{"mr","mrs"},
"mr.":{"messrs.","mr."},
"mrd":{"mrd","mrds"},
"mri":{"mri","mris"},
"mrna":{"mrna","mrnas"},
"mrs.":{"mmes.","mrs."},
"ms":{"ms","mses"},
"ms-dos":{"ms-dos","ms-doses"},
"ms.":{"ms.","mses."},
"msasa":{"msasa","msasas"},
"msb":{"msb","msbs"},
"msec":{"msec","msecs"},
"msg":{"msg","msgs"},
"msh":{"msh","mshes"},
"mst":{"mst","msts"},
"mt":{"mt","mts"},
"mu-meson":{"mu-meson","mu-mesons"},
"muazzin":{"muazzin","muazzins"},
"mucilage":{"mucilage","mucilages"},
"muck":{"muck","mucked","mucking","mucks"},
"muckheap":{"muckheap","muckheaps"},
"muckhill":{"muckhill","muckhills"},
"muckle":{"muckle","muckles"},
"muckrake":{"muckrake","muckraked","muckraking"},
"muckraker":{"muckraker","muckrakers"},
"muckraking":{"muckraking","muckrakings"},
"mucky":{"muckier","muckiest","mucky"},
"mucoraceae":{"mucoraceae","mucoraceaes"},
"mucorales":{"mucorales","mucoraleses"},
"mucosa":{"mucosa","mucosae","mucosas"},
"mucovioscidosis":{"mucovioscidoses","mucovioscidosis"},
"mucro":{"mucro","mucrones"},
"mucus":{"mucus","mucuses"},
"mud":{"mud","muds"},
"mudcat":{"mudcat","mudcats"},
"muddiness":{"muddiness","muddinesses"},
"muddle":{"muddle","muddled","muddles","muddling"},
"muddler":{"muddler","muddlers"},
"muddy":{"muddied","muddier","muddies","muddiest","muddy","muddying"},
"mudejar":{"mudejar","mudejares"},
"mudfish":{"mudfish","mudfishes"},
"mudguard":{"mudguard","mudguards"},
"mudra":{"mudra","mudras"},
"mudskipper":{"mudskipper","mudskippers"},
"mudslinger":{"mudslinger","mudslingers"},
"mudspringer":{"mudspringer","mudspringers"},
"muenchen":{"muenchen","muenchens"},
"muezzin":{"muezzin","muezzins"},
"muff":{"muff","muffed","muffing","muffs"},
"muffin":{"muffin","muffins"},
"muffle":{"muffle","muffled","muffles","muffling"},
"muffler":{"muffler","mufflers"},
"mufti":{"mufti","muftis"},
"mug":{"mug","mugged","mugging","mugs"},
"mugful":{"mugful","mugfuls"},
"mugger":{"mugger","muggers"},
"muggins":{"muggins","mugginses"},
"muggy":{"muggier","muggiest","muggy"},
"mugil":{"mugil","mugils"},
"mugilidae":{"mugilidae","mugilidaes"},
"mugiloidea":{"mugiloidea","mugiloideas"},
"mugwump":{"mugwump","mugwumps"},
"muhammad":{"muhammad","muhammads"},
"muhammadan":{"muhammadan","muhammadans"},
"muhammadanism":{"muhammadanism","muhammadanisms"},
"muhammedan":{"muhammedan","muhammedans"},
"muhlenbergia":{"muhlenbergia","muhlenbergias"},
"mujik":{"mujik","mujiks"},
"mukden":{"mukden","mukdens"},
"mulatto":{"mulatto","mulattoes","mulattos"},
"mulberry":{"mulberries","mulberry"},
"mulch":{"mulch","mulched","mulching"},
"mulct":{"mulct","mulcted","mulcting","mulcts"},
"mulcting":{"mulcting","mulctings"},
"mule":{"mule","mules"},
"mules":{"mules","muleses"},
"muleta":{"muleta","muletas"},
"muleteer":{"muleteer","muleteers"},
"mulishness":{"mulishness","mulishnesses"},
"mull":{"mull","mulled","mulling","mulls"},
"mulla":{"mulla","mullas"},
"mullah":{"mullah","mullahs"},
"mullein":{"mullein","mulleins"},
"mullet":{"mullet","mullets"},
"mullidae":{"mullidae","mullidaes"},
"mulligan":{"mulligan","mulligans"},
"mulloidichthys":{"mulloidichthys","mulloidichthyses"},
"mulloway":{"mulloway","mulloways"},
"mullus":{"mullus","mulluses"},
"multifariousness":{"multifariousness","multifariousnesses"},
"multiflora":{"multiflora","multifloras"},
"multimedia":{"multimedia","multimedias"},
"multipara":{"multipara","multiparae","multiparas"},
"multiple":{"multiple","multiples"},
"multiplex":{"multiplex","multiplexed","multiplexing"},
"multiplication":{"multiplication","multiplications"},
"multiplicity":{"multiplicities","multiplicity"},
"multiplier":{"multiplier","multipliers"},
"multiply":{"multiplied","multiplies","multiply","multiplying"},
"multiprocessing":{"multiprocessing","multiprocessings"},
"multiprogramming":{"multiprogramming","multiprogrammings"},
"multitude":{"multitude","multitudes"},
"multiversity":{"multiversities","multiversity"},
"mulwi":{"mulwi","mulwis"},
"mum":{"mum","mums"},
"mumble":{"mumble","mumbled","mumbles","mumbling"},
"mumbler":{"mumbler","mumblers"},
"mumbling":{"mumbling","mumblings"},
"mummer":{"mummer","mummers"},
"mummery":{"mummeries","mummery"},
"mummichog":{"mummichog","mummichogs"},
"mummify":{"mummified","mummifies","mummify","mummifying"},
"mummy":{"mummies","mummy"},
"mumps":{"mumps","mumpses"},
"munch":{"munch","munched","munches","munching"},
"munching":{"munching","munchings"},
"munda":{"munda","mundas"},
"munda-mon-khmer":{"munda-mon-khmer","munda-mon-khmers"},
"mung":{"mung","mungs"},
"mungo":{"mungo","mungos"},
"munich":{"munich","muniches"},
"municipality":{"municipalities","municipality"},
"municipalize":{"municipalize","municipalized","municipalizing"},
"munificence":{"munificence","munificences"},
"munition":{"munition","munitioned","munitioning","munitions"},
"munitions":{"munitions","munitionses"},
"munj":{"munj","munjs"},
"munja":{"munja","munjas"},
"munjeet":{"munjeet","munjeets"},
"munjuk":{"munjuk","munjuks"},
"muntiacus":{"muntiacus","muntiacuses"},
"muntingia":{"muntingia","muntingias"},
"muntjac":{"muntjac","muntjacs"},
"muon":{"muon","muons"},
"muraenidae":{"muraenidae","muraenidaes"},
"mural":{"mural","murals"},
"murder":{"murder","murdered","murdering","murders"},
"murderer":{"murderer","murderers"},
"murderousness":{"murderousness","murderousnesses"},
"murex":{"murex","murexes","murices"},
"muridae":{"muridae","muridaes"},
"muritaniya":{"muritaniya","muritaniyas"},
"murk":{"murk","murks"},
"murkiness":{"murkiness","murkinesses"},
"murky":{"murkier","murkiest","murky"},
"murmur":{"murmur","murmured","murmuring","murmurs"},
"murmuration":{"murmuration","murmurations"},
"murmuring":{"murmuring","murmurings"},
"muroidea":{"muroidea","muroideas"},
"murphy":{"murphies","murphy"},
"murray":{"murray","murrays"},
"mus":{"mus","muses"},
"musa":{"musa","musas"},
"musaceae":{"musaceae","musaceaes"},
"musales":{"musales","musaleses"},
"musca":{"musca","muscas"},
"muscadel":{"muscadel","muscadels"},
"muscadelle":{"muscadelle","muscadelles"},
"muscadine":{"muscadine","muscadines"},
"muscardinus":{"muscardinus","muscardinuses"},
"muscari":{"muscari","muscaris"},
"muscat":{"muscat","muscats"},
"muscatel":{"muscatel","muscatels"},
"musci":{"musci","muscis"},
"muscicapa":{"muscicapa","muscicapas"},
"muscicapidae":{"muscicapidae","muscicapidaes"},
"muscidae":{"muscidae","muscidaes"},
"muscivora":{"muscivora","muscivoras"},
"muscivora-forficata":{"muscivora-forficata","muscivora-forficatas"},
"muscle":{"muscle","muscled","muscles","muscling"},
"musclebuilder":{"musclebuilder","musclebuilders"},
"musclebuilding":{"musclebuilding","musclebuildings"},
"muscleman":{"muscleman","musclemen"},
"muscoidea":{"muscoidea","muscoideas"},
"musculature":{"musculature","musculatures"},
"musculus":{"musculus","musculuses"},
"musd":{"musd","musds"},
"muse":{"muse","mused","muses","musing"},
"musette":{"musette","musettes"},
"museum":{"museum","museums"},
"musgoi":{"musgoi","musgois"},
"musgu":{"musgu","musgus"},
"mush":{"mush","mushed","mushes","mushing"},
"mushiness":{"mushiness","mushinesses"},
"mushroom":{"mushroom","mushroomed","mushrooming","mushrooms"},
"mushy":{"mushier","mushiest","mushy"},
"music":{"music","musics"},
"musical":{"musical","musicals"},
"musicality":{"musicalities","musicality"},
"musicalize":{"musicalize","musicalized","musicalizing"},
"musicalness":{"musicalness","musicalnesses"},
"musician":{"musician","musicians"},
"musing":{"musing","musings"},
"musjid":{"musjid","musjids"},
"musk":{"musk","musks"},
"muskat":{"muskat","muskats"},
"muskellunge":{"muskellunge","muskellunges"},
"musket":{"musket","muskets"},
"muskhogean":{"muskhogean","muskhogeans"},
"muskmelon":{"muskmelon","muskmelons"},
"muskogean":{"muskogean","muskogeans"},
"muskrat":{"muskrat","muskrats"},
"muskwood":{"muskwood","muskwoods"},
"musky":{"muskier","muskies","muskiest","musky"},
"muslim":{"muslim","muslims"},
"muslimism":{"muslimism","muslimisms"},
"musophaga":{"musophaga","musophagas"},
"musophagidae":{"musophagidae","musophagidaes"},
"musquash":{"musquash","musquashes"},
"muss":{"muss","mussed","musses","mussing"},
"mussalman":{"mussalman","mussalmans"},
"mussel":{"mussel","mussels"},
"mussiness":{"mussiness","mussinesses"},
"mussolini":{"mussolini","mussolinis"},
"mussulman":{"mussulman","mussulmans"},
"mussy":{"mussier","mussiest","mussy"},
"mustache":{"mustache","mustaches"},
"mustachio":{"mustachio","mustachios"},
"mustagh":{"mustagh","mustaghs"},
"mustard":{"mustard","mustards"},
"mustela":{"mustela","mustelas"},
"mustelid":{"mustelid","mustelids"},
"mustelidae":{"mustelidae","mustelidaes"},
"musteline":{"musteline","mustelines"},
"mustelus":{"mustelus","musteluses"},
"muster":{"muster","mustered","mustering","musters"},
"mustiness":{"mustiness","mustinesses"},
"musty":{"mustier","mustiest","musty"},
"mut":{"mut","muts"},
"mutability":{"mutabilities","mutability"},
"mutableness":{"mutableness","mutablenesses"},
"mutant":{"mutant","mutants"},
"mutate":{"mutate","mutated","mutating"},
"mutation":{"mutation","mutations"},
"mute":{"mute","muted","muter","mutes","mutest","muting"},
"muteness":{"muteness","mutenesses"},
"mutilate":{"mutilate","mutilated","mutilates","mutilating"},
"mutilation":{"mutilation","mutilations"},
"mutineer":{"mutineer","mutineers"},
"mutinus":{"mutinus","mutinuses"},
"mutiny":{"mutinied","mutinies","mutiny","mutinying"},
"mutt":{"mutt","mutts"},
"mutter":{"mutter","muttered","muttering","mutters"},
"mutterer":{"mutterer","mutterers"},
"muttering":{"muttering","mutterings"},
"mutton":{"mutton","muttons"},
"muttonfish":{"muttonfish","muttonfishes"},
"muttonhead":{"muttonhead","muttonheads"},
"mutuality":{"mutualities","mutuality"},
"mutualness":{"mutualness","mutualnesses"},
"muumuu":{"muumuu","muumuus"},
"muzhik":{"muzhik","muzhiks"},
"muzjik":{"muzjik","muzjiks"},
"muzzle":{"muzzle","muzzled","muzzles","muzzling"},
"muzzy":{"muzzier","muzziest","muzzy"},
"mv":{"mv","mvs"},
"mvp":{"mvp","mvps"},
"mx":{"mx","mxes"},
"mya":{"mya","myas"},
"myaceae":{"myaceae","myaceaes"},
"myacidae":{"myacidae","myacidaes"},
"myadestes":{"myadestes","myadesteses"},
"myalgia":{"myalgia","myalgias"},
"myanmar":{"myanmar","myanmars"},
"mycelium":{"mycelia","mycelilia","mycelium"},
"mycetoma":{"mycetoma","mycetomas","mycetomata"},
"mycetophilidae":{"mycetophilidae","mycetophilidaes"},
"mycobacteria":{"mycobacteria","mycobacterias"},
"mycobacteriacaea":{"mycobacteriacaea","mycobacteriacaeas"},
"mycobacterium":{"mycobacterium","mycobacteriums"},
"mycoplasma":{"mycoplasma","mycoplasmas","mycoplasmata"},
"mycoplasmatacaea":{"mycoplasmatacaea","mycoplasmatacaeas"},
"mycoplasmatales":{"mycoplasmatales","mycoplasmataleses"},
"mycorhiza":{"mycorhiza","mycorhizas"},
"mycorrhiza":{"mycorrhiza","mycorrhizae","mycorrhizas"},
"mycosis":{"mycoses","mycosis"},
"mycostatin":{"mycostatin","mycostatins"},
"mycrosporidia":{"mycrosporidia","mycrosporidias"},
"mycteroperca":{"mycteroperca","mycteropercas"},
"myctophidae":{"myctophidae","myctophidaes"},
"myelencephalon":{"myelencephala","myelencephalon","myelencephalons","mylencephala"},
"myelin":{"myelin","myelins"},
"myeline":{"myeline","myelines"},
"myeloma":{"myeloma","myelomas","myelomata"},
"myg":{"myg","mygs"},
"myiasis":{"myiases","myiasis"},
"mylar":{"mylar","mylars"},
"myliobatidae":{"myliobatidae","myliobatidaes"},
"mylitta":{"mylitta","mylittas"},
"mylodontidae":{"mylodontidae","mylodontidaes"},
"mym":{"mym","myms"},
"myna":{"myna","mynas"},
"mynah":{"mynah","mynahs"},
"myocarditis":{"myocarditis","myocarditises"},
"myocardium":{"myocardia","myocardium"},
"myocastor":{"myocastor","myocastors"},
"myodynia":{"myodynia","myodynias"},
"myofibril":{"myofibril","myofibrils"},
"myofibrilla":{"myofibrilla","myofibrillas"},
"myoma":{"myoma","myomas","myomata"},
"myomorpha":{"myomorpha","myomorphas"},
"myopathy":{"myopathies","myopathy"},
"myopia":{"myopia","myopias"},
"myopus":{"myopus","myopuses"},
"myosis":{"myoses","myosis"},
"myosotis":{"myosotis","myosotises"},
"myotis":{"myotis","myotises"},
"myrcia":{"myrcia","myrcias"},
"myrciaria":{"myrciaria","myrciarias"},
"myriad":{"myriad","myriads"},
"myriagram":{"myriagram","myriagrams"},
"myriameter":{"myriameter","myriameters"},
"myriametre":{"myriametre","myriametres"},
"myriapoda":{"myriapoda","myriapodas"},
"myrica":{"myrica","myricas"},
"myricaceae":{"myricaceae","myricaceaes"},
"myricales":{"myricales","myricaleses"},
"myricaria":{"myricaria","myricarias"},
"myriophyllum":{"myriophyllum","myriophyllums"},
"myristica":{"myristica","myristicas"},
"myristicaceae":{"myristicaceae","myristicaceaes"},
"myrmecia":{"myrmecia","myrmecias"},
"myrmecobius":{"myrmecobius","myrmecobiuses"},
"myrmecophaga":{"myrmecophaga","myrmecophagas"},
"myrmecophagidae":{"myrmecophagidae","myrmecophagidaes"},
"myrmeleon":{"myrmeleon","myrmeleons"},
"myrmeleontidae":{"myrmeleontidae","myrmeleontidaes"},
"myrmidon":{"myrmidon","myrmidones","myrmidons"},
"myrobalan":{"myrobalan","myrobalans"},
"myroxylon":{"myroxylon","myroxylons"},
"myrrh":{"myrrh","myrrhs"},
"myrrhis":{"myrrhis","myrrhises"},
"myrsinaceae":{"myrsinaceae","myrsinaceaes"},
"myrsine":{"myrsine","myrsines"},
"myrtaceae":{"myrtaceae","myrtaceaes"},
"myrtales":{"myrtales","myrtaleses"},
"myrtillocactus":{"myrtillocactus","myrtillocactuses"},
"myrtle":{"myrtle","myrtles"},
"myrtus":{"myrtus","myrtuses"},
"mysidacea":{"mysidacea","mysidaceas"},
"mysidae":{"mysidae","mysidaes"},
"mysis":{"myses","mysis"},
"mystery":{"mysteries","mystery"},
"mystic":{"mystic","mystics"},
"mysticeti":{"mysticeti","mysticetis"},
"mysticism":{"mysticism","mysticisms"},
"mystification":{"mystification","mystifications"},
"mystify":{"mystified","mystifies","mystify","mystifying"},
"myth":{"myth","myths"},
"mythicize":{"mythicize","mythicized","mythicizing"},
"mythography":{"mythographies","mythography"},
"mythologisation":{"mythologisation","mythologisations"},
"mythologization":{"mythologization","mythologizations"},
"mythologize":{"mythologize","mythologized","mythologizing"},
"mythology":{"mythologies","mythology"},
"mythos":{"mythoi","mythos"},
"mytilid":{"mytilid","mytilids"},
"mytilidae":{"mytilidae","mytilidaes"},
"mytilus":{"mytilus","mytiluses"},
"myxine":{"myxine","myxines"},
"myxinidae":{"myxinidae","myxinidaes"},
"myxiniformes":{"myxiniformes","myxiniformeses"},
"myxinikela":{"myxinikela","myxinikelas"},
"myxinoidea":{"myxinoidea","myxinoideas"},
"myxinoidei":{"myxinoidei","myxinoideis"},
"myxobacter":{"myxobacter","myxobacters"},
"myxobacterales":{"myxobacterales","myxobacteraleses"},
"myxobacteria":{"myxobacteria","myxobacterias"},
"myxobacteriaceae":{"myxobacteriaceae","myxobacteriaceaes"},
"myxobacteriales":{"myxobacteriales","myxobacterialeses"},
"myxobacterium":{"myxobacterium","myxobacteriums"},
"myxocephalus":{"myxocephalus","myxocephaluses"},
"myxoma":{"myxoma","myxomas","myxomata"},
"myxomycete":{"myxomycete","myxomycetes"},
"myxomycetes":{"myxomycetes","myxomyceteses"},
"myxomycota":{"myxomycota","myxomycotas"},
"myxophyceae":{"myxophyceae","myxophyceaes"},
"myxosporidia":{"myxosporidia","myxosporidias"},
"myxovirus":{"myxovirus","myxoviruses"},
"n":{"n","ns"},
"na":{"na","nas"},
"nab":{"nab","nabbed","nabbing","nabs"},
"nabalus":{"nabalus","nabaluses"},
"nabe":{"nabe","nabes"},
"naboom":{"naboom","nabooms"},
"nabu":{"nabu","nabus"},
"nabumetone":{"nabumetone","nabumetones"},
"nacre":{"nacre","nacres"},
"nad":{"nad","nads"},
"nada":{"nada","nadas"},
"nadir":{"nadir","nadirs"},
"nadolol":{"nadolol","nadolols"},
"naemorhedus":{"naemorhedus","naemorheduses"},
"naevus":{"naevi","naevus"},
"nag":{"nag","nagged","nagging","nags"},
"naga":{"naga","nagas"},
"nagami":{"nagami","nagamis"},
"nagari":{"nagari","nagaris"},
"nageia":{"nageia","nageias"},
"nagger":{"nagger","naggers"},
"nagi":{"nagi","nagis"},
"nahuatl":{"nahuatl","nahuatls"},
"naiad":{"naiad","naiades","naiads"},
"naiadaceae":{"naiadaceae","naiadaceaes"},
"naiadales":{"naiadales","naiadaleses"},
"naias":{"naias","naiases"},
"nail":{"nail","nailed","nailing","nails"},
"nailrod":{"nailrod","nailrods"},
"nairobi":{"nairobi","nairobis"},
"naive":{"naive","naiver","naivest"},
"naiveness":{"naiveness","naivenesses"},
"naivete":{"naivete","naivetes"},
"naivety":{"naiveties","naivety"},
"naja":{"naja","najas"},
"najadaceae":{"najadaceae","najadaceaes"},
"najas":{"najas","najases"},
"nakedness":{"nakedness","nakednesses"},
"nakedwood":{"nakedwood","nakedwoods"},
"nalfon":{"nalfon","nalfons"},
"nama":{"nama","namas"},
"namaqua":{"namaqua","namaquas"},
"namby-pamby":{"namby-pambies","namby-pamby"},
"name":{"name","named","names","naming"},
"nameko":{"nameko","namekos"},
"namelessness":{"namelessness","namelessnesses"},
"names":{"names","nameses"},
"namesake":{"namesake","namesakes"},
"naming":{"naming","namings"},
"nammad":{"nammad","nammads"},
"namtar":{"namtar","namtars"},
"namtaru":{"namtaru","namtarus"},
"nandrolone":{"nandrolone","nandrolones"},
"nandu":{"nandu","nandus"},
"nanism":{"nanism","nanisms"},
"nanjing":{"nanjing","nanjings"},
"nanking":{"nanking","nankings"},
"nanny":{"nannies","nanny"},
"nanny-goat":{"nanny-goat","nanny-goats"},
"nanocephaly":{"nanocephalies","nanocephaly"},
"nanometer":{"nanometer","nanometers"},
"nanometre":{"nanometre","nanometres"},
"nantua":{"nantua","nantuas"},
"naomi":{"naomi","naomis"},
"naos":{"naoi","naos"},
"nap":{"nap","napped","napping","naps"},
"napa":{"napa","napas"},
"napaea":{"napaea","napaeas"},
"nape":{"nape","napes"},
"napea":{"napea","napeas"},
"napery":{"naperies","napery"},
"naphthalize":{"naphthalize","naphthalized","naphthalizing"},
"naphthoquinone":{"naphthoquinone","naphthoquinones"},
"napier":{"napier","napiers"},
"napkin":{"napkin","napkins"},
"napoleon":{"napoleon","napoleons"},
"nappy":{"nappier","nappies","nappiest","nappy"},
"naprosyn":{"naprosyn","naprosyns"},
"naproxen":{"naproxen","naproxens"},
"napu":{"napu","napus"},
"naranjilla":{"naranjilla","naranjillas"},
"narc":{"narc","narcs"},
"narcism":{"narcism","narcisms"},
"narcissism":{"narcissism","narcissisms"},
"narcissist":{"narcissist","narcissists"},
"narcissus":{"narciscissi","narciscissuses","narcissi","narcissus","narcissuses"},
"narcist":{"narcist","narcists"},
"narcoma":{"narcoma","narcomas","narcomata"},
"narcotic":{"narcotic","narcotics"},
"narcotize":{"narcotize","narcotized","narcotizing"},
"nard":{"nard","nards"},
"nardo":{"nardo","nardos"},
"nardoo":{"nardoo","nardoos"},
"narghile":{"narghile","narghiles"},
"nark":{"nark","narks"},
"narraganset":{"narraganset","narragansets"},
"narragansett":{"narragansett","narragansetts"},
"narrate":{"narrate","narrated","narrates","narrating"},
"narration":{"narration","narrations"},
"narrative":{"narrative","narratives"},
"narrator":{"narrator","narrators"},
"narrow":{"narrow","narrowed","narrower","narrowest","narrowing","narrows"},
"narthecium":{"narthecium","nartheciums"},
"narwal":{"narwal","narwals"},
"narwhal":{"narwhal","narwhals"},
"narwhale":{"narwhale","narwhales"},
"nasa":{"nasa","nasas"},
"nasal":{"nasal","nasals"},
"nasalis":{"nasalis","nasalises"},
"nasalize":{"nasalize","nasalized","nasalizes","nasalizing"},
"nascence":{"nascence","nascences"},
"nascency":{"nascencies","nascency"},
"naseberry":{"naseberries","naseberry"},
"naseby":{"nasebies","naseby"},
"nashville":{"nashville","nashvilles"},
"nasopharynx":{"nasopharynges","nasopharynx","nasopharynxes"},
"nassau":{"nassau","nassaus"},
"nasser":{"nasser","nassers"},
"nast":{"nast","nasts"},
"nastiness":{"nastiness","nastinesses"},
"nasturtium":{"nasturtium","nasturtiums"},
"nasty":{"nastier","nasties","nastiest","nasty"},
"nasua":{"nasua","nasuas"},
"natality":{"natalities","natality"},
"natantia":{"natantia","natantias"},
"natator":{"natator","natators"},
"natatorium":{"natatoria","natatorium","natatoriums"},
"naticidae":{"naticidae","naticidaes"},
"nation":{"nation","nations"},
"national":{"national","nationals"},
"nationalisation":{"nationalisation","nationalisations"},
"nationalism":{"nationalism","nationalisms"},
"nationalist":{"nationalist","nationalists"},
"nationality":{"nationalities","nationality"},
"nationalization":{"nationalization","nationalizations"},
"nationalize":{"nationalize","nationalized","nationalizing"},
"native":{"native","natives"},
"nativity":{"nativities","nativity"},
"nato":{"nato","natos"},
"natrix":{"natrix","natrixes"},
"natter":{"natter","nattered","nattering","natters"},
"natterjack":{"natterjack","natterjacks"},
"nattiness":{"nattiness","nattinesses"},
"natty":{"nattier","nattiest","natty"},
"natural":{"natural","naturals"},
"naturalisation":{"naturalisation","naturalisations"},
"naturalism":{"naturalism","naturalisms"},
"naturalist":{"naturalist","naturalists"},
"naturalization":{"naturalization","naturalizations"},
"naturalize":{"naturalize","naturalized","naturalizes","naturalizing"},
"naturalness":{"naturalness","naturalnesses"},
"nature":{"nature","natures"},
"naturism":{"naturism","naturisms"},
"naturist":{"naturist","naturists"},
"nauch":{"nauch","nauches"},
"nauclea":{"nauclea","naucleas"},
"naucrates":{"naucrates","naucrateses"},
"naught":{"naught","naughts"},
"naughtiness":{"naughtiness","naughtinesses"},
"naughty":{"naughtier","naughtiest","naughty"},
"naumachia":{"naumachia","naumachiae","naumachias"},
"naumachy":{"naumachies","naumachy"},
"naupathia":{"naupathia","naupathias"},
"nauplius":{"nauplii","nauplius"},
"nausea":{"nausea","nauseas"},
"nauseant":{"nauseant","nauseants"},
"nauseate":{"nauseate","nauseated","nauseates","nauseating"},
"nauseatingness":{"nauseatingness","nauseatingnesses"},
"nautch":{"nautch","nautches"},
"nautilidae":{"nautilidae","nautilidaes"},
"nautilus":{"nautili","nautilus","nautiluses"},
"navaho":{"navaho","navahoes","navahos"},
"navajo":{"navajo","navajoes","navajos"},
"navarino":{"navarino","navarinos"},
"nave":{"nave","naves"},
"navel":{"navel","navels"},
"navicular":{"navicular","naviculars"},
"navigate":{"navigate","navigated","navigates","navigating"},
"navigation":{"navigation","navigations"},
"navigator":{"navigator","navigators"},
"navvy":{"navvies","navvy"},
"navy":{"navies","navy"},
"nay":{"nay","nays"},
"naysay":{"naysaid","naysay","naysaying"},
"nazi":{"nazi","nazis"},
"naziism":{"naziism","naziisms"},
"nazism":{"nazism","nazisms"},
"nb":{"nb","nbs"},
"nbe":{"nbe","nbes"},
"nbw":{"nbw","nbws"},
"nd":{"nd","nds"},
"ndebele":{"ndebele","ndebeles"},
"ndjamena":{"ndjamena","ndjamenas"},
"ne":{"ne","nes"},
"neanderthal":{"neanderthal","neanderthals"},
"neap":{"neap","neaps"},
"near":{"near","nearer","nearest","nears"},
"nearness":{"nearness","nearnesses"},
"nearsightedness":{"nearsightedness","nearsightednesses"},
"neat":{"neat","neater","neatest"},
"neaten":{"neaten","neatened","neatening","neatens"},
"neatness":{"neatness","neatnesses"},
"neb":{"neb","nebs"},
"nebe":{"nebe","nebes"},
"nebn":{"nebn","nebns"},
"nebo":{"nebo","nebos"},
"nebraska":{"nebraska","nebraskas"},
"nebraskan":{"nebraskan","nebraskans"},
"nebula":{"nebula","nebulae","nebulas"},
"nebulize":{"nebulize","nebulized","nebulizing"},
"nebulosity":{"nebulosities","nebulosity"},
"necessary":{"necessaries","necessary"},
"necessitate":{"necessitate","necessitated","necessitates","necessitating"},
"necessity":{"necessities","necessity"},
"neck":{"neck","necked","necking","necks"},
"neck-rein":{"neck-rein","neck-reined","neck-reining"},
"neckar":{"neckar","neckars"},
"neckband":{"neckband","neckbands"},
"neckcloth":{"neckcloth","neckcloths"},
"necking":{"necking","neckings"},
"necklace":{"necklace","necklaces"},
"necktie":{"necktie","neckties"},
"necrology":{"necrologies","necrology"},
"necromancer":{"necromancer","necromancers"},
"necromania":{"necromania","necromanias"},
"necrophagia":{"necrophagia","necrophagias"},
"necrophagy":{"necrophagies","necrophagy"},
"necrophilia":{"necrophilia","necrophilias"},
"necrophilism":{"necrophilism","necrophilisms"},
"necropolis":{"necropoleis","necropoli","necropolis","necropolises"},
"necropsy":{"necropsies","necropsy"},
"necroscopy":{"necroscopies","necroscopy"},
"necrose":{"necrose","necrosed","necroses","necrosing"},
"necrosis":{"necroses","necrosis"},
"necrotomy":{"necrotomies","necrotomy"},
"nectar":{"nectar","nectars"},
"nectarine":{"nectarine","nectarines"},
"nectary":{"nectaries","nectary"},
"necturus":{"necturus","necturuses"},
"neddy":{"neddies","neddy"},
"need":{"need","needed","needing","needs"},
"needle":{"needle","needled","needles","needling"},
"needlebush":{"needlebush","needlebushes"},
"needlecraft":{"needlecraft","needlecrafts"},
"needlefish":{"needlefish","needlefishes"},
"needlepoint":{"needlepoint","needlepoints"},
"needlewoman":{"needlewoman","needlewomen"},
"needlewood":{"needlewood","needlewoods"},
"needlework":{"needlework","needleworks"},
"needy":{"needier","neediest","needy"},
"neem":{"neem","neems"},
"neencephalon":{"neencephalon","neencephalons"},
"nefariousness":{"nefariousness","nefariousnesses"},
"negaprion":{"negaprion","negaprions"},
"negate":{"negate","negated","negates","negating"},
"negating":{"negating","negatings"},
"negation":{"negation","negations"},
"negative":{"negative","negatived","negatives","negativing"},
"negativism":{"negativism","negativisms"},
"negativist":{"negativist","negativists"},
"negativity":{"negativities","negativity"},
"negev":{"negev","negevs"},
"neglect":{"neglect","neglected","neglecting","neglects"},
"neglectfulness":{"neglectfulness","neglectfulnesses"},
"neglige":{"neglige","negliges"},
"negligee":{"negligee","negligees"},
"negligence":{"negligence","negligences"},
"negotiant":{"negotiant","negotiants"},
"negotiate":{"negotiate","negotiated","negotiates","negotiating"},
"negotiation":{"negotiation","negotiations"},
"negotiator":{"negotiator","negotiators"},
"negotiatress":{"negotiatress","negotiatresses"},
"negotiatrix":{"negotiatrix","negotiatrixes"},
"negrillo":{"negrillo","negrilloes","negrillos"},
"negrito":{"negrito","negritoes","negritos"},
"negro":{"negro","negroes"},
"negroid":{"negroid","negroids"},
"negus":{"negus","neguses"},
"nehru":{"nehru","nehrus"},
"neigh":{"neigh","neighed","neighing","neighs"},
"neighbor":{"neighbor","neighbored","neighboring","neighbors"},
"neighborhood":{"neighborhood","neighborhoods"},
"neighborliness":{"neighborliness","neighborlinesses"},
"neighbour":{"neighbour","neighboured","neighbouring","neighbours"},
"neighbourhood":{"neighbourhood","neighbourhoods"},
"neighbourliness":{"neighbourliness","neighbourlinesses"},
"nelumbo":{"nelumbo","nelumbos"},
"nelumbonaceae":{"nelumbonaceae","nelumbonaceaes"},
"nematocera":{"nematocera","nematoceras"},
"nematoda":{"nematoda","nematodas"},
"nematode":{"nematode","nematodes"},
"nembutal":{"nembutal","nembutals"},
"nemertea":{"nemertea","nemerteas"},
"nemertean":{"nemertean","nemerteans"},
"nemertina":{"nemertina","nemertinas"},
"nemertine":{"nemertine","nemertines"},
"nemesis":{"nemeses","nemesis"},
"nenets":{"nenets","nenetses"},
"nentsi":{"nentsi","nentsis"},
"nentsy":{"nentsies","nentsy"},
"neo-latin":{"neo-latin","neo-latins"},
"neo-nazi":{"neo-nazi","neo-nazis"},
"neoceratodus":{"neoceratodus","neoceratoduses"},
"neocortex":{"neocortex","neocortexes"},
"neodymium":{"neodymium","neodymiums"},
"neoencephalon":{"neoencephalon","neoencephalons"},
"neofiber":{"neofiber","neofibers"},
"neohygrophorus":{"neohygrophorus","neohygrophoruses"},
"neolentinus":{"neolentinus","neolentinuses"},
"neologism":{"neologism","neologisms"},
"neologize":{"neologize","neologized","neologizing"},
"neology":{"neologies","neology"},
"neomycin":{"neomycin","neomycins"},
"neomys":{"neomys","neomyses"},
"neon":{"neon","neons"},
"neonate":{"neonate","neonates"},
"neopallium":{"neopallium","neopalliums"},
"neophron":{"neophron","neophrons"},
"neophyte":{"neophyte","neophytes"},
"neoplasm":{"neoplasm","neoplasms"},
"neosho":{"neosho","neoshos"},
"neotoma":{"neotoma","neotomas"},
"nepa":{"nepa","nepas"},
"nepalese":{"nepalese","nepaleses"},
"nepali":{"nepali","nepalis"},
"nepenthaceae":{"nepenthaceae","nepenthaceaes"},
"nepenthes":{"nepenthes","nepentheses"},
"nepeta":{"nepeta","nepetas"},
"nephelium":{"nephelium","nepheliums"},
"nephew":{"nephew","nephews"},
"nephrectomy":{"nephrectomies","nephrectomy"},
"nephridium":{"nephridia","nephridiia","nephridium"},
"nephritis":{"nephritis","nephritises"},
"nephrolepis":{"nephrolepis","nephrolepises"},
"nephrolith":{"nephrolith","nephroliths"},
"nephron":{"nephron","nephrons"},
"nephrops":{"nephrops","nephropses"},
"nephropsidae":{"nephropsidae","nephropsidaes"},
"nephrotomy":{"nephrotomies","nephrotomy"},
"nepidae":{"nepidae","nepidaes"},
"neptunium":{"neptunium","neptuniums"},
"nerd":{"nerd","nerds"},
"nereid":{"nereid","nereids"},
"neritid":{"neritid","neritids"},
"neritidae":{"neritidae","neritidaes"},
"nerium":{"nerium","neriums"},
"nerodia":{"nerodia","nerodias"},
"nerthus":{"nerthus","nerthuses"},
"nerve":{"nerve","nerved","nerves","nerving"},
"nervelessness":{"nervelessness","nervelessnesses"},
"nerveroot":{"nerveroot","nerveroots"},
"nerves":{"nerves","nerveses"},
"nervousness":{"nervousness","nervousnesses"},
"nervure":{"nervure","nervures"},
"nervus":{"nervus","nervuses"},
"nervy":{"nervier","nerviest","nervy"},
"nescience":{"nescience","nesciences"},
"nesokia":{"nesokia","nesokias"},
"ness":{"ness","nesses"},
"nessie":{"nessie","nessies"},
"nest":{"nest","nested","nesting","nests"},
"nester":{"nester","nesters"},
"nestle":{"nestle","nestled","nestles","nestling"},
"nestling":{"nestling","nestlings"},
"nestor":{"nestor","nestors"},
"net":{"net","nets","netted","netting"},
"netherlander":{"netherlander","netherlanders"},
"netherlands":{"netherlands","netherlandses"},
"netherworld":{"netherworld","netherworlds"},
"netkeeper":{"netkeeper","netkeepers"},
"netsuke":{"netsuke","netsukes"},
"netting":{"netting","nettings"},
"nettle":{"nettle","nettled","nettles","nettling"},
"netty":{"netties","netty"},
"network":{"network","networked","networking","networks"},
"neuralgia":{"neuralgia","neuralgias"},
"neuralgy":{"neuralgies","neuralgy"},
"neurectomy":{"neurectomies","neurectomy"},
"neurilemma":{"neurilemma","neurilemmas"},
"neuroanatomy":{"neuroanatomies","neuroanatomy"},
"neurofibroma":{"neurofibroma","neurofibromas","neurofibromata"},
"neuroglia":{"neuroglia","neuroglias"},
"neurogliacyte":{"neurogliacyte","neurogliacytes"},
"neurohypophysis":{"neurohypophyses","neurohypophysis"},
"neurologist":{"neurologist","neurologists"},
"neurology":{"neurologies","neurology"},
"neuroma":{"neuroma","neuromas","neuromata"},
"neuron":{"neuron","neurons"},
"neuropsychology":{"neuropsychologies","neuropsychology"},
"neuroptera":{"neuroptera","neuropteras"},
"neuropteran":{"neuropteran","neuropterans"},
"neuropteron":{"neuropteron","neuropterons"},
"neurosarcoma":{"neurosarcoma","neurosarcomas"},
"neurosis":{"neuroses","neurosis"},
"neurospora":{"neurospora","neurosporas"},
"neurosurgeon":{"neurosurgeon","neurosurgeons"},
"neurotic":{"neurotic","neurotics"},
"neuroticism":{"neuroticism","neuroticisms"},
"neurotomy":{"neurotomies","neurotomy"},
"neurotrichus":{"neurotrichus","neurotrichuses"},
"neurula":{"neurula","neurulae","neurulas"},
"neutering":{"neutering","neuterings"},
"neutral":{"neutral","neutrals"},
"neutralisation":{"neutralisation","neutralisations"},
"neutrality":{"neutralities","neutrality"},
"neutralization":{"neutralization","neutralizations"},
"neutralize":{"neutralize","neutralized","neutralizes","neutralizing"},
"neutretto":{"neutretto","neutrettos"},
"neutrino":{"neutrino","neutrinos"},
"nevada":{"nevada","nevadas"},
"neve":{"neve","neves"},
"nevus":{"nevi","nevus","nevuses"},
"new":{"new","newer","newest"},
"newborn":{"newborn","newborns"},
"newcastle":{"newcastle","newcastles"},
"newcastle-upon-tyne":{"newcastle-upon-tyne","newcastle-upon-tynes"},
"newcomer":{"newcomer","newcomers"},
"newel":{"newel","newels"},
"newlywed":{"newlywed","newlyweds"},
"newmarket":{"newmarket","newmarkets"},
"news":{"news","newses"},
"newsagent":{"newsagent","newsagents"},
"newsboy":{"newsboy","newsboys"},
"newsdealer":{"newsdealer","newsdealers"},
"newsflash":{"newsflash","newsflashes"},
"newsletter":{"newsletter","newsletters"},
"newsman":{"newsman","newsmen"},
"newsmonger":{"newsmonger","newsmongers"},
"newspaper":{"newspaper","newspapered","newspapering","newspapers"},
"newspaperman":{"newspaperman","newspapermen"},
"newspaperwoman":{"newspaperwoman","newspaperwomen"},
"newsperson":{"newsperson","newspersons"},
"newsprint":{"newsprint","newsprints"},
"newssheet":{"newssheet","newssheets"},
"newsvendor":{"newsvendor","newsvendors"},
"newsworthiness":{"newsworthiness","newsworthinesses"},
"newswriter":{"newswriter","newswriters"},
"newsy":{"newsier","newsies","newsiest","newsy"},
"newt":{"newt","newts"},
"newton":{"newton","newtons"},
"nexus":{"nexus","nexuses"},
"ni":{"ni","nis"},
"ni-hard":{"ni-hard","ni-hards"},
"ni-resist":{"ni-resist","ni-resists"},
"niacin":{"niacin","niacins"},
"niagara":{"niagara","niagaras"},
"niamey":{"niamey","niameys"},
"nib":{"nib","nibs"},
"nibble":{"nibble","nibbled","nibbles","nibbling"},
"nibbling":{"nibbling","nibblings"},
"nibelung":{"nibelung","nibelungen","nibelungs"},
"niblick":{"niblick","niblicks"},
"nicad":{"nicad","nicads"},
"nicandra":{"nicandra","nicandras"},
"nice":{"nice","nicer","nicest"},
"niceness":{"niceness","nicenesses"},
"nicety":{"niceties","nicety"},
"niche":{"niche","niched","niches","niching"},
"nick":{"nick","nicked","nicking","nicks"},
"nickel":{"nickel","nickeled","nickeling","nickelled","nickelling","nickels"},
"nickelodeon":{"nickelodeon","nickelodeons"},
"nicker":{"nicker","nickered","nickering","nickers"},
"nicknack":{"nicknack","nicknacks"},
"nickname":{"nickname","nicknamed","nicknames","nicknaming"},
"nicosia":{"nicosia","nicosias"},
"nicotiana":{"nicotiana","nicotianas"},
"nictitate":{"nictitate","nictitated","nictitates","nictitating"},
"nid-nod":{"nid-nod","nid-nodded","nid-nodding","nid-nods"},
"nidaros":{"nidaros","nidaroses"},
"nidify":{"nidified","nidifies","nidify","nidifying"},
"nidularia":{"nidularia","nidularias"},
"nidulariaceae":{"nidulariaceae","nidulariaceaes"},
"nidulariales":{"nidulariales","nidularialeses"},
"nidus":{"nidi","nidus","niduses"},
"niece":{"niece","nieces"},
"niello":{"nielli","niello","nielloed","nielloing","niellos"},
"nierembergia":{"nierembergia","nierembergias"},
"nifty":{"niftier","nifties","niftiest","nifty"},
"niger":{"niger","nigers"},
"niger-kordofanian":{"niger-kordofanian","niger-kordofanians"},
"niggard":{"niggard","niggards"},
"niggardliness":{"niggardliness","niggardlinesses"},
"niggardness":{"niggardness","niggardnesses"},
"nigger":{"nigger","niggers"},
"niggle":{"niggle","niggled","niggles","niggling"},
"nigh":{"nigh","nigher","nighest"},
"night":{"night","nights"},
"night-robe":{"night-robe","night-robes"},
"night-sight":{"night-sight","night-sights"},
"nightbird":{"nightbird","nightbirds"},
"nightcap":{"nightcap","nightcaps"},
"nightclothes":{"nightclothes","nightclotheses"},
"nightclub":{"nightclub","nightclubbed","nightclubbing","nightclubs"},
"nightcrawler":{"nightcrawler","nightcrawlers"},
"nightdress":{"nightdress","nightdresses"},
"nightfall":{"nightfall","nightfalls"},
"nightgown":{"nightgown","nightgowns"},
"nighthawk":{"nighthawk","nighthawks"},
"nightie":{"nightie","nighties"},
"nightingale":{"nightingale","nightingales"},
"nightjar":{"nightjar","nightjars"},
"nightmare":{"nightmare","nightmares"},
"nightrider":{"nightrider","nightriders"},
"nightstick":{"nightstick","nightsticks"},
"nighttime":{"nighttime","nighttimes"},
"nightwalker":{"nightwalker","nightwalkers"},
"nightwear":{"nightwear","nightwears"},
"nighty":{"nighties","nighty"},
"nigra":{"nigra","nigras"},
"nigrify":{"nigrified","nigrifies","nigrify","nigrifying"},
"nigroporus":{"nigroporus","nigroporuses"},
"nihau":{"nihau","nihaus"},
"nihil":{"nihil","nihils"},
"nihilist":{"nihilist","nihilists"},
"nihon":{"nihon","nihons"},
"nil":{"nil","nils"},
"nile":{"nile","niles"},
"nilgai":{"nilgai","nilgais"},
"nilghau":{"ghaus","nilghau","nilghaus"},
"nill":{"nill","nilled","nilling"},
"nilo-saharan":{"nilo-saharan","nilo-saharans"},
"nilotic":{"nilotic","nilotics"},
"nim":{"nim","nimmed","nimming"},
"nimble":{"nimble","nimbler","nimblest"},
"nimbleness":{"nimbleness","nimblenesses"},
"nimblewill":{"nimblewill","nimblewills"},
"nimbostratus":{"nimbostrati","nimbostratus"},
"nimbus":{"nimbi","nimbus","nimbuses"},
"nimiety":{"nimieties","nimiety"},
"nimravus":{"nimravus","nimravuses"},
"nin-sin":{"nin-sin","nin-sins"},
"nincompoop":{"nincompoop","nincompoops"},
"nine":{"nine","nines"},
"ninepin":{"ninepin","ninepins"},
"ninepins":{"ninepins","ninepinses"},
"niner":{"niner","niners"},
"nineteen":{"nineteen","nineteens"},
"nineteenth":{"nineteenth","nineteenths"},
"nineties":{"nineties","ninetieses"},
"ninety":{"nineties","ninety"},
"ninhursag":{"ninhursag","ninhursags"},
"ninib":{"ninib","ninibs"},
"ninigi":{"ninigi","ninigis"},
"ninigino-mikoto":{"ninigino-mikoto","ninigino-mikotos"},
"ninkharsag":{"ninkharsag","ninkharsags"},
"ninkhursag":{"ninkhursag","ninkhursags"},
"ninny":{"ninnies","ninny"},
"ninth":{"ninth","ninths"},
"nintoo":{"nintoo","nintoos"},
"nintu":{"nintu","nintus"},
"ninurta":{"ninurta","ninurtas"},
"niobite":{"niobite","niobites"},
"niobium":{"niobium","niobiums"},
"niobrara":{"niobrara","niobraras"},
"nip":{"nip","nipped","nipping","nips"},
"nipa":{"nipa","nipas"},
"nipper":{"nipper","nippers"},
"nipple":{"nipple","nipples"},
"nippon":{"nippon","nippons"},
"nipponese":{"nipponese","nipponeses"},
"nippy":{"nippier","nippiest","nippy"},
"nirvana":{"nirvana","nirvanas"},
"nisan":{"nisan","nisans"},
"nissan":{"nissan","nissans"},
"nisus":{"nisus","nisuses"},
"nit-pick":{"nit-pick","nit-picked","nit-picking"},
"nitella":{"nitella","nitellas"},
"niter":{"niter","niters"},
"nitrate":{"nitrate","nitrated","nitrates","nitrating"},
"nitre":{"nitre","nitres"},
"nitrify":{"nitrified","nitrifies","nitrify","nitrifying"},
"nitrile":{"nitrile","nitriles"},
"nitrobacter":{"nitrobacter","nitrobacters"},
"nitrobacteria":{"nitrobacteria","nitrobacterias"},
"nitrobacteriaceae":{"nitrobacteriaceae","nitrobacteriaceaes"},
"nitrocellulose":{"nitrocellulose","nitrocelluloses"},
"nitrocotton":{"nitrocotton","nitrocottons"},
"nitrofurantoin":{"nitrofurantoin","nitrofurantoins"},
"nitrogen":{"nitrogen","nitrogens"},
"nitroglycerin":{"nitroglycerin","nitroglycerins"},
"nitroglycerine":{"nitroglycerine","nitroglycerines"},
"nitrosobacteria":{"nitrosobacteria","nitrosobacterias"},
"nitrosomonas":{"nitrosomonas","nitrosomonases"},
"nitrospan":{"nitrospan","nitrospans"},
"nitrostat":{"nitrostat","nitrostats"},
"nitty":{"nittier","nittiest","nitty"},
"nitty-gritty":{"nitty-gritties","nitty-gritty"},
"nitweed":{"nitweed","nitweeds"},
"nitwit":{"nitwit","nitwits"},
"nix":{"nix","nixes"},
"nixon":{"nixon","nixons"},
"njord":{"njord","njords"},
"njorth":{"njorth","njorths"},
"nne":{"nne","nnes"},
"nnw":{"nnw","nnws"},
"no":{"no","noes"},
"no-hitter":{"no-hitter","no-hitters"},
"no-no":{"no-no","no-nos"},
"no-see-um":{"no-see-um","no-see-ums"},
"no-show":{"no-show","no-shows"},
"no.":{"no.","nos"},
"nob":{"nob","nobs"},
"nobble":{"nobble","nobbled","nobbles","nobbling"},
"nobby":{"nobbier","nobbiest","nobby"},
"nobelist":{"nobelist","nobelists"},
"nobelium":{"nobelium","nobeliums"},
"nobility":{"nobilities","nobility"},
"noble":{"noble","nobler","nobles","noblest"},
"noble-mindedness":{"noble-mindedness","noble-mindednesses"},
"nobleman":{"nobleman","noblemen"},
"noblesse":{"noblesse","noblesses"},
"noblewoman":{"noblewoman","noblewomen"},
"nobody":{"nobodies","nobody"},
"nock":{"nock","nocked","nocking","nocks"},
"noctambulism":{"noctambulism","noctambulisms"},
"noctambulist":{"noctambulist","noctambulists"},
"noctiluca":{"noctiluca","noctilucas"},
"noctua":{"noctua","noctuas"},
"noctuid":{"noctuid","noctuids"},
"noctuidae":{"noctuidae","noctuidaes"},
"nod":{"nod","nodded","nodding","nods"},
"noddy":{"noddies","noddy"},
"node":{"node","nodes"},
"nodule":{"nodule","nodules"},
"nodus":{"nodi","nodus"},
"noel":{"noel","noels"},
"noemi":{"noemi","noemis"},
"nog":{"nog","nogs"},
"noggin":{"noggin","noggins"},
"noise":{"noise","noised","noises","noising"},
"noisette":{"noisette","noisettes"},
"noisiness":{"noisiness","noisinesses"},
"noisomeness":{"noisomeness","noisomenesses"},
"noisy":{"noisier","noisiest","noisy"},
"nolina":{"nolina","nolinas"},
"noma":{"noma","nomas"},
"nomad":{"nomad","nomads"},
"nomarchy":{"nomarchies","nomarchy"},
"nomen":{"nomen","nomina"},
"nomenclature":{"nomenclature","nomenclatures"},
"nomia":{"nomia","nomias"},
"nominal":{"nominal","nominals"},
"nominalize":{"nominalize","nominalized","nominalizing"},
"nominate":{"nominate","nominated","nominates","nominating"},
"nominating":{"nominating","nominatings"},
"nomination":{"nomination","nominations"},
"nominative":{"nominative","nominatives"},
"nominee":{"nominee","nominees"},
"nomocracy":{"nomocracries","nomocracy"},
"nomogram":{"nomogram","nomograms"},
"nomograph":{"nomograph","nomographs"},
"nomography":{"nomographies","nomography"},
"non-engagement":{"non-engagement","non-engagements"},
"non-involvement":{"non-involvement","non-involvements"},
"non-issue":{"non-issue","non-issues"},
"non-jew":{"non-jew","non-jews"},
"non-pros":{"non-pros","non-prossed","non-prosses","non-prossing"},
"non-resistant":{"non-resistant","non-resistants"},
"non-ugric":{"non-ugric","non-ugrics"},
"nonacceptance":{"nonacceptance","nonacceptances"},
"nonaccomplishment":{"nonaccomplishment","nonaccomplishments"},
"nonachievement":{"nonachievement","nonachievements"},
"nonage":{"nonage","nonages"},
"nonalignment":{"nonalignment","nonalignments"},
"nonalinement":{"nonalinement","nonalinements"},
"nonary":{"nonaries","nonary"},
"nonattender":{"nonattender","nonattenders"},
"nonbelieiver":{"nonbelieiver","nonbelieivers"},
"nonce":{"nonce","nonces"},
"nonchalance":{"nonchalance","nonchalances"},
"noncitizen":{"noncitizen","noncitizens"},
"noncom":{"noncom","noncoms"},
"noncompliance":{"noncompliance","noncompliances"},
"nonconductor":{"nonconductor","nonconductors"},
"nonconformance":{"nonconformance","nonconformances"},
"nonconformist":{"nonconformist","nonconformists"},
"nonconformity":{"nonconformities","nonconformity"},
"nondescript":{"nondescript","nondescripts"},
"nonentity":{"nonentities","nonentity"},
"nonessential":{"nonessential","nonessentials"},
"nonesuch":{"nonesuch","nonesuches"},
"nonfiction":{"nonfiction","nonfictions"},
"nonindulgence":{"nonindulgence","nonindulgences"},
"noninterference":{"noninterference","noninterferences"},
"nonintervention":{"nonintervention","noninterventions"},
"nonpareil":{"nonpareil","nonpareils"},
"nonparticipation":{"nonparticipation","nonparticipations"},
"nonpartisanship":{"nonpartisanship","nonpartisanships"},
"nonpayment":{"nonpayment","nonpayments"},
"nonperformance":{"nonperformance","nonperformances"},
"nonplus":{"nonplus","nonplused","nonpluses","nonplusing","nonplussed","nonplusses","nonplussing"},
"nonpros":{"nonpros","nonprossed","nonprossing"},
"nonremittal":{"nonremittal","nonremittals"},
"nonsense":{"nonsense","nonsenses"},
"nonsensicality":{"nonsensicalities","nonsensicality"},
"nonsmoker":{"nonsmoker","nonsmokers"},
"nonstarter":{"nonstarter","nonstarters"},
"nonstop":{"nonstop","nonstops"},
"nonsuch":{"nonsuch","nonsuches"},
"nonsuit":{"nonsuit","nonsuited","nonsuiting"},
"nonviolence":{"nonviolence","nonviolences"},
"noodle":{"noodle","noodles"},
"nook":{"nook","nooks"},
"nooky":{"nookies","nooky"},
"noon":{"noon","noons"},
"noonday":{"noonday","noondays"},
"noontide":{"noontide","noontides"},
"noose":{"noose","noosed","nooses","noosing"},
"nopal":{"nopal","nopals"},
"nopalea":{"nopalea","nopaleas"},
"noradrenaline":{"noradrenaline","noradrenalines"},
"nordic":{"nordic","nordics"},
"noreaster":{"noreaster","noreasters"},
"noreg":{"noreg","noregs"},
"norepinephrine":{"norepinephrine","norepinephrines"},
"norethandrolone":{"norethandrolone","norethandrolones"},
"norethindrone":{"norethindrone","norethindrones"},
"norge":{"norge","norges"},
"noria":{"noria","norias"},
"norm":{"norm","norms"},
"normal":{"normal","normals"},
"normalcy":{"normalcies","normalcy"},
"normalisation":{"normalisation","normalisations"},
"normality":{"normalities","normality"},
"normalization":{"normalization","normalizations"},
"normalize":{"normalize","normalized","normalizes","normalizing"},
"norman-french":{"norman-french","norman-frenches"},
"normandie":{"normandie","normandies"},
"normandy":{"normandies","normandy"},
"normanize":{"normanize","normanized","normanizing"},
"norse":{"norse","norses"},
"norseman":{"norseman","norsemen"},
"north":{"north","norths"},
"northcountryman":{"northcountryman","northcountrymen"},
"northeast":{"northeast","northeasts"},
"northeaster":{"northeaster","northeasters"},
"northeasterly":{"northeasterlies","northeasterly"},
"norther":{"norther","northers"},
"northerly":{"northerlies","northerly"},
"northerner":{"northerner","northerners"},
"northland":{"northland","northlands"},
"northman":{"northman","northmen"},
"northwest":{"northwest","northwests"},
"northwester":{"northwester","northwesters"},
"northwesterly":{"northwesterlies","northwesterly"},
"norway":{"norway","norways"},
"norwegian":{"norwegian","norwegians"},
"nose":{"nose","nosed","noses","nosing"},
"nosebag":{"nosebag","nosebags"},
"nosebleed":{"nosebleed","nosebleeds"},
"nosecount":{"nosecount","nosecounts"},
"nosegay":{"nosegay","nosegays"},
"nosepiece":{"nosepiece","nosepieces"},
"nosey-parker":{"nosey-parker","nosey-parkers"},
"nosh":{"nosh","noshes"},
"nosiness":{"nosiness","nosinesses"},
"nosology":{"nosologies","nosology"},
"nostocaceae":{"nostocaceae","nostocaceaes"},
"nostril":{"nostril","nostrils"},
"nostrils":{"nostrils","nostrilses"},
"nostrum":{"nostrum","nostrums"},
"nosy":{"nosier","nosiest","nosy"},
"nosy-parker":{"nosy-parker","nosy-parkers"},
"notability":{"notabilities","notability"},
"notable":{"notable","notables"},
"notarize":{"notarize","notarized","notarizing"},
"notary":{"notaries","notary"},
"notate":{"notate","notated","notating"},
"notation":{"notation","notations"},
"notch":{"notch","notched","notches","notching"},
"note":{"note","noted","notes","noting"},
"notebook":{"notebook","notebooks"},
"notecase":{"notecase","notecases"},
"notechis":{"notechis","notechises"},
"notemigonus":{"notemigonus","notemigonuses"},
"notepaper":{"notepaper","notepapers"},
"nothing":{"nothing","nothings"},
"nothingness":{"nothingness","nothingnesses"},
"nothofagus":{"nothofagus","nothofaguses"},
"nothosauria":{"nothosauria","nothosaurias"},
"notice":{"notice","noticed","notices","noticing"},
"noticeability":{"noticeabilities","noticeability"},
"noticeableness":{"noticeableness","noticeablenesses"},
"notification":{"notification","notifications"},
"notify":{"notified","notifies","notify","notifying"},
"notifying":{"notifying","notifyings"},
"notion":{"notion","notions"},
"notions":{"notions","notionses"},
"notomys":{"notomys","notomyses"},
"notonecta":{"notonecta","notonectas"},
"notonectidae":{"notonectidae","notonectidaes"},
"notophthalmus":{"notophthalmus","notophthalmuses"},
"notoriety":{"notorieties","notoriety"},
"notornis":{"notornis","notornises"},
"notoryctidae":{"notoryctidae","notoryctidaes"},
"notoryctus":{"notoryctus","notoryctuses"},
"notostraca":{"notostraca","notostracas"},
"notropis":{"notropis","notropises"},
"notum":{"nota","notum"},
"nought":{"nought","noughts"},
"noumenon":{"noumena","noumenon","noumenons"},
"noun":{"noun","nouns"},
"nourish":{"nourish","nourished","nourishes","nourishing"},
"nourishing":{"nourishing","nourishings"},
"nourishment":{"nourishment","nourishments"},
"nous":{"nous","nouses"},
"nouveau-riche":{"nouveau-riche","nouveau-riches"},
"nov":{"nov","novs"},
"nova":{"nova","novae","novas"},
"novel":{"novel","novels"},
"novelette":{"novelette","novelettes"},
"novelisation":{"novelisation","novelisations"},
"novelist":{"novelist","novelists"},
"novelization":{"novelization","novelizations"},
"novelize":{"novelize","novelized","novelizing"},
"novella":{"novella","novellas","novelle"},
"novelties":{"novelties","noveltieses"},
"novelty":{"novelties","novelty"},
"november":{"november","novembers"},
"novemdecillion":{"novemdecillion","novemdecillions"},
"novena":{"novena","novenae","novenas"},
"novice":{"novice","novices"},
"noviciate":{"noviciate","noviciates"},
"novitiate":{"novitiate","novitiates"},
"novocain":{"novocain","novocains"},
"novocaine":{"novocaine","novocaines"},
"nowadays":{"nowadays","nowadayses"},
"nowness":{"nowness","nownesses"},
"nox":{"nox","noxes"},
"noxiousness":{"noxiousness","noxiousnesses"},
"nozzle":{"nozzle","nozzles"},
"np":{"np","nps"},
"nsaid":{"nsaid","nsaids"},
"nuance":{"nuance","nuances"},
"nub":{"nub","nubs"},
"nuba":{"nuba","nubas"},
"nubbiness":{"nubbiness","nubbinesses"},
"nubby":{"nubbier","nubbiest","nubby"},
"nubecula":{"nubecula","nubeculae"},
"nucellus":{"nucelli","nucellus"},
"nucha":{"nucha","nuchae"},
"nucifraga":{"nucifraga","nucifragas"},
"nuclearize":{"nuclearize","nuclearized","nuclearizing"},
"nucleole":{"nucleole","nucleoles"},
"nucleolus":{"nucleoli","nucleolus","nucleoluses"},
"nucleoplasm":{"nucleoplasm","nucleoplasms"},
"nucleus":{"nuclei","nucleus","nucleuses"},
"nuda":{"nuda","nudas"},
"nude":{"nude","nuder","nudes","nudest"},
"nudeness":{"nudeness","nudenesses"},
"nudge":{"nudge","nudged","nudges","nudging"},
"nudibranch":{"nudibranch","nudibranches"},
"nudibranchia":{"nudibranchia","nudibranchias"},
"nudism":{"nudism","nudisms"},
"nudist":{"nudist","nudists"},
"nudity":{"nudities","nudity"},
"nuernberg":{"nuernberg","nuernbergs"},
"nugget":{"nugget","nuggets"},
"nuisance":{"nuisance","nuisances"},
"nuke":{"nuke","nuked","nukes","nuking"},
"nullify":{"nullified","nullifies","nullify","nullifying"},
"nullipara":{"nullipara","nulliparae"},
"nullity":{"nullities","nullity"},
"numb":{"numb","numbed","numbing","numbs"},
"numbat":{"numbat","numbats"},
"number":{"number","numbered","numbering","numbers"},
"numbering":{"numbering","numberings"},
"numberplate":{"numberplate","numberplates"},
"numbers":{"numbers","numberses"},
"numbfish":{"numbfish","numbfishes"},
"numdah":{"numdah","numdahs"},
"numen":{"numen","numina"},
"numenius":{"numenius","numeniuses"},
"numeral":{"numeral","numerals"},
"numerate":{"numerate","numerated","numerating"},
"numeration":{"numeration","numerations"},
"numerosity":{"numerosities","numerosity"},
"numerousness":{"numerousness","numerousnesses"},
"numida":{"numida","numidas"},
"numididae":{"numididae","numididaes"},
"numidinae":{"numidinae","numidinaes"},
"numismatics":{"numismatics","numismaticses"},
"numismatist":{"numismatist","numismatists"},
"numismatologist":{"numismatologist","numismatologists"},
"numismatology":{"numismatologies","numismatology"},
"nummulitidae":{"nummulitidae","nummulitidaes"},
"numskull":{"numskull","numskulls"},
"nun":{"nun","nuns"},
"nuncio":{"nuncio","nuncios"},
"nunnery":{"nunneries","nunnery"},
"nupe":{"nupe","nupes"},
"nuphar":{"nuphar","nuphars"},
"nuprin":{"nuprin","nuprins"},
"nuptial":{"nuptial","nuptials"},
"nuptials":{"nuptials","nuptialses"},
"nuremburg":{"nuremburg","nuremburgs"},
"nuri":{"nuri","nuris"},
"nurnberg":{"nurnberg","nurnbergs"},
"nurse":{"nurse","nursed","nurses","nursing"},
"nurseling":{"nurseling","nurselings"},
"nursemaid":{"nursemaid","nursemaids"},
"nursery":{"nurseries","nursery"},
"nurseryman":{"nurseryman","nurserymen"},
"nursling":{"nursling","nurslings"},
"nurture":{"nurture","nurtured","nurtures","nurturing"},
"nurturing":{"nurturing","nurturings"},
"nut":{"nut","nuts","nutted","nutting"},
"nutate":{"nutate","nutated","nutating"},
"nutation":{"nutation","nutations"},
"nutcase":{"nutcase","nutcases"},
"nutcracker":{"nutcracker","nutcrackers"},
"nutcrackers":{"nutcrackers","nutcrackerses"},
"nutgrass":{"nutgrass","nutgrasses"},
"nuthatch":{"nuthatch","nuthatches"},
"nuthouse":{"nuthouse","nuthouses"},
"nutmeg":{"nutmeg","nutmegs"},
"nutmeg-yew":{"nutmeg-yew","nutmeg-yews"},
"nutria":{"nutria","nutrias"},
"nutrient":{"nutrient","nutrients"},
"nutriment":{"nutriment","nutriments"},
"nutritionist":{"nutritionist","nutritionists"},
"nutritiousness":{"nutritiousness","nutritiousnesses"},
"nutritiveness":{"nutritiveness","nutritivenesses"},
"nutsedge":{"nutsedge","nutsedges"},
"nutshell":{"nutshell","nutshells"},
"nutty":{"nuttier","nuttiest","nutty"},
"nuytsia":{"nuytsia","nuytsias"},
"nuzzle":{"nuzzle","nuzzled","nuzzles","nuzzling"},
"nw":{"nw","nws"},
"nwbn":{"nwbn","nwbns"},
"nwbw":{"nwbw","nwbws"},
"nyala":{"nyala","nyalas"},
"nyanja":{"nyanja","nyanjas"},
"nyasaland":{"nyasaland","nyasalands"},
"nybble":{"nybble","nybbles"},
"nyctaginaceae":{"nyctaginaceae","nyctaginaceaes"},
"nyctaginia":{"nyctaginia","nyctaginias"},
"nyctalopia":{"nyctalopia","nyctalopias"},
"nyctanassa":{"nyctanassa","nyctanassas"},
"nyctereutes":{"nyctereutes","nyctereuteses"},
"nycticebus":{"nycticebus","nycticebuses"},
"nycticorax":{"nycticorax","nycticoraxes"},
"nyctimene":{"nyctimene","nyctimenes"},
"nylghai":{"nylghai","nylghais"},
"nylghau":{"nylghau","nylghaus"},
"nylon":{"nylon","nylons"},
"nylons":{"nylons","nylonses"},
"nymph":{"nymph","nymphs"},
"nympha":{"nympha","nymphae"},
"nymphaea":{"nymphaea","nymphaeas"},
"nymphaeaceae":{"nymphaeaceae","nymphaeaceaes"},
"nymphalid":{"nymphalid","nymphalids"},
"nymphalidae":{"nymphalidae","nymphalidaes"},
"nymphalis":{"nymphalis","nymphalises"},
"nymphicus":{"nymphicus","nymphicuses"},
"nympho":{"nympho","nymphos"},
"nympholepsy":{"nympholepsies","nympholepsy"},
"nymphomaniac":{"nymphomaniac","nymphomaniacs"},
"nynorsk":{"nynorsk","nynorsks"},
"nyoro":{"nyoro","nyoros"},
"nypa":{"nypa","nypas"},
"nyssa":{"nyssa","nyssas"},
"nyssaceae":{"nyssaceae","nyssaceaes"},
"nystatin":{"nystatin","nystatins"},
"o":{"o","oes","os"},
"oaf":{"oaf","oafs"},
"oahu":{"oahu","oahus"},
"oak":{"oak","oaks"},
"oar":{"oar","oared","oaring","oars"},
"oarfish":{"oarfish","oarfishes"},
"oarlock":{"oarlock","oarlocks"},
"oarsman":{"oarsman","oarsmen"},
"oas":{"oas","oases"},
"oasis":{"oases","oasis"},
"oat":{"oat","oats"},
"oath":{"oath","oaths"},
"oatmeal":{"oatmeal","oatmeals"},
"oaxaca":{"oaxaca","oaxacas"},
"ob":{"ob","obs"},
"obbligato":{"obbligati","obbligato","obbligatos"},
"obduracy":{"obduracies","obduracy"},
"obeah":{"obeah","obeahs"},
"obeche":{"obeche","obeches"},
"obechi":{"obechi","obechis"},
"obedience":{"obedience","obediences"},
"obedientiary":{"obedientiaries","obedientiary"},
"obeisance":{"obeisance","obeisances"},
"obelisk":{"obelisk","obelisks"},
"obelus":{"obeli","obelus"},
"obesity":{"obesities","obesity"},
"obey":{"obey","obeyed","obeying"},
"obfuscate":{"obfuscate","obfuscated","obfuscating"},
"obfuscation":{"obfuscation","obfuscations"},
"obi":{"obi","obis"},
"obit":{"obit","obits"},
"obituary":{"obituaries","obituary"},
"object":{"object","objected","objecting","objects"},
"objectify":{"objectified","objectifies","objectify","objectifying"},
"objection":{"objection","objections"},
"objectionableness":{"objectionableness","objectionablenesses"},
"objective":{"objective","objectives"},
"objectiveness":{"objectiveness","objectivenesses"},
"objectivity":{"objectivities","objectivity"},
"objector":{"objector","objectors"},
"objet_d'art":{"objets_d'art","objet_d'art"},
"objurgate":{"objurgate","objurgated","objurgates","objurgating"},
"objurgation":{"objurgation","objurgations"},
"oblateness":{"oblateness","oblatenesses"},
"oblation":{"oblation","oblations"},
"obligate":{"obligate","obligated","obligates","obligating"},
"obligation":{"obligation","obligations"},
"obligato":{"obligato","obligatos"},
"oblige":{"oblige","obliged","obliges","obliging"},
"obligingness":{"obligingness","obligingnesses"},
"oblique":{"oblique","obliqued","obliques","obliquing"},
"obliqueness":{"obliqueness","obliquenesses"},
"obliquity":{"obliquities","obliquity"},
"obliterate":{"obliterate","obliterated","obliterates","obliterating"},
"obliteration":{"obliteration","obliterations"},
"oblivion":{"oblivion","oblivions"},
"obliviousness":{"obliviousness","obliviousnesses"},
"oblong":{"oblong","oblongs"},
"oblongness":{"oblongness","oblongnesses"},
"obloquy":{"obloquies","obloquy","obloquys"},
"obnoxiousness":{"obnoxiousness","obnoxiousnesses"},
"oboe":{"oboe","oboes"},
"obol":{"obol","obols"},
"obolus":{"oboli","obolus"},
"obscenity":{"obscenities","obscenity"},
"obscure":{"obscure","obscured","obscurer","obscurest","obscuring"},
"obscureness":{"obscureness","obscurenesses"},
"obscurity":{"obscurities","obscurity"},
"obsequiousness":{"obsequiousness","obsequiousnesses"},
"obsequy":{"obsequies","obsequy"},
"observance":{"observance","observances"},
"observation":{"observation","observations"},
"observatory":{"observatories","observatory"},
"observe":{"observe","observed","observes","observing"},
"observer":{"observer","observers"},
"obsess":{"obsess","obsessed","obsesses","obsessing"},
"obsession":{"obsession","obsessions"},
"obsessiveness":{"obsessiveness","obsessivenesses"},
"obsessivity":{"obsessivities","obsessivity"},
"obsolesce":{"obsolesce","obsolesced","obsolescing"},
"obsolescence":{"obsolescence","obsolescences"},
"obsolete":{"obsolete","obsoleted","obsoleting"},
"obsoleteness":{"obsoleteness","obsoletenesses"},
"obstacle":{"obstacle","obstacles"},
"obstetrician":{"obstetrician","obstetricians"},
"obstetrics":{"obstetrics","obstetricses"},
"obstinacy":{"obstinacies","obstinacy"},
"obstinance":{"obstinance","obstinances"},
"obstruct":{"obstruct","obstructed","obstructing","obstructs"},
"obstruction":{"obstruction","obstructions"},
"obstructionist":{"obstructionist","obstructionists"},
"obstructor":{"obstructor","obstructors"},
"obtain":{"obtain","obtained","obtaining","obtains"},
"obtainment":{"obtainment","obtainments"},
"obtention":{"obtention","obtentions"},
"obtrude":{"obtrude","obtruded","obtrudes","obtruding"},
"obtund":{"obtund","obtunded","obtunding"},
"obturate":{"obturate","obturated","obturating"},
"obtuseness":{"obtuseness","obtusenesses"},
"obvert":{"obvert","obverted","obverting"},
"obviate":{"obviate","obviated","obviates","obviating"},
"obviation":{"obviation","obviations"},
"obviousness":{"obviousness","obviousnesses"},
"oca":{"oca","ocas"},
"ocarina":{"ocarina","ocarinas"},
"occasion":{"occasion","occasioned","occasioning","occasions"},
"occident":{"occident","occidents"},
"occidental":{"occidental","occidentals"},
"occidentalize":{"occidentalize","occidentalized","occidentalizes","occidentalizing"},
"occiput":{"occipita","occiput","occiputs"},
"occitan":{"occitan","occitans"},
"occlude":{"occlude","occluded","occludes","occluding"},
"occlusion":{"occlusion","occlusions"},
"occlusive":{"occlusive","occlusives"},
"occult":{"occult","occulted","occulting","occults"},
"occupancy":{"occupancies","occupancy"},
"occupant":{"occupant","occupants"},
"occupation":{"occupation","occupations"},
"occupier":{"occupier","occupiers"},
"occupy":{"occupied","occupies","occupy","occupying"},
"occupying":{"occupying","occupyings"},
"occur":{"occur","occurred","occurring","occurs"},
"occurrence":{"occurrence","occurrences"},
"ocean":{"ocean","oceans"},
"oceanarium":{"oceanaria","oceanariia","oceanarium","oceanariums"},
"oceania":{"oceania","oceanias"},
"oceanic":{"oceanic","oceanics"},
"oceanica":{"oceanica","oceanicas"},
"oceanid":{"oceanid","oceanides","oceanids"},
"oceanites":{"oceanites","oceaniteses"},
"ocellus":{"ocelli","ocellus","ocelluses"},
"ocelot":{"ocelot","ocelots"},
"ocher":{"ocher","ochers"},
"ochlocracy":{"ochlocracies","ochlocracy"},
"ochna":{"ochna","ochnas"},
"ochnaceae":{"ochnaceae","ochnaceaes"},
"ochotona":{"ochotona","ochotonas"},
"ochotonidae":{"ochotonidae","ochotonidaes"},
"ochre":{"ochre","ochres"},
"ochrea":{"ochrea","ochreae","ocreae"},
"ochroma":{"ochroma","ochromas"},
"ocimum":{"ocimum","ocimums"},
"ocotillo":{"ocotillo","ocotillos"},
"ocrea":{"ocrea","ocreae"},
"oct":{"oct","octs"},
"octad":{"octad","octads"},
"octahedron":{"octahedra","octahedron","octahedrons"},
"octarchy":{"octarchies","octarchy"},
"octave":{"octave","octaves"},
"octavian":{"octavian","octavians"},
"octavo":{"octavo","octavos"},
"octet":{"octet","octets"},
"octette":{"octette","octettes"},
"octillion":{"octillion","octillions"},
"october":{"october","octobers"},
"octocentenary":{"octocentenaries","octocentenary"},
"octodecillion":{"octodecillion","octodecillions"},
"octodecimo":{"octodecimo","octodecimos"},
"octogenarian":{"octogenarian","octogenarians","octogenarinarians"},
"octogenary":{"octogenaries","octogenarnaries","octogenary"},
"octonary":{"octonaries","octonary"},
"octopoda":{"octopoda","octopodas"},
"octopodidae":{"octopodidae","octopodidaes"},
"octopus":{"octopi","octopus","octopuses"},
"octroi":{"octroi","octrois"},
"octuple":{"octuple","octupled","octupling"},
"ocular":{"ocular","oculars"},
"oculist":{"oculist","oculists"},
"oculomotor":{"oculomotor","oculomotors"},
"oculus":{"oculus","oculuses"},
"ocyurus":{"ocyurus","ocyuruses"},
"od":{"od","ods"},
"odalisque":{"odalisque","odalisques"},
"odd":{"odd","odder","oddest"},
"oddball":{"oddball","oddballs"},
"oddity":{"oddities","oddity"},
"oddment":{"oddment","oddments"},
"oddments":{"oddments","oddmentses"},
"oddness":{"oddness","oddnesses"},
"odds":{"odds","oddses"},
"ode":{"ode","odes"},
"oder":{"oder","oders"},
"odeum":{"odea","odeum"},
"odiousness":{"odiousness","odiousnesses"},
"odium":{"odium","odiums"},
"odobenidae":{"odobenidae","odobenidaes"},
"odobenus":{"odobenus","odobenuses"},
"odocoileus":{"odocoileus","odocoileuses"},
"odometer":{"odometer","odometers"},
"odonata":{"odonata","odonatas"},
"odontaspididae":{"odontaspididae","odontaspididaes"},
"odontaspis":{"odontaspis","odontaspises"},
"odontoceti":{"odontoceti","odontocetis"},
"odontophorus":{"odontophorus","odontophoruses"},
"odor":{"odor","odors"},
"odour":{"odour","odours"},
"odysseus":{"odysseus","odysseuses"},
"odyssey":{"odyssey","odysseys"},
"oecanthus":{"oecanthus","oecanthuses"},
"oedema":{"oedema","oedemas","oedemata"},
"oedipus":{"oedipus","oedipuses"},
"oedogoniaceae":{"oedogoniaceae","oedogoniaceaes"},
"oedogoniales":{"oedogoniales","oedogonialeses"},
"oedogonium":{"oedogonium","oedogoniums"},
"oenanthe":{"oenanthe","oenanthes"},
"oengus":{"oengus","oenguses"},
"oenologist":{"oenologist","oenologists"},
"oenology":{"oenologies","oenology"},
"oenophile":{"oenophile","oenophiles"},
"oenophilist":{"oenophilist","oenophilists"},
"oenothera":{"oenothera","oenotheras"},
"oesophagus":{"oesophagi","oesophagus","oesophaguses"},
"oesterreich":{"oesterreich","oesterreiches"},
"oestridae":{"oestridae","oestridaes"},
"oestrogen":{"oestrogen","oestrogens"},
"oestrone":{"oestrone","oestrones"},
"oestrus":{"oestrus","oestruses"},
"oeuvre":{"oeuvre","oeuvres"},
"off-licence":{"off-licence","off-licences"},
"off-roader":{"off-roader","off-roaders"},
"off-white":{"off-white","off-whites"},
"offence":{"offence","offences"},
"offend":{"offend","offended","offending","offends"},
"offender":{"offender","offenders"},
"offense":{"offense","offenses"},
"offensive":{"offensive","offensives"},
"offensiveness":{"offensiveness","offensivenesses"},
"offer":{"offer","offered","offering","offers"},
"offering":{"offering","offerings"},
"offertory":{"offertories","offertory"},
"office":{"office","offices"},
"officeholder":{"officeholder","officeholders"},
"officer":{"officer","officered","officering","officers"},
"official":{"official","officials"},
"officialdom":{"officialdom","officialdoms"},
"officiary":{"officiaries","officiary"},
"officiate":{"officiate","officiated","officiates","officiating"},
"officiating":{"officiating","officiatings"},
"officiation":{"officiation","officiations"},
"officiousness":{"officiousness","officiousnesses"},
"offprint":{"offprint","offprints"},
"offset":{"offset","offsets","offsetting"},
"offshoot":{"offshoot","offshoots"},
"offspring":{"offspring","offsprings"},
"offstage":{"offstage","offstages"},
"oftenness":{"oftenness","oftennesses"},
"ogalala":{"ogalala","ogalalas"},
"ogcocephalidae":{"ogcocephalidae","ogcocephalidaes"},
"ogdoad":{"ogdoad","ogdoads"},
"ogive":{"ogive","ogives"},
"oglala":{"oglala","oglalas"},
"ogle":{"ogle","ogled","ogling"},
"ogre":{"ogre","ogres"},
"ohio":{"ohio","ohios"},
"ohioan":{"ohioan","ohioans"},
"ohm":{"ohm","ohms"},
"oil":{"oil","oiled","oiling","oils"},
"oil-water_interface":{"oil-water_interface","oil-water_interfaces"},
"oilbird":{"oilbird","oilbirds"},
"oiler":{"oiler","oilers"},
"oilfish":{"oilfish","oilfishes"},
"oiliness":{"oiliness","oilinesses"},
"oilman":{"oilman","oilmen"},
"oilrig":{"oilrig","oilrigs"},
"oilskin":{"oilskin","oilskins"},
"oilstove":{"oilstove","oilstoves"},
"oily":{"oilier","oiliest","oily"},
"oink":{"oink","oinked","oinking","oinks"},
"ointment":{"ointment","ointments"},
"ojibwa":{"ojibwa","ojibwas"},
"ojibway":{"ojibway","ojibways"},
"ok":{"ok","oks"},
"oka":{"oka","okas"},
"okapi":{"okapi","okapis"},
"okapia":{"okapia","okapias"},
"okay":{"okay","okayed","okaying","okays"},
"okeh":{"okeh","okehs"},
"okey":{"okey","okeys"},
"okinawa":{"okinawa","okinawas"},
"oklahoma":{"oklahoma","oklahomas"},
"okra":{"okra","okras"},
"ola":{"ola","olas"},
"old":{"old","older","oldest"},
"old-man-of-the-woods":{"old-man-of-the-woods","old-man-of-the-woodses"},
"old-timer":{"old-timer","old-timers"},
"olden":{"olden","oldened","oldening"},
"oldster":{"oldster","oldsters"},
"oldwench":{"oldwench","oldwenches"},
"oldwife":{"oldwife","oldwives"},
"ole":{"ole","oles"},
"olea":{"olea","oleas"},
"oleaceae":{"oleaceae","oleaceaes"},
"oleaginousness":{"oleaginousness","oleaginousnesses"},
"oleales":{"oleales","olealeses"},
"oleander":{"oleander","oleanders"},
"oleandra":{"oleandra","oleandras"},
"oleandraceae":{"oleandraceae","oleandraceaes"},
"olearia":{"olearia","olearias"},
"olefin":{"olefin","olefins"},
"olefine":{"olefine","olefines"},
"olein":{"olein","oleins"},
"oleo":{"oleo","oleos"},
"oleomargarine":{"oleomargarine","oleomargarines"},
"oleum":{"olea","oleum","oleums"},
"olfaction":{"olfaction","olfactions"},
"olfactory":{"olfactories","olfactory"},
"olfersia":{"olfersia","olfersias"},
"olibanum":{"olibanum","olibanums"},
"oligarchy":{"oligarchies","oligarchy"},
"oligocene":{"oligocene","oligocenes"},
"oligochaeta":{"oligochaeta","oligochaetas"},
"oligochaete":{"oligochaete","oligochaetes"},
"oligoclase":{"oligoclase","oligoclases"},
"oligodendria":{"oligodendria","oligodendrias"},
"oligodendroglia":{"oligodendroglia","oligodendroglias"},
"oligoplites":{"oligoplites","oligopliteses"},
"oligopoly":{"oligopolies","oligopoly"},
"oligoporus":{"oligoporus","oligoporuses"},
"oligopsony":{"oligopsonies","oligopsony"},
"olimbos":{"olimbos","olimboses"},
"olio":{"olio","olios"},
"olive":{"olive","olives"},
"olla":{"olla","ollas"},
"olm":{"olm","olms"},
"ology":{"ologies","ology"},
"olympia":{"olympia","olympias"},
"olympiad":{"olympiad","olympiads"},
"olympian":{"olympian","olympians"},
"olympics":{"olympics","olympicses"},
"olympus":{"olympus","olympuses"},
"omaha":{"omaha","omahas"},
"oman":{"oman","omen"},
"omasum":{"omasum","omasums"},
"omayyad":{"omayyad","omayyades","omayyads"},
"omb":{"omb","ombs"},
"ombu":{"ombu","ombus"},
"ombudsman":{"ombudsman","ombudsmen"},
"omdurman":{"omdurman","omdurmen"},
"omega":{"omega","omegas"},
"omelet":{"omelet","omelets"},
"omelette":{"omelette","omelettes"},
"omen":{"omen","omened","omening","omens"},
"omentum":{"omenta","omentum"},
"omission":{"omission","omissions"},
"omit":{"omit","omits","omitted","omitting"},
"ommatidium":{"ommatidia","ommatidium","ommatidtidia"},
"ommiad":{"ades","ommiad","ommiades","ommiads"},
"omnibus":{"omnibus","omnibuses"},
"omnipresence":{"omnipresence","omnipresences"},
"omnium-gatherum":{"omnium-gatherum","omnium-gatherums"},
"omomyid":{"omomyid","omomyids"},
"omphalos":{"omphalos","omphaloses"},
"omphalotus":{"omphalotus","omphalotuses"},
"omphalus":{"omphalus","omphaluses"},
"onager":{"onager","onagers","onagri"},
"onagraceae":{"onagraceae","onagraceaes"},
"onanism":{"onanism","onanisms"},
"onanist":{"onanist","onanists"},
"once-over":{"once-over","once-overs"},
"onchocerciasis":{"onchocerciases","onchocerciasis"},
"onchorynchus":{"onchorynchus","onchorynchuses"},
"oncidium":{"oncidium","oncidiums"},
"oncoming":{"oncoming","oncomings"},
"oncovin":{"oncovin","oncovins"},
"ondatra":{"ondatra","ondatras"},
"one":{"one","ones"},
"one-billionth":{"one-billionth","one-billionths"},
"one-dimensionality":{"one-dimensionalities","one-dimensionality"},
"one-eighth":{"one-eighth","one-eighths"},
"one-eighty":{"one-eighty","one-eightys"},
"one-fifth":{"one-fifth","one-fifths"},
"one-fourth":{"one-fourth","one-fourths"},
"one-half":{"one-half","one-halves"},
"one-hitter":{"one-hitter","one-hitters"},
"one-hundredth":{"one-hundredth","one-hundredths"},
"one-millionth":{"one-millionth","one-millionths"},
"one-ninth":{"one-ninth","one-ninths"},
"one-quadrillionth":{"one-quadrillionth","one-quadrillionths"},
"one-quintillionth":{"one-quintillionth","one-quintillionths"},
"one-seventh":{"one-seventh","one-sevenths"},
"one-sixth":{"one-sixth","one-sixths"},
"one-step":{"one-step","one-stepped","one-stepping"},
"one-tenth":{"one-tenth","one-tenths"},
"one-third":{"one-third","one-thirds"},
"one-thousandth":{"one-thousandth","one-thousandths"},
"one-trillionth":{"one-trillionth","one-trillionths"},
"one-up":{"one-up","one-upped","one-upping"},
"oneida":{"oneida","oneidas"},
"oneness":{"oneness","onenesses"},
"onerousness":{"onerousness","onerousnesses"},
"onion":{"onion","onions"},
"onionskin":{"onionskin","onionskins"},
"oniscidae":{"oniscidae","oniscidaes"},
"oniscus":{"oniscus","oniscuses"},
"onlay":{"onlaid","onlay","onlaying"},
"onlooker":{"onlooker","onlookers"},
"onobrychis":{"onobrychis","onobrychises"},
"onoclea":{"onoclea","onocleas"},
"onondaga":{"onondaga","onondagas"},
"ononis":{"ononis","ononises"},
"onopordon":{"onopordon","onopordons"},
"onopordum":{"onopordum","onopordums"},
"onosmodium":{"onosmodium","onosmodiums"},
"onrush":{"onrush","onrushes"},
"onset":{"onset","onsets"},
"onslaught":{"onslaught","onslaughts"},
"ontogenesis":{"ontogeneses","ontogenesis"},
"ontogeny":{"ontogenies","ontogeny"},
"onus":{"onus","onuses"},
"onychium":{"onychium","onychiums"},
"onychogalea":{"onychogalea","onychogaleas"},
"onychomys":{"onychomys","onychomyses"},
"onychophora":{"onychophora","onychophoras"},
"onychophoran":{"onychophoran","onychophorans"},
"oodles":{"oodles","oodleses"},
"oogonium":{"oogonia","oogonium","oogoniums"},
"oomph":{"oomph","oomphs"},
"oomycetes":{"oomycetes","oomyceteses"},
"oophorectomy":{"oophorectomies","oophorectomy"},
"ootheca":{"ootheca","oothecae"},
"ooze":{"ooze","oozed","oozes","oozing"},
"oozing":{"oozing","oozings"},
"oozy":{"oozier","ooziest","oozy"},
"opacify":{"opacified","opacify","opacifying"},
"opacity":{"opacities","opacity"},
"opah":{"opah","opahs"},
"opal":{"opal","opals"},
"opalescence":{"opalescence","opalescences"},
"opaque":{"opaque","opaqued","opaques","opaquing"},
"opaqueness":{"opaqueness","opaquenesses"},
"opec":{"opec","opecs"},
"open":{"open","opened","opener","openest","opening","opens"},
"opener":{"opener","openers"},
"openhandedness":{"openhandedness","openhandednesses"},
"opening":{"opening","openings"},
"openness":{"openness","opennesses"},
"opepe":{"opepe","opepes"},
"opera":{"opera","operas"},
"operate":{"operate","operated","operates","operating"},
"operation":{"operation","operations"},
"operations":{"operations","operationses"},
"operative":{"operative","operatives"},
"operator":{"operator","operators"},
"opera_seria":{"operas_seria","opera_seria","opera_serias"},
"operculum":{"opercula","operculum","operculums"},
"operetta":{"operetta","operettas"},
"operoseness":{"operoseness","operosenesses"},
"opheodrys":{"opheodrys","opheodryses"},
"ophidia":{"ophidia","ophidias"},
"ophidian":{"ophidian","ophidians"},
"ophidiidae":{"ophidiidae","ophidiidaes"},
"ophiodon":{"ophiodon","ophiodons"},
"ophiodontidae":{"ophiodontidae","ophiodontidaes"},
"ophioglossaceae":{"ophioglossaceae","ophioglossaceaes"},
"ophioglossales":{"ophioglossales","ophioglossaleses"},
"ophioglossum":{"ophioglossum","ophioglossums"},
"ophiolatry":{"ophiolatries","ophiolatry"},
"ophiophagus":{"ophiophagus","ophiophaguses"},
"ophisaurus":{"ophisaurus","ophisauruses"},
"ophiurida":{"ophiurida","ophiuridas"},
"ophiuroidea":{"ophiuroidea","ophiuroideas"},
"ophrys":{"ophrys","ophryses"},
"ophthalmia":{"ophthalmia","ophthalmias"},
"ophthalmitis":{"ophthalmitis","ophthalmitises"},
"ophthalmologist":{"ophthalmologist","ophthalmologists"},
"opiate":{"opiate","opiated","opiating"},
"opiliones":{"opiliones","opilioneses"},
"opine":{"opine","opined","opines","opining"},
"opinion":{"opinion","opinions"},
"opisthobranchia":{"opisthobranchia","opisthobranchias"},
"opisthocomidae":{"opisthocomidae","opisthocomidaes"},
"opisthocomus":{"opisthocomus","opisthocomuses"},
"opisthognathidae":{"opisthognathidae","opisthognathidaes"},
"opossum":{"opossum","opossums"},
"oppenheimer":{"oppenheimer","oppenheimers"},
"opponent":{"opponent","opponents"},
"opportuneness":{"opportuneness","opportunenesses"},
"opportunism":{"opportunism","opportunisms"},
"opportunist":{"opportunist","opportunists"},
"opportunity":{"opportunities","opportunity"},
"oppose":{"oppose","opposed","opposes","opposing"},
"opposite":{"opposite","opposites"},
"oppositeness":{"oppositeness","oppositenesses"},
"opposition":{"opposition","oppositions"},
"oppress":{"oppress","oppressed","oppresses","oppressing"},
"oppression":{"oppression","oppressions"},
"oppressiveness":{"oppressiveness","oppressivenesses"},
"oppressor":{"oppressor","oppressors"},
"opprobrium":{"opprobrium","opprobriums"},
"oppugn":{"oppugn","oppugned","oppugning","oppugns"},
"opsonify":{"opsonified","opsonify","opsonifying"},
"opsonize":{"opsonize","opsonized","opsonizes","opsonizing"},
"opt":{"opt","opted","opting"},
"optative":{"optative","optatives"},
"optic":{"optic","optics"},
"optician":{"optician","opticians"},
"optimize":{"optimize","optimized","optimizing"},
"optimum":{"optima","optimum","optimums"},
"option":{"option","options"},
"optometrist":{"optometrist","optometrists"},
"opulence":{"opulence","opulences"},
"opuntia":{"opuntia","opuntias"},
"opuntiales":{"opuntiales","opuntialeses"},
"opus":{"opera","opus","opuses"},
"opv":{"opv","opvs"},
"orach":{"orach","oraches"},
"orache":{"orache","oraches"},
"oracle":{"oracle","oracles"},
"oradexon":{"oradexon","oradexons"},
"oral":{"oral","orals"},
"orang":{"orang","orangs"},
"orange":{"orange","oranges"},
"orangeman":{"orangeman","orangemen"},
"orangeness":{"orangeness","orangenesses"},
"orangery":{"orangeries","orangery"},
"orangutan":{"orangutan","orangutans"},
"orangutang":{"orangutang","orangutangs"},
"orate":{"orate","orated","orating"},
"oration":{"oration","orations"},
"orator":{"orator","orators"},
"oratorio":{"oratorio","oratorios"},
"oratory":{"oratories","oratory"},
"orb":{"orb","orbed","orbing","orbs"},
"orbignya":{"orbignya","orbignyas"},
"orbit":{"orbit","orbited","orbiting","orbits"},
"orbiter":{"orbiter","orbiters"},
"orca":{"orca","orcas"},
"orchard":{"orchard","orchards"},
"orchardman":{"orchardman","orchardmen"},
"orchestia":{"orchestia","orchestias"},
"orchestiidae":{"orchestiidae","orchestiidaes"},
"orchestra":{"orchestra","orchestras"},
"orchestrate":{"orchestrate","orchestrated","orchestrates","orchestrating"},
"orchid":{"orchid","orchids"},
"orchidaceae":{"orchidaceae","orchidaceaes"},
"orchidales":{"orchidales","orchidaleses"},
"orchidectomy":{"orchidectomies","orchidectomy"},
"orchiectomy":{"orchiectomies","orchiectomy"},
"orchil":{"orchil","orchils"},
"orcinus":{"orcinus","orcinuses"},
"orcus":{"orcus","orcuses"},
"ordain":{"ordain","ordained","ordaining","ordains"},
"ordaining":{"ordaining","ordainings"},
"ordeal":{"ordeal","ordeals"},
"order":{"order","ordered","ordering","orders"},
"order-chenopodiales":{"order-chenopodiales","order-chenopodialeses"},
"ordering":{"ordering","orderings"},
"orderliness":{"orderliness","orderlinesses"},
"orderly":{"orderlies","orderly"},
"ordinal":{"ordinal","ordinals"},
"ordinance":{"ordinance","ordinances"},
"ordinary":{"ordinaries","ordinary"},
"ordination":{"ordination","ordinations"},
"ordnance":{"ordnance","ordnances"},
"ordonnance":{"ordonnance","ordonnances"},
"ordovician":{"ordovician","ordovicians"},
"ordure":{"ordure","ordures"},
"ore":{"ore","ores"},
"oreamnos":{"oreamnos","oreamnoses"},
"orebody":{"orebodies","orebody"},
"orectolobidae":{"orectolobidae","orectolobidaes"},
"orectolobus":{"orectolobus","orectolobuses"},
"oregano":{"oregano","oreganos"},
"oregon":{"oregon","oregons"},
"oreo":{"oreo","oreos"},
"oreopteris":{"oreopteris","oreopterises"},
"oreortyx":{"oreortyx","oreortyxes"},
"organ":{"organ","organs"},
"organa":{"organa","organums"},
"organdie":{"organdie","organdies"},
"organdy":{"organdies","organdy"},
"organelle":{"organelle","organelles"},
"organic":{"organic","organics"},
"organisation":{"organisation","organisations"},
"organism":{"organism","organisms"},
"organist":{"organist","organists"},
"organization":{"organization","organizations"},
"organize":{"orgainzed","orgainzing","organize","organizes"},
"organizer":{"organizer","organizers"},
"organon":{"organa","organon","organons"},
"organs":{"organs","organses"},
"organum":{"organum","organums"},
"organza":{"organza","organzas"},
"orgasm":{"orgasm","orgasms"},
"orgy":{"orgies","orgy"},
"oribi":{"oribi","oribis"},
"oriel":{"oriel","oriels"},
"orient":{"orient","oriented","orienting","orients"},
"oriental":{"oriental","orientals"},
"orientalize":{"orientalize","orientalized","orientalizing"},
"orientate":{"orientate","orientated","orientates","orientating"},
"orientation":{"orientation","orientations"},
"orifice":{"orifice","orifices"},
"origin":{"origin","origins"},
"original":{"original","originals"},
"originality":{"originalities","originality"},
"originate":{"originate","originated","originates","originating"},
"origination":{"origination","originations"},
"originator":{"originator","originators"},
"orinasal":{"orinasal","orinasals"},
"orinoco":{"orinoco","orinocos"},
"oriole":{"oriole","orioles"},
"oriolidae":{"oriolidae","oriolidaes"},
"oriolus":{"oriolus","orioluses"},
"orion":{"orion","orions"},
"orison":{"orison","orisons"},
"orites":{"orites","oriteses"},
"orleans":{"orleans","orleanses"},
"orlop":{"orlop","orlops"},
"ormazd":{"ormazd","ormazds"},
"ormer":{"ormer","ormers"},
"ormosia":{"ormosia","ormosias"},
"ormuzd":{"ormuzd","ormuzds"},
"ornament":{"ornament","ornamented","ornamenting","ornaments"},
"ornamental":{"ornamental","ornamentals"},
"ornamentalist":{"ornamentalist","ornamentalists"},
"ornamentation":{"ornamentation","ornamentations"},
"ornateness":{"ornateness","ornatenesses"},
"orneriness":{"orneriness","ornerinesses"},
"ornery":{"ornerier","orneriest","ornery"},
"ornithischia":{"ornithischia","ornithischias"},
"ornithischian":{"ornithischian","ornithischians"},
"ornithogalum":{"ornithogalum","ornithogalums"},
"ornithologist":{"ornithologist","ornithologists"},
"ornithomimida":{"ornithomimida","ornithomimidas"},
"ornithopod":{"ornithopod","ornithopods"},
"ornithopoda":{"ornithopoda","ornithopodas"},
"ornithorhynchidae":{"ornithorhynchidae","ornithorhynchidaes"},
"ornithorhynchus":{"ornithorhynchus","ornithorhynchuses"},
"orobanchaceae":{"orobanchaceae","orobanchaceaes"},
"orontium":{"orontium","orontiums"},
"orphan":{"orphan","orphaned","orphaning","orphans"},
"orphanage":{"orphanage","orphanages"},
"orphrey":{"orphrey","orphreys"},
"orpin":{"orpin","orpins"},
"orpine":{"orpine","orpines"},
"orrery":{"orreries","orrery"},
"orris":{"orris","orrises"},
"orrisroot":{"orrisroot","orrisroots"},
"ortalis":{"ortalis","ortalises"},
"orthicon":{"orthicon","orthicons"},
"orthodontia":{"orthodontia","orthodontias"},
"orthodontics":{"orthodontics","orthodonticses"},
"orthodoxy":{"orthodoxies","orthodoxy"},
"orthogonality":{"orthogonalities","orthogonality"},
"orthography":{"orthographies","orthography"},
"orthopaedics":{"orthopaedics","orthopaedicses"},
"orthopedics":{"orthopedics","orthopedicses"},
"orthophosphate":{"orthophosphate","orthophosphates"},
"orthopristis":{"orthopristis","orthopristises"},
"orthoptera":{"orthoptera","orthopteras"},
"orthopteran":{"orthopteran","orthopterans"},
"orthopteron":{"orthopteron","orthopterons"},
"orthostichy":{"orthostichies","orthostichy"},
"orthotomus":{"orthotomus","orthotomuses"},
"ortolan":{"ortolan","ortolans"},
"orudis":{"orudis","orudises"},
"oruvail":{"oruvail","oruvails"},
"orycteropodidae":{"orycteropodidae","orycteropodidaes"},
"orycteropus":{"orycteropus","orycteropuses"},
"oryctolagus":{"oryctolagus","oryctolaguses"},
"oryx":{"oryx","oryxes"},
"oryza":{"oryza","oryzas"},
"oryzomys":{"oryzomys","oryzomyses"},
"oryzopsis":{"oryzopses","oryzopsis"},
"os":{"os","oses","ossa"},
"osage":{"osage","osages"},
"oscillate":{"oscillate","oscillated","oscillates","oscillating"},
"oscillation":{"oscillation","oscillations"},
"oscillatoriaceae":{"oscillatoriaceae","oscillatoriaceaes"},
"oscilloscope":{"oscilloscope","oscilloscopes"},
"oscine":{"oscine","oscines"},
"oscines":{"oscines","oscineses"},
"oscitance":{"oscitance","oscitances"},
"oscitancy":{"oscitancy","oscitantancies"},
"osculate":{"osculate","osculated","osculates","osculating"},
"osculation":{"osculation","osculations"},
"osculator":{"osculator","osculators"},
"osculum":{"oscula","osculum"},
"osha":{"osha","oshas"},
"osier":{"osier","osiers"},
"oslo":{"oslo","oslos"},
"osmanli":{"osmanli","osmanlis"},
"osmanthus":{"osmanthus","osmanthuses"},
"osmeridae":{"osmeridae","osmeridaes"},
"osmerus":{"osmerus","osmeruses"},
"osmitrol":{"osmitrol","osmitrols"},
"osmium":{"osmium","osmiums"},
"osmose":{"osmose","osmosed","osmosing"},
"osmund":{"osmund","osmunds"},
"osmundaceae":{"osmundaceae","osmundaceaes"},
"osprey":{"osprey","ospreys"},
"ossicle":{"ossicle","ossicles"},
"ossiculum":{"ossiculum","ossiculums"},
"ossification":{"ossification","ossifications"},
"ossify":{"ossified","ossifies","ossify","ossifying"},
"ossuary":{"ossuaries","ossuary"},
"ostariophysi":{"ostariophysi","ostariophysis"},
"osteichthyes":{"osteichthyes","osteichthyeses"},
"ostentation":{"ostentation","ostentations"},
"ostentatiousness":{"ostentatiousness","ostentatiousnesses"},
"osteoarthritis":{"osteoarthritis","osteoarthritises"},
"osteoblast":{"osteoblast","osteoblasts"},
"osteoma":{"oateomas","oateomata","osteoma","osteomas","osteomata"},
"osteopath":{"osteopath","osteopaths"},
"osteopathist":{"osteopathist","osteopathists"},
"osteopetrosis":{"osteopetroses","osteopetrosis"},
"osteoplasty":{"osteoplasties","osteoplasty"},
"osteosarcoma":{"osteosarcoma","osteosarcomas"},
"osteostracan":{"osteostracan","osteostracans"},
"osteostraci":{"osteostraci","osteostracis"},
"osteotomy":{"osteotomies","osteotomy"},
"ostiary":{"ostiaries","ostiary"},
"ostium":{"ostia","ostium"},
"ostler":{"ostler","ostlers"},
"ostraciidae":{"ostraciidae","ostraciidaes"},
"ostracism":{"ostracism","ostracisms"},
"ostracize":{"ostracize","ostracized","ostracizing","ostraized"},
"ostracod":{"ostracod","ostracods"},
"ostracoda":{"ostracoda","ostracodas"},
"ostracodermi":{"ostracodermi","ostracodermis"},
"ostracon":{"ostraca","ostracon"},
"ostrea":{"ostrea","ostreas"},
"ostreidae":{"ostreidae","ostreidaes"},
"ostrich":{"ostrich","ostriches"},
"ostrya":{"ostrya","ostryas"},
"ostryopsis":{"ostryopses","ostryopsis"},
"ostyak":{"ostyak","ostyaks"},
"ostyak-samoyed":{"ostyak-samoyed","ostyak-samoyeds"},
"otalgia":{"otalgia","otalgias"},
"otaria":{"otaria","otarias"},
"otariidae":{"otariidae","otariidaes"},
"other":{"other","others"},
"otherness":{"otherness","othernesses"},
"otherworldliness":{"otherworldliness","otherworldlinesses"},
"otides":{"otides","otideses"},
"otididae":{"otididae","otididaes"},
"otis":{"otis","otises"},
"oto":{"oto","otos"},
"otoe":{"otoe","otoes"},
"otoganglion":{"otoganglion","otoganglions"},
"otolaryngologist":{"otolaryngologist","otolaryngologists"},
"otolaryngology":{"otolaryngologies","otolaryngology"},
"otologist":{"otologist","otologists"},
"otology":{"otologies","otology"},
"otorhinolaryngologist":{"otorhinolaryngologist","otorhinolaryngologists"},
"ottar":{"ottar","ottars"},
"ottawa":{"ottawa","ottawas"},
"otter":{"otter","otters"},
"otterhound":{"otterhound","otterhounds"},
"otto":{"otto","ottos"},
"ottoman":{"ottoman","ottomans","ottomen"},
"otus":{"otus","otuses"},
"ouachita":{"ouachita","ouachitas"},
"ouija":{"ouija","ouijas"},
"ounce":{"ounce","ounces"},
"ouranopithecus":{"ouranopithecus","ouranopithecuses"},
"ouranos":{"ouranos","ouranoses"},
"ousel":{"ousel","ousels"},
"oust":{"oust","ousted","ousting","ousts"},
"ouster":{"ouster","ousters"},
"ousting":{"ousting","oustings"},
"out":{"out","outed","outing","outs"},
"out-basket":{"out-basket","out-baskets"},
"out-migration":{"out-migration","out-migrations"},
"out-of-doors":{"out-of-doors","out-of-doorses"},
"out-tray":{"out-tray","out-trays"},
"outargue":{"outargue","outargued","outarguing"},
"outbalance":{"outbalance","outbalanced","outbalances","outbalancing"},
"outbid":{"outbid","outbidden","outbidding","outbids"},
"outbloom":{"outbloom","outbloomed","outblooming"},
"outbrave":{"outbrave","outbraved","outbraving"},
"outbreak":{"outbreak","outbreaks"},
"outbreed":{"outbred","outbreed","outbreeding","outbreeds"},
"outbuild":{"outbuild","outbuilding","outbuilt"},
"outburn":{"outburn","outburned","outburning","outburnt"},
"outburst":{"outburst","outbursts"},
"outcast":{"outcast","outcasts"},
"outclass":{"outclass","outclassed","outclassing"},
"outclimb":{"outclimb","outclimbed","outclimbing"},
"outcome":{"outcome","outcomes"},
"outcrop":{"outcrop","outcropped","outcropping","outcrops"},
"outcropping":{"outcropping","outcroppings"},
"outcross":{"outcross","outcrossed","outcrossing"},
"outcry":{"outcried","outcries","outcry","outcrying"},
"outdate":{"outdate","outdated","outdating"},
"outdistance":{"outdistance","outdistanced","outdistances","outdistancing"},
"outdo":{"outdid","outdo","outdoes","outdoing","outdone"},
"outdoors":{"outdoors","outdoorses"},
"outdoorsman":{"outdoorsman","outdoorsmen"},
"outdraw":{"outdraw","outdrawing","outdrawn","outdrew"},
"outdrink":{"outdrank","outdrink","outdrinking","outdrunk"},
"outerwear":{"outerwear","outerwears"},
"outface":{"outface","outfaced","outfaces","outfacing"},
"outfit":{"outfit","outfits","outfitted","outfitting"},
"outflank":{"outflank","outflanked","outflanking","outflanks"},
"outflow":{"outflow","outflows"},
"outfly":{"outflew","outflown","outfly","outflying"},
"outfox":{"outfox","outfoxed","outfoxes","outfoxing"},
"outgas":{"outgas","outgassed","outgasses","outgassing"},
"outgeneral":{"outgeneral","outgeneraled","outgeneraling","outgeneralled","outgeneralling","outgenerals"},
"outgo":{"outgo","outgoes","outgoing","outgone","outwent"},
"outgoer":{"outgoer","outgoers"},
"outgrow":{"outgrew","outgrow","outgrowing","outgrown","outgrows"},
"outgrowth":{"outgrowth","outgrowths"},
"outguess":{"outguess","outguessed","outguesses","outguessing"},
"outgush":{"outgush","outgushed","outgushing"},
"outhouse":{"outhouse","outhouses"},
"outing":{"outing","outings"},
"outlander":{"outlander","outlanders"},
"outlandishness":{"outlandishness","outlandishnesses"},
"outlast":{"outlast","outlasted","outlasting","outlasts"},
"outlaugh":{"outlaugh","outlaughed","outlaughing"},
"outlaw":{"outlaw","outlawed","outlawing","outlaws"},
"outlawry":{"outlawries","outlawry"},
"outlay":{"outlaid","outlay","outlaying","outlays"},
"outleap":{"outleap","outleaped","outleaping","outleapt"},
"outlet":{"outlet","outlets"},
"outline":{"outline","outlined","outlines","outlining"},
"outlive":{"outlive","outlived","outlives","outliving"},
"outlook":{"outlook","outlooked","outlooking","outlooks"},
"outman":{"outman","outmanned","outmanning","outmans"},
"outmaneuver":{"outmaneuver","outmaneuvered","outmaneuvering","outmaneuvers"},
"outmanoeuver":{"outmanoeuver","outmanoeuvered","outmanoeuvering"},
"outmarch":{"outmarch","outmarched","outmarching"},
"outmatch":{"outmatch","outmatched","outmatches","outmatching"},
"outmode":{"outmode","outmoded","outmoding"},
"outnumber":{"outnumber","outnumbered","outnumbering"},
"outpace":{"outpace","outpaced","outpacing"},
"outperform":{"outperform","outperformed","outperforming"},
"outplay":{"outplay","outplayed","outplaying"},
"outpoint":{"outpoint","outpointed","outpointing","outpoints"},
"outpoll":{"outpoll","outpolled","outpolling"},
"outpost":{"outpost","outposts"},
"outpour":{"outpour","outpoured","outpouring"},
"outpouring":{"outpouring","outpourings"},
"outpull":{"outpull","outpulled","outpulling"},
"output":{"output","outputs","outputted","outputting"},
"outrace":{"outrace","outraced","outracing"},
"outrage":{"outrage","outraged","outrages","outraging"},
"outrageousness":{"outrageousness","outrageousnesses"},
"outrange":{"outrange","outranged","outranging"},
"outrank":{"outrank","outranked","outranking","outranks"},
"outreach":{"outreach","outreached","outreaching"},
"outride":{"outridden","outride","outrides","outriding","outrode"},
"outrival":{"outrival","outrivalled","outrivalling","outrivals"},
"outroar":{"outroar","outroared","outroaring"},
"outroot":{"outroot","outrooted","outrooting"},
"outrun":{"outran","outrun","outrunning","outruns"},
"outscore":{"outscore","outscored","outscores","outscoring"},
"outsell":{"outsell","outselling","outsells","outsold"},
"outset":{"outset","outsets"},
"outshine":{"outshine","outshined","outshines","outshining","outshone"},
"outshoot":{"outshoot","outshooting","outshoots","outshot"},
"outside":{"outside","outsides"},
"outsider":{"outsider","outsiders"},
"outsing":{"outsang","outsing","outsinging","outsung"},
"outskirt":{"outskirt","outskirts"},
"outsleep":{"outsleep","outsleeping","outslept"},
"outsmart":{"outsmart","outsmarted","outsmarting","outsmarts"},
"outsoar":{"oursoared","outsoar","outsoaring"},
"outspan":{"outspan","outspanned","outspanning","outspans"},
"outsparkle":{"outsparkle","outsparkled","outsparkling"},
"outspeak":{"outspeak","outspeaking","outspoke","outspoken"},
"outspeed":{"outsped","outspeed","outspeeded","outspeeding"},
"outspend":{"outspend","outspending","outspent"},
"outspokenness":{"outspokenness","outspokennesses"},
"outspread":{"outspread","outspreading","outspreads"},
"outstand":{"outstand","outstanding","outstands","outstood"},
"outstanding":{"outstanding","outstandings"},
"outstare":{"outstare","outstared","outstaring"},
"outstation":{"outstation","outstations"},
"outstay":{"outstay","outstayed","outstaying","outstays"},
"outstretch":{"outstretch","outstretched","outstretching"},
"outstride":{"ourstrode","outstridden","outstride","outstriding"},
"outstrip":{"outstrip","outstripped","outstripping","outstrips"},
"outswear":{"outswear","outswearing","outswore","outsworn"},
"outtell":{"outtell","outtelling","outtold"},
"outthink":{"outthink","outthinking","outthinks","outthought"},
"outthrow":{"outthrew","outthrow","outthrowing","outthrown"},
"outtrick":{"outtrick","outtricked","outtricking"},
"outturn":{"outturn","outturns"},
"outvote":{"outvote","outvoted","outvoting"},
"outward":{"outward","outwards"},
"outwardness":{"outwardness","outwardnesses"},
"outwatch":{"outwatch","outwatched","outwatching"},
"outwear":{"outwear","outwearing","outwears","outwore","outworn"},
"outweary":{"outwearied","outweary","outwearying"},
"outweep":{"outweep","outweeping","outwept"},
"outweigh":{"outweigh","outweighed","outweighing","outweighs"},
"outwell":{"outwell","outwelled","outwelling"},
"outwit":{"outwit","outwits","outwitted","outwitting"},
"outwk":{"outwk","outwked","outwking","outwks","outwrought"},
"outwork":{"outwork","outworked","outworking"},
"ouzel":{"ouzel","ouzels"},
"ouzo":{"ouzo","ouzos"},
"oval":{"oval","ovals"},
"ovalbumin":{"ovalbumin","ovalbumins"},
"ovalipes":{"ovalipes","ovalipeses"},
"ovambo":{"ovambo","ovambos"},
"ovariectomy":{"ovariectomies","ovariectomy"},
"ovariotomy":{"ovariotomies","ovariotomy"},
"ovary":{"ovaries","ovary"},
"ovation":{"ovation","ovations"},
"oven":{"oven","ovens"},
"ovenbird":{"ovenbird","ovenbirds"},
"over-crowding":{"over-crowding","over-crowdings"},
"overabound":{"overabound","overabounded","overabounding"},
"overabundance":{"overabundance","overabundances"},
"overachieve":{"overachieve","overachieved","overachieving"},
"overact":{"overact","overacted","overacting","overacts"},
"overacting":{"overacting","overactings"},
"overall":{"overall","overalls"},
"overappraisal":{"overappraisal","overappraisals"},
"overarch":{"overarch","overarched","overarches","overarching"},
"overawe":{"overawe","overawed","overawes","overawing"},
"overbalance":{"overbalance","overbalanced","overbalances","overbalancing"},
"overbear":{"overbear","overbearing","overbears","overbore","overborne"},
"overbearingness":{"overbearingness","overbearingnesses"},
"overbid":{"overbid","overbidding","overbids"},
"overblow":{"overblew","overblow","overblowing","overblown","overblows"},
"overbook":{"overbook","overbooked","overbooking"},
"overbuild":{"overbuild","overbuilding","overbuilds","overbuilt"},
"overburden":{"overburden","overburdened","overburdening","overburdens"},
"overbuy":{"overbought","overbuy","overbuying"},
"overcall":{"overcall","overcalled","overcalling","overcalls"},
"overcapacity":{"overcapacities","overcapacity"},
"overcapitalize":{"overcapitalize","overcapitalized","overcapitalizing"},
"overcast":{"overcast","overcasting","overcasts"},
"overcasting":{"overcasting","overcastings"},
"overcharge":{"overcharge","overcharged","overcharges","overcharging"},
"overclothes":{"overclothes","overclotheses"},
"overcloud":{"ocerclouding","overcloud","overclouded","overclouds"},
"overcoat":{"overcoat","overcoats"},
"overcoating":{"overcoating","overcoatings"},
"overcolor":{"overcolor","overcolored","overcoloring"},
"overcome":{"overcame","overcome","overcomes","overcoming"},
"overcompensate":{"overcompensate","overcompensated","overcompensates","overcompensating"},
"overconfidence":{"overconfidence","overconfidences"},
"overcount":{"overcount","overcounted","overcounting"},
"overcrop":{"overcrop","overcropped","overcropping","overcrops"},
"overcrossing":{"overcrossing","overcrossings"},
"overcrowd":{"overcrowd","overcrowded","overcrowding"},
"overdevelop":{"overdevelop","overdeveloped","overdeveloping"},
"overdo":{"overdid","overdo","overdoes","overdoing","overdone"},
"overdose":{"overdose","overdosed","overdoses","overdosing"},
"overdraw":{"overdraw","overdrawing","overdrawn","overdraws","overdrew"},
"overdress":{"overdress","overdressed","overdresses","overdressing"},
"overdrink":{"overdrank","overdrink","overdrinking","overdrunk"},
"overdrive":{"overdrive","overdriven","overdrives","overdriving","overdrove"},
"overdry":{"overdried","overdry","overdrying"},
"overdye":{"overdye","overdyed","overdyeing"},
"overeat":{"overate","overeat","overeaten","overeating"},
"overeating":{"overeating","overeatings"},
"overemphasize":{"overemphasize","overemphasized","overemphasizes","overemphasizing"},
"overestimate":{"overestimate","overestimated","overestimates","overestimating"},
"overestimation":{"overestimation","overestimations"},
"overexcite":{"overexcite","overexcited","overexciting"},
"overexert":{"overexert","overexerted","overexerting"},
"overexploitation":{"overexploitation","overexploitations"},
"overexpose":{"overexpose","overexposed","overexposing"},
"overextend":{"overextend","overextended","overextending","overextends"},
"overfeed":{"overfed","overfeed","overfeeding"},
"overfill":{"overfill","overfilled","overfilling"},
"overfish":{"overfish","overfished","overfishing"},
"overflow":{"overflow","overflowed","overflowing","overflows"},
"overflowing":{"overflowing","overflowings"},
"overfly":{"overflew","overflies","overflown","overfly","overflying"},
"overgarment":{"overgarment","overgarments"},
"overglaze":{"overglaze","overglazed","overglazing"},
"overgovern":{"overgovern","overgoverned","overgoverning"},
"overgraze":{"overgraze","overgrazed","overgrazing"},
"overgrow":{"overgrew","overgrow","overgrowing","overgrown","overgrows"},
"overgrowth":{"overgrowth","overgrowths"},
"overhand":{"overhand","overhanded","overhanding"},
"overhang":{"overhang","overhanging","overhangs","overhung"},
"overhaul":{"overhaul","overhauled","overhauling","overhauls"},
"overhauling":{"overhauling","overhaulings"},
"overhead":{"overhead","overheads"},
"overhear":{"overhear","overheard","overhearing","overhears"},
"overheat":{"overheat","overheated","overheating"},
"overindulge":{"overindulge","overindulged","overindulges","overindulging"},
"overindulgence":{"overindulgence","overindulgences"},
"overissue":{"overissue","overissued","overissues","overissuing"},
"overjoy":{"overjoy","overjoyed","overjoying"},
"overlabor":{"overlabor","overlabored","overlaboring"},
"overlap":{"overlap","overlapped","overlapping","overlaps"},
"overlapping":{"overlapping","overlappings"},
"overlay":{"overlaid","overlay","overlaying","overlays"},
"overlayer":{"overlayer","overlayers"},
"overleap":{"overleap","overleaped","overleaping","overleapt"},
"overlie":{"overlain","overlay","overlie","overlies","overlying"},
"overlight":{"overlight","overlighted","overlighting","overlit"},
"overload":{"overload","overloaded","overloading","overloads"},
"overlook":{"overlook","overlooked","overlooking","overlooks"},
"overlord":{"overlord","overlords"},
"overman":{"overman","overmanned","overmanning","overmans","overmen"},
"overmaster":{"overmaster","overmastered","overmastering","overmasters"},
"overmatch":{"overmatch","overmatched","overmatching"},
"overmuch":{"overmuch","overmuches"},
"overmuchness":{"overmuchness","overmuchnesses"},
"overnighter":{"overnighter","overnighters"},
"overpass":{"overpass","overpassed","overpasses","overpassing","overpast"},
"overpay":{"overpaid","overpay","overpaying","overpays"},
"overpeople":{"overpeople","overpeopled","overpeopling"},
"overpersuade":{"overpersuade","overpersuaded","overpersuading"},
"overplay":{"overplay","overplayed","overplaying","overplays"},
"overplus":{"overplus","overpluses"},
"overpopulation":{"overpopulation","overpopulations"},
"overpower":{"overpower","overpowered","overpowering","overpowers"},
"overpraise":{"overpraise","overpraised","overpraising"},
"overprice":{"overprice","overpriced","overpricing"},
"overprint":{"overpinted","overprint","overprinted","overprinting","overprints"},
"overprize":{"overprize","overprized","overprizing"},
"overproduce":{"overproduce","overproduced","overproducing"},
"overproduction":{"overproduction","overproductions"},
"overprotection":{"overprotection","overprotections"},
"overrate":{"overrate","overrated","overrates","overrating"},
"overrating":{"overrating","overratings"},
"overreach":{"overreach","overreached","overreaches","overreaching"},
"overreact":{"overreact","overreacted","overreacting"},
"overreckoning":{"overreckoning","overreckonings"},
"overrefine":{"overrefine","overrefined","overrefining"},
"overrefinement":{"overrefinement","overrefinements"},
"override":{"overridden","override","overrides","overriding","overrode"},
"overroast":{"overroast","overroasted","overroasting"},
"overrule":{"overrule","overruled","overrules","overruling"},
"overrun":{"overran","overrun","overrunning","overruns"},
"oversee":{"oversaw","oversee","overseeing","overseen","oversees"},
"overseer":{"overseer","overseers"},
"oversell":{"oversell","overselling","oversells","oversold"},
"overset":{"overset","oversets","oversetting"},
"oversew":{"oversew","oversewed","oversewing","oversewn","oversews"},
"overshadow":{"overshadow","overshadowed","overshadowing","overshadows"},
"overshielding":{"overshielding","overshieldings"},
"overshoot":{"overshoot","overshooting","overshoots","overshot"},
"oversight":{"oversight","oversights"},
"oversimplify":{"oversimplified","oversimplifies","oversimplify","oversimplifying"},
"overslaugh":{"overslaugh","overslaughed","overslaughing"},
"oversleep":{"oversleep","oversleeping","oversleeps","overslept"},
"overspend":{"overspend","overspending","overspends","overspent"},
"overspill":{"overspill","overspills"},
"overspread":{"overspread","overspreading","overspreads"},
"overstate":{"overstate","overstated","overstates","overstating"},
"overstatement":{"overstatement","overstatements"},
"overstay":{"overstay","overstayed","overstaying","overstays"},
"overstep":{"overstep","overstepped","overstepping","oversteps"},
"overstock":{"overstock","overstocked","overstocking"},
"overstrain":{"overstrain","overstrained","overstraining","overstrains"},
"overstretch":{"overstretch","overstretched","overstretches","overstretching"},
"overstride":{"overstridden","overstride","overstriding","overstrode"},
"overstudy":{"overstudied","overstudy","overstudying"},
"overstuff":{"overstuff","overstuffed","overstuffing"},
"oversubscribe":{"oversubscribe","oversubscribed","oversubscribing"},
"oversupply":{"oversupplied","oversupplies","oversupply","oversupplying"},
"overtake":{"overtake","overtaken","overtakes","overtaking","overtook"},
"overtaking":{"overtaking","overtakings"},
"overtask":{"overtask","overtasked","overtasking"},
"overtax":{"overtax","overtaxed","overtaxing"},
"overthrow":{"overthrew","overthrow","overthrowing","overthrown","overthrows"},
"overtime":{"overtime","overtimes"},
"overtire":{"overtire","overtired","overtires","overtiring"},
"overtone":{"overtone","overtones"},
"overtop":{"overtop","overtopped","overtopping","overtops"},
"overtrade":{"overtrade","overtraded","overtrading"},
"overtrain":{"overtrain","overtrained","overtraining"},
"overtrump":{"overtrump","overtrumped","overtrumping"},
"overture":{"overture","overtures"},
"overturn":{"overturn","overturned","overturning","overturns"},
"overturning":{"overturning","overturnings"},
"overuse":{"overuse","overused","overuses","overusing"},
"overutilisation":{"overutilisation","overutilisations"},
"overutilization":{"overutilization","overutilizations"},
"overvaluation":{"overvaluation","overvaluations"},
"overvalue":{"overvalue","overvalued","overvalues","overvaluing"},
"overwatch":{"overwatch","overwatched","overwatching"},
"overwear":{"overwear","overwearing","overwore","overworn"},
"overweary":{"overwearied","overwearies","overweary","overwearying"},
"overweigh":{"overweigh","overweighed","overweighing"},
"overweight":{"overweight","overweighted","overweighting","overweights"},
"overwhelm":{"overwhelm","overwhelmed","overwhelming","overwhelms"},
"overwind":{"overwind","overwinding","overwinds","overwound"},
"overwinter":{"overwinter","overwintered","overwintering"},
"overwork":{"overwork","overworked","overworking","overworks","overwrought"},
"overworking":{"overworking","overworkings"},
"overwrite":{"overwrite","overwrites","overwriting","overwritten","overwrote"},
"ovibos":{"ovibos","oviboses"},
"oviduct":{"oviduct","oviducts"},
"oviposit":{"oviposit","oviposited","oviposting"},
"ovis":{"ovis","ovises"},
"ovoflavin":{"ovoflavin","ovoflavins"},
"ovolo":{"ovoli","ovolo"},
"ovotestis":{"ovotestes","ovotestis"},
"ovulate":{"ovulate","ovulated","ovulating"},
"ovum":{"ova","ovum"},
"owe":{"owe","owed","owing"},
"owelty":{"owelties","owelty"},
"owl":{"owl","owls"},
"owlclaws":{"owlclaws","owlclawses"},
"owlt":{"owlt","owlts"},
"own":{"own","owned","owning","owns"},
"owner":{"owner","owners"},
"ownership":{"ownership","ownerships"},
"ox":{"ox","oxen"},
"oxalacetate":{"oxalacetate","oxalacetates"},
"oxalidaceae":{"oxalidaceae","oxalidaceaes"},
"oxalis":{"oxalis","oxalises"},
"oxaloacetate":{"oxaloacetate","oxaloacetates"},
"oxandra":{"oxandra","oxandras"},
"oxaprozin":{"oxaprozin","oxaprozins"},
"oxazepam":{"oxazepam","oxazepams"},
"oxen":{"oxen","oxens"},
"oxeye":{"oxeye","oxeyes"},
"oxford":{"oxford","oxfords"},
"oxheart":{"oxheart","oxhearts"},
"oxidant":{"oxidant","oxidants"},
"oxidation":{"oxidation","oxidations"},
"oxidation-reduction":{"oxidation-reduction","oxidation-reductions"},
"oxide":{"oxide","oxides"},
"oxidisation":{"oxidisation","oxidisations"},
"oxidization":{"oxidization","oxidizations"},
"oxidize":{"oxidize","oxidized","oxidizes","oxidizing"},
"oxidizer":{"oxidizer","oxidizers"},
"oxlip":{"oxlip","oxlips"},
"oxtongue":{"oxtongue","oxtongues"},
"oxyacid":{"oxyacid","oxyacids"},
"oxybelis":{"oxybelis","oxybelises"},
"oxybenzene":{"oxybenzene","oxybenzenes"},
"oxycephaly":{"oxycephalies","oxycephaly"},
"oxydendrum":{"oxydendrum","oxydendrums"},
"oxygen":{"oxygen","oxygens"},
"oxygenate":{"oxygenate","oxygenated","oxygenates","oxygenating"},
"oxylebius":{"oxylebius","oxylebiuses"},
"oxymoron":{"oxymomora","oxymora","oxymoron"},
"oxyphenbutazone":{"oxyphenbutazone","oxyphenbutazones"},
"oxytetracycline":{"oxytetracycline","oxytetracyclines"},
"oxytropis":{"oxytropis","oxytropises"},
"oxyura":{"oxyura","oxyuras"},
"oxyuranus":{"oxyuranus","oxyuranuses"},
"oxyuridae":{"oxyuridae","oxyuridaes"},
"oyster":{"oyster","oysters"},
"oystercatcher":{"oystercatcher","oystercatchers"},
"oysterfish":{"oysterfish","oysterfishes"},
"oysterman":{"oysterman","oystermen"},
"ozarks":{"ozarks","ozarkses"},
"ozocerite":{"ozocerite","ozocerites"},
"ozokerite":{"ozokerite","ozokerites"},
"ozonium":{"ozonium","ozoniums"},
"ozothamnus":{"ozothamnus","ozothamnuses"},
"p":{"p","ps"},
"pa":{"pa","pas"},
"paba":{"paba","pabas"},
"pabir":{"pabir","pabirs"},
"pablum":{"pablum","pablums"},
"pabulum":{"pabulum","pabulums"},
"pac":{"pac","pacs"},
"paca":{"paca","pacas"},
"pace":{"pace","paced","paces","pacing"},
"pacemaker":{"pacemaker","pacemakers"},
"pacer":{"pacer","pacers"},
"pacesetter":{"pacesetter","pacesetters"},
"pacha":{"pacha","pachas"},
"pachouli":{"pachouli","pachoulis"},
"pachuco":{"pachuco","pachucos"},
"pachycephala":{"pachycephala","pachycephalas"},
"pachycephalosaur":{"pachycephalosaur","pachycephalosaurs"},
"pachycephalosaurus":{"pachycephalosaurus","pachycephalosauruses"},
"pachyderma":{"pachyderma","pachydermas"},
"pachyrhizus":{"pachyrhizus","pachyrhizuses"},
"pachysandra":{"pachysandra","pachysandras"},
"pacific":{"pacific","pacifics"},
"pacification":{"pacification","pacifications"},
"pacificist":{"pacificist","pacificists"},
"pacifier":{"pacifier","pacifiers"},
"pacifism":{"pacifism","pacifisms"},
"pacifist":{"pacifist","pacifists"},
"pacify":{"pacified","pacifies","pacify","pacifying"},
"pacing":{"pacing","pacings"},
"pack":{"pack","packed","packing","packs"},
"package":{"package","packaged","packages","packaging"},
"packer":{"packer","packers"},
"packera":{"packera","packeras"},
"packet":{"packet","packeted","packeting","packets"},
"packing":{"packing","packings"},
"packinghouse":{"packinghouse","packinghouses"},
"packman":{"packman","packmen"},
"packrat":{"packrat","packrats"},
"pact":{"pact","pacts"},
"pad":{"pad","padded","padding","pads"},
"padauk":{"padauk","padauks"},
"padda":{"padda","paddas"},
"padding":{"padding","paddings"},
"paddle":{"paddle","paddled","paddles","paddling"},
"paddle-wheeler":{"paddle-wheeler","paddle-wheelers"},
"paddlefish":{"paddlefish","paddlefishes"},
"paddler":{"paddler","paddlers"},
"paddlewheel":{"paddlewheel","paddlewheels"},
"paddock":{"paddock","paddocked","paddocking","paddocks"},
"paddy":{"paddies","paddy"},
"paddymelon":{"paddymelon","paddymelons"},
"pademelon":{"pademelon","pademelons"},
"padlock":{"padlock","padlocked","padlocking"},
"padouk":{"padouk","padouks"},
"padova":{"padova","padovas"},
"padre":{"padre","padres","padri"},
"padrone":{"padrone","padrones","padroni"},
"padua":{"padua","paduas"},
"paean":{"paean","paeans"},
"paederast":{"paederast","paederasts"},
"paederasty":{"paederasties","paederasty"},
"paediatrician":{"paediatrician","paediatricians"},
"paediatrics":{"paediatrics","paediatricses"},
"paella":{"paella","paellas"},
"paeonia":{"paeonia","paeonias"},
"paeoniaceae":{"paeoniaceae","paeoniaceaes"},
"paeony":{"paeonies","paeony"},
"pagan":{"pagan","pagans"},
"paganism":{"paganism","paganisms"},
"page":{"page","paged","pages","paging"},
"pageant":{"pageant","pageants"},
"pageantry":{"pageantries","pageantry"},
"pageboy":{"pageboy","pageboys"},
"pagellus":{"pagellus","pagelluses"},
"paginate":{"paginate","paginated","paginates","paginating"},
"pagination":{"pagination","paginations"},
"pagoda":{"pagoda","pagodas"},
"pagophila":{"pagophila","pagophilas"},
"pagophilus":{"pagophilus","pagophiluses"},
"pagrus":{"pagrus","pagruses"},
"paguridae":{"paguridae","paguridaes"},
"pagurus":{"pagurus","paguruses"},
"pahautea":{"pahautea","pahauteas"},
"paigle":{"paigle","paigles"},
"pail":{"pail","pails"},
"pailful":{"pailful","pailfuls"},
"paillasse":{"paillasse","paillasses"},
"pain":{"pain","pained","paining","pains"},
"painfulness":{"painfulness","painfulnesses"},
"painkiller":{"painkiller","painkillers"},
"pains":{"pains","painses"},
"painstakingness":{"painstakingness","painstakingnesses"},
"paint":{"paint","painted","painting","paints"},
"painter":{"painter","painters"},
"painting":{"painting","paintings"},
"painty":{"paintier","paintiest","painty"},
"pair":{"pair","paired","pairing","pairs"},
"pairing":{"pairing","pairings"},
"paisa":{"paisa","paisas","paise"},
"paisano":{"paisan","paisano","paisanos"},
"paiute":{"paiute","paiutes"},
"pajama":{"pajama","pajamas"},
"pajamas":{"pajamas","pajamases"},
"pakchoi":{"pakchoi","pakchois"},
"pakistan":{"pakistan","pakistans"},
"pal":{"pal","palled","palling","pals"},
"palace":{"palace","palaces"},
"paladin":{"paladin","paladins"},
"palaemon":{"palaemon","palaemons"},
"palaemonidae":{"palaemonidae","palaemonidaes"},
"palaeobiology":{"palaeobiologies","palaeobiology"},
"palaeobotany":{"palaeobotanies","palaeobotany"},
"palaeoclimatology":{"palaeoclimatologies","palaeoclimatology"},
"palaeodendrology":{"palaeodendrologies","palaeodendrology"},
"palaeoencephalon":{"palaeoencephalon","palaeoencephalons"},
"palaeoethnography":{"palaeoethnographies","palaeoethnography"},
"palaeogeography":{"palaeogeographies","palaeogeography"},
"palaeogeology":{"palaeogeologies","palaeogeology"},
"palaeology":{"palaeologies","palaeology"},
"palaeontologist":{"palaeontologist","palaeontologists"},
"palaeontology":{"palaeontologies","palaeontology"},
"palaeopathology":{"palaeopathologies","palaeopathology"},
"palaeornithology":{"palaeornithologies","palaeornithology"},
"palaeozoology":{"palaeozoologies","palaeozoology"},
"palaestra":{"palaestra","palaestras"},
"palaetiology":{"palaetiologies","palaetiology"},
"palanquin":{"palanquin","palanquins"},
"palaquium":{"palaquium","palaquiums"},
"palas":{"palas","palases"},
"palatability":{"palatabilities","palatability"},
"palatableness":{"palatableness","palatablenesses"},
"palatalize":{"palatalize","palatalized","palatalizes","palatalizing"},
"palate":{"palate","palates"},
"palatinate":{"palatinate","palatinates"},
"palatine":{"palatine","palatines"},
"palaver":{"palaver","palavered","palavering","palavers"},
"pale":{"pale","paled","paler","pales","palest","paling"},
"palea":{"palea","paleae"},
"paleacrita":{"paleacrita","paleacritas"},
"paleencephalon":{"paleencephalon","paleencephalons"},
"paleness":{"paleness","palenesses"},
"paleoanthropology":{"paleoanthropologies","paleoanthropology"},
"paleobiology":{"paleobiologies","paleobiology"},
"paleobotany":{"paleobotanies","paleobotany"},
"paleocene":{"paleocene","paleocenes"},
"paleoclimatology":{"paleoclimatologies","paleoclimatology"},
"paleocortex":{"paleocortex","paleocortexes"},
"paleodendrology":{"paleodendrologies","paleodendrology"},
"paleoencephalon":{"paleoencephalon","paleoencephalons"},
"paleoethnography":{"paleoethnographies","paleoethnography"},
"paleogeography":{"paleogeographies","paleogeography"},
"paleogeology":{"paleogeologies","paleogeology"},
"paleology":{"paleologies","paleology"},
"paleontologist":{"paleontologist","paleontologists"},
"paleontology":{"paleontologies","paleontology"},
"paleopathology":{"paleopathologies","paleopathology"},
"paleornithology":{"paleornithologies","paleornithology"},
"paleozoic":{"paleozoic","paleozoics"},
"paleozoology":{"paleozoologies","paleozoology"},
"palestine":{"palestine","palestines"},
"palestra":{"palestra","palestrae","palestras"},
"paletiology":{"paletiologies","paletiology"},
"palette":{"palette","palettes"},
"palfrey":{"palfrey","palfreys"},
"paling":{"paling","palings"},
"palingenesis":{"palingeneses","palingenesis"},
"palinuridae":{"palinuridae","palinuridaes"},
"palinurus":{"palinurus","palinuruses"},
"palisade":{"palisade","palisaded","palisades","palisading"},
"paliurus":{"paliurus","paliuruses"},
"pall":{"pall","palled","palling","palls"},
"palladium":{"palladium","palladiums"},
"pallas":{"pallas","pallases"},
"pallbearer":{"pallbearer","pallbearers"},
"pallet":{"pallet","pallets"},
"pallette":{"pallette","pallettes"},
"palliasse":{"palliasse","palliasses"},
"palliate":{"palliate","palliated","palliates","palliating"},
"palliation":{"palliation","palliations"},
"pallidness":{"pallidness","pallidnesses"},
"pallium":{"pallia","pallium","palliums"},
"pallor":{"pallor","pallors"},
"pally":{"pallier","palliest","pally"},
"palm":{"palm","palmed","palming","palms"},
"palmaceae":{"palmaceae","palmaceaes"},
"palmae":{"palmae","palmaes"},
"palmales":{"palmales","palmaleses"},
"palmer":{"palmer","palmers"},
"palmetto":{"palmetto","palmettoes","palmettos"},
"palmist":{"palmist","palmists"},
"palmistry":{"palmistries","palmistry"},
"palmy":{"palmier","palmiest","palmy"},
"palmyra":{"palmyra","palmyras"},
"palometa":{"palometa","palometas"},
"palomino":{"palomino","palominos"},
"palooka":{"palooka","palookas"},
"palp":{"palp","palps"},
"palpability":{"palpabilities","palpability"},
"palpate":{"palpate","palpated","palpates","palpating"},
"palpation":{"palpation","palpations"},
"palpitate":{"palpitate","palpitated","palpitates","palpitating"},
"palpitation":{"palpitation","palpitations"},
"palpus":{"palpi","palpus"},
"palsgrave":{"palsgrave","palsgraves"},
"palsy":{"palsied","palsies","palsy","palsying"},
"palter":{"palter","paltered","paltering","palters"},
"paltering":{"paltering","palterings"},
"paltriness":{"paltriness","paltrinesses"},
"paltry":{"paltrier","paltriest","paltry"},
"pamper":{"pamper","pampered","pampering","pampers"},
"pampering":{"pampering","pamperings"},
"pampero":{"pampero","pamperos"},
"pamphlet":{"pamphlet","pamphlets"},
"pamphleteer":{"pamphleteer","pamphleteered","pamphleteering"},
"pan":{"pan","panned","panning","pans"},
"pan-broil":{"pan-broil","pan-broiled","pan-broiling"},
"pan-fry":{"pan-fry","panfried","panfrying"},
"panacea":{"panacea","panaceas"},
"panache":{"panache","panaches"},
"panadol":{"panadol","panadols"},
"panama":{"panama","panamas"},
"panamica":{"panamica","panamicas"},
"panamiga":{"panamiga","panamigas"},
"panatela":{"panatela","panatelas"},
"panax":{"panax","panaxes"},
"pancake":{"pancake","pancaked","pancakes","pancaking"},
"pancratium":{"pancratia","pancratium"},
"panda":{"panda","pandas"},
"pandanaceae":{"pandanaceae","pandanaceaes"},
"pandanales":{"pandanales","pandanaleses"},
"pandanus":{"pandanus","pandanuses"},
"pandar":{"pandar","pandars"},
"pandemonium":{"pandemonium","pandemoniums"},
"pander":{"pander","pandered","pandering","panders"},
"panderer":{"panderer","panderers"},
"pandion":{"pandion","pandions"},
"pandionidae":{"pandionidae","pandionidaes"},
"pandora":{"pandora","pandoras","pandores"},
"pandore":{"pandore","pandores"},
"pandowdy":{"pandowdies","pandowdy"},
"pandy":{"pandied","pandies","pandy","pandying"},
"pane":{"pane","paned","panes","paning"},
"panegyric":{"panegyric","panegyrics"},
"panegyrist":{"panegyrist","panegyrists"},
"panegyrize":{"panegyrize","panegyrized","panegyrizing"},
"panel":{"panel","paneled","paneling","panelled","panelling","panels"},
"paneling":{"paneling","panelings"},
"panelist":{"panelist","panelists"},
"panelling":{"panelling","panellings"},
"panetela":{"panetela","panetelas"},
"panetella":{"panetella","panetellas"},
"panettone":{"panettone","panettones","panettoni"},
"pang":{"pang","panged","panging","pangs"},
"panga":{"panga","pangas"},
"pangaea":{"pangaea","pangaeas"},
"pangea":{"pangea","pangeas"},
"pangolin":{"pangolin","pangolins"},
"panhandle":{"panhandle","panhandled","panhandling"},
"panhysterectomy":{"panhysterectomies","panhysterectomy"},
"panic":{"panic","panicked","panicking","panics"},
"panicum":{"panicum","panicums"},
"panipat":{"panipat","panipats"},
"panjabi":{"panjabi","panjabis"},
"panjandrum":{"panjandrum","panjandrums"},
"pannier":{"pannier","panniers"},
"panofsky":{"panofskies","panofsky"},
"panonychus":{"panonychus","panonychuses"},
"panoply":{"panoplies","panoply"},
"panorama":{"panorama","panoramas"},
"panpipe":{"panpipe","panpipes"},
"pansy":{"pansies","pansy"},
"pant":{"pant","panted","panting","pants"},
"pantaloon":{"pantaloon","pantaloons"},
"pantheism":{"pantheism","pantheisms"},
"panther":{"panther","panthers"},
"panthera":{"panthera","pantheras"},
"pantie":{"pantie","panties"},
"panting":{"panting","pantings"},
"panto":{"panto","pantos"},
"pantomime":{"pantomime","pantomimed","pantomimes","pantomiming"},
"pantomimer":{"pantomimer","pantomimers"},
"pantomimist":{"pantomimist","pantomimists"},
"pantothen":{"pantothen","pantothens"},
"pantotheria":{"pantotheria","pantotherias"},
"pantry":{"pantries","pantry"},
"pantryman":{"pantryman","pantrymen"},
"panty":{"panties","panty"},
"pantywaist":{"pantywaist","pantywaists"},
"pap":{"pap","paps"},
"papa":{"papa","papas"},
"papacy":{"papacies","papacy"},
"papaia":{"papaia","papaias"},
"paparazzo":{"paparazzi","paparazzo"},
"papaver":{"papaver","papavers"},
"papaveraceae":{"papaveraceae","papaveraceaes"},
"papaverales":{"papaverales","papaveraleses"},
"papaw":{"papaw","papaws"},
"papaya":{"papaya","papayas"},
"paper":{"paper","papered","papering","papers"},
"paperback":{"paperback","paperbacks"},
"paperboard":{"paperboard","paperboards"},
"paperclip":{"paperclip","paperclips"},
"paperer":{"paperer","paperers"},
"paperhanger":{"paperhanger","paperhangers"},
"paperhanging":{"paperhanging","paperhangings"},
"papering":{"papering","paperings"},
"paperknife":{"paperknife","paperknives"},
"papers":{"papers","paperses"},
"papeterie":{"papeterie","papeteries"},
"paphiopedilum":{"paphiopedilum","paphiopedilums"},
"papilionaceae":{"papilionaceae","papilionaceaes"},
"papilionoideae":{"papilionoideae","papilionoideaes"},
"papilla":{"papilla","papillae"},
"papilloma":{"papilloma","papillomas","papillomata"},
"papillon":{"papillon","papillons"},
"papio":{"papio","papios"},
"papoose":{"papoose","papooses"},
"papooseroot":{"papooseroot","papooseroots"},
"pappa":{"pappa","pappas"},
"pappoose":{"pappoose","pappooses"},
"pappus":{"pappi","pappus"},
"pappy":{"pappier","pappies","pappiest","pappy"},
"paprika":{"paprika","paprikas"},
"paprilus":{"paprilus","papriluses"},
"papua":{"papua","papuas"},
"papuan":{"papuan","papuans"},
"papula":{"papula","papulae"},
"papule":{"papule","papules"},
"papyrus":{"papyri","papyrus","papyruses"},
"par":{"par","pars"},
"para":{"para","paras"},
"parabasis":{"parabases","parabasis"},
"parable":{"parable","parables"},
"parabola":{"parabola","parabolas"},
"parabolize":{"parabolize","parabolized","parabolizing"},
"paracentesis":{"paracenteses","paracentesis"},
"paracheirodon":{"paracheirodon","paracheirodons"},
"parachute":{"parachute","parachuted","parachutes","parachuting"},
"parachuter":{"parachuter","parachuters"},
"parachuting":{"parachuting","parachutings"},
"parachutist":{"parachutist","parachutists"},
"parade":{"parade","paraded","parades","parading"},
"parader":{"parader","paraders"},
"paradiddle":{"paradiddle","paradiddles"},
"paradigm":{"paradigm","paradigms"},
"paradisaeidae":{"paradisaeidae","paradisaeidaes"},
"paradise":{"paradise","paradises"},
"paradox":{"paradox","paradoxes"},
"paradoxurus":{"paradoxurus","paradoxuruses"},
"paradrop":{"paradrop","paradropped","paradropping"},
"paraesthesia":{"paraesthesia","paraesthesias"},
"paraffin":{"paraffin","paraffined","paraffining","paraffins"},
"paragon":{"paragon","paragons"},
"paragraph":{"paragraph","paragraphed","paragraphing","paragraphs"},
"parakeet":{"parakeet","parakeets"},
"paralanguage":{"paralanguage","paralanguages"},
"paralegal":{"paralegal","paralegals"},
"paraleipsis":{"paraleipses","paraleipsis"},
"paralepsis":{"paralepses","paralepsis"},
"paralichthys":{"paralichthys","paralichthyses"},
"paralipsis":{"paraleipses","paralipses","paralipsis"},
"paralithodes":{"paralithodes","paralithodeses"},
"parallel":{"parallel","paralleled","paralleling","parallelled","parallelling","parallels"},
"parallelepiped":{"parallelepiped","parallelepipeds"},
"parallelepipedon":{"parallelepipedon","parallelepipedons"},
"parallelism":{"parallelism","parallelisms"},
"parallelopiped":{"parallelopiped","parallelopipeds"},
"parallelopipedon":{"parallelopipedon","parallelopipedons"},
"paralysis":{"paralyses","paralysis"},
"paralyze":{"paralyze","paralyzed","paralyzes","paralyzing"},
"paramaribo":{"paramaribo","paramaribos"},
"paramecia":{"paramecia","paramecias"},
"paramecium":{"paramecia","paramecium","parameciums"},
"parament":{"parament","paramenta","paraments"},
"parameter":{"parameter","parameters"},
"paramilitary":{"paramilitaries","paramilitary"},
"paramo":{"paramo","paramos"},
"paramount":{"paramount","paramounts"},
"paramour":{"paramour","paramours"},
"paramyxovirus":{"paramyxovirus","paramyxoviruses"},
"parana":{"parana","paranas"},
"paranoiac":{"paranoiac","paranoiacs"},
"paranoid":{"paranoid","paranoids"},
"paranthias":{"paranthias","paranthiases"},
"paranthropus":{"paranthropus","paranthropuses"},
"parapet":{"parapet","parapets"},
"paraphernalia":{"paraphernalia","paraphernalias"},
"paraphrase":{"paraphrase","paraphrased","paraphrases","paraphrasing"},
"paraphrasis":{"paraphrases","paraphrasis"},
"paraphrenia":{"paraphrenia","paraphrenias"},
"paraphysis":{"paraphyses","paraphysis"},
"parapodium":{"parapodia","parapodium"},
"parapsychology":{"parapsychologies","parapsychology"},
"paraquet":{"paraquet","paraquets"},
"parascalops":{"parascalops","parascalopses"},
"paraselene":{"paraselenae","paraselene"},
"parashah":{"parashah","parashoth"},
"parasitaxus":{"parasitaxus","parasitaxuses"},
"parasite":{"parasite","parasites"},
"parasitize":{"parasitize","parasitized","parasitizing"},
"parasol":{"parasol","parasols"},
"parastichy":{"parastichies","parastichy"},
"parasympathetic":{"parasympathetic","parasympathetics"},
"parasyntheton":{"parasyntheta","parasyntheton"},
"parathelypteris":{"parathelypteris","parathelypterises"},
"parathyroid":{"parathyroid","parathyroids"},
"paratrooper":{"paratrooper","paratroopers"},
"paratyphoid":{"paratyphoid","paratyphoids"},
"parazoa":{"parazoa","parazoas"},
"parazoan":{"parazoan","parazoans"},
"parboil":{"parboil","parboiled","parboiling","parboils"},
"parbuckle":{"parbuckle","parbuckled","parbuckling"},
"parcel":{"parcel","parceled","parceling","parcelled","parcelling","parcels"},
"parceling":{"parceling","parcelings"},
"parcelling":{"parcelling","parcellings"},
"parch":{"parch","parched","parches","parching"},
"parchment":{"parchment","parchments"},
"pardner":{"pardner","pardners"},
"pardon":{"pardon","pardoned","pardoning","pardons"},
"pare":{"pare","pared","pares","paring"},
"paregoric":{"paregoric","paregorics"},
"parent":{"parent","parented","parenting","parents"},
"parent-in-law":{"parent-in-law","patents-in-law"},
"parentage":{"parentage","parentages"},
"parenthesis":{"parentheses","parenthesis"},
"parenthesize":{"parenthesize","parenthesized","parenthesizes","parenthesizing"},
"parer":{"parer","parers"},
"parergon":{"parerga","parergon"},
"paresthesia":{"paresthesia","paresthesias"},
"pareu":{"pareu","pareus"},
"parget":{"parget","pargeted","pargeting","pargets","pargetted","pargetting"},
"pargeting":{"pargeting","pargetings"},
"parhelion":{"parhelia","parhelion","parhelions"},
"pari-mutuel":{"pari-mutuel","pari-mutuels","paris-mutuels"},
"pariah":{"pariah","pariahs"},
"paridae":{"paridae","paridaes"},
"paries":{"paries","parieses"},
"parietales":{"parietales","parietaleses"},
"parietaria":{"parietaria","parietarias"},
"paring":{"paring","parings"},
"parings":{"parings","paringses"},
"paris":{"paris","parises"},
"parish":{"parish","parishes"},
"parity":{"parities","parity"},
"park":{"park","parked","parking","parks"},
"parka":{"parka","parkas"},
"parkeriaceae":{"parkeriaceae","parkeriaceaes"},
"parkia":{"parkia","parkias"},
"parkinglot":{"parkinglot","parkinglots"},
"parkinson":{"parkinson","parkinsons"},
"parkinsonia":{"parkinsonia","parkinsonias"},
"parkinsonism":{"parkinsonism","parkinsonisms"},
"parkway":{"parkway","parkways"},
"parky":{"parkier","parkiest","parky"},
"parlance":{"parlance","parlances"},
"parlay":{"parlay","parlayed","parlaying","parlays"},
"parley":{"parley","parleyed","parleying","parleys"},
"parliament":{"parliament","parliaments"},
"parliamentarian":{"parliamentarian","parliamentarians"},
"parlor":{"parlor","parlors"},
"parlormaid":{"parlormaid","parlormaids"},
"parlour":{"parlour","parlours"},
"parlourmaid":{"parlourmaid","parlourmaids"},
"parmelia":{"parmelia","parmelias"},
"parmeliaceae":{"parmeliaceae","parmeliaceaes"},
"parnassia":{"parnassia","parnassias"},
"parnassus":{"parnassus","parnassuses"},
"parochetus":{"parochetus","parochetuses"},
"parodist":{"parodist","parodists"},
"parody":{"parodied","parodies","parody","parodying"},
"parole":{"parole","paroled","paroles","paroling"},
"parolee":{"parolee","parolees"},
"paronomasia":{"paronomasia","paronomasias"},
"paronychia":{"paronychia","paronychias"},
"parophrys":{"parophrys","parophryses"},
"paroquet":{"paroquet","paroquets"},
"paroxysm":{"paroxysm","paroxysms"},
"parquet":{"pardqueted","parquet","parqueted","parqueting","parquets"},
"parqueterie":{"parqueterie","parqueteries"},
"parquetry":{"parquetries","parquetry"},
"parr":{"parr","parrs"},
"parrakeet":{"parrakeet","parrakeets"},
"parroket":{"parroket","parrokets"},
"parroquet":{"parroquet","parroquets"},
"parrot":{"parrot","parroted","parroting","parrots"},
"parrotfish":{"parrotfish","parrotfishes"},
"parrotia":{"parrotia","parrotias"},
"parrotiopsis":{"parrotiopses","parrotiopsis"},
"parry":{"parried","parries","parry","parrying"},
"parse":{"parse","parsed","parsing"},
"parsec":{"parsec","parsecs"},
"parsee":{"parsee","parsees"},
"parseeism":{"parseeism","parseeisms"},
"parsi":{"parsi","parsis"},
"parsiism":{"parsiism","parsiisms"},
"parsimoniousness":{"parsimoniousness","parsimoniousnesses"},
"parsimony":{"parsimonies","parsimony"},
"parsley":{"parsley","parsleys"},
"parsnip":{"parsnip","parsnips"},
"parson":{"parson","parsons"},
"parsonage":{"parsonage","parsonages"},
"part":{"part","parted","parting","parts"},
"partake":{"partake","partaken","partakes","partaking","partook"},
"partaker":{"partaker","partakers"},
"parterre":{"parterre","parterres"},
"parthenium":{"parthenium","partheniums"},
"parthenocissus":{"parthenocissus","parthenocissuses"},
"parthenogenesis":{"parthenogeneses","parthenogenesis"},
"parthenogeny":{"parthenogenies","parthenogeny"},
"partiality":{"partialities","partiality"},
"participant":{"participant","participants"},
"participate":{"participate","participated","participates","participating"},
"participation":{"participation","participations"},
"participle":{"participle","participles"},
"particle":{"particle","particles"},
"particular":{"particular","particulars"},
"particularity":{"particularities","particularity"},
"particularization":{"particularization","particularizations"},
"particularize":{"particularize","particularized","particularizes","particularizing"},
"parting":{"parting","partings"},
"partisan":{"partisan","partisans"},
"partisanship":{"partisanship","partisanships"},
"partita":{"partita","partitas"},
"partition":{"partition","partitioned","partitioning","partitions"},
"partitioning":{"partitioning","partitionings"},
"partizan":{"partizan","partizans"},
"partner":{"partner","partnered","partnering","partners"},
"partnership":{"partnership","partnerships"},
"partridge":{"partridge","partridges"},
"partridgeberry":{"partridgeberries","partridgeberry"},
"parturiency":{"parturiencies","parturiency"},
"parturition":{"parturition","parturitions"},
"party":{"parties","party"},
"parula":{"parula","parulas"},
"parulidae":{"parulidae","parulidaes"},
"parulis":{"parulides","parulis"},
"parus":{"parus","paruses"},
"parvati":{"parvati","parvatis"},
"parvenu":{"parvenu","parvenus"},
"parvo":{"parvo","parvos"},
"parvovirus":{"parvovirus","parvoviruses"},
"pas":{"pas"},
"pas-de-calais":{"pas-de-calais","pas-de-calaises"},
"pasang":{"pasang","pasangs"},
"pascal":{"pascal","pascals"},
"pasch":{"pasch","pasches"},
"pascha":{"pascha","paschas"},
"pase":{"pase","pases"},
"paseo":{"paseo","paseos"},
"pasha":{"pasha","pashas"},
"pashto":{"pashto","pashtos"},
"paso_doble":{"pasos_dobles","paso_doble","paso_dobles"},
"paspalum":{"paspalum","paspalums"},
"pasqueflower":{"pasqueflower","pasqueflowers"},
"pasquinade":{"pasquinade","pasquinaded","pasquinades","pasquinading","pasquinased"},
"pass":{"pass","passed","passes","passing"},
"passacaglia":{"passacaglia","passacaglias"},
"passado":{"passado","passadoes","passados"},
"passage":{"passage","passaged","passages","passaging"},
"passageway":{"passageway","passageways"},
"passbook":{"passbook","passbooks"},
"passe-partout":{"passe-partout","passe-partouts"},
"passementerie":{"passementerie","passementeries"},
"passenger":{"passenger","passengers"},
"passepied":{"passepied","passepieds"},
"passer":{"passer","passers"},
"passer-by":{"passer-by","passers-by"},
"passerby":{"passerby","passersby"},
"passeres":{"passeres","passereses"},
"passeridae":{"passeridae","passeridaes"},
"passeriformes":{"passeriformes","passeriformeses"},
"passerina":{"passerina","passerinas"},
"passerine":{"passerine","passerines"},
"passero":{"passero","passeros"},
"passiflora":{"passiflora","passifloras"},
"passifloraceae":{"passifloraceae","passifloraceaes"},
"passing":{"passing","passings"},
"passion":{"passion","passions"},
"passionateness":{"passionateness","passionatenesses"},
"passionflower":{"passionflower","passionflowers"},
"passivate":{"passivate","passivated","passivating"},
"passive":{"passive","passives"},
"passiveness":{"passiveness","passivenesses"},
"passivism":{"passivism","passivisms"},
"passivity":{"passivities","passivity"},
"passkey":{"passkey","passkeys"},
"passover":{"passover","passovers"},
"passport":{"passport","passports"},
"passus":{"passus","passuses"},
"password":{"password","passwords"},
"past":{"past","pasts"},
"pasta":{"pasta","pastas"},
"paste":{"paste","pasted","pastes","pasting"},
"pastel":{"pastel","pastels"},
"pastern":{"pastern","pasterns"},
"pasteur":{"pasteur","pasteurs"},
"pasteurellosis":{"pasteurelloses","pasteurellosis"},
"pasteurize":{"pasteurize","pasteurized","pasteurizing"},
"pasticcio":{"pasticci","pasticcio"},
"pastiche":{"pastiche","pastiches"},
"pastil":{"pastil","pastils"},
"pastille":{"pastille","pastilles"},
"pastime":{"pastime","pastimes"},
"pastinaca":{"pastinaca","pastinacas"},
"pasto":{"pasto","pastos"},
"pastor":{"pastor","pastors","postored","postoring"},
"pastoral":{"pastoral","pastorals"},
"pastorale":{"pastorale","pastorales","pastorali"},
"pastorate":{"pastorate","pastorates"},
"pastorium":{"pastorium","pastoriums"},
"pastorship":{"pastorship","pastorships"},
"pastry":{"pastries","pastry"},
"pasturage":{"pasturage","pasturages"},
"pasture":{"pasture","pastured","pastures","pasturing"},
"pastureland":{"pastureland","pasturelands"},
"pasty":{"pastier","pasties","pastiest","pasty"},
"pat":{"pat","pats","patted","patting"},
"patagium":{"patagia","patagium"},
"patas":{"patas","patases"},
"patavium":{"patavium","pataviums"},
"patch":{"patch","patched","patches","patching"},
"patchboard":{"patchboard","patchboards"},
"patchouli":{"patchouli","patchoulis"},
"patchouly":{"patchoulies","patchouly"},
"patchwork":{"patchwork","patchworks"},
"patchy":{"patchier","patchiest","patchy"},
"pate":{"pate","pates"},
"patella":{"patella","patellae","patellas"},
"patellidae":{"patellidae","patellidaes"},
"patent":{"patent","patented","patenting","patents"},
"pater":{"pater","paters"},
"paterfamilias":{"paterfamilias","paterfamiliases","patresfamilias"},
"paternity":{"paternities","paternity"},
"path":{"path","paths"},
"pathan":{"pathan","pathans"},
"pathfinder":{"pathfinder","pathfinders"},
"pathologist":{"pathologist","pathologists"},
"pathology":{"pathologies","pathology"},
"pathos":{"pathos","pathoses"},
"pathway":{"pathway","pathways"},
"patience":{"patience","patiences"},
"patient":{"patient","patients"},
"patina":{"patina","patinas"},
"patinate":{"patinate","patinated","patinates","patinating"},
"patio":{"patio","patios"},
"patness":{"patness","patnesses"},
"patois":{"patois","patoises"},
"patriarch":{"patriarch","patriarches","patriarchs"},
"patriarchate":{"patriarchate","patriarchates"},
"patriarchy":{"patriarchies","patriarchy"},
"patrician":{"patrician","patricians"},
"patrick":{"patrick","patricks"},
"patrikin":{"patrikin","patrikins"},
"patrilineage":{"patrilineage","patrilineages"},
"patrimony":{"patrimonies","patrimony"},
"patriot":{"patriot","patriots"},
"patriotism":{"patriotism","patriotisms"},
"patrisib":{"patrisib","patrisibs"},
"patrol":{"patrol","patrolled","patrolling","patrols"},
"patrolling":{"patrolling","patrollings"},
"patrolman":{"patrolman","patrolmen"},
"patrolwoman":{"patrolwoman","patrolwomen"},
"patron":{"patron","patrons"},
"patronage":{"patronage","patronages"},
"patronize":{"patronize","patronized","patronizes","patronizing"},
"patronne":{"patronne","patronnes"},
"patsy":{"patsies","patsy"},
"patten":{"patten","pattens"},
"patter":{"patter","pattered","pattering","patters"},
"pattern":{"pattern","patterned","patterning","patterns"},
"patty":{"patties","patty"},
"paucity":{"paucities","paucity"},
"paul":{"paul","pauls"},
"paulownia":{"paulownia","paulownias"},
"paunch":{"paunch","paunches"},
"paunchiness":{"paunchiness","paunchinesses"},
"paunchy":{"paunchier","paunchiest","paunchy"},
"pauper":{"pauper","paupers"},
"pauperism":{"pauperism","pauperisms"},
"pauperization":{"pauperization","pauperizations"},
"pauperize":{"pauperize","pauperized","pauperizes","pauperizing"},
"pauropoda":{"pauropoda","pauropodas"},
"pause":{"pause","paused","pauses","pausing"},
"pave":{"pave","paved","paving"},
"pavement":{"pavement","pavements"},
"pavilion":{"pavilion","pavilioned","pavilioning","pavilions"},
"paving":{"paving","pavings"},
"pavior":{"pavior","paviors"},
"paviour":{"paviour","paviours"},
"pavis":{"pavis","pavises"},
"pavise":{"pavise","pavises"},
"pavlov":{"pavlov","pavlovs"},
"pavo":{"pavo","pavos"},
"paw":{"paw","pawed","pawing","paws"},
"pawky":{"pawkier","pawkiest","pawky"},
"pawl":{"pawl","pawls"},
"pawn":{"pawn","pawned","pawning","pawns"},
"pawnee":{"pawnee","pawnees"},
"pawning":{"pawning","pawnings"},
"pawnshop":{"pawnshop","pawnshops"},
"pawpaw":{"pawpaw","pawpaws"},
"pax":{"pax","paxes"},
"paxto":{"paxto","paxtos"},
"pay":{"paid","pay","paying","pays"},
"pay-phone":{"pay-phone","pay-phones"},
"pay-station":{"pay-station","pay-stations"},
"paycheck":{"paycheck","paychecks"},
"paye":{"paye","payes"},
"payena":{"payena","payenas"},
"payer":{"payer","payers"},
"paygrade":{"paygrade","paygrades"},
"paying":{"paying","payings"},
"payload":{"payload","payloads"},
"payment":{"payment","payments"},
"payoff":{"payoff","payoffs"},
"payroll":{"payroll","payrolls"},
"paysheet":{"paysheet","paysheets"},
"pb":{"pb","pbs"},
"pbs":{"pbs","pbses"},
"pc":{"pc","pcs"},
"pcp":{"pcp","pcps"},
"pct":{"pct","pcts"},
"pd":{"pd","pds"},
"pdl":{"pdl","pdls"},
"pe-tsai":{"pe-tsai","pe-tsais"},
"pea":{"pea","peas"},
"pea-souper":{"pea-souper","pea-soupers"},
"peace":{"peace","peaces"},
"peaceableness":{"peaceableness","peaceablenesses"},
"peacefulness":{"peacefulness","peacefulnesses"},
"peacemaker":{"peacemaker","peacemakers"},
"peacenik":{"peacenik","peaceniks"},
"peach":{"peach","peached","peaches","peaching"},
"peachwood":{"peachwood","peachwoods"},
"peachy":{"peachier","peachiest","peachy"},
"peacoat":{"peacoat","peacoats"},
"peacock":{"peacock","peacocked","peacocking","peacocks"},
"peafowl":{"peafowl","peafowls"},
"peag":{"peag","peags"},
"peak":{"peak","peaked","peaking","peaks"},
"peal":{"peal","pealed","pealing","peals"},
"pealing":{"pealing","pealings"},
"pean":{"pean","peans"},
"peanut":{"peanut","peanuts"},
"pear":{"pear","pears"},
"pearl":{"pearl","pearled","pearling","pearls"},
"pearler":{"pearler","pearlers"},
"pearlweed":{"pearlweed","pearlweeds"},
"pearlwort":{"pearlwort","pearlworts"},
"pearly":{"pearlies","pearly"},
"peasant":{"peasant","peasants"},
"pease":{"pease","peasen","peases"},
"peasecod":{"peasecod","peasecods"},
"peat":{"peat","peats"},
"peaty":{"peatier","peatiest","peaty"},
"peavey":{"peavey","peaveys"},
"peavy":{"peavies","peavy"},
"peba":{"peba","pebas"},
"pebble":{"pebble","pebbled","pebbles","pebbling"},
"pecan":{"pecan","pecans"},
"peccadillo":{"peccadillo","peccadilloes","peccadillos"},
"peccary":{"peccaries","peccary"},
"peccavi":{"peccavi","peccavis"},
"peck":{"peck","pecked","pecking","pecks"},
"pecker":{"pecker","peckers"},
"pecky":{"peckier","peckiest","pecky"},
"pecos":{"pecos","pecoses"},
"pecs":{"pecs","pecses"},
"pecten":{"pecten","pectens","pectines"},
"pectinibranchia":{"pectinibranchia","pectinibranchias"},
"pectinidae":{"pectinidae","pectinidaes"},
"pectoral":{"pectoral","pectorals"},
"pectoralis":{"pectoralis","pectoralises"},
"pectus":{"pectus","pectuses"},
"peculate":{"peculate","peculated","peculates","peculating"},
"peculation":{"peculation","peculations"},
"peculator":{"peculator","peculators"},
"peculiarity":{"peculiarities","peculiarity"},
"peculium":{"peculia","peculium"},
"pedagogue":{"pedagogue","pedagogues"},
"pedagogy":{"pedagogies","pedagogy"},
"pedal":{"pedal","pedaled","pedaling","pedalled","pedalling","pedals"},
"pedaler":{"pedaler","pedalers"},
"pedaliaceae":{"pedaliaceae","pedaliaceaes"},
"pedaller":{"pedaller","pedallers"},
"pedalo":{"pedalo","pedaloes","pedalos"},
"pedant":{"pedant","pedants"},
"pedantry":{"pedantries","pedantry"},
"peddle":{"peddle","peddled","peddles","peddling"},
"peddler":{"peddler","peddlers"},
"peddling":{"peddling","peddlings"},
"pederast":{"pederast","pederasts"},
"pederasty":{"pederasties","pederasty"},
"pedesis":{"pedeses","pedesis"},
"pedestal":{"pedestal","pedestaled","pedestaling","pedestalled","pedestalling","pedestals"},
"pedestrian":{"pedestrian","pedestrians"},
"pedestrianize":{"pedestrianize","pedestrianized","pedestrianizing"},
"pediatrician":{"pediatrician","pediatricians"},
"pediatrics":{"pediatrics","pediatricses"},
"pediatrist":{"pediatrist","pediatrists"},
"pedicab":{"pedicab","pedicabs"},
"pediculati":{"pediculati","pediculatis"},
"pediculidae":{"pediculidae","pediculidaes"},
"pediculosis":{"pediculoses","pediculosis"},
"pediculus":{"pediculus","pediculuses"},
"pedigree":{"pedigree","pedigrees"},
"pedilanthus":{"pedilanthus","pedilanthuses"},
"pediocactus":{"pediocactus","pediocactuses"},
"pedioecetes":{"pedioecetes","pedioeceteses"},
"pedionomus":{"pedionomus","pedionomuses"},
"pedipalpi":{"pedipalpi","pedipalpis"},
"pedlar":{"pedlar","pedlars"},
"pedwood":{"pedwood","pedwoods"},
"pee":{"pee","peed","peeing","pees"},
"peeing":{"peeing","peeings"},
"peek":{"peek","peeked","peeking","peeks"},
"peekaboo":{"peekaboo","peekaboos"},
"peel":{"peel","peeled","peeling","peels"},
"peeler":{"peeler","peelers"},
"peen":{"peen","peened","peening"},
"peep":{"peep","peeped","peeping","peeps"},
"peeper":{"peeper","peepers"},
"peephole":{"peephole","peepholes"},
"peepshow":{"peepshow","peepshows"},
"peepul":{"peepul","peepuls"},
"peer":{"peer","peered","peering","peers"},
"peerage":{"peerage","peerages"},
"peeress":{"peeress","peeresses"},
"peeve":{"peeve","peeved","peeving"},
"peevishness":{"peevishness","peevishnesses"},
"peewee":{"peewee","peewees"},
"peewit":{"peewit","peewits"},
"peg":{"peg","pegged","pegging","pegs"},
"pegasus":{"pegasus","pegasuses"},
"pegleg":{"pegleg","peglegs"},
"peignoir":{"peignoir","peignoirs"},
"peiping":{"peiping","peipings"},
"peirce":{"peirce","peirces"},
"peireskia":{"peireskia","peireskias"},
"pekan":{"pekan","pekans"},
"peke":{"peke","pekes"},
"pekinese":{"pekinese","pekineses"},
"peking":{"peking","pekings"},
"pekingese":{"pekingese","pekingeses"},
"pekoe":{"pekoe","pekoes"},
"pel":{"pel","pels"},
"pelargonium":{"pelargonium","pelargoniums"},
"pelecanidae":{"pelecanidae","pelecanidaes"},
"pelecaniformes":{"pelecaniformes","pelecaniformeses"},
"pelecanoididae":{"pelecanoididae","pelecanoididaes"},
"pelecanus":{"pelecanus","pelecanuses"},
"pelecypod":{"pelecypod","pelecypods"},
"pelf":{"pelf","pelves"},
"peliosis":{"pelioses","peliosis"},
"pellaea":{"pellaea","pellaeas"},
"pellet":{"pellet","pelleted","pelleting","pellets"},
"pelletize":{"pelletize","pelletized","pelletizing"},
"pellicularia":{"pellicularia","pellicularias"},
"pellitory":{"pellitories","pellitory"},
"pellitory-of-spain":{"pellitory-of-spain","pellitory-of-spains"},
"pellitory-of-the-wall":{"pellitory-of-the-wall","pellitory-of-the-walls"},
"pellucidity":{"pellucidities","pellucidity"},
"pellucidness":{"pellucidness","pellucidnesses"},
"pelmet":{"pelmet","pelmets"},
"pelobatidae":{"pelobatidae","pelobatidaes"},
"peloponnese":{"peloponnese","peloponneses"},
"peloponnesus":{"peloponnesus","peloponnesuses"},
"pelorus":{"pelorus","peloruses"},
"pelota":{"pelota","pelotas"},
"pelt":{"pelt","pelted","pelting","pelts"},
"peltandra":{"peltandra","peltandras"},
"pelting":{"pelting","peltings"},
"peltiphyllum":{"peltiphyllum","peltiphyllums"},
"peltry":{"peltries","peltry"},
"peludo":{"peludo","peludos"},
"pelvis":{"pelves","pelvis","pelvises"},
"pelycosauria":{"pelycosauria","pelycosaurias"},
"pembroke":{"pembroke","pembrokes"},
"pempheridae":{"pempheridae","pempheridaes"},
"pen":{"pen","penned","penning","pens"},
"pen-friend":{"pen-friend","pen-friends"},
"penalization":{"penalization","penalizations"},
"penalize":{"penalize","penalized","penalizes","penalizing"},
"penalty":{"penalties","penalty"},
"penance":{"penance","penanced","penances","penancing"},
"penchant":{"penchant","penchants"},
"pencil":{"pencil","penciled","penciling","pencilled","pencilling","pencils"},
"pend":{"pend","pended","pending"},
"pendant":{"pendant","pendants"},
"pendency":{"pendencies","pendency"},
"pendulum":{"pendulum","pendulums"},
"peneidae":{"peneidae","peneidaes"},
"penelope":{"penelope","penelopes"},
"penetrability":{"penetrabilities","penetrability"},
"penetrate":{"penetrate","penetrated","penetrates","penetrating"},
"penetration":{"penetration","penetrations"},
"peneus":{"peneus","peneuses"},
"penguin":{"penguin","penguins"},
"penicillium":{"penicillia","penicillium","penicilliums"},
"peninsula":{"peninsula","peninsulas"},
"peninsular":{"peninsular","peninsulars"},
"penis":{"penes","penis","penises"},
"penitence":{"penitence","penitences"},
"penitent":{"penitent","penitents"},
"penitentiary":{"penitentiaries","penitentiary"},
"penknife":{"penknife","penknives"},
"penman":{"penman","penmen"},
"penmanship":{"penmanship","penmanships"},
"penna":{"penna","pennae"},
"pennant":{"pennant","pennants"},
"pennatula":{"pennatula","pennatulas"},
"pennatulidae":{"pennatulidae","pennatulidaes"},
"penni":{"penni","pennia","pennis"},
"pennilessness":{"pennilessness","pennilessnesses"},
"penning":{"penning","pennings"},
"pennisetum":{"pennisetum","pennisetums"},
"pennon":{"pennon","pennons"},
"pennoncel":{"pennoncel","pennoncels"},
"pennoncelle":{"pennoncelle","pennoncelles"},
"pennsylvania":{"pennsylvania","pennsylvanias"},
"pennsylvanian":{"pennsylvanian","pennsylvanians"},
"penny":{"pence","pennies","penny"},
"penny-dreadful":{"penny-dreadful","penny-dreadfulls"},
"penny-pinching":{"penny-pinching","penny-pinchings"},
"pennyroyal":{"pennyroyal","pennyroyals"},
"pennywhistle":{"pennywhistle","pennywhistles"},
"pennyworth":{"pennyworth","pennyworths"},
"penocha":{"penocha","penochas"},
"penology":{"penologies","penology"},
"penoncel":{"penoncel","penoncels"},
"penpusher":{"penpusher","penpushers"},
"pensee":{"pensee","pensees"},
"pension":{"pension","pensioned","pensioning","pensions"},
"pensionary":{"pensionaries","pensionary"},
"pensioner":{"pensioner","pensioners"},
"pensiveness":{"pensiveness","pensivenesses"},
"penstemon":{"penstemon","penstemons"},
"penstock":{"penstock","penstocks"},
"pentacle":{"pentacle","pentacles"},
"pentad":{"pentad","pentads"},
"pentagram":{"pentagram","pentagrams"},
"pentahedron":{"pentahedra","pentahedron","pentahedrons"},
"pentail":{"pentail","pentails"},
"pentamethylenetetrazol":{"pentamethylenetetrazol","pentamethylenetetrazols"},
"pentarchy":{"pentarchies","pentarchy"},
"pentastomid":{"pentastomid","pentastomids"},
"pentastomida":{"pentastomida","pentastomidas"},
"pentateuch":{"pentateuch","pentateuches"},
"pentecost":{"pentecost","pentecosts"},
"pentecostal":{"pentecostal","pentecostals"},
"pentecostalist":{"pentecostalist","pentecostalists"},
"penthouse":{"penthouse","penthouses"},
"pentimento":{"pentimenti","pentimento"},
"pentobarbital":{"pentobarbital","pentobarbitals"},
"pentothal":{"pentothal","pentothals"},
"pentylenetetrazol":{"pentylenetetrazol","pentylenetetrazols"},
"penuche":{"penuche","penuches"},
"penult":{"penult","penults"},
"penultima":{"penultima","penultimas"},
"penultimate":{"penultimate","penultimates"},
"penumbra":{"penumbra","penumbrae","penumbras"},
"penuriousness":{"penuriousness","penuriousnesses"},
"penury":{"penuries","penury"},
"peon":{"peon","peons"},
"peony":{"peonies","peony"},
"people":{"people","peopled","peoples","peopling"},
"pep":{"pep","pepped","pepping","peps"},
"pepcid":{"pepcid","pepcids"},
"peplos":{"peplos","peploses"},
"peplum":{"pepla","peplum","peplums"},
"peplus":{"peplus","pepluses"},
"pepo":{"pepo","pepos"},
"pepper":{"pepper","peppered","peppering","peppers"},
"peppercorn":{"peppercorn","peppercorns"},
"pepperidge":{"pepperidge","pepperidges"},
"pepperiness":{"pepperiness","pepperinesses"},
"peppermint":{"peppermint","peppermints"},
"peppershaker":{"peppershaker","peppershakers"},
"pepperwood":{"pepperwood","pepperwoods"},
"pepperwort":{"pepperwort","pepperworts"},
"peppiness":{"peppiness","peppinesses"},
"peppy":{"peppier","peppiest","peppy"},
"pepsi":{"pepsi","pepsis"},
"peptidase":{"peptidase","peptidases"},
"peptization":{"peptization","peptizations"},
"peptize":{"peptize","peptized","peptizing"},
"peptizing":{"peptizing","peptizings"},
"pequot":{"pequot","pequots"},
"perambulate":{"perambulate","perambulated","perambulates","perambulating"},
"perambulation":{"perambulation","perambulations"},
"perambulator":{"perambulator","perambulators"},
"peramelidae":{"peramelidae","peramelidaes"},
"perca":{"perca","percas"},
"perceive":{"perceive","perceived","perceives","perceiving"},
"perceiver":{"perceiver","perceivers"},
"perceiving":{"perceiving","perceivings"},
"percent":{"percent","percents"},
"percentage":{"percentage","percentages"},
"percept":{"percept","percepts"},
"perception":{"perception","perceptions"},
"perceptiveness":{"perceptiveness","perceptivenesses"},
"perceptivity":{"perceptivities","perceptivity"},
"perch":{"perch","perched","perches","perching"},
"perchloromethane":{"perchloromethane","perchloromethanes"},
"percidae":{"percidae","percidaes"},
"perciformes":{"perciformes","perciformeses"},
"percina":{"percina","percinas"},
"percoid":{"percoid","percoids"},
"percoidea":{"percoidea","percoideas"},
"percoidean":{"percoidean","percoideans"},
"percolate":{"percolate","percolated","percolates","percolating"},
"percomorphi":{"percomorphi","percomorphis"},
"percophidae":{"percophidae","percophidaes"},
"percuss":{"percuss","percussed","percussing"},
"percussion":{"percussion","percussions"},
"perdicidae":{"perdicidae","perdicidaes"},
"perdicinae":{"perdicinae","perdicinaes"},
"perdition":{"perdition","perditions"},
"perdix":{"perdix","perdixes"},
"perdure":{"perdure","perdured","perduring"},
"peregrinate":{"peregrinate","peregrinated","peregrinating"},
"peregrine":{"peregrine","peregrines"},
"perennial":{"perennial","perennials"},
"pereskia":{"pereskia","pereskias"},
"perfect":{"perfect","perfected","perfecting","perfects"},
"perfecta":{"perfecta","perfectas"},
"perfectability":{"perfectabilities","perfectability"},
"perfectibility":{"perfectibilities","perfectibility"},
"perfection":{"perfection","perfections"},
"perfective":{"perfective","perfectives"},
"perfecto":{"perfecto","perfectos"},
"perfidiousness":{"perfidiousness","perfidiousnesses"},
"perfidy":{"perfidies","perfidy"},
"perforate":{"perforate","perforated","perforates","perforating"},
"perform":{"perform","performed","performing","performs"},
"performance":{"performance","performances"},
"performer":{"performer","performers"},
"performing":{"performing","performings"},
"perfume":{"perfume","perfumed","perfumes","perfuming"},
"perfumery":{"perfumeries","perfumery"},
"perfuse":{"perfuse","perfused","perfuses","perfusing"},
"pergola":{"pergola","pergolas"},
"perhaps":{"perhaps","perhapses"},
"peri":{"peri","peris"},
"periactin":{"periactin","periactins"},
"perianth":{"perianth","perianths"},
"periapsis":{"periapses","periapsis"},
"pericallis":{"pericallis","pericallises"},
"pericardium":{"pericardia","pericardidia","pericardium"},
"pericarp":{"pericarp","pericarps"},
"perichondrium":{"perichondria","perichondrium"},
"periclase":{"periclase","periclases"},
"pericranium":{"pericrania","pericranium"},
"peridiniidae":{"peridiniidae","peridiniidaes"},
"peridinium":{"peridinium","peridiniums"},
"peridium":{"peridium","peridridia"},
"perigon":{"perigon","perigons"},
"perihelion":{"perihelia","perihelion"},
"peril":{"peril","periled","periling","perilled","perilling","perils"},
"perilla":{"perilla","perillas"},
"perilousness":{"perilousness","perilousnesses"},
"perilune":{"perilune","perilunes"},
"perimeter":{"perimeter","perimeters"},
"perinephrium":{"perinephria","perinephrium"},
"perineum":{"perinea","perineum"},
"period":{"period","periods"},
"periodical":{"periodical","periodicals"},
"periodicity":{"periodicities","periodicity"},
"periodontia":{"periodontia","periodontias"},
"periodontics":{"periodontics","periodonticses"},
"periodontitis":{"periodontitis","periodontitises"},
"periodontium":{"periodontia","periodontium"},
"perionychium":{"perionychia","perionychiia","perionychium"},
"periophthalmus":{"periophthalmus","periophthalmuses"},
"periosteum":{"periostea","periosteum"},
"peripatetic":{"peripatetic","peripatetics"},
"peripatidae":{"peripatidae","peripatidaes"},
"peripatopsidae":{"peripatopsidae","peripatopsidaes"},
"peripatopsis":{"peripatopses","peripatopsis"},
"peripatus":{"peripatus","peripatuses"},
"peripeteia":{"peripeteia","peripeteias"},
"peripheral":{"peripheral","peripherals"},
"periphery":{"peripheries","periphery"},
"periphrasis":{"periphrases","periphrasis"},
"periplaneta":{"periplaneta","periplanetas"},
"periploca":{"periploca","periplocas"},
"periselene":{"periselene","periselenes"},
"perish":{"perish","perished","perishes","perishing"},
"perishable":{"perishable","perishables"},
"perishables":{"perishables","perishableses"},
"perisoreus":{"perisoreus","perisoreuses"},
"perissodactyl":{"perissodactyl","perissodactyls"},
"perissodactyla":{"perissodactyla","perissodactylas"},
"peristalsis":{"peristalses","peristalsis"},
"peristediinae":{"peristediinae","peristediinaes"},
"peristedion":{"peristedion","peristedions"},
"perithecium":{"perithecia","perithecicia","perithecium"},
"peritoneum":{"peritonea","peritoneum","peritoneums"},
"periwig":{"periwig","periwigs"},
"periwinkle":{"periwinkle","periwinkles"},
"perjure":{"perjure","perjured","perjuring"},
"perjurer":{"perjurer","perjurers"},
"perjury":{"perjuries","perjury"},
"perk":{"perk","perked","perking","perks"},
"perkiness":{"perkiness","perkinesses"},
"perky":{"perkier","perkiest","perky"},
"perliche":{"perliche","perliches"},
"perm":{"perm","perms"},
"permanence":{"permanence","permanences"},
"permanency":{"permanencies","permanency"},
"permanent":{"permanent","permanents"},
"permeability":{"permeabilities","permeability"},
"permeableness":{"permeableness","permeablenesses"},
"permeate":{"permeate","permeated","permeates","permeating"},
"permeation":{"permeation","permeations"},
"permian":{"permian","permians"},
"permission":{"permission","permissions"},
"permissiveness":{"permissiveness","permissivenesses"},
"permit":{"permit","permits","permitted","permitting"},
"permittivity":{"permittivities","permittivity"},
"permutability":{"permutabilities","permutability"},
"permutableness":{"permutableness","permutablenesses"},
"permutation":{"permutation","permutations"},
"permute":{"permute","permuted","permutes","permuting"},
"pernambuco":{"pernambuco","pernambucos"},
"perniciousness":{"perniciousness","perniciousnesses"},
"pernio":{"pernio","pernios"},
"pernis":{"pernis","pernises"},
"perodicticus":{"perodicticus","perodicticuses"},
"perognathus":{"perognathus","perognathuses"},
"peromyscus":{"peromyscus","peromyscuses"},
"peronospora":{"peronospora","peronosporas"},
"peronosporaceae":{"peronosporaceae","peronosporaceaes"},
"peronosporales":{"peronosporales","peronosporaleses"},
"perorate":{"perorate","perorated","perorating"},
"peroxide":{"peroxide","peroxided","peroxides","peroxiding"},
"perpendicular":{"perpendicular","perpendiculars"},
"perpendicularity":{"perpendicularities","perpendicularity"},
"perpetrate":{"perpetrate","perpetrated","perpetrates","perpetrating"},
"perpetration":{"perpetration","perpetrations"},
"perpetrator":{"perpetrator","perpetrators"},
"perpetuate":{"perpetuate","perpetuated","perpetuating"},
"perpetuation":{"perpetuation","perpetuations"},
"perpetuity":{"perpetuities","perpetuity"},
"perplex":{"perplex","perplexed","perplexes","perplexing"},
"perplexity":{"perplexities","perplexity"},
"perquisite":{"perquisite","perquisites"},
"perron":{"perron","perrons"},
"perry":{"perries","perry"},
"persea":{"persea","perseas"},
"persecute":{"persecute","persecuted","persecutes","persecuting"},
"persecution":{"persecution","persecutions"},
"persecutor":{"persecutor","persecutors"},
"persephone":{"persephone","persephones"},
"perseverance":{"perseverance","perseverances"},
"perseveration":{"perseveration","perseverations"},
"persevere":{"persevere","persevered","perseveres","persevering"},
"perseverence":{"perseverence","perseverences"},
"persia":{"persia","persias"},
"persian":{"persian","persians"},
"persimmon":{"persimmon","persimmons"},
"persist":{"persist","persisted","persisting","persists"},
"persistence":{"persistence","persistences"},
"persistency":{"persistencies","persistency"},
"person":{"people","person","persons"},
"persona":{"persona","personae","personas"},
"personage":{"personage","personages"},
"personal":{"personal","personals"},
"personality":{"personalities","personality"},
"personalize":{"personalize","personalized","personalizes","personalizing"},
"personalty":{"personalties","personalty"},
"personate":{"personate","personated","personates","personating"},
"personation":{"personation","personations"},
"personification":{"personification","personifications"},
"personify":{"personified","personifies","personify","personifying"},
"personnel":{"personnel","personnels"},
"persoonia":{"persoonia","persoonias"},
"perspective":{"perspective","perspectives"},
"perspex":{"perspex","perspexes"},
"perspicaciousness":{"perspicaciousness","perspicaciousnesses"},
"perspicacity":{"perspicacities","perspicacity"},
"perspicuity":{"perspicuities","perspicuity"},
"perspicuousness":{"perspicuousness","perspicuousnesses"},
"perspiration":{"perspiration","perspirations"},
"perspire":{"perspire","perspired","perspires","perspiring"},
"perspiring":{"perspiring","perspirings"},
"persuade":{"persuade","persuaded","persuades","persuading"},
"persuasion":{"persuasion","persuasions"},
"persuasiveness":{"persuasiveness","persuasivenesses"},
"pert":{"pert","perter","pertest"},
"pertain":{"pertain","pertained","pertaining","pertains"},
"pertinacity":{"pertinacities","pertinacity"},
"pertinence":{"pertinence","pertinences"},
"pertinency":{"pertinencies","pertinency"},
"pertness":{"pertness","pertnesses"},
"perturb":{"perturb","perturbed","perturbing","perturbs"},
"perturbation":{"perturbation","perturbations"},
"pertusaria":{"pertusaria","pertusarias"},
"pertusariaceae":{"pertusariaceae","pertusariaceaes"},
"pertussis":{"pertusses","pertussis"},
"peruke":{"peruke","perukes"},
"perusal":{"perusal","perusals"},
"peruse":{"peruse","perused","perusing"},
"perusing":{"perusing","perusings"},
"pervade":{"pervade","pervaded","pervades","pervading"},
"pervasion":{"pervasion","pervasions"},
"perverseness":{"perverseness","perversenesses"},
"perversity":{"perversities","perversity"},
"pervert":{"pervert","perverted","perverting","perverts"},
"perviousness":{"perviousness","perviousnesses"},
"pes":{"pedes","pes"},
"pesach":{"pesach","pesaches"},
"pesah":{"pesah","pesahs"},
"peseta":{"peseta","pesetas"},
"pesky":{"peskier","peskiest","pesky"},
"peso":{"peso","pesos"},
"pessary":{"passaries","pessaries","pessary"},
"pessimist":{"pessimist","pessimists"},
"pest":{"pest","pests"},
"pester":{"pester","pestered","pestering","pesters"},
"pesterer":{"pesterer","pesterers"},
"pesthouse":{"pesthouse","pesthouses"},
"pestilence":{"pestilence","pestilences"},
"pestle":{"pestle","pestled","pestles","pestling"},
"pet":{"pet","pets","petted","petting"},
"petal":{"petal","petals"},
"petasites":{"petasites","petasiteses"},
"petaurista":{"petaurista","petauristas"},
"petauristidae":{"petauristidae","petauristidaes"},
"petaurus":{"petaurus","petauruses"},
"petchary":{"petcharies","petchary"},
"petechia":{"petechia","petechiae"},
"peter":{"peter","petered","petering","peters"},
"peterburg":{"peterburg","peterburgs"},
"peterman":{"peterman","petermen"},
"petersburg":{"petersburg","petersburgs"},
"petfood":{"petfood","petfoods"},
"petiole":{"petiole","petioles"},
"petiteness":{"petiteness","petitenesses"},
"petitio":{"petitio","petitios"},
"petition":{"petition","petitioned","petitioning","petitions"},
"petitioner":{"petitioner","petitioners"},
"petrarca":{"petrarca","petrarcas"},
"petrarch":{"petrarch","petrarches"},
"petrifaction":{"petrifaction","petrifactions"},
"petrification":{"petrification","petrifications"},
"petrify":{"petrified","petrifies","petrify","petrifying"},
"petrocoptis":{"petrocoptis","petrocoptises"},
"petrogale":{"petrogale","petrogales"},
"petrograd":{"petrograd","petrograds"},
"petrol":{"petrol","petrols"},
"petrolatum":{"petrolatum","petrolatums"},
"petroleum":{"petroleum","petroleums"},
"petrology":{"petrologies","petrology"},
"petromyzon":{"petromyzon","petromyzons"},
"petromyzoniformes":{"petromyzoniformes","petromyzoniformeses"},
"petromyzontidae":{"petromyzontidae","petromyzontidaes"},
"petroselinum":{"petroselinum","petroselinums"},
"petteria":{"petteria","petterias"},
"petticoat":{"petticoat","petticoats"},
"pettifog":{"pettifog","pettifogged","pettifogging","pettifogs"},
"pettifogger":{"pettifogger","pettifoggers"},
"pettiness":{"pettiness","pettinesses"},
"petting":{"petting","pettings"},
"pettishness":{"pettishness","pettishnesses"},
"petty":{"pettier","pettiest","petty"},
"petulance":{"petulance","petulances"},
"petunia":{"petunia","petunias"},
"pew":{"pew","pews"},
"pewee":{"pewee","pewees"},
"pewit":{"pewit","pewits"},
"peyote":{"peyote","peyotes"},
"peziza":{"peziza","pezizas"},
"pezizaceae":{"pezizaceae","pezizaceaes"},
"pezizales":{"pezizales","pezizaleses"},
"pezophaps":{"pezophaps","pezophapses"},
"pfalz":{"pfalz","pfalzs"},
"pfannkuchen":{"pfannkuchen","pfannkuchens"},
"pfennig":{"pfennig","pfennige","pfennigs"},
"ph":{"ph","phs"},
"phacelia":{"phacelia","phacelias"},
"phacochoerus":{"phacochoerus","phacochoeruses"},
"phaeophyceae":{"phaeophyceae","phaeophyceaes"},
"phaeophyta":{"phaeophyta","phaeophytas"},
"phaethon":{"phaethon","phaethons"},
"phaethontidae":{"phaethontidae","phaethontidaes"},
"phaeton":{"phaeton","phaetons"},
"phage":{"phage","phages"},
"phalacrocoracidae":{"phalacrocoracidae","phalacrocoracidaes"},
"phalacrocorax":{"phalacrocorax","phalacrocoraxes"},
"phalacrosis":{"phalacroses","phalacrosis"},
"phalaenopsis":{"phalaenopses","phalaenopsis"},
"phalaenoptilus":{"phalaenoptilus","phalaenoptiluses"},
"phalange":{"phalange","phalanges"},
"phalanger":{"phalanger","phalangers"},
"phalangeridae":{"phalangeridae","phalangeridaes"},
"phalangida":{"phalangida","phalangidas"},
"phalangiidae":{"phalangiidae","phalangiidaes"},
"phalangium":{"phalangium","phalangiums"},
"phalanstery":{"phalansteries","phalanstery"},
"phalanx":{"phalanges","phalanx","phalanxes"},
"phalaris":{"phalaris","phalarises"},
"phalaropidae":{"phalaropidae","phalaropidaes"},
"phalaropus":{"phalaropus","phalaropuses"},
"phallaceae":{"phallaceae","phallaceaes"},
"phallales":{"phallales","phallaleses"},
"phallus":{"phalli","phallus","phalluses"},
"phalsa":{"phalsa","phalsas"},
"phanerogam":{"phanerogam","phanerogams"},
"phantasma":{"phantasma","phantasmata"},
"phantasmagoria":{"phantasmagoria","phantasmagorias"},
"phantasy":{"phantasies","phantasy"},
"phantom":{"phantom","phantoms"},
"pharmaceutics":{"pharmaceutics","pharmaceuticses"},
"pharmacist":{"pharmacist","pharmacists"},
"pharmacologist":{"pharmacologist","pharmacologists"},
"pharmacology":{"pharmacologies","pharmacology"},
"pharmacopoeia":{"pharmacopoeia","pharmacopoeias"},
"pharmacy":{"pharmacies","pharmacy"},
"pharomacrus":{"pharomacrus","pharomacruses"},
"pharos":{"pharos","pharoses"},
"pharsalus":{"pharsalus","pharsaluses"},
"pharyngitis":{"pharyngitis","pharyngitises"},
"pharyngotomy":{"pharyngotomies","pharyngotomy"},
"pharynx":{"pharynges","pharynx","pharynxes"},
"phascogale":{"phascogale","phascogales"},
"phascolarctos":{"phascolarctos","phascolarctoses"},
"phase":{"phase","phased","phases","phasing"},
"phaseolus":{"phaseolus","phaseoluses"},
"phasianidae":{"phasianidae","phasianidaes"},
"phasianus":{"phasianus","phasianuses"},
"phasmatidae":{"phasmatidae","phasmatidaes"},
"phasmatodea":{"phasmatodea","phasmatodeas"},
"phasmid":{"phasmid","phasmids"},
"phasmida":{"phasmida","phasmidas"},
"phasmidae":{"phasmidae","phasmidaes"},
"phasmidia":{"phasmidia","phasmidias"},
"pheasant":{"pheasant","pheasants"},
"phegopteris":{"phegopteris","phegopterises"},
"phellem":{"phellem","phellems"},
"phellodendron":{"phellodendron","phellodendrons"},
"phenacetin":{"phenacetin","phenacetins"},
"phenicia":{"phenicia","phenicias"},
"phenobarbital":{"phenobarbital","phenobarbitals"},
"phenobarbitone":{"phenobarbitone","phenobarbitones"},
"phenocopy":{"phenocopies","phenocopy"},
"phenol":{"phenol","phenols"},
"phenolic":{"phenolic","phenolics"},
"phenomenon":{"phenomena","phenomenon","phenomenons"},
"phenoplast":{"phenoplast","phenoplasts"},
"phenothiazine":{"phenothiazine","phenothiazines"},
"phenylacetamide":{"phenylacetamide","phenylacetamides"},
"phenylamine":{"phenylamine","phenylamines"},
"phenylbutazone":{"phenylbutazone","phenylbutazones"},
"phenylethylene":{"phenylethylene","phenylethylenes"},
"phi":{"phi","phis"},
"phi-phenomenon":{"phi-phenomena","phi-phenomenon"},
"phial":{"phial","phials"},
"philadelphaceae":{"philadelphaceae","philadelphaceaes"},
"philadelphia":{"philadelphia","philadelphias"},
"philaenus":{"philaenus","philaenuses"},
"philander":{"philander","philandered","philandering","philanders"},
"philanderer":{"philanderer","philanderers"},
"philanthropist":{"philanthropist","philanthropists"},
"philanthropy":{"philanthropies","philanthropy"},
"philatelist":{"philatelist","philatelists"},
"philately":{"philatelies","philately"},
"philhellene":{"philhellene","philhellenes"},
"philhellinist":{"philhellinist","philhellinists"},
"philippi":{"philippi","philippis"},
"philippic":{"philippic","philippics"},
"philippine":{"philippine","philippines"},
"philippines":{"philippines","philippineses"},
"philistine":{"philistine","philistines"},
"philistinism":{"philistinism","philistinisms"},
"phillidae":{"phillidae","phillidaes"},
"phillyrea":{"phillyrea","phillyreas"},
"philodendron":{"philodendra","philodendron","philodendrons"},
"philohela":{"philohela","philohelas"},
"philologist":{"philologist","philologists"},
"philologue":{"philologue","philologues"},
"philology":{"philologies","philology"},
"philomachus":{"philomachus","philomachuses"},
"philophylla":{"philophylla","philophyllas"},
"philosopher":{"philosopher","philosophers"},
"philosophize":{"philosophize","philosophized","philosophizes","philosophizing"},
"philosophy":{"philosophies","philosophy"},
"philter":{"philter","philtered","philtering","philters"},
"philtre":{"philtre","philtres"},
"philtrum":{"philtra","philtrum"},
"phlebodium":{"phlebodium","phlebodiums"},
"phlebogram":{"phlebogram","phlebograms"},
"phlebotomus":{"phlebotomus","phlebotomuses"},
"phlebotomy":{"phlebotomies","phlebotomy"},
"phlegm":{"phlegm","phlegms"},
"phleum":{"phleum","phleums"},
"phloem":{"phloem","phloems"},
"phlox":{"phlox","phloxes"},
"phlyctaena":{"phlyctaena","phlyctenae"},
"phlyctena":{"phlyctena","phlyctenae"},
"phobia":{"phobia","phobias"},
"phoca":{"phoca","phocas"},
"phocaena":{"phocaena","phocaenas"},
"phocidae":{"phocidae","phocidaes"},
"phocomelia":{"phocomelia","phocomelias"},
"phoebe":{"phoebe","phoebes"},
"phoebus":{"phoebus","phoebuses"},
"phoenicia":{"phoenicia","phoenicias"},
"phoenicophorium":{"phoenicophorium","phoenicophoriums"},
"phoenicopteridae":{"phoenicopteridae","phoenicopteridaes"},
"phoeniculidae":{"phoeniculidae","phoeniculidaes"},
"phoeniculus":{"phoeniculus","phoeniculuses"},
"phoenicurus":{"phoenicurus","phoenicuruses"},
"phoenix":{"phoenix","phoenixes"},
"pholadidae":{"pholadidae","pholadidaes"},
"pholas":{"pholas","pholases"},
"pholidae":{"pholidae","pholidaes"},
"pholidota":{"pholidota","pholidotas"},
"pholiota":{"pholiota","pholiotas"},
"pholis":{"pholis","pholises"},
"pholistoma":{"pholistoma","pholistomas"},
"phonate":{"phonate","phonated","phonating"},
"phone":{"phone","phoned","phones","phoning"},
"phonebook":{"phonebook","phonebooks"},
"phonemics":{"phonemics","phonemicses"},
"phoner":{"phoner","phoners"},
"phoney":{"phoney","phoneys"},
"phonograph":{"phonograph","phonographed","phonographing","phonographs"},
"phonography":{"phonographies","phonography"},
"phonology":{"phonologies","phonology"},
"phony":{"phoneys","phonier","phonies","phoniest","phony"},
"phoradendron":{"phoradendron","phoradendrons"},
"phoronida":{"phoronida","phoronidas"},
"phoronidea":{"phoronidea","phoronideas"},
"phorrhoea":{"phorrhoea","phorrhoeas"},
"phosphate":{"phosphate","phosphates"},
"phosphoresce":{"phosphoresce","phosphoresced","phosphorescing"},
"phosphorus":{"phosphori","phosphorus","phosphoruses"},
"photinia":{"photinia","photinias"},
"photo":{"photo","photoed","photoing","photos"},
"photo-offset":{"photo-offset","photo-offsets"},
"photoblepharon":{"photoblepharon","photoblepharons"},
"photocell":{"photocell","photocells"},
"photocompose":{"photocompose","photocomposed","photocomposing"},
"photoconduction":{"photoconduction","photoconductions"},
"photoconductivity":{"photoconductivities","photoconductivity"},
"photocopy":{"photocopied","photocopies","photocopy","photocopying"},
"photoengraving":{"photoengraving","photoengravings"},
"photoflash":{"photoflash","photoflashes"},
"photoflood":{"photoflood","photofloods"},
"photograph":{"photograph","photographed","photographing","photographs"},
"photographer":{"photographer","photographers"},
"photography":{"photographies","photography"},
"photogravure":{"photogravure","photogravures"},
"photolithograph":{"photolithograph","photolithographed","photolithographing"},
"photomap":{"photomap","photomapped","photomapping","photomaps"},
"photometer":{"photometer","photometers"},
"photosensitivity":{"photosensitivities","photosensitivity"},
"photoset":{"photoset","photosets","photosetting"},
"photostat":{"photostat","photostated","photostating","photostats","photostatted","photostatting"},
"phoxinus":{"phoxinus","phoxinuses"},
"phragmacone":{"phragmacone","phragmacones"},
"phragmipedium":{"phragmipedium","phragmipediums"},
"phragmites":{"phragmites","phragmiteses"},
"phragmocone":{"phragmocone","phragmocones"},
"phrase":{"phrase","phrased","phrases","phrasing"},
"phraseology":{"phraseologies","phraseology"},
"phrasing":{"phrasing","phrasings"},
"phratry":{"phratries","phratry"},
"phrenologist":{"phrenologist","phrenologists"},
"phrensy":{"phrensies","phrensy"},
"phrynosoma":{"phrynosoma","phrynosomas"},
"phthiriidae":{"phthiriidae","phthiriidaes"},
"phthirius":{"phthirius","phthiriuses"},
"phthirus":{"phthirus","phthiruses"},
"phthisis":{"phthises","phthisis"},
"phthorimaea":{"phthorimaea","phthorimaeas"},
"phycomycetes":{"phycomycetes","phycomyceteses"},
"phylactery":{"phylacteries","phylactery"},
"phyle":{"phylae","phyle"},
"phyllidae":{"phyllidae","phyllidaes"},
"phyllitis":{"phyllitis","phyllitises"},
"phyllium":{"phyllium","phylliums"},
"phylloclad":{"phylloclad","phylloclads"},
"phyllocladaceae":{"phyllocladaceae","phyllocladaceaes"},
"phylloclade":{"phylloclade","phylloclades"},
"phyllocladus":{"phyllocladus","phyllocladuses"},
"phyllodoce":{"phyllodoce","phyllodoces"},
"phylloporus":{"phylloporus","phylloporuses"},
"phylloquinone":{"phylloquinone","phylloquinones"},
"phyllorhynchus":{"phyllorhynchus","phyllorhynchuses"},
"phylloscopus":{"phylloscopus","phylloscopuses"},
"phyllostachys":{"phyllostachys","phyllostachyses"},
"phyllostomatidae":{"phyllostomatidae","phyllostomatidaes"},
"phyllostomidae":{"phyllostomidae","phyllostomidaes"},
"phyllostomus":{"phyllostomus","phyllostomuses"},
"phyllotaxis":{"phyllotaxes","phyllotaxis","phyllotaxtaxes"},
"phyllotaxy":{"phyllotaxies","phyllotaxy"},
"phylloxera":{"phylloxera","phylloxeras"},
"phylloxeridae":{"phylloxeridae","phylloxeridaes"},
"phylogenesis":{"phylogeneses","phylogenesis"},
"phylogeny":{"phylogenies","phylogeny"},
"phylum":{"phyla","phylum"},
"physalia":{"physalia","physalias"},
"physalis":{"physalis","physalises"},
"physaria":{"physaria","physarias"},
"physchometrika":{"physchometrika","physchometrikas"},
"physeter":{"physeter","physeters"},
"physeteridae":{"physeteridae","physeteridaes"},
"physiatrics":{"physiatrics","physiatricses"},
"physic":{"physic","physicked","physicking","physics"},
"physicalism":{"physicalism","physicalisms"},
"physicality":{"physicalities","physicality"},
"physicalness":{"physicalness","physicalnesses"},
"physician":{"physician","physicians"},
"physicist":{"physicist","physicists"},
"physics":{"physics","physicses"},
"physidae":{"physidae","physidaes"},
"physiognomy":{"physiognomies","physiognomy"},
"physiography":{"physiographies","physiography"},
"physiologist":{"physiologist","physiologists"},
"physiology":{"physiologies","physiology"},
"physioltherapist":{"physioltherapist","physioltherapists"},
"physiotherapy":{"physiotherapies","physiotherapy"},
"physique":{"physique","physiques"},
"physostigma":{"physostigma","physostigmas"},
"phytelephas":{"phytelephas","phytelephases"},
"phytohormone":{"phytohormone","phytohormones"},
"phytolacca":{"phytolacca","phytolaccas"},
"phytolaccaceae":{"phytolaccaceae","phytolaccaceaes"},
"phytologist":{"phytologist","phytologists"},
"phytology":{"phytologies","phytology"},
"phytomastigina":{"phytomastigina","phytomastiginas"},
"phytonadione":{"phytonadione","phytonadiones"},
"phytophthora":{"phytophthora","phytophthoras"},
"pi":{"pi","pis"},
"pi-meson":{"pi-meson","pi-mesons"},
"pia":{"pia","pias"},
"piaffe":{"piaffe","piaffed","piaffing"},
"piaget":{"piaget","piagets"},
"pianissimo":{"pianissimo","pianissimos"},
"pianist":{"pianist","pianists"},
"piano":{"piano","pianos"},
"pianoforte":{"pianoforte","pianofortes"},
"pianola":{"pianola","pianolas"},
"piaster":{"piaster","piasters"},
"piastre":{"piastre","piastres"},
"piazza":{"piazza","piazzas","piazze"},
"pibgorn":{"pibgorn","pibgorns"},
"pica":{"pica","picas"},
"pica-pica":{"pica-pica","pica-picas"},
"picador":{"picador","picadores","picadors"},
"picaninny":{"picaninnies","picaninny"},
"picardie":{"picardie","picardies"},
"picardy":{"picardies","picardy"},
"picariae":{"picariae","picariaes"},
"picaro":{"picaro","picaros"},
"picasso":{"picasso","picassos"},
"piccalilli":{"piccalilli","piccalillis"},
"piccaninny":{"piccaninnies","piccaninny"},
"piccolo":{"piccolo","piccolos"},
"picea":{"picea","piceas"},
"pichi":{"pichi","pichis"},
"pichiciago":{"pichiciago","pichiciagos"},
"pichiciego":{"pichiciego","pichiciegos"},
"picidae":{"picidae","picidaes"},
"piciformes":{"piciformes","piciformeses"},
"pick":{"pick","picked","picking","picks"},
"pick-me-up":{"pick-me-up","pick-me-ups"},
"pickaninny":{"pickaninnies","pickaninny"},
"pickax":{"pickax","pickaxed","pickaxes","pickaxing"},
"pickaxe":{"pickaxe","pickaxes"},
"pickerel":{"pickerel","pickerels"},
"pickerelweed":{"pickerelweed","pickerelweeds"},
"pickeringia":{"pickeringia","pickeringias"},
"picket":{"picket","picketed","picketing","pickets"},
"picking":{"picking","pickings"},
"pickle":{"pickle","pickled","pickles","pickling"},
"picklepuss":{"picklepuss","picklepusses"},
"picknicker":{"picknicker","picknickers"},
"pickpocket":{"pickpocket","pickpockets"},
"pickup":{"pickup","pickups"},
"picky":{"pickier","pickiest","picky"},
"picnic":{"picnic","picnicked","picnicking","picnics"},
"picnicker":{"picnicker","picnickers"},
"picoides":{"picoides","picoideses"},
"picometer":{"picometer","picometers"},
"picometre":{"picometre","picometres"},
"picot":{"picot","picoted","picoting"},
"picrasma":{"picrasma","picrasmas"},
"picris":{"picris","picrises"},
"pictorial":{"pictorial","pictorials"},
"picture":{"picture","pictured","pictures","picturing"},
"picturing":{"picturing","picturings"},
"picumnus":{"picumnus","picumnuses"},
"picus":{"picus","picuses"},
"pid":{"pid","pids"},
"piddle":{"piddle","piddled","piddles","piddling"},
"pidginize":{"pidginize","pidginized","pidginizing"},
"pidlimdi":{"pidlimdi","pidlimdis"},
"pie":{"pie","pies"},
"pie-dog":{"pie-dog","pie-dogs"},
"piece":{"piece","pieced","pieces","piecing"},
"pied-a-terre":{"pied-a-terre","pieds-a-terre"},
"piedmont":{"piedmont","piedmonts"},
"pieman":{"pieman","piemen"},
"piemonte":{"piemonte","piemontes"},
"pieplant":{"pieplant","pieplants"},
"pier":{"pier","piers"},
"pierce":{"pierce","pierced","pierces","piercing"},
"pierid":{"pierid","pierids"},
"pieridae":{"pieridae","pieridaes"},
"pieris":{"pieris","pierises"},
"pierre":{"pierre","pierres"},
"pierrot":{"pierrot","pierrots"},
"pieta":{"pieta","pietas"},
"pietism":{"pietism","pietisms"},
"piety":{"pieties","piety"},
"piezoelectricity":{"piezoelectricities","piezoelectricity"},
"piffle":{"piffle","piffled","piffles","piffling"},
"pig":{"pig","pigged","pigging","pigs"},
"pigboat":{"pigboat","pigboats"},
"pigeon":{"pigeon","pigeoned","pigeoning","pigeons"},
"pigeonhole":{"pigeonhole","pigeonholed","pigeonholes","pigeonholing"},
"pigeonholing":{"pigeonholing","pigeonholings"},
"pigfish":{"pigfish","pigfishes"},
"piggery":{"piggeries","piggery"},
"piggishness":{"piggishness","piggishnesses"},
"piggy":{"piggier","piggies","piggiest","piggy"},
"piggyback":{"piggyback","piggybacked","piggybacking"},
"pigheadedness":{"pigheadedness","pigheadednesses"},
"piglet":{"piglet","piglets"},
"pigman":{"pigman","pigmen"},
"pigment":{"pigment","pigmented","pigmenting","pigments"},
"pigmy":{"pigmies","pigmy"},
"pignolia":{"pignolia","pignolias"},
"pignut":{"pignut","pignuts"},
"pigpen":{"pigpen","pigpens"},
"pigsty":{"pigsties","pigsty"},
"pigswill":{"pigswill","pigswills"},
"pigwash":{"pigwash","pigwashes"},
"pigweed":{"pigweed","pigweeds"},
"pika":{"pika","pikas"},
"pike":{"pike","piked","pikes","piking"},
"pikeman":{"pikeman","pikemen"},
"pikeperch":{"pikeperch","pikeperches"},
"pikestaff":{"pikestaff","pikestaves"},
"pilaf":{"pilaf","pilafs"},
"pilaff":{"pilaff","pilaffs"},
"pilau":{"pilau","pilaus"},
"pilaw":{"pilaw","pilaws"},
"pilchard":{"pilchard","pilchards"},
"pile":{"pile","piled","piles","piling"},
"pilea":{"pilea","pileas"},
"piles":{"piles","pileses"},
"pileum":{"pilea","pileum"},
"pileus":{"pileus","pileuses"},
"pilewort":{"pilewort","pileworts"},
"pilfer":{"pilfer","pilfered","pilfering","pilfers"},
"pilferer":{"pilferer","pilferers"},
"pilgrim":{"pilgrim","pilgrims"},
"pilgrimage":{"pilgrimage","pilgrimages"},
"pili":{"pili","pilis"},
"piling":{"piling","pilings"},
"pill":{"pill","pilled","pilling","pills"},
"pillage":{"pillage","pillaged","pillages","pillaging"},
"pillager":{"pillager","pillagers"},
"pillaging":{"pillaging","pillagings"},
"pillar":{"pillar","pillared","pillaring","pillars"},
"pillbox":{"pillbox","pillboxes"},
"pillory":{"pilloried","pillories","pillory","pillorying"},
"pillow":{"pillow","pillowed","pillowing","pillows"},
"pillowcase":{"pillowcase","pillowcases"},
"pillwort":{"pillwort","pillworts"},
"pilosella":{"pilosella","pilosellas"},
"pilot":{"pilot","piloted","piloting","pilots"},
"pilotage":{"pilotage","pilotages"},
"pilotfish":{"pilotfish","pilotfishes"},
"pilothouse":{"pilothouse","pilothouses"},
"piloting":{"piloting","pilotings"},
"pilsener":{"pilsener","pilseners"},
"pilsner":{"pilsner","pilsners"},
"pilularia":{"pilularia","pilularias"},
"pimenta":{"pimenta","pimentas"},
"pimento":{"pimento","pimentos"},
"pimiento":{"pimiento","pimientos"},
"pimp":{"pimp","pimped","pimping","pimps"},
"pimpernel":{"pimpernel","pimpernels"},
"pimpinella":{"pimpinella","pimpinellas"},
"pin":{"pin","pinned","pinning","pins"},
"pin-up":{"pin-up","pin-ups"},
"pinaceae":{"pinaceae","pinaceaes"},
"pinafore":{"pinafore","pinafores"},
"pinball":{"pinball","pinballs"},
"pincer":{"pincer","pincers"},
"pinch":{"pinch","pinched","pinches","pinching"},
"pinch-hit":{"pinch-hit","pinch-hits","pinch-hitting"},
"pinche":{"pinche","pinches"},
"pinchpenny":{"pinchpennies","pinchpenny"},
"pinckneya":{"pinckneya","pinckneyas"},
"pinctada":{"pinctada","pinctadas"},
"pindaric":{"pindaric","pindarics"},
"pine":{"pine","pined","pines","pining"},
"pineapple":{"pineapple","pineapples"},
"pinery":{"pineries","pinery"},
"pinesap":{"pinesap","pinesaps"},
"pinetum":{"pineta","pinetum"},
"pineus":{"pineus","pineuses"},
"pineweed":{"pineweed","pineweeds"},
"pinfish":{"pinfish","pinfishes"},
"ping":{"ping","pinged","pinging","pings"},
"ping-pong":{"ping-pong","ping-pongs"},
"pingo":{"pingo","pingos"},
"pinguicula":{"pinguicula","pinguiculas"},
"pinguinus":{"pinguinus","pinguinuses"},
"pinhead":{"pinhead","pinheads"},
"pinicola":{"pinicola","pinicolas"},
"pinion":{"pinion","pinioned","pinioning","pinions"},
"pink":{"pink","pinked","pinker","pinkest","pinking","pinks"},
"pinkeye":{"pinkeye","pinkeyes"},
"pinkie":{"pinkie","pinkies"},
"pinko":{"pinko","pinkos"},
"pinky":{"pinkies","pinky"},
"pinna":{"pinna","pinnae","pinnas"},
"pinnace":{"pinnace","pinnaces"},
"pinnacle":{"pinnacle","pinnacled","pinnacles","pinnacling"},
"pinnatiped":{"pinnatiped","pinnatipeds"},
"pinniped":{"pinniped","pinnipeds"},
"pinnipedia":{"pinnipedia","pinnipedias"},
"pinnotheres":{"pinnotheres","pinnothereses"},
"pinnotheridae":{"pinnotheridae","pinnotheridaes"},
"pinnula":{"pinnula","pinnulae"},
"pinnule":{"pinnule","pinnules"},
"pinny":{"pinnies","pinny"},
"pinochle":{"pinochle","pinochles"},
"pinon":{"pinon","pinons"},
"pinophytina":{"pinophytina","pinophytinas"},
"pinopsida":{"pinopsida","pinopsidas"},
"pinot":{"pinot","pinots"},
"pinpoint":{"pinpoint","pinpointed","pinpointing","pinpoints"},
"pint":{"pint","pints"},
"pintado":{"pintado","pintados"},
"pintail":{"pintail","pintails"},
"pinto":{"pinto","pintos"},
"pinus":{"pinus","pinuses"},
"pinwheel":{"pinwheel","pinwheels"},
"pinworm":{"pinworm","pinworms"},
"piny":{"pinier","piniest","piny"},
"pinyon":{"pinyon","pinyons"},
"pion":{"pion","pions"},
"pioneer":{"pioneer","pioneered","pioneering","pioneers"},
"piousness":{"piousness","piousnesses"},
"pip":{"pip","pipped","pipping","pips"},
"pip-squeak":{"pip-squeak","pip-squeaks"},
"pipa":{"pipa","pipas"},
"pipage":{"pipage","pipages"},
"pipal":{"pipal","pipals"},
"pipe":{"pipe","piped","pipes","piping"},
"pipeclay":{"pipeclay","pipeclays"},
"pipefish":{"pipefish","pipefishes"},
"pipefitting":{"pipefitting","pipefittings"},
"pipeline":{"pipeline","pipelined","pipelines","pipelining"},
"piper":{"piper","pipers"},
"piperaceae":{"piperaceae","piperaceaes"},
"piperales":{"piperales","piperaleses"},
"piperin":{"piperin","piperins"},
"piperine":{"piperine","piperines"},
"piperocaine":{"piperocaine","piperocaines"},
"pipes":{"pipes","pipeses"},
"pipet":{"pipet","pipetted","pipetting"},
"pipework":{"pipework","pipeworks"},
"pipewort":{"pipewort","pipeworts"},
"pipidae":{"pipidae","pipidaes"},
"pipile":{"pipile","pipiles"},
"pipilo":{"pipilo","pipilos"},
"piping":{"piping","pipings"},
"pipistrel":{"pipistrel","pipistrels"},
"pipistrelle":{"pipistrelle","pipistrelles"},
"pipistrellus":{"pipistrellus","pipistrelluses"},
"pipit":{"pipit","pipits"},
"pipra":{"pipra","pipras"},
"pipridae":{"pipridae","pipridaes"},
"pipsissewa":{"pipsissewa","pipsissewas"},
"piptadenia":{"piptadenia","piptadenias"},
"pipturus":{"pipturus","pipturuses"},
"pipul":{"pipul","pipuls"},
"piquance":{"piquance","piquances"},
"piquancy":{"piquancies","piquancy"},
"pique":{"pique","piqued","piques","piquing"},
"piqueria":{"piqueria","piquerias"},
"piracy":{"piracies","piracy"},
"pirana":{"pirana","piranas"},
"piranga":{"piranga","pirangas"},
"piranha":{"piranha","piranhas"},
"pirate":{"pirate","pirated","pirates","pirating"},
"pirog":{"pirog","pirogi"},
"pirogi":{"pirogi","pirogis"},
"pirogue":{"pirogue","pirogues"},
"piroshki":{"piroshki","piroshkis"},
"pirouette":{"pirouette","pirouetted","pirouetting"},
"piroxicam":{"piroxicam","piroxicams"},
"pirozhki":{"pirozhki","pirozhkis"},
"pisanosaur":{"pisanosaur","pisanosaurs"},
"pisanosaurus":{"pisanosaurus","pisanosauruses"},
"piscary":{"piscaries","piscary"},
"pisces":{"pisces","pisceses"},
"piscidia":{"piscidia","piscidias"},
"piscina":{"piscina","piscinae","piscinas"},
"pish":{"pish","pished","pishing"},
"pisiform":{"pisiform","pisiforms"},
"pismire":{"pismire","pismires"},
"pisonia":{"pisonia","pisonias"},
"piss":{"piss","pissed","pisses","pissing"},
"pissing":{"pissing","pissings"},
"pissoir":{"pissoir","pissoirs"},
"pistachio":{"pistachio","pistachios"},
"pistacia":{"pistacia","pistacias"},
"pistia":{"pistia","pistias"},
"pistil":{"pistil","pistils"},
"pistol":{"pistol","pistoled","pistoling","pistolled","pistolling","pistols"},
"pistol-whip":{"pistol-whip","pistol-whipped","pistol-whipping","pistol-whips"},
"piston":{"piston","pistons"},
"pisum":{"pisum","pisums"},
"pit":{"pit","pits","pitted","pitting"},
"pita":{"pita","pitas"},
"pitahaya":{"pitahaya","pitahayas"},
"pitanga":{"pitanga","pitangas"},
"pitapat":{"pitapat","pitapats","pitapatted","pitapatting"},
"pitch":{"pitch","pitched","pitches","pitching"},
"pitchblende":{"pitchblende","pitchblendes"},
"pitcher":{"pitcher","pitchers"},
"pitcherful":{"pitcherful","pitcherfuls"},
"pitchfork":{"pitchfork","pitchforked","pitchforking","pitchforks"},
"pitching":{"pitching","pitchings"},
"pitchman":{"pitchman","pitchmen"},
"pitchy":{"pitchier","pitchiest","pitchy"},
"pitfall":{"pitfall","pitfalls"},
"pith":{"pith","pithed","pithing","piths"},
"pithecanthropus":{"pithecanthropus","pithecanthropuses"},
"pithecellobium":{"pithecellobium","pithecellobiums"},
"pithecia":{"pithecia","pithecias"},
"pithecolobium":{"pithecolobium","pithecolobiums"},
"pithiness":{"pithiness","pithinesses"},
"pithos":{"pithoi","pithos"},
"pithy":{"pithier","pithiest","pithy"},
"pitilessness":{"pitilessness","pitilessnesses"},
"pitman":{"pitman","pitmans","pitmen"},
"pitprop":{"pitprop","pitprops"},
"pitter-patter":{"pitter-patter","pitter-pattered","pitter-pattering","pitter-patters"},
"pittidae":{"pittidae","pittidaes"},
"pitting":{"pitting","pittings"},
"pituitary":{"pituitaries","pituitary"},
"pituophis":{"pituophis","pituophises"},
"pity":{"pitied","pities","pity","pitying"},
"pitymys":{"pitymys","pitymyses"},
"pityrogramma":{"pityrogramma","pityrogrammas"},
"piute":{"piute","piutes"},
"pivot":{"pivot","pivoted","pivoting","pivots"},
"pix":{"pix","pixes"},
"pixel":{"pixel","pixels"},
"pixie":{"pixie","pixies"},
"pixy":{"pixies","pixy"},
"pizza":{"pizza","pizzas"},
"pizzaz":{"pizzaz","pizzazs"},
"pizzazz":{"pizzazz","pizzazzs"},
"pizzeria":{"pizzeria","pizzerias"},
"pizzicato":{"pizzicati","pizzicato","pizzicatos"},
"placard":{"placard","placarded","placarding","placards"},
"placate":{"placate","placated","placates","placating"},
"placation":{"placation","placations"},
"place":{"place","placed","places","placing"},
"place-kick":{"place-kick","place-kicked","place-kicking"},
"place-kicking":{"place-kicking","place-kickings"},
"place-worship":{"place-worship","place-worships"},
"placebo":{"placebo","placeboes","placebos"},
"placeman":{"placeman","placemen"},
"placement":{"placement","placements"},
"placenta":{"placenta","placentae","placentas"},
"placental":{"placental","placentals"},
"placeseeker":{"placeseeker","placeseekers"},
"placidity":{"placidities","placidity"},
"placidness":{"placidness","placidnesses"},
"placodermi":{"placodermi","placodermis"},
"placuna":{"placuna","placunas"},
"plafond":{"plafond","plafonds"},
"plagianthus":{"plagianthus","plagianthuses"},
"plagiarisation":{"plagiarisation","plagiarisations"},
"plagiarist":{"plagiarist","plagiarists"},
"plagiarization":{"plagiarization","plagiarizations"},
"plagiarize":{"plagiarize","plagiarized","plagiarizes","plagiarizing"},
"plagiary":{"plagiaries","plagiary"},
"plagioclase":{"plagioclase","plagioclases"},
"plague":{"plague","plagued","plagues","plaguing"},
"plaice":{"plaice","plaices"},
"plaid":{"plaid","plaids"},
"plain":{"plain","plainer","plainest","plains"},
"plain-clothesman":{"plain-clothesman","plain-clothesmen"},
"plainchant":{"plainchant","plainchants"},
"plainclothesman":{"plainclothesman","plainclothesmen"},
"plainness":{"plainness","plainnesses"},
"plainsman":{"plainsman","plainsmen"},
"plainsong":{"plainsong","plainsongs"},
"plaint":{"plaint","plaints"},
"plaintiff":{"plaintiff","plaintiffs"},
"plait":{"plait","plaited","plaiting","plaits"},
"plan":{"plan","planned","planning","plans"},
"planakeen":{"planakeen","planakeens"},
"planaria":{"planaria","planarias"},
"planarian":{"planarian","planarians"},
"planchet":{"planchet","planchets"},
"plane":{"plane","planed","planes","planing"},
"planeness":{"planeness","planenesses"},
"planer":{"planer","planers"},
"planet":{"planet","planets"},
"planetarium":{"planetaria","planetariia","planetarium","planetariums"},
"planetary":{"planetartaries","planetary"},
"planetoid":{"planetoid","planetoids"},
"plangency":{"plangencies","plangency"},
"planimeter":{"planimeter","planimeters"},
"plank":{"plank","planked","planking","planks"},
"planner":{"planner","planners"},
"planning":{"planning","plannings"},
"planococcus":{"planococcus","planococcuses"},
"planography":{"planographies","planography"},
"plant":{"plant","planted","planting","plants"},
"plantae":{"plantae","plantaes"},
"plantagenet":{"plantagenet","plantagenets"},
"plantaginaceae":{"plantaginaceae","plantaginaceaes"},
"plantaginales":{"plantaginales","plantaginaleses"},
"plantago":{"plantago","plantagos"},
"plantain":{"plantain","plantains"},
"plantation":{"plantation","plantations"},
"planter":{"planter","planters"},
"planthopper":{"planthopper","planthoppers"},
"planula":{"planula","planulae"},
"plaque":{"plaque","plaques"},
"plash":{"plash","plashed","plashes","plashing"},
"plashy":{"plashier","plashiest","plashy"},
"plasm":{"plasm","plasms"},
"plasma":{"plasma","plasmas"},
"plasmacyte":{"plasmacyte","plasmacytes"},
"plasmin":{"plasmin","plasmins"},
"plasmodesm":{"plasmodesm","plasmodesms"},
"plasmodesma":{"plasmodesdesmata","plasmodesma","plasmodesmata"},
"plasmodiidae":{"plasmodiidae","plasmodiidaes"},
"plasmodiophora":{"plasmodiophora","plasmodiophoras"},
"plasmodiophoraceae":{"plasmodiophoraceae","plasmodiophoraceaes"},
"plasmodium":{"plasmodia","plasmodium","plasmodiums"},
"plassey":{"plassey","plasseys"},
"plaster":{"plaster","plastered","plastering","plasters"},
"plasterboard":{"plasterboard","plasterboards"},
"plastering":{"plastering","plasterings"},
"plastic":{"plastic","plastics"},
"plasticity":{"plasticities","plasticity"},
"plastique":{"plastique","plastiques"},
"plat":{"plat","plats","platted","platting"},
"plataea":{"plataea","plataeas"},
"platalea":{"platalea","plataleas"},
"plataleidae":{"plataleidae","plataleidaes"},
"platan":{"platan","platans"},
"platanaceae":{"platanaceae","platanaceaes"},
"platanistidae":{"platanistidae","platanistidaes"},
"platanthera":{"platanthera","platantheras"},
"platanus":{"platanus","platanuses"},
"plate":{"plate","plated","plates","plating"},
"plateau":{"plateau","plateaus","plateaux"},
"plateful":{"plateful","platefuls"},
"platelayer":{"platelayer","platelayers"},
"platelet":{"platelet","platelets"},
"platform":{"platform","platformed","platforming","platforms"},
"platforms":{"platforms","platformses"},
"platichthys":{"platichthys","platichthyses"},
"plating":{"plating","platings"},
"platinum":{"platinum","platinums"},
"platitude":{"platitude","platitudes"},
"platonism":{"platonism","platonisms"},
"plattdeutsch":{"plattdeutsch","plattdeutsches"},
"platte":{"platte","plattes"},
"platter":{"platter","platters"},
"platy":{"platies","platy"},
"platycephalidae":{"platycephalidae","platycephalidaes"},
"platycerium":{"platycerium","platyceriums"},
"platyctenea":{"platyctenea","platycteneas"},
"platyhelminth":{"platyhelminth","platyhelminths"},
"platyhelminthes":{"platyhelminthes","platyhelmintheses"},
"platylobium":{"platylobium","platylobiums"},
"platymiscium":{"platymiscium","platymisciums"},
"platypoecilus":{"platypoecilus","platypoeciluses"},
"platypus":{"platypi","platypus","platypuses"},
"platyrrhini":{"platyrrhini","platyrrhinis"},
"platystemon":{"platystemon","platystemons"},
"plaudit":{"plaudit","plaudits"},
"plaudits":{"plaudits","plauditses"},
"plausibility":{"plausibilities","plausibility"},
"plausibleness":{"plausibleness","plausiblenesses"},
"plautus":{"plautus","plautuses"},
"play":{"play","played","playing","plays"},
"playa":{"playa","playas"},
"playacting":{"playacting","playactings"},
"playactor":{"playactor","playactors"},
"playboy":{"playboy","playboys"},
"playday":{"playday","playdays"},
"player":{"player","players"},
"playfellow":{"playfellow","playfellows"},
"playfulness":{"playfulness","playfulnesses"},
"playgoer":{"playgoer","playgoers"},
"playground":{"playground","playgrounds"},
"playhouse":{"playhouse","playhouses"},
"playing":{"playing","playings"},
"playmate":{"playmate","playmates"},
"playpen":{"playpen","playpens"},
"playroom":{"playroom","playrooms"},
"playschool":{"playschool","playschools"},
"playscript":{"playscript","playscripts"},
"plaything":{"plaything","playthings"},
"playtime":{"playtime","playtimes"},
"playwright":{"playwright","playwrights"},
"play_a_part":{"played_a_part","playing_a_part","plays_a_part","play_a_part"},
"plaza":{"plaza","plazas"},
"plea":{"plea","pleas"},
"pleach":{"pleach","pleached","pleaches","pleaching"},
"plead":{"plead","pleaded","pleading","pleads","pled"},
"pleasance":{"pleasance","pleasances"},
"pleasant":{"pleasant","pleasanter","pleasantest"},
"pleasantness":{"pleasantness","pleasantnesses"},
"pleasantry":{"pleasantries","pleasantry"},
"please":{"please","pleased","pleases","pleasing"},
"pleasing":{"pleasing","pleasings"},
"pleasingness":{"pleasingness","pleasingnesses"},
"pleasure":{"pleasure","pleasured","pleasures","pleasuring"},
"pleat":{"pleat","pleated","pleating","pleats"},
"pleating":{"pleating","pleatings"},
"pleb":{"pleb","plebs"},
"plebe":{"plebe","plebes"},
"plebeian":{"plebeian","plebeians"},
"plebiscite":{"plebiscite","plebiscites"},
"plecoptera":{"plecoptera","plecopteras"},
"plecopteran":{"plecopteran","plecopterans"},
"plecotus":{"plecotus","plecotuses"},
"plectania":{"plectania","plectanias"},
"plectognath":{"plectognath","plectognaths"},
"plectognathi":{"plectognathi","plectognathis"},
"plectomycetes":{"plectomycetes","plectomyceteses"},
"plectorrhiza":{"plectorrhiza","plectorrhizas"},
"plectron":{"plectron","plectrons"},
"plectrophenax":{"plectrophenax","plectrophenaxes"},
"plectrum":{"plectra","plectrum","plectrums"},
"pledge":{"pledge","pledged","pledges","pledging"},
"pleione":{"pleione","pleiones"},
"pleiospilos":{"pleiospilos","pleiospiloses"},
"pleistocene":{"pleistocene","pleistocenes"},
"plenipotentiary":{"plenipotentiaries","plenipotentiary"},
"plenitude":{"plenitude","plenitudes"},
"plenteousness":{"plenteousness","plenteousnesses"},
"plentifulness":{"plentifulness","plentifulnesses"},
"plentitude":{"plentitude","plentitudes"},
"plenty":{"plenties","plenty"},
"plenum":{"plena","plenum","plenums"},
"pleomorphism":{"pleomorphism","pleomorphisms"},
"pleonaste":{"pleonaste","pleonastes"},
"pleopod":{"pleopod","pleopods"},
"plesianthropus":{"plesianthropus","plesianthropuses"},
"plesiosaur":{"plesiosaur","plesiosaurs"},
"plesiosauria":{"plesiosauria","plesiosaurias"},
"plesiosaurus":{"plesiosaurus","plesiosauruses"},
"plethodon":{"plethodon","plethodons"},
"plethodont":{"plethodont","plethodonts"},
"plethodontidae":{"plethodontidae","plethodontidaes"},
"plethora":{"plethora","plethoras"},
"pleura":{"pleura","pleurae","pleuras"},
"pleuralgia":{"pleuralgia","pleuralgias"},
"pleurobrachia":{"pleurobrachia","pleurobrachias"},
"pleurobrachiidae":{"pleurobrachiidae","pleurobrachiidaes"},
"pleurocarp":{"pleurocarp","pleurocarps"},
"pleurodynia":{"pleurodynia","pleurodynias"},
"pleuron":{"pleura","pleuron"},
"pleuronectes":{"pleuronectes","pleuronecteses"},
"pleuronectidae":{"pleuronectidae","pleuronectidaes"},
"pleurosorus":{"pleurosorus","pleurosoruses"},
"pleurotomy":{"pleurotomies","pleurotomy"},
"pleurotus":{"pleurotus","pleurotuses"},
"pleven":{"pleven","plevens"},
"plevna":{"plevna","plevnas"},
"plexiglas":{"plexiglas","plexiglases"},
"plexiglass":{"plexiglass","plexiglasses"},
"plexus":{"plexus","plexuses"},
"pliability":{"pliabilities","pliability"},
"pliancy":{"pliancies","pliancy"},
"pliantness":{"pliantness","pliantnesses"},
"plica":{"plica","plicae","plicas"},
"plication":{"plication","plications"},
"plicatoperipatus":{"plicatoperipatus","plicatoperipatuses"},
"pliers":{"pliers","plierses"},
"plight":{"plight","plighted","plighting","plights"},
"plimsoll":{"plimsoll","plimsolls"},
"plink":{"plink","plinked","plinking"},
"plinth":{"plinth","plinths"},
"pliocene":{"pliocene","pliocenes"},
"ploceidae":{"ploceidae","ploceidaes"},
"ploceus":{"ploceus","ploceuses"},
"plod":{"plod","plodded","plodding","plods"},
"plodder":{"plodder","plodders"},
"plodding":{"plodding","ploddings"},
"plonko":{"plonko","plonkos"},
"plop":{"plop","plopped","plopping","plops"},
"plosion":{"plosion","plosions"},
"plosive":{"plosive","plosives"},
"plot":{"plot","plots","plotted","plotting"},
"plotter":{"plotter","plotters"},
"plough":{"plough","ploughed","ploughing","ploughs"},
"ploughboy":{"ploughboy","ploughboys"},
"ploughing":{"ploughing","ploughings"},
"ploughman":{"ploughman","ploughmen"},
"ploughshare":{"ploughshare","ploughshares"},
"ploughwright":{"ploughwright","ploughwrights"},
"plow":{"plow","plowed","plowing","plows"},
"plowboy":{"plowboy","plowboys"},
"plowing":{"plowing","plowings"},
"plowman":{"ploughmen","plowman","plowmen"},
"plowshare":{"plowshare","plowshares"},
"plowwright":{"plowwright","plowwrights"},
"ploy":{"ploy","ploys"},
"ployurethan":{"ployurethan","ployurethans"},
"pluck":{"pluck","plucked","plucking","plucks"},
"pluckiness":{"pluckiness","pluckinesses"},
"plucky":{"pluckier","pluckiest","plucky"},
"plug":{"plug","plugged","plugging","plugs"},
"plug-ugly":{"plug-uglies","plug-ugly"},
"plugboard":{"plugboard","plugboards"},
"plugger":{"plugger","pluggers"},
"plum":{"plum","plums"},
"plumage":{"plumage","plumages"},
"plumb":{"plumb","plumbed","plumbing","plumbs"},
"plumbaginaceae":{"plumbaginaceae","plumbaginaceaes"},
"plumbaginales":{"plumbaginales","plumbaginaleses"},
"plumbago":{"plumbago","plumbagos"},
"plumber":{"plumber","plumbers"},
"plumbery":{"plumberies","plumbery"},
"plumbing":{"plumbing","plumbings"},
"plumbism":{"plumbism","plumbisms"},
"plumcot":{"plumcot","plumcots"},
"plume":{"plume","plumed","plumes","pluming"},
"plumeria":{"plumeria","plumerias"},
"plumiera":{"plumiera","plumieras"},
"plummet":{"plummet","plummeted","plummeting","plummets"},
"plummy":{"plummier","plummiest","plummy"},
"plump":{"plump","plumped","plumper","plumpest","plumping"},
"plumpness":{"plumpness","plumpnesses"},
"plumy":{"plumier","plumiest","plumy"},
"plunder":{"plunder","plundered","plundering","plunders"},
"plunderer":{"plunderer","plunderers"},
"plundering":{"plundering","plunderings"},
"plunge":{"plunge","plunged","plunges","plunging"},
"plunger":{"plunger","plungers"},
"plunk":{"plunk","plunked","plunking","plunks"},
"plunker":{"plunker","plunkers"},
"pluperfect":{"pluperfect","pluperfects"},
"plural":{"plural","plurals"},
"plurality":{"pluralities","plurality"},
"pluralize":{"pluralize","pluralized","pluralizing"},
"plus":{"plus","pluses"},
"plush":{"plush","plusher","plushest"},
"plushy":{"plushier","plushiest","plushy"},
"pluteaceae":{"pluteaceae","pluteaceaes"},
"pluteus":{"pluteus","pluteuses"},
"pluto":{"pluto","plutos"},
"plutocracy":{"plutocracies","plutocracy"},
"pluton":{"pluton","plutons"},
"plutonium":{"plutonium","plutoniums"},
"pluvialis":{"pluvialis","pluvialises"},
"pluvianus":{"pluvianus","pluvianuses"},
"ply":{"plied","plies","ply","plying"},
"plyboard":{"plyboard","plyboards"},
"plyers":{"plyers","plyerses"},
"plywood":{"plywood","plywoods"},
"pm":{"pm","pms"},
"pms":{"pms","pmses"},
"pneuma":{"pneuma","pneumas"},
"pneumectomy":{"pneumectomies","pneumectomy","pneumonectomies"},
"pneumobacillus":{"pneumobacilli","pneumobacillus"},
"pneumococcus":{"pneumococcus","pneumococcuses"},
"pneumoconiosis":{"pneumoconioses","pneumoconiosis"},
"pneumogastric":{"pneumogastric","pneumogastrics"},
"pneumonectomy":{"pneumonectomies","pneumonectomy"},
"pneumonia":{"pneumonia","pneumonias"},
"pneumonoconiosis":{"pneumonoconioses","pneumonoconiosis"},
"po":{"po","pos"},
"poa":{"poa","poas"},
"poaceae":{"poaceae","poaceaes"},
"poach":{"poach","poached","poaching"},
"poacher":{"poacher","poachers"},
"pob":{"pob","pobs"},
"pocahontas":{"pocahontas","pocahontases"},
"pochard":{"pochard","pochards"},
"pocket":{"pocket","pocketed","pocketing","pockets"},
"pocketbook":{"pocketbook","pocketbooks"},
"pocketcomb":{"pocketcomb","pocketcombs"},
"pocketful":{"pocketful","pocketfuls"},
"pocketknife":{"pocketknife","pocketknives"},
"pocky":{"pockier","pockiest","pocky"},
"pococurante":{"pococurante","pococuranti"},
"pod":{"pod","podded","podding","pods"},
"podalyria":{"podalyria","podalyrias"},
"podargidae":{"podargidae","podargidaes"},
"podargus":{"podargus","podarguses"},
"podgy":{"podgier","podgiest","podgy"},
"podiatrist":{"podiatrist","podiatrists"},
"podiatry":{"podiatries","podiatry"},
"podiceps":{"podiceps","podicepses"},
"podicipedidae":{"podicipedidae","podicipedidaes"},
"podicipediformes":{"podicipediformes","podicipediformeses"},
"podicipitiformes":{"podicipitiformes","podicipitiformeses"},
"podilymbus":{"podilymbus","podilymbuses"},
"podium":{"podia","podium","podiums"},
"podocarpaceae":{"podocarpaceae","podocarpaceaes"},
"podocarpus":{"podocarpus","podocarpuses"},
"podophyllum":{"podophyllum","podophyllums"},
"podsol":{"podsol","podsols"},
"podzol":{"podzol","podzols"},
"poeciliid":{"poeciliid","poeciliids"},
"poeciliidae":{"poeciliidae","poeciliidaes"},
"poecilocapsus":{"poecilocapsus","poecilocapsuses"},
"poecilogale":{"poecilogale","poecilogales"},
"poem":{"poem","poems"},
"poenology":{"poenologies","poenology"},
"poephila":{"poephila","poephilas"},
"poesy":{"poesies","poesy"},
"poet":{"poet","poets"},
"poet-singer":{"poet-singer","poet-singers"},
"poetize":{"poetize","poetized","poetizes","poetizing"},
"poetry":{"poetries","poetry"},
"pogey":{"pogey","pogeys"},
"pogge":{"pogge","pogges"},
"pogonophora":{"pogonophora","pogonophoras"},
"pogonophoran":{"pogonophoran","pogonophorans"},
"pogostemon":{"pogostemon","pogostemons"},
"pogy":{"pogies","pogy"},
"poignance":{"poignance","poignances"},
"poignancy":{"poignancies","poignancy"},
"poilu":{"poilu","poilus"},
"poinciana":{"poinciana","poincianas"},
"poinsettia":{"poinsettia","poinsettias"},
"point":{"point","pointed","pointing","points"},
"pointedness":{"pointedness","pointednesses"},
"pointer":{"pointer","pointers"},
"pointlessness":{"pointlessness","pointlessnesses"},
"pointsman":{"pointsman","pointsmen"},
"pointy":{"pointier","pointiest","pointy"},
"poise":{"poise","poised","poises","poising"},
"poison":{"poison","poisoned","poisoning","poisons"},
"poisonberry":{"poisonberries","poisonberry"},
"poitiers":{"poitiers","poitierses"},
"poitou":{"poitou","poitous"},
"poitou-charentes":{"poitou-charentes","poitou-charenteses"},
"poivrade":{"poivrade","poivrades"},
"poke":{"poke","poked","pokes","poking"},
"pokeberry":{"pokeberries","pokeberry"},
"poker":{"poker","pokered","pokering","pokers"},
"pokey":{"pokey","pokeys"},
"poking":{"poking","pokings"},
"poky":{"pokier","pokies","pokiest","poky"},
"pol":{"pol","pols"},
"poland":{"poland","polands"},
"polanisia":{"polanisia","polanisias"},
"polarimeter":{"polarimeter","polarimeters"},
"polaris":{"polaris","polarises"},
"polarisation":{"polarisation","polarisations"},
"polariscope":{"polariscope","polariscopes"},
"polarity":{"polarities","polarity"},
"polarization":{"polarization","polarizations"},
"polarize":{"polarize","polarized","polarizing"},
"pole":{"pole","poled","poles","poling"},
"pole-vault":{"pole-vault","pole-vaulted","pole-vaulting"},
"poleax":{"poleax","poleaxes"},
"poleaxe":{"poleaxe","poleaxes"},
"polecat":{"polecat","polecats"},
"polemize":{"polemize","polemized","polemizes","polemizing"},
"polemoniaceae":{"polemoniaceae","polemoniaceaes"},
"polemoniales":{"polemoniales","polemonialeses"},
"poler":{"poler","polers"},
"polestar":{"polestar","polestars"},
"polianthes":{"polianthes","poliantheses"},
"police":{"police","policed","polices","policing"},
"policeman":{"policeman","policemen"},
"policewoman":{"policewoman","policewomen"},
"policy":{"policies","policy"},
"polio":{"polio","polios"},
"poliomyelitis":{"poliomyelitis","poliomyelitises"},
"polioptila":{"polioptila","polioptilas"},
"polis":{"poleis","polis"},
"polish":{"polish","polished","polishes","polishing"},
"polisher":{"polisher","polishers"},
"polishing":{"polishing","polishings"},
"polistes":{"polistes","polisteses"},
"politeness":{"politeness","politenesses"},
"politesse":{"politesse","politesses"},
"politic":{"politic","politicked","politicking"},
"politician":{"politician","politicians"},
"politicize":{"politicize","politicized","politicizing"},
"politico":{"politico","politicos"},
"politics":{"politics","politicses"},
"polity":{"polities","polity"},
"polk":{"polk","polks"},
"polka":{"polka","polkaed","polkaing","polkas"},
"poll":{"poll","polled","polling","polls"},
"pollachius":{"pollachius","pollachiuses"},
"pollack":{"pollack","pollacks"},
"pollard":{"pollard","pollarded","pollarding","pollards"},
"pollen":{"pollen","pollened","pollening"},
"pollenation":{"pollenation","pollenations"},
"pollex":{"pollex","pollexes"},
"pollinate":{"pollinate","pollinated","pollinates","pollinating"},
"pollination":{"pollination","pollinations"},
"pollinium":{"polliniia","pollinium"},
"pollinosis":{"pollinoses","pollinosis"},
"polliwog":{"polliwog","polliwogs"},
"pollock":{"pollock","pollocks"},
"pollster":{"pollster","pollsters"},
"pollute":{"pollute","polluted","pollutes","polluting"},
"pollution":{"pollution","pollutions"},
"pollyanna":{"pollyanna","pollyannas"},
"pollyfish":{"pollyfish","pollyfishes"},
"pollywog":{"pollywog","pollywogs"},
"polo":{"polo","polos"},
"polo-neck":{"polo-neck","polo-necks"},
"polonium":{"polonium","poloniums"},
"polony":{"polonies","polony"},
"polska":{"polska","polskas"},
"poltroon":{"poltroon","poltroons"},
"poly":{"poly","polys"},
"polyamide":{"polyamide","polyamides"},
"polyangiaceae":{"polyangiaceae","polyangiaceaes"},
"polyangium":{"polyangium","polyangiums"},
"polyanthus":{"polyanthus","polyanthuses"},
"polyborus":{"polyborus","polyboruses"},
"polybotria":{"polybotria","polybotrias"},
"polybotrya":{"polybotrya","polybotryas"},
"polybutene":{"polybutene","polybutenes"},
"polybutylene":{"polybutylene","polybutylenes"},
"polychaeta":{"polychaeta","polychaetas"},
"polychaete":{"polychaete","polychaetes"},
"polychasium":{"polychasia","polychasium"},
"polychete":{"polychete","polychetes"},
"polychrome":{"polychrome","polychromed","polychromes","polychroming"},
"polycirrus":{"polycirrus","polycirruses"},
"polydactylus":{"polydactylus","polydactyluses"},
"polyergus":{"polyergus","polyerguses"},
"polyethylene":{"polyethylene","polyethylenes"},
"polyfoam":{"polyfoam","polyfoams"},
"polygala":{"polygala","polygalas"},
"polygalaceae":{"polygalaceae","polygalaceaes"},
"polygamy":{"polygamies","polygamy"},
"polyglot":{"polyglot","polyglots"},
"polygon":{"polygon","polygons"},
"polygonaceae":{"polygonaceae","polygonaceaes"},
"polygonales":{"polygonales","polygonaleses"},
"polygonatum":{"polygonatum","polygonatums"},
"polygonia":{"polygonia","polygonias"},
"polygonum":{"polygonum","polygonums"},
"polygyny":{"polygynies","polygyny"},
"polyhedron":{"polyhedra","polyhedron","polyhedrons"},
"polymastigina":{"polymastigina","polymastiginas"},
"polymerisation":{"polymerisation","polymerisations"},
"polymerization":{"polymerization","polymerizations"},
"polymorphism":{"polymorphism","polymorphisms"},
"polynemidae":{"polynemidae","polynemidaes"},
"polyodon":{"polyodon","polyodons"},
"polyodontidae":{"polyodontidae","polyodontidaes"},
"polyoma":{"polyoma","polyomas"},
"polyose":{"polyose","polyoses"},
"polyp":{"polyp","polyps"},
"polyparium":{"polyparium","polyparparia"},
"polypary":{"polyparies","polypary"},
"polypedates":{"polypedates","polypedateses"},
"polypedatidae":{"polypedatidae","polypedatidaes"},
"polyphone":{"polyphone","polyphones"},
"polyphony":{"polyphonies","polyphony"},
"polyplacophora":{"polyplacophora","polyplacophoras"},
"polyplacophore":{"polyplacophore","polyplacophores"},
"polypodiaceae":{"polypodiaceae","polypodiaceaes"},
"polypodiales":{"polypodiales","polypodialeses"},
"polypodium":{"polypodium","polypodiums"},
"polypody":{"polypodies","polypody"},
"polyporaceae":{"polyporaceae","polyporaceaes"},
"polypore":{"polypore","polypores"},
"polyporus":{"polyporus","polyporuses"},
"polyprion":{"polyprion","polyprions"},
"polypropene":{"polypropene","polypropenes"},
"polypropylene":{"polypropylene","polypropylenes"},
"polypus":{"polypus","polypuses"},
"polysaccharide":{"polysaccharide","polysaccharides"},
"polystichum":{"polystichum","polystichums"},
"polysyllable":{"polysyllable","polysyllables"},
"polytechnic":{"polytechnic","polytechnics"},
"polytetrafluoroethylene":{"polytetrafluoroethylene","polytetrafluoroethylenes"},
"polytheism":{"polytheism","polytheisms"},
"polythene":{"polythene","polythenes"},
"polytonalism":{"polytonalism","polytonalisms"},
"polytonality":{"polytonalities","polytonality"},
"polyurethane":{"polyurethane","polyurethanes"},
"polyzoa":{"polyzoa","polyzoas"},
"polyzoan":{"polyzoan","polyzoans"},
"polyzoarium":{"polyzoariia","polyzoarium"},
"pom":{"pom","poms"},
"pom-pom":{"pom-pom","pom-poms"},
"pomacanthus":{"pomacanthus","pomacanthuses"},
"pomacentridae":{"pomacentridae","pomacentridaes"},
"pomacentrus":{"pomacentrus","pomacentruses"},
"pomade":{"pomade","pomaded","pomades","pomading"},
"pomaderris":{"pomaderris","pomaderrises"},
"pomatomidae":{"pomatomidae","pomatomidaes"},
"pomatomus":{"pomatomus","pomatomuses"},
"pomatum":{"pomatum","pomatums"},
"pome":{"pome","pomes"},
"pomegranate":{"pomegranate","pomegranates"},
"pomelo":{"pomelo","pomelos"},
"pomfret":{"pomfret","pomfrets"},
"pommel":{"pommel","pommeled","pommeling","pommelled","pommelling","pommels"},
"pommy":{"pommies","pommy"},
"pomolobus":{"pomolobus","pomolobuses"},
"pomoxis":{"pomoxes","pomoxis"},
"pomp":{"pomp","pomps"},
"pompano":{"pompano","pompanos"},
"pompey":{"pompey","pompeys"},
"pompon":{"pompon","pompons"},
"pomposity":{"pomposities","pomposity"},
"pompousness":{"pompousness","pompousnesses"},
"ponca":{"ponca","poncas"},
"ponce":{"ponce","ponces"},
"poncho":{"poncho","ponchos"},
"poncirus":{"poncirus","ponciruses"},
"pond":{"pond","ponded","ponding","ponds"},
"pond-skater":{"pond-skater","pond-skaters"},
"ponder":{"ponder","pondered","pondering","ponders"},
"ponderosa":{"ponderosa","ponderosas"},
"ponderosity":{"ponderosities","ponderosity"},
"ponderousness":{"ponderousness","ponderousnesses"},
"pondo":{"pondo","pondos"},
"pondweed":{"pondweed","pondweeds"},
"pone":{"pone","pones"},
"pong":{"pong","ponged","ponging"},
"pongamia":{"pongamia","pongamias"},
"pongid":{"pongid","pongids"},
"pongidae":{"pongidae","pongidaes"},
"pongo":{"pongo","pongos"},
"poniard":{"poniard","poniarded","poniarding","poniards"},
"ponka":{"ponka","ponkas"},
"pons":{"pons","ponses"},
"ponstel":{"ponstel","ponstels"},
"pontederia":{"pontederia","pontederias"},
"pontederiaceae":{"pontederiaceae","pontederiaceaes"},
"pontifex":{"pontifex","pontifices"},
"pontiff":{"pontiff","pontiffs"},
"pontificate":{"pontificate","pontificated","pontificates","pontificating"},
"pontos":{"pontos","pontoses"},
"pontus":{"pontus","pontuses"},
"pony":{"ponied","ponies","pony","ponying"},
"ponycart":{"ponycart","ponycarts"},
"pooch":{"pooch","pooches"},
"poodle":{"poodle","poodles"},
"pooecetes":{"pooecetes","pooeceteses"},
"poof":{"poof","poofs"},
"pooh-bah":{"pooh-bah","pooh-bahs"},
"pooh-pooh":{"pooh-pooh","pooh-poohed","pooh-poohing","pooh-poohs"},
"pool":{"pool","pooled","pooling","pools"},
"poop":{"poop","pooped","pooping","poops"},
"poor":{"poor","poorer","poorest"},
"poor-mouth":{"poor-mouth","poor-mouthed","poor-mouthing"},
"poorhouse":{"poorhouse","poorhouses"},
"poorness":{"poorness","poornesses"},
"poorwill":{"poorwill","poorwills"},
"poove":{"poove","pooves"},
"pop":{"pop","popped","popping","pops"},
"popcorn":{"popcorn","popcorns"},
"pope":{"pope","popes"},
"popillia":{"popillia","popillias"},
"poplar":{"poplar","poplars"},
"poppet":{"poppet","poppets"},
"popping":{"popping","poppings"},
"popple":{"popple","poppled","poppling"},
"poppy":{"poppies","poppy"},
"poppycock":{"poppycock","poppycocks"},
"popsicle":{"popsicle","popsicles"},
"popsy":{"popsies","popsy"},
"populace":{"populace","populaces"},
"popularisation":{"popularisation","popularisations"},
"popularization":{"popularization","popularizations"},
"popularize":{"popularize","popularized","popularizes","popularizing"},
"populate":{"populate","populated","populates","populating"},
"populating":{"populating","populatings"},
"population":{"population","populations"},
"populist":{"populist","populists"},
"populus":{"populus","populuses"},
"porbeagle":{"porbeagle","porbeagles"},
"porc":{"porc","porcs"},
"porcellio":{"porcellio","porcellios"},
"porcellionidae":{"porcellionidae","porcellionidaes"},
"porch":{"porch","porches"},
"porcupine":{"porcupine","porcupines"},
"porcupinefish":{"porcupinefish","porcupinefishes"},
"porcupines":{"porcupines","porcupineses"},
"pore":{"pore","pored","pores","poring"},
"porgy":{"porgies","porgy"},
"porifera":{"porifera","poriferas"},
"poriferan":{"poriferan","poriferans"},
"pork":{"pork","porks"},
"porkfish":{"porkfish","porkfishes"},
"porkpie":{"porkpie","porkpies"},
"porky":{"porkier","porkiest","porky"},
"porn":{"porn","porns"},
"porno":{"porno","pornos"},
"pornographer":{"pornographer","pornographers"},
"pornography":{"pornographies","pornography"},
"poronotus":{"poronotus","poronotuses"},
"poroporo":{"poroporo","poroporos"},
"porosity":{"porosities","porosity"},
"porousness":{"porousness","porousnesses"},
"porphyra":{"porphyra","porphyras"},
"porphyrio":{"porphyrio","porphyrios"},
"porphyrula":{"porphyrula","porphyrulas"},
"porphyry":{"porphyries","porphyry"},
"porpoise":{"porpoise","porpoises"},
"port":{"port","ported","porting","ports"},
"port-au-prince":{"port-au-prince","port-au-princes"},
"port-of-spain":{"port-of-spain","port-of-spains"},
"portability":{"portabilities","portability"},
"portable":{"portable","portables"},
"portage":{"portage","portaged","portaging"},
"portal":{"portal","portals"},
"portamento":{"portamenti","portamento"},
"portend":{"portend","portended","portending","portends"},
"portent":{"portent","portents"},
"porter":{"porter","porters"},
"porterhouse":{"porterhouse","porterhouses"},
"portfolio":{"portfolio","portfolios"},
"porthole":{"porthole","portholes"},
"portico":{"portico","porticoes","porticos"},
"portiere":{"portiere","portieres"},
"portion":{"portion","portioned","portioning","portions"},
"portly":{"portlier","portlies","portliest","portly"},
"portmanteau":{"portmanteau","portmanteaus","portmanteaux"},
"portrait":{"portrait","portraits"},
"portraitist":{"portraitist","portraitists"},
"portraiture":{"portraiture","portraitures"},
"portray":{"portray","portrayed","portraying","portrays"},
"portrayal":{"portrayal","portrayals"},
"portraying":{"portraying","portrayings"},
"portulacacaea":{"portulacacaea","portulacacaeas"},
"portunidae":{"portunidae","portunidaes"},
"portunus":{"portunus","portunuses"},
"porzana":{"porzana","porzanas"},
"posada":{"posada","posadas"},
"pose":{"pose","posed","poses","posing"},
"poser":{"poser","posers"},
"poseur":{"poseur","poseurs"},
"posing":{"posing","posings"},
"posit":{"posit","posited","positing","posits"},
"position":{"position","positioned","positioning","positions"},
"positioner":{"positioner","positioners"},
"positioning":{"positioning","positionings"},
"positive":{"positive","positives"},
"positivism":{"positivism","positivisms"},
"positivist":{"positivist","positivists"},
"positivity":{"positivities","positivity"},
"positron":{"positron","positrons"},
"posse":{"posse","posses"},
"posseman":{"posseman","possemen"},
"possess":{"possess","possessed","possesses","possessing"},
"possession":{"possession","possessions"},
"possessive":{"possessive","possessives"},
"possessor":{"possessor","possessors"},
"possibility":{"possibilities","possibility"},
"possibleness":{"possibleness","possiblenesses"},
"possum":{"possum","possums"},
"possumwood":{"possumwood","possumwoods"},
"post":{"post","posted","posting","posts"},
"postage":{"postage","postages"},
"postagestamp":{"postagestamp","postagestamps"},
"postal":{"postal","postals"},
"postbag":{"postbag","postbags"},
"postbox":{"postbox","postboxes"},
"postcard":{"postcard","postcards"},
"postcava":{"postcava","postcavas"},
"postcode":{"postcode","postcodes"},
"postdate":{"postdate","postdated","postdates","postdating"},
"poster":{"poster","posters"},
"posterboard":{"posterboard","posterboards"},
"posterior":{"posterior","posteriors"},
"posteriority":{"posteriorities","posteriority"},
"posterity":{"posterities","posterity"},
"postern":{"postern","posterns"},
"postfix":{"postfix","postfixed","postfixing"},
"postgraduate":{"postgraduate","postgraduates"},
"posthole":{"posthole","postholes"},
"postiche":{"postiche","postiches"},
"postilion":{"postilion","postilions"},
"postillion":{"postillion","postillions"},
"posting":{"posting","postings"},
"postliminium":{"postliminiia","postliminium"},
"postliminy":{"postliminies","postliminy"},
"postman":{"postman","postmen"},
"postmark":{"postmark","postmarked","postmarking","postmarks"},
"postmaster":{"postmaster","postmasters"},
"postmen":{"postmen","postwomen"},
"postmortem":{"postmortem","postmortems"},
"postoffice":{"postoffice","postoffices"},
"postpone":{"postpone","postponed","postpones","postponing"},
"postponement":{"postponement","postponements"},
"postponer":{"postponer","postponers"},
"postscript":{"postscript","postscripts"},
"postulate":{"postulate","postulated","postulates","postulating"},
"postulation":{"postulation","postulations"},
"posture":{"posture","postured","postures","posturing"},
"postwoman":{"postwoman","postwomen"},
"posy":{"posies","posy"},
"pot":{"pot","pots","potted","potting"},
"potable":{"potable","potables"},
"potamogale":{"potamogale","potamogales"},
"potamogalidae":{"potamogalidae","potamogalidaes"},
"potamogeton":{"potamogeton","potamogetons"},
"potamogetonaceae":{"potamogetonaceae","potamogetonaceaes"},
"potamophis":{"potamophis","potamophises"},
"potash":{"potash","potashes"},
"potassium":{"potassium","potassiums"},
"potation":{"potation","potations"},
"potato":{"potato","potatoes"},
"potbelly":{"potbellies","potbelly"},
"potboy":{"potboy","potboys"},
"potence":{"potence","potences"},
"potency":{"potencies","potency"},
"potentate":{"potentate","potentates"},
"potential":{"potential","potentials"},
"potentiality":{"potentialities","potentiality"},
"potentiate":{"potentiate","potentiated","potentiating"},
"potentilla":{"potentilla","potentillas"},
"potentiometer":{"potentiometer","potentiometers"},
"poterium":{"poterium","poteriums"},
"potful":{"potful","potfuls"},
"pothecary":{"pothecarcaries","pothecary"},
"pother":{"pother","pothered","pothering","pothers"},
"pothole":{"pothole","potholes"},
"potholer":{"potholer","potholers"},
"pothos":{"pothos","pothoses"},
"pothouse":{"pothouse","pothouses"},
"potiche":{"potiche","potiches"},
"potman":{"potman","potmen"},
"potomac":{"potomac","potomacs"},
"potomania":{"potomania","potomanias"},
"potoroinae":{"potoroinae","potoroinaes"},
"potorous":{"potorous","potorouses"},
"potos":{"potos","potoses"},
"potpourri":{"potpourri","potpourris"},
"potter":{"potter","pottered","pottering","potters"},
"potterer":{"potterer","potterers"},
"pottery":{"potteries","pottery"},
"potto":{"potto","pottos"},
"potty":{"pottier","potties","pottiest","potty"},
"pouch":{"pouch","pouched","pouches","pouching"},
"poudrin":{"poudrin","poudrins"},
"pouf":{"pouf","poufs"},
"pouffe":{"pouffe","pouffes"},
"poulet":{"poulet","poulets"},
"poulterer":{"poulterer","poulterers"},
"poultice":{"poultice","poulticed","poultices","poulticing"},
"poultry":{"poultries","poultry"},
"poultryman":{"poultryman","poultrymen"},
"pounce":{"pounce","pounced","pounces","pouncing"},
"pound":{"pound","pounded","pounding","pounds"},
"poundage":{"poundage","poundages"},
"poundal":{"poundal","poundals"},
"pounding":{"pounding","poundings"},
"pour":{"pour","poured","pouring","pours"},
"pourboire":{"pourboire","pourboires"},
"pouring":{"pouring","pourings"},
"pousse-cafe":{"pousse-cafe","pousse-cafes"},
"poussette":{"poussette","poussetted","poussetting"},
"pout":{"pout","pouted","pouting","pouts"},
"pouteria":{"pouteria","pouterias"},
"pouty":{"poutier","poutiest","pouty"},
"poverty":{"poverties","poverty"},
"pow":{"pow","pows"},
"powder":{"powder","powdered","powdering","powders"},
"powderiness":{"powderiness","powderinesses"},
"powderpuff":{"powderpuff","powderpuffs"},
"power":{"power","powered","powering","powers"},
"powerboat":{"powerboat","powerboats"},
"powerfulness":{"powerfulness","powerfulnesses"},
"powerhouse":{"powerhouse","powerhouses"},
"powerlessness":{"powerlessness","powerlessnesses"},
"powhatan":{"powhatan","powhatans"},
"powwow":{"powwow","powwowed","powwowing","powwows"},
"pox":{"pox","poxes"},
"poyou":{"poyou","poyous"},
"pr":{"pr","prs"},
"practicability":{"practicabilities","practicability"},
"practicableness":{"practicableness","practicablenesses"},
"practice":{"practice","practiced","practices","practicing"},
"practician":{"practician","practicians"},
"practise":{"practise","practised","practises","practising"},
"practitioner":{"practitioner","practitioners"},
"praenomen":{"praenomen","praenonomens","praenonomina"},
"praesidium":{"praesidium","praesidiums"},
"praetor":{"praetor","praetors"},
"praetorium":{"praetorium","praetoriums"},
"prag":{"prag","prags"},
"prague":{"prague","pragues"},
"praha":{"praha","prahas"},
"praia":{"praia","praias"},
"prairie":{"prairie","prairies"},
"praise":{"praise","praised","praises","praising"},
"pram":{"pram","prams"},
"prance":{"prance","pranced","prances","prancing"},
"prank":{"prank","pranked","pranking","pranks"},
"prankishness":{"prankishness","prankishnesses"},
"prankster":{"prankster","pranksters"},
"praseodymium":{"praseodymium","praseodymiums"},
"prat":{"prat","prats"},
"prate":{"prate","prated","prates","prating"},
"pratincole":{"pratincole","pratincoles"},
"prattle":{"prattle","prattled","prattles","prattling"},
"praunus":{"praunus","praunuses"},
"prawn":{"prawn","prawned","prawning","prawns"},
"praxis":{"praxes","praxis","praxises"},
"pray":{"pray","prayed","praying","prays"},
"prayer":{"prayer","prayers"},
"prc":{"prc","prcs"},
"preach":{"preach","preached","preaches","preaching"},
"preacher":{"preacher","preachers"},
"preachify":{"preachified","preachifies","preachify","preachifying"},
"preaching":{"preaching","preachings"},
"preachment":{"preachment","preachments"},
"preachy":{"preachier","preachiest","preachy"},
"prearrange":{"prearrange","prearranged","prearranging"},
"prebendary":{"prebendaries","prebendary"},
"precambrian":{"precambrian","precambrians"},
"precancel":{"precancel","precanceled","precanceling","precancelled","precancelling","precancels"},
"precast":{"precast","precasting","precasts"},
"precaution":{"precaution","precautions"},
"precava":{"precava","precavas"},
"precede":{"precede","preceded","precedes","preceding"},
"precedence":{"precedence","precedences"},
"precedency":{"precedencies","precedency"},
"precedent":{"precdedents","precedent","precedents"},
"precentor":{"precentor","precentors"},
"precept":{"precept","precepts"},
"preceptor":{"preceptor","preceptors"},
"preceptory":{"preceptories","preceptory"},
"precess":{"precess","precessed","precessing"},
"precession":{"precession","precessions"},
"precinct":{"precinct","precincts"},
"preciosity":{"preciosities","preciosity"},
"preciousness":{"preciousness","preciousnesses"},
"precipice":{"precipice","precipices"},
"precipitance":{"precipitance","precipitances"},
"precipitancy":{"precipitancies","precipitancy"},
"precipitate":{"precipitate","precipitated","precipitates","precipitating"},
"precipitateness":{"precipitateness","precipitatenesses"},
"precipitation":{"precipitation","precipitations"},
"precipitator":{"precipitator","precipitators"},
"precipitousness":{"precipitousness","precipitousnesses"},
"precis":{"precis","precised","precises","precising"},
"preciseness":{"preciseness","precisenesses"},
"precision":{"precision","precisions"},
"preclude":{"preclude","precluded","precludes","precluding"},
"preclusion":{"preclusion","preclusions"},
"precociousness":{"precociousness","precociousnesses"},
"precocity":{"precocities","precocity"},
"precognition":{"precognition","precognitions"},
"preconceive":{"preconceive","preconceived","preconceiving"},
"preconception":{"preconception","preconceptions"},
"preconcert":{"preconcert","preconcerted","preconcerting"},
"precondemn":{"precondemn","precondemned","precondemning"},
"precondition":{"precondition","preconditioned","preconditioning","preconditions"},
"preconize":{"preconize","preconized","preconizing"},
"precontract":{"precontract","precontracted","precontracting"},
"precook":{"precook","precooked","precooking"},
"precursor":{"precursor","precursors"},
"predate":{"predate","predated","predates","predating"},
"predation":{"predation","predations"},
"predator":{"predator","predators"},
"predecease":{"predecease","predeceased","predeceasing"},
"predecessor":{"predecessor","predecessors"},
"predella":{"predella","predelle"},
"predestinate":{"predestinate","predestinated","predestinates","predestinating"},
"predestination":{"predestination","predestinations"},
"predestinationist":{"predestinationist","predestinationists"},
"predestine":{"predestine","predestined","predestines","predestining"},
"predetermination":{"predetermination","predeterminations"},
"predetermine":{"predetermine","predetermined","predetermines","predetermining"},
"predicament":{"predicament","predicaments"},
"predicate":{"predicate","predicated","predicates","predicating"},
"predication":{"predication","predications"},
"predict":{"predict","predicted","predicting","predicts"},
"prediction":{"prediction","predictions"},
"predictor":{"predictor","predictors"},
"predigest":{"predigest","predigested","predigesting"},
"predilection":{"predilection","predilections"},
"predispose":{"predispose","predisposed","predisposing"},
"predisposition":{"predisposition","predispositions"},
"predominance":{"predominance","predominances"},
"predominate":{"predominate","predominated","predominates","predominating"},
"predomination":{"predomination","predominations"},
"preemie":{"preemie","preemies"},
"preeminence":{"preeminence","preeminences"},
"preempt":{"preempt","preempted","preempting"},
"preen":{"preen","preened","preening","preens"},
"preexist":{"preexist","preexisted","preexisting"},
"prefab":{"prefab","prefabbed","prefabbing"},
"prefabricate":{"prefabricate","prefabricated","prefabricates","prefabricating"},
"preface":{"preface","prefaced","prefaces","prefacing"},
"prefect":{"prefect","prefects"},
"prefecture":{"prefecture","prefectures"},
"prefer":{"prefer","preferred","preferring","prefers"},
"preference":{"preference","preferences"},
"preferment":{"preferment","preferments"},
"prefiguration":{"prefiguration","prefigurations"},
"prefigure":{"prefigure","prefigured","prefigures","prefiguring"},
"prefix":{"prefix","prefixed","prefixes","prefixing"},
"preform":{"preform","preformed","preforming"},
"pregnancy":{"pregnancies","pregnancy"},
"preheat":{"preheat","preheated","preheating"},
"prehension":{"prehension","prehensions"},
"prehistory":{"prehistories","prehistory"},
"prejudge":{"prejudge","prejudged","prejudging"},
"prejudgement":{"prejudgement","prejudgements"},
"prejudgment":{"prejudgment","prejudgments"},
"prejudice":{"prejudice","prejudiced","prejudices","prejudicing"},
"prelacy":{"prelacies","prelacy"},
"prelate":{"prelate","prelates"},
"prelature":{"prelature","prelatures"},
"prelim":{"prelim","prelims"},
"preliminary":{"preliminaries","preliminary"},
"prelims":{"prelims","prelimses"},
"prelude":{"prelude","preluded","preludes","preluding"},
"prematureness":{"prematureness","prematurenesses"},
"prematurity":{"prematurities","prematurity"},
"premaxilla":{"premaxilla","premaxillae"},
"premeditate":{"premeditate","premeditated","premeditating"},
"premie":{"premie","premies"},
"premier":{"premier","premiered","premiering","premiers"},
"premiere":{"premiere","premiered","premieres","premiering"},
"premise":{"premise","premised","premises","premising"},
"premiss":{"premiss","premisses"},
"premium":{"premium","premiums"},
"premix":{"premix","premixes"},
"premolar":{"premolar","premolars"},
"premonish":{"premonish","premonished","premonishing"},
"premonition":{"premonition","premonitions"},
"prenanthes":{"prenanthes","prenantheses"},
"prenomen":{"prenomen","prenonomens","prenonomina"},
"prentice":{"prentice","prentices"},
"preoccupancy":{"preoccupancies","preoccupancy"},
"preoccupation":{"preoccupation","preoccupations"},
"preoccupy":{"preoccupied","preoccupies","preoccupy","preoccupying"},
"preordain":{"preordain","preordained","preordaining","preordains"},
"preordination":{"preordination","preordinations"},
"prep":{"prep","prepped","prepping","preps"},
"prepack":{"prepack","prepacked","prepacking"},
"prepackage":{"prepackage","prepackaged","prepackaging"},
"preparation":{"preparation","preparations"},
"preparatory":{"preparatories","preparatory"},
"prepare":{"prepare","prepared","prepares","preparing"},
"preparedness":{"preparedness","preparednesses"},
"prepay":{"prepaid","prepay","prepaying","prepays"},
"preponderance":{"preponderance","preponderances"},
"preponderate":{"preponderate","preponderated","preponderates","preponderating"},
"preposition":{"preposition","prepositions"},
"prepossess":{"prepossess","prepossessed","prepossesses","prepossessing"},
"prepossession":{"prepossession","prepossessions"},
"preppie":{"preppie","preppies"},
"prepuce":{"prepuce","prepuces"},
"prerecord":{"prerecord","prerecorded","prerecording"},
"prerequisite":{"prerequisite","prerequisites"},
"prerogative":{"prerogative","prerogatives"},
"presa":{"presa","prese"},
"presage":{"presage","presaged","presages","presaging"},
"presbytery":{"presbyteries","presbytery"},
"presbytes":{"presbytes","presbyteses"},
"prescience":{"prescience","presciences"},
"prescind":{"prescind","prescinded","prescinding"},
"prescribe":{"prescribe","prescribed","prescribes","prescribing"},
"prescript":{"prescript","prescripts"},
"prescription":{"prescription","prescriptions"},
"presence":{"presence","presences"},
"present":{"present","presented","presenting","presents"},
"presentation":{"presentation","presentations"},
"presenter":{"presenter","presenters"},
"presentiment":{"presentiment","presentiments"},
"presentment":{"presentment","presentments"},
"presentness":{"presentness","presentnesses"},
"preservation":{"preservation","preservations"},
"preservative":{"preservative","preservatives"},
"preserve":{"preserve","preserved","preserves","preserving"},
"preserver":{"preserver","preservers"},
"preserves":{"preserves","preserveses"},
"preserving":{"preserving","preservings"},
"preset":{"preset","presetting"},
"preside":{"preside","presided","presides","presiding"},
"presidency":{"presidencies","presidency"},
"president":{"president","presidents"},
"presidentship":{"presidentship","presidentships"},
"presidio":{"presidio","presidios"},
"presidium":{"presidia","presidium","presidiums"},
"presignify":{"presignified","presignifies","presignify","presignifying"},
"press":{"press","pressed","presses","pressing"},
"press-up":{"press-up","press-ups"},
"pressing":{"pressing","pressings"},
"pressman":{"pressman","pressmen"},
"pressmark":{"pressmark","pressmarks"},
"pressure":{"pressure","pressured","pressures","pressuring"},
"pressurize":{"pressurize","pressurized","pressurizes","pressurizing"},
"prestidigitation":{"prestidigitation","prestidigitations"},
"prestidigitator":{"prestidigitator","prestidigitators"},
"prestige":{"prestige","prestiges"},
"prestigiousness":{"prestigiousness","prestigiousnesses"},
"prestissimo":{"prestissimo","prestissimos"},
"presto":{"presto","prestos"},
"presume":{"presume","presumed","presumes","presuming"},
"presumption":{"presumption","presumptions"},
"presumptuousness":{"presumptuousness","presumptuousnesses"},
"presuppose":{"presuppose","presupposed","presupposing"},
"presupposition":{"presupposition","presuppositions"},
"pretence":{"pretence","pretences"},
"pretend":{"pretend","pretended","pretending","pretends"},
"pretender":{"pretender","pretenders"},
"pretending":{"pretending","pretendings"},
"pretense":{"pretense","pretenses"},
"pretension":{"pretension","pretensions"},
"pretentiousness":{"pretentiousness","pretentiousnesses"},
"preterit":{"preterit","preterits"},
"preterite":{"preterite","preterites"},
"preterition":{"preterition","preteritions"},
"pretermission":{"pretermission","pretermissions"},
"pretermit":{"pretermit","pretermits","pretermitted","pretermitting"},
"pretest":{"pretest","pretested","pretesting"},
"pretext":{"pretext","pretexts"},
"pretor":{"pretor","pretors"},
"pretoria":{"pretoria","pretorias"},
"pretorium":{"pretorium","pretoriums"},
"pretrial":{"pretrial","pretrials"},
"prettify":{"prettified","prettifies","prettify","prettifying"},
"prettiness":{"prettiness","prettinesses"},
"pretty":{"prettied","prettier","pretties","prettiest","pretty","prettying"},
"preussen":{"preussen","preussens"},
"prevail":{"prevail","prevailed","prevailing","prevails"},
"prevalence":{"prevalence","prevalences"},
"prevaricate":{"prevaricate","prevaricated","prevaricates","prevaricating"},
"prevarication":{"prevarication","prevarications"},
"prevaricator":{"prevaricator","prevaricators"},
"prevent":{"prevent","prevented","preventing","prevents"},
"preventative":{"preventative","preventatives"},
"prevention":{"prevention","preventions"},
"preventive":{"preventive","preventives"},
"preview":{"preview","previewed","previewing","previews"},
"prevision":{"prevision","previsions"},
"prevue":{"prevue","prevues"},
"prexy":{"prexes","prexies","prexy"},
"prey":{"prey","preyed","preying","preys"},
"preying":{"preying","preyings"},
"priacanthidae":{"priacanthidae","priacanthidaes"},
"priacanthus":{"priacanthus","priacanthuses"},
"price":{"price","priced","prices","pricing"},
"pricelessness":{"pricelessness","pricelessnesses"},
"pricey":{"pricey","pricier","priciest"},
"prick":{"prick","pricked","pricking","pricks"},
"pricker":{"pricker","prickers"},
"prickle":{"prickle","prickled","prickles","prickling"},
"prickle-weed":{"prickle-weed","prickle-weeds"},
"prickleback":{"prickleback","pricklebacks"},
"prickling":{"prickling","pricklings"},
"prickly":{"pricklier","prickliest","prickly"},
"prickteaser":{"prickteaser","prickteasers"},
"pride":{"pride","prided","prides","priding"},
"pride-of-india":{"pride-of-india","pride-of-indias"},
"pridefulness":{"pridefulness","pridefulnesses"},
"prie-dieu":{"prie-dieu","prie-dieus","prie-dieux"},
"priest":{"priest","priested","priesting","priests"},
"priest-doctor":{"priest-doctor","priest-doctors"},
"priestly":{"priestlier","priestliest","priestly"},
"prig":{"prig","prigs"},
"priggishness":{"priggishness","priggishnesses"},
"prill":{"prill","prilled","prilling"},
"prim":{"prim","primmed","primmer","primmest","primming","prims"},
"primacy":{"primacies","primacy"},
"primary":{"primaries","primary"},
"primate":{"primate","primates"},
"primates":{"primates","primateses"},
"prime":{"prime","primed","primes","priming"},
"primeminister":{"primeminister","primeministers"},
"primer":{"primer","primers"},
"primigravida":{"primigravida","primigravidas"},
"primipara":{"primipara","primiparae","primiparas"},
"primitive":{"primitive","primitives"},
"primitiveness":{"primitiveness","primitivenesses"},
"primitivism":{"primitivism","primitivisms"},
"primness":{"primness","primnesses"},
"primo":{"primi","primo","primos"},
"primogenitor":{"primogenitor","primogenitors"},
"primordium":{"primordia","primordium","primordiums"},
"primp":{"primp","primped","primping","primps"},
"primrose":{"primrose","primroses"},
"primula":{"primula","primulas"},
"primulaceae":{"primulaceae","primulaceaes"},
"primulales":{"primulales","primulaleses"},
"primus":{"primus","primuses"},
"prince":{"prince","princes"},
"princedom":{"princedom","princedoms"},
"princely":{"princelier","princeliest","princely"},
"princess":{"princess","princesses"},
"princeton":{"princeton","princetons"},
"princewood":{"princewood","princewoods"},
"principal":{"principal","principals"},
"principality":{"principalities","principality"},
"principium":{"principia","principiia","principium"},
"principle":{"principle","principles"},
"prinia":{"prinia","prinias"},
"prink":{"prink","prinked","prinking","prinks"},
"print":{"print","printed","printing","prints"},
"printer":{"printer","printers"},
"printery":{"printeries","printery"},
"printing":{"printing","printings"},
"printmaker":{"printmaker","printmakers"},
"priodontes":{"priodontes","priodonteses"},
"prionace":{"prionace","prionaces"},
"prionotus":{"prionotus","prionotuses"},
"prior":{"prior","priors"},
"prioress":{"prioress","prioresses"},
"priority":{"priorities","priority"},
"priory":{"priories","priory"},
"prism":{"prism","prisms"},
"prison":{"prison","prisons"},
"prison-breaking":{"prison-breaking","prison-breakings"},
"prisonbreak":{"prisonbreak","prisonbreaks"},
"prisoner":{"prisoner","prisoners"},
"prissy":{"prissier","prissiest","prissy"},
"pristidae":{"pristidae","pristidaes"},
"pristis":{"pristis","pristises"},
"pritzelago":{"pritzelago","pritzelagos"},
"privacy":{"privacies","privacy"},
"private":{"private","privates"},
"privateer":{"privateer","privateered","privateering","privateers"},
"privateersman":{"privateersman","privateersmen"},
"privateness":{"privateness","privatenesses"},
"privates":{"privates","privateses"},
"privation":{"privation","privations"},
"privilege":{"privilege","privileged","privileges","privileging"},
"privity":{"privities","privity"},
"privy":{"privies","privy"},
"prize":{"prize","prized","prizes","prizing"},
"prizefight":{"prizefight","prizefights"},
"prizefighter":{"prizefighter","prizefighters"},
"pro":{"pro","pros"},
"probability":{"probabilities","probability"},
"probate":{"probate","probated","probates","probating"},
"probationer":{"probationer","probationers"},
"probe":{"probe","probed","probes","probing"},
"probing":{"probing","probings"},
"problem":{"problem","problems"},
"proboscidea":{"proboscidea","proboscideas"},
"proboscidean":{"proboscidean","proboscideans"},
"proboscidian":{"proboscidian","proboscidians"},
"proboscis":{"proboscides","proboscis","proboscises"},
"procaryote":{"procaryote","procaryotes"},
"procavia":{"procavia","procavias"},
"procaviidae":{"procaviidae","procaviidaes"},
"procedure":{"procedure","procedures"},
"proceed":{"proceed","proceeded","proceeding","proceeds"},
"proceeding":{"proceeding","proceedings"},
"proceedings":{"proceedings","proceedingses"},
"proceeds":{"proceeds","proceedses"},
"procellaria":{"procellaria","procellarias"},
"procellariidae":{"procellariidae","procellariidaes"},
"procellariiformes":{"procellariiformes","procellariiformeses"},
"proces-verbal":{"proces-verbal","proces-verbaux"},
"process":{"process","processed","processes","processing"},
"procession":{"procession","processioned","processioning","processions"},
"processional":{"processional","processionals"},
"processor":{"processor","processors"},
"prociphilus":{"prociphilus","prociphiluses"},
"proclaim":{"proclaim","proclaimed","proclaiming","proclaims"},
"proclamation":{"proclamation","proclamations"},
"proclivity":{"proclivities","proclivity"},
"procnias":{"procnias","procniases"},
"proconsulate":{"proconsulate","proconsulates"},
"proconsulship":{"proconsulship","proconsulships"},
"procrastinate":{"procrastinate","procrastinated","procrastinates","procrastinating"},
"procrastination":{"procrastination","procrastinations"},
"procrastinator":{"procrastinator","procrastinators"},
"procreate":{"procreate","procreated","procreates","procreating"},
"procreation":{"procreation","procreations"},
"proctor":{"proctor","proctored","proctoring","proctors"},
"procural":{"procural","procurals"},
"procurance":{"procurance","procurances"},
"procurator":{"procurator","procurators"},
"procure":{"procure","procured","procures","procuring"},
"procurement":{"procurement","procurements"},
"procurer":{"procurer","procurers"},
"procyon":{"procyon","procyons"},
"procyonidae":{"procyonidae","procyonidaes"},
"prod":{"prod","prodded","prodding","prods"},
"prodding":{"prodding","proddings"},
"prodigal":{"prodigal","prodigals"},
"prodigality":{"prodigalities","prodigality"},
"prodigy":{"prodigies","prodigy"},
"produce":{"produce","produced","produces","producing"},
"producer":{"producer","producers"},
"product":{"product","products"},
"production":{"production","productions"},
"productiveness":{"productiveness","productivenesses"},
"productivity":{"productivities","productivity"},
"profanation":{"profanation","profanations"},
"profane":{"profane","profaned","profanes","profaning"},
"profaneness":{"profaneness","profanenesses"},
"profanity":{"profanities","profanity"},
"profess":{"profess","professed","professes","professing"},
"professing":{"professing","professings"},
"profession":{"profession","professions"},
"professional":{"professional","professionals"},
"professionalize":{"professionalize","professionalized","professionalizing"},
"professor":{"professor","professors"},
"professorship":{"professorship","professorships"},
"proffer":{"proffer","proffered","proffering","proffers"},
"proficiency":{"proficiencies","proficiency"},
"proficient":{"proficient","proficients"},
"profile":{"profile","profiled","profiles","profiling"},
"profit":{"profit","profited","profiting","profits"},
"profitability":{"profitabilities","profitability"},
"profitableness":{"profitableness","profitablenesses"},
"profiteer":{"profiteer","profiteered","profiteering","profiteers"},
"profits":{"profits","profitses"},
"profligacy":{"profligacies","profligacy"},
"profligate":{"profligate","profligates"},
"profound":{"profound","profounder","profoundest"},
"profoundness":{"profoundness","profoundnesses"},
"profundity":{"profundities","profundity"},
"profuseness":{"profuseness","profusenesses"},
"profusion":{"profusion","profusions"},
"prog":{"prog","progged","progging"},
"progenitor":{"progenitor","progenitors"},
"progeny":{"progenies","progeny"},
"proglottid":{"proglotglottides","proglottid","proglottides"},
"proglottis":{"proglotglottides","proglottis"},
"progne":{"progne","prognes"},
"prognosis":{"prognoses","prognosis"},
"prognostic":{"prognostic","prognostics"},
"prognosticate":{"prognosticate","prognosticated","prognosticates","prognosticating"},
"prognostication":{"prognostication","prognostications"},
"prognosticator":{"prognosticator","prognosticators"},
"program":{"program","programed","programing","programmed","programming","programs"},
"programme":{"programme","programmed","programmes","programming"},
"programmer":{"programmer","programmers"},
"programming":{"programming","programmings"},
"progress":{"progress","progressed","progresses","progressing"},
"progression":{"progression","progressions"},
"progressive":{"progressive","progressives"},
"progressiveness":{"progressiveness","progressivenesses"},
"progressivity":{"progressivities","progressivity"},
"prohibit":{"prohibit","prohibited","prohibiting","prohibits"},
"prohibiter":{"prohibiter","prohibiters"},
"prohibition":{"prohibition","prohibitions"},
"prohibitionist":{"prohibitionist","prohibitionists"},
"project":{"project","projected","projecting","projects"},
"projectile":{"projectile","projectiles"},
"projection":{"projection","projections"},
"projectionist":{"projectionist","projectionists"},
"prokaryote":{"prokaryote","prokaryotes"},
"prolapse":{"prolapse","prolapsed","prolapses","prolapsing"},
"prolapsus":{"prolapsus","prolapsuses"},
"prole":{"prole","proles"},
"prolegomenon":{"prolegomena","prolegomenon"},
"prolepsis":{"prolepses","prolepsis"},
"proletarian":{"proletarian","proletarians"},
"proletariat":{"proletariat","proletariats"},
"proletary":{"proletaries","proletartaries","proletary"},
"proliferate":{"proliferate","proliferated","proliferating"},
"prolificacy":{"prolificacies","prolificacy"},
"prolixity":{"prolixities","prolixity"},
"prolixness":{"prolixness","prolixnesses"},
"prolog":{"prolog","prologed","prologing","prologs"},
"prologue":{"prologue","prologued","prologues","prologuing"},
"prologuize":{"prologuize","prologuized","prologuizing"},
"prolong":{"prolong","prolonged","prolonging","prolongs"},
"prolongation":{"prolongation","prolongations"},
"prolusion":{"prolusion","prolusions"},
"prom":{"prom","proms"},
"promenade":{"promenade","promenaded","promenades","promenading"},
"promethium":{"promethium","promethiums"},
"prominence":{"prominence","prominences"},
"promiscuity":{"promiscuities","promiscuity"},
"promiscuousness":{"promiscuousness","promiscuousnesses"},
"promise":{"promise","promised","promises","promising"},
"promiser":{"promiser","promisers"},
"promisor":{"promisor","promisors"},
"promo":{"promo","promos"},
"promontory":{"promontories","promontory"},
"promote":{"promote","promoted","promotes","promoting"},
"promoter":{"promoter","promoters"},
"promotion":{"promotion","promotions"},
"prompt":{"prompt","prompted","prompter","promptest","prompting","prompts"},
"promptbook":{"promptbook","promptbooks"},
"prompter":{"prompter","prompters"},
"prompting":{"prompting","promptings"},
"promptitude":{"promptitude","promptitudes"},
"promptness":{"promptness","promptnesses"},
"promulgate":{"promulgate","promulgated","promulgates","promulgating"},
"promulgation":{"promulgation","promulgations"},
"promycelium":{"promycelilia","promycelium"},
"pronate":{"pronate","pronated","pronating"},
"pronephros":{"pronephra","pronephroi","pronephros"},
"prong":{"prong","pronged","pronging"},
"prongbuck":{"prongbuck","prongbucks"},
"pronghorn":{"pronghorn","pronghorns"},
"pronoun":{"pronoun","pronouns"},
"pronounce":{"pronounce","pronounced","pronounces","pronouncing"},
"pronouncement":{"pronouncement","pronouncements"},
"pronucleus":{"pronuclei","pronucleus"},
"pronunciamento":{"pronunciamento","pronunciamentoes","pronunciamentos"},
"pronunciation":{"pronunciation","pronunciations"},
"proof":{"proof","proofed","proofing","proofs","prooves"},
"proofread":{"proofread","proofreading","proofreads"},
"prop":{"prop","propped","propping","props"},
"propagandist":{"propagandist","propagandists"},
"propagandize":{"propagandize","propagandized","propagandizing"},
"propagate":{"propagate","propagated","propagates","propagating"},
"propagation":{"propagation","propagations"},
"propagator":{"propagator","propagators"},
"propanal":{"propanal","propanals"},
"propanamide":{"propanamide","propanamides"},
"propanol":{"propanol","propanols"},
"propanone":{"propanone","propanones"},
"propel":{"propel","propelled","propelling","propels"},
"propellant":{"propellant","propellants"},
"propellent":{"propellent","propellents"},
"propeller":{"propeller","propellers"},
"propellor":{"propellor","propellors"},
"propenal":{"propenal","propenals"},
"propend":{"propend","propended","propending"},
"propene":{"propene","propenes"},
"propenoate":{"propenoate","propenoates"},
"propenonitrile":{"propenonitrile","propenonitriles"},
"propensity":{"propensities","propensity"},
"properness":{"properness","propernesses"},
"property":{"properties","property"},
"prophecy":{"prophecies","prophecy"},
"prophesy":{"prophesied","prophesies","prophesy","prophesying"},
"prophet":{"prophet","prophets"},
"prophylactic":{"prophylactic","prophylactics"},
"prophylaxis":{"prophylaxes","prophylaxis"},
"propinquity":{"propinquities","propinquity"},
"propionaldehyde":{"propionaldehyde","propionaldehydes"},
"propitiate":{"propitiate","propitiated","propitiates","propitiating"},
"propitiation":{"propitiation","propitiations"},
"propitiousness":{"propitiousness","propitiousnesses"},
"propjet":{"propjet","propjets"},
"propman":{"propman","propmen"},
"propone":{"propone","proponed","proponing"},
"proponent":{"proponent","proponents"},
"proportion":{"proportion","proportioned","proportioning","proportions"},
"proportional":{"proportional","proportionals"},
"proportionality":{"proportionalities","proportionality"},
"proportionate":{"proportionate","proportionated","proportionating"},
"proportionateness":{"proportionateness","proportionatenesses"},
"proposal":{"proposal","proposals"},
"propose":{"propose","proposed","proposes","proposing"},
"proposer":{"proposer","proposers"},
"proposition":{"proposition","propositioned","propositioning","propositions"},
"propositus":{"propositi","propositus"},
"propound":{"propound","propounded","propounding"},
"propoxyphene":{"propoxyphene","propoxyphenes"},
"propranolol":{"propranolol","propranolols"},
"proprietary":{"proprietaries","proprietary"},
"proprietor":{"proprietor","proprietors"},
"proprietorship":{"proprietorship","proprietorships"},
"propriety":{"proprieties","propriety"},
"proprionamide":{"proprionamide","proprionamides"},
"proptosis":{"proptoses","proptosis"},
"propulsion":{"propulsion","propulsions"},
"propyl":{"propyl","propyls"},
"propylaeum":{"propylaea","propylaeum"},
"propylene":{"propylene","propylenes"},
"propylon":{"propyla","propylon","propylons"},
"prorate":{"prorate","prorated","prorating"},
"prorogue":{"prorogue","prorogued","proroguing"},
"prosaicness":{"prosaicness","prosaicnesses"},
"prosauropoda":{"prosauropoda","prosauropodas"},
"proscenium":{"proscenium","prosceniums"},
"proscribe":{"proscribe","proscribed","proscribes","proscribing"},
"proscription":{"proscription","proscriptions"},
"prose":{"prose","prosed","proses","prosing"},
"prosect":{"prosect","prosected","prosecting"},
"prosecute":{"prosecute","prosecuted","prosecutes","prosecuting"},
"prosecution":{"prosecution","prosecutions"},
"prosecutor":{"prosecutor","prosecutors"},
"proselyte":{"proselyte","proselyted","proselyting"},
"proselytism":{"proselytism","proselytisms"},
"proselytize":{"proselytize","proselytized","proselytizing"},
"prosencephalon":{"prosencephala","prosencephalon","prosencephalons"},
"proserpina":{"proserpina","proserpinas"},
"proserpine":{"proserpine","proserpines"},
"prosimii":{"prosimii","prosimiis"},
"prosiness":{"prosiness","prosinesses"},
"prosodion":{"prosodion","prosodions"},
"prosody":{"prosodies","prosody"},
"prosopis":{"prosopis","prosopises"},
"prosopium":{"prosopium","prosopiums"},
"prosopopeia":{"prosopopeia","prosopopeias"},
"prosopopoeia":{"prosopopoeia","prosopopoeias"},
"prospect":{"prospect","prospected","prospecting","prospects"},
"prospector":{"prospector","prospectors"},
"prospectus":{"prospectus","prospectuses"},
"prosper":{"prosper","prospered","prospering","prospers"},
"prosperity":{"prosperities","prosperity"},
"prostate":{"prostate","prostates"},
"prostatectomy":{"prostatectomies","prostatectomy"},
"prosthesis":{"prostheses","prosthesis"},
"prostitute":{"prostitute","prostituted","prostitutes","prostituting"},
"prostitution":{"prostitution","prostitutions"},
"prostomium":{"prostomia","prostomium"},
"prostrate":{"prostrate","prostrated","prostrates","prostrating"},
"prosy":{"prosier","prosiest","prosy"},
"protactinium":{"protactinium","protactiniums"},
"protagonist":{"protagonist","protagonists"},
"protanopia":{"protanopia","protanopias"},
"protasis":{"protases","protasis"},
"proteaceae":{"proteaceae","proteaceaes"},
"proteales":{"proteales","protealeses"},
"protease":{"protease","proteases"},
"protect":{"protect","protected","protecting"},
"protecting":{"protecting","protectings"},
"protection":{"protection","protections"},
"protector":{"protector","protectors"},
"protectorate":{"protectorate","protectorates"},
"protectory":{"protectories","protectory"},
"proteidae":{"proteidae","proteidaes"},
"protein":{"protein","proteins"},
"proteinase":{"proteinase","proteinases"},
"proteinuria":{"proteinuria","proteinurias"},
"proteles":{"proteles","proteleses"},
"proterochampsa":{"proterochampsa","proterochampsas"},
"proterozoic":{"proterozoic","proterozoics"},
"protest":{"protest","protested","protesting","protests"},
"protestant":{"protestant","protestants"},
"protestation":{"protestation","protestations"},
"protester":{"protester","protesters"},
"proteus":{"proteus","proteuses"},
"prothalamion":{"prothalamia","prothalamimia","prothalamion"},
"prothalamium":{"prothalamimia","prothalamium"},
"prothallium":{"prothallia","prothallium"},
"prothallus":{"prothalli","prothallus"},
"prothonotary":{"prothonotaries","prothonotary"},
"prothorax":{"prothorax","prothothoraces","prothothoraxes"},
"protist":{"protist","protists"},
"protista":{"protista","protistas"},
"protistan":{"protistan","protistans"},
"protium":{"protium","protiums"},
"protoactinium":{"protoactinium","protoactiniums"},
"protoanthropology":{"protoanthropologies","protoanthropology"},
"protoarchaeology":{"protoarchaeologies","protoarchaeology"},
"protoarcheology":{"protoarcheologies","protoarcheology"},
"protocol":{"protocol","protocoled","protocoling","protocols"},
"protoctista":{"protoctista","protoctistas"},
"protohistory":{"protohistories","protohistory"},
"protomammal":{"protomammal","protomammals"},
"protonema":{"protonema","protonemata"},
"protonotary":{"prothonotaries","protonotary"},
"protoplasm":{"protoplasm","protoplasms"},
"protoplast":{"protoplast","protoplasts"},
"prototheria":{"prototheria","prototherias"},
"prototype":{"prototype","prototypes"},
"protozoa":{"protozoa","protozoas"},
"protozoan":{"protozoa","protozoan","protozoans"},
"protozoon":{"protozoon","protozoons"},
"protract":{"protract","protracted","protracting","protracts"},
"protraction":{"protraction","protractions"},
"protrude":{"protrude","protruded","protrudes","protruding"},
"protrusion":{"protrusion","protrusions"},
"protuberance":{"protuberance","protuberances"},
"protuberate":{"protuberate","protuberated","protuberating"},
"protura":{"protura","proturas"},
"proturan":{"proturan","proturans"},
"proud":{"proud","prouder","proudest"},
"proust":{"proust","prousts"},
"provability":{"provabilities","provability"},
"prove":{"prove","proved","proven","proves","proving"},
"provenance":{"provenance","provenances"},
"provencal":{"provencal","provencals"},
"provender":{"provender","provenders"},
"proventil":{"proventil","proventils"},
"proventriculus":{"proventriculus","proventricutriculi"},
"provera":{"provera","proveras"},
"proverb":{"proverb","proverbs"},
"provide":{"provide","provided","provides","providing"},
"providence":{"providence","providences"},
"provider":{"provider","providers"},
"providing":{"providing","providings"},
"province":{"province","provinces"},
"provincial":{"provincial","provincials"},
"provincialism":{"provincialism","provincialisms"},
"provincialize":{"provincialize","provincialized","provincializing"},
"proving":{"proving","provings"},
"provision":{"provision","provisioned","provisioning","provisions"},
"provisional":{"provisional","provisionals"},
"provisioner":{"provisioner","provisioners"},
"provisions":{"provisions","provisionses"},
"proviso":{"proviso","provisoes","provisos"},
"provo":{"provo","provos"},
"provocation":{"provocation","provocations"},
"provoke":{"provoke","provoked","provokes","provoking"},
"provoker":{"provoker","provokers"},
"prow":{"prow","prows"},
"prowess":{"prowess","prowesses"},
"prowl":{"prowl","prowled","prowling","prowls"},
"prowler":{"prowler","prowlers"},
"proxima":{"proxima","proximas"},
"proximity":{"proximities","proximity"},
"proxy":{"proxies","proxy"},
"prozac":{"prozac","prozacs"},
"prude":{"prude","prudes"},
"prudence":{"prudence","prudences"},
"prudery":{"pruderies","prudery"},
"prudishness":{"prudishness","prudishnesses"},
"prumnopitys":{"prumnopitys","prumnopityses"},
"prune":{"prune","pruned","prunes","pruning"},
"prunella":{"prunella","prunellas"},
"prunellidae":{"prunellidae","prunellidaes"},
"pruner":{"pruner","pruners"},
"prunus":{"prunus","prunuses"},
"prurience":{"prurience","pruriences"},
"pruriency":{"pruriencies","pruriency"},
"prussia":{"prussia","prussias"},
"pry":{"pried","pries","pry","prying"},
"prying":{"prying","pryings"},
"prytaneum":{"prytanea","prytaneum"},
"ps":{"ps","pses"},
"psalm":{"psalm","psalmed","psalming","psalms"},
"psalmody":{"psalmodies","psalmody"},
"psalter":{"psalter","psalters"},
"psalterium":{"psalterium","psalteriums"},
"psaltery":{"psalteries","psaltery"},
"psaltriparus":{"psaltriparus","psaltriparuses"},
"psammoma":{"psammoma","psammomas"},
"psenes":{"psenes","pseneses"},
"psephurus":{"psephurus","psephuruses"},
"psetta":{"psetta","psettas"},
"psettichthys":{"psettichthys","psettichthyses"},
"pseud":{"pseud","pseuds"},
"pseudacris":{"pseudacris","pseudacrises"},
"pseudaletia":{"pseudaletia","pseudaletias"},
"pseudechis":{"pseudechis","pseudechises"},
"pseudemys":{"pseudemys","pseudemyses"},
"pseudo":{"pseudo","pseudos"},
"pseudobombax":{"pseudobombax","pseudobombaxes"},
"pseudocarp":{"pseudocarp","pseudocarps"},
"pseudococcidae":{"pseudococcidae","pseudococcidaes"},
"pseudococcus":{"pseudococcus","pseudococcuses"},
"pseudocolus":{"pseudocolus","pseudocoluses"},
"pseudolarix":{"pseudolarix","pseudolarixes"},
"pseudomonadales":{"pseudomonadales","pseudomonadaleses"},
"pseudomonas":{"pseudomonas","pseudomonases"},
"pseudomonodaceae":{"pseudomonodaceae","pseudomonodaceaes"},
"pseudomutuality":{"pseudomutualities","pseudomutuality"},
"pseudonym":{"pseudonym","pseudonyms"},
"pseudopleuronectes":{"pseudopleuronectes","pseudopleuronecteses"},
"pseudopod":{"pseudopod","pseudopods"},
"pseudopodium":{"pseudopodia","pseudopodium","pseudopodiums"},
"pseudoryx":{"pseudoryx","pseudoryxes"},
"pseudoscorpion":{"pseudoscorpion","pseudoscorpions"},
"pseudoscorpiones":{"pseudoscorpiones","pseudoscorpioneses"},
"pseudoscorpionida":{"pseudoscorpionida","pseudoscorpionidas"},
"pseudotaxus":{"pseudotaxus","pseudotaxuses"},
"pseudotsuga":{"pseudotsuga","pseudotsugas"},
"pseudowintera":{"pseudowintera","pseudowinteras"},
"pshaw":{"pshaw","pshawed","pshawing","pshaws"},
"psi":{"psi","psis"},
"psidium":{"psidium","psidiums"},
"psilocin":{"psilocin","psilocins"},
"psilocybin":{"psilocybin","psilocybins"},
"psilophytaceae":{"psilophytaceae","psilophytaceaes"},
"psilophytales":{"psilophytales","psilophytaleses"},
"psilopsida":{"psilopsida","psilopsidas"},
"psilotaceae":{"psilotaceae","psilotaceaes"},
"psilotales":{"psilotales","psilotaleses"},
"psilotatae":{"psilotatae","psilotataes"},
"psilotum":{"psilotum","psilotums"},
"psithyrus":{"psithyrus","psithyruses"},
"psittacidae":{"psittacidae","psittacidaes"},
"psittaciformes":{"psittaciformes","psittaciformeses"},
"psittacosaur":{"psittacosaur","psittacosaurs"},
"psittacosaurus":{"psittacosaurus","psittacosauruses"},
"psittacosis":{"psittacoses","psittacosis"},
"psittacula":{"psittacula","psittaculas"},
"psittacus":{"psittacus","psittacuses"},
"psoas":{"psoae","psoai","psoas"},
"psocidae":{"psocidae","psocidaes"},
"psocoptera":{"psocoptera","psocopteras"},
"psophia":{"psophia","psophias"},
"psophiidae":{"psophiidae","psophiidaes"},
"psophocarpus":{"psophocarpus","psophocarpuses"},
"psoralea":{"psoralea","psoraleas"},
"pst":{"pst","psts"},
"psyche":{"psyche","psyches"},
"psychiatrist":{"psychiatrist","psychiatrists"},
"psychiatry":{"psychiatries","psychiatry"},
"psychic":{"psychic","psychics"},
"psycho":{"psycho","psychos"},
"psychoanalysis":{"psychoanalyses","psychoanalysis"},
"psychoanalyst":{"psychoanalyst","psychoanalysts"},
"psychoanalyze":{"psychoanalyze","psychoanalyzed","psychoanalyzes","psychoanalyzing"},
"psychodidae":{"psychodidae","psychodidaes"},
"psychohistory":{"psychohistories","psychohistory"},
"psychokinesis":{"psychokineses","psychokinesis"},
"psychologist":{"psychologist","psychologists"},
"psychologize":{"psychologize","psychologized","psychologizing"},
"psychology":{"psychologies","psychology"},
"psychometrics":{"psychometrics","psychometricses"},
"psychometry":{"psychometries","psychometry"},
"psychoneurosis":{"psychoneuroses","psychoneurosis"},
"psychoneurotic":{"psychoneurotic","psychoneurotics"},
"psychonomics":{"psychonomics","psychonomicses"},
"psychopath":{"psychopath","psychopaths"},
"psychopathology":{"psychopathologies","psychopathology"},
"psychopathy":{"psychopathies","psychopathy"},
"psychophysiology":{"psychophysiologies","psychophysiology"},
"psychopsis":{"psychopses","psychopsis"},
"psychosis":{"psychochoses","psychoses","psychosis"},
"psychotherapeutics":{"psychotherapeutics","psychotherapeuticses"},
"psychotherapist":{"psychotherapist","psychotherapists"},
"psychotherapy":{"psychotherapies","psychotherapy"},
"psychotic":{"psychotic","psychotics"},
"psychotria":{"psychotria","psychotrias"},
"psylla":{"psylla","psyllas"},
"psyllid":{"psyllid","psyllids"},
"psyllidae":{"psyllidae","psyllidaes"},
"psyllium":{"psyllium","psylliums"},
"pt":{"pt","pts"},
"ptarmigan":{"ptarmigan","ptarmigans"},
"pteretis":{"pteretis","pteretises"},
"pteridaceae":{"pteridaceae","pteridaceaes"},
"pteridium":{"pteridium","pteridiums"},
"pteridophyta":{"pteridophyta","pteridophytas"},
"pteridophyte":{"pteridophyte","pteridophytes"},
"pteridosperm":{"pteridosperm","pteridosperms"},
"pteridospermae":{"pteridospermae","pteridospermaes"},
"pteridospermaphyta":{"pteridospermaphyta","pteridospermaphytas"},
"pteridospermopsida":{"pteridospermopsida","pteridospermopsidas"},
"pteriidae":{"pteriidae","pteriidaes"},
"pteris":{"pteris","pterises"},
"pternohyla":{"pternohyla","pternohylas"},
"pterocarpus":{"pterocarpus","pterocarpuses"},
"pterocarya":{"pterocarya","pterocaryas"},
"pterocles":{"pterocles","pterocleses"},
"pteroclididae":{"pteroclididae","pteroclididaes"},
"pterocnemia":{"pterocnemia","pterocnemias"},
"pterodactylidae":{"pterodactylidae","pterodactylidaes"},
"pterodactylus":{"pterodactylus","pterodactyluses"},
"pterois":{"pterois","pteroises"},
"pteropogon":{"pteropogon","pteropogons"},
"pteropsida":{"pteropsida","pteropsidas"},
"pteropus":{"pteropus","pteropuses"},
"pterosaur":{"pterosaur","pterosaurs"},
"pterosauria":{"pterosauria","pterosaurias"},
"pterospermum":{"pterospermum","pterospermums"},
"pterostylis":{"pterostylis","pterostylises"},
"pterygium":{"pterygia","pterygium"},
"pteryla":{"pteryla","pterylae"},
"ptilocercus":{"ptilocercus","ptilocercuses"},
"ptilocrinus":{"ptilocrinus","ptilocrinuses"},
"ptilonorhynchidae":{"ptilonorhynchidae","ptilonorhynchidaes"},
"ptilonorhynchus":{"ptilonorhynchus","ptilonorhynchuses"},
"ptloris":{"ptloris","ptlorises"},
"ptochocracy":{"ptochocracies","ptochocracy"},
"ptolemy":{"ptolemies","ptolemy"},
"ptomain":{"ptomain","ptomains"},
"ptomaine":{"ptomaine","ptomaines"},
"ptosis":{"ptoses","ptosis"},
"ptsd":{"ptsd","ptsds"},
"ptyas":{"ptyas","ptyases"},
"ptychozoon":{"ptychozoon","ptychozoons"},
"pu":{"pu","pus"},
"pub":{"pub","pubs"},
"pub-crawl":{"pub-crawl","pub-crawled","pub-crawling","pub-crawls"},
"puberty":{"puberties","puberty"},
"pubes":{"pubes","pubeses"},
"pubescence":{"pubescence","pubescences"},
"pubis":{"pubes","pubis","pubises"},
"public":{"public","publics"},
"publican":{"publican","publicans"},
"publication":{"publication","publications"},
"publicist":{"publicist","publicists"},
"publicity":{"publicities","publicity"},
"publicize":{"publicize","publicized","publicizes","publicizing"},
"publicizer":{"publicizer","publicizers"},
"publicizing":{"publicizing","publicizings"},
"publish":{"publish","published","publishes","publishing"},
"publisher":{"publisher","publishers"},
"publishing":{"publishing","publishings"},
"puccinia":{"puccinia","puccinias"},
"pucciniaceae":{"pucciniaceae","pucciniaceaes"},
"puccoon":{"puccoon","puccoons"},
"puck":{"puck","pucks"},
"pucker":{"pucker","puckered","puckering","puckers"},
"puckerbush":{"puckerbush","puckerbushes"},
"puckishness":{"puckishness","puckishnesses"},
"pud":{"pud","puds"},
"pudden-head":{"pudden-head","pudden-heads"},
"pudding":{"pudding","puddings"},
"puddingwife":{"puddingwife","puddingwives"},
"puddle":{"puddle","puddled","puddles","puddling"},
"puddler":{"puddler","puddlers"},
"pudendum":{"pudenda","pudendum"},
"pudginess":{"pudginess","pudginesses"},
"pudgy":{"pudgier","pudgiest","pudgy"},
"pueblo":{"pueblo","pueblos"},
"pueraria":{"pueraria","puerarias"},
"puerility":{"puerilities","puerility"},
"puff":{"puff","puffed","puffing","puffs"},
"puffball":{"puffball","puffballs"},
"puffer":{"puffer","puffers"},
"puffery":{"pufferies","puffery"},
"puffiness":{"puffiness","puffinesses"},
"puffingl":{"puffingl","puffingls"},
"puffinus":{"puffinus","puffinuses"},
"puffy":{"puffier","puffiest","puffy"},
"pug":{"pug","pugs"},
"pug-dog":{"pug-dog","pug-dogs"},
"pugilism":{"pugilism","pugilisms"},
"pugilist":{"pugilist","pugilists"},
"puglia":{"puglia","puglias"},
"pugnacity":{"pugnacities","pugnacity"},
"pujunan":{"pujunan","pujunans"},
"puka":{"puka","pukas"},
"puke":{"puke","puked","pukes","puking"},
"puking":{"puking","pukings"},
"puku":{"puku","pukus"},
"pul":{"pul","puli","puls"},
"pulasan":{"pulasan","pulasans"},
"pulassan":{"pulassan","pulassans"},
"pule":{"pule","puled","pules","puling"},
"pulex":{"pulex","pulexes"},
"pulicaria":{"pulicaria","pulicarias"},
"pulicidae":{"pulicidae","pulicidaes"},
"pull":{"pull","pulled","pulling","pulls"},
"pull-in":{"pull-in","pull-ins"},
"pull-off":{"pull-off","pull-offs"},
"pull-up":{"pull-up","pull-ups"},
"pullet":{"pullet","pullets"},
"pulley":{"pulley","pulleyed","pulleying","pulleys"},
"pulley-block":{"pulley-block","pulley-blocks"},
"pulling":{"pulling","pullings"},
"pullman":{"pullman","pullmans","pullmen"},
"pullout":{"pullout","pullouts"},
"pullover":{"pullover","pullovers"},
"pullulate":{"pullulate","pullulated","pullulates","pullulating"},
"pullulation":{"pullulation","pullulations"},
"pulmonata":{"pulmonata","pulmonatas"},
"pulp":{"pulp","pulped","pulping","pulps"},
"pulpit":{"pulpit","pulpits"},
"pulpy":{"pulpier","pulpiest","pulpy"},
"pulsate":{"pulsate","pulsated","pulsates","pulsating"},
"pulsatilla":{"pulsatilla","pulsatillas"},
"pulsation":{"pulsation","pulsations"},
"pulse":{"pulse","pulsed","pulses","pulsing"},
"pulsing":{"pulsing","pulsings"},
"pulverisation":{"pulverisation","pulverisations"},
"pulverization":{"pulverization","pulverizations"},
"pulverize":{"pulverize","pulverized","pulverizes","pulverizing"},
"pulverizer":{"pulverizer","pulverizers"},
"pulvillus":{"pulvilli","pulvillus"},
"pulvinus":{"pulvini","pulvinus"},
"puma":{"puma","pumas"},
"pumice":{"pumice","pumiced","pumices","pumicing"},
"pummel":{"pummel","pummeled","pummeling","pummelled","pummelling","pummels"},
"pummelo":{"pummelo","pummelos"},
"pump":{"pump","pumped","pumping","pumps"},
"pumpernickel":{"pumpernickel","pumpernickels"},
"pumpkin":{"pumpkin","pumpkins"},
"pumpkinseed":{"pumpkinseed","pumpkinseeds"},
"pumps":{"pumps","pumpses"},
"pun":{"pun","punned","punning","puns"},
"punch":{"punch","punched","punches","punching"},
"punchball":{"punchball","punchballs"},
"puncher":{"puncher","punchers"},
"punchinello":{"punchinello","punchinelloes","punchinellos"},
"punchy":{"punchier","punchiest","punchy"},
"punctilio":{"punctilio","punctilios"},
"punctiliousness":{"punctiliousness","punctiliousnesses"},
"punctuality":{"punctualities","punctuality"},
"punctuate":{"punctuate","punctuated","punctuates","punctuating"},
"punctuation":{"punctuation","punctuations"},
"punctuator":{"punctuator","punctuators"},
"puncture":{"puncture","punctured","punctures","puncturing"},
"puncturing":{"puncturing","puncturings"},
"pundit":{"pundit","pundits"},
"pungapung":{"pungapung","pungapungs"},
"pungency":{"pungencies","pungency"},
"punica":{"punica","punicas"},
"punicaceae":{"punicaceae","punicaceaes"},
"puniness":{"puniness","puninesses"},
"punish":{"punish","punished","punishes","punishing"},
"punishment":{"punishment","punishments"},
"punjabi":{"punjabi","punjabis"},
"punk":{"punk","punks"},
"punkey":{"punkey","punkeys"},
"punkie":{"punkie","punkies"},
"punky":{"punkies","punky"},
"punning":{"punning","punnings"},
"punt":{"punt","punted","punting","punts"},
"punter":{"punter","punters"},
"punting":{"punting","puntings"},
"punty":{"punties","punty"},
"puny":{"punier","puniest","puny"},
"pup":{"pup","pupped","pupping","pups"},
"pupa":{"pupa","pupae","pupas"},
"puparium":{"pupariia","puparium"},
"pupate":{"pupate","pupated","pupating"},
"pupil":{"pupil","pupils"},
"puppet":{"puppet","puppets"},
"puppeteer":{"puppeteer","puppeteered","puppeteering"},
"puppetry":{"puppetries","puppetry"},
"puppy":{"puppies","puppy"},
"purau":{"purau","puraus"},
"purchase":{"purchase","purchased","purchases","purchasing"},
"purchaser":{"purchaser","purchasers"},
"purchasing":{"purchasing","purchasings"},
"purdah":{"purdah","purdahs"},
"pure":{"pure","purer","purest"},
"pureblood":{"pureblood","purebloods"},
"purebred":{"purebred","purebreds"},
"puree":{"puree","pureed","pureeing","purees"},
"pureness":{"pureness","purenesses"},
"purgation":{"purgation","purgations"},
"purgative":{"purgative","purgatives"},
"purgatory":{"purgatories","purgatory"},
"purge":{"purge","purged","purges","purging"},
"purger":{"purger","purgers"},
"purging":{"purging","purgings"},
"purify":{"purified","purifies","purify","purifying"},
"purinethol":{"purinethol","purinethols"},
"puritan":{"puritan","puritans"},
"purity":{"purities","purity"},
"purl":{"purl","purled","purling","purls"},
"purloin":{"purloin","purloined","purloining","purloins"},
"purloo":{"purloo","purloos"},
"purple":{"purple","purpled","purpler","purples","purplest","purpling"},
"purpleness":{"purpleness","purplenesses"},
"purport":{"purport","purported","purporting","purports"},
"purpose":{"purpose","purposed","purposes","purposing"},
"purposefulness":{"purposefulness","purposefulnesses"},
"purposelessness":{"purposelessness","purposelessnesses"},
"purpura":{"purpura","purpuras"},
"purr":{"purr","purred","purring","purrs"},
"purse":{"purse","pursed","purses","pursing"},
"purser":{"purser","pursers"},
"pursuance":{"pursuance","pursuances"},
"pursue":{"pursue","pursued","pursues","pursuing"},
"pursued":{"pursued","pursueds"},
"pursuer":{"pursuer","pursuers"},
"pursuit":{"pursuit","pursuits"},
"pursy":{"pursier","pursiest","pursy"},
"purulence":{"purulence","purulences"},
"purulency":{"purulencies","purulency"},
"purus":{"purus","puruses"},
"purvey":{"purvey","purveyed","purveying","purveys"},
"purveyor":{"purveyor","purveyors"},
"purview":{"purview","purviews"},
"pus":{"pus","puses"},
"puseyism":{"puseyism","puseyisms"},
"push":{"push","pushed","pushes","pushing"},
"push-up":{"push-up","push-ups"},
"pushcart":{"pushcart","pushcarts"},
"pushchair":{"pushchair","pushchairs"},
"pusher":{"pusher","pushers"},
"pushiness":{"pushiness","pushinesses"},
"pushing":{"pushing","pushings"},
"pushover":{"pushover","pushovers"},
"pushpin":{"pushpin","pushpins"},
"pushup":{"pushup","pushups"},
"pushy":{"pushier","pushiest","pushy"},
"pusillanimity":{"pusillanimities","pusillanimity"},
"pusillanimousness":{"pusillanimousness","pusillanimousnesses"},
"pusly":{"puslies","pusly"},
"puss":{"puss","pusses"},
"pussley":{"pussley","pussleys"},
"pussy":{"pussies","pussy"},
"pussy-paw":{"pussy-paw","pussy-paws"},
"pussy-paws":{"pussy-paws","pussy-pawses"},
"pussycat":{"pussycat","pussycats"},
"pussyfoot":{"pussyfoot","pussyfooted","pussyfooting","pussyfoots"},
"pussytoes":{"pussytoes","pussytoeses"},
"put":{"put","puts","putting"},
"put-down":{"put-down","put-downs"},
"put-on":{"put-on","put-ons"},
"put-put":{"put-put","put-puts","put-putted","put-putting"},
"putamen":{"putamen","putatamina"},
"putrefaction":{"putrefaction","putrefactions"},
"putrefy":{"putrefied","putrefies","putrefy","putrefying"},
"putrescence":{"putrescence","putrescences"},
"putridness":{"putridness","putridnesses"},
"putsch":{"putsch","putsches"},
"putt":{"putt","putted","putting","putts"},
"puttee":{"puttee","puttees","putties"},
"puttees":{"puttees","putteeses"},
"putter":{"putter","puttered","puttering","putters"},
"putterer":{"putterer","putterers"},
"putting":{"putting","puttings"},
"putto":{"putti","putto"},
"putty":{"puttied","putty","puttying"},
"puttyroot":{"puttyroot","puttyroots"},
"puzzle":{"puzzle","puzzled","puzzles","puzzling"},
"puzzlement":{"puzzlement","puzzlements"},
"puzzler":{"puzzler","puzzlers"},
"pva":{"pva","pvas"},
"pvc":{"pvc","pvcs"},
"pycnanthemum":{"pycnanthemum","pycnanthemums"},
"pycnidium":{"pycnidiia","pycnidium"},
"pycnogonid":{"pycnogonid","pycnogonids"},
"pycnogonida":{"pycnogonida","pycnogonidas"},
"pycnosis":{"pycnoses","pycnosis"},
"pydna":{"pydna","pydnas"},
"pye-dog":{"pye-dog","pye-dogs"},
"pygidium":{"pygidiia","pygidium"},
"pygmy":{"pygmies","pygmy"},
"pygopodidae":{"pygopodidae","pygopodidaes"},
"pygopus":{"pygopus","pygopuses"},
"pygoscelis":{"pygoscelis","pygoscelises"},
"pyjama":{"pyjama","pyjamas"},
"pyjamas":{"pyjamas","pyjamases"},
"pyknosis":{"pyknoses","pyknosis"},
"pylodictus":{"pylodictus","pylodictuses"},
"pylorectomy":{"pylorectomies","pylorectomy"},
"pylorus":{"pylori","pylorus"},
"pyongyang":{"pyongyang","pyongyangs"},
"pyorrhea":{"pyorrhea","pyorrheas"},
"pyorrhoea":{"pyorrhoea","pyorrhoeas"},
"pyracanth":{"pyracanth","pyracanths"},
"pyracantha":{"pyracantha","pyracanthas"},
"pyralid":{"pyralid","pyralids"},
"pyralidae":{"pyralidae","pyralidaes"},
"pyralididae":{"pyralididae","pyralididaes"},
"pyralis":{"pyralis","pyralises"},
"pyramid":{"pyramid","pyramided","pyramiding","pyramids"},
"pyrausta":{"pyrausta","pyraustas"},
"pyre":{"pyre","pyres"},
"pyrenomycetes":{"pyrenomycetes","pyrenomyceteses"},
"pyrethrum":{"pyrethrum","pyrethrums"},
"pyrexia":{"pyrexia","pyrexias"},
"pyridoxal":{"pyridoxal","pyridoxals"},
"pyridoxamine":{"pyridoxamine","pyridoxamines"},
"pyridoxine":{"pyridoxine","pyridoxines"},
"pyrite":{"pyrite","pyrites"},
"pyrocephalus":{"pyrocephalus","pyrocephaluses"},
"pyrography":{"pyrographies","pyrography"},
"pyrola":{"pyrola","pyrolas"},
"pyrolaceae":{"pyrolaceae","pyrolaceaes"},
"pyrolatry":{"pyrolatries","pyrolatry"},
"pyrophorus":{"pyrophorus","pyrophoruses"},
"pyroscope":{"pyroscope","pyroscopes"},
"pyrosis":{"pyroses","pyrosis"},
"pyrotechnics":{"pyrotechnics","pyrotechnicses"},
"pyrotechny":{"pyrotechnies","pyrotechny"},
"pyrrhic":{"pyrrhic","pyrrhics"},
"pyrrhocoridae":{"pyrrhocoridae","pyrrhocoridaes"},
"pyrrhula":{"pyrrhula","pyrrhulas"},
"pyrrhuloxia":{"pyrrhuloxia","pyrrhuloxias"},
"pyrrosia":{"pyrrosia","pyrrosias"},
"pyrularia":{"pyrularia","pyrularias"},
"pyrus":{"pyrus","pyruses"},
"pythiaceae":{"pythiaceae","pythiaceaes"},
"pythonidae":{"pythonidae","pythonidaes"},
"pythoninae":{"pythoninae","pythoninaes"},
"pyx":{"pyx","pyxes"},
"pyxidanthera":{"pyxidanthera","pyxidantheras"},
"pyxidium":{"pyxidiia","pyxidium"},
"pyxie":{"pyxie","pyxies"},
"pyxis":{"pyxides","pyxis"},
"qaddish":{"qaddish","qaddishim"},
"qadi":{"qadi","qadis"},
"qatar":{"qatar","qatars"},
"qatari":{"qatari","qataris"},
"qiana":{"qiana","qianas"},
"qiang":{"qiang","qiangs"},
"qiangic":{"qiangic","qiangics"},
"qindarka":{"qindarka","qindarkas"},
"qintar":{"qintar","qintars"},
"quaalude":{"quaalude","quaaludes"},
"quack":{"quack","quacked","quacking","quacks"},
"quackery":{"quackeries","quackery"},
"quackgrass":{"quackgrass","quackgrasses"},
"quad":{"quad","quads"},
"quadragesima":{"quadragesima","quadragesimas"},
"quadrangle":{"quadrangle","quadrangles"},
"quadrant":{"quadrant","quadrants"},
"quadraphony":{"quadraphonies","quadraphony"},
"quadrate":{"quadrate","quadrated","quadrating"},
"quadratic":{"quadratic","quadratics"},
"quadrennium":{"quadrennia","quadrennium","quadrenniums"},
"quadriceps":{"quadriceps","quadricepses"},
"quadriga":{"quadriga","quadrigae","quadrigas"},
"quadrilateral":{"quadrilateral","quadrilaterals"},
"quadrillion":{"quadrillion","quadrillions"},
"quadrillionth":{"quadrillionth","quadrillionths"},
"quadrisect":{"quadrisect","quadrisected","quadrisecting"},
"quadrivium":{"quadrivia","quadrivium"},
"quadruple":{"quadruple","quadrupled","quadrupling"},
"quadruplet":{"quadruplet","quadruplets"},
"quadruplicate":{"quadruplicate","quadruplicated","quadruplicates","quadruplicating"},
"quaff":{"quaff","quaffed","quaffing","quaffs"},
"quagga":{"quagga","quaggas"},
"quaggy":{"quaggier","quaggiest","quaggy"},
"quagmire":{"quagmire","quagmires"},
"quahaug":{"quahaug","quahaugs"},
"quahog":{"quahog","quahogs"},
"quail":{"quail","quailed","quailing","quails"},
"quaint":{"quaint","quainter","quaintest"},
"quake":{"quake","quaked","quakes","quaking"},
"quaker":{"quaker","quakers"},
"quakers":{"quakers","quakerses"},
"quaky":{"quakier","quakiest","quaky"},
"quale":{"quale","qualia"},
"qualification":{"qualification","qualifications"},
"qualifier":{"qualifier","qualifiers"},
"qualify":{"qualified","qualifies","qualify","qualifying"},
"qualifying":{"qualifying","qualifyings"},
"quality":{"qualities","quality"},
"qualm":{"qualm","qualms"},
"quamash":{"quamash","quamashes"},
"quamassia":{"quamassia","quamassias"},
"quandang":{"quandang","quandangs"},
"quandary":{"quandaries","quandary"},
"quandong":{"quandong","quandongs"},
"quango":{"quango","quangos"},
"quantifiability":{"quantifiabilities","quantifiability"},
"quantify":{"quantified","quantifies","quantify","quantifying"},
"quantisation":{"quantisation","quantisations"},
"quantity":{"quantities","quantity"},
"quantization":{"quantization","quantizations"},
"quantize":{"quantize","quantized","quantizing"},
"quantong":{"quantong","quantongs"},
"quantum":{"quanta","quantum","quantums"},
"quarantine":{"quarantine","quarantined","quarantining"},
"quarrel":{"quarrel","quarreled","quarreling","quarrelled","quarrelling","quarrels"},
"quarreler":{"quarreler","quarrelers"},
"quarrelsomeness":{"quarrelsomeness","quarrelsomenesses"},
"quarrier":{"quarrier","quarriers"},
"quarry":{"quarried","quarries","quarry","quarrying"},
"quarryman":{"quarryman","quarrymen"},
"quart":{"quart","quarts"},
"quarter":{"quarter","quartered","quartering","quarters"},
"quarter-circle":{"quarter-circle","quarter-circles"},
"quarter-hour":{"quarter-hour","quarter-hours"},
"quarterback":{"quarterback","quarterbacked","quarterbacking","quarterbacks"},
"quarterly":{"quarterlies","quarterly"},
"quartermaster":{"quartermaster","quartermasters"},
"quartern":{"quartern","quarterns"},
"quarters":{"quarters","quarterses"},
"quartersaw":{"quartersaw","quartersawed","quartersawing","quartersawn","quartersaws"},
"quarterstaff":{"quarterstaff","quarterstaves"},
"quartervine":{"quartervine","quartervines"},
"quartet":{"quartet","quartets"},
"quartette":{"quartette","quartettes"},
"quartic":{"quartic","quartics"},
"quarto":{"quarto","quartos"},
"quartz":{"quartz","quartzs"},
"quasar":{"quasar","quasars"},
"quash":{"quash","quashed","quashes","quashing"},
"quassia":{"quassia","quassias"},
"quatercentenary":{"quatercentenaries","quatercentenary"},
"quatercentennial":{"quatercentennial","quatercentennials"},
"quatern":{"quatern","quaterns"},
"quaternary":{"quaternaries","quaternary"},
"quaternion":{"quaternion","quaternions"},
"quaternity":{"quaternities","quaternity"},
"quattuordecillion":{"quattuordecillion","quattuordecillions"},
"quaver":{"quaver","quavered","quavering","quavers"},
"quay":{"quay","quays"},
"queasiness":{"queasiness","queasinesses"},
"queasy":{"queasier","queasiest","queasy"},
"quebec":{"quebec","quebecs"},
"quebracho":{"quebracho","quebrachos"},
"quechua":{"quechua","quechuas"},
"queen":{"queen","queened","queening","queens"},
"queenfish":{"queenfish","queenfishes"},
"queenly":{"queenlier","queenliest","queenly"},
"queer":{"queer","queered","queerer","queerest","queering","queers"},
"queerness":{"queerness","queernesses"},
"quell":{"quell","quelled","quelling","quells"},
"quelling":{"quelling","quellings"},
"quench":{"quench","quenched","quenches","quenching"},
"quenching":{"quenching","quenchings"},
"quercitron":{"quercitron","quercitrons"},
"quercus":{"quercus","quercuses"},
"query":{"queried","queries","query","querying"},
"quest":{"quest","quested","questing","quests"},
"question":{"question","questioned","questioning","questions"},
"questionary":{"questionaries","questionary"},
"questioner":{"questioner","questioners"},
"questioning":{"questioning","questionings"},
"questionnaire":{"questionnaire","questionnaires"},
"quetzal":{"quetzal","quetzales","quetzals"},
"queue":{"queue","queued","queues","queuing"},
"quezal":{"quezal","quezales"},
"quiaquia":{"quiaquia","quiaquias"},
"quibble":{"quibble","quibbled","quibbles","quibbling"},
"quibbler":{"quibbler","quibblers"},
"quichua":{"quichua","quichuas"},
"quick":{"quick","quicker","quickest"},
"quick-freeze":{"quick-freeze","quick-freezes","quick-freezing","quick-froze","quick-frozen"},
"quick-wittedness":{"quick-wittedness","quick-wittednesses"},
"quicken":{"quicken","quickened","quickening","quickens"},
"quickening":{"quickening","quickenings"},
"quickie":{"quickie","quickies"},
"quicklime":{"quicklime","quicklimes"},
"quickness":{"quickness","quicknesses"},
"quicksilver":{"quicksilver","quicksilvered","quicksilvering","quicksilvers"},
"quickstep":{"quickstep","quickstepped","quickstepping","quicksteps"},
"quicky":{"quickies","quicky"},
"quid":{"quid","quids"},
"quiddity":{"quiddities","quiddity"},
"quiescence":{"quiescence","quiescences"},
"quiescency":{"quiescencies","quiescency"},
"quiet":{"quiet","quieted","quieter","quietest","quieting","quiets"},
"quietness":{"quietness","quietnesses"},
"quietude":{"quietude","quietudes"},
"quietus":{"quietus","quietuses"},
"quill":{"quill","quilled","quilling","quills"},
"quilt":{"quilt","quilted","quilting","quilts"},
"quin":{"quin","quins"},
"quinacrine":{"quinacrine","quinacrines"},
"quinary":{"quinaries","quinary"},
"quince":{"quince","quinces"},
"quincentenary":{"quincentenaries","quincentenary"},
"quincentennial":{"quincentennial","quincentennials"},
"quine":{"quine","quines"},
"quinella":{"quinella","quinellas"},
"quinquagesima":{"quinquagesima","quinquagesimas"},
"quinquecentenary":{"quinquecentenaries","quinquecentenary"},
"quinquennium":{"quinquennia","quinquennium"},
"quint":{"quint","quints"},
"quintal":{"quintal","quintals"},
"quintessence":{"quintessence","quintessences"},
"quintet":{"quintet","quintets"},
"quintette":{"quintette","quintettes"},
"quintillion":{"quintillion","quintillions"},
"quintillionth":{"quintillionth","quintillionths"},
"quintuple":{"quintuple","quintupled","quintupling"},
"quintuplet":{"quintuplet","quintuplets"},
"quintuplicate":{"quintuplicate","quintuplicated","quintuplicating"},
"quip":{"quip","quipped","quipping","quips"},
"quipu":{"quipu","quipus"},
"quira":{"quira","quiras"},
"quirk":{"quirk","quirks"},
"quirkiness":{"quirkiness","quirkinesses"},
"quirt":{"quirt","quirted","quirting"},
"quiscalus":{"quiscalus","quiscaluses"},
"quisling":{"quisling","quislings"},
"quislingism":{"quislingism","quislingisms"},
"quist":{"quist","quists"},
"quit":{"quit","quits","quitted","quitting"},
"quitclaim":{"quitclaim","quitclaimed","quitclaiming","quitclaims"},
"quito":{"quito","quitos"},
"quittance":{"quittance","quittances"},
"quiver":{"quiver","quivered","quivering","quivers"},
"quivering":{"quivering","quiverings"},
"quixotism":{"quixotism","quixotisms"},
"quiz":{"quiz","quizzed","quizzes","quizzing"},
"quizmaster":{"quizmaster","quizmasters"},
"quoin":{"quoin","quoined","quoining","quoins"},
"quoits":{"quoits","quoitses"},
"quota":{"quota","quotas"},
"quotation":{"quotation","quotations"},
"quote":{"quote","quoted","quotes","quoting"},
"quran":{"quran","qurans"},
"r":{"r","rs"},
"ra":{"ra","ras"},
"rabat":{"rabat","rabats"},
"rabato":{"rabato","rabatos"},
"rabbet":{"rabbet","rabbeted","rabbeting","rabbets"},
"rabbi":{"rabbi","rabbies","rabbis"},
"rabbit":{"rabbit","rabbited","rabbiting","rabbits","rabbitted","rabbitting"},
"rabbiteye":{"rabbiteye","rabbiteyes"},
"rabbitfish":{"rabbitfish","rabbitfishes"},
"rabbitry":{"rabbitries","rabbitry"},
"rabbitweed":{"rabbitweed","rabbitweeds"},
"rabbitwood":{"rabbitwood","rabbitwoods"},
"rabble":{"rabble","rabbled","rabbles","rabbling"},
"rabble-rouser":{"rabble-rouser","rabble-rousers"},
"rabelais":{"rabelais","rabelaises"},
"rabies":{"rabies","rabieses"},
"raccoon":{"raccoon","raccoons"},
"race":{"race","raced","races","racing"},
"racecourse":{"racecourse","racecourses"},
"racehorse":{"racehorse","racehorses"},
"racer":{"racer","racers"},
"racerunner":{"racerunner","racerunners"},
"racetrack":{"racetrack","racetracks"},
"raceway":{"raceway","raceways"},
"rachet":{"rachet","rachets"},
"rachis":{"rachis","rachises","rhachises"},
"rachitis":{"rachitis","rachitises"},
"rachycentridae":{"rachycentridae","rachycentridaes"},
"rachycentron":{"rachycentron","rachycentrons"},
"racialism":{"racialism","racialisms"},
"racialist":{"racialist","racialists"},
"racine":{"racine","racines"},
"raciness":{"raciness","racinesses"},
"racism":{"racism","racisms"},
"racist":{"racist","racists"},
"rack":{"rack","racked","racking","racks"},
"rack-rent":{"rack-rent","rack-rented","rack-renting"},
"racket":{"racket","racketed","racketing","rackets"},
"racketeer":{"racketeer","racketeered","racketeering","racketeers"},
"racketiness":{"racketiness","racketinesses"},
"racon":{"racon","racons"},
"raconteur":{"raconteur","raconteurs"},
"racoon":{"racoon","racoons"},
"racquet":{"racquet","racquets"},
"racy":{"racier","raciest","racy"},
"rad":{"rad","rads"},
"radar":{"radar","radars"},
"radial":{"radial","radials"},
"radian":{"radian","radians"},
"radiance":{"radiance","radiances"},
"radiancy":{"radiancies","radiancy"},
"radiate":{"radiate","radiated","radiates","radiating"},
"radiation":{"radiation","radiations"},
"radiator":{"radiator","radiators"},
"radical":{"radical","radicals"},
"radiigera":{"radiigera","radiigeras"},
"radio":{"radio","radioed","radioing","radios"},
"radio-gramophone":{"radio-gramophone","radio-gramophones"},
"radio-phonograph":{"radio-phonograph","radio-phonographs"},
"radioactivity":{"radioactivities","radioactivity"},
"radiobroadcast":{"radiobroadcast","radiobroadcasted","radiobroadcasting"},
"radiocarbon":{"radiocarbon","radiocarbons"},
"radiocast":{"radiocast","radiocasted","radiocasting"},
"radiocommunication":{"radiocommunication","radiocommunications"},
"radiogram":{"radiogram","radiograms"},
"radiograph":{"radiograph","radiographed","radiographing","radiographs"},
"radiography":{"radiographies","radiography"},
"radiolaria":{"radiolaria","radiolarias"},
"radiolocation":{"radiolocation","radiolocations"},
"radiologist":{"radiologist","radiologists"},
"radiology":{"radiologies","radiology"},
"radiophone":{"radiophone","radiophoned","radiophones","radiophoning"},
"radioscopy":{"radioscopies","radioscopy"},
"radiosensitivity":{"radiosensitivities","radiosensitivity"},
"radiotelegraph":{"radiotelegraph","radiotelegraphs"},
"radiotelegraphy":{"radiotelegraphies","radiotelegraphy"},
"radiotelephone":{"radiotelephone","radiotelephoned","radiotelephones","radiotelephoning"},
"radiotelephony":{"radiotelephonies","radiotelephony"},
"radiotherapist":{"radiotherapist","radiotherapists"},
"radiotherapy":{"radiotherapies","radiotherapy"},
"radish":{"radish","radishes"},
"radium":{"radium","radiums"},
"radius":{"radii","radius","radiuses"},
"radix":{"radices","radix","radixes"},
"radome":{"radome","radomes"},
"radon":{"radon","radons"},
"radula":{"radula","radulae"},
"radyera":{"radyera","radyeras"},
"raetam":{"raetam","raetams"},
"raf":{"raf","rafs"},
"raffia":{"raffia","raffias"},
"raffle":{"raffle","raffled","raffles","raffling"},
"raft":{"raft","rafted","rafting","rafts"},
"rafter":{"rafter","raftered","raftering","rafters"},
"raftman":{"raftman","raftmen"},
"rafts":{"rafts","raftses"},
"raftsman":{"raftsman","raftsmen"},
"rag":{"rag","ragged","ragging","rags"},
"ragamuffin":{"ragamuffin","ragamuffins"},
"ragbag":{"ragbag","ragbags"},
"rage":{"rage","raged","rages","raging"},
"ragee":{"ragee","ragees"},
"ragi":{"ragi","ragis"},
"ragman":{"ragman","ragmen"},
"ragnarok":{"ragnarok","ragnaroks"},
"ragout":{"ragout","ragouted","ragouting","ragouts"},
"ragtag":{"ragtag","ragtags"},
"ragtime":{"ragtime","ragtimes"},
"ragweed":{"ragweed","ragweeds"},
"ragwort":{"ragwort","ragworts"},
"raid":{"raid","raided","raiding","raids"},
"raider":{"raider","raiders"},
"rail":{"rail","railed","railing","rails"},
"railcar":{"railcar","railcars"},
"railing":{"railing","railings"},
"raillery":{"railleries","raillery"},
"railroad":{"railroad","railroaded","railroading","railroads"},
"railroader":{"railroader","railroaders"},
"rails":{"rails","railses"},
"railway":{"railway","railways"},
"railwayman":{"railwayman","railwaymen"},
"raiment":{"raiment","raiments"},
"rain":{"rain","rained","raining","rains"},
"rain-giver":{"rain-giver","rain-givers"},
"rainbow":{"rainbow","rainbows"},
"raincoat":{"raincoat","raincoats"},
"raindrop":{"raindrop","raindrops"},
"rainfall":{"rainfall","rainfalls"},
"rainproof":{"rainproof","rainproofed","rainproofing"},
"rainwater":{"rainwater","rainwaters"},
"rainy":{"rainier","rainiest","rainy"},
"raise":{"raise","raised","raises","raising"},
"raiser":{"raiser","raisers"},
"raisin":{"raisin","raisins"},
"raising":{"raising","raisings"},
"raja":{"raja","rajas"},
"rajah":{"rajah","rajahs"},
"rajidae":{"rajidae","rajidaes"},
"rajiformes":{"rajiformes","rajiformeses"},
"rake":{"rake","raked","rakes","raking"},
"rakishness":{"rakishness","rakishnesses"},
"rale":{"rale","rales"},
"raleigh":{"raleigh","raleighs"},
"rallidae":{"rallidae","rallidaes"},
"rally":{"rallied","rallies","rally","rallying"},
"rallying":{"rallying","rallyings"},
"ram":{"ram","rammed","ramming","rams"},
"ramble":{"ramble","rambled","rambles","rambling"},
"rambotan":{"rambotan","rambotans"},
"rambutan":{"rambutan","rambutans"},
"ramee":{"ramee","ramees"},
"ramekin":{"ramekin","ramekins"},
"ramentum":{"ramenta","ramentum"},
"ramequin":{"ramequin","ramequins"},
"ramie":{"ramie","ramies"},
"ramification":{"ramification","ramifications"},
"ramify":{"ramified","ramifies","ramify","ramifying"},
"ramjet":{"ramjet","ramjets"},
"ramona":{"ramona","ramonas"},
"ramontchi":{"ramontchi","ramontchis"},
"ramp":{"ramp","ramped","ramping","ramps"},
"rampage":{"rampage","rampaged","rampages","rampaging"},
"rampart":{"rampart","ramparted","ramparting","ramparts"},
"ramphastidae":{"ramphastidae","ramphastidaes"},
"ramphomicron":{"ramphomicron","ramphomicrons"},
"rampion":{"rampion","rampions"},
"ramrod":{"ramrod","ramrodded","ramrodding","ramrods"},
"ramsons":{"ramsons","ramsonses"},
"ramus":{"rami","ramus"},
"rana":{"rana","ranas"},
"ranales":{"ranales","ranaleses"},
"ranatra":{"ranatra","ranatras"},
"ranch":{"ranch","ranched","ranches","ranching"},
"ranchero":{"ranchero","rancheros"},
"ranchman":{"ranchman","ranchmen"},
"rancho":{"rancho","ranchos"},
"rancor":{"rancor","rancors"},
"rancour":{"rancour","rancours"},
"randomisation":{"randomisation","randomisations"},
"randomization":{"randomization","randomizations"},
"randomize":{"randomize","randomized","randomizing"},
"randomness":{"randomness","randomnesses"},
"randy":{"randier","randies","randiest","randy"},
"ranee":{"ranee","ranees"},
"range":{"range","ranged","ranges","ranging"},
"ranger":{"ranger","rangers"},
"rangifer":{"rangifer","rangifers"},
"rangoon":{"rangoon","rangoons"},
"rangpur":{"rangpur","rangpurs"},
"rangy":{"rangier","rangiest","rangy"},
"rani":{"rani","ranis"},
"ranid":{"ranid","ranids"},
"ranidae":{"ranidae","ranidaes"},
"ranitidine":{"ranitidine","ranitidines"},
"rank":{"rank","ranked","ranker","rankest","ranking","ranks"},
"rankine":{"rankine","rankines"},
"rankle":{"rankle","rankled","rankles","rankling"},
"rankness":{"rankness","ranknesses"},
"ransack":{"ransack","ransacked","ransacking","ransacks"},
"ransacking":{"ransacking","ransackings"},
"ransom":{"ransom","ransomed","ransoming","ransoms"},
"rant":{"rant","ranted","ranting","rants"},
"ranter":{"ranter","ranters"},
"ranting":{"ranting","rantings"},
"ranunculaceae":{"ranunculaceae","ranunculaceaes"},
"ranunculales":{"ranunculales","ranunculaleses"},
"ranunculus":{"ranunculus","ranunculuses"},
"raoulia":{"raoulia","raoulias"},
"rap":{"rap","rapped","rapping","raps","rapt"},
"rapaciousness":{"rapaciousness","rapaciousnesses"},
"rapacity":{"rapacities","rapacity"},
"rapateaceae":{"rapateaceae","rapateaceaes"},
"rape":{"rape","raped","rapes","raping"},
"raper":{"raper","rapers"},
"raphanus":{"raphanus","raphanuses"},
"raphe":{"raphae","raphe"},
"raphia":{"raphia","raphias"},
"raphicerus":{"raphicerus","raphiceruses"},
"raphidae":{"raphidae","raphidaes"},
"raphide":{"raphide","raphides"},
"raphidiidae":{"raphidiidae","raphidiidaes"},
"raphis":{"raphides","raphis"},
"raphus":{"raphus","raphuses"},
"rapid":{"rapid","rapider","rapidest"},
"rapidity":{"rapidities","rapidity"},
"rapine":{"rapine","rapines"},
"rapist":{"rapist","rapists"},
"rappel":{"rappel","rappelled","rappelling","rappels"},
"rapport":{"rapport","rapports"},
"rapprochement":{"rapprochement","rapprochements"},
"rapscallion":{"rapscallion","rapscallions"},
"raptor":{"raptor","raptors"},
"raptores":{"raptores","raptoreses"},
"rapture":{"rapture","raptured","raptures","rapturing"},
"rare":{"rare","rarer","rarest"},
"rarebit":{"rarebit","rarebits"},
"raree-show":{"raree-show","raree-shows"},
"rarefy":{"rarefied","rarefies","rarefy","rarefying","rarfied","rarfies","rarfying"},
"rareness":{"rareness","rarenesses"},
"rarity":{"rarities","rarity"},
"rascal":{"rascal","rascals"},
"rascality":{"rascalities","rascality"},
"rase":{"rase","rased","rases","rasing"},
"rash":{"rash","rasher","rashes","rashest"},
"rasher":{"rasher","rashers"},
"rashness":{"rashness","rashnesses"},
"raskolnikov":{"raskolnikov","raskolnikovs"},
"rasp":{"rasp","rasped","rasping","rasps"},
"raspatory":{"raspaies","raspatory"},
"raspberry":{"raspberries","raspberry"},
"rasping":{"rasping","raspings"},
"raspy":{"raspier","raspiest","raspy"},
"rassling":{"rassling","rasslings"},
"rat":{"rat","rats","ratted","ratting"},
"rat-a-tat-tat":{"rat-a-tat-tat","rat-a-tat-tats"},
"rat-catcher":{"rat-catcher","rat-catchers"},
"rat-tat":{"rat-tat","rat-tats"},
"ratability":{"ratabilities","ratability"},
"ratables":{"ratables","ratableses"},
"ratafee":{"ratafee","ratafees"},
"ratafia":{"ratafia","ratafias"},
"ratan":{"ratan","ratans"},
"ratch":{"ratch","ratches"},
"ratchet":{"ratchet","ratchets"},
"rate":{"rate","rated","rates","rating"},
"rateability":{"rateabilities","rateability"},
"rateables":{"rateables","rateableses"},
"ratel":{"ratel","ratels"},
"ratepayer":{"ratepayer","ratepayers"},
"ratfish":{"ratfish","ratfishes"},
"ratibida":{"ratibida","ratibidas"},
"ratification":{"ratification","ratifications"},
"ratifier":{"ratifier","ratifiers"},
"ratify":{"ratified","ratifies","ratify","ratifying"},
"rating":{"rating","ratings"},
"ratio":{"ratio","ratios"},
"ratiocinate":{"ratiocinate","ratiocinated","ratiocinating"},
"ratiocinator":{"ratiocinator","ratiocinators"},
"ration":{"ration","rationed","rationing","rations"},
"rational":{"rational","rationals"},
"rationale":{"rationale","rationales"},
"rationalisation":{"rationalisation","rationalisations"},
"rationalism":{"rationalism","rationalisms"},
"rationalist":{"rationalist","rationalists"},
"rationality":{"rationalities","rationality"},
"rationalization":{"rationalization","rationalizations"},
"rationalize":{"rationalize","rationalized","rationalizes","rationalizing"},
"rationalness":{"rationalness","rationalnesses"},
"ratitae":{"ratitae","ratitaes"},
"ratite":{"ratite","ratites"},
"ratlin":{"ratlin","ratlins"},
"ratline":{"ratline","ratlines"},
"rattail":{"rattail","rattails"},
"rattan":{"rattan","rattans"},
"ratter":{"ratter","ratters"},
"ratting":{"ratting","rattings"},
"rattle":{"rattle","rattled","rattles","rattling"},
"rattlebox":{"rattlebox","rattleboxes"},
"rattler":{"rattler","rattlers"},
"rattlesnake":{"rattlesnake","rattlesnakes"},
"rattletop":{"rattletop","rattletops"},
"rattling":{"rattling","rattlings"},
"rattly":{"rattlier","rattliest","rattly"},
"rattus":{"rattus","rattuses"},
"ratty":{"rattier","rattiest","ratty"},
"rau-sed":{"rau-sed","rau-seds"},
"raunchy":{"raunchier","raunchiest","raunchy"},
"rauvolfia":{"rauvolfia","rauvolfias"},
"rauwolfia":{"rauwolfia","rauwolfias"},
"ravage":{"ravage","ravaged","ravages","ravaging"},
"ravaging":{"ravaging","ravagings"},
"rave":{"rave","raved","raves","raving"},
"ravel":{"ravel","raveled","raveling","ravelled","ravelling","ravels"},
"raveling":{"raveling","ravelings"},
"ravelling":{"ravelling","ravellings"},
"raven":{"raven","ravened","ravening","ravens"},
"ravenala":{"ravenala","ravenalas"},
"ravenna":{"ravenna","ravennas"},
"ravenousness":{"ravenousness","ravenousnesses"},
"raver":{"raver","ravers"},
"ravine":{"ravine","ravines"},
"raving":{"raving","ravings"},
"ravioli":{"ravioli","raviolis"},
"ravish":{"ravish","ravished","ravishes","ravishing"},
"ravisher":{"ravisher","ravishers"},
"ravishment":{"ravishment","ravishments"},
"raw":{"raw","rawer","rawest","raws"},
"rawhide":{"rawhide","rawhided","rawhiding"},
"ray":{"ray","rayed","raying","rays"},
"rayons":{"rayons","rayonses"},
"raz-cut":{"raz-cut","raz-cuts","raz-cutting"},
"raze":{"raze","razed","razes","razing"},
"razee":{"razee","razeed","razeeing","razees"},
"razing":{"razing","razings"},
"razmataz":{"razmataz","razmatazs"},
"razor":{"razor","razored","razoring","razors"},
"razorback":{"razorback","razorbacks"},
"razorbill":{"razorbill","razorbills"},
"razz":{"razz","razzed","razzing"},
"razzia":{"razzia","razzias"},
"razzing":{"razzing","razzings"},
"razzle":{"razzle","razzles"},
"razzle-dazzle":{"razzle-dazzle","razzle-dazzles"},
"razzmatazz":{"razzmatazz","razzmatazzs"},
"rb":{"rb","rbs"},
"rbi":{"rbi","rbis"},
"re":{"re","res"},
"re-act":{"re-act","re-acted","re-acting"},
"re-afforestation":{"re-afforestation","re-afforestations"},
"re-claim":{"re-claim","re-claimed","re-claiming"},
"re-count":{"re-count","re-counted","re-counting"},
"re-cover":{"re-cover","re-covered","re-covering"},
"re-echo":{"re-echo","re-echoed","re-echoing"},
"re-edit":{"re-edit","re-edited","re-editing"},
"re-educate":{"re-educate","re-educated","re-educating"},
"re-elect":{"re-elect","re-elected","re-electing"},
"re-embark":{"re-embark","re-embarked","re-embarking"},
"re-enact":{"re-enact","re-enacted","re-enacting"},
"re-encounter":{"re-encounter","re-encountered","re-encountering"},
"re-entry":{"re-entries","re-entry"},
"re-equip":{"re-equip","re-equipped","re-equipping","re-equips"},
"re-establish":{"re-establish","re-established","re-establishing"},
"re-evaluate":{"re-evaluate","re-evaluated","re-evaluating"},
"re-experience":{"re-experience","re-experienced","re-experiencing"},
"re-experiencing":{"re-experiencing","re-experiencings"},
"re-form":{"re-form","re-formed","re-forming"},
"re-lay":{"re-laid","re-lay","re-laying"},
"re-lease":{"re-lease","re-leased","re-leasing"},
"re-record":{"re-record","re-recorded","re-recording"},
"re-sentencing":{"re-sentencing","re-sentencings"},
"re-tread":{"re-tread","re-treading","re-treads","re-trod","re-trodden"},
"re-up":{"re-up","re-upped","re-upping"},
"re-uptake":{"re-uptake","re-uptakes"},
"reach":{"reach","reached","reaches","reaching"},
"reaching":{"reaching","reachings"},
"react":{"react","reacted","reacting","reacts"},
"reaction":{"reaction","reactions"},
"reactionary":{"reactionaries","reactionary"},
"reactivate":{"reactivataing","reactivate","reactivated"},
"reactivity":{"reactivities","reactivity"},
"reactor":{"reactor","reactors"},
"read":{"read","reading","reads"},
"readability":{"readabilities","readability"},
"readdress":{"readdress","readdressed","readdressing"},
"reader":{"reader","readers"},
"readiness":{"readiness","readinesses"},
"reading":{"reading","readings"},
"readjust":{"readjust","readjusted","readjusting","readjusts"},
"readjustment":{"readjustment","readjustments"},
"readopt":{"readopt","readopted","readopting"},
"ready":{"readied","readier","readiest","ready","readying"},
"readying":{"readying","readyings"},
"reaffirm":{"reaffirm","reaffirmed","reaffirming"},
"reagan":{"reagan","reagans"},
"real":{"real","reals"},
"realign":{"realign","realigned","realigning","realigns"},
"realisation":{"realisation","realisations"},
"realism":{"realism","realisms"},
"realist":{"realist","realists"},
"reality":{"realities","reality"},
"realization":{"realization","realizations"},
"realize":{"realize","realized","realizes","realizing"},
"reallocation":{"reallocation","reallocations"},
"reallotment":{"reallotment","reallotments"},
"realm":{"realm","realms"},
"realness":{"realness","realnesses"},
"realtor":{"realtor","realtors"},
"realty":{"realties","realty"},
"ream":{"ream","reamed","reaming"},
"reamer":{"reamer","reamers"},
"reanimate":{"reanimate","reanimated","reanimates","reanimating"},
"reap":{"reap","reaped","reaping","reaps"},
"reaper":{"reaper","reapers"},
"reappear":{"reappear","reappeared","reappearing","reappears"},
"reappoint":{"reappoint","reappointed","reappointing"},
"reapportion":{"reapportion","reapportioned","reapportioning","reapportions"},
"reapportioning":{"reapportioning","reapportionings"},
"reapportionment":{"reapportionment","reapportionments"},
"reappraisal":{"reappraisal","reappraisals"},
"reappraise":{"reappraise","reappraised","reappraising"},
"rear":{"rear","reared","rearing","rears"},
"rearing":{"rearing","rearings"},
"rearm":{"rearm","rearmed","rearming","rearms"},
"rearmouse":{"rearmice","rearmouse","reremice"},
"rearrange":{"rearrange","rearranged","rearranging"},
"reason":{"reason","reasoned","reasoning","reasons"},
"reasonableness":{"reasonableness","reasonablenesses"},
"reasoner":{"reasoner","reasoners"},
"reasoning":{"reasoning","reasonings"},
"reassemble":{"reassemble","reassembled","reassembling"},
"reassembly":{"reassemblies","reassembly"},
"reassert":{"reassert","reasserted","reasserting","reasserts"},
"reassess":{"reassess","reassessed","reassesses","reassessing"},
"reassessment":{"reassessment","reassessments"},
"reassign":{"reassign","reassigned","reassigning","reassigns"},
"reassociate":{"reassociate","reassociated","reassociating"},
"reassume":{"reassume","reassumed","reassuming"},
"reassure":{"reassure","reassured","reassures","reassuring"},
"reaumur":{"reaumur","reaumurs"},
"reave":{"reave","reaved","reaves","reaving","reft"},
"reb":{"reb","rebs"},
"rebate":{"rebate","rebated","rebates","rebating"},
"rebato":{"rabatos","rebato","rebatos"},
"rebel":{"rebel","rebelled","rebelling","rebels"},
"rebellion":{"rebellion","rebellions"},
"rebelliousness":{"rebelliousness","rebelliousnesses"},
"rebind":{"rebind","rebinding","rebound"},
"rebirth":{"rebirth","rebirths"},
"rebound":{"rebound","rebounded","rebounding","rebounds"},
"rebozo":{"rebozo","rebozos"},
"rebroadcast":{"rebroadcast","rebroadcasted","rebroadcasting","rebroadcasts"},
"rebuff":{"rebuff","rebuffed","rebuffing","rebuffs"},
"rebuild":{"rebuild","rebuilding","rebuilds","rebuilt"},
"rebuke":{"rebuke","rebuked","rebukes","rebuking"},
"reburial":{"reburial","reburials"},
"rebury":{"reburied","rebury","reburying"},
"reburying":{"reburying","reburyings"},
"rebus":{"rebus","rebuses"},
"rebut":{"rebut","rebuts","rebutted","rebutting"},
"rebuttal":{"rebuttal","rebuttals"},
"rebutter":{"rebutter","rebutters"},
"recalcitrance":{"recalcitrance","recalcitrances"},
"recalcitrancy":{"recalcitrancies","recalcitrancy"},
"recalcitrate":{"recalcitrate","recalcitrated","recalcitrating"},
"recall":{"recall","recalled","recalling","recalls"},
"recant":{"recant","recanted","recanting","recants"},
"recantation":{"recantation","recantations"},
"recap":{"recap","recapped","recapping","recaps"},
"recapitalize":{"recapitalize","recapitalized","recapitalizing"},
"recapitulate":{"recapitulate","recapitulated","recapitulates","recapitulating"},
"recapitulation":{"recapitulation","recapitulations"},
"recapture":{"recapture","recaptured","recaptures","recapturing"},
"recast":{"recast","recasted","recasting","recasts"},
"recasting":{"recasting","recastings"},
"recce":{"recce","recces"},
"recco":{"recco","reccos"},
"reccy":{"reccies","reccy"},
"recede":{"recede","receded","recedes","receding"},
"receding":{"receding","recedings"},
"receipt":{"receipt","receipted","receipting","receipts"},
"receipts":{"receipts","receiptses"},
"receive":{"receive","received","receives","receiving"},
"receiver":{"receiver","receivers"},
"receiving":{"receiving","receivings"},
"recency":{"recencies","recency"},
"recentness":{"recentness","recentnesses"},
"receptacle":{"receptacle","receptacles"},
"reception":{"reception","receptions"},
"receptiveness":{"receptiveness","receptivenesses"},
"receptivity":{"receptivities","receptivity"},
"receptor":{"receptor","receptors"},
"recess":{"recess","recessed","recesses","recessing"},
"recession":{"recession","recessions"},
"recharge":{"recharge","recharged","recharges","recharging"},
"rechristen":{"rechristen","rechristened","rechristening"},
"recidivate":{"recidivate","recidivated","recidivates","recidivating"},
"recidivism":{"recidivism","recidivisms"},
"recidivist":{"recidivist","recidivists"},
"recife":{"recife","recifes"},
"recipe":{"recipe","recipes"},
"recipient":{"recipient","recipients"},
"reciprocal":{"reciprocal","reciprocals"},
"reciprocality":{"reciprocalities","reciprocality"},
"reciprocate":{"reciprocate","reciprocated","reciprocating"},
"reciprocation":{"reciprocation","reciprocations"},
"reciprocity":{"reciprocities","reciprocity"},
"recission":{"recission","recissions"},
"recital":{"recital","recitals"},
"recitation":{"recitation","recitations"},
"recite":{"recite","recited","recites","reciting"},
"reck":{"reck","recked","recking"},
"recklessness":{"recklessness","recklessnesses"},
"reckon":{"reckon","reckoned","reckoning","reckons"},
"reckoner":{"reckoner","reckoners"},
"reckoning":{"reckoning","reckonings"},
"reclaim":{"reclaim","reclaimed","reclaiming","reclaims"},
"reclamation":{"reclamation","reclamations"},
"reclassify":{"reclassified","reclassify","reclassifying"},
"recline":{"recline","reclined","reclines","reclining"},
"recliner":{"recliner","recliners"},
"reclothe":{"reclad","reclothe","reclothed","reclothing"},
"recluse":{"recluse","recluses"},
"reclusiveness":{"reclusiveness","reclusivenesses"},
"recognisance":{"recognisance","recognisances"},
"recognition":{"recognition","recognitions"},
"recognizance":{"recognizance","recognizances"},
"recognize":{"recognize","recognized","recognizes","recognizing"},
"recoil":{"recoil","recoiled","recoiling","recoils"},
"recoin":{"recoin","recoined","recoining"},
"recollect":{"recollect","recollected","recollecting","recollects"},
"recollection":{"recollection","recollections"},
"recolor":{"recolor","recolored","recoloring"},
"recombine":{"recombine","recombined","recombining"},
"recommencement":{"recommencement","recommencements"},
"recommend":{"recommend","recommended","recommending","recommends"},
"recommendation":{"recommendation","recommendations"},
"recommit":{"recommit","recommits","recommitted","recommitting"},
"recompense":{"recompense","recompensed","recompenses","recompensing"},
"recompose":{"recompose","recomposed","recomposing"},
"recompute":{"recompute","recomputed","recomputing"},
"reconcile":{"reconcile","reconciled","reconciles","reconciling"},
"reconciler":{"reconciler","reconcilers"},
"reconciliation":{"reconciliation","reconciliations"},
"reconditeness":{"reconditeness","reconditenesses"},
"recondition":{"recondition","reconditioned","reconditioning"},
"reconnect":{"reconnect","reconnected","reconnecting"},
"reconnoiter":{"reconnoiter","reconnoitered","reconnoitering","reconnoiters"},
"reconnoitering":{"reconnoitering","reconnoiterings"},
"reconnoitre":{"reconnoitre","reconnoitred","reconnoitres","reconnoitring"},
"reconquer":{"reconquer","reconquered","reconquering"},
"reconsider":{"reconsider","reconsidered","reconsidering"},
"reconsideration":{"reconsideration","reconsiderations"},
"reconsolidate":{"reconsolidate","reconsolidated","reconsolidating"},
"reconstitute":{"reconstitute","reconstituted","reconstituting"},
"reconstruct":{"reconstruct","reconstructed","reconstructing","reconstructs"},
"reconstruction":{"reconstruction","reconstructions"},
"recontaminate":{"recontaminate","recontaminated","recontaminating"},
"reconvene":{"reconvene","reconvened","reconvening"},
"reconvert":{"reconvert","reconverted","reconverting"},
"reconvey":{"reconvey","reconveyed","reconveying"},
"reconvict":{"reconvict","reconvicted","reconvicting"},
"recopy":{"recopied","recopies","recopy","recopying"},
"record":{"record","recorded","recording","records"},
"record-breaker":{"record-breaker","record-breakers"},
"record-holder":{"record-holder","record-holders"},
"record-keeper":{"record-keeper","record-keepers"},
"recordbook":{"recordbook","recordbooks"},
"recorder":{"recorder","recorders"},
"recording":{"recording","recordings"},
"recount":{"recount","recounted","recounting","recounts"},
"recounting":{"recounting","recountings"},
"recoup":{"recoup","recouped","recouping","recoups"},
"recourse":{"recourse","recourses"},
"recover":{"recover","recovered","recovering","recovers"},
"recoverer":{"recoverer","recoverers"},
"recovery":{"recoveries","recovery"},
"recreant":{"recreant","recreants"},
"recreate":{"recreate","recreated","recreates","recreating"},
"recreation":{"recreation","recreations"},
"recriminate":{"recriminate","recriminated","recriminating"},
"recrudesce":{"recrudesce","recrudesced","recrudescing"},
"recruit":{"recruit","recruited","recruiting","recruits"},
"recruitment":{"recruitment","recruitments"},
"rectangle":{"rectangle","rectangles"},
"rectangularity":{"rectangularities","rectangularity"},
"rectification":{"rectification","rectifications"},
"rectify":{"rectified","rectifies","rectify","rectifying"},
"rectitude":{"rectitude","rectitudes"},
"recto":{"recto","rectos"},
"rector":{"rector","rectors"},
"rectory":{"rectories","rectory"},
"rectrix":{"rectrices","rectrix"},
"rectum":{"recta","rectum","rectums"},
"rectus":{"recti","rectus"},
"recuperate":{"recuperate","recuperated","recuperates","recuperating"},
"recuperation":{"recuperation","recuperations"},
"recur":{"recur","recurred","recurring","recurs"},
"recurrence":{"recurrence","recurrences"},
"recurve":{"recurve","recurved","recurving"},
"recurvirostra":{"recurvirostra","recurvirostras"},
"recurvirostridae":{"recurvirostridae","recurvirostridaes"},
"recusal":{"recusal","recusals"},
"recusant":{"recusant","recusants"},
"recusation":{"recusation","recusations"},
"recycle":{"recycle","recycled","recycles","recycling"},
"red":{"red","redded","redder","reddest","redding","reds"},
"red-blindness":{"red-blindness","red-blindnesses"},
"red-hot":{"red-hot","red-hots"},
"red-pencil":{"red-pencil","red-penciled","red-penciling","red-pencilled","red-pencilling","red-pencillled","red-pencillling","red-pencills"},
"redaction":{"redaction","redactions"},
"redactor":{"redactor","redactors"},
"redbelly":{"redbellies","redbelly"},
"redberry":{"redberries","redberry"},
"redbird":{"redbird","redbirds"},
"redbreast":{"redbreast","redbreasts"},
"redbrush":{"redbrush","redbrushes"},
"redbud":{"redbud","redbuds"},
"redbug":{"redbug","redbugs"},
"redcap":{"redcap","redcaps"},
"redcoat":{"redcoat","redcoats"},
"redd":{"redd","redded","redding","redds"},
"redden":{"redden","reddened","reddening","reddens"},
"redeem":{"redeem","redeemed","redeeming","redeems"},
"redeemer":{"redeemer","redeemers"},
"redemonstrate":{"redemonstrate","redemonstrated","redemonstrating"},
"redemption":{"redemption","redemptions"},
"redeploy":{"redeploy","redeployed","redeploying"},
"redeployment":{"redeployment","redeployments"},
"redescribe":{"redescribe","redescribed","redescribing"},
"redesign":{"redesign","redesigned","redesigning"},
"redevelop":{"redevelop","redeveloped","redeveloping","redevelops"},
"redevelopment":{"redevelopment","redevelopments"},
"redfish":{"redfish","redfishes"},
"redhead":{"redhead","redheads"},
"redheader":{"redheader","redheaders"},
"redhorse":{"redhorse","redhorses"},
"redia":{"redia","rediae"},
"redintegrate":{"redintegrate","redintegrated","redintegrating"},
"redirect":{"redirect","redirected","redirecting","redirects"},
"rediscount":{"rediscount","rediscounted","rediscounting"},
"rediscover":{"rediscover","rediscovered","rediscovering"},
"rediscovery":{"rediscoveries","rediscovery"},
"redisposition":{"redisposition","redispositions"},
"redissolve":{"redissolve","redissolved","redissolving"},
"redistribute":{"redistribute","redistributed","redistributing"},
"redistrict":{"redistrict","redistricted","redistricting"},
"redivide":{"redivide","redivided","redividing"},
"redmaids":{"redmaids","redmaidses"},
"redneck":{"redneck","rednecks"},
"redness":{"redness","rednesses"},
"redo":{"redid","redo","redoes","redoing","redone"},
"redolence":{"redolence","redolences"},
"redouble":{"redouble","redoubled","redoubles","redoubling"},
"redoubt":{"redoubt","redoubts"},
"redound":{"redound","redounded","redounding"},
"redox":{"redox","redoxes"},
"redpoll":{"redpoll","redpolls"},
"redraft":{"redraft","redrafted","redrafting"},
"redraw":{"redraw","redrawing","redrawn","redrew"},
"redress":{"redress","redressed","redresses","redressing"},
"redrive":{"redrive","redriven","redriving","redrove"},
"redroot":{"redroot","redroots"},
"redshank":{"redshank","redshanks"},
"redskin":{"redskin","redskins"},
"redstart":{"redstart","redstarts"},
"redtail":{"redtail","redtails"},
"reduce":{"reduce","reduced","reduces","reducing"},
"reducing":{"reducing","reducings"},
"reduction":{"reduction","reductions"},
"redundance":{"redundance","redundances"},
"redundancy":{"redundancies","redundancy"},
"reduplicate":{"reduplicate","reduplicated","reduplicates","reduplicating"},
"reduviid":{"reduviid","reduviids"},
"reduviidae":{"reduviidae","reduviidaes"},
"redwing":{"redwing","redwings"},
"redwood":{"redwood","redwoods"},
"reebok":{"reebok","reeboks"},
"reecho":{"reecho","reechoed","reechoing"},
"reed":{"reed","reeded","reeding","reeds"},
"reedbird":{"reedbird","reedbirds"},
"reedbuck":{"reedbuck","reedbucks"},
"reedit":{"reedit","reedited","reediting"},
"reedmace":{"reedmace","reedmaces"},
"reedy":{"reedier","reediest","reedy"},
"reef":{"reef","reefed","reefing","reefs"},
"reefer":{"reefer","reefers"},
"reek":{"reek","reeked","reeking","reeks"},
"reel":{"reel","reeled","reeling","reels"},
"reenforce":{"reenforce","reenforced","reenforces","reenforcing"},
"reenforcement":{"reenforcement","reenforcements"},
"reenter":{"reenter","reentered","reentering"},
"reentry":{"reentries","reentry"},
"reeve":{"reeve","reeved","reeves","reeving","rove"},
"reexamination":{"reexamination","reexaminations"},
"reexamine":{"reexamine","reexamined","reexamines","reexamining"},
"reexport":{"reexport","reexported","reexporting"},
"ref":{"ref","reffed","reffing","refs"},
"refabrication":{"refabrication","refabrications"},
"reface":{"reface","refaced","refacing"},
"refashion":{"refashion","refashioned","refashioning","refashions"},
"refasten":{"refasten","refastened","refastening"},
"refect":{"refect","refected","refecting"},
"refectory":{"refectories","refectory"},
"refer":{"refer","referred","referring","refers"},
"referee":{"referee","refereed","refereeing","referees"},
"refereeing":{"refereeing","refereeings"},
"reference":{"reference","referenced","references","referencing"},
"referendum":{"referenda","referendum","referendums"},
"refill":{"refill","refilled","refilling","refills"},
"refilling":{"refilling","refillings"},
"refinance":{"refinance","refinanced","refinancing"},
"refine":{"refine","refined","refines","refining"},
"refinement":{"refinement","refinements"},
"refinery":{"refineries","refinery"},
"refining":{"refining","refinings"},
"refinish":{"refinish","refinished","refinishing"},
"refinisher":{"refinisher","refinishers"},
"refire":{"refire","refired","refiring"},
"refit":{"refit","refits","refitted","refitting"},
"reflect":{"reflect","reflected","reflecting","reflects"},
"reflectance":{"reflectance","reflectances"},
"reflection":{"reflection","reflections"},
"reflectivity":{"reflectivities","reflectivity"},
"reflector":{"reflector","reflectors"},
"reflectorize":{"reflectorize","reflectorized","reflectorizing"},
"reflex":{"reflex","reflexed","reflexes","reflexing"},
"reflexion":{"reflexion","reflexions"},
"reflexive":{"reflexive","reflexives"},
"reflexiveness":{"reflexiveness","reflexivenesses"},
"reflexivity":{"reflexivities","reflexivity"},
"reflower":{"reflower","reflowered","reflowering"},
"reflux":{"reflux","refluxes"},
"reforest":{"reforest","reforested","reforesting"},
"reforestation":{"reforestation","reforestations"},
"reform":{"reform","reformed","reforming","reforms"},
"reformation":{"reformation","reformations"},
"reformatory":{"reformatories","reformatory"},
"reformer":{"reformer","reformers"},
"reformist":{"reformist","reformists"},
"reformulate":{"reformulate","reformulated","reformulates","reformulating"},
"refortify":{"refortified","refortify","refortifying"},
"refract":{"refract","refracted","refracting"},
"refraction":{"refraction","refractions"},
"refractiveness":{"refractiveness","refractivenesses"},
"refractivity":{"refractivities","refractivity"},
"refractoriness":{"refractoriness","refractorinesses"},
"refractory":{"refractories","refractory"},
"refrain":{"refrain","refrained","refraining","refrains"},
"reframe":{"reframe","reframed","reframing"},
"refreeze":{"refreeze","refreezed","refreezing"},
"refresh":{"refresh","refreshed","refreshes","refreshing"},
"refresher":{"refresher","refreshers"},
"refreshment":{"refreshment","refreshments"},
"refrigerate":{"refrigerate","refrigerated","refrigerating"},
"refrigeration":{"refrigeration","refrigerations"},
"refrigerator":{"refrigerator","refrigerators"},
"refuel":{"refuel","refueled","refueling","refuelled","refuelling","refuels"},
"refueling":{"refueling","refuelings"},
"refuge":{"refuge","refuged","refuges","refuging"},
"refugee":{"refugee","refugees"},
"refugium":{"refugia","refugium"},
"refulgence":{"refulgence","refulgences"},
"refulgency":{"refulgencies","refulgency"},
"refund":{"refund","refunded","refunding","refunds"},
"refurbish":{"refurbish","refurbished","refurbishes","refurbishing"},
"refurnish":{"refurnish","refurnished","refurnishing"},
"refusal":{"refusal","refusals"},
"refuse":{"refuse","refused","refuses","refusing"},
"refutation":{"refutation","refutations"},
"refute":{"refute","refuted","refutes","refuting"},
"refuting":{"refuting","refutings"},
"regain":{"regain","regained","regaining","regains"},
"regaining":{"regaining","regainings"},
"regale":{"regale","regaled","regales","regaling"},
"regalecidae":{"regalecidae","regalecidaes"},
"regalia":{"regalia","regalias"},
"regality":{"regalities","regality"},
"regard":{"regard","regarded","regarding","regards"},
"regather":{"regather","regathered","regathering"},
"regatta":{"regatta","regattas"},
"regency":{"regencies","regency"},
"regenerate":{"regenerate","regenerated","regenerates","regenerating"},
"regent":{"regent","regents"},
"regerminate":{"regerminate","regerminated","regerminating"},
"regime":{"regime","regimes"},
"regimen":{"regimen","regimens"},
"regiment":{"regiment","regimented","regimenting","regiments"},
"region":{"region","regions"},
"register":{"register","registered","registering","registers"},
"registrar":{"registrar","registrars"},
"registration":{"registration","registrations"},
"registry":{"registries","registry"},
"reglaecus":{"reglaecus","reglaecuses"},
"regnellidium":{"regnellidium","regnellidiums"},
"regorge":{"regorge","regorged","regorges","regorging"},
"regress":{"regress","regressed","regresses","regressing"},
"regression":{"regression","regressions"},
"regret":{"regret","regrets","regretted","regretting"},
"regrets":{"regrets","regretses"},
"regroup":{"regroup","regrouped","regrouping","regroups"},
"regular":{"regular","regulars"},
"regularisation":{"regularisation","regularisations"},
"regularity":{"regularities","regularity"},
"regularization":{"regularization","regularizations"},
"regularize":{"regularize","regularized","regularizes","regularizing"},
"regulate":{"regulate","regulated","regulates","regulating"},
"regulating":{"regulating","regulatings"},
"regulation":{"regulation","regulations"},
"regulator":{"regulator","regulators"},
"regulus":{"regulus","reguluses"},
"regur":{"regur","regurs"},
"regurgitate":{"regurgitate","regurgitated","regurgitates","regurgitating"},
"regurgitation":{"regurgitation","regurgitations"},
"rehabilitate":{"rehabilitate","rehabilitated","rehabilitating"},
"rehabilitation":{"rehabilitation","rehabilitations"},
"rehandle":{"rehandle","rehandled","rehandling"},
"rehash":{"rehash","rehashed","rehashes","rehashing"},
"rehear":{"rehear","reheard","rehearing","rehears"},
"rehearing":{"rehearing","rehearings"},
"rehearsal":{"rehearsal","rehearsals"},
"rehearse":{"rehearse","rehearsed","rehearses","rehearsing"},
"reheat":{"reheat","reheated","reheating"},
"rehire":{"rehire","rehired","rehiring"},
"rehospitalize":{"rehospitalize","rehospitalized","rehospitalizing"},
"rehouse":{"rehouse","rehoused","rehousing"},
"rehydrate":{"rehydrate","rehydrated","rehydrating"},
"reichsmark":{"reichsmark","reichsmarks"},
"reification":{"reification","reifications"},
"reify":{"reified","reifies","reify","reifying"},
"reign":{"reign","reigned","reigning","reigns"},
"reignite":{"reignite","reignited","reigniting"},
"reimburse":{"reimburse","reimbursed","reimburses","reimbursing"},
"reimport":{"reimport","reimported","reimporting"},
"reimpose":{"reimpose","reimposed","reimposing"},
"reimprison":{"reimprison","reimprisoned","reimprisoning"},
"rein":{"rein","reined","reining","reins"},
"reincarnate":{"reincarnate","reincarnated","reincarnating"},
"reincarnation":{"reincarnation","reincarnations"},
"reindeer":{"reindeer","reindeers"},
"reindoctrinate":{"reindoctrinate","reindoctrinated","reindoctrinating"},
"reinfect":{"reinfect","reinfected","reinfecting"},
"reinflame":{"reinflame","reinflamed","reinflaming"},
"reinflate":{"reinflate","reinflated","reinflating"},
"reinforce":{"reinforce","reinforced","reinforces","reinforcing"},
"reinforcement":{"reinforcement","reinforcements"},
"reinforcer":{"reinforcer","reinforcers"},
"reinhabit":{"reinhabit","reinhabited","reinhabiting"},
"reinject":{"reinject","reinjected","reinjecting"},
"reinsert":{"reinsert","reinserted","reinserting"},
"reinsman":{"reinsman","reinsmen"},
"reinspect":{"reinspect","reinspected","reinspecting"},
"reinstall":{"reinstall","reinstalled","reinstalling"},
"reinstate":{"reinstate","reinstated","reinstates","reinstating"},
"reinstitute":{"reinstitute","reinstituted","reinstituting"},
"reinsure":{"reinsure","reinsured","reinsuring"},
"reintegrate":{"reintegrate","reintegrated","reintegrating"},
"reinter":{"reinter","reintered","reintering"},
"reinterpret":{"reinterpret","reinterpreted","reinterpreting","reinterprets"},
"reinterrogate":{"reinterrogate","reinterrogated","reinterrogating"},
"reintroduce":{"reintroduce","reintroduced","reintroducing"},
"reinvade":{"reinvade","reinvaded","reinvading"},
"reinvent":{"reinvent","reinvented","reinventing"},
"reinvest":{"reinvest","reinvested","reinvesting"},
"reinvestigate":{"reinvestigate","reinvestigated","reinvestigating"},
"reinvigorate":{"reinvigorate","reinvigorated","reinvigorates","reinvigorating"},
"reinvite":{"reinvite","reinvited","reinviting"},
"reissue":{"reissue","reissues"},
"reiterate":{"reiterate","reiterated","reiterates","reiterating"},
"reiteration":{"reiteration","reiterations"},
"reithrodontomys":{"reithrodontomys","reithrodontomyses"},
"reject":{"reject","rejected","rejecting","rejects"},
"rejection":{"rejection","rejections"},
"rejoice":{"rejoice","rejoiced","rejoices","rejoicing"},
"rejoicing":{"rejoicing","rejoicings"},
"rejoin":{"rejoin","rejoined","rejoining","rejoins"},
"rejoinder":{"rejoinder","rejoinders"},
"rejudge":{"rejudge","rejudged","rejudging"},
"rejuvenate":{"rejuvenate","rejuvenated","rejuvenating"},
"rejuvenation":{"rejuvenation","rejuvenations"},
"rekindle":{"rekindle","rekindled","rekindling"},
"reknit":{"reknit","reknitted","reknitting"},
"relafen":{"relafen","relafens"},
"relapse":{"relapse","relapsed","relapses","relapsing"},
"relapsing":{"relapsing","relapsings"},
"relate":{"relate","related","relates","relating"},
"relation":{"relation","relations"},
"relations":{"relations","relationses"},
"relationship":{"relationship","relationships"},
"relative":{"relative","relatives"},
"relative-in-law":{"relative-in-law","relative-in-laws"},
"relativity":{"relativities","relativity"},
"relatum":{"relata","relatum"},
"relaunch":{"relaunch","relaunched","relaunching"},
"relaunder":{"relaunder","relaundered","relaundering"},
"relax":{"relax","relaxed","relaxes","relaxing"},
"relaxant":{"relaxant","relaxants"},
"relaxation":{"relaxation","relaxations"},
"relay":{"relay","relayed","relaying","relays"},
"relays":{"relays","relayses"},
"release":{"release","released","releases","releasing"},
"relegate":{"relegate","relegated","relegates","relegating"},
"relegating":{"relegating","relegatings"},
"relegation":{"relegation","relegations"},
"relend":{"relend","relending","relent"},
"relent":{"relent","relented","relenting","relents"},
"relentlessness":{"relentlessness","relentlessnesses"},
"relet":{"relet","reletting"},
"relevance":{"relevance","relevances"},
"relevancy":{"relevancies","relevancy"},
"reliability":{"reliabilities","reliability"},
"reliableness":{"reliableness","reliablenesses"},
"reliance":{"reliance","reliances"},
"relic":{"relic","relics"},
"relief":{"relief","reliefs","relieves"},
"relieve":{"relieve","relieved","relieves","relieving"},
"reliever":{"reliever","relievers"},
"relievo":{"relievo","relievos"},
"relight":{"relight","relighted","relighting","relit"},
"religion":{"religion","religions"},
"religionist":{"religionist","religionists"},
"religiosity":{"religiosities","religiosity"},
"religiousness":{"religiousness","religiousnesses"},
"reline":{"reline","relined","relining"},
"relinquish":{"relinquish","relinquished","relinquishes","relinquishing"},
"relinquishing":{"relinquishing","relinquishings"},
"relinquishment":{"relinquishment","relinquishments"},
"reliquary":{"reliquaries","reliquary"},
"reliquidate":{"reliquidate","reliquidated","reliquidating"},
"relish":{"relish","relished","relishes","relishing"},
"relishing":{"relishing","relishings"},
"relistening":{"relistening","relistenings"},
"relive":{"relive","relived","relives","reliving"},
"reliving":{"reliving","relivings"},
"reload":{"reload","reloaded","reloading","reloads"},
"reloan":{"reloan","reloaned","reloaning"},
"relocate":{"relocate","relocated","relocates","relocating"},
"relocation":{"relocation","relocations"},
"reluct":{"reluct","relucted","relucting"},
"reluctance":{"reluctance","reluctances"},
"reluctivity":{"reluctivities","reluctivity"},
"rely":{"relied","relies","rely","relying"},
"rem":{"rem","rems"},
"remain":{"remain","remained","remaining","remains"},
"remainder":{"remainder","remaindered","remaindering","remainders"},
"remainderman":{"remainderman","remaindermen"},
"remains":{"remains","remainses"},
"remake":{"remade","remake","remakes","remaking"},
"remaking":{"remaking","remakings"},
"reman":{"reman","remanned","remanning"},
"remand":{"remand","remanded","remanding","remands"},
"remark":{"remark","remarked","remarking","remarks"},
"remarry":{"remarried","remarry","remarrying"},
"rematch":{"rematch","rematches"},
"rembrandt":{"rembrandt","rembrandts"},
"remeasure":{"remeasure","remeasured","remeasuring"},
"remediation":{"remediation","remediations"},
"remedy":{"remedied","remedies","remedy","remedying"},
"remember":{"remember","remembered","remembering","remembers"},
"remembering":{"remembering","rememberings"},
"remembrance":{"remembrance","remembrances"},
"remerge":{"remerge","remerged","remerging"},
"remex":{"remex","remiges"},
"remilegia":{"remilegia","remilegias"},
"remilitarize":{"remilitarize","remilitarized","remilitarizing"},
"remind":{"remind","reminded","reminding","reminds"},
"reminder":{"reminder","reminders"},
"reminisce":{"reminisce","reminisced","reminiscing"},
"reminiscence":{"reminiscence","reminiscences"},
"remise":{"remise","remised","remising"},
"remission":{"remission","remissions"},
"remissness":{"remissness","remissnesses"},
"remit":{"remit","remits","remitted","remitting"},
"remittal":{"remittal","remittals"},
"remittance":{"remittance","remittances"},
"remitter":{"remitter","remitters"},
"remix":{"remix","remixed","remixing"},
"remnant":{"remnant","remnants"},
"remodel":{"remodel","remodeled","remodeling","remodelled","remodelling"},
"remodify":{"remodified","remodify","remodifying"},
"remonstrance":{"remonstrance","remonstrances"},
"remonstrate":{"remonstrate","remonstrated","remonstrates","remonstrating"},
"remonstrator":{"remonstrator","remonstrators"},
"remora":{"remora","remoras"},
"remorse":{"remorse","remorses"},
"remote":{"remote","remoter","remotes","remotest"},
"remoteness":{"remoteness","remotenesses"},
"remotion":{"remotion","remotions"},
"remount":{"remount","remounted","remounting","remouted"},
"removal":{"removal","removals"},
"remove":{"remove","removed","removes","removing"},
"remunerate":{"remunerate","remunerated","remunerates","remunerating"},
"remuneration":{"remuneration","remunerations"},
"remunerator":{"remunerator","remunerators"},
"renaissance":{"renaissance","renaissances"},
"rename":{"rename","renamed","renaming"},
"renascence":{"renascence","renascences"},
"rencounter":{"rencounter","rencountered","rencountering"},
"rend":{"rend","rending","rends","rent"},
"render":{"render","rendered","rendering","renders"},
"rendering":{"rendering","renderings"},
"rendezvous":{"rendezvous","rendezvoused","rendezvouses","rendezvousing"},
"rendition":{"rendition","renditions"},
"renegade":{"renegade","renegades"},
"renegado":{"renegado","renegados"},
"renege":{"renege","reneges"},
"renegotiate":{"renegotiate","renegotiated","renegotiating"},
"renew":{"renew","renewed","renewing","renews"},
"renewal":{"renewal","renewals"},
"rennin":{"rennin","rennins"},
"renominate":{"renominate","renominated","renominating"},
"renounce":{"renounce","renounced","renounces","renouncing"},
"renouncement":{"renouncement","renouncements"},
"renovate":{"renovate","renovated","renovates","renovating"},
"renovation":{"renovation","renovations"},
"renovator":{"renovator","renovators"},
"renown":{"renown","renowns"},
"rent":{"rent","rented","renting","rents"},
"rental":{"rental","rentals"},
"rente":{"rente","rentes"},
"renter":{"renter","renters"},
"rentier":{"rentier","rentiers"},
"renting":{"renting","rentings"},
"renunciation":{"renunciation","renunciations"},
"reoccupy":{"reoccupied","reoccupy","reoccupying"},
"reopen":{"reopen","reopened","reopening"},
"reoppose":{"reoppose","reopposed","reopposing"},
"reorder":{"reorder","reordered","reordering"},
"reorganisation":{"reorganisation","reorganisations"},
"reorganization":{"reorganization","reorganizations"},
"reorganize":{"reorganize","reorganized","reorganizes","reorganizing"},
"reorient":{"reorient","reoriented","reorienting","reorients"},
"rep":{"rep","reps"},
"repackage":{"repackage","repackaged","repackaging"},
"repaint":{"repaint","repainted","repainting"},
"repair":{"repair","repaired","repairing","repairs"},
"repairer":{"repairer","repairers"},
"repairman":{"repairman","repairmen"},
"reparation":{"reparation","reparations"},
"repartition":{"repartition","repartitioned","repartitioning"},
"repast":{"repast","repasts"},
"repatriate":{"repatriate","repatriated","repatriates","repatriating"},
"repave":{"repave","repaved","repaving"},
"repay":{"repaid","repay","repaying","repays"},
"repayment":{"repayment","repayments"},
"repeal":{"repeal","repealed","repealing","repeals"},
"repeat":{"repeat","repeated","repeating","repeats"},
"repeater":{"repeater","repeaters"},
"repeating":{"repeating","repeatings"},
"repel":{"repel","repelled","repelling","repels"},
"repellant":{"repellant","repellants"},
"repellent":{"repellent","repellents"},
"repelling":{"repelling","repellings"},
"repent":{"repent","repented","repenting","repents"},
"repentance":{"repentance","repentances"},
"repeople":{"repeople","repeopled","repeopling"},
"repercussion":{"repercussion","repercussions"},
"repertoire":{"repertoire","repertoires"},
"repertory":{"repertories","repertory"},
"repetition":{"repetition","repetitions"},
"repetitiousness":{"repetitiousness","repetitiousnesses"},
"repetitiveness":{"repetitiveness","repetitivenesses"},
"rephrase":{"rephrase","rephrased","rephrases","rephrasing"},
"rephrasing":{"rephrasing","rephrasings"},
"repine":{"repine","repined","repining"},
"replace":{"replace","replaced","replaces","replacing"},
"replaceability":{"replaceabilities","replaceability"},
"replacement":{"replacement","replacements"},
"replacing":{"replacing","replacings"},
"replant":{"replant","replanted","replanting"},
"replay":{"replay","replayed","replaying","replays"},
"replenish":{"replenish","replenished","replenishes","replenishing"},
"replenisher":{"replenisher","replenishers"},
"replenishment":{"replenishment","replenishments"},
"replete":{"replete","repleted","repletes","repleting"},
"repletion":{"repletion","repletions"},
"replevin":{"replevin","replevined","replevining"},
"replevy":{"replevied","replevies","replevy","replevying"},
"replica":{"replica","replicas"},
"replicate":{"replicate","replicated","replicates","replicating"},
"replication":{"replication","replications"},
"reply":{"replied","replies","reply","replying"},
"repolish":{"repolish","repolished","repolishing"},
"report":{"report","reported","reporting","reports"},
"reportage":{"reportage","reportages"},
"reporter":{"reporter","reporters"},
"reporting":{"reporting","reportings"},
"repose":{"repose","reposed","reposes","reposing"},
"reposit":{"reposit","reposited","repositing"},
"repositing":{"repositing","repositings"},
"reposition":{"reposition","repositioned","repositioning","repositions"},
"repository":{"repositories","repository"},
"repossess":{"repossess","repossessed","repossesses","repossessing"},
"repot":{"repot","repots","repotted","repotting"},
"repp":{"repp","repps"},
"reprehend":{"reprehend","reprehended","reprehending"},
"reprehension":{"reprehension","reprehensions"},
"represent":{"represent","represented","representing","represents"},
"representation":{"representation","representations"},
"representative":{"representative","representatives"},
"repress":{"repress","repressed","represses","repressing"},
"reprieve":{"reprieve","reprieved","reprieves","reprieving"},
"reprimand":{"reprimand","reprimanded","reprimanding","reprimands"},
"reprint":{"reprint","reprinted","reprinting","reprints"},
"reprinting":{"reprinting","reprintings"},
"reprise":{"reprise","reprised","reprises","reprising"},
"repristinate":{"repristinate","repristinated","repristinating"},
"repro":{"repro","repros"},
"reproach":{"reproach","reproached","reproaches","reproaching"},
"reprobate":{"reprobate","reprobated","reprobates","reprobating"},
"reprocess":{"reprocess","reprocessed","reprocesses","reprocessing"},
"reproduce":{"reproduce","reproduced","reproduces","reproducing"},
"reproducer":{"reproducer","reproducers"},
"reproducibility":{"reproducibilities","reproducibility"},
"reproduction":{"reproduction","reproductions"},
"reprogram":{"reprogram","reprogramed","reprograming","reprogrammed","reprogramming"},
"reproof":{"reproof","reproofed","reproofing","reproofs","reprooves"},
"reproval":{"reproval","reprovals"},
"reprove":{"reprove","reproved","reproves","reproving"},
"reprovision":{"reprovision","reprovisioned","reprovisioning"},
"reptantia":{"reptantia","reptantias"},
"reptile":{"reptile","reptiles"},
"reptilia":{"reptilia","reptilias"},
"reptilian":{"reptilian","reptilians"},
"repture":{"repture","reptures"},
"republic":{"republic","republics"},
"republican":{"republican","republicans"},
"republication":{"republication","republications"},
"republish":{"republish","republished","republishing"},
"republishing":{"republishing","republishings"},
"repudiate":{"repudiate","repudiated","repudiates","repudiating"},
"repudiation":{"repudiation","repudiations"},
"repudiator":{"repudiator","repudiators"},
"repugn":{"repugn","repugned","repugning","repugns"},
"repugnance":{"repugnance","repugnances"},
"repulse":{"repulse","repulsed","repulses","repulsing"},
"repulsion":{"repulsion","repulsions"},
"repulsiveness":{"repulsiveness","repulsivenesses"},
"repurchase":{"repurchase","repurchased","repurchases","repurchasing"},
"reputability":{"reputabilities","reputability"},
"reputation":{"reputation","reputations"},
"repute":{"repute","reputed","reputes","reputing"},
"request":{"request","requested","requesting","requests"},
"requiem":{"requiem","requiems"},
"require":{"require","required","requires","requiring"},
"requirement":{"requirement","requirements"},
"requisite":{"requisite","requisites"},
"requisition":{"requisition","requisitioned","requisitioning","requisitions"},
"requite":{"requite","requited","requites","requiting"},
"requittal":{"requittal","requittals"},
"reradiate":{"reradiate","reradiated","reradiating"},
"reread":{"reread","rereading"},
"rerebrace":{"rerebrace","rerebraces"},
"reredos":{"reredos","reredoses"},
"reremouse":{"reremice","reremouse"},
"reroute":{"reroute","rerouted","rerouting"},
"rerun":{"reran","rerun","rerunning","reruns"},
"resail":{"resail","resailed","resailing"},
"rescind":{"rescind","rescinded","rescinding","rescinds"},
"rescinding":{"rescinding","rescindings"},
"rescission":{"rescission","rescissions"},
"rescript":{"rescript","rescripts"},
"rescue":{"rescue","rescued","rescues","rescuing"},
"rescuer":{"rescuer","rescuers"},
"research":{"research","researched","researches","researching"},
"researcher":{"researcher","researchers"},
"reseat":{"reseat","reseated","reseating"},
"reseau":{"reseau","reseaus","reseaux"},
"resect":{"resect","resected","resecting"},
"resedaceae":{"resedaceae","resedaceaes"},
"resell":{"resell","reselling","resold"},
"resemblance":{"resemblance","resemblances"},
"resemble":{"resemble","resembled","resembling"},
"resend":{"resend","resending","resent"},
"resent":{"resent","resented","resenting","resents"},
"resentment":{"resentment","resentments"},
"reserpine":{"reserpine","reserpines"},
"reservation":{"reservation","reservations"},
"reserve":{"reserve","reserved","reserves","reserving"},
"reserves":{"reserves","reserveses"},
"reservoir":{"reservoir","reservoired","reservoiring","reservoirs"},
"reset":{"reset","resets","resetting"},
"resettle":{"resettle","resettled","resettling"},
"resettlement":{"resettlement","resettlements"},
"reshape":{"reshape","reshaped","reshapes","reshaping"},
"reshuffle":{"reshuffle","reshuffled","reshuffles","reshuffling"},
"reshuffling":{"reshuffling","reshufflings"},
"reside":{"reside","resided","resides","residing"},
"residence":{"residence","residences"},
"residency":{"residencies","residency"},
"resident":{"resident","residents"},
"residentiary":{"residentiaries","residentiary"},
"residual":{"residual","residuals"},
"residue":{"residue","residues"},
"residuum":{"residua","residuum","residuums"},
"resign":{"resign","resigned","resigning","resigns"},
"resignation":{"resignation","resignations"},
"resile":{"resile","resiled","resiling"},
"resilience":{"resilience","resiliences"},
"resiliency":{"resiliencies","resiliency"},
"resin":{"resin","resined","resining","resins"},
"resinate":{"resinate","resinated","resinating"},
"resist":{"resist","resisted","resisting","resists"},
"resistance":{"resistance","resistances"},
"resister":{"resister","resisters"},
"resistivity":{"resistivities","resistivity"},
"resistor":{"resistor","resistors"},
"resit":{"resat","resit","resits","resitting"},
"resole":{"resole","resoled","resoles","resoling"},
"resolute":{"resolute","resolutes"},
"resoluteness":{"resoluteness","resolutenesses"},
"resolution":{"resolution","resolutions"},
"resolve":{"resolve","resolved","resolves","resolving"},
"resolvent":{"resolvent","resolvents"},
"resolving":{"resolving","resolvings"},
"resonance":{"resonance","resonances"},
"resonate":{"resonate","resonated","resonates","resonating"},
"resonator":{"resonator","resonators"},
"resorcinolphthalein":{"resorcinolphthalein","resorcinolphthaleins"},
"resort":{"resort","resorted","resorting","resorts"},
"resound":{"resound","resounded","resounding","resounds"},
"resource":{"resource","resources"},
"resourcefulness":{"resourcefulness","resourcefulnesses"},
"respect":{"respect","respected","respecting","respects"},
"respectability":{"respectabilities","respectability"},
"respectable":{"respectable","respectables"},
"respectfulness":{"respectfulness","respectfulnesses"},
"respiration":{"respiration","respirations"},
"respirator":{"respirator","respirators"},
"respire":{"respire","respired","respires","respiring"},
"respite":{"respite","respites"},
"resplendence":{"resplendence","resplendences"},
"resplendency":{"resplendencies","resplendency"},
"respond":{"respond","responded","responding","responds"},
"respondent":{"respondent","respondents"},
"responder":{"responder","responders"},
"response":{"response","responses"},
"responsibility":{"responsibilities","responsibility"},
"responsibleness":{"responsibleness","responsiblenesses"},
"responsiveness":{"responsiveness","responsivenesses"},
"responsory":{"responsories","responsory"},
"responsum":{"responsa","responsum"},
"rest":{"rest","rested","resting","rests"},
"restate":{"restate","restated","restates","restating"},
"restaurant":{"restaurant","restaurants"},
"restauranter":{"restauranter","restauranters"},
"restaurateur":{"restaurateur","restaurateurs"},
"restharrow":{"restharrow","restharrows"},
"restitute":{"restitute","restituted","restitutes","restituting"},
"restitution":{"restitution","restitutions"},
"restiveness":{"restiveness","restivenesses"},
"restlessness":{"restlessness","restlessnesses"},
"restock":{"restock","restocked","restocking"},
"restoration":{"restoration","restorations"},
"restorative":{"restorative","restoratives"},
"restore":{"restore","restored","restores","restoring"},
"restorer":{"restorer","restorers"},
"restrain":{"restrain","restrained","restraining","restrains"},
"restraint":{"restraint","restraints"},
"restrict":{"restrict","restricted","restricting","restricts"},
"restriction":{"restriction","restrictions"},
"restroom":{"restroom","restrooms"},
"restructure":{"restructure","restructured","restructuring"},
"result":{"result","resulted","resulting","results"},
"resultant":{"resultant","resultants"},
"resume":{"resume","resumed","resumes","resuming"},
"resumption":{"resumption","resumptions"},
"resurface":{"resurface","resurfaced","resurfacing"},
"resurge":{"resurge","resurged","resurging"},
"resurgence":{"resurgence","resurgences"},
"resurrect":{"resurrect","resurrected","resurrecting","resurrects"},
"resurvey":{"resurvey","resurveyed","resurveying"},
"resuscitate":{"resuscitate","resuscitated","resuscitates","resuscitating"},
"ret":{"ret","rets","retted","retting"},
"retail":{"retail","retailed","retailing"},
"retailer":{"retailer","retailers"},
"retain":{"retain","retained","retaining","retains"},
"retainer":{"retainer","retainers"},
"retake":{"retake","retaken","retakes","retaking","retook"},
"retaking":{"retaking","retakings"},
"retaliate":{"retaliate","retaliated","retaliates","retaliating"},
"retaliation":{"retaliation","retaliations"},
"retaliator":{"retaliator","retaliators"},
"retama":{"retama","retamas"},
"retard":{"retard","retarded","retarding","retards"},
"retardation":{"retardation","retardations"},
"retch":{"retch","retched","retches","retching"},
"rete":{"rete","retia"},
"retell":{"retell","retelling","retells","retold"},
"retem":{"retem","retems"},
"retention":{"retention","retentions"},
"retentiveness":{"retentiveness","retentivenesses"},
"retentivity":{"retentivities","retentivity"},
"rethink":{"rethink","rethinking","rethinks","rethought"},
"retiarius":{"retiararii","retiarius"},
"reticence":{"reticence","reticences"},
"reticle":{"reticle","reticles"},
"reticulate":{"reticulate","reticulated","reticulating"},
"reticulation":{"reticulation","reticulations"},
"reticule":{"reticule","reticules"},
"reticulitermes":{"reticulitermes","reticulitermeses"},
"reticulum":{"reticulum","reticulums"},
"retina":{"retina","retinae","retinas"},
"retinaculum":{"retinacula","retinaculum"},
"retinal":{"retinal","retinals"},
"retinene":{"retinene","retinenes"},
"retinol":{"retinol","retinols"},
"retinue":{"retinue","retinues"},
"retire":{"retire","retired","retires","retiring"},
"retiree":{"retiree","retirees"},
"retirement":{"retirement","retirements"},
"retool":{"retool","retooled","retooling","retools"},
"retort":{"retort","retorted","retorting","retorts"},
"retouch":{"retouch","retouched","retouches","retouching"},
"retrace":{"retrace","retraced","retraces","retracing"},
"retract":{"retract","retracted","retracting","retracts"},
"retraction":{"retraction","retractions"},
"retrain":{"retrain","retrained","retraining"},
"retread":{"retread","retreaded","retreading","retreads"},
"retreat":{"retreat","retreated","retreating","retreats"},
"retrench":{"retrench","retrenched","retrenching"},
"retrenchment":{"retrenchment","retrenchments"},
"retribution":{"retribution","retributions"},
"retrieval":{"retrieval","retrievals"},
"retrieve":{"retrieve","retrieved","retrieves","retrieving"},
"retro":{"retro","retros"},
"retro-rocket":{"retro-rocket","retro-rockets"},
"retroact":{"retroact","retroacted","retroacting"},
"retrocede":{"retrocede","retroceded","retroceding"},
"retrofire":{"retrofire","retrofired","retrofiring"},
"retrofit":{"retrofit","retrofits","retrofitted","retrofitting"},
"retroflection":{"retroflection","retroflections"},
"retroflexion":{"retroflexion","retroflexions"},
"retrograde":{"retrograde","retrograded","retrogrades","retrograding"},
"retrogress":{"retrogress","retrogressed","retrogresses","retrogressing"},
"retrogression":{"retrogression","retrogressions"},
"retrophyllum":{"retrophyllum","retrophyllums"},
"retrospect":{"retrospect","retrospected","retrospecting","retrospects"},
"retroversion":{"retroversion","retroversions"},
"retry":{"retried","retries","retry","retrying"},
"return":{"return","returned","returning","returns"},
"reunification":{"reunification","reunifications"},
"reunify":{"reunified","reunifies","reunify","reunifying"},
"reunion":{"reunion","reunions"},
"reunite":{"reunite","reunited","reunites","reuniting"},
"reuptake":{"reuptake","reuptakes"},
"rev":{"rev","revs","revved","revving"},
"revalorize":{"revalorize","revalorized","revalorizes","revalorizing"},
"revaluation":{"revaluation","revaluations"},
"revalue":{"revalue","revalued","revalues","revaluing"},
"revamp":{"revamp","revamped","revamping","revamps"},
"revascularize":{"revascularize","revascularized","revascularizing"},
"reveal":{"reveal","revealed","revealing","reveals"},
"revealing":{"revealing","revealings"},
"revealment":{"revealment","revealments"},
"reveille":{"reveille","reveilles"},
"revel":{"revel","reveled","reveling","revelled","revelling","revels"},
"revelation":{"revelation","revelations"},
"reveler":{"reveler","revelers"},
"reveller":{"reveller","revellers"},
"revelry":{"revelries","revelry"},
"revenge":{"revenge","revenged","revenges","revenging"},
"revenue":{"revenue","revenues"},
"reverb":{"reverb","reverbed","reverbing"},
"reverberance":{"reverberance","reverberances"},
"reverberate":{"reverberate","reverberated","reverberates","reverberating"},
"reverberation":{"reverberation","reverberations"},
"reverberatory":{"reverberatories","reverberatory"},
"revere":{"revere","revered","reveres","revering"},
"reverence":{"reverence","reverenced","reverences","reverencing"},
"reverend":{"reverend","reverends"},
"reverie":{"reverie","reveries"},
"revers":{"revers","reverses"},
"reversal":{"reversal","reversals"},
"reverse":{"reverse","reversed","reverses","reversing"},
"reversion":{"reversion","reversions"},
"reversionist":{"reversionist","reversionists"},
"reverso":{"reverso","reversos"},
"revert":{"revert","reverted","reverting","reverts"},
"reverting":{"reverting","revertings"},
"revery":{"reveries","revery"},
"revest":{"revest","revested","revesting"},
"revet":{"revet","revets","revetted","revetting"},
"revetement":{"revetement","revetements"},
"revetment":{"revetment","revetments"},
"review":{"review","reviewed","reviewing","reviews"},
"reviewer":{"reviewer","reviewers"},
"revile":{"revile","reviled","reviles","reviling"},
"revilement":{"revilement","revilements"},
"reviler":{"reviler","revilers"},
"revisal":{"revisal","revisals"},
"revise":{"revise","revised","revises","revising"},
"reviser":{"reviser","revisers"},
"revising":{"revising","revisings"},
"revision":{"revision","revisions"},
"revisit":{"revisit","revisited","revisiting"},
"revitalisation":{"revitalisation","revitalisations"},
"revitalization":{"revitalization","revitalizations"},
"revitalize":{"revitalize","revitalized","revitalizes","revitalizing"},
"revival":{"revival","revivals"},
"revivalist":{"revivalist","revivalists"},
"revive":{"revive","revived","revives","reviving"},
"revivification":{"revivification","revivifications"},
"revivify":{"revivified","revivifies","revivify","revivifying"},
"revoke":{"revoke","revoked","revokes","revoking"},
"revolt":{"revolt","revolted","revolting","revolts"},
"revolution":{"revolution","revolutions"},
"revolutionary":{"revolutionaries","revolutionary"},
"revolutionist":{"revolutionist","revolutionists"},
"revolutionize":{"revolutionize","revolutionized","revolutionizes","revolutionizing"},
"revolve":{"revolve","revolved","revolves","revolving"},
"revolver":{"revolver","revolvers"},
"revue":{"revue","revues"},
"revulsion":{"revulsion","revulsions"},
"rewa-rewa":{"rewa-rewa","rewa-rewas"},
"reward":{"reward","rewarded","rewarding","rewards"},
"rewin":{"rewin","rewinning","rewon"},
"rewind":{"rewind","rewinding","rewinds","rewound"},
"rewire":{"rewire","rewired","rewiring"},
"reword":{"reword","reworded","rewording","rewords"},
"rewording":{"rewording","rewordings"},
"rework":{"rework","reworked","reworking","rewrought"},
"rewrite":{"rewrite","rewrites","rewriting","rewritten","rewrote"},
"rewriter":{"rewriter","rewriters"},
"rewriting":{"rewriting","rewritings"},
"reykjavik":{"reykjavik","reykjaviks"},
"rf":{"rf","rfs"},
"rh":{"rh","rhs"},
"rhabdomyoma":{"rhabdomyoma","rhabdomyomas","rhabdomyomata"},
"rhachis":{"rachides","rhachides","rhachis","rhachises"},
"rhagoletis":{"rhagoletis","rhagoletises"},
"rhamnaceae":{"rhamnaceae","rhamnaceaes"},
"rhamnales":{"rhamnales","rhamnaleses"},
"rhamnus":{"rhamnus","rhamnuses"},
"rhapis":{"rhapis","rhapises"},
"rhapsodize":{"rhapsodize","rhapsodized","rhapsodizing"},
"rhapsody":{"rhapsodies","rhapsody"},
"rhatany":{"rhatanies","rhatany"},
"rhea":{"rhea","rheas"},
"rhebok":{"rhebok","rheboks"},
"rheidae":{"rheidae","rheidaes"},
"rheiformes":{"rheiformes","rheiformeses"},
"rhein":{"rhein","rheins"},
"rheinland":{"rheinland","rheinlands"},
"rhenium":{"rhenium","rheniums"},
"rhennish":{"rhennish","rhennishes"},
"rheostat":{"rheostat","rheostats"},
"rhesus":{"rhesus","rhesuses"},
"rhetoric":{"rhetoric","rhetorics"},
"rhetorician":{"rhetorician","rhetoricians"},
"rheum":{"rheum","rheums"},
"rheumatic":{"rheumatic","rheumatics"},
"rheumatism":{"rheumatism","rheumatisms"},
"rheumy":{"rheumier","rheumiest","rheumy"},
"rhexia":{"rhexia","rhexias"},
"rhibhus":{"rhibhus","rhibhuses"},
"rhincodon":{"rhincodon","rhincodons"},
"rhincodontidae":{"rhincodontidae","rhincodontidaes"},
"rhine":{"rhine","rhines"},
"rhineland":{"rhineland","rhinelands"},
"rhinencephalon":{"rhinencephala","rhinencephalon","rhinencephalons"},
"rhinitis":{"rhinitis","rhinitises"},
"rhino":{"rhino","rhinos"},
"rhinobatidae":{"rhinobatidae","rhinobatidaes"},
"rhinoceros":{"rhinoceri","rhinoceros","rhinoceroses"},
"rhinocerotidae":{"rhinocerotidae","rhinocerotidaes"},
"rhinolaryngologist":{"rhinolaryngologist","rhinolaryngologists"},
"rhinolophidae":{"rhinolophidae","rhinolophidaes"},
"rhinonicteris":{"rhinonicteris","rhinonicterises"},
"rhinoplasty":{"rhinoplasties","rhinoplasty"},
"rhinoptera":{"rhinoptera","rhinopteras"},
"rhinotermitidae":{"rhinotermitidae","rhinotermitidaes"},
"rhipsalis":{"rhipsalis","rhipsalises"},
"rhiptoglossa":{"rhiptoglossa","rhiptoglossas"},
"rhizobiaceae":{"rhizobiaceae","rhizobiaceaes"},
"rhizobium":{"rhizobium","rhizobiums"},
"rhizome":{"rhizome","rhizomes"},
"rhizophora":{"rhizophora","rhizophoras"},
"rhizophoraceae":{"rhizophoraceae","rhizophoraceaes"},
"rhizopod":{"rhizopod","rhizopods"},
"rhizopoda":{"rhizopoda","rhizopodas"},
"rhizopodan":{"rhizopodan","rhizopodans"},
"rhizopogon":{"rhizopogon","rhizopogons"},
"rhizopogonaceae":{"rhizopogonaceae","rhizopogonaceaes"},
"rhizotomy":{"rhizotomies","rhizotomy"},
"rho":{"rho","rhos"},
"rhodanthe":{"rhodanthe","rhodanthes"},
"rhodesia":{"rhodesia","rhodesias"},
"rhodium":{"rhodium","rhodiums"},
"rhodophyceae":{"rhodophyceae","rhodophyceaes"},
"rhodophyta":{"rhodophyta","rhodophytas"},
"rhodopsin":{"rhodopsin","rhodopsins"},
"rhodosphaera":{"rhodosphaera","rhodosphaeras"},
"rhodymenia":{"rhodymenia","rhodymenias"},
"rhodymeniaceae":{"rhodymeniaceae","rhodymeniaceaes"},
"rhoeadales":{"rhoeadales","rhoeadaleses"},
"rhomb":{"rhomb","rhombs"},
"rhombencephalon":{"rhombencephalon","rhombencephalons"},
"rhombohedron":{"rhombohedra","rhombohedron"},
"rhomboideus":{"rhomboidei","rhomboideus"},
"rhombus":{"rhombi","rhombus","rhombuses"},
"rhonchus":{"rhonchus","rhonchuses"},
"rhone":{"rhone","rhones"},
"rhubarb":{"rhubarb","rhubarbs"},
"rhumb":{"rhumb","rhumbs"},
"rhumba":{"rhumba","rhumbas"},
"rhus":{"rhus","rhuses"},
"rhyacotriton":{"rhyacotriton","rhyacotritons"},
"rhyme":{"rhyme","rhymed","rhymes","rhyming"},
"rhynchocephalia":{"rhynchocephalia","rhynchocephalias"},
"rhynchoelaps":{"rhynchoelaps","rhynchoelapses"},
"rhyncostylis":{"rhyncostylis","rhyncostylises"},
"rhynia":{"rhynia","rhynias"},
"rhyniaceae":{"rhyniaceae","rhyniaceaes"},
"rhythm":{"rhythm","rhythms"},
"rhytidectomy":{"rhytidectomies","rhytidectomy"},
"rhytidoplasty":{"rhytidoplasties","rhytidoplasty"},
"rhyton":{"rhyta","rhyton"},
"rial":{"rial","rials"},
"rialto":{"rialto","rialtos"},
"riata":{"riata","riatas"},
"rib":{"rib","ribbed","ribbing","ribs"},
"ribaldry":{"ribaldries","ribaldry"},
"riband":{"riband","ribands"},
"ribband":{"ribband","ribbands"},
"ribbon":{"ribbon","ribboned","ribboning","ribbons"},
"ribbonfish":{"ribbonfish","ribbonfishes"},
"ribbonwood":{"ribbonwood","ribbonwoods"},
"ribes":{"ribes","ribeses"},
"ribgrass":{"ribgrass","ribgrasses"},
"ribhus":{"ribhus","ribhuses"},
"riboflavin":{"riboflavin","riboflavins"},
"ribwort":{"ribwort","ribworts"},
"rice":{"rice","riced","ricing"},
"ricebird":{"ricebird","ricebirds"},
"ricegrass":{"ricegrass","ricegrasses"},
"ricercar":{"ricercar","ricercars"},
"ricercare":{"ricercacari","ricercare","ricercari"},
"rich":{"rich","richer","richest"},
"richea":{"richea","richeas"},
"richelieu":{"richelieu","richelieus"},
"richen":{"richen","richened","richening"},
"riches":{"riches","richeses"},
"richmond":{"richmond","richmonds"},
"richmondena":{"richmondena","richmondenas"},
"richness":{"richness","richnesses"},
"richweed":{"richweed","richweeds"},
"ricinus":{"ricinus","ricinuses"},
"rick":{"rick","ricked","ricking","ricks"},
"ricketiness":{"ricketiness","ricketinesses"},
"rickets":{"rickets","ricketses"},
"rickettsia":{"rickettsia","rickettsiae","rickettsias"},
"rickettsiaceae":{"rickettsiaceae","rickettsiaceaes"},
"rickettsiales":{"rickettsiales","rickettsialeses"},
"rickety":{"ricketier","ricketiest","rickety"},
"rickey":{"rickey","rickeys"},
"rickrack":{"rickrack","rickracks"},
"ricksha":{"ricksha","rickshas"},
"rickshaw":{"rickshaw","rickshaws"},
"ricochet":{"ricochet","ricocheted","ricocheting","ricochets","ricochetted","ricochetting"},
"ricrac":{"ricrac","ricracs"},
"rictus":{"rictus","rictuses"},
"rid":{"rid","ridded","ridding","rids"},
"riddance":{"riddance","riddances"},
"riddle":{"riddle","riddled","riddles","riddling"},
"ride":{"ridden","ride","rides","riding","rode"},
"rider":{"rider","riders"},
"ridge":{"ridge","ridged","ridges","ridging"},
"ridgel":{"ridgel","ridgels"},
"ridgeling":{"ridgeling","ridgelings"},
"ridgepole":{"ridgepole","ridgepoles"},
"ridgil":{"ridgil","ridgils"},
"ridgling":{"ridgling","ridglings"},
"ridgy":{"ridgier","ridgiest","ridgy"},
"ridicule":{"ridicule","ridiculed","ridicules","ridiculing"},
"ridiculousness":{"ridiculousness","ridiculousnesses"},
"riding":{"riding","ridings"},
"ridotto":{"ridotto","ridottos"},
"riemann":{"riemann","riemanns"},
"rife":{"rife","rifer","rifest"},
"riff":{"riff","riffed","riffing","riffs"},
"riffian":{"riffian","riffians"},
"riffle":{"riffle","riffled","riffles","riffling"},
"riffraff":{"riffraff","riffraffs"},
"rifle":{"rifle","rifled","rifles","rifling"},
"riflebird":{"riflebird","riflebirds"},
"rifleman":{"rifleman","riflemen"},
"rifling":{"rifling","riflings"},
"rift":{"rift","rifted","rifting","rifts"},
"rig":{"rig","rigged","rigging","rigs"},
"riga":{"riga","rigas"},
"rigamarole":{"rigamarole","rigamaroles"},
"rigel":{"rigel","rigels"},
"rigging":{"rigging","riggings"},
"right":{"right","righted","righting","rights"},
"right-handedness":{"right-handedness","right-handednesses"},
"right-hander":{"right-hander","right-handers"},
"right-of-way":{"right-of-way","right-of-ways","rights-of-way"},
"right-winger":{"right-winger","right-wingers"},
"rightfield":{"rightfield","rightfields"},
"rightfulness":{"rightfulness","rightfulnesses"},
"rightist":{"rightist","rightists"},
"rightness":{"rightness","rightnesses"},
"rigidify":{"rigidified","rigidifies","rigidify","rigidifying"},
"rigidity":{"rigidities","rigidity"},
"rigidness":{"rigidness","rigidnesses"},
"rigil":{"rigil","rigils"},
"rigmarole":{"rigmarole","rigmaroles"},
"rign-a-rosy":{"rign-a-rosies","rign-a-rosy"},
"rigor":{"rigor","rigors"},
"rigorousness":{"rigorousness","rigorousnesses"},
"rigour":{"rigour","rigours"},
"riksmal":{"riksmal","riksmals"},
"rile":{"rile","riled","riles","riling"},
"rilievo":{"rilievo","rilievos"},
"rill":{"rill","rilled","rilling","rills"},
"rim":{"rim","rimmed","rimming","rims"},
"rime":{"rime","rimed","rimes","riming"},
"rimu":{"rimu","rimus"},
"rimy":{"rimier","rimiest","rimy"},
"rind":{"rind","rinded","rinding","rinds"},
"rinderpest":{"rinderpest","rinderpests"},
"ring":{"rang","ring","ringed","ringing","rings","rung"},
"ring-around-a-rosy":{"ring-around-a-rosies","ring-around-a-rosy"},
"ring-around-the-rosy":{"ring-around-the-rosies","ring-around-the-rosy"},
"ring-binder":{"ring-binder","ring-binders"},
"ringdove":{"ringdove","ringdoves"},
"ringer":{"ringer","ringers"},
"ringhals":{"ringhals","ringhalses"},
"ringing":{"ringing","ringings"},
"ringleader":{"ringleader","ringleaders"},
"ringlet":{"ringlet","ringlets"},
"ringside":{"ringside","ringsides"},
"ringtail":{"ringtail","ringtails"},
"ringworm":{"ringworm","ringworms"},
"rink":{"rink","rinks"},
"rinkhals":{"rinkhals","rinkhalses"},
"rinse":{"rinse","rinsed","rinses","rinsing"},
"rinsing":{"rinsing","rinsings"},
"rio":{"rio","rios"},
"riot":{"riot","rioted","rioting","riots"},
"rioting":{"rioting","riotings"},
"rip":{"rip","ripped","ripping","rips"},
"rip-off":{"rip-off","rip-offs"},
"riparia":{"riparia","riparias"},
"ripe":{"ripe","riper","ripest"},
"ripen":{"ripen","ripened","ripening"},
"ripening":{"ripening","ripenings"},
"riposte":{"riposte","riposted","ripostes","riposting"},
"ripple":{"ripple","rippled","ripples","rippling"},
"ripple-grass":{"ripple-grass","ripple-grasses"},
"rippling":{"rippling","ripplings"},
"ripsaw":{"ripsaw","ripsaws"},
"riptide":{"riptide","riptides"},
"risc":{"risc","riscs"},
"rise":{"rise","risen","rises","rising","rose"},
"risibility":{"risibilities","risibility"},
"rising":{"rising","risings"},
"risk":{"risk","risked","risking","risks"},
"riskiness":{"riskiness","riskinesses"},
"risking":{"risking","riskings"},
"risky":{"riskier","riskiest","risky"},
"risotto":{"risotto","risottos"},
"rissa":{"rissa","rissas"},
"ritalin":{"ritalin","ritalins"},
"rite":{"rite","rites"},
"ritornello":{"ritornello","ritornellos"},
"ritual":{"ritual","rituals"},
"ritzy":{"ritzier","ritziest","ritzy"},
"rival":{"rival","rivaled","rivaling","rivalled","rivalling","rivals"},
"rivalry":{"rivalries","rivalry"},
"rive":{"rive","rived","riven","rives","riving"},
"river":{"river","rivers"},
"riverbank":{"riverbank","riverbanks"},
"riverbed":{"riverbed","riverbeds"},
"riverside":{"riverside","riversides"},
"rivet":{"rivet","riveted","riveting","rivets","rivetted","rivetting"},
"riveter":{"riveter","riveters"},
"rivetter":{"rivetter","rivetters"},
"rivina":{"rivina","rivinas"},
"rivulet":{"rivulet","rivulets"},
"riyadh":{"riyadh","riyadhs"},
"riyal":{"riyal","riyals"},
"rn":{"rn","rns"},
"rna":{"rna","rnas"},
"roach":{"roach","roaches"},
"road":{"road","roads"},
"roadblock":{"roadblock","roadblocks"},
"roadhog":{"roadhog","roadhogs"},
"roadhouse":{"roadhouse","roadhouses"},
"roadman":{"roadman","roadmen"},
"roadrunner":{"roadrunner","roadrunners"},
"roads":{"roads","roadses"},
"roadside":{"roadside","roadsides"},
"roadstead":{"roadstead","roadsteads"},
"roadster":{"roadster","roadsters"},
"roadway":{"roadway","roadways"},
"roam":{"roam","roamed","roaming","roams"},
"roamer":{"roamer","roamers"},
"roan":{"roan","roans"},
"roar":{"roar","roared","roaring","roars"},
"roarer":{"roarer","roarers"},
"roaring":{"roaring","roarings"},
"roast":{"roast","roasted","roasting","roasts"},
"rob":{"rob","robbed","robbing","robs"},
"robalo":{"robalo","robalos"},
"robaxin":{"robaxin","robaxins"},
"robber":{"robber","robbers"},
"robbery":{"robberies","robbery"},
"robe":{"robe","robed","robes","robing"},
"robe-de-chambre":{"robe-de-chambre","robe-de-chambres"},
"roberts":{"roberts","robertses"},
"robin":{"robin","robins"},
"robinia":{"robinia","robinias"},
"roble":{"roble","robles"},
"robot":{"robot","robots"},
"robotize":{"robotize","robotized","robotizing"},
"robustness":{"robustness","robustnesses"},
"rocambole":{"rocambole","rocamboles"},
"roccella":{"roccella","roccellas"},
"roccellaceae":{"roccellaceae","roccellaceaes"},
"roccus":{"roccus","roccuses"},
"rocephin":{"rocephin","rocephins"},
"rock":{"rock","rocked","rocking","rocks"},
"rockchuck":{"rockchuck","rockchucks"},
"rockcress":{"rockcress","rockcresses"},
"rocker":{"rocker","rockers"},
"rockery":{"rockeries","rockery"},
"rocket":{"rocket","rocketed","rocketing","rockets"},
"rockfish":{"rochfish","rockfish","rockfishes"},
"rockfoil":{"rockfoil","rockfoils"},
"rockies":{"rockies","rockieses"},
"rockling":{"rockling","rocklings"},
"rockrose":{"rockrose","rockroses"},
"rocky":{"rockier","rockiest","rocky"},
"rocroi":{"rocroi","rocrois"},
"rod":{"rod","rods"},
"rodent":{"rodent","rodents"},
"rodentia":{"rodentia","rodentias"},
"rodeo":{"rodeo","rodeos"},
"rodolia":{"rodolia","rodolias"},
"rodomontade":{"rodomontade","rodomontades"},
"roe":{"roe","roes"},
"roebuck":{"roebuck","roebucks"},
"roentgen":{"roentgen","roentgens"},
"roentgenogram":{"roentgenogram","roentgenograms"},
"roentgenoscope":{"roentgenoscope","roentgenoscopes"},
"rogaine":{"rogaine","rogaines"},
"rogue":{"rogue","rogued","rogues","roguing"},
"roguery":{"rogueries","roguery"},
"roguishness":{"roguishness","roguishnesses"},
"roil":{"roil","roiled","roiling","roils"},
"roily":{"roilier","roiliest","roily"},
"roister":{"roister","roistered","roistering","roisters"},
"role":{"role","roles"},
"roll":{"roll","rolled","rolling","rolls"},
"rollback":{"rollback","rollbacks"},
"rollcall":{"rollcall","rollcalls"},
"roller":{"roller","rollers"},
"roller-skate":{"roller-skate","roller-skated","roller-skating"},
"rollick":{"rollick","rollicked","rollicking","rollicks"},
"rolling":{"rolling","rollings"},
"roly-poly":{"roly-polies","roly-poly"},
"rolypoliness":{"rolypoliness","rolypolinesses"},
"rom":{"rom","roms"},
"roma":{"roma","romas"},
"romaic":{"romaic","romaics"},
"romaine":{"romaine","romaines"},
"roman":{"roman","romen"},
"roman-fleuve":{"roman-fleuve","romans-fleuves"},
"romance":{"romance","romanced","romances","romancing"},
"romanesque":{"romanesque","romanesques"},
"romania":{"romania","romanias"},
"romanism":{"romanism","romanisms"},
"romanize":{"romanize","romanized","romanizes","romanizing"},
"romanoff":{"romanoff","romanoffs"},
"romanov":{"romanov","romanovs"},
"romantic":{"romantic","romantics"},
"romanticisation":{"romanticisation","romanticisations"},
"romanticism":{"romanticism","romanticisms"},
"romanticist":{"romanticist","romanticists"},
"romanticization":{"romanticization","romanticizations"},
"romanticize":{"romanticize","romanticized","romanticizes","romanticizing"},
"romany":{"romanies","romany"},
"rome":{"rome","romes"},
"romeo":{"romeo","romeos"},
"rommany":{"romanies","rommanies","rommany"},
"rommel":{"rommel","rommels"},
"romneya":{"romneya","romneyas"},
"romp":{"romp","romped","romping","romps"},
"ron":{"ron","rons"},
"rondeau":{"rondeau","rondeaus","rondeaux"},
"rondel":{"rondel","rondels"},
"rondo":{"rondo","rondos"},
"roneo":{"roneo","roneos"},
"roneograph":{"roneograph","roneographs"},
"rood":{"rood","roods"},
"rood-tree":{"rood-tree","rood-trees"},
"roof":{"roof","roofed","roofing","roofs"},
"rooftree":{"rooftree","rooftrees"},
"rooibos":{"rooibos","rooiboses"},
"rook":{"rook","rooked","rooking","rooks"},
"rookery":{"rookeries","rookery"},
"rookie":{"rookie","rookies"},
"rooky":{"rookier","rookiest","rooky"},
"room":{"room","roomed","rooming","rooms"},
"roomer":{"roomer","roomers"},
"roomful":{"roomful","roomfuls"},
"roominess":{"roominess","roominesses"},
"rooms":{"rooms","roomses"},
"roomy":{"roomier","roomiest","roomy"},
"roosevelt":{"roosevelt","roosevelts"},
"roost":{"roost","roosted","roosting","roosts"},
"rooster":{"rooster","roosters"},
"root":{"root","rooted","rooting","roots"},
"rootstalk":{"rootstalk","rootstalks"},
"rootstock":{"rootstock","rootstocks"},
"rooty":{"rootier","rootiest","rooty"},
"rope":{"rope","roped","ropes","roping"},
"ropebark":{"ropebark","ropebarks"},
"ropedancer":{"ropedancer","ropedancers"},
"ropery":{"roperies","ropery"},
"ropewalk":{"ropewalk","ropewalks"},
"ropewalker":{"ropewalker","ropewalkers"},
"ropeway":{"ropeway","ropeways"},
"ropiness":{"ropiness","ropinesses"},
"ropy":{"ropier","ropiest","ropy"},
"roquet":{"roquet","roqueted","roqueting","roquets"},
"roquette":{"roquette","roquettes"},
"roridulaceae":{"roridulaceae","roridulaceaes"},
"rorippa":{"rorippa","rorippas"},
"rorqual":{"rorqual","rorquals"},
"rosa":{"rosa","rosas"},
"rosacea":{"rosacea","rosaceas"},
"rosaceae":{"rosaceae","rosaceaes"},
"rosales":{"rosales","rosaleses"},
"rosarium":{"rosarium","rosarsaria","rosarsariums"},
"rosary":{"rosaries","rosary"},
"rose":{"rose","rosed","roses","rosing"},
"rose-root":{"rose-root","rose-roots"},
"rosebay":{"rosebay","rosebays"},
"rosebud":{"rosebud","rosebuds"},
"rosefish":{"rosefish","rosefishes"},
"roselle":{"roselle","roselles"},
"rosellinia":{"rosellinia","rosellinias"},
"rosemary":{"rosemaries","rosemary"},
"rosery":{"roseries","rosery"},
"rosette":{"rosette","rosettes"},
"rosewood":{"rosewood","rosewoods"},
"rosidae":{"rosidae","rosidaes"},
"rosilla":{"rosilla","rosillas"},
"rosin":{"rosin","rosined","rosining","rosins"},
"rosiness":{"rosiness","rosinesses"},
"rosinweed":{"rosinweed","rosinweeds"},
"rosita":{"rosita","rositas"},
"rosmarinus":{"rosmarinus","rosmarinuses"},
"ross":{"ross","rosses"},
"rossbach":{"rossbach","rossbaches"},
"rossetti":{"rossetti","rossettis"},
"rossini":{"rossini","rossinis"},
"rostellum":{"rostella","rostellum"},
"roster":{"roster","rosters"},
"rostov":{"rostov","rostovs"},
"rostrum":{"rostra","rostrum","rostrums"},
"rosy":{"rosier","rosiest","rosy"},
"rot":{"rot","rots","rotted","rotting"},
"rota":{"rota","rotas"},
"rotary":{"rotaries","rotary"},
"rotate":{"rotate","rotated","rotates","rotating"},
"rotation":{"rotation","rotations"},
"rotator":{"rotator","rotatores","rotators"},
"rotc":{"rotc","rotcs"},
"rote":{"rote","rotes"},
"rotifera":{"rotifera","rotiferas"},
"rotl":{"artal","rotl","rotls"},
"rotogravure":{"rotogravure","rotogravures"},
"rotor":{"rotor","rotors"},
"rotten":{"rotten","rottener","rottenest"},
"rottenness":{"rottenness","rottennesses"},
"rotter":{"rotter","rotters"},
"rotting":{"rotting","rottings"},
"rotunda":{"rotunda","rotundas"},
"rotundity":{"rotundities","rotundity"},
"rouble":{"rouble","roubles"},
"roue":{"roue","roues"},
"rouge":{"rouge","rouged","rouges","rouging"},
"rougeberry":{"rougeberries","rougeberry"},
"rough":{"rough","roughed","rougher","roughest","roughing","roughs"},
"rough-and-tumble":{"rough-and-tumble","rough-and-tumbles"},
"rough-dry":{"rough-dried","rough-dries","rough-dry","rough-drying"},
"rough-hew":{"rough-hew","rough-hewed","rough-hewing","rough-hewn","rough-hews"},
"roughcast":{"roughcast","roughcasting","roughcasts"},
"roughen":{"roughen","roughened","roughening"},
"roughhew":{"roughhew","roughhewed","roughhewing","roughhewn"},
"roughhouse":{"roughhouse","roughhoused","roughhouses","roughhousing"},
"roughleg":{"roughleg","roughlegs"},
"roughneck":{"roughneck","roughnecks"},
"roughness":{"roughness","roughnesses"},
"rouleau":{"rouleau","rouleaus","rouleaux"},
"roulette":{"roulette","roulettes"},
"roumania":{"roumania","roumanias"},
"round":{"round","rounded","rounder","roundest","rounding","rounds"},
"roundabout":{"roundabout","roundabouts"},
"roundedness":{"roundedness","roundednesses"},
"roundel":{"roundel","roundels"},
"roundhouse":{"roundhouse","roundhouses"},
"roundsman":{"roundsman","roundsmen"},
"roundtable":{"roundtable","roundtables"},
"roundtrip":{"roundtrip","roundtrips"},
"roundworm":{"roundworm","roundworms"},
"rouse":{"rouse","roused","rouses","rousing"},
"rousing":{"rousing","rousings"},
"rousseau":{"rousseau","rousseaus"},
"roust":{"roust","rousted","rousting"},
"roustabout":{"roustabout","roustabouts"},
"rout":{"rout","routed","routing","routs"},
"route":{"route","routed","routeing","routes","routing"},
"routine":{"routine","routines"},
"rove":{"rove","roved","roves","roving"},
"rover":{"rover","rovers"},
"roving":{"roving","rovings"},
"row":{"row","rowed","rowing","rows"},
"rowan":{"rowan","rowans"},
"rowboat":{"rowboat","rowboats"},
"rowdiness":{"rowdiness","rowdinesses"},
"rowdy":{"rowdier","rowdies","rowdiest","rowdy"},
"rowdyism":{"rowdyism","rowdyisms"},
"rowel":{"rowel","roweled","roweling","rowelled","rowelling","rowels"},
"rower":{"rower","rowers"},
"rowing":{"rowing","rowings"},
"rowlock":{"rowlock","rowlocks"},
"royal":{"royal","royals"},
"royalist":{"royalist","royalists"},
"royalty":{"royalties","royalty"},
"roystonea":{"roystonea","roystoneas"},
"rozelle":{"rozelle","rozelles"},
"rpm":{"rpm","rpms"},
"rtlt":{"rtlt","rtlts"},
"ru":{"ru","rus"},
"ruanda":{"ruanda","ruandas"},
"rub":{"rub","rubbed","rubbing","rubs"},
"rub-a-dub":{"rub-a-dub","rub-a-dubs"},
"rubato":{"rubati","rubato","rubatos"},
"rubber":{"rubber","rubbered","rubbering","rubbers"},
"rubber-necking":{"rubber-necking","rubber-neckings"},
"rubberize":{"rubberize","rubberized","rubberizes","rubberizing"},
"rubberneck":{"rubberneck","rubbernecked","rubbernecking","rubbernecks"},
"rubbing":{"rubbing","rubbings"},
"rubbish":{"rubbish","rubbishes"},
"rubble":{"rubble","rubbles"},
"rubby":{"rubbies","rubby"},
"rube":{"rube","rubes"},
"rubella":{"rubella","rubellas"},
"rubeola":{"rubeola","rubeolas"},
"rubia":{"rubia","rubias"},
"rubiaceae":{"rubiaceae","rubiaceaes"},
"rubiales":{"rubiales","rubialeses"},
"rubicon":{"rubicon","rubicons"},
"rubidium":{"rubidium","rubidiums"},
"ruble":{"ruble","rubles"},
"rubric":{"rubric","rubrics"},
"rubus":{"rubus","rubuses"},
"ruby":{"rubied","rubies","ruby","rubying"},
"ruck":{"ruck","rucked","rucking","rucks"},
"rucksack":{"rucksack","rucksacks"},
"ruckus":{"ruckus","ruckuses"},
"ruction":{"ruction","ructions"},
"rudapithecus":{"rudapithecus","rudapithecuses"},
"rudbeckia":{"rudbeckia","rudbeckias"},
"rudd":{"rudd","rudds"},
"rudder":{"rudder","rudders"},
"rudderfish":{"rudderfish","rudderfishes"},
"rudderpost":{"rudderpost","rudderposts"},
"rudderstock":{"rudderstock","rudderstocks"},
"ruddiness":{"ruddiness","ruddinesses"},
"ruddle":{"ruddle","ruddled","ruddles","ruddling"},
"ruddles":{"ruddles","ruddleses"},
"ruddy":{"ruddier","ruddiest","ruddy"},
"rude":{"rude","ruder","rudest"},
"rudeness":{"rudeness","rudenesses"},
"rudiment":{"rudiment","rudiments"},
"rudiments":{"rudiments","rudimentses"},
"rue":{"rue","rued","rues","ruing"},
"ruefulness":{"ruefulness","ruefulnesses"},
"ruff":{"ruff","ruffs"},
"ruffian":{"ruffian","ruffians"},
"ruffle":{"ruffle","ruffled","ruffles","ruffling"},
"rug":{"rug","rugs"},
"ruga":{"ruga","rugae"},
"rugby":{"rugbies","rugby"},
"ruggedisation":{"ruggedisation","ruggedisations"},
"ruggedization":{"ruggedization","ruggedizations"},
"ruggedize":{"ruggedize","ruggedized","ruggedizes","ruggedizing"},
"ruggedness":{"ruggedness","ruggednesses"},
"rugger":{"rugger","ruggers"},
"ruhr":{"ruhr","ruhrs"},
"ruin":{"ruin","ruined","ruining","ruins"},
"ruination":{"ruination","ruinations"},
"ruiner":{"ruiner","ruiners"},
"ruining":{"ruining","ruinings"},
"rule":{"rule","ruled","rules","ruling"},
"ruler":{"ruler","rulers"},
"ruling":{"ruling","rulings"},
"rum":{"rum","rummer","rummest","rums"},
"rumania":{"rumania","rumanias"},
"rumba":{"rumba","rumbas"},
"rumble":{"rumble","rumbled","rumbles","rumbling"},
"rumbling":{"rumbling","rumblings"},
"rumen":{"rumen","rumens","rumina"},
"rumex":{"rumex","rumexes"},
"ruminantia":{"ruminantia","ruminantias"},
"ruminate":{"ruminate","ruminated","ruminates","ruminating"},
"rumination":{"rumination","ruminations"},
"rummage":{"rummage","rummaged","rummages","rummaging"},
"rummy":{"rummies","rummy"},
"rumohra":{"rumohra","rumohras"},
"rumor":{"rumor","rumored","rumoring","rumors"},
"rumormonger":{"rumormonger","rumormongers"},
"rumour":{"rumour","rumoured","rumouring","rumours"},
"rumourmonger":{"rumourmonger","rumourmongers"},
"rump":{"rump","rumps"},
"rumple":{"rumple","rumpled","rumples","rumpling"},
"rumpus":{"rumpus","rumpuses"},
"rumrunner":{"rumrunner","rumrunners"},
"run":{"ran","run","running","runs"},
"run-in":{"run-in","run-ins"},
"runabout":{"runabout","runabouts"},
"runaway":{"runaway","runaways"},
"runch":{"runch","runches"},
"rundle":{"rundle","rundles"},
"rundown":{"rundown","rundowns"},
"rundstedt":{"rundstedt","rundstedts"},
"rune":{"rune","runes"},
"rung":{"rung","rungs"},
"runnel":{"runnel","runnels"},
"runner":{"runner","runners"},
"runner-up":{"runner-up","runner-ups","runners-up"},
"runniness":{"runniness","runninesses"},
"running":{"running","runnings"},
"runny":{"runnier","runniest","runny"},
"runoff":{"runoff","runoffs"},
"runt":{"runt","runts"},
"runtiness":{"runtiness","runtinesses"},
"runty":{"runtier","runtiest","runty"},
"runway":{"runway","runways"},
"rupee":{"rupee","rupees"},
"rupert":{"rupert","ruperts"},
"rupiah":{"rupiah","rupiahs"},
"rupicapra":{"rupicapra","rupicapras"},
"rupicola":{"rupicola","rupicolas"},
"ruptiliocarpon":{"ruptiliocarpon","ruptiliocarpons"},
"rupture":{"rupture","ruptured","ruptures","rupturing"},
"rupturewort":{"rupturewort","ruptureworts"},
"ruralize":{"ruralize","ruralized","ruralizing"},
"ruscaceae":{"ruscaceae","ruscaceaes"},
"ruscus":{"ruscus","ruscuses"},
"ruse":{"ruse","ruses"},
"rush":{"rush","rushed","rushes","rushing"},
"rushing":{"rushing","rushings"},
"rushlight":{"rushlight","rushlights"},
"rushmore":{"rushmore","rushmores"},
"rushy":{"rushier","rushiest","rushy"},
"rusk":{"rusk","rusks"},
"russ":{"russ","russes"},
"russell":{"russell","russells"},
"russet":{"russet","russets"},
"russia":{"russia","russias"},
"russianize":{"russianize","russianized","russianizes","russianizing"},
"russki":{"russki","russkis"},
"russky":{"russkies","russky"},
"russula":{"russula","russulas"},
"russulaceae":{"russulaceae","russulaceaes"},
"rust":{"rust","rusted","rusting","rusts"},
"rustic":{"rustic","rustics"},
"rusticate":{"rusticate","rusticated","rusticates","rusticating"},
"rusticity":{"rusticities","rusticity"},
"rusting":{"rusting","rustings"},
"rustle":{"rustle","rustled","rustles","rustling"},
"rustler":{"rustler","rustlers"},
"rustling":{"rustling","rustlings"},
"rusty":{"rustier","rustiest","rusty"},
"rut":{"rut","ruts","rutted","rutting"},
"ruta":{"ruta","rutas"},
"rutabaga":{"rutabaga","rutabagas"},
"rutaceae":{"rutaceae","rutaceaes"},
"ruth":{"ruth","ruths"},
"ruthenium":{"ruthenium","rutheniums"},
"rutherfordium":{"rutherfordium","rutherfordiums"},
"ruthfulness":{"ruthfulness","ruthfulnesses"},
"ruthlessness":{"ruthlessness","ruthlessnesses"},
"rutilus":{"rutilus","rutiluses"},
"rutty":{"ruttier","ruttiest","rutty"},
"rv":{"rv","rvs"},
"rwanda":{"rwanda","rwandas"},
"rx":{"rx","rxs"},
"rya":{"rya","ryas"},
"rydberg":{"rydberg","rydbergs"},
"rye":{"rye","ryes"},
"ryegrass":{"ryegrass","ryegrasses"},
"rynchopidae":{"rynchopidae","rynchopidaes"},
"rynchops":{"rynchops","rynchopses"},
"rypticus":{"rypticus","rypticuses"},
"s":{"s","ses"},
"s/n":{"s/n","s/ns"},
"sabah":{"sabah","sabahs"},
"sabal":{"sabal","sabals"},
"sabaton":{"sabaton","sabatons"},
"sabayon":{"sabayon","sabayons"},
"sabbat":{"sabbat","sabbats"},
"sabbatical":{"sabbatical","sabbaticals"},
"saber":{"saber","sabered","sabering","sabers"},
"sabertooth":{"saberteeth","sabertooth"},
"sabicu":{"sabicu","sabicus"},
"sabine":{"sabine","sabines"},
"sabinea":{"sabinea","sabineas"},
"sable":{"sable","sables"},
"sabot":{"sabot","sabots"},
"sabotage":{"sabotage","sabotaged","sabotages","sabotaging"},
"saboteur":{"saboteur","saboteurs"},
"sabra":{"sabra","sabras"},
"sabre":{"sabre","sabred","sabres","sabring"},
"sac":{"sac","sacs"},
"saccharide":{"saccharide","saccharides"},
"saccharify":{"saccharified","saccharifies","saccharify","saccharifying"},
"saccharomyces":{"saccharomyces","saccharomyceses"},
"saccharomycetaceae":{"saccharomycetaceae","saccharomycetaceaes"},
"saccharose":{"saccharose","saccharoses"},
"saccharum":{"saccharum","saccharums"},
"saccule":{"saccule","saccules"},
"sacculus":{"sacculus","sacculuses"},
"sachsen":{"sachsen","sachsens"},
"sack":{"sack","sacked","sacking","sacks"},
"sackful":{"sackful","sackfuls"},
"sacking":{"sacking","sackings"},
"sacque":{"sacque","sacques"},
"sacralize":{"sacralize","sacralized","sacralizing"},
"sacrament":{"sacrament","sacraments"},
"sacramento":{"sacramento","sacramentos"},
"sacrarium":{"sacrarcraria","sacraria","sacrarium"},
"sacrifice":{"sacrifice","sacrificed","sacrifices","sacrificing"},
"sacrilege":{"sacrilege","sacrileges"},
"sacristan":{"sacristan","sacristans"},
"sacristy":{"sacristies","sacristy"},
"sacrum":{"sacra","sacrum"},
"sad":{"sad","sadder","saddest","sads"},
"sadden":{"sadden","saddened","saddening","saddens"},
"saddhu":{"saddhu","saddhus"},
"saddle":{"saddle","saddled","saddles","saddling"},
"saddleback":{"saddleback","saddlebacks"},
"saddlebill":{"saddlebill","saddlebills"},
"saddlebow":{"saddlebow","saddlebows"},
"saddlecloth":{"saddlecloth","saddlecloths"},
"saddlecoth":{"saddlecoth","saddlecoths"},
"saddlery":{"saddleries","saddlery"},
"sadducee":{"sadducee","sadducees"},
"sade":{"sade","sades"},
"sadhu":{"sadhu","sadhus"},
"sadleria":{"sadleria","sadlerias"},
"sadness":{"sadness","sadnesses"},
"safari":{"safari","safaris"},
"safe":{"safe","safer","safes","safest"},
"safe-deposit":{"safe-deposit","safe-deposits"},
"safebreaker":{"safebreaker","safebreakers"},
"safecracker":{"safecracker","safecrackers"},
"safeguard":{"safeguard","safeguarded","safeguarding","safeguards"},
"safekeeping":{"safekeeping","safekeepings"},
"safety":{"safeties","safety"},
"safety-deposit":{"safety-deposit","safety-deposits"},
"safflower":{"safflower","safflowers"},
"saffron":{"saffron","saffrons"},
"sag":{"sag","sagged","sagging","sags"},
"saga":{"saga","sagas"},
"sagaciousness":{"sagaciousness","sagaciousnesses"},
"sagacity":{"sagacities","sagacity"},
"sage":{"sage","sager","sages","sagest"},
"sagebrush":{"sagebrush","sagebrushes"},
"saggy":{"saggier","saggiest","saggy"},
"sagina":{"sagina","saginas"},
"sagittaria":{"sagittaria","sagittarias"},
"sagittariidae":{"sagittariidae","sagittariidaes"},
"sagittarius":{"sagittarius","sagittariuses"},
"sagittate-leaf":{"sagittate-leaf","sagittate-leaves"},
"saguaro":{"saguaro","saguaros"},
"sahaptan":{"sahaptan","sahaptans"},
"sahaptian":{"sahaptian","sahaptians"},
"sahaptin":{"sahaptin","sahaptins"},
"sahara":{"sahara","saharas"},
"sahuaro":{"saguaros","sahuaro","sahuaros"},
"saiga":{"saiga","saigas"},
"saigon":{"saigon","saigons"},
"sail":{"sail","sailed","sailing","sails"},
"sailboat":{"sailboat","sailboats"},
"sailfish":{"sailfish","sailfishes"},
"sailing":{"sailing","sailings"},
"sailing-race":{"sailing-race","sailing-races"},
"sailor":{"sailor","sailors"},
"sailplane":{"sailplane","sailplanes"},
"sailplaning":{"sailplaning","sailplanings"},
"saimiri":{"saimiri","saimiris"},
"sainfoin":{"sainfoin","sainfoins"},
"saint":{"saint","sainted","sainting","saints"},
"saint-mihiel":{"saint-mihiel","saint-mihiels"},
"saintly":{"saintlier","saintliest","saintly"},
"saintpaulia":{"saintpaulia","saintpaulias"},
"sakartvelo":{"sakartvelo","sakartvelos"},
"sake":{"sake","sakes"},
"saki":{"saki","sakis"},
"sakkara":{"sakkara","sakkaras"},
"sakti":{"sakti","saktis"},
"saktism":{"saktism","saktisms"},
"salaam":{"salaam","salaamed","salaaming"},
"salaciousness":{"salaciousness","salaciousnesses"},
"salacity":{"salacities","salacity"},
"salad":{"salad","salads"},
"salai":{"salai","salais"},
"salal":{"salal","salals"},
"salamander":{"salamander","salamanders"},
"salamandra":{"salamandra","salamandras"},
"salamandridae":{"salamandridae","salamandridaes"},
"salami":{"salami","salamis"},
"salary":{"salaried","salaries","salary","salarying"},
"sale":{"sale","sales"},
"salem":{"salem","salems"},
"saleratus":{"saleratus","saleratuses"},
"saleroom":{"saleroom","salerooms"},
"sales":{"sales","saleses"},
"salesclerk":{"salesclerk","salesclerks"},
"salesgirl":{"salesgirl","salesgirls"},
"saleslady":{"salesladies","saleslady"},
"salesman":{"salesman","salesmen"},
"salesroom":{"salesroom","salesrooms"},
"saleswoman":{"saleswoman","saleswomen"},
"salian":{"salian","salians"},
"salicaceae":{"salicaceae","salicaceaes"},
"salicales":{"salicales","salicaleses"},
"salicornia":{"salicornia","salicornias"},
"salience":{"salience","saliences"},
"saliency":{"saliencies","saliency"},
"salient":{"salient","salients"},
"salientia":{"salientia","salientias"},
"salientian":{"salientian","salientians"},
"salify":{"salified","salifies","salify","salifying"},
"salina":{"salina","salinas"},
"saline":{"saline","salines"},
"salinity":{"salinities","salinity"},
"salisbury":{"salisburies","salisbury"},
"salish":{"salish","salishes"},
"salishan":{"salishan","salishans"},
"saliva":{"saliva","salivas"},
"salivate":{"salivate","salivated","salivating"},
"salix":{"salix","salixes"},
"sallade":{"sallade","sallades"},
"sallet":{"sallet","sallets"},
"sallow":{"sallow","sallowed","sallower","sallowest","sallowing","sallows"},
"sally":{"sallied","sallies","sally","sallying"},
"salmi":{"salmi","salmis"},
"salmo":{"salmo","salmos"},
"salmon":{"salmon","salmons"},
"salmonberry":{"salmonberries","salmonberry"},
"salmonella":{"salmonella","salmonellae","salmonellas"},
"salmonidae":{"salmonidae","salmonidaes"},
"salmwood":{"salmwood","salmwoods"},
"salol":{"salol","salols"},
"salon":{"salon","salons"},
"salonika":{"salonika","salonikas"},
"saloon":{"saloon","saloons"},
"salp":{"salp","salps"},
"salpa":{"salpa","salpas"},
"salpichroa":{"salpichroa","salpichroas"},
"salpidae":{"salpidae","salpidaes"},
"salpinctes":{"salpinctes","salpincteses"},
"salpingectomy":{"salpingectomies","salpingectomy"},
"salpinx":{"salpinges","salpinx"},
"salsify":{"salsifies","salsify"},
"salsilla":{"salsilla","salsillas"},
"salsola":{"salsola","salsolas"},
"salt":{"salt","salted","salting","salts"},
"saltarello":{"saltarelli","saltarello","saltarellos"},
"saltiness":{"saltiness","saltinesses"},
"saltire":{"saltire","saltires"},
"saltpeter":{"saltpeter","saltpeters"},
"saltpetre":{"saltpetre","saltpetres"},
"saltshaker":{"saltshaker","saltshakers"},
"saltus":{"saltus","saltuses"},
"saltwater":{"saltwater","saltwaters"},
"saltwort":{"saltwort","saltworts"},
"salty":{"saltier","saltiest","salty"},
"salubriousness":{"salubriousness","salubriousnesses"},
"salubrity":{"salubrities","salubrity"},
"saluki":{"saluki","salukis"},
"salutation":{"salutation","salutations"},
"salutatorian":{"salutatorian","salutatorians"},
"salutatory":{"salutatories","salutatory"},
"salute":{"salute","saluted","salutes","saluting"},
"salvador":{"salvador","salvadors"},
"salvadoran":{"salvadoran","salvadorans"},
"salvadorean":{"salvadorean","salvadoreans"},
"salvadorian":{"salvadorian","salvadorians"},
"salvage":{"salvage","salvaged","salvages","salvaging"},
"salvager":{"salvager","salvagers"},
"salvation":{"salvation","salvations"},
"salve":{"salve","salved","salves","salving"},
"salvelinus":{"salvelinus","salvelinuses"},
"salvia":{"salvia","salvias"},
"salvinia":{"salvinia","salvinias"},
"salviniaceae":{"salviniaceae","salviniaceaes"},
"salvo":{"salvo","salvoes","salvos"},
"salvor":{"salvor","salvors"},
"sam":{"sam","sams"},
"saman":{"saman","samen"},
"samara":{"samara","samaras"},
"samarcand":{"samarcand","samarcands"},
"samaritan":{"samaritan","samaritans"},
"samarium":{"samarium","samariums"},
"samarkand":{"samarkand","samarkands"},
"samba":{"samba","sambas"},
"sambar":{"sambar","sambars"},
"sambo":{"sambo","sambos"},
"sambucus":{"sambucus","sambucuses"},
"sambur":{"sambur","samburs"},
"sameness":{"sameness","samenesses"},
"samhita":{"samhita","samhitas"},
"sami":{"sami","samis"},
"samia":{"samia","samias"},
"samiel":{"samiel","samiels"},
"sammy":{"sammies","sammy"},
"samoa":{"samoa","samoas"},
"samolus":{"samolus","samoluses"},
"samoyed":{"samoyed","samoyeds"},
"samoyede":{"samoyede","samoyedes"},
"samoyedic":{"samoyedic","samoyedics"},
"samphire":{"samphire","samphires"},
"sample":{"sample","sampled","samples","sampling"},
"sampler":{"sampler","samplers"},
"samurai":{"samurai","samurairais"},
"sana":{"sana","sanas"},
"sanaa":{"sanaa","sanaas"},
"sanatarium":{"sanatarium","sanatariums"},
"sanatorium":{"sanatoria","sanatorium","sanatoriums"},
"sanbenito":{"sanbenito","sanbenitos"},
"sanctify":{"sanctified","sanctifies","sanctify","sanctifying"},
"sanctimoniousness":{"sanctimoniousness","sanctimoniousnesses"},
"sanctimony":{"sanctimonies","sanctimony"},
"sanction":{"sanction","sanctioned","sanctioning","sanctions"},
"sanctity":{"sanctities","sanctity"},
"sanctuary":{"sanctuaries","sanctuary"},
"sanctum":{"sancta","sanctum","sanctums"},
"sand":{"sand","sanded","sanding","sands"},
"sand-cast":{"sand-cast","sand-casting","sand-casts"},
"sandal":{"sandal","sandals"},
"sandarac":{"sandarac","sandaracs"},
"sandarach":{"sandarach","sandaraches"},
"sandbag":{"sandbag","sandbagged","sandbagging","sandbags"},
"sandbar":{"sandbar","sandbars"},
"sandberry":{"sandberries","sandberry"},
"sandblast":{"sandblast","sandblasted","sandblasting"},
"sandbox":{"sandbox","sandboxes"},
"sandbur":{"sandbur","sandburs"},
"sander":{"sander","sanders"},
"sanderling":{"sanderling","sanderlings"},
"sandfish":{"sandfish","sandfishes"},
"sandfly":{"sandflies","sandfly"},
"sandglass":{"sandglass","sandglasses"},
"sandgrouse":{"sandgrouse","sandgrouses"},
"sandhi":{"sandhi","sandhis"},
"sandhopper":{"sandhopper","sandhoppers"},
"sandman":{"sandman","sandmen"},
"sandpaper":{"sandpaper","sandpapered","sandpapering","sandpapers"},
"sandpile":{"sandpile","sandpiles"},
"sandril":{"sandril","sandrils"},
"sands":{"sands","sandses"},
"sandspur":{"sandspur","sandspurs"},
"sandstorm":{"sandstorm","sandstorms"},
"sandwich":{"sandwich","sandwiched","sandwiches","sandwiching"},
"sandwort":{"sandwort","sandworts"},
"sandy":{"sandier","sandiest","sandy"},
"sane":{"sane","saner","sanest"},
"saneness":{"saneness","sanenesses"},
"sanfoin":{"sanfoin","sanfoins"},
"sang":{"sang","sangs"},
"sang-froid":{"sang-froid","sang-froids"},
"sangapenum":{"sangapenum","sangapenums"},
"sangaree":{"sangaree","sangarees"},
"sangraal":{"sangraal","sangraals"},
"sangria":{"sangria","sangrias"},
"sanguinaria":{"sanguinaria","sanguinarias"},
"sanguineness":{"sanguineness","sanguinenesses"},
"sanguinity":{"sanguinities","sanguinity"},
"sanicle":{"sanicle","sanicles"},
"sanicula":{"sanicula","saniculas"},
"sanies":{"sanies","sanieses"},
"sanitarium":{"sanitaria","sanitarium","sanitariums"},
"sanitary":{"sanitaries","sanitary"},
"sanitation":{"sanitation","sanitations"},
"sanitisation":{"sanitisation","sanitisations"},
"sanitization":{"sanitization","sanitizations"},
"sanitize":{"sanitize","sanitized","sanitizes","sanitizing"},
"sanitizing":{"sanitizing","sanitizings"},
"sanity":{"sanities","sanity"},
"sansei":{"sansei","sanseis"},
"sansevieria":{"sansevieria","sansevierias"},
"sanskrit":{"sanskrit","sanskrits"},
"santalaceae":{"santalaceae","santalaceaes"},
"santalales":{"santalales","santalaleses"},
"santalum":{"santalum","santalums"},
"santee":{"santee","santees"},
"santiago":{"santiago","santiagos"},
"santolina":{"santolina","santolinas"},
"santonica":{"santonica","santonicas"},
"sanvitalia":{"sanvitalia","sanvitalias"},
"saone":{"saone","saones"},
"sap":{"sap","sapped","sapping","saps"},
"saphead":{"saphead","sapheads"},
"saphena":{"saphena","saphenae"},
"sapidity":{"sapidities","sapidity"},
"sapidness":{"sapidness","sapidnesses"},
"sapience":{"sapience","sapiences"},
"sapindaceae":{"sapindaceae","sapindaceaes"},
"sapindales":{"sapindales","sapindaleses"},
"sapindus":{"sapindus","sapinduses"},
"sapir":{"sapir","sapirs"},
"sapling":{"sapling","saplings"},
"sapodilla":{"sapodilla","sapodillas"},
"saponaria":{"saponaria","saponarias"},
"saponify":{"saponified","saponifies","saponify","saponifying"},
"sapota":{"sapota","sapotas"},
"sapotaceae":{"sapotaceae","sapotaceaes"},
"sapote":{"sapote","sapotes"},
"sapphire":{"sapphire","sapphires"},
"sapphism":{"sapphism","sapphisms"},
"sappy":{"sappier","sappiest","sappy"},
"sapraemia":{"sapraemia","sapraemias"},
"sapremia":{"sapremia","sapremias"},
"saprolegnia":{"saprolegnia","saprolegnias"},
"saprolegniales":{"saprolegniales","saprolegnialeses"},
"saprophyte":{"saprophyte","saprophytes"},
"saqqara":{"saqqara","saqqaras"},
"saqqarah":{"saqqarah","saqqarahs"},
"saragossa":{"saragossa","saragossas"},
"sarape":{"sarape","sarapes"},
"saratoga":{"saratoga","saratogas"},
"sarcasm":{"sarcasm","sarcasms"},
"sarcina":{"sarcina","sarcinae","sarcinas"},
"sarcobatus":{"sarcobatus","sarcobatuses"},
"sarcocephalus":{"sarcocephalus","sarcocephaluses"},
"sarcochilus":{"sarcochilus","sarcochiluses"},
"sarcocystidean":{"sarcocystidean","sarcocystideans"},
"sarcocystieian":{"sarcocystieian","sarcocystieians"},
"sarcocystis":{"sarcocystis","sarcocystises"},
"sarcodes":{"sarcodes","sarcodeses"},
"sarcodina":{"sarcodina","sarcodinas"},
"sarcodine":{"sarcodine","sarcodines"},
"sarcodinian":{"sarcodinian","sarcodinians"},
"sarcolemma":{"sarcolemma","sarcolemmas"},
"sarcoma":{"sarcoma","sarcomas","sarcomata"},
"sarcophaga":{"sarcophaga","sarcophagas"},
"sarcophagus":{"sarcophagi","sarcophagus","sarcophaguses"},
"sarcophilus":{"sarcophilus","sarcophiluses"},
"sarcoptes":{"sarcoptes","sarcopteses"},
"sarcoptid":{"sarcoptid","sarcoptids"},
"sarcoptidae":{"sarcoptidae","sarcoptidaes"},
"sarcorhamphus":{"sarcorhamphus","sarcorhamphuses"},
"sarcoscyphaceae":{"sarcoscyphaceae","sarcoscyphaceaes"},
"sarcosporidia":{"sarcosporidia","sarcosporidias"},
"sarcosporidian":{"sarcosporidian","sarcosporidians"},
"sarcostemma":{"sarcostemma","sarcostemmas"},
"sarcostyle":{"sarcostyle","sarcostyles"},
"sard":{"sard","sards"},
"sarda":{"sarda","sardas"},
"sardegna":{"sardegna","sardegnas"},
"sardina":{"sardina","sardinas"},
"sardine":{"sardine","sardines"},
"sardinia":{"sardinia","sardinias"},
"sardinops":{"sardinops","sardinopses"},
"sardius":{"sardius","sardiuses"},
"saree":{"saree","sarees"},
"sargasso":{"sargasso","sargassos"},
"sargassum":{"sargassum","sargassums"},
"sari":{"sari","saris"},
"sarpanitu":{"sarpanitu","sarpanitus"},
"sarracenia":{"sarracenia","sarracenias"},
"sarraceniaceae":{"sarraceniaceae","sarraceniaceaes"},
"sarraceniales":{"sarraceniales","sarracenialeses"},
"sarsaparilla":{"sarsaparilla","sarsaparillas"},
"sartor":{"sartor","sartors"},
"sartorius":{"sartorii","sartorius","sartoriuses"},
"sash":{"sash","sashed","sashes","sashing"},
"sashay":{"sashay","sashayed","sashaying","sashays"},
"saskatoon":{"saskatoon","saskatoons"},
"sasquatch":{"sasquatch","sasquatches"},
"sass":{"sass","sassed","sasses","sassing"},
"sassaby":{"sassabies","sassaby"},
"sassafras":{"sassafras","sassafrases"},
"sassanid":{"sassanid","sassasanidae","sassasanids"},
"sassing":{"sassing","sassings"},
"sassy":{"sassier","sassiest","sassy"},
"sat":{"sat","sats"},
"satan":{"satan","satans"},
"satanism":{"satanism","satanisms"},
"satanist":{"satanist","satanists"},
"satchel":{"satchel","satchels"},
"sate":{"sate","sated","sates","sating"},
"satellite":{"satellite","satellites"},
"satiate":{"satiate","satiated","satiates","satiating"},
"satiation":{"satiation","satiations"},
"satiety":{"satieties","satiety"},
"satinleaf":{"satinleaf","satinleaves"},
"satinpod":{"satinpod","satinpods"},
"satinwood":{"satinwood","satinwoods"},
"satire":{"satire","satires"},
"satirist":{"satirist","satirists"},
"satirize":{"satirize","satirized","satirizes","satirizing"},
"satisfaction":{"satisfaction","satisfactions"},
"satisfy":{"satisfied","satisfies","satisfy","satisfying"},
"satisfying":{"satisfying","satisfyings"},
"satrapy":{"satrapies","satrapy"},
"satsuma":{"satsuma","satsumas"},
"saturate":{"saturate","saturated","saturates","saturating"},
"saturation":{"saturation","saturations"},
"saturday":{"saturday","saturdays"},
"satureia":{"satureia","satureias"},
"satureja":{"satureja","saturejas"},
"saturnalia":{"saturnalia","saturnalias"},
"saturnia":{"saturnia","saturnias"},
"saturniid":{"saturniid","saturniids"},
"saturniidae":{"saturniidae","saturniidaes"},
"saturnism":{"saturnism","saturnisms"},
"satyr":{"satyr","satyrs"},
"sauce":{"sauce","sauced","sauces","saucing"},
"sauce-alone":{"sauce-alone","sauce-alones"},
"sauceboat":{"sauceboat","sauceboats"},
"saucepan":{"saucepan","saucepans"},
"saucer":{"saucer","saucers"},
"sauciness":{"sauciness","saucinesses"},
"saucy":{"sauccier","saucciest","saucier","sauciest","saucy"},
"saudi":{"saudi","saudis"},
"saul":{"saul","sauls"},
"sauna":{"sauna","saunas"},
"saunter":{"saunter","sauntered","sauntering","saunters"},
"saunterer":{"saunterer","saunterers"},
"saurel":{"saurel","saurels"},
"sauria":{"sauria","saurias"},
"saurischia":{"saurischia","saurischias"},
"saurischian":{"saurischian","saurischians"},
"sauromalus":{"sauromalus","sauromaluses"},
"sauropod":{"sauropod","sauropods"},
"sauropoda":{"sauropoda","sauropodas"},
"sauropodomorpha":{"sauropodomorpha","sauropodomorphas"},
"sauropterygia":{"sauropterygia","sauropterygias"},
"saurosuchus":{"saurosuchus","saurosuchuses"},
"saururaceae":{"saururaceae","saururaceaes"},
"saururus":{"saururus","saururuses"},
"saury":{"sauries","saury"},
"sausage":{"sausage","sausages"},
"saussurea":{"saussurea","saussureas"},
"saute":{"saute","sauteed","sauteing","sautes"},
"sauteing":{"sauteing","sauteings"},
"sauterne":{"sauterne","sauternes"},
"sauternes":{"sauternes","sauterneses"},
"savage":{"savage","savaged","savages","savaging"},
"savageness":{"savageness","savagenesses"},
"savagery":{"savageries","savagery"},
"savanna":{"savanna","savannas"},
"savannah":{"savannah","savannahs"},
"savant":{"savant","savants"},
"save":{"save","saved","saves","saving"},
"saver":{"saver","savers"},
"savin":{"savin","savins"},
"saving":{"saving","savings"},
"savings":{"savings","savingses"},
"savior":{"savior","saviors"},
"saviour":{"saviour","saviours"},
"savoir-faire":{"savoir-faire","savoir-faires"},
"savor":{"savor","savored","savoring","savors"},
"savoriness":{"savoriness","savorinesses"},
"savoring":{"savoring","savorings"},
"savorlessness":{"savorlessness","savorlessnesses"},
"savory":{"savorier","savories","savoriest","savory","savouries"},
"savour":{"savour","savours"},
"savoury":{"savourier","savouries","savouriest","savoury"},
"savoy":{"savoy","savoys"},
"savvy":{"savvied","savvies","savvy","savvying"},
"saw":{"saw","sawed","sawing","sawn","saws"},
"sawbill":{"sawbill","sawbills"},
"sawbones":{"sawbones","sawboneses"},
"sawbuck":{"sawbuck","sawbucks"},
"sawfish":{"sawfish","sawfishes"},
"sawfly":{"sawflies","sawfly"},
"sawhorse":{"sawhorse","sawhorses"},
"sawmill":{"sawmill","sawmills"},
"sawtooth":{"sawteeth","sawtooth"},
"sawwort":{"sawwort","sawworts"},
"sawyer":{"sawyer","sawyers"},
"sax":{"sax","saxes"},
"saxe":{"saxe","saxes"},
"saxe-gothea":{"saxe-gothea","saxe-gotheas"},
"saxegothea":{"saxegothea","saxegotheas"},
"saxicola":{"saxicola","saxicolas"},
"saxifraga":{"saxifraga","saxifragas"},
"saxifragaceae":{"saxifragaceae","saxifragaceaes"},
"saxifrage":{"saxifrage","saxifrages"},
"saxony":{"saxonies","saxony"},
"saxophone":{"saxophone","saxophones"},
"saxtuba":{"saxtuba","saxtubas"},
"say":{"said","say","saying","says"},
"say-so":{"say-so","say-sos"},
"sayanci":{"sayanci","sayancis"},
"saying":{"saying","sayings"},
"sayonara":{"sayonara","sayonaras"},
"sayornis":{"sayornis","sayornises"},
"sb":{"sb","sbs"},
"sbe":{"sbe","sbes"},
"sbw":{"sbw","sbws"},
"sc":{"sc","scs"},
"scab":{"scab","scabbed","scabbing","scabs"},
"scabbard":{"scabbard","scabbarded","scabbarding","scabbards"},
"scabble":{"scabble","scabbled","scabling"},
"scabby":{"scabbier","scabbiest","scabby"},
"scabies":{"scabies","scabieses"},
"scabiosa":{"scabiosa","scabiosas"},
"scabious":{"scabious","scabiouses"},
"scad":{"scad","scads"},
"scads":{"scads","scadses"},
"scaffold":{"scaffold","scaffolded","scaffolding","scaffolds"},
"scag":{"scag","scags"},
"scalade":{"scalade","scalades"},
"scalado":{"scalado","scalalados"},
"scalawag":{"scalawag","scalawags"},
"scald":{"scald","scalded","scalding","scalds"},
"scaldfish":{"scaldfish","scaldfishes"},
"scale":{"scale","scaled","scales","scaling"},
"scalenus":{"scaleni","scalenus","scalenuses"},
"scaling":{"scaling","scalings"},
"scallion":{"scallion","scallions"},
"scallop":{"scallop","scalloped","scalloping","scallops"},
"scalloper":{"scalloper","scallopers"},
"scallopine":{"scallopine","scallopines"},
"scallopini":{"scallopini","scallopinis"},
"scallywag":{"scallywag","scallywags"},
"scalp":{"scalp","scalped","scalping","scalps"},
"scaly":{"scalier","scaliest","scaly"},
"scam":{"scam","scams"},
"scammony":{"scammonies","scammony"},
"scammonyroot":{"scammonyroot","scammonyroots"},
"scamp":{"scamp","scamped","scamping","scamps"},
"scamper":{"scamper","scampered","scampering","scampers"},
"scampo":{"scampo","scampos"},
"scan":{"scan","scanned","scanning","scans"},
"scandal":{"scandal","scandals"},
"scandalisation":{"scandalisation","scandalisations"},
"scandalization":{"scandalization","scandalizations"},
"scandalize":{"scandalize","scandalized","scandalizes","scandalizing"},
"scandalmongering":{"scandalmongering","scandalmongerings"},
"scandentia":{"scandentia","scandentias"},
"scandinavia":{"scandinavia","scandinavias"},
"scandinavian":{"scandinavian","scandinavians"},
"scandium":{"scandium","scandiums"},
"scant":{"scant","scanted","scanter","scantest","scanting"},
"scantiness":{"scantiness","scantinesses"},
"scantling":{"scantling","scantlings"},
"scantness":{"scantness","scantnesses"},
"scanty":{"scantier","scanties","scantiest","scanty"},
"scape":{"scape","scapes"},
"scapegoat":{"scapegoat","scapegoats"},
"scapegrace":{"scapegrace","scapegraces"},
"scaphiopus":{"scaphiopus","scaphiopuses"},
"scaphopoda":{"scaphopoda","scaphopodas"},
"scaphosepalum":{"scaphosepalum","scaphosepalums"},
"scapula":{"scapula","scapulae","scapulas"},
"scapular":{"scapular","scapulars"},
"scapulary":{"scapularies","scapulary"},
"scar":{"scar","scarred","scarring","scars"},
"scarab":{"scarab","scarabs"},
"scarabaean":{"scarabaean","scarabaeans"},
"scarabaeid":{"scarabaeid","scarabaeids"},
"scarabaeidae":{"scarabaeidae","scarabaeidaes"},
"scarabaeus":{"scarabaeus","scarabaeuses"},
"scarce":{"scarce","scarcer","scarcest"},
"scarceness":{"scarceness","scarcenesses"},
"scarcity":{"scarcities","scarcity"},
"scardinius":{"scardinius","scardiniuses"},
"scare":{"scare","scared","scares","scaring"},
"scarecrow":{"scarecrow","scarecrows"},
"scaremonger":{"scaremonger","scaremongers"},
"scarf":{"scarf","scarfed","scarfing","scarfs","scarves"},
"scarfpin":{"scarfpin","scarfpins"},
"scaridae":{"scaridae","scaridaes"},
"scarify":{"scarified","scarifies","scarify","scarifying"},
"scarlatina":{"scarlatina","scarlatinas"},
"scarlet":{"scarlet","scarlets"},
"scarp":{"scarp","scarped","scarping","scarps"},
"scarper":{"scarper","scarpered","scarpering","scarpers"},
"scartella":{"scartella","scartellas"},
"scary":{"scarier","scariest","scary"},
"scat":{"scat","scats","scatted","scatting"},
"scathe":{"scathe","scathed","scathes","scathing"},
"scatter":{"scatter","scattered","scattering","scatters"},
"scatterbrain":{"scatterbrain","scatterbrains"},
"scattergun":{"scattergun","scatterguns"},
"scattering":{"scattering","scatterings"},
"scatty":{"scattier","scattiest","scatty"},
"scaup":{"scaup","scaups"},
"scavenge":{"scavenge","scavenged","scavenges","scavenging"},
"scavenger":{"scavenger","scavengers"},
"scd":{"scd","scds"},
"sceliphron":{"sceliphron","sceliphrons"},
"sceloglaux":{"sceloglaux","sceloglauxes"},
"sceloporus":{"sceloporus","sceloporuses"},
"scenario":{"scenario","scenarios"},
"scend":{"scend","scended","scending","scends"},
"scene":{"scene","scenes"},
"scenery":{"sceneries","scenery"},
"scent":{"scent","scented","scenting","scents"},
"scepter":{"scepter","sceptered","sceptering","scepters"},
"sceptic":{"sceptic","sceptics"},
"scepticism":{"scepticism","scepticisms"},
"sceptre":{"sceptre","sceptred","sceptres","sceptring"},
"scet":{"scet","scets"},
"schadenfreude":{"schadenfreude","schadenfreudes"},
"schaffneria":{"schaffneria","schaffnerias"},
"schatchen":{"schatchen","schatchens","schatchonim","shadchans"},
"schedule":{"schedule","scheduled","schedules","scheduling"},
"scheduling":{"scheduling","schedulings"},
"schefflera":{"schefflera","scheffleras"},
"schema":{"schema","schemas","schemata"},
"schematic":{"schematic","schematics"},
"schematisation":{"schematisation","schematisations"},
"schematization":{"schematization","schematizations"},
"schematize":{"schematize","schematized","schematizing"},
"scheme":{"scheme","schemed","schemes","scheming"},
"schemer":{"schemer","schemers"},
"schenk":{"schenk","schenks"},
"scheol":{"scheol","scheols"},
"scherzando":{"scherzandi","scherzando","scherzandos"},
"scherzo":{"scherzi","scherzo","scherzoi","scherzos"},
"scheuchzeriaceae":{"scheuchzeriaceae","scheuchzeriaceaes"},
"schinus":{"schinus","schinuses"},
"schism":{"schism","schisms"},
"schismatize":{"schismatize","schismatized","schismatizing"},
"schistorrhachis":{"schistorrhachis","schistorrhachises"},
"schistosoma":{"schistosoma","schistosomas"},
"schistosomatidae":{"schistosomatidae","schistosomatidaes"},
"schistosome":{"schistosome","schistosomes"},
"schistosomiasis":{"schistosomiases","schistosomiasis"},
"schizachyrium":{"schizachyrium","schizachyriums"},
"schizaea":{"schizaea","schizaeas"},
"schizaeaceae":{"schizaeaceae","schizaeaceaes"},
"schizanthus":{"schizanthus","schizanthuses"},
"schizo":{"schizo","schizos"},
"schizomycetes":{"schizomycetes","schizomyceteses"},
"schizopetalon":{"schizopetalon","schizopetalons"},
"schizophragma":{"schizophragma","schizophragmas"},
"schizophrenia":{"schizophrenia","schizophrenias"},
"schizophyceae":{"schizophyceae","schizophyceaes"},
"schizophyta":{"schizophyta","schizophytas"},
"schizosaccharomyces":{"schizosaccharomyces","schizosaccharomyceses"},
"schizosaccharomycetaceae":{"schizosaccharomycetaceae","schizosaccharomycetaceaes"},
"schlemiel":{"schlemiel","schlemiels"},
"schlep":{"schlep","schlepped","schlepping","schleps"},
"schlesien":{"schlesien","schlesiens"},
"schlock":{"schlock","schlocks"},
"schlockmeister":{"schlockmeister","schlockmeisters"},
"schlumbergera":{"schlumbergera","schlumbergeras"},
"schmaltz":{"schmaltz","schmaltzs"},
"schmalz":{"schmalz","schmalzs"},
"schmear":{"schmear","schmears"},
"schmeer":{"schmeer","schmeers"},
"schmo":{"schmo","schmoes"},
"schmuck":{"schmuck","schmucks"},
"schnapps":{"schnapps","schnappses"},
"schnaps":{"schnaps","schnapses"},
"schnecken":{"schnecken","schneckens"},
"schnittlaugh":{"schnittlaugh","schnittlaughs"},
"schnitzel":{"schnitzel","schnitzels"},
"schnorchel":{"schnorchel","schnorchels"},
"schnorkel":{"schnorkel","schnorkels"},
"schnozzle":{"schnozzle","schnozzles"},
"scholar":{"scholar","scholars"},
"scholarship":{"scholarship","scholarships"},
"scholastic":{"scholastic","scholastics"},
"scholasticism":{"scholasticism","scholasticisms"},
"scholium":{"scholia","scholium"},
"schomburgkia":{"schomburgkia","schomburgkias"},
"school":{"school","schooled","schooling","schools"},
"schoolbook":{"schoolbook","schoolbooks"},
"schoolboy":{"schoolboy","schoolboys"},
"schoolchild":{"schoolchild","schoolchildren"},
"schooldays":{"schooldays","schooldayses"},
"schoolfellow":{"schoolfellow","schoolfellows"},
"schoolgirl":{"schoolgirl","schoolgirls"},
"schoolhouse":{"schoolhouse","schoolhouses"},
"schooling":{"schooling","schoolings"},
"schoolman":{"schoolman","schoolmen"},
"schoolmarm":{"schoolmarm","schoolmarms"},
"schoolmaster":{"schoolmaster","schoolmasters"},
"schoolmate":{"schoolmate","schoolmates"},
"schoolmistress":{"schoolmistress","schoolmistresses"},
"schoolroom":{"schoolroom","schoolrooms"},
"schoolteacher":{"schoolteacher","schoolteachers"},
"schooltime":{"schooltime","schooltimes"},
"schooner":{"schooner","schooners"},
"schrod":{"schrod","schrods"},
"schrodinger":{"schrodinger","schrodingers"},
"schul":{"schul","schuln"},
"schuss":{"schuss","schussed","schussing"},
"schutzstaffel":{"schutzstaffel","schutzstaffeln"},
"schwa":{"schwa","schwas"},
"schwarzwald":{"schwarzwald","schwarzwalds"},
"schweiz":{"schweiz","schweizs"},
"sciadopityaceae":{"sciadopityaceae","sciadopityaceaes"},
"sciadopitys":{"sciadopitys","sciadopityses"},
"sciaena":{"sciaena","sciaenas"},
"sciaenid":{"sciaenid","sciaenids"},
"sciaenidae":{"sciaenidae","sciaenidaes"},
"sciaenops":{"sciaenops","sciaenopses"},
"sciamachy":{"sciamachies","sciamachy"},
"sciara":{"sciara","sciaras"},
"sciarid":{"sciarid","sciarids"},
"sciaridae":{"sciaridae","sciaridaes"},
"science":{"science","sciences"},
"scientist":{"scientist","scientists"},
"scilla":{"scilla","scillas"},
"scincella":{"scincella","scincellas"},
"scincid":{"scincid","scincids"},
"scincidae":{"scincidae","scincidaes"},
"scincus":{"scincus","scincuses"},
"scindapsus":{"scindapsus","scindapsuses"},
"scintilla":{"scintilla","scintillas"},
"scintillate":{"scintillate","scintillated","scintillates","scintillating"},
"scintillation":{"scintillation","scintillations"},
"sciomachy":{"sciomachies","sciomachy"},
"scipio":{"scipio","scipios"},
"scirpus":{"scirpus","scirpuses"},
"scirrhus":{"scirrhi","scirrhus","scirrhuses"},
"scissor":{"scissor","scissored","scissoring"},
"scissortail":{"scissortail","scissortails"},
"scissure":{"scissure","scissures"},
"sciuridae":{"sciuridae","sciuridaes"},
"sciuromorpha":{"sciuromorpha","sciuromorphas"},
"sciurus":{"sciurus","sciuruses"},
"sclera":{"sclera","scleras"},
"scleranthus":{"scleranthus","scleranthuses"},
"sclerenchyma":{"sclerenchyma","sclerenchymata"},
"scleroderma":{"scleroderma","sclerodermas"},
"sclerodermataceae":{"sclerodermataceae","sclerodermataceaes"},
"sclerodermatales":{"sclerodermatales","sclerodermataleses"},
"scleroma":{"scleroma","scleromata"},
"scleroparei":{"scleroparei","scleropareis"},
"scleroprotein":{"scleroprotein","scleroproteins"},
"sclerosis":{"scleroses","sclerosis"},
"sclerotiniaceae":{"sclerotiniaceae","sclerotiniaceaes"},
"sclerotium":{"sclerotium","sclerotiums"},
"sclerotomy":{"sclerotomies","sclerotomy"},
"sclk":{"sclk","sclks"},
"scoff":{"scoff","scoffed","scoffing","scoffs"},
"scoffer":{"scoffer","scoffers"},
"scoffing":{"scoffing","scoffings"},
"scoke":{"scoke","scokes"},
"scold":{"scold","scolded","scolding","scolds"},
"scolder":{"scolder","scolders"},
"scolding":{"scolding","scoldings"},
"scolex":{"scoleces","scolex","scolices"},
"scolion":{"scolion","scolions"},
"scollop":{"scollop","scolloped","scolloping","scollops"},
"scolopacidae":{"scolopacidae","scolopacidaes"},
"scolopax":{"scolopax","scolopaxes"},
"scolymus":{"scolymus","scolymuses"},
"scolytidae":{"scolytidae","scolytidaes"},
"scolytus":{"scolytus","scolytuses"},
"scomber":{"scomber","scombers"},
"scomberesocidae":{"scomberesocidae","scomberesocidaes"},
"scomberesox":{"scomberesox","scomberesoxes"},
"scomberomorus":{"scomberomorus","scomberomoruses"},
"scombresocidae":{"scombresocidae","scombresocidaes"},
"scombresox":{"scombresox","scombresoxes"},
"scombridae":{"scombridae","scombridaes"},
"scombroid":{"scombroid","scombroids"},
"scombroidea":{"scombroidea","scombroideas"},
"sconce":{"sconce","sconces"},
"scoop":{"scoop","scooped","scooping","scoops"},
"scoopful":{"scoopful","scoopfuls"},
"scoot":{"scoot","scooted","scooting","scoots"},
"scooter":{"scooter","scooters"},
"scope":{"scope","scopes"},
"scophthalmus":{"scophthalmus","scophthalmuses"},
"scopolamine":{"scopolamine","scopolamines"},
"scopolia":{"scopolia","scopolias"},
"scopula":{"scopula","scopulae","scopulas"},
"scorch":{"scorch","scorched","scorches","scorching"},
"score":{"score","scored","scores","scoring"},
"scorecard":{"scorecard","scorecards"},
"scorekeeper":{"scorekeeper","scorekeepers"},
"scorer":{"scorer","scorers"},
"scores":{"scores","scoreses"},
"scoria":{"scoria","scorias","socriae"},
"scorify":{"scorified","scorifies","scorify","scorifying"},
"scorn":{"scorn","scorned","scorning","scorns"},
"scorpaena":{"scorpaena","scorpaenas"},
"scorpaenid":{"scorpaenid","scorpaenids"},
"scorpaenidae":{"scorpaenidae","scorpaenidaes"},
"scorpaenoid":{"scorpaenoid","scorpaenoids"},
"scorpaenoidea":{"scorpaenoidea","scorpaenoideas"},
"scorpio":{"scorpio","scorpios"},
"scorpion":{"scorpion","scorpions"},
"scorpionfish":{"scorpionfish","scorpionfishes"},
"scorpionida":{"scorpionida","scorpionidas"},
"scorpionweed":{"scorpionweed","scorpionweeds"},
"scorpius":{"scorpius","scorpiuses"},
"scorzonera":{"scorzonera","scorzoneras"},
"scot":{"scot","scots"},
"scotch":{"scotch","scotched","scotches","scotching"},
"scotchman":{"scotchman","scotchmen"},
"scotchwoman":{"scotchwoman","scotchwomen"},
"scoter":{"scoter","scoters"},
"scotoma":{"scotoma","scotomas","scotomata"},
"scots":{"scots","scotses"},
"scotsman":{"scotsman","scotsmen"},
"scotswoman":{"scotswoman","scotswomen"},
"scottie":{"scottie","scotties"},
"scottish":{"scottish","scottishes"},
"scotty":{"scotties","scotty"},
"scoundrel":{"scoundrel","scoundrels"},
"scour":{"scour","scoured","scouring","scours"},
"scourge":{"scourge","scourged","scourges","scourging"},
"scouring":{"scouring","scourings"},
"scouse":{"scouse","scouses"},
"scout":{"scout","scouted","scouting","scouts"},
"scouting":{"scouting","scoutings"},
"scow":{"scow","scows"},
"scowl":{"scowl","scowled","scowling","scowls"},
"scrabble":{"scrabble","scrabbled","scrabbles","scrabbling"},
"scrabbly":{"scrabblier","scrabbliest","scrabbly"},
"scrag":{"scrag","scragged","scragging","scrags"},
"scraggly":{"scragglier","scraggliest","scraggly"},
"scraggy":{"scraggier","scraggiest","scraggy"},
"scram":{"scram","scrammed","scramming","scrams"},
"scramble":{"scramble","scrambled","scrambles","scrambling"},
"scrap":{"scrap","scrapped","scrapping","scraps"},
"scrapbook":{"scrapbook","scrapbooks"},
"scrape":{"scrape","scraped","scrapes","scraping"},
"scraper":{"scraper","scrapers"},
"scrapheap":{"scrapheap","scrapheaps"},
"scraping":{"scraping","scrapings"},
"scrapper":{"scrapper","scrappers"},
"scrappy":{"scrappier","scrappiest","scrappy"},
"scraps":{"scraps","scrapses"},
"scratch":{"scratch","scratched","scratches","scratching"},
"scratchiness":{"scratchiness","scratchinesses"},
"scratching":{"scratching","scratchings"},
"scratchy":{"scratchier","scratchiest","scratchy"},
"scrawl":{"scrawl","scrawled","scrawling","scrawls"},
"scrawniness":{"scrawniness","scrawninesses"},
"scrawny":{"scrawnier","scrawniest","scrawny"},
"scream":{"scream","screamed","screaming","screams"},
"screaming":{"screaming","screamings"},
"scree":{"scree","screes"},
"screech":{"screech","screeched","screeches","screeching"},
"screeching":{"screeching","screechings"},
"screechy":{"screechier","screechiest","screechy"},
"screen":{"screen","screened","screening","screens"},
"screening":{"screening","screenings"},
"screenwriter":{"screenwriter","screenwriters"},
"screw":{"screw","screwed","screwing","screws"},
"screwball":{"screwball","screwballs"},
"screwbean":{"screwbean","screwbeans"},
"screwing":{"screwing","screwings"},
"screwy":{"screwier","screwiest","screwy"},
"scribble":{"scribble","scribbled","scribbles","scribbling"},
"scribbler":{"scribbler","scribblers"},
"scribe":{"scribe","scribed","scribes","scribing"},
"scriber":{"scriber","scribers"},
"scrimmage":{"scrimmage","scrimmaged","scrimmages","scrimmaging"},
"scrimp":{"scrimp","scrimped","scrimping","scrimps"},
"scrimpy":{"scrimpier","scrimpiest","scrimpy"},
"scrimshaw":{"scrimshaw","scrimshawed","scrimshawing"},
"script":{"script","scripted","scripting","scripts"},
"scriptorium":{"scriptoria","scriptorium","scriptoriums"},
"scripture":{"scripture","scriptures"},
"scrivener":{"scrivener","scriveners"},
"scrod":{"scrod","scrods"},
"scrofula":{"scrofula","scrofulas"},
"scroll":{"scroll","scrolled","scrolling","scrolls"},
"scrooge":{"scrooge","scrooges"},
"scrophularia":{"scrophularia","scrophularias"},
"scrophulariaceae":{"scrophulariaceae","scrophulariaceaes"},
"scrophulariales":{"scrophulariales","scrophularialeses"},
"scrotum":{"scrota","scrotum","scrotums"},
"scrounge":{"scrounge","scrounged","scrounges","scrounging"},
"scrounger":{"scrounger","scroungers"},
"scroungy":{"scroungier","scroungiest","scroungy"},
"scrub":{"scrub","scrubbed","scrubbing","scrubs"},
"scrubbing":{"scrubbing","scrubbings"},
"scrubbird":{"scrubbird","scrubbirds"},
"scrubby":{"scrubbier","scrubbiest","scrubby"},
"scrubs":{"scrubs","scrubses"},
"scrubwoman":{"scrubwoman","scrubwomen"},
"scruff":{"scruff","scruffs"},
"scruffy":{"scruffier","scruffiest","scruffy"},
"scrum":{"scrum","scrummed","scrumming","scrums"},
"scrummage":{"scrummage","scrummaged","scrummages","scrummaging"},
"scrunch":{"scrunch","scrunched","scrunches","scrunching"},
"scruple":{"scruple","scrupled","scruples","scrupling"},
"scruples":{"scruples","scrupleses"},
"scrupulousness":{"scrupulousness","scrupulousnesses"},
"scrutineer":{"scrutineer","scrutineers"},
"scrutinize":{"scrutinize","scrutinized","scrutinizes","scrutinizing"},
"scrutiny":{"scrutinies","scrutiny"},
"scry":{"scried","scries","scry","scrying"},
"scsi":{"scsi","scsis"},
"scuba":{"scuba","scubas"},
"scud":{"scud","scudded","scudding","scuds"},
"scudding":{"scudding","scuddings"},
"scudo":{"scudi","scudo"},
"scuff":{"scuff","scuffed","scuffing","scuffs"},
"scuffing":{"scuffing","scuffings"},
"scuffle":{"scuffle","scuffled","scuffles","scuffling"},
"scuffs":{"scuffs","scuffses"},
"scull":{"scull","sculled","sculling"},
"scullery":{"sculleries","scullery"},
"sculpin":{"sculpin","sculpins"},
"sculpt":{"sculpt","sculpted","sculpting","sculpts"},
"sculptor":{"sculptor","sculptors"},
"sculpture":{"sculpture","sculptured","sculptures","sculpturing"},
"sculpturer":{"sculpturer","sculpturers"},
"scum":{"scum","scummed","scumming","scums"},
"scumble":{"scumble","scumbled","scumbling"},
"scummy":{"scummier","scummiest","scummy"},
"scungy":{"scungier","scungiest","scungy"},
"scunner":{"scunner","scunnered","scunnering"},
"scup":{"scup","scups"},
"scurf":{"scurf","scurfs"},
"scurfy":{"scurfier","scurfiest","scurfy"},
"scurrility":{"scurrilities","scurrility"},
"scurry":{"scurried","scurries","scurry","scurrying"},
"scurvy":{"scurvier","scurviest","scurvy"},
"scutcheon":{"scutcheon","scutcheons"},
"scutellaria":{"scutellaria","scutellarias"},
"scutellum":{"scutella","scutellum"},
"scutigera":{"scutigera","scutigeras"},
"scutigerella":{"scutigerella","scutigerellas"},
"scutigeridae":{"scutigeridae","scutigeridaes"},
"scutter":{"scutter","scuttered","scuttering"},
"scuttle":{"scuttle","scuttled","scuttles","scuttling"},
"scuttlebutt":{"scuttlebutt","scuttlebutts"},
"scutum":{"scuta","scutum"},
"scyliorhinidae":{"scyliorhinidae","scyliorhinidaes"},
"scyphistoma":{"scyphistoma","scyphistomae","scyphistomas"},
"scyphozoa":{"scyphozoa","scyphozoas"},
"scyphus":{"scyphi","scyphus"},
"scythe":{"scythe","scythed","scythes","scything"},
"se":{"se","ses"},
"sea":{"sea","seas"},
"sea-duty":{"sea-duties","sea-duty"},
"sea-ear":{"sea-ear","sea-ears"},
"sea-rocket":{"sea-rocket","sea-rockets"},
"seabed":{"seabed","seabeds"},
"seabird":{"seabird","seabirds"},
"seaboard":{"seaboard","seaboards"},
"seacoast":{"seacoast","seacoasts"},
"seafarer":{"seafarer","seafarers"},
"seafaring":{"seafaring","seafarings"},
"seafowl":{"seafowl","seafowls"},
"seagull":{"seagull","seagulls"},
"seahorse":{"seahorse","seahorses"},
"seal":{"seal","sealed","sealing","seals"},
"sealant":{"sealant","sealants"},
"sealer":{"sealer","sealers"},
"sealing":{"sealing","sealings"},
"sealskin":{"sealskin","sealskins"},
"sealyham":{"sealyham","sealyhams"},
"seam":{"seam","seamed","seaming","seams"},
"seaman":{"seaman","seamen"},
"seamstress":{"seamstress","seamstresses"},
"seamy":{"seamier","seamiest","seamy"},
"seanad":{"seanad","seanads"},
"seance":{"seance","seances"},
"seaplane":{"seaplane","seaplanes"},
"seapoose":{"seapoose","seapooses"},
"seaport":{"seaport","seaports"},
"seaquake":{"seaquake","seaquakes"},
"sear":{"sear","seared","searing","sears"},
"search":{"search","searched","searches","searching"},
"searcher":{"searcher","searchers"},
"searching":{"searching","searchings"},
"searchlight":{"searchlight","searchlights"},
"searobin":{"searobin","searobins"},
"seashell":{"seashell","seashells"},
"seashore":{"seashore","seashores"},
"seasickness":{"seasickness","seasicknesses"},
"seaside":{"seaside","seasides"},
"seasnail":{"seasnail","seasnails"},
"season":{"season","seasoned","seasoning","seasons"},
"seasonableness":{"seasonableness","seasonablenesses"},
"seasoner":{"seasoner","seasoners"},
"seasoning":{"seasoning","seasonings"},
"seat":{"seat","seated","seating","seats"},
"seating":{"seating","seatings"},
"seats":{"seats","seatses"},
"seawall":{"seawall","seawalls"},
"seawater":{"seawater","seawaters"},
"seaway":{"seaway","seaways"},
"seaworthiness":{"seaworthiness","seaworthinesses"},
"seaworthy":{"seaworthier","seaworthiest","seaworthy"},
"sebastiana":{"sebastiana","sebastianas"},
"sebastodes":{"sebastodes","sebastodeses"},
"sebastopol":{"sebastopol","sebastopols"},
"sebe":{"sebe","sebes"},
"sebs":{"sebs","sebses"},
"sec":{"sec","secs"},
"secale":{"secale","secales"},
"secco":{"secco","seccos"},
"secede":{"secede","seceded","secedes","seceding"},
"secession":{"secession","secessions"},
"sechuana":{"sechuana","sechuanas"},
"seckel":{"seckel","seckels"},
"seclude":{"seclude","secluded","secludes","secluding"},
"seclusion":{"seclusion","seclusions"},
"secobarbital":{"secobarbital","secobarbitals"},
"seconal":{"seconal","seconals"},
"second":{"second","seconded","seconding","seconds"},
"second-guess":{"second-guess","second-guessed","second-guessing"},
"second-rater":{"second-rater","second-raters"},
"secondary":{"secondaries","secondary"},
"secondo":{"secondi","secondo"},
"secotiaceae":{"secotiaceae","secotiaceaes"},
"secotiales":{"secotiales","secotialeses"},
"secpar":{"secpar","secpars"},
"secrecy":{"secrecies","secrecy"},
"secret":{"secret","secrets"},
"secretaire":{"secretaire","secretaires"},
"secretariat":{"secretariat","secretariats"},
"secretariate":{"secretariate","secretariates"},
"secretary":{"secretaries","secretary"},
"secretary-general":{"secretaries-general","secretary-general"},
"secrete":{"secrete","secreted","secretes","secreting"},
"secreting":{"secreting","secretings"},
"secretiveness":{"secretiveness","secretivenesses"},
"sect":{"sect","sects"},
"sectarianism":{"sectarianism","sectarianisms"},
"sectary":{"sectaries","sectary"},
"section":{"section","sectioned","sectioning","sections"},
"sectionalism":{"sectionalism","sectionalisms"},
"sectionalization":{"sectionalization","sectionalizations"},
"sector":{"sector","sectored","sectoring","sectors"},
"sectral":{"sectral","sectrals"},
"secular":{"secular","seculars"},
"secularisation":{"secularisation","secularisations"},
"secularist":{"secularist","secularists"},
"secularity":{"secularities","secularity"},
"secularization":{"secularization","secularizations"},
"secularize":{"secularize","secularized","secularizing"},
"secundigravida":{"secundigravida","secundigravidas"},
"secure":{"secure","secured","securer","securest","securing"},
"secureness":{"secureness","securenesses"},
"security":{"securities","security"},
"sedan":{"sedan","sedans"},
"sedate":{"sedate","sedater","sedates","sedatest"},
"sedateness":{"sedateness","sedatenesses"},
"sedation":{"sedation","sedations"},
"sedative":{"sedative","sedatives"},
"sedative-hypnotic":{"sedative-hypnotic","sedative-hypnotics"},
"seder":{"seder","seders"},
"sediment":{"sediment","sediments"},
"sedimentation":{"sedimentation","sedimentations"},
"seduce":{"seduce","seduced","seduces","seducing"},
"seducement":{"seducement","seducements"},
"seducer":{"seducer","seducers"},
"seduction":{"seduction","seductions"},
"sedulity":{"sedulities","sedulity"},
"sedulousness":{"sedulousness","sedulousnesses"},
"see":{"saw","see","seeing","seen","sees"},
"seed":{"seed","seeded","seeding","seeds"},
"seedcase":{"seedcase","seedcases"},
"seediness":{"seediness","seedinesses"},
"seedling":{"seedling","seedlings"},
"seedman":{"seedman","seedmen"},
"seedpod":{"seedpod","seedpods"},
"seedsman":{"seedsman","seedsmen"},
"seedy":{"seedier","seediest","seedy"},
"seeing":{"seeing","seeings"},
"seek":{"seek","seeking","seeks","sought"},
"seeker":{"seeker","seekers"},
"seeking":{"seeking","seekings"},
"seeland":{"seeland","seelands"},
"seem":{"seem","seemed","seeming","seems"},
"seeming":{"seeming","seemings"},
"seemliness":{"seemliness","seemlinesses"},
"seemly":{"seemlier","seemliest","seemly"},
"seep":{"seep","seeped","seeping","seeps"},
"seepage":{"seepage","seepages"},
"seer":{"seer","seers"},
"seesaw":{"seesaw","seesawed","seesawing","seesaws"},
"seethe":{"seethe","seethed","seethes","seething"},
"segment":{"segment","segmented","segmenting","segments"},
"segmentalize":{"segmentalize","segmentalized","segmentalizing"},
"segmentation":{"segmentation","segmentations"},
"segno":{"segni","segno"},
"segregate":{"segregate","segregated","segregating"},
"segregation":{"segregation","segregations"},
"segregationist":{"segregationist","segregationists"},
"seigneur":{"seigneur","seigneurs"},
"seigneury":{"seigneuries","seigneury"},
"seignior":{"seignior","seigniors"},
"seigniory":{"seigniories","seigniory"},
"seignory":{"seignories","seignory"},
"seine":{"seine","seined","seines","seining"},
"seism":{"seism","seisms"},
"seismosaur":{"seismosaur","seismosaurs"},
"seismosaurus":{"seismosaurus","seismosauruses"},
"seiurus":{"seiurus","seiuruses"},
"seize":{"seize","seized","seizes","seizing"},
"seizer":{"seizer","seizers"},
"seizing":{"seizing","seizings"},
"seizure":{"seizure","seizures"},
"sekhet":{"sekhet","sekhets"},
"selachian":{"selachian","selachians"},
"selachii":{"selachii","selachiis"},
"selaginella":{"selaginella","selaginellas"},
"selaginellaceae":{"selaginellaceae","selaginellaceaes"},
"selaginellales":{"selaginellales","selaginellaleses"},
"selar":{"selar","selars"},
"select":{"select","selected","selecting","selects"},
"selection":{"selection","selections"},
"selectman":{"selectman","selectmen"},
"selector":{"selector","selectors"},
"selenarctos":{"selenarctos","selenarctoses"},
"selene":{"selene","selenes"},
"selenicereus":{"selenicereus","selenicereuses"},
"selenipedium":{"selenipedium","selenipediums"},
"selenium":{"selenium","seleniums"},
"selenolatry":{"selenolatries","selenolatry"},
"seleucid":{"seleucid","seleucidae","seleucids"},
"seleucus":{"seleucus","seleucuses"},
"self":{"self","selves"},
"self-abasement":{"self-abasement","self-abasements"},
"self-abnegation":{"self-abnegation","self-abnegations"},
"self-abuse":{"self-abuse","self-abuses"},
"self-accusation":{"self-accusation","self-accusations"},
"self-actualize":{"self-actualize","self-actualized","self-actualizing"},
"self-aggrandisement":{"self-aggrandisement","self-aggrandisements"},
"self-aggrandizement":{"self-aggrandizement","self-aggrandizements"},
"self-analysis":{"self-analyses","self-analysis"},
"self-annihilation":{"self-annihilation","self-annihilations"},
"self-assertiveness":{"self-assertiveness","self-assertivenesses"},
"self-assurance":{"self-assurance","self-assurances"},
"self-centeredness":{"self-centeredness","self-centerednesses"},
"self-command":{"self-command","self-commands"},
"self-complacency":{"self-complacencies","self-complacency"},
"self-concern":{"self-concern","self-concerns"},
"self-condemnation":{"self-condemnation","self-condemnations"},
"self-confidence":{"self-confidence","self-confidences"},
"self-consciousness":{"self-consciousness","self-consciousnesses"},
"self-contemplation":{"self-contemplation","self-contemplations"},
"self-control":{"self-control","self-controls"},
"self-cultivation":{"self-cultivation","self-cultivations"},
"self-deceit":{"self-deceit","self-deceits"},
"self-deception":{"self-deception","self-deceptions"},
"self-defence":{"self-defence","self-defences"},
"self-defense":{"self-defense","self-defenses"},
"self-denial":{"self-denial","self-denials"},
"self-destruction":{"self-destruction","self-destructions"},
"self-determination":{"self-determination","self-determinations"},
"self-direction":{"self-direction","self-directions"},
"self-discipline":{"self-discipline","self-disciplines"},
"self-disgust":{"self-disgust","self-disgusts"},
"self-distrust":{"self-distrust","self-distrusts"},
"self-doubt":{"self-doubt","self-doubts"},
"self-education":{"self-education","self-educations"},
"self-effacement":{"self-effacement","self-effacements"},
"self-esteem":{"self-esteem","self-esteems"},
"self-examination":{"self-examination","self-examinations"},
"self-feeder":{"self-feeder","self-feeders"},
"self-fertilisation":{"self-fertilisation","self-fertilisations"},
"self-fertilization":{"self-fertilization","self-fertilizations"},
"self-flagellation":{"self-flagellation","self-flagellations"},
"self-fulfillment":{"self-fulfillment","self-fulfillments"},
"self-government":{"self-government","self-governments"},
"self-gratification":{"self-gratification","self-gratifications"},
"self-hatred":{"self-hatred","self-hatreds"},
"self-heal":{"self-heal","self-heals"},
"self-hypnosis":{"self-hypnoses","self-hypnosis"},
"self-ignite":{"self-ignite","self-ignited","self-igniting"},
"self-importance":{"self-importance","self-importances"},
"self-improvement":{"self-improvement","self-improvements"},
"self-inductance":{"self-inductance","self-inductances"},
"self-indulgence":{"self-indulgence","self-indulgences"},
"self-interest":{"self-interest","self-interests"},
"self-justification":{"self-justification","self-justifications"},
"self-love":{"self-love","self-loves"},
"self-mortification":{"self-mortification","self-mortifications"},
"self-organisation":{"self-organisation","self-organisations"},
"self-organization":{"self-organization","self-organizations"},
"self-possession":{"self-possession","self-possessions"},
"self-praise":{"self-praise","self-praises"},
"self-pride":{"self-pride","self-prides"},
"self-protection":{"self-protection","self-protections"},
"self-punishment":{"self-punishment","self-punishments"},
"self-realisation":{"self-realisation","self-realisations"},
"self-realization":{"self-realization","self-realizations"},
"self-reformation":{"self-reformation","self-reformations"},
"self-regard":{"self-regard","self-regards"},
"self-reliance":{"self-reliance","self-reliances"},
"self-renunciation":{"self-renunciation","self-renunciations"},
"self-reproach":{"self-reproach","self-reproaches"},
"self-reproof":{"self-reproof","self-reproofs","self-reprooves"},
"self-respect":{"self-respect","self-respects"},
"self-restraint":{"self-restraint","self-restraints"},
"self-rule":{"self-rule","self-rules"},
"self-sacrifice":{"self-sacrifice","self-sacrifices"},
"self-satisfaction":{"self-satisfaction","self-satisfactions"},
"self-seeker":{"self-seeker","self-seekers"},
"self-seeking":{"self-seeking","self-seekings"},
"self-starter":{"self-starter","self-starters"},
"self-study":{"self-studies","self-study"},
"self-sufficiency":{"self-sufficiencies","self-sufficiency"},
"self-suggestion":{"self-suggestion","self-suggestions"},
"self-torment":{"self-torment","self-torments"},
"self-torture":{"self-torture","self-tortures"},
"self-will":{"self-will","self-wills"},
"self-worship":{"self-worship","self-worships"},
"selflessness":{"selflessness","selflessnesses"},
"selkup":{"selkup","selkups"},
"sell":{"sell","selling","sells","sold"},
"seller":{"seller","sellers"},
"selling":{"selling","sellings"},
"seltzer":{"seltzer","seltzers"},
"selvage":{"selvage","selvages"},
"selvedge":{"selvedge","selvedges"},
"semanticist":{"semanticist","semanticists"},
"semaphore":{"semaphore","semaphored","semaphoring"},
"semblance":{"semblance","semblances"},
"semen":{"semen","semens"},
"semester":{"semester","semesters"},
"semi":{"semi","semis"},
"semiautomatic":{"semiautomatic","semiautomatics"},
"semibreve":{"semibreve","semibreves"},
"semicircle":{"semicircle","semicircles"},
"semicolon":{"semicolon","semicolons"},
"semiconductor":{"semiconductor","semiconductors"},
"semiconsciousness":{"semiconsciousness","semiconsciousnesses"},
"semiepiphyte":{"semiepiphyte","semiepiphytes"},
"semifinal":{"semifinal","semifinals"},
"seminar":{"seminar","seminars"},
"seminarian":{"seminarian","seminarians"},
"seminarist":{"seminarist","seminarists"},
"seminary":{"seminaries","seminary"},
"seminole":{"seminole","seminoles"},
"seminoma":{"seminoma","seminomas"},
"semiotician":{"semiotician","semioticians"},
"semipro":{"semipro","semipros"},
"semiprofessional":{"semiprofessional","semiprofessionals"},
"semiquaver":{"semiquaver","semiquavers"},
"semitone":{"semitone","semitones"},
"semitrailer":{"semitrailer","semitrailers"},
"semitransparency":{"semitransparencies","semitransparency"},
"semitropics":{"semitropics","semitropicses"},
"semivowel":{"semivowel","semivowels"},
"semiweekly":{"semiweeklies","semiweekly"},
"sempatch":{"sempatch","sempatches"},
"sempstress":{"sempstress","sempstresses"},
"senate":{"senate","senates"},
"senator":{"senator","senators"},
"send":{"send","sending","sends","sent"},
"send-off":{"send-off","send-offs"},
"sender":{"sender","senders"},
"sendup":{"sendup","sendups"},
"seneca":{"seneca","senecas"},
"senecio":{"senecio","senecios"},
"senega":{"senega","senegas"},
"senescence":{"senescence","senescences"},
"seneschal":{"seneschal","seneschals"},
"senility":{"senilities","senility"},
"senior":{"senior","seniors"},
"seniority":{"seniorities","seniority"},
"senor":{"senor","senores","senors"},
"senora":{"senora","senoras"},
"senorita":{"senorita","senoritas"},
"sens":{"sens","senses"},
"sensation":{"sensation","sensations"},
"sensationalism":{"sensationalism","sensationalisms"},
"sensationalist":{"sensationalist","sensationalists"},
"sense":{"sense","sensed","senses","sensing"},
"senselessness":{"senselessness","senselessnesses"},
"sensibility":{"sensibilities","sensibility"},
"sensillum":{"sensilla","sensillum"},
"sensing":{"sensing","sensings"},
"sensitisation":{"sensitisation","sensitisations"},
"sensitiveness":{"sensitiveness","sensitivenesses"},
"sensitivity":{"sensitivities","sensitivity"},
"sensitization":{"sensitization","sensitizations"},
"sensitize":{"sensitize","sensitized","sensitizes","sensitizing"},
"sensitizing":{"sensitizing","sensitizings"},
"sensor":{"sensor","sensors"},
"sensualism":{"sensualism","sensualisms"},
"sensuality":{"sensualities","sensuality"},
"sensualize":{"sensualize","sensualized","sensualizes","sensualizing"},
"sensualness":{"sensualness","sensualnesses"},
"sentence":{"sentence","sentenced","sentences","sentencing"},
"sentience":{"sentience","sentiences"},
"sentiency":{"sentiencies","sentiency"},
"sentiment":{"sentiment","sentiments"},
"sentimentalisation":{"sentimentalisation","sentimentalisations"},
"sentimentalist":{"sentimentalist","sentimentalists"},
"sentimentality":{"sentimentalities","sentimentality"},
"sentimentalization":{"sentimentalization","sentimentalizations"},
"sentimentalize":{"sentimentalize","sentimentalized","sentimentalizes","sentimentalizing"},
"sentinel":{"sentinel","sentineled","sentineling","sentinelled","sentinelling","sentinels"},
"sentry":{"sentries","sentry"},
"senusi":{"senusi","senussis"},
"senussi":{"senussi","senussis"},
"seoul":{"seoul","seouls"},
"sep":{"sep","seps"},
"separate":{"separate","separated","separates","separating"},
"separateness":{"separateness","separatenesses"},
"separation":{"separation","separations"},
"separator":{"separator","separators"},
"separatrix":{"separatrix","separatrixes"},
"sephardi":{"sephardi","sephardim"},
"sepia":{"sepia","sepias"},
"sepiidae":{"sepiidae","sepiidaes"},
"sepiolite":{"sepiolite","sepiolites"},
"sept":{"sept","septs"},
"septarium":{"septariia","septarium"},
"september":{"september","septembers"},
"septenary":{"septenaries","septenary"},
"septennium":{"septennia","septennium","septenniums"},
"septentrion":{"septentrion","septentrions"},
"septet":{"septet","septets"},
"septette":{"septette","septettes"},
"septicaemia":{"septicaemia","septicaemias"},
"septicemia":{"septicemia","septicemias"},
"septillion":{"septillion","septillions"},
"septobasidiaceae":{"septobasidiaceae","septobasidiaceaes"},
"septobasidium":{"septobasidium","septobasidiums"},
"septuagesima":{"septuagesima","septuagesimas"},
"septum":{"septa","septum"},
"sepulcher":{"sepulcher","sepulchered","sepulchering","sepulchers"},
"sepulchre":{"sepulchre","sepulchres"},
"sepulture":{"sepulture","sepultures"},
"sequel":{"sequel","sequels"},
"sequela":{"sequela","sequelae"},
"sequence":{"sequence","sequences"},
"sequester":{"sequester","sequestered","sequestering","sequesters"},
"sequestrate":{"sequestrate","sequestrated","sequestrates","sequestrating"},
"sequestration":{"sequestration","sequestrations"},
"sequestrum":{"sequestra","sequestrum"},
"sequin":{"sequin","sequins"},
"sequoia":{"sequoia","sequoias"},
"sequoiadendron":{"sequoiadendron","sequoiadendrons"},
"seraglio":{"seraglio","seraglios"},
"serai":{"serai","serais"},
"serail":{"serail","serails"},
"serape":{"serape","serapes"},
"seraph":{"seraph","seraphim","seraphs"},
"serax":{"serax","seraxes"},
"serb":{"serb","serbs"},
"serbia":{"serbia","serbias"},
"serbian":{"serbian","serbians"},
"serbo-croat":{"serbo-croat","serbo-croats"},
"serbo-croatian":{"serbo-croatian","serbo-croatians"},
"serenade":{"serenade","serenaded","serenades","serenading"},
"serene":{"serene","serener","serenest"},
"serenity":{"serenities","serenity"},
"serenoa":{"serenoa","serenoas"},
"serf":{"serf","serfs","serves"},
"serfdom":{"serfdom","serfdoms"},
"serfhood":{"serfhood","serfhoods"},
"serge":{"serge","serged","serging"},
"sergeant":{"sergeant","sergeants"},
"sergeant-at-law":{"sergeant-at-law","sergeant-at-laws"},
"serial":{"serial","serials"},
"serialisation":{"serialisation","serialisations"},
"serialism":{"serialism","serialisms"},
"serialization":{"serialization","serializations"},
"serialize":{"serialize","serialized","serializing"},
"sericocarpus":{"sericocarpus","sericocarpuses"},
"sericterium":{"sericterium","sericteriums"},
"serictery":{"sericteries","serictery"},
"seriema":{"seriema","seriemas"},
"series":{"series"},
"serif":{"serif","serifs"},
"serinus":{"serinus","serinuses"},
"seriocomedy":{"seriocomedies","seriocomedy"},
"seriola":{"seriola","seriolas"},
"serious-mindedness":{"serious-mindedness","serious-mindednesses"},
"seriousness":{"seriousness","seriousnesses"},
"seriph":{"seriph","seriphs"},
"seriphidium":{"seriphidium","seriphidiums"},
"seriphus":{"seriphus","seriphuses"},
"serjeant":{"serjeant","serjeants"},
"serjeant-at-arms":{"serjeant-at-arms","serjeant-at-armses"},
"serjeant-at-law":{"serjeant-at-law","serjeant-at-laws"},
"sermon":{"sermon","sermons"},
"sermonize":{"sermonize","sermonized","sermonizes","sermonizing"},
"sermonizer":{"sermonizer","sermonizers"},
"serograph":{"serograph","serographs"},
"serologist":{"serologist","serologists"},
"serosa":{"serosa","serosae","serosas"},
"serotherapy":{"serotherapies","serotherapy"},
"serotine":{"serotine","serotines"},
"serotonin":{"serotonin","serotonins"},
"serpasil":{"serpasil","serpasils"},
"serpent":{"serpent","serpents"},
"serpent-worship":{"serpent-worship","serpent-worships"},
"serpentes":{"serpentes","serpenteses"},
"serpentine":{"serpentine","serpentined","serpentining"},
"serranid":{"serranid","serranids"},
"serranidae":{"serranidae","serranidaes"},
"serranus":{"serranus","serranuses"},
"serrasalmus":{"serrasalmus","serrasalmuses"},
"serratula":{"serratula","serratulas"},
"serratus":{"serratus","serratuses"},
"sertularia":{"sertularia","sertularias"},
"serum":{"sera","serum","serums"},
"serval":{"serval","servals"},
"servant":{"servant","servants"},
"serve":{"serve","served","serves","serving"},
"server":{"server","servers"},
"service":{"service","serviced","services","servicing"},
"serviceability":{"serviceabilities","serviceability"},
"serviceableness":{"serviceableness","serviceablenesses"},
"serviceberry":{"serviceberries","serviceberry"},
"serviceman":{"serviceman","servicemen"},
"servicing":{"servicing","servicings"},
"serviette":{"serviette","serviettes"},
"servility":{"servilities","servility"},
"serving":{"serving","servings"},
"servo":{"servo","servos"},
"servomechanism":{"servomechanism","servomechanisms"},
"servosystem":{"servosystem","servosystems"},
"sesame":{"sesame","sesames"},
"sesamum":{"sesamum","sesamums"},
"seseli":{"seseli","seselis"},
"sesotho":{"sesotho","sesothos"},
"sesquipedalia":{"sesquipedalia","sesquipedalias"},
"sesquipedalian":{"sesquipedalian","sesquipedalians"},
"sess":{"sess","sesses"},
"session":{"session","sessions"},
"sestertium":{"sestertia","sestertium"},
"sestet":{"sestet","sestets"},
"set":{"set","sets","setting"},
"set-to":{"set-to","set-tos"},
"seta":{"seta","setae"},
"setaria":{"setaria","setarias"},
"setback":{"setback","setbacks"},
"seth":{"seth","seths"},
"setoff":{"setoff","setoffs"},
"setophaga":{"setophaga","setophagas"},
"setswana":{"setswana","setswanas"},
"sett":{"sett","setts"},
"settee":{"settee","settees"},
"setterwort":{"setterwort","setterworts"},
"setting":{"setting","settings"},
"settle":{"settle","settled","settles","settling"},
"settlement":{"settlement","settlements"},
"settler":{"settler","settlers"},
"settling":{"settling","settlings"},
"setup":{"setup","setups"},
"sevastopol":{"sevastopol","sevastopols"},
"seven":{"seven","sevens"},
"seven-up":{"seven-up","seven-ups"},
"sevener":{"sevener","seveners"},
"sevens":{"sevens","sevenses"},
"sevensome":{"sevensome","sevensomes"},
"seventeen":{"seventeen","seventeens"},
"seventeenth":{"seventeenth","seventeenths"},
"seventh":{"seventh","sevenths"},
"seventies":{"seventies","seventieses"},
"seventy":{"seventies","seventy"},
"sever":{"sever","severed","severing","severs"},
"severalty":{"severalties","severalty"},
"severance":{"severance","severances"},
"severe":{"severe","severer","severest"},
"severeness":{"severeness","severenesses"},
"severing":{"severing","severings"},
"severity":{"severities","severity"},
"sew":{"sew","sewed","sewing","sewn","sews"},
"sewage":{"sewage","sewages"},
"sewellel":{"sewellel","sewellels"},
"sewer":{"sewer","sewered","sewering","sewers"},
"sewerage":{"sewerage","sewerages"},
"sewing":{"sewing","sewings"},
"sex":{"sex","sexed","sexes","sexing"},
"sexcentenary":{"sexcentenaries","sexcentenary"},
"sexiness":{"sexiness","sexinesses"},
"sexist":{"sexist","sexists"},
"sexlessness":{"sexlessness","sexlessnesses"},
"sextet":{"sextet","sextets"},
"sextette":{"sextette","sextettes"},
"sextillion":{"sextillion","sextillions"},
"sexto":{"sexto","sextos"},
"sextodecimo":{"sextodecimo","sextodecimos"},
"sexton":{"sexton","sextons"},
"sextuple":{"sextuple","sextupled","sextupling"},
"sextuplet":{"sextuplet","sextuplets"},
"sexuality":{"sexualities","sexuality"},
"sexualize":{"sexualize","sexualized","sexulizing"},
"sexy":{"sexier","sexiest","sexy"},
"seymour":{"seymour","seymours"},
"sgml":{"sgml","sgmls"},
"sgraffito":{"sgraffiti","sgraffito"},
"shabbas":{"shabbas","shabbasim"},
"shabbat":{"shabbat","shabbatim"},
"shabbiness":{"shabbiness","shabbinesses"},
"shabby":{"shabbier","shabbiest","shabby"},
"shabuoth":{"shabuoth","shabuoths"},
"shack":{"shack","shacked","shacking","shacks"},
"shackle":{"shackle","shackled","shackles","shackling"},
"shacko":{"shacko","shackoes","shackos"},
"shad":{"shad","shads"},
"shadberry":{"shadberries","shadberry"},
"shadblow":{"shadblow","shadblows"},
"shadbush":{"shadbush","shadbushes"},
"shadchan":{"schatchonim","shadchan","shadchanim","shadchans"},
"shaddock":{"shaddock","shaddocks"},
"shade":{"shade","shaded","shades","shading"},
"shades":{"shades","shadeses"},
"shadflower":{"shadflower","shadflowers"},
"shadfly":{"shadflies","shadfly"},
"shadiness":{"shadiness","shadinesses"},
"shading":{"shading","shadings"},
"shadow":{"shadow","shadowed","shadowing","shadows"},
"shadowbox":{"shadowbox","shadowboxed","shadowboxes","shadowboxing"},
"shadowgraph":{"shadowgraph","shadowgraphs"},
"shadowiness":{"shadowiness","shadowinesses"},
"shadowing":{"shadowing","shadowings"},
"shadowy":{"shadowier","shadowiest","shadowy"},
"shady":{"shadier","shadiest","shady"},
"shaft":{"shaft","shafted","shafting","shafts"},
"shag":{"shag","shagged","shagging","shags"},
"shagbark":{"shagbark","shagbarks"},
"shagging":{"shagging","shaggings"},
"shaggy":{"shaggier","shaggiest","shaggy"},
"shaggycap":{"shaggycap","shaggycaps"},
"shaggymane":{"shaggymane","shaggymanes"},
"shahaptian":{"shahaptian","shahaptians"},
"shake":{"shake","shaken","shakes","shaking","shook"},
"shake-up":{"shake-up","shake-ups"},
"shakespeare":{"shakespeare","shakespeares"},
"shake_hands":{"shaken_hands","shakes_hands","shake_hands","shaking_hands","shook_hands"},
"shakiness":{"shakiness","shakinesses"},
"shaking":{"shaking","shakings"},
"shako":{"shako","shakoes","shakos"},
"shakspere":{"shakspere","shaksperes"},
"shakti":{"shakti","shaktis"},
"shaktism":{"shaktism","shaktisms"},
"shaky":{"shakier","shakiest","shaky"},
"shall":{"shall","should"},
"shallon":{"shallon","shallons"},
"shallot":{"shallot","shallots"},
"shallow":{"shallow","shallowed","shallower","shallowest","shallowing","shallows"},
"shallowness":{"shallowness","shallownesses"},
"shallu":{"shallu","shallus"},
"sham":{"sham","shammed","shamming","shams"},
"shaman":{"shaman","shamen"},
"shamble":{"shamble","shambled","shambles","shambling"},
"shambles":{"shambles","shambleses"},
"shambling":{"shambling","shamblings"},
"shame":{"shame","shamed","shames","shaming"},
"shamefacedness":{"shamefacedness","shamefacednesses"},
"shamefulness":{"shamefulness","shamefulnesses"},
"shamelessness":{"shamelessness","shamelessnesses"},
"shammas":{"shammas","shammosim"},
"shammes":{"shammes","shammosim"},
"shammy":{"shammies","shammy"},
"shampoo":{"shampoo","shampooed","shampooing","shampoos"},
"shamrock":{"shamrock","shamrocks"},
"shamus":{"shamus","shamuses"},
"shan":{"shan","shans"},
"shandy":{"shandies","shandy"},
"shandygaff":{"shandygaff","shandygaffs"},
"shanghai":{"shanghai","shanghaied","shanghaiing","shanghais"},
"shanghaier":{"shanghaier","shanghaiers"},
"shangri-la":{"shangri-la","shangri-las"},
"shank":{"shank","shanks"},
"shanny":{"shannies","shanny"},
"shantey":{"shantey","shanteys"},
"shanty":{"shanties","shanty"},
"shape":{"shape","shaped","shapes","shaping"},
"shapeliness":{"shapeliness","shapelinesses"},
"shapely":{"shapelier","shapeliest","shapely"},
"shaper":{"shaper","shapers"},
"shaping":{"shaping","shapings"},
"shard":{"shard","shards"},
"share":{"share","shared","shares","sharing"},
"share-out":{"share-out","share-outs"},
"sharecrop":{"sharecrop","sharecropped","sharecropping","sharecrops"},
"sharecropper":{"sharecropper","sharecroppers"},
"shareholder":{"shareholder","shareholders"},
"shareowner":{"shareowner","shareowners"},
"sharer":{"sharer","sharers"},
"sharing":{"sharing","sharings"},
"shark":{"shark","sharked","sharking","sharks"},
"sharksucker":{"sharksucker","sharksuckers"},
"sharp":{"sharp","sharped","sharper","sharpest","sharping","sharps"},
"sharp-sightedness":{"sharp-sightedness","sharp-sightednesses"},
"sharpen":{"sharpen","sharpened","sharpening","sharpens"},
"sharper":{"sharper","sharpers"},
"sharpie":{"sharpie","sharpies"},
"sharpness":{"sharpness","sharpnesses"},
"sharpshooter":{"sharpshooter","sharpshooters"},
"sharpy":{"sharpies","sharpy"},
"shatter":{"shatter","shattered","shattering","shatters"},
"shattering":{"shattering","shatterings"},
"shave":{"shave","shaved","shaven","shaves","shaving"},
"shaver":{"shaver","shavers"},
"shaving":{"shaving","shavings"},
"shavous":{"shavous","shavouses"},
"shavuot":{"shavuot","shavuots"},
"shavuoth":{"shavuoth","shavuoths"},
"shaw":{"shaw","shaws"},
"shawl":{"shawl","shawled","shawling","shawls"},
"shawnee":{"shawnee","shawnees"},
"shawny":{"shawnies","shawny"},
"she-goat":{"she-goat","she-goats"},
"sheaf":{"sheaf","sheaves"},
"shear":{"shear","sheared","shearing","shears","shn","shorn"},
"sheatfish":{"sheatfish","sheatfishes"},
"sheath":{"sheath","sheaths"},
"sheathe":{"sheathe","sheathed","sheathing"},
"sheathing":{"sheathing","sheathings"},
"sheave":{"sheave","sheaved","sheaves","sheaving"},
"shebat":{"shebat","shebats"},
"shed":{"shed","shedded","shedding","sheds"},
"shedding":{"shedding","sheddings"},
"sheen":{"sheen","sheened","sheening","sheens"},
"sheeny":{"sheenier","sheenies","sheeniest","sheeny"},
"sheepcote":{"sheepcote","sheepcotes"},
"sheepdog":{"sheepdog","sheepdogs"},
"sheepfold":{"sheepfold","sheepfolds"},
"sheepherder":{"sheepherder","sheepherders"},
"sheepishness":{"sheepishness","sheepishnesses"},
"sheepman":{"sheepman","sheepmen"},
"sheeprun":{"sheeprun","sheepruns"},
"sheepshead":{"sheepshead","sheepsheads"},
"sheepskin":{"sheepskin","sheepskins"},
"sheeptick":{"sheeptick","sheepticks"},
"sheepwalk":{"sheepwalk","sheepwalks"},
"sheer":{"sheer","sheered","sheerer","sheerest","sheering"},
"sheet":{"sheet","sheeted","sheeting","sheets"},
"sheik":{"sheik","sheiks"},
"sheika":{"sheika","sheikas"},
"sheikdom":{"sheikdom","sheikdoms"},
"sheikh":{"sheikh","sheikhs"},
"sheikha":{"sheikha","sheikhas"},
"sheikhdom":{"sheikhdom","sheikhdoms"},
"shekel":{"shekel","shekels"},
"shekels":{"shekels","shekelses"},
"sheldrake":{"sheldrake","sheldrakes"},
"shelf":{"shelf","shelves"},
"shell":{"shell","shelled","shelling","shells"},
"shellac":{"shellac","shellaced","shellacing","shellacs"},
"shellbark":{"shellbark","shellbarks"},
"shellfish":{"shellfish","shellfishes"},
"shellflower":{"shellflower","shellflowers"},
"shelling":{"shelling","shellings"},
"shelter":{"shelter","sheltered","sheltering","shelters"},
"shelterbelt":{"shelterbelt","shelterbelts"},
"sheltie":{"sheltie","shelties"},
"shelty":{"shelties","shelty"},
"shelve":{"shelve","shelved","shelves","shelving"},
"shen-pao":{"shen-pao","shen-paos"},
"shenanigan":{"shenanigan","shenanigans"},
"shend":{"shend","shending","shends","shent"},
"shenyang":{"shenyang","shenyangs"},
"shepard":{"shepard","shepards"},
"shepherd":{"shepherd","shepherded","shepherding","shepherds"},
"sherbert":{"sherbert","sherberts"},
"sherbet":{"sherbet","sherbets"},
"sherd":{"sherd","sherds"},
"sheriff":{"sheriff","sheriffs"},
"sherlock":{"sherlock","sherlocks"},
"sherpa":{"sherpa","sherpas"},
"sherry":{"sherries","sherry"},
"shetland":{"shetland","shetlands"},
"shevat":{"shevat","shevats"},
"shew":{"shew","shewed","shewing","shewn","shews"},
"shf":{"shf","shfs"},
"shia":{"shia","shias"},
"shiah":{"shiah","shiahs"},
"shiatsu":{"shiatsu","shiatsus"},
"shibah":{"shibah","shibahs"},
"shibboleth":{"shibboleth","shibboleths"},
"shield":{"shield","shielded","shielding","shields"},
"shift":{"shift","shifted","shifting","shifts"},
"shiftiness":{"shiftiness","shiftinesses"},
"shifting":{"shifting","shiftings"},
"shifty":{"shiftier","shiftiest","shifty"},
"shigella":{"shigella","shigellae"},
"shigellosis":{"shigelloses","shigellosis"},
"shiitake":{"shiitake","shiitakes"},
"shiite":{"shiite","shiites"},
"shikar":{"shikar","shikarred","shikarring","shikars"},
"shikaree":{"shikaree","shikarees"},
"shikari":{"shikari","shikaris"},
"shiksa":{"shiksa","shiksas"},
"shikse":{"shikse","shikses"},
"shillalah":{"shillalah","shillalahs"},
"shillelagh":{"shillelagh","shillelaghs"},
"shilling":{"shilling","shillings"},
"shilly-shally":{"shilly-shallied","shilly-shallies","shilly-shally","shilly-shallying"},
"shillyshally":{"shillyshallies","shillyshally"},
"shiloh":{"shiloh","shilohs"},
"shim":{"shim","shimmed","shimming","shims"},
"shimmer":{"shimmer","shimmered","shimmering","shimmers"},
"shimmy":{"shimmied","shimmies","shimmy","shimmying"},
"shin":{"shin","shinned","shinning","shins"},
"shinbone":{"shinbone","shinbones"},
"shindig":{"shindig","shindigs"},
"shindy":{"shindies","shindy"},
"shine":{"shine","shined","shines","shining","shone"},
"shiner":{"shiner","shiners"},
"shingle":{"shingle","shingled","shingles","shingling"},
"shingler":{"shingler","shinglers"},
"shingles":{"shingles","shingleses"},
"shininess":{"shininess","shininesses"},
"shining":{"shining","shinings"},
"shinleaf":{"shinleaf","shinleaves"},
"shinny":{"shinnied","shinnies","shinny","shinnying","shinties"},
"shinpad":{"shinpad","shinpads"},
"shinto":{"shinto","shintos"},
"shintoism":{"shintoism","shintoisms"},
"shinty":{"shinties","shinty"},
"shiny":{"shinier","shiniest","shiny"},
"ship":{"ship","shipped","shipping","ships"},
"shipload":{"shipload","shiploads"},
"shipman":{"shipman","shipmen"},
"shipmaster":{"shipmaster","shipmasters"},
"shipment":{"shipment","shipments"},
"shipper":{"shipper","shippers"},
"shipping":{"shipping","shippings"},
"shipway":{"shipway","shipways"},
"shipworm":{"shipworm","shipworms"},
"shipwreck":{"shipwreck","shipwrecked","shipwrecking","shipwrecks"},
"shipyard":{"shipyard","shipyards"},
"shire":{"shire","shires"},
"shirk":{"shirk","shirked","shirking","shirks"},
"shirker":{"shirker","shirkers"},
"shirking":{"shirking","shirkings"},
"shirr":{"shirr","shirred","shirring"},
"shirt":{"shirt","shirts"},
"shirtfront":{"shirtfront","shirtfronts"},
"shirtwaist":{"shirtwaist","shirtwaists"},
"shirtwaister":{"shirtwaister","shirtwaisters"},
"shirty":{"shirtier","shirtiest","shirty"},
"shit":{"shat","shit","shits","shitting"},
"shithead":{"shithead","shitheads"},
"shitlist":{"shitlist","shitlists"},
"shittah":{"shittah","shittahs"},
"shittim":{"shittim","shittims"},
"shittimwood":{"shittimwood","shittimwoods"},
"shitting":{"shitting","shittings"},
"shitty":{"shittier","shittiest","shitty"},
"shiva":{"shiva","shivas"},
"shivah":{"shivah","shivahs"},
"shivaism":{"shivaism","shivaisms"},
"shivaree":{"shivaree","shivarees"},
"shiver":{"shiver","shivered","shivering","shivers"},
"shivering":{"shivering","shiverings"},
"shlemiel":{"shlemiel","shlemiels"},
"shlock":{"shlock","shlocks"},
"shlockmeister":{"shlockmeister","shlockmeisters"},
"shluh":{"shluh","shluhs"},
"shmear":{"shmear","shmears"},
"shmo":{"shmo","shmoes"},
"shoal":{"shoal","shoaled","shoaling","shoals"},
"shoaly":{"shoalier","shoaliest","shoaly"},
"shoat":{"shoat","shoats"},
"shock":{"shock","shocked","shocking","shocks"},
"shoddiness":{"shoddiness","shoddinesses"},
"shoddy":{"shoddier","shoddies","shoddiest","shoddy"},
"shoe":{"shod","shodden","shoe","shoed","shoeing","shoes"},
"shoebill":{"shoebill","shoebills"},
"shoebird":{"shoebird","shoebirds"},
"shoeblack":{"shoeblack","shoeblacks"},
"shoelace":{"shoelace","shoelaces"},
"shoemaker":{"shoemaker","shoemakers"},
"shoemaking":{"shoemaking","shoemakings"},
"shoes":{"shoes","shoeses"},
"shoeshop":{"shoeshop","shoeshops"},
"shoestring":{"shoestring","shoestrings"},
"shofar":{"shofar","shofars","shoforth","shofroth"},
"shogunate":{"shogunate","shogunates"},
"shoji":{"shoji","shojis"},
"shona":{"shona","shonas"},
"shoo":{"shoo","shooed","shooing","shoos"},
"shoo-in":{"shoo-in","shoo-ins"},
"shoofly":{"shooflies","shoofly"},
"shook":{"shook","shooked","shooking","shooks"},
"shoot":{"shoot","shooting","shoots","shot"},
"shooter":{"shooter","shooters"},
"shooting":{"shooting","shootings"},
"shootout":{"shootout","shootouts"},
"shop":{"shop","shopped","shopping","shops"},
"shopfront":{"shopfront","shopfronts"},
"shophar":{"shofroth","shophar","shophars"},
"shopkeeper":{"shopkeeper","shopkeepers"},
"shoplifter":{"shoplifter","shoplifters"},
"shopwalker":{"shopwalker","shopwalkers"},
"shopwindow":{"shopwindow","shopwindows"},
"shore":{"shore","shored","shores","shoring"},
"shorea":{"shorea","shoreas"},
"shorebird":{"shorebird","shorebirds"},
"shoreline":{"shoreline","shorelines"},
"shoring":{"shoring","shorings"},
"short":{"short","shorter","shortest","shorts"},
"short-circuit":{"short-circuit","short-circuited","short-circuiting","short-circuits"},
"short-stop":{"short-stop","short-stops"},
"short-wave":{"short-wave","short-waved","short-waving"},
"shortage":{"shortage","shortages"},
"shortbread":{"shortbread","shortbreads"},
"shortchange":{"shortchange","shortchanged","shortchanging"},
"shortcoming":{"shortcoming","shortcomings"},
"shortcut":{"shortcut","shortcuts"},
"shorten":{"shorten","shortened","shortening","shortens"},
"shortfall":{"shortfall","shortfalls"},
"shorthand":{"shorthand","shorthands"},
"shorthorn":{"shorthorn","shorthorns"},
"shortness":{"shortness","shortnesses"},
"shortsightedness":{"shortsightedness","shortsightednesses"},
"shortstop":{"shortstop","shortstops"},
"shorty":{"shorties","shorty"},
"shoshone":{"shoshone","shoshones"},
"shoshonean":{"shoshonean","shoshoneans"},
"shoshoni":{"shoshoni","shoshonis"},
"shoshonian":{"shoshonian","shoshonians"},
"shot":{"shot","shots","shotted","shotting"},
"shotgun":{"shotgun","shotguned","shotguning","shotguns"},
"shoulder":{"shoulder","shouldered","shouldering","shoulders"},
"shout":{"shout","shouted","shouting","shouts"},
"shouter":{"shouter","shouters"},
"shouting":{"shouting","shoutings"},
"shove":{"shove","shoved","shoves","shoving"},
"shove-halfpenny":{"shove-halfpennies","shove-halfpenny"},
"shovel":{"shovel","shoveled","shoveling","shovelled","shovelling","shovels"},
"shovelboard":{"shovelboard","shovelboards"},
"shoveler":{"shoveler","shovelers"},
"shovelful":{"shovelful","shovelfuls"},
"shovelhead":{"shovelhead","shovelheads"},
"show":{"show","showed","showing","shown","shows"},
"show-off":{"show-off","show-offs"},
"showcase":{"showcase","showcased","showcases","showcasing"},
"showdown":{"showdown","showdowns"},
"shower":{"shower","showered","showering","showers"},
"showgirl":{"showgirl","showgirls"},
"showiness":{"showiness","showinesses"},
"showing":{"showing","showings"},
"showjumping":{"showjumping","showjumpings"},
"showman":{"showman","showmen"},
"showpiece":{"showpiece","showpieces"},
"showroom":{"showroom","showrooms"},
"showy":{"showier","showiest","showy"},
"shred":{"shred","shredded","shredding","shreds"},
"shredder":{"shredder","shredders"},
"shreiking":{"shreiking","shreikings"},
"shrew":{"shrew","shrews"},
"shrewd":{"shrewd","shrewder","shrewdest"},
"shrewdness":{"shrewdness","shrewdnesses"},
"shrewmouse":{"shrewmice","shrewmouse"},
"shriek":{"shriek","shrieked","shrieking","shrieks"},
"shrieking":{"shrieking","shriekings"},
"shrievalty":{"shrievalties","shrievalty"},
"shrill":{"shrill","shrilled","shriller","shrillest","shrilling","shrills"},
"shrillness":{"shrillness","shrillnesses"},
"shrimp":{"shrimp","shrimped","shrimping","shrimps"},
"shrimpy":{"shrimpier","shrimpiest","shrimpy"},
"shrine":{"shrine","shrined","shrines","shrining"},
"shrink":{"shrank","shrink","shrinking","shrinks","shrunk","shrunken"},
"shrink-wrap":{"shrink-wrap","shrink-wrapped","shrink-wrapping","shrink-wraps"},
"shrinkage":{"shrinkage","shrinkages"},
"shrinking":{"shrinking","shrinkings"},
"shrive":{"shrive","shrived","shriven","shrives","shriving","shrove"},
"shrivel":{"shrivel","shriveled","shriveling","shrivelled","shrivelling","shrivels"},
"shroud":{"shroud","shrouded","shrouding","shrouds"},
"shrub":{"shrub","shrubs"},
"shrubbery":{"shrubberies","shrubbery"},
"shrubby":{"shrubbier","shrubbiest","shrubby"},
"shrug":{"shrug","shrugged","shrugging","shrugs"},
"sht-cut":{"sht-cut","sht-cutting"},
"shua":{"shua","shuas"},
"shuck":{"shuck","shucked","shucking","shucks"},
"shucks":{"shucks","shuckses"},
"shudder":{"shudder","shuddered","shuddering","shudders"},
"shudra":{"shudra","shudras"},
"shuffle":{"shuffle","shuffled","shuffles","shuffling"},
"shuffleboard":{"shuffleboard","shuffleboards"},
"shuffling":{"shuffling","shufflings"},
"shufty":{"shufties","shufty"},
"shuggy":{"shuggies","shuggy"},
"shul":{"shul","shuln"},
"shumac":{"shumac","shumacs"},
"shun":{"shun","shunned","shunning","shuns"},
"shunning":{"shunning","shunnings"},
"shunt":{"shunt","shunted","shunting","shunts"},
"shush":{"shush","shushed","shushing"},
"shut":{"shut","shuts","shutting"},
"shut-in":{"shut-in","shut-ins"},
"shutdown":{"shutdown","shutdowns"},
"shutter":{"shutter","shuttered","shuttering","shutters"},
"shutting":{"shutting","shuttings"},
"shuttle":{"shuttle","shuttled","shuttles","shuttling"},
"shuttlecock":{"shuttlecock","shuttlecocked","shuttlecocking","shuttlecocks"},
"shwa":{"shwa","shwas"},
"shy":{"shied","shier","shies","shiest","shy","shyer","shyest","shying"},
"shyster":{"shyster","shysters"},
"si":{"si","sis"},
"sialia":{"sialia","sialias"},
"sialidae":{"sialidae","sialidaes"},
"sialis":{"sialis","sialises"},
"sialolith":{"sialolith","sialoliths"},
"siam":{"siam","siams"},
"siamang":{"siamang","siamangs"},
"siamese":{"siamese","siameses"},
"sian":{"sian","sians"},
"sib":{"sib","sibs"},
"sibilant":{"sibilant","sibilants"},
"sibine":{"sibine","sibines"},
"sibling":{"sibling","siblings"},
"sic":{"sic","sicked","sicking","sics"},
"sichuan":{"sichuan","sichuans"},
"sicilia":{"sicilia","sicilias"},
"sicily":{"sicilies","sicily"},
"sick":{"sick","sicker","sickest","sicks"},
"sickbay":{"sickbay","sickbays"},
"sicken":{"sicken","sickened","sickening","sickens"},
"sickener":{"sickener","sickeners"},
"sickeningness":{"sickeningness","sickeningnesses"},
"sickle":{"sickle","sickles"},
"sicklepod":{"sicklepod","sicklepods"},
"sickly":{"sicklied","sicklier","sickliest","sickly","sicklying"},
"sickness":{"sickness","sicknesses"},
"sida":{"sida","sidas"},
"sidalcea":{"sidalcea","sidalceas"},
"siddhartha":{"siddhartha","siddharthas"},
"siddur":{"siddur","siddurim","siddurs"},
"side":{"side","sided","sides","siding"},
"side-glance":{"side-glance","side-glances"},
"side-look":{"side-look","side-looks"},
"side-step":{"side-step","side-stepped","side-stepping"},
"side-whiskers":{"side-whiskers","side-whiskerses"},
"sideboard":{"sideboard","sideboards"},
"sideburn":{"sideburn","sideburns"},
"sidekick":{"sidekick","sidekicks"},
"sidelight":{"sidelight","sidelights"},
"sideline":{"sideline","sidelines"},
"sideman":{"sideman","sidemen"},
"siderite":{"siderite","siderites"},
"sideritis":{"sideritis","sideritises"},
"sideslip":{"sideslip","sideslipped","sideslipping","sideslips"},
"sidesman":{"sidesman","sidesmen"},
"sidesplitter":{"sidesplitter","sidesplitters"},
"sidestep":{"sidestep","sidestepped","sidestepping","sidesteps"},
"sideswipe":{"sideswipe","sideswiped","sideswiping"},
"sidetrack":{"sidetrack","sidetracked","sidetracking","sidetracks"},
"sidewalk":{"sidewalk","sidewalks"},
"sidewinder":{"sidewinder","sidewinders"},
"siding":{"siding","sidings"},
"sidle":{"sidle","sidled","sidles","sidling"},
"sids":{"sids","sidses"},
"siege":{"siege","sieged","sieges","sieging"},
"siemens":{"siemens","siemenses"},
"sierra":{"sierra","sierras"},
"siesta":{"siesta","siestas"},
"sieve":{"sieve","sieved","sieves","sieving"},
"sift":{"sift","sifted","sifting","sifts"},
"sifting":{"sifting","siftings"},
"sigh":{"sigh","sighed","sighing","sighs"},
"sight":{"sight","sighted","sighting","sights"},
"sight-read":{"sight-read","sight-reading","sight-reads"},
"sightedness":{"sightedness","sightednesses"},
"sightlessness":{"sightlessness","sightlessnesses"},
"sightly":{"sightlier","sightliest","sightly"},
"sightsee":{"sightsaw","sightsee","sightseeing","sightseen","sightsees"},
"sightseeing":{"sightseeing","sightseeings"},
"sightseer":{"sightseer","sightseers"},
"sigint":{"sigint","sigints"},
"siglos":{"sigloi","siglos"},
"sigma":{"sigma","sigmas"},
"sigmodon":{"sigmodon","sigmodons"},
"sign":{"sign","signed","signing","signs"},
"signal":{"signal","signaled","signaling","signalled","signalling","signals"},
"signal-to-noise":{"signal-to-noise","signal-to-noises"},
"signal/noise":{"signal/noise","signal/noises"},
"signaler":{"signaler","signalers"},
"signaling":{"signaling","signalings"},
"signalize":{"signalize","signalized","signalizes","signalizing"},
"signaller":{"signaller","signallers"},
"signalman":{"signalman","signalmen"},
"signatory":{"signatories","signatory"},
"signature":{"signature","signatures"},
"signboard":{"signboard","signboards"},
"signer":{"signer","signers"},
"signet":{"signet","signeted","signeting","signets"},
"significance":{"significance","significances"},
"significant":{"significant","significants"},
"signification":{"signification","significations"},
"signify":{"signified","signifies","signify","signifying"},
"signing":{"signing","signings"},
"signior":{"signior","signiors"},
"signor":{"signor","signori","signors"},
"signora":{"signora","signoras","signore"},
"signorina":{"signorina","signorinas","signorine"},
"signory":{"signories","signory"},
"signpost":{"signpost","signposts"},
"sika":{"sika","sikas"},
"silage":{"silage","silages"},
"silence":{"silence","silenced","silences","silencing"},
"silencer":{"silencer","silencers"},
"silene":{"silene","silenes"},
"silent":{"silent","silents"},
"silesia":{"silesia","silesias"},
"silhouette":{"silhouette","silhouetted","silhouettes","silhouetting"},
"silica":{"silica","silicas"},
"silicify":{"silicified","silicifies","silicify","silicifying"},
"silicon":{"silicon","silicons"},
"silicone":{"silicone","silicones"},
"siliqua":{"siliqua","siliquas"},
"silique":{"silique","siliques"},
"silk":{"silk","silks"},
"silk-screen":{"silk-screen","silk-screens"},
"silkgrass":{"silkgrass","silkgrasses"},
"silkiness":{"silkiness","silkinesses"},
"silkweed":{"silkweed","silkweeds"},
"silkwood":{"silkwood","silkwoods"},
"silkworm":{"silkworm","silkworms"},
"silky":{"silkier","silkiest","silky"},
"sill":{"sill","sills"},
"sillabub":{"sillabub","sillabubs"},
"sillaginidae":{"sillaginidae","sillaginidaes"},
"sillago":{"sillago","sillagos"},
"silliness":{"silliness","sillinesses"},
"silly":{"sillier","sillies","silliest","silly"},
"silo":{"silo","silos"},
"silphium":{"silphium","silphiums"},
"silt":{"silt","silted","silting","silts"},
"silurian":{"silurian","silurians"},
"silurid":{"silurid","silurids"},
"siluridae":{"siluridae","siluridaes"},
"siluriformes":{"siluriformes","siluriformeses"},
"silurus":{"silurus","siluruses"},
"silva":{"silva","silvas"},
"silvan":{"silvan","silvans"},
"silvanus":{"silvanus","silvanuses"},
"silver":{"silver","silvered","silvering","silvers"},
"silver-lace":{"silver-lace","silver-laces"},
"silverberry":{"silverberries","silverberry"},
"silverbush":{"silverbush","silverbushes"},
"silverfish":{"silverfish","silverfishes"},
"silverlace":{"silverlace","silverlaces"},
"silverrod":{"silverrod","silverrods"},
"silverside":{"silverside","silversides"},
"silversides":{"silversides","silversideses"},
"silversmith":{"silversmith","silversmiths"},
"silversword":{"silversword","silverswords"},
"silvertip":{"silvertip","silvertips"},
"silvervine":{"silvervine","silvervines"},
"silverweed":{"silverweed","silverweeds"},
"silverworker":{"silverworker","silverworkers"},
"silvia":{"silvia","silvias"},
"silybum":{"silybum","silybums"},
"simal":{"simal","simals"},
"simarouba":{"simarouba","simaroubas"},
"simaroubaceae":{"simaroubaceae","simaroubaceaes"},
"similar":{"similar","similars"},
"similarity":{"similarities","similarity"},
"similitude":{"similitude","similitudes"},
"simmer":{"simmer","simmered","simmering"},
"simmering":{"simmering","simmerings"},
"simoom":{"simoom","simooms"},
"simoon":{"simoon","simoons"},
"simper":{"simper","simpered","simpering","simpers"},
"simple":{"simple","simpler","simples","simplest"},
"simpleness":{"simpleness","simplenesses"},
"simpleton":{"simpleton","simpletons"},
"simplex":{"simplex","simplexes","simplices"},
"simplicity":{"simplicities","simplicity"},
"simplification":{"simplification","simplifications"},
"simplify":{"simplified","simplifies","simplify","simplifying"},
"simpson":{"simpson","simpsons"},
"simulacrum":{"simulacra","simulacrum","simulacrums"},
"simulate":{"simulate","simulated","simulates","simulating"},
"simulation":{"simulation","simulations"},
"simulcast":{"simulcast","simulcasted","simulcasting"},
"simuliidae":{"simuliidae","simuliidaes"},
"simulium":{"simulium","simuliums"},
"simultaneity":{"simultaneities","simultaneity"},
"simultaneousness":{"simultaneousness","simultaneousnesses"},
"sin":{"sin","sinned","sinning","sins"},
"sinai":{"sinai","sinais"},
"sinanthropus":{"sinanthropus","sinanthropuses"},
"sinapis":{"sinapis","sinapises"},
"sinapism":{"sinapism","sinapisms"},
"sincere":{"sincere","sincerer","sincerest"},
"sincerity":{"sincerities","sincerity"},
"sinciput":{"sincipita","sinciput","sinciputs"},
"sindhi":{"sindhi","sindhis"},
"sinequan":{"sinequan","sinequans"},
"sinew":{"sinew","sinewed","sinewing","sinews"},
"sinfonia":{"sinfonia","sinfonie"},
"sinfonietta":{"sinfonietta","sinfoniettas"},
"sinfulness":{"sinfulness","sinfulnesses"},
"sing":{"sang","sing","singing","sings","sung"},
"sing-kwa":{"sing-kwa","sing-kwas"},
"singan":{"singan","singans"},
"singapore":{"singapore","singapores"},
"singe":{"singe","singed","singeing","singes"},
"singer":{"singer","singers"},
"singhalese":{"singhalese","singhaleses"},
"singing":{"singing","singings"},
"single":{"single","singled","singles","singling"},
"single-foot":{"single-feet","single-foot","single-footed","single-footing","single-foots"},
"single-leaf":{"single-leaf","single-leaves"},
"single-space":{"single-space","single-spaced","single-spacing"},
"single-step":{"single-step","single-stepped","single-stepping","single-steps"},
"singleness":{"singleness","singlenesses"},
"singlet":{"singlet","singlets"},
"singular":{"singular","singulars"},
"singularity":{"singularities","singularity"},
"singularize":{"singularize","singularized","singularizing"},
"singultus":{"singultus","singultuses"},
"sinhala":{"sinhala","sinhalas"},
"sinhalese":{"sinhalese","sinhaleses"},
"sinicize":{"sinicize","sinicized","sinicizing"},
"sinistrality":{"sinistralities","sinistrality"},
"sinitic":{"sinitic","sinitics"},
"sink":{"sank","sink","sinking","sinks","sunk","sunken"},
"sinker":{"sinker","sinkers"},
"sinkhole":{"sinkhole","sinkholes"},
"sinking":{"sinking","sinkings"},
"sinlessness":{"sinlessness","sinlessnesses"},
"sinner":{"sinner","sinners"},
"sinning":{"sinning","sinnings"},
"sinningia":{"sinningia","sinningias"},
"sino-tibetan":{"sino-tibetan","sino-tibetans"},
"sinoper":{"sinoper","sinopers"},
"sinopia":{"sinopia","sinopias"},
"sinopis":{"sinopis","sinopises"},
"sinuation":{"sinuation","sinuationtions"},
"sinuosity":{"sinuosities","sinuosity"},
"sinuousness":{"sinuousness","sinuousnesses"},
"sinus":{"sinus","sinuses"},
"sinusoid":{"sinusoid","sinusoids"},
"siouan":{"siouan","siouans"},
"sioux":{"sioux","siouxes"},
"sip":{"sip","sipped","sipping","sips"},
"siphon":{"siphon","siphoned","siphoning","siphons"},
"siphonaptera":{"siphonaptera","siphonapteras"},
"siphonophora":{"siphonophora","siphonophoras"},
"sipper":{"sipper","sippers"},
"sipping":{"sipping","sippings"},
"sipuncula":{"sipuncula","sipunculas"},
"sipunculid":{"sipunculid","sipunculids"},
"sir":{"sir","sirs"},
"siracusa":{"siracusa","siracusas"},
"sire":{"sire","sired","sires","siring"},
"siren":{"siren","sirens"},
"sirenia":{"sirenia","sirenias"},
"sirenian":{"sirenian","sirenians"},
"sirenidae":{"sirenidae","sirenidaes"},
"siriasis":{"siriases","siriasis"},
"siris":{"siris","sirises"},
"sirius":{"sirius","siriuses"},
"sirocco":{"sirocco","siroccos"},
"sirup":{"sirup","sirups"},
"sis":{"ses","sis"},
"sisal":{"sisal","sisals"},
"sise":{"ses","sise"},
"sisham":{"sisham","sishams"},
"siskin":{"siskin","siskins"},
"sison":{"sison","sisons"},
"sissiness":{"sissiness","sissinesses"},
"sissoo":{"sissoo","sissoos"},
"sissu":{"sissu","sissus"},
"sissy":{"sissies","sissy"},
"sister":{"sister","sisters"},
"sister-in-law":{"sister-in-law","sisters-in-law"},
"sisterhood":{"sisterhood","sisterhoods"},
"sistership":{"sistership","sisterships"},
"sistrum":{"sistra","sistrum"},
"sistrurus":{"sistrurus","sistruruses"},
"sisyridae":{"sisyridae","sisyridaes"},
"sisyrinchium":{"sisyrinchium","sisyrinchiums"},
"sit":{"sat","sit","sits","sitting"},
"sit-down":{"sit-down","sit-downs"},
"sit-in":{"sit-in","sit-ins"},
"site":{"site","sited","sites","siting"},
"sitophylus":{"sitophylus","sitophyluses"},
"sitotroga":{"sitotroga","sitotrogas"},
"sitsang":{"sitsang","sitsangs"},
"sitta":{"sitta","sittas"},
"sitter":{"sitter","sitters"},
"sittidae":{"sittidae","sittidaes"},
"sitting":{"sitting","sittings"},
"situate":{"situate","situated","situates","situating"},
"situating":{"situating","situatings"},
"situation":{"situation","situations"},
"situla":{"situla","situlae"},
"sium":{"sium","siums"},
"siva":{"siva","sivas"},
"sivaism":{"sivaism","sivaisms"},
"sivan":{"sivan","sivans"},
"siwan":{"siwan","siwans"},
"six":{"six","sixes"},
"six-gun":{"six-gun","six-guns"},
"six-shooter":{"six-shooter","six-shooters"},
"sixer":{"sixer","sixers"},
"sixmo":{"sixmo","sixmos"},
"sixpence":{"sixpence","sixpences"},
"sixsome":{"sixsome","sixsomes"},
"sixteen":{"sixteen","sixteens"},
"sixteenmo":{"sixteenmo","sixteenmos"},
"sixteenth":{"sixteenth","sixteenths"},
"sixth":{"sixth","sixths"},
"sixties":{"sixties","sixtieses"},
"sixty":{"sixties","sixty"},
"sixty-fourmo":{"sixty-fourmo","sixty-fourmos"},
"sixty-nine":{"sixty-nine","sixty-nines"},
"size":{"size","sized","sizes","sizing"},
"sizeableness":{"sizeableness","sizeablenesses"},
"sizing":{"sizing","sizings"},
"sizzle":{"sizzle","sizzled","sizzling"},
"sjaelland":{"sjaelland","sjaellands"},
"sk-ampicillin":{"sk-ampicillin","sk-ampicillins"},
"skate":{"skate","skated","skates","skating"},
"skateboard":{"skateboard","skateboarded","skateboarding"},
"skater":{"skater","skaters"},
"skates":{"skates","skateses"},
"skedaddle":{"skedaddle","skedaddled","skedaddling"},
"skeet":{"skeet","skeets"},
"skein":{"skein","skeins"},
"skeleton":{"skeleton","skeletons"},
"skeletonize":{"skeletonize","skeletonized","skeletonizing"},
"skelly":{"skellied","skellies","skelly","skellying"},
"skelter":{"skelter","skeltered","skeltering"},
"sken":{"sken","skenned","skenning","skens"},
"skeptic":{"skeptic","skeptics"},
"skepticism":{"skepticism","skepticisms"},
"skerry":{"skerries","skerry"},
"sket":{"sket","skets","sketted","sketting"},
"sketch":{"sketch","sketched","sketches","sketching"},
"sketchblock":{"sketchblock","sketchblocks"},
"sketchbook":{"sketchbook","sketchbooks"},
"sketchy":{"sketchier","sketchiest","sketchy"},
"skew":{"skew","skewed","skewing","skews"},
"skewer":{"skewer","skewered","skewering","skewers"},
"skewness":{"skewness","skewnesses"},
"ski":{"ski","skied","skiing","skis"},
"skiagram":{"skiagram","skiagrams"},
"skiagraph":{"skiagraph","skiagraphs"},
"skiagraphy":{"skiagraphies","skiagraphy"},
"skiamachy":{"skiamachies","skiamachy"},
"skid":{"skid","skidded","skidding","skids"},
"skiddoo":{"skiddoo","skiddooed","skiddooing"},
"skiddy":{"skiddier","skiddiest","skiddy"},
"skill":{"skill","skills"},
"skillet":{"skillet","skillets"},
"skilletfish":{"skilletfish","skilletfishes"},
"skim":{"skim","skimmed","skimming","skims"},
"skimmer":{"skimmer","skimmers"},
"skimming":{"skimming","skimmings"},
"skimp":{"skimp","skimped","skimping","skimps"},
"skimpy":{"skimpier","skimpiest","skimpy"},
"skin":{"skin","skinned","skinning","skins"},
"skin-dive":{"skin-dive","skin-dived","skin-dives","skin-diving","skin-dove"},
"skin-diver":{"skin-diver","skin-divers"},
"skin-pop":{"skin-pop","skin-popped","skin-popping","skin-pops"},
"skinflint":{"skinflint","skinflints"},
"skinful":{"skinful","skinfuls"},
"skink":{"skink","skinks"},
"skinner":{"skinner","skinners"},
"skinniness":{"skinniness","skinninesses"},
"skinny":{"skinnier","skinnies","skinniest","skinny"},
"skinny-dip":{"skinny-dip","skinny-dipped","skinny-dipping","skinny-dips","skinny-dipt"},
"skip":{"skip","skipped","skipping","skips"},
"skipjack":{"skipjack","skipjacks"},
"skipper":{"skipper","skippered","skippering","skippers"},
"skirl":{"skirl","skirled","skirling","skirls"},
"skirmish":{"skirmish","skirmished","skirmishes","skirmishing"},
"skirret":{"skirret","skirrets"},
"skirt":{"skirt","skirted","skirting","skirts"},
"skis":{"skis","skises"},
"skitter":{"skitter","skittered","skittering","skitters"},
"skittishness":{"skittishness","skittishnesses"},
"skittle":{"skittle","skittles"},
"skittles":{"skittles","skittleses"},
"skive":{"skive","skived","skiving"},
"skivvies":{"skivvies","skivvieses"},
"skivvy":{"skivvies","skivvy"},
"skollie":{"skollie","skollies"},
"skolly":{"skollies","skolly"},
"skua":{"skua","skuas"},
"skulduggery":{"skulduggeries","skulduggery"},
"skulk":{"skulk","skulked","skulking","skulks"},
"skulker":{"skulker","skulkers"},
"skulking":{"skulking","skulkings"},
"skull":{"skull","skulls"},
"skullcap":{"skullcap","skullcaps"},
"skullduggery":{"skullduggeries","skullduggery"},
"skunk":{"skunk","skunked","skunking","skunks"},
"skunkbush":{"skunkbush","skunkbushes"},
"skunkweed":{"skunkweed","skunkweeds"},
"sky":{"skied","skies","sky","skyed","skying"},
"sky-blue":{"sky-blue","sky-blues"},
"skydive":{"skydive","skydived","skydives","skydiving","skydove"},
"skydiver":{"skydiver","skydivers"},
"skyjack":{"skyjack","skyjacked","skyjacking"},
"skylark":{"skylark","skylarked","skylarking","skylarks"},
"skylight":{"skylight","skylighted","skylighting","skylights"},
"skyline":{"skyline","skylines"},
"skyrocket":{"skyrocket","skyrocketed","skyrocketing","skyrockets"},
"skyscraper":{"skyscraper","skyscrapers"},
"skywrite":{"skywrite","skywriting","skywritten","skywrote"},
"slab":{"slab","slabbed","slabbing","slabs"},
"slack":{"slack","slacked","slacker","slackest","slacking","slacks"},
"slacken":{"slacken","slackened","slackening","slackens"},
"slackening":{"slackening","slackenings"},
"slacker":{"slacker","slackers"},
"slacking":{"slacking","slackings"},
"slackness":{"slackness","slacknesses"},
"slag":{"slag","slagged","slagging","slags"},
"slaggy":{"slaggier","slaggiest","slaggy"},
"slake":{"slake","slaked","slakes","slaking"},
"slalom":{"slalom","slalomed","slaloming"},
"slam":{"slam","slammed","slamming","slams"},
"slander":{"slander","slandered","slandering","slanders"},
"slanderer":{"slanderer","slanderers"},
"slang":{"slang","slanged","slanging","slangs"},
"slangy":{"slangier","slangiest","slangy"},
"slant":{"slant","slanted","slanting","slants"},
"slant-eye":{"slant-eye","slant-eyes"},
"slap":{"slap","slapped","slapping","slaps"},
"slaphappy":{"slaphappier","slaphappiest","slaphappy"},
"slash":{"slash","slashed","slashes","slashing"},
"slashing":{"slashing","slashings"},
"slask":{"slask","slasks"},
"slat":{"slat","slats","slatted","slatting"},
"slate":{"slate","slated","slates","slating"},
"slater":{"slater","slaters"},
"slating":{"slating","slatings"},
"slattern":{"slattern","slatterns"},
"slatternliness":{"slatternliness","slatternlinesses"},
"slaty":{"slatier","slatiest","slaty"},
"slaughter":{"slaughter","slaughtered","slaughtering","slaughters"},
"slaughterer":{"slaughterer","slaughterers"},
"slaughterhouse":{"slaughterhouse","slaughterhouses"},
"slaughterman":{"slaughterman","slaughtermen"},
"slave":{"slave","slaved","slaves","slaving"},
"slave-maker":{"slave-maker","slave-makers"},
"slaveholder":{"slaveholder","slaveholders"},
"slaver":{"slaver","slavered","slavering","slavers"},
"slavery":{"slaveries","slavery"},
"slavey":{"slavey","slaveys"},
"slavic":{"slavic","slavics"},
"slavocracy":{"slavocracies","slavocracy"},
"slavonic":{"slavonic","slavonics"},
"slaw":{"slaw","slaws"},
"slay":{"slain","slay","slaying","slays","slew"},
"slayer":{"slayer","slayers"},
"slaying":{"slaying","slayings"},
"sle":{"sle","sles"},
"sleave":{"sleave","sleaved","sleaving"},
"sleaze":{"sleaze","sleazes"},
"sleazy":{"sleazier","sleaziest","sleazy"},
"sled":{"sled","sledded","sledding","sleds"},
"sledding":{"sledding","sleddings"},
"sledge":{"sledge","sledged","sledges","sledging"},
"sledgehammer":{"sledgehammer","sledgehammered","sledgehammering","sledgehammers"},
"sleek":{"sleek","sleeked","sleeker","sleekest","sleeking"},
"sleekness":{"sleekness","sleeknesses"},
"sleep":{"sleep","sleeping","sleeps","slept"},
"sleeper":{"sleeper","sleepers"},
"sleepiness":{"sleepiness","sleepinesses"},
"sleeping":{"sleeping","sleepings"},
"sleeplessness":{"sleeplessness","sleeplessnesses"},
"sleepwalk":{"sleepwalk","sleepwalked","sleepwalking","sleepwalks"},
"sleepwalker":{"sleepwalker","sleepwalkers"},
"sleepwalking":{"sleepwalking","sleepwalkings"},
"sleepy":{"sleepier","sleepiest","sleepy"},
"sleet":{"sleet","sleeted","sleeting"},
"sleety":{"sleetier","sleetiest","sleety"},
"sleeve":{"sleeve","sleeved","sleeves","sleeving"},
"sleigh":{"sleigh","sleighed","sleighing","sleighs"},
"sleight":{"sleight","sleights"},
"slenderize":{"slenderize","slenderized","slenderizes","slenderizing"},
"slenderness":{"slenderness","slendernesses"},
"sleuth":{"sleuth","sleuths"},
"sleuthhound":{"sleuthhound","sleuthhounds"},
"sleuthing":{"sleuthing","sleuthings"},
"slew":{"slew","slewed","slewing","slews"},
"slews":{"slews","slewses"},
"slezsko":{"slezsko","slezskos"},
"slice":{"slice","sliced","slices","slicing"},
"slick":{"slick","slicked","slicker","slickest","slicking","slicks"},
"slicker":{"slicker","slickers"},
"slickness":{"slickness","slicknesses"},
"slide":{"slid","slide","slides","sliding"},
"slider":{"slider","sliders"},
"slight":{"slight","slighted","slighter","slightest","slighting","slights"},
"slightness":{"slightness","slightnesses"},
"slim":{"slim","slimmed","slimmer","slimmest","slimming"},
"slime":{"slime","slimed","slimes","sliming"},
"sliminess":{"sliminess","sliminesses"},
"slimness":{"slimness","slimnesses"},
"slimsy":{"slimsier","slimsiest","slimsy"},
"slimy":{"slimier","slimiest","slimy"},
"sling":{"sling","slinging","slings","slung"},
"slingshot":{"slingshot","slingshots"},
"slink":{"slink","slinked","slinking","slinks","slunk"},
"slinky":{"slinkier","slinkiest","slinky"},
"slip":{"slip","slipped","slipping","slips"},
"slipcover":{"slipcover","slipcovered","slipcovering","slipcovers"},
"slipover":{"slipover","slipovers"},
"slipper":{"slipper","slippered","slippering","slippers"},
"slipperiness":{"slipperiness","slipperinesses"},
"slipperwort":{"slipperwort","slipperworts"},
"slippery":{"slipperier","slipperiest","slippery"},
"slippy":{"slippier","slippiest","slippy"},
"slipstick":{"slipstick","slipsticks"},
"slipstream":{"slipstream","slipstreams"},
"slipup":{"slipup","slipups"},
"slipway":{"slipway","slipways"},
"slit":{"slit","slits","slitting"},
"slither":{"slither","slithered","slithering","slithers"},
"sliver":{"sliver","slivered","slivering","slivers"},
"sloanea":{"sloanea","sloaneas"},
"slob":{"slob","slobs"},
"slobber":{"slobber","slobbered","slobbering","slobbers"},
"sloe":{"sloe","sloes"},
"slog":{"slog","slogged","slogging","slogs"},
"slogan":{"slogan","slogans"},
"sloganeer":{"sloganeer","sloganeered","sloganeering"},
"sloganize":{"sloganize","sloganized","sloganizing"},
"slogger":{"slogger","sloggers"},
"sloop":{"sloop","sloops"},
"slop":{"slop","slopped","slopping","slops"},
"slope":{"slope","sloped","slopes","sloping"},
"sloppiness":{"sloppiness","sloppinesses"},
"sloppy":{"sloppier","sloppiest","sloppy"},
"slops":{"slops","slopses"},
"slopshop":{"slopshop","slopshops"},
"slosh":{"slosh","sloshed","sloshes","sloshing"},
"slot":{"slot","slots","slotted","slotting"},
"sloth":{"sloth","sloths"},
"slothfulness":{"slothfulness","slothfulnesses"},
"slouch":{"slouch","slouched","slouches","slouching"},
"slouchy":{"slouchier","slouchiest","slouchy"},
"slough":{"slough","sloughed","sloughing","sloughs"},
"sloughing":{"sloughing","sloughings"},
"sloven":{"sloven","slovens"},
"slovenliness":{"slovenliness","slovenlinesses"},
"slovenly":{"slovenlier","slovenliest","slovenly"},
"slow":{"slow","slowed","slower","slowest","slowing"},
"slow-wittedness":{"slow-wittedness","slow-wittednesses"},
"slowcoach":{"slowcoach","slowcoaches"},
"slowdown":{"slowdown","slowdowns"},
"slowing":{"slowing","slowings"},
"slowness":{"slowness","slownesses"},
"slowpoke":{"slowpoke","slowpokes"},
"slowworm":{"slowworm","slowworms"},
"slub":{"slub","slubs"},
"slubber":{"slubber","slubbered","slubbering"},
"sludge":{"sludge","sludges"},
"sludgy":{"sludgier","sludgiest","sludgy"},
"slue":{"slue","slued","slues","sluing"},
"slug":{"slug","slugged","slugging","slugs"},
"slugabed":{"slugabed","slugabeds"},
"slugfest":{"slugfest","slugfests"},
"sluggard":{"sluggard","sluggards"},
"slugger":{"slugger","sluggers"},
"sluggishness":{"sluggishness","sluggishnesses"},
"sluice":{"sluice","sluiced","sluices","sluicing"},
"sluicegate":{"sluicegate","sluicegates"},
"sluiceway":{"sluiceway","sluiceways"},
"slum":{"slum","slummed","slumming","slums"},
"slumber":{"slumber","slumbered","slumbering","slumbers"},
"slumberer":{"slumberer","slumberers"},
"slummy":{"slummier","slummiest","slummy"},
"slump":{"slump","slumped","slumping","slumps"},
"slur":{"slur","slurred","slurring","slurs"},
"slurp":{"slurp","slurped","slurping"},
"slurry":{"slurries","slurry"},
"slush":{"slush","slushed","slushes","slushing"},
"slushy":{"slushier","slushiest","slushy"},
"slut":{"slut","sluts"},
"sluttishness":{"sluttishness","sluttishnesses"},
"sly":{"slier","sliest","sly","slyer","slyest"},
"slyboots":{"slyboots","slybootses"},
"slyness":{"slyness","slynesses"},
"sm":{"sm","sms"},
"smack":{"smack","smacked","smacking","smacks"},
"smacking":{"smacking","smackings"},
"small":{"small","smaller","smallest","smalls"},
"small-arm":{"small-arm","small-arms"},
"smallmouth":{"smallmouth","smallmouths"},
"smallness":{"smallness","smallnesses"},
"smallpox":{"smallpox","smallpoxes"},
"smalto":{"smalti","smalto","smaltos"},
"smarm":{"smarm","smarms"},
"smarminess":{"smarminess","smarminesses"},
"smarmy":{"smarmier","smarmiest","smarmy"},
"smart":{"smart","smarted","smarter","smartest","smarting","smarts"},
"smarten":{"smarten","smartened","smartening"},
"smarting":{"smarting","smartings"},
"smartness":{"smartness","smartnesses"},
"smarty":{"smarties","smarty"},
"smart_aleck":{"smart_aleck","smart_alecks"},
"smash":{"smash","smashed","smashes","smashing"},
"smash-up":{"smash-up","smash-ups"},
"smasher":{"smasher","smashers"},
"smashing":{"smashing","smashings"},
"smashup":{"smashup","smashups"},
"smatter":{"smatter","smattered","smattering","smatters"},
"smattering":{"smattering","smatterings"},
"smear":{"smear","smeared","smearing","smears"},
"smeary":{"smearier","smeariest","smeary"},
"smell":{"smell","smelled","smelling","smells","smelt"},
"smelling":{"smelling","smellings"},
"smelly":{"smellier","smelliest","smelly"},
"smelt":{"smelt","smelted","smelting","smelts"},
"smelter":{"smelter","smelters"},
"smeltery":{"smelteries","smeltery"},
"smew":{"smew","smews"},
"smidge":{"smidge","smidges"},
"smidgen":{"smidgen","smidgens"},
"smidgeon":{"smidgeon","smidgeons"},
"smidgin":{"smidgin","smidgins"},
"smilacaceae":{"smilacaceae","smilacaceaes"},
"smilax":{"smilax","smilaxes"},
"smile":{"smile","smiled","smiles","smiling"},
"smiledon":{"smiledon","smiledons"},
"smiler":{"smiler","smilers"},
"smiling":{"smiling","smilings"},
"smilo":{"smilo","smilos"},
"smirch":{"smirch","smirched","smirches","smirching"},
"smirk":{"smirk","smirked","smirking","smirks"},
"smite":{"smit","smite","smites","smiting","smitten","smote"},
"smith":{"smith","smiths"},
"smithery":{"smitheries","smithery"},
"smithy":{"smithies","smithy"},
"smock":{"smock","smocked","smocking","smocks"},
"smog":{"smog","smogs"},
"smogginess":{"smogginess","smogginesses"},
"smoke":{"smoke","smoked","smokes","smoking"},
"smokehouse":{"smokehouse","smokehouses"},
"smoker":{"smoker","smokers"},
"smokestack":{"smokestack","smokestacks"},
"smoking":{"smoking","smokings"},
"smoky":{"smokier","smokiest","smoky"},
"smolder":{"smolder","smoldered","smoldering","smolders"},
"smooch":{"smooch","smooched","smooches","smooching"},
"smooching":{"smooching","smoochings"},
"smooth":{"smooth","smoothed","smoother","smoothest","smoothing"},
"smoother":{"smoother","smoothers"},
"smoothhound":{"smoothhound","smoothhounds"},
"smoothie":{"smoothie","smoothies"},
"smoothy":{"smoothies","smoothy"},
"smother":{"smother","smothered","smothering","smothers"},
"smoulder":{"smoulder","smouldered","smouldering","smoulders"},
"smudge":{"smudge","smudged","smudges","smudging"},
"smudgy":{"smudgier","smudgiest","smudgy"},
"smug":{"smug","smugger","smuggest","smugs"},
"smuggle":{"smuggle","smuggled","smuggles","smuggling"},
"smuggler":{"smuggler","smugglers"},
"smut":{"smut","smuts","smutted","smutting"},
"smuttiness":{"smuttiness","smuttinesses"},
"smutty":{"smuttier","smuttiest","smutty"},
"smyrnium":{"smyrnium","smyrniums"},
"sn":{"sn","sns"},
"snack":{"snack","snacked","snacking","snacks"},
"snaffle":{"snaffle","snaffled","snaffles","snaffling"},
"snafu":{"snafu","snafued","snafues","snafuing","snafus"},
"snag":{"snag","snagged","snagging","snags"},
"snaggletooth":{"snaggleteeth","snaggletooth"},
"snail":{"snail","snails"},
"snailfish":{"snailfish","snailfishes"},
"snailflower":{"snailflower","snailflowers"},
"snake":{"snake","snaked","snakes","snaking"},
"snakeberry":{"snakeberries","snakeberry"},
"snakebird":{"snakebird","snakebirds"},
"snakeblenny":{"snakeblennies","snakeblenny"},
"snakefish":{"snakefish","snakefishes"},
"snakehead":{"snakehead","snakeheads"},
"snakeroot":{"snakeroot","snakeroots"},
"snakeweed":{"snakeweed","snakeweeds"},
"snakewood":{"snakewood","snakewoods"},
"snaky":{"snakier","snakiest","snaky"},
"snap":{"snap","snapped","snapping","snaps"},
"snapline":{"snapline","snaplines"},
"snapper":{"snapper","snappers"},
"snappishness":{"snappishness","snappishnesses"},
"snappy":{"snappier","snappiest","snappy"},
"snapshot":{"snapshot","snapshots","snapshotted","snapshotting"},
"snare":{"snare","snared","snares","snaring"},
"snarl":{"snarl","snarled","snarling","snarls"},
"snarl-up":{"snarl-up","snarl-ups"},
"snarly":{"snarlier","snarliest","snarly"},
"snatch":{"snatch","snatched","snatches","snatching"},
"snatcher":{"snatcher","snatchers"},
"snatchy":{"snatchier","snatchiest","snatchy"},
"snazzy":{"snazzier","snazziest","snazzy"},
"sneak":{"sneak","sneaked","sneaking","sneaks","snuck"},
"sneaker":{"sneaker","sneakers"},
"sneakiness":{"sneakiness","sneakinesses"},
"sneaky":{"sneakier","sneakiest","sneaky"},
"sned":{"sned","snedded","snedding","sneds"},
"sneer":{"sneer","sneered","sneering","sneers"},
"sneering":{"sneering","sneerings"},
"sneeze":{"sneeze","sneezed","sneezes","sneezing"},
"sneezer":{"sneezer","sneezers"},
"sneezewort":{"sneezewort","sneezeworts"},
"sneezing":{"sneezing","sneezings"},
"snick":{"snick","snicked","snicking","snicks"},
"snicker":{"snicker","snickered","snickering","snickers"},
"snickersnee":{"snickersnee","snickersnees"},
"snide":{"snide","snider","snidest"},
"sniff":{"sniff","sniffed","sniffing","sniffs"},
"sniffle":{"sniffle","sniffled","sniffles","sniffling"},
"sniffy":{"sniffier","sniffiest","sniffy"},
"snifter":{"snifter","snifters"},
"snigger":{"snigger","sniggers"},
"sniggle":{"sniggle","sniggled","sniggling"},
"snip":{"snip","snipped","snipping","snips"},
"snipe":{"snipe","sniped","snipes","sniping"},
"snipefish":{"snipefish","snipefishes"},
"sniper":{"sniper","snipers"},
"snippet":{"snippet","snippets"},
"snipping":{"snipping","snippings"},
"snippy":{"snippier","snippiest","snippy"},
"snips":{"snips","snipses"},
"snitch":{"snitch","snitched","snitches","snitching"},
"snivel":{"snivel","sniveled","sniveling","snivelled","snivelling","snivels"},
"sniveler":{"sniveler","snivelers"},
"sniveling":{"sniveling","snivelings"},
"snob":{"snob","snobs"},
"snobbery":{"snobberies","snobbery"},
"snobbishness":{"snobbishness","snobbishnesses"},
"snog":{"snog","snogged","snogging","snogs"},
"snood":{"snood","snooded","snooding"},
"snook":{"snook","snooks"},
"snoop":{"snoop","snooped","snooping","snoops"},
"snooper":{"snooper","snoopers"},
"snoopiness":{"snoopiness","snoopinesses"},
"snoopy":{"snoopier","snoopiest","snoopy"},
"snoot":{"snoot","snooted","snooting","snoots"},
"snooty":{"snootier","snootiest","snooty"},
"snooze":{"snooze","snoozed","snoozes","snoozing"},
"snore":{"snore","snored","snores","snoring"},
"snorer":{"snorer","snorers"},
"snoring":{"snoring","snorings"},
"snorkel":{"snorkel","snorkels"},
"snorkeling":{"snorkeling","snorkelings"},
"snort":{"snort","snorted","snorting","snorts"},
"snorter":{"snorter","snorters"},
"snorting":{"snorting","snortings"},
"snot":{"snot","snots"},
"snotty":{"snottier","snotties","snottiest","snotty"},
"snout":{"snout","snouts"},
"snow":{"snow","snowed","snowing","snows"},
"snow-in-summer":{"snow-in-summer","snow-in-summers"},
"snow-on-the-mountain":{"snow-on-the-mountain","snow-on-the-mountains"},
"snowball":{"snowball","snowballed","snowballing","snowballs"},
"snowbank":{"snowbank","snowbanks"},
"snowbell":{"snowbell","snowbells"},
"snowberry":{"snowberries","snowberry"},
"snowbird":{"snowbird","snowbirds"},
"snowdrop":{"snowdrop","snowdrops"},
"snowfall":{"snowfall","snowfalls"},
"snowflake":{"snowflake","snowflakes"},
"snowman":{"snowman","snowmen"},
"snowplough":{"snowplough","snowploughs"},
"snowplow":{"snowplow","snowplows"},
"snowshoe":{"snowshoe","snowshoed","snowshoeing","snowshoes"},
"snowstorm":{"snowstorm","snowstorms"},
"snowy":{"snowier","snowiest","snowy"},
"snub":{"snub","snubbed","snubbing","snubs"},
"snubber":{"snubber","snubbers"},
"snuff":{"snuff","snuffed","snuffing","snuffs"},
"snuff-color":{"snuff-color","snuff-colors"},
"snuff-colour":{"snuff-colour","snuff-colours"},
"snuffle":{"snuffle","snuffled","snuffles","snuffling"},
"snuffy":{"snuffier","snuffiest","snuffy"},
"snug":{"snug","snugged","snugger","snuggest","snugging","snugs"},
"snuggery":{"snuggeries","snuggery"},
"snuggle":{"snuggle","snuggled","snuggles","snuggling"},
"snuggling":{"snuggling","snugglings"},
"snugness":{"snugness","snugnesses"},
"so":{"so","sos"},
"so-and-so":{"so-and-so","so-and-sos"},
"soak":{"soak","soaked","soaking","soaks"},
"soakage":{"soakage","soakages"},
"soaker":{"soaker","soakers"},
"soaking":{"soaking","soakings"},
"soap":{"soap","soaped","soaping","soaps"},
"soapberry":{"soapberries","soapberry"},
"soapbox":{"soapbox","soapboxes"},
"soaprock":{"soaprock","soaprocks"},
"soapstone":{"soapstone","soapstones"},
"soapsuds":{"soapsuds","soapsudses"},
"soapweed":{"soapweed","soapweeds"},
"soapwort":{"soapwort","soapworts"},
"soapy":{"soapier","soapiest","soapy"},
"soar":{"soar","soared","soaring","soars"},
"soaring":{"soaring","soarings"},
"sob":{"sob","sobbed","sobbing","sobs"},
"sobbing":{"sobbing","sobbings"},
"sober":{"sober","sobered","soberer","soberest","sobering"},
"soberness":{"soberness","sobernesses"},
"sobriety":{"sobrieties","sobriety"},
"sobriquet":{"sobriquet","sobriquets"},
"soccer":{"soccer","soccers"},
"sociability":{"sociabilities","sociability"},
"sociable":{"sociable","sociables"},
"sociableness":{"sociableness","sociablenesses"},
"social":{"social","socials"},
"socialisation":{"socialisation","socialisations"},
"socialism":{"socialism","socialisms"},
"socialist":{"socialist","socialists"},
"sociality":{"socialities","sociality"},
"socialization":{"socialization","socializations"},
"socialize":{"socialize","socialized","socializes","socializing"},
"socializing":{"socializing","socializings"},
"society":{"societies","society"},
"sociopath":{"sociopath","sociopaths"},
"sock":{"sock","socked","socking","socks","sox"},
"socket":{"socket","socketed","socketing","sockets"},
"sockeye":{"sockeye","sockeyes"},
"socman":{"socman","socmen"},
"sod":{"sod","sodded","sodding","sods"},
"soda":{"soda","sodas"},
"sodality":{"sodalities","sodality"},
"sodbuster":{"sodbuster","sodbusters"},
"sodden":{"sodden","soddened","soddening"},
"soddy":{"soddier","soddies","soddiest","soddy"},
"sodium":{"sodium","sodiums"},
"sodoku":{"sodoku","sodokus"},
"sodomist":{"sodomist","sodomists"},
"sodomite":{"sodomite","sodomites"},
"sodomy":{"sodomies","sodomy"},
"sofa":{"sofa","sofas"},
"sofia":{"sofia","sofias"},
"soft":{"soft","softer","softest"},
"soft-cover":{"soft-cover","soft-covers"},
"soft-pedal":{"soft-pedal","soft-pedaled","soft-pedaling","soft-pedalled","soft-pedalling","soft-pedals"},
"soft-shoe":{"soft-shoe","soft-shoes"},
"soft-soap":{"soft-soap","soft-soaped","soft-soaping"},
"softback":{"softback","softbacks"},
"softball":{"softball","softballs"},
"soften":{"soften","softened","softening","softens"},
"softheartedness":{"softheartedness","softheartednesses"},
"softie":{"softie","softies"},
"software":{"software","softwares"},
"softwood":{"softwood","softwoods"},
"softy":{"softies","softy"},
"soggy":{"soggier","soggiest","soggy"},
"soh":{"soh","sohs"},
"soil":{"soil","soiled","soiling","soils"},
"soiling":{"soiling","soilings"},
"soilure":{"soilure","soilures"},
"soissons":{"soissons","soissonses"},
"soixante-neuf":{"soixante-neuf","soixante-neufs"},
"soja":{"soja","sojas"},
"sojourn":{"sojourn","sojourned","sojourning","sojourns"},
"sokeman":{"socmen","sokeman","sokemen"},
"sol":{"sol","sols"},
"sol-fa":{"sol-fa","sol-faed","sol-faing","sol-fas"},
"solace":{"solace","solaced","solaces","solacing"},
"solacement":{"solacement","solacements"},
"solan":{"solan","solans"},
"solanaceae":{"solanaceae","solanaceaes"},
"solandra":{"solandra","solandras"},
"solanopteris":{"solanopteris","solanopterises"},
"solanum":{"solanum","solanums"},
"solarium":{"solaria","solarium","solariums"},
"solatium":{"solatia","solatium"},
"solder":{"solder","soldered","soldering"},
"soldering":{"soldering","solderings"},
"soldier":{"soldier","soldiered","soldiering","soldiers"},
"soldiering":{"soldiering","soldierings"},
"soldiership":{"soldiership","soldierships"},
"soldiery":{"soldieries","soldiery"},
"soldo":{"soldi","soldo"},
"sole":{"sole","soled","soles","soling"},
"solea":{"solea","soleas"},
"solecism":{"solecism","solecisms"},
"soleidae":{"soleidae","soleidaes"},
"soleirolia":{"soleirolia","soleirolias"},
"solemness":{"solemness","solemnesses"},
"solemnify":{"solemnified","solemnifies","solemnify","solemnifying"},
"solemnity":{"solemnities","solemnity"},
"solemnization":{"solemnization","solemnizations"},
"solemnize":{"solemnize","solemnized","solemnizing"},
"solenichthyes":{"solenichthyes","solenichthyeses"},
"solenidae":{"solenidae","solenidaes"},
"solenogaster":{"solenogaster","solenogasters"},
"solenogastres":{"solenogastres","solenogastreses"},
"solenopsis":{"solenopses","solenopsis"},
"solenostemon":{"solenostemon","solenostemons"},
"soleus":{"soleus","soleuses"},
"solfa":{"solfa","solfas"},
"solfege":{"solfege","solfeges"},
"solfeggio":{"solfegfeggi","solfegfeggios","solfeggi","solfeggio","solfeggios"},
"solferino":{"solferino","solferinos"},
"solicit":{"solicit","solicited","soliciting","solicits"},
"solicitation":{"solicitation","solicitations"},
"solicitor":{"solicitor","solicitors"},
"solicitousness":{"solicitousness","solicitousnesses"},
"solicitude":{"solicitude","solicitudes"},
"solid":{"solid","solider","solidest","solids"},
"solidago":{"solidago","solidagos"},
"solidarity":{"solidarities","solidarity"},
"solidification":{"solidification","solidifications"},
"solidify":{"solidified","solidifies","solidify","solidifying"},
"solidifying":{"solidifying","solidifyings"},
"solidity":{"solidities","solidity"},
"solidness":{"solidness","solidnesses"},
"solidus":{"solidi","solidus","soliduses"},
"soliloquize":{"soliloquize","soliloquized","soliloquizes","soliloquizing"},
"soliloquy":{"soliloquies","soliloquy","soliloquys"},
"solitaire":{"solitaire","solitaires"},
"solitariness":{"solitariness","solitarinesses"},
"solitary":{"solitaries","solitary"},
"solitude":{"solitude","solitudes"},
"solitudinarian":{"solitudinarian","solitudinarians"},
"solleret":{"solleret","sollerets"},
"solmisation":{"solmisation","solmisations"},
"solmization":{"solmization","solmizations"},
"solo":{"soli","solo","soloed","soloing","solos"},
"solon":{"solon","solons"},
"solubility":{"solubilities","solubility"},
"solubleness":{"solubleness","solublenesses"},
"solum":{"sola","solum","solums"},
"solution":{"solution","solutions"},
"solve":{"solve","solved","solves","solving"},
"solvent":{"solvent","solvents"},
"solving":{"solving","solvings"},
"soma":{"soma","somas","somata"},
"somaesthesia":{"somaesthesia","somaesthesias"},
"somaesthesis":{"somaestheses","somaesthesis"},
"somali":{"somali","somalis"},
"somalia":{"somalia","somalias"},
"somatatesthesis":{"somatatestheses","somatatesthesis"},
"somateria":{"somateria","somaterias"},
"somatesthesia":{"somatesthesia","somatesthesias"},
"somatotrophin":{"somatotrophin","somatotrophins"},
"somatotropin":{"somatotropin","somatotropins"},
"somatotype":{"somatotype","somatotypes"},
"somberness":{"somberness","sombernesses"},
"sombreness":{"sombreness","sombrenesses"},
"sombrero":{"sombrero","sombreros"},
"somebody":{"somebodies","somebody"},
"someone":{"someone","someones"},
"somersault":{"somersault","somersaulted","somersaulting","somersaults"},
"somersaulting":{"somersaulting","somersaultings"},
"somesthesia":{"somesthesia","somesthesias"},
"somesthesis":{"somestheses","somesthesis"},
"something":{"something","somethings"},
"somite":{"somite","somites"},
"somme":{"somme","sommes"},
"sommelier":{"sommelier","sommeliers"},
"somnambulate":{"somnambulate","somnambulated","somnambulates","somnambulating"},
"somnambulism":{"somnambulism","somnambulisms"},
"somnambulist":{"somnambulist","somnambulists"},
"somniloquism":{"somniloquism","somniloquisms"},
"somniloquy":{"somniloquy","somniloquys"},
"somnolence":{"somnolence","somnolences"},
"somrai":{"somrai","somrais"},
"son":{"son","sons"},
"son-in-law":{"son-in-law","sons-in-law"},
"sonant":{"sonant","sonants"},
"sonar":{"sonar","sonars"},
"sonata":{"sonata","sonatas"},
"sonatina":{"sonatina","sonatinas","sonatine"},
"sonchus":{"sonchus","sonchuses"},
"sondage":{"sondage","sondages"},
"song":{"song","songs"},
"songbird":{"songbird","songbirds"},
"songfulness":{"songfulness","songfulnesses"},
"songhai":{"songhai","songhais"},
"songster":{"songster","songsters"},
"songwriter":{"songwriter","songwriters"},
"sonnet":{"sonnet","sonnets"},
"sonny":{"sonnies","sonny"},
"sonography":{"sonographies","sonography"},
"sonora":{"sonora","sonoras"},
"sonority":{"sonorities","sonority"},
"sonorousness":{"sonorousness","sonorousnesses"},
"sonsy":{"sonsier","sonsiest","sonsy"},
"soon":{"soon","sooner","soonest"},
"soot":{"soot","sooted","sooting","soots"},
"soothe":{"soothe","soothed","soothes","soothing"},
"soothsay":{"soothsaid","soothsay","soothsaying","soothsays"},
"soothsayer":{"soothsayer","soothsayers"},
"soothsaying":{"soothsaying","soothsayings"},
"sootiness":{"sootiness","sootinesses"},
"sooty":{"sootier","sootiest","sooty"},
"sop":{"sop","sopped","sopping","sops"},
"sophi":{"sophi","sophies"},
"sophism":{"sophism","sophisms"},
"sophist":{"sophist","sophists"},
"sophisticate":{"sophisticate","sophisticated","sophisticates","sophisticating"},
"sophistication":{"sophistication","sophistications"},
"sophistry":{"sophistries","sophistry"},
"sophomore":{"sophomore","sophomores"},
"sophora":{"sophora","sophoras"},
"sophy":{"sophies","sophy"},
"soporific":{"soporific","soporifics"},
"soppy":{"soppier","soppiest","soppy"},
"sopranino":{"sopranino","sopraninos"},
"soprano":{"soprano","sopranos"},
"sops":{"sops","sopses"},
"sora":{"sora","soras"},
"sorb":{"sorb","sorbs"},
"sorbent":{"sorbent","sorbents"},
"sorbet":{"sorbet","sorbets"},
"sorbian":{"sorbian","sorbians"},
"sorbus":{"sorbus","sorbuses"},
"sorcerer":{"sorcerer","sorcerers"},
"sorcery":{"sorceries","sorcery"},
"sordidness":{"sordidness","sordidnesses"},
"sordino":{"sordini","sordino"},
"sore":{"sore","sorer","sores","sorest"},
"soreness":{"soreness","sorenesses"},
"sorex":{"sorex","sorexes"},
"sorgho":{"sorgho","sorghos"},
"sorghum":{"sorghum","sorghums"},
"sorgo":{"sorgo","sorgos"},
"soricidae":{"soricidae","soricidaes"},
"sorority":{"sororities","sorority"},
"sorosis":{"soroses","sorosis"},
"sorrel":{"sorrel","sorrels"},
"sorriness":{"sorriness","sorrinesses"},
"sorrow":{"sorrow","sorrowed","sorrowing","sorrows"},
"sorrowfulness":{"sorrowfulness","sorrowfulnesses"},
"sorry":{"sorrier","sorriest","sorry"},
"sort":{"sort","sorted","sorting","sorts"},
"sortie":{"sortie","sorties"},
"sorting":{"sorting","sortings"},
"sortition":{"sortition","sortitions"},
"sorus":{"sori","sorus"},
"sos":{"sos","soss"},
"sostenuto":{"sostenuti","sostenuto","sostenutos"},
"sot":{"sot","sots"},
"sothis":{"sothis","sothises"},
"sotho":{"sotho","sothos"},
"sou":{"sou","sous"},
"souari":{"souari","souaris"},
"soubise":{"soubise","soubises"},
"soubriquet":{"soubriquet","soubriquets"},
"soudan":{"soudan","soudans"},
"sough":{"sough","soughed","soughing","soughs"},
"soul":{"soul","souls"},
"soul-searching":{"soul-searching","soul-searchings"},
"soulfulness":{"soulfulness","soulfulnesses"},
"sound":{"sound","sounded","sounder","soundest","sounding","sounds"},
"soundboard":{"soundboard","soundboards"},
"sounding":{"sounding","soundings"},
"soundlessness":{"soundlessness","soundlessnesses"},
"soundness":{"soundness","soundnesses"},
"soundproof":{"soundproof","soundproofed","soundproofing"},
"soup":{"soup","souped","souping","soups"},
"soup-strainer":{"soup-strainer","soup-strainers"},
"soupcon":{"soupcon","soupcons"},
"soupfin":{"soupfin","soupfins"},
"soupiness":{"soupiness","soupinesses"},
"soupspoon":{"soupspoon","soupspoons"},
"soupy":{"soupier","soupiest","soupy"},
"sour":{"sour","soured","sourer","sourest","souring","sours"},
"sourbread":{"sourbread","sourbreads"},
"source":{"source","sources"},
"sourdine":{"sourdine","sourdines"},
"sourness":{"sourness","sournesses"},
"sourpuss":{"sourpuss","sourpusses"},
"soursop":{"soursop","soursops"},
"sourwood":{"sourwood","sourwoods"},
"sousa":{"sousa","sousas"},
"sousaphone":{"sousaphone","sousaphones"},
"souse":{"souse","soused","souses","sousing"},
"sousing":{"sousing","sousings"},
"souslik":{"souslik","sousliks"},
"south":{"south","souths"},
"southeast":{"southeast","southeasts"},
"southeaster":{"southeaster","southeasters"},
"southeasterly":{"southeasterlies","southeasterly"},
"souther":{"souther","southers"},
"southerly":{"southerlies","southerly"},
"southern":{"southern","southerns"},
"southernwood":{"southernwood","southernwoods"},
"southland":{"southland","southlands"},
"southpaw":{"southpaw","southpaws"},
"southwest":{"southwest","southwests"},
"southwester":{"southwester","southwesters"},
"southwesterly":{"southwesterlies","southwesterly"},
"southwestern":{"southwestern","southwesterns"},
"souvenir":{"souvenir","souvenirs"},
"souvlaki":{"souvlaki","souvlakis"},
"souvlakia":{"souvlakia","souvlakias"},
"sovereign":{"sovereign","sovereigns"},
"sovereignty":{"sovereignties","sovereignty"},
"soviet":{"soviet","soviets"},
"sovietism":{"sovietism","sovietisms"},
"sovkhoz":{"sovkhoz","sovkhozy"},
"sow":{"sow","sowed","sowing","sown","sows"},
"sowbane":{"sowbane","sowbanes"},
"sowbread":{"sowbread","sowbreads"},
"soy":{"soy","soys"},
"soya":{"soya","soyas"},
"soyabean":{"soyabean","soyabeans"},
"soyamilk":{"soyamilk","soyamilks"},
"soybean":{"soybean","soybeans"},
"soymilk":{"soymilk","soymilks"},
"spa":{"spa","spas"},
"space":{"space","spaced","spaces","spacing"},
"space-time":{"space-time","space-times"},
"spacecraft":{"spacecraft","spacecrafts"},
"spacefaring":{"spacefaring","spacefarings"},
"spaceflight":{"spaceflight","spaceflights"},
"spaceman":{"spaceman","spacemen"},
"spaceship":{"spaceship","spaceships"},
"spacewoman":{"spacewoman","spacewomen"},
"spacing":{"spacing","spacings"},
"spaciousness":{"spaciousness","spaciousnesses"},
"spackle":{"spackle","spackles"},
"spade":{"spade","spaded","spades","spading"},
"spadefish":{"spadefish","spadefishes"},
"spadefoot":{"spadefoot","spadefoots"},
"spadeful":{"spadeful","spadefuls"},
"spadix":{"spadices","spadix"},
"spado":{"spado","spadones","spados"},
"spag":{"spag","spagged","spagging","spags"},
"spahee":{"spahee","spahees"},
"spahi":{"spahi","spahis"},
"spain":{"spain","spains"},
"spalacidae":{"spalacidae","spalacidaes"},
"spalax":{"spalax","spalaxes"},
"span":{"span","spanned","spanning","spans"},
"spancel":{"spancel","spanceled","spanceling","spancelled","spancelling","spancels"},
"spangle":{"spangle","spangled","spangles","spangling"},
"spanish":{"spanish","spanishes"},
"spank":{"spank","spanked","spanking","spanks"},
"spanking":{"spanking","spankings"},
"spanner":{"spanner","spanners"},
"spar":{"spar","sparred","sparring","spars"},
"sparaxis":{"sparaxes","sparaxis"},
"spare":{"spare","spared","sparer","spares","sparest","sparing"},
"spareness":{"spareness","sparenesses"},
"spareribs":{"spareribs","spareribses"},
"sparganiaceae":{"sparganiaceae","sparganiaceaes"},
"sparganium":{"sparganium","sparganiums"},
"sparge":{"sparge","sparged","sparging"},
"sparid":{"sparid","sparids"},
"sparidae":{"sparidae","sparidaes"},
"spark":{"spark","sparked","sparking","sparks"},
"sparkle":{"sparkle","sparkled","sparkles","sparkling"},
"sparkleberry":{"sparkleberries","sparkleberry"},
"sparkling":{"sparkling","sparklings"},
"sparkplug":{"sparkplug","sparkplugged","sparkplugging","sparkplugs"},
"sparling":{"sparling","sparlings"},
"sparmannia":{"sparmannia","sparmannias"},
"sparrow":{"sparrow","sparrows"},
"sparse":{"sparse","sparser","sparsest"},
"sparseness":{"sparseness","sparsenesses"},
"sparsity":{"sparsities","sparsity"},
"spartina":{"spartina","spartinas"},
"spartium":{"spartium","spartiums"},
"spasm":{"spasm","spasms"},
"spasmolytic":{"spasmolytic","spasmolytics"},
"spat":{"spat","spats"},
"spatangoida":{"spatangoida","spatangoidas"},
"spatchcock":{"spatchcock","spatchcocked","spatchcocking"},
"spate":{"spate","spates"},
"spathiphyllum":{"spathiphyllum","spathiphyllums"},
"spatiality":{"spatialities","spatiality"},
"spats":{"spats","spatses"},
"spatter":{"spatter","spattered","spattering","spatters"},
"spatterdock":{"spatterdock","spatterdocks"},
"spattering":{"spattering","spatterings"},
"spatula":{"spatula","spatulas"},
"spawn":{"spawn","spawned","spawning","spawns"},
"spay":{"spay","spayed","spaying","spays"},
"speak":{"speak","speaking","speaks","spoke","spoken"},
"speakeasy":{"speakeasies","speakeasy"},
"speaker":{"speaker","speakers"},
"speaking":{"speaking","speakings"},
"spear":{"spear","speared","spearing","spears"},
"spearfish":{"spearfish","spearfishes"},
"spearhead":{"spearhead","spearheaded","spearheading","spearheads"},
"spearman":{"spearman","spearmen"},
"spearmint":{"spearmint","spearmints"},
"spec":{"spec","specs"},
"specialisation":{"specialisation","specialisations"},
"specialise":{"specialise","specialised","specialising"},
"specialism":{"specialism","specialisms"},
"specialist":{"specialist","specialists"},
"speciality":{"specialities","speciality"},
"specialization":{"specialization","specializations"},
"specialize":{"specialize","specialized","specializes","specializing"},
"specializer":{"specializer","specializers"},
"specialness":{"specialness","specialnesses"},
"specialty":{"specialties","specialty"},
"specie":{"specie","species"},
"species":{"species"},
"specific":{"specific","specifics"},
"specification":{"specification","specifications"},
"specify":{"specified","specifies","specify","specifying"},
"specimen":{"specimen","specimens"},
"speciosity":{"speciosities","speciosity"},
"speciousness":{"speciousness","speciousnesses"},
"speck":{"speck","specked","specking","specks"},
"speckle":{"speckle","speckled","speckles","speckling"},
"specs":{"specs","specses"},
"spectacle":{"spectacle","spectacles"},
"spectacles":{"spectacles","spectacleses"},
"spectacular":{"spectacular","spectaculars"},
"spectate":{"spectate","spectated","spectating"},
"spectator":{"spectator","spectators"},
"specter":{"specter","specters"},
"spectre":{"spectre","spectres"},
"spectrogram":{"spectrogram","spectrograms"},
"spectrograph":{"spectrograph","spectrographs"},
"spectrometer":{"spectrometer","spectrometers"},
"spectrometry":{"spectrometries","spectrometry"},
"spectroscope":{"spectroscope","spectroscopes"},
"spectroscopy":{"spectroscopies","spectroscopy"},
"spectrum":{"spectra","spectrum","spectrums"},
"speculate":{"speculate","speculated","speculates","speculating"},
"speculation":{"speculation","speculations"},
"speculator":{"speculator","speculators"},
"speculum":{"specula","speculum","speculums"},
"speech":{"speech","speeches"},
"speechify":{"speechified","speechifies","speechify","speechifying"},
"speechmaker":{"speechmaker","speechmakers"},
"speed":{"sped","speed","speeded","speeding","speeds"},
"speeder":{"speeder","speeders"},
"speeding":{"speeding","speedings"},
"speedo":{"speedo","speedos"},
"speedometer":{"speedometer","speedometers"},
"speedread":{"speedread","speedreading"},
"speedup":{"speedup","speedups"},
"speedwell":{"speedwell","speedwells"},
"speedy":{"speedier","speediest","speedy"},
"spelaeologist":{"spelaeologist","spelaeologists"},
"spelaeology":{"spelaeologies","spelaeology"},
"speleologist":{"speleologist","speleologists"},
"speleology":{"speleologies","speleology"},
"spell":{"spell","spelled","spelling","spells","spelt"},
"spell-checker":{"spell-checker","spell-checkers"},
"spellbind":{"spellbind","spellbinding","spellbinds","spellbound"},
"spelldown":{"spelldown","spelldowns"},
"speller":{"speller","spellers"},
"spelling":{"spelling","spellings"},
"spelt":{"spelt","spelts"},
"spelunker":{"spelunker","spelunkers"},
"spend":{"spend","spending","spends","spent"},
"spend-all":{"spend-all","spend-alls"},
"spender":{"spender","spenders"},
"spending":{"spending","spendings"},
"spendthrift":{"spendthrift","spendthrifts"},
"spenser":{"spenser","spensers"},
"spergula":{"spergula","spergulas"},
"spergularia":{"spergularia","spergularias"},
"sperm":{"sperm","sperms"},
"spermary":{"spermaries","spermary"},
"spermatium":{"spermatia","spermatium"},
"spermatocide":{"spermatocide","spermatocides"},
"spermatogonium":{"spermatogonia","spermatogonium"},
"spermatophyta":{"spermatophyta","spermatophytas"},
"spermatophyte":{"spermatophyte","spermatophytes"},
"spermatozoid":{"spermatozoid","spermatozoids"},
"spermatozoon":{"spermatozoa","spermatozoon","spermatozoons"},
"spermicide":{"spermicide","spermicides"},
"spermogonium":{"spermogonia","spermogonium"},
"spermophile":{"spermophile","spermophiles"},
"spermophilus":{"spermophilus","spermophiluses"},
"spew":{"spew","spewed","spewing","spews"},
"sphacele":{"sphacele","sphaceles"},
"sphacelotheca":{"sphacelotheca","sphacelothecas"},
"sphaeralcea":{"sphaeralcea","sphaeralceas"},
"sphaeriaceae":{"sphaeriaceae","sphaeriaceaes"},
"sphaeriales":{"sphaeriales","sphaerialeses"},
"sphaerobolaceae":{"sphaerobolaceae","sphaerobolaceaes"},
"sphaerocarpaceae":{"sphaerocarpaceae","sphaerocarpaceaes"},
"sphaerocarpales":{"sphaerocarpales","sphaerocarpaleses"},
"sphaerocarpos":{"sphaerocarpos","sphaerocarposes"},
"sphaerocarpus":{"sphaerocarpus","sphaerocarpuses"},
"sphagnales":{"sphagnales","sphagnaleses"},
"sphagnum":{"sphagnum","sphagnums"},
"sphalerite":{"sphalerite","sphalerites"},
"sphecidae":{"sphecidae","sphecidaes"},
"sphecius":{"sphecius","spheciuses"},
"sphecoid":{"sphecoid","sphecoids"},
"sphecoidea":{"sphecoidea","sphecoideas"},
"sphecotheres":{"sphecotheres","sphecothereses"},
"spheniscidae":{"spheniscidae","spheniscidaes"},
"sphenisciformes":{"sphenisciformes","sphenisciformeses"},
"spheniscus":{"spheniscus","spheniscuses"},
"sphenodon":{"sphenodon","sphenodons"},
"sphenopsida":{"sphenopsida","sphenopsidas"},
"sphere":{"sphere","sphered","spheres","sphering"},
"sphericalness":{"sphericalness","sphericalnesses"},
"sphericity":{"sphericities","sphericity"},
"spheroid":{"spheroid","spheroids"},
"sphincter":{"sphincter","sphincters"},
"sphingid":{"sphingid","sphingids"},
"sphingidae":{"sphingidae","sphingidaes"},
"sphinx":{"sphinges","sphinx","sphinxes"},
"sphyraena":{"sphyraena","sphyraenas"},
"sphyraenidae":{"sphyraenidae","sphyraenidaes"},
"sphyrapicus":{"sphyrapicus","sphyrapicuses"},
"sphyrna":{"sphyrna","sphyrnas"},
"sphyrnidae":{"sphyrnidae","sphyrnidaes"},
"spic":{"spic","spics"},
"spica":{"spica","spicae","spicas"},
"spice":{"spice","spiced","spices","spicing"},
"spiceberry":{"spiceberries","spiceberry"},
"spicebush":{"spicebush","spicebushes"},
"spicery":{"spiceries","spicery"},
"spiciness":{"spiciness","spicinesses"},
"spick":{"spick","spicks"},
"spicule":{"spicule","spicules"},
"spiculum":{"spiculum","spiculums"},
"spicy":{"spicier","spiciest","spicy"},
"spider":{"spider","spiders"},
"spiderflower":{"spiderflower","spiderflowers"},
"spiderman":{"spiderman","spidermen"},
"spiderwort":{"spiderwort","spiderworts"},
"spiegel":{"spiegel","spiegels"},
"spiegeleisen":{"spiegeleisen","spiegeleisens"},
"spiel":{"spiel","spieled","spieling","spiels"},
"spiffy":{"spiffier","spiffiest","spiffy"},
"spigot":{"spigot","spigots"},
"spik":{"spik","spiks"},
"spike":{"spike","spiked","spikes","spiking"},
"spikemoss":{"spikemoss","spikemosses"},
"spikenard":{"spikenard","spikenards"},
"spiky":{"spikier","spikiest","spiky"},
"spile":{"spile","spiles"},
"spill":{"spill","spilled","spilling","spills","spilt"},
"spillage":{"spillage","spillages"},
"spillikin":{"spillikin","spillikins"},
"spillikins":{"spillikins","spillikinses"},
"spillway":{"spillway","spillways"},
"spilogale":{"spilogale","spilogales"},
"spin":{"spin","spinning","spins","spun"},
"spin-dry":{"spin-dried","spin-dries","spin-dry","spin-drying"},
"spin-off":{"spin-off","spin-offs"},
"spinach":{"spinach","spinaches"},
"spinacia":{"spinacia","spinacias"},
"spinal":{"spinal","spinals"},
"spindle":{"spindle","spindled","spindles","spindling"},
"spindleberry":{"spindleberries","spindleberry"},
"spindlelegs":{"spindlelegs","spindlelegses"},
"spindleshanks":{"spindleshanks","spindleshankses"},
"spindly":{"spindlier","spindliest","spindly"},
"spindrift":{"spindrift","spindrifts"},
"spine":{"spine","spines"},
"spinner":{"spinner","spinners"},
"spinnery":{"spinneries","spinnery"},
"spinney":{"spinney","spinneys"},
"spinster":{"spinster","spinsters"},
"spinus":{"spinus","spinuses"},
"spiny":{"spinier","spiniest","spiny"},
"spiraea":{"spiraea","spiraeas"},
"spiral":{"spiral","spiraled","spiraling","spiralled","spiralling","spirals"},
"spirant":{"spirant","spirants"},
"spiranthes":{"spiranthes","spirantheses"},
"spire":{"spire","spired","spires","spiring"},
"spirea":{"spirea","spireas"},
"spirilla":{"spirilla","spirillas"},
"spirillaceae":{"spirillaceae","spirillaceaes"},
"spirillum":{"spirilla","spirillum","spirillums"},
"spirit":{"spirit","spirited","spiriting","spirits"},
"spiritedness":{"spiritedness","spiritednesses"},
"spiritlessness":{"spiritlessness","spiritlessnesses"},
"spirits":{"spirits","spiritses"},
"spiritual":{"spiritual","spirituals"},
"spiritualisation":{"spiritualisation","spiritualisations"},
"spiritualist":{"spiritualist","spiritualists"},
"spirituality":{"spiritualities","spirituality"},
"spiritualization":{"spiritualization","spiritualizations"},
"spiritualize":{"spiritualize","spiritualized","spiritualizing"},
"spiritualty":{"spiritualties","spiritualty"},
"spirochaeta":{"spirochaeta","spirochaetas"},
"spirochaetaceae":{"spirochaetaceae","spirochaetaceaes"},
"spirochaetales":{"spirochaetales","spirochaetaleses"},
"spirochaete":{"spirochaete","spirochaetes"},
"spirochete":{"spirochete","spirochetes"},
"spirodela":{"spirodela","spirodelas"},
"spironolactone":{"spironolactone","spironolactones"},
"spirt":{"spirt","spirted","spirting","spirts"},
"spirula":{"spirula","spirulas"},
"spirulidae":{"spirulidae","spirulidaes"},
"spiry":{"spirier","spiriest","spiry"},
"spit":{"spat","spit","spits","spitted","spitting"},
"spite":{"spite","spited","spites","spiting"},
"spitefulness":{"spitefulness","spitefulnesses"},
"spitting":{"spitting","spittings"},
"spittle":{"spittle","spittles"},
"spittlebug":{"spittlebug","spittlebugs"},
"spittoon":{"spittoon","spittoons"},
"spizella":{"spizella","spizellas"},
"splash":{"splash","splashed","splashes","splashing"},
"splashboard":{"splashboard","splashboards"},
"splashguard":{"splashguard","splashguards"},
"splashiness":{"splashiness","splashinesses"},
"splashing":{"splashing","splashings"},
"splashy":{"splashier","splashiest","splashy"},
"splatter":{"splatter","splattered","splattering","splatters"},
"splattering":{"splattering","splatterings"},
"splay":{"splay","splayed","splaying","splays"},
"splayfoot":{"splayfeet","splayfoot","splayfoots"},
"spleen":{"spleen","spleens"},
"splendor":{"splendor","splendors"},
"splendour":{"splendour","splendours"},
"splenectomy":{"splenectomies","splenectomy"},
"splenius":{"splenii","splenius"},
"splice":{"splice","spliced","splices","splicing"},
"splicing":{"splicing","splicings"},
"spline":{"spline","splines"},
"splint":{"splint","splinted","splinting","splints"},
"splinter":{"splinter","splintered","splintering","splinters"},
"splintering":{"splintering","splinterings"},
"splinters":{"splinters","splinterses"},
"split":{"split","splits","splitting"},
"splitsaw":{"splitsaw","splitsaws"},
"splitworm":{"splitworm","splitworms"},
"splodge":{"splodge","splodges"},
"splotch":{"splotch","splotched","splotches","splotching"},
"splotchy":{"splotchier","splotchiest","splotchy"},
"splurge":{"splurge","splurged","splurges","splurging"},
"splutter":{"splutter","spluttered","spluttering","splutters"},
"spodoptera":{"spodoptera","spodopteras"},
"spoil":{"spoil","spoiled","spoiling","spoils","spoilt"},
"spoilables":{"spoilables","spoilableses"},
"spoilage":{"spoilage","spoilages"},
"spoilation":{"spoilation","spoilations"},
"spoiler":{"spoiler","spoilers"},
"spoiling":{"spoiling","spoilings"},
"spoilsman":{"spoilsman","spoilsmen"},
"spoilsport":{"spoilsport","spoilsports"},
"spoke":{"spoke","spoked","spokes","spoking"},
"spokesman":{"spokesman","spokesmen"},
"spokesperson":{"spokesperson","spokespersons"},
"spokeswoman":{"spokeswoman","spokeswomen"},
"spoliate":{"spoliate","spoliated","spoliating"},
"spoliation":{"spoliation","spoliations"},
"spondias":{"spondias","spondiases"},
"sponge":{"sponge","sponged","sponges","sponging"},
"spongefly":{"spongeflies","spongefly"},
"sponger":{"sponger","spongers"},
"spongillafly":{"spongillaflies","spongillafly"},
"sponginess":{"sponginess","sponginesses"},
"spongy":{"spongier","spongiest","spongy"},
"sponsor":{"sponsor","sponsored","sponsoring","sponsors"},
"spontaneity":{"spontaneities","spontaneity"},
"spontaneousness":{"spontaneousness","spontaneousnesses"},
"spoof":{"spoof","spoofed","spoofing","spoofs"},
"spook":{"spook","spooks"},
"spooky":{"spookier","spookiest","spooky"},
"spool":{"spool","spooled","spooling","spools"},
"spoon":{"spoon","spooned","spooning","spoons"},
"spoon-feed":{"spoon-fed","spoon-feed","spoon-feeding","spoon-feeds"},
"spoondrift":{"spoondrift","spoondrifts"},
"spooney":{"spooney","spoonies"},
"spoonflower":{"spoonflower","spoonflowers"},
"spoonful":{"spoonful","spoonfuls"},
"spoony":{"spoonier","spoonies","spooniest","spoony"},
"spoor":{"spoor","spoored","spooring"},
"sporangium":{"sporangium","sporangiums"},
"spore":{"spore","spores"},
"sporobolus":{"sporobolus","sporoboluses"},
"sporocarp":{"sporocarp","sporocarps"},
"sporogonium":{"sporogonia","sporogonium"},
"sporophyl":{"sporophyl","sporophyls"},
"sporophyll":{"sporophyll","sporophylls"},
"sporozoa":{"sporozoa","sporozoas"},
"sport":{"sport","sported","sporting","sports"},
"sportiveness":{"sportiveness","sportivenesses"},
"sportscaster":{"sportscaster","sportscasters"},
"sportsman":{"sportsman","sportsmen"},
"sportswoman":{"sportswoman","sportswomen"},
"sports_arena":{"sports_arena","sports_arenas"},
"sporty":{"sportier","sportiest","sporty"},
"sporulate":{"sporulate","sporulated","sporulating"},
"sporulation":{"sporulation","sporulations"},
"spot":{"spot","spots","spotted","spotting"},
"spot-check":{"spot-check","spot-checked","spot-checking"},
"spotlessness":{"spotlessness","spotlessnesses"},
"spotlight":{"spotlight","spotlighted","spotlighting","spotlights","spotlit"},
"spotsylvania":{"spotsylvania","spotsylvanias"},
"spotter":{"spotter","spotters"},
"spotting":{"spotting","spottings"},
"spotty":{"spottier","spottiest","spotty"},
"spouse":{"spouse","spoused","spouses","spousing"},
"spout":{"spout","spouted","spouting","spouts"},
"spraddle":{"spraddle","spraddled","spraddling"},
"sprag":{"sprag","sprags"},
"spraguea":{"spraguea","spragueas"},
"sprain":{"sprain","sprained","spraining","sprains"},
"sprat":{"sprat","sprats"},
"sprawl":{"sprawl","sprawled","sprawling","sprawls"},
"sprawling":{"sprawling","sprawlings"},
"spray":{"spray","sprayed","spraying","sprays"},
"sprayer":{"sprayer","sprayers"},
"spraying":{"spraying","sprayings"},
"spread":{"spread","spreading","spreads"},
"spread-eagle":{"spread-eagle","spread-eagled","spread-eagles","spread-eagling"},
"spreader":{"spreader","spreaders"},
"spreadhead":{"spreadhead","spreadheads"},
"spreading":{"spreading","spreadings"},
"spree":{"spree","spreed","spreeing","sprees"},
"sprig":{"sprig","sprigged","sprigging","sprigs"},
"sprightliness":{"sprightliness","sprightlinesses"},
"sprightly":{"sprightlier","sprightliest","sprightly"},
"sprigtail":{"sprigtail","sprigtails"},
"spring":{"sprang","spring","springing","springs","sprung"},
"springbok":{"springbok","springboks"},
"springbuck":{"springbuck","springbucks"},
"springer":{"springer","springers"},
"springfield":{"springfield","springfields"},
"springhaas":{"springhaas","springhase"},
"springhouse":{"springhouse","springhouses"},
"springiness":{"springiness","springinesses"},
"springtail":{"springtail","springtails"},
"springtime":{"springtime","springtimes"},
"springy":{"springier","springiest","springy"},
"sprinkle":{"sprinkle","sprinkled","sprinkles","sprinkling"},
"sprinkles":{"sprinkles","sprinkleses"},
"sprinkling":{"sprinkling","sprinklings"},
"sprint":{"sprint","sprinted","sprinting","sprints"},
"sprite":{"sprite","sprites"},
"sprites":{"sprites","spriteses"},
"sprocket":{"sprocket","sprockets"},
"sprout":{"sprout","sprouted","sprouting","sprouts"},
"sprouting":{"sprouting","sproutings"},
"spruce":{"spruce","spruced","sprucer","spruces","sprucest","sprucing"},
"spruceness":{"spruceness","sprucenesses"},
"spry":{"sprier","spriest","spry","spryer","spryest"},
"spud":{"spud","spudded","spudding","spuds"},
"spue":{"spue","spued","spues","spuing"},
"spug":{"spug","spugs"},
"spuggy":{"spuggies","spuggy"},
"spume":{"spume","spumed","spumes","spuming"},
"spumone":{"spumone","spumoni"},
"spunk":{"spunk","spunks"},
"spunky":{"spunkier","spunkiest","spunky"},
"spur":{"spur","spurred","spurring","spurs"},
"spurn":{"spurn","spurned","spurning","spurns"},
"spurrey":{"spurrey","spurries"},
"spurring":{"spurring","spurrings"},
"spurry":{"spurries","spurry"},
"spurt":{"spurt","spurted","spurting","spurts"},
"sputnik":{"sputnik","sputniks"},
"sputter":{"sputter","sputtered","sputtering","sputters"},
"sputtering":{"sputtering","sputterings"},
"sputum":{"sputa","sputum","sputums"},
"spy":{"spied","spies","spy","spying"},
"spyeria":{"spyeria","spyerias"},
"spyglass":{"spyglass","spyglasses"},
"spyhole":{"spyhole","spyholes"},
"spying":{"spying","spyings"},
"squab":{"squab","squabs"},
"squabble":{"squabble","squabbled","squabbles","squabbling"},
"squabby":{"squabbier","squabbiest","squabby"},
"squacco":{"squacco","squaccos"},
"squad":{"squad","squads"},
"squalidae":{"squalidae","squalidaes"},
"squalidness":{"squalidness","squalidnesses"},
"squall":{"squall","squalled","squalling","squalls"},
"squally":{"squallier","squalliest","squally"},
"squalor":{"squalor","squalors"},
"squalus":{"squalus","squaluses"},
"squama":{"squama","squamae"},
"squamata":{"squamata","squamatas"},
"squander":{"squander","squandered","squandering","squanders"},
"squanderer":{"squanderer","squanderers"},
"square":{"square","squared","squarer","squares","squarest","squaring"},
"square-dance":{"square-dance","square-danced","square-dancing"},
"squark":{"squark","squarks"},
"squash":{"squash","squashed","squashes","squashing"},
"squashy":{"squashier","squashiest","squashy"},
"squat":{"squat","squats","squatted","squatter","squattest","squatting"},
"squatina":{"squatina","squatinas"},
"squatinidae":{"squatinidae","squatinidaes"},
"squatness":{"squatness","squatnesses"},
"squatter":{"squatter","squatters"},
"squattiness":{"squattiness","squattinesses"},
"squatting":{"squatting","squattings"},
"squatty":{"squattier","squattiest","squatty"},
"squaw":{"squaw","squaws"},
"squawbush":{"squawbush","squawbushes"},
"squawk":{"squawk","squawked","squawking","squawks"},
"squawker":{"squawker","squawkers"},
"squawky":{"squawkier","squawkiest","squawky"},
"squawroot":{"squawroot","squawroots"},
"squeak":{"squeak","squeaked","squeaking","squeaks"},
"squeaker":{"squeaker","squeakers"},
"squeaky":{"squeakier","squeakiest","squeaky"},
"squeal":{"squeal","squealed","squealing","squeals"},
"squealer":{"squealer","squealers"},
"squeamishness":{"squeamishness","squeamishnesses"},
"squeegee":{"squeegee","squeegeed","squeegeeing","squeegees","squilgee"},
"squeezability":{"squeezabilities","squeezability"},
"squeeze":{"squeeze","squeezed","squeezes","squeezing"},
"squelch":{"squelch","squelched","squelches","squelching"},
"squeteague":{"squeteague","squeteagues"},
"squib":{"squib","squibbed","squibbing","squibs"},
"squid":{"squid","squids"},
"squiffy":{"squiffier","squiffiest","squiffy"},
"squiggle":{"squiggle","squiggles"},
"squill":{"squill","squills"},
"squilla":{"squilla","squillas"},
"squillidae":{"squillidae","squillidaes"},
"squint":{"squint","squinted","squinter","squintest","squinting","squints"},
"squinty":{"squintier","squintiest","squinty"},
"squire":{"squire","squired","squires","squiring"},
"squirearchy":{"squirearchies","squirearchy"},
"squirm":{"squirm","squirmed","squirming","squirms"},
"squirmy":{"squirmier","squirmiest","squirmy"},
"squirrel":{"squirrel","squirreled","squirreling","squirrelled","squirrelling","squirrels"},
"squirrelfish":{"squirrelfish","squirrelfishes"},
"squirt":{"squirt","squirted","squirting","squirts"},
"squish":{"squish","squished","squishes","squishing"},
"squiz":{"squiz","squizzes"},
"sr":{"sr","srs"},
"srbija":{"srbija","srbijas"},
"sse":{"sse","sses"},
"ssw":{"ssw","ssws"},
"stab":{"stab","stabbed","stabbing","stabs"},
"stabilisation":{"stabilisation","stabilisations"},
"stability":{"stabilities","stability"},
"stabilization":{"stabilization","stabilizations"},
"stabilize":{"stabilize","stabilized","stabilizing"},
"stable":{"stable","stabled","stables","stabling"},
"stableboy":{"stableboy","stableboys"},
"stableman":{"stableman","stablemen"},
"stablemate":{"stablemate","stablemates"},
"stableness":{"stableness","stablenesses"},
"stabroek":{"stabroek","stabroeks"},
"staccato":{"staccati","staccato","staccatos"},
"stachys":{"stachys","stachyses"},
"stack":{"stack","stacked","stacking","stacks"},
"stacks":{"stacks","stackses"},
"stadium":{"stadia","stadium","stadiums"},
"staff":{"staff","staffed","staffing","staffs","staves"},
"staffer":{"staffer","staffers"},
"staffman":{"staffman","staffmen"},
"stag":{"stag","stagged","stagging","stags"},
"stage":{"stage","staged","stages","staging"},
"stage-manage":{"stage-manage","stage-managed","stage-managing"},
"stagecoach":{"stagecoach","stagecoaches"},
"stagehand":{"stagehand","stagehands"},
"stager":{"stager","stagers"},
"stagger":{"stagger","staggered","staggering","staggers"},
"staggerbush":{"staggerbush","staggerbushes"},
"staghead":{"staghead","stagheads"},
"staginess":{"staginess","staginesses"},
"staging":{"staging","stagings"},
"stagnancy":{"stagnancies","stagnancy"},
"stagnate":{"stagnate","stagnated","stagnates","stagnating"},
"stagnation":{"stagnation","stagnations"},
"stagy":{"stagier","stagiest","stagy"},
"staid":{"staid","staider","staidest"},
"staidness":{"staidness","staidnesses"},
"stain":{"stain","stained","staining","stains"},
"staining":{"staining","stainings"},
"stair":{"stair","stairs"},
"staircase":{"staircase","staircases"},
"stairs":{"stairs","stairses"},
"stairway":{"stairway","stairways"},
"stake":{"stake","staked","stakes","staking"},
"stakes":{"stakes","stakeses"},
"staking":{"staking","stakings"},
"stale":{"stale","staled","staler","stalest","staling"},
"stalemate":{"stalemate","stalemated","stalemates","stalemating"},
"staleness":{"staleness","stalenesses"},
"stalin":{"stalin","stalins"},
"stalingrad":{"stalingrad","stalingrads"},
"stalinism":{"stalinism","stalinisms"},
"stalino":{"stalino","stalinos"},
"stalk":{"stalk","stalked","stalking","stalks"},
"stalking":{"stalking","stalkings"},
"stalking-horse":{"stalking-horse","stalking-horses"},
"stalky":{"stalkier","stalkiest","stalky"},
"stall":{"stall","stalled","stalling","stalls"},
"stall-feed":{"stall-fed","stall-feed","stall-feeding","stall-feeds"},
"stalling":{"stalling","stallings"},
"stallion":{"stallion","stallions"},
"stalls":{"stalls","stallses"},
"stalwart":{"stalwart","stalwarts"},
"stalwartness":{"stalwartness","stalwartnesses"},
"stamboul":{"stamboul","stambouls"},
"stambul":{"stambul","stambuls"},
"stamen":{"stamen","stamens","stamina"},
"stamina":{"stamina","staminas"},
"staminode":{"staminode","staminodes"},
"staminodium":{"staminodium","staminonodia"},
"stammer":{"stammer","stammered","stammering","stammers"},
"stammerer":{"stammerer","stammerers"},
"stamp":{"stamp","stamped","stamping","stamps"},
"stampede":{"stampede","stampeded","stampedes","stampeding"},
"stanch":{"stanch","stanched","stancher","stanchest","stanching"},
"stanchion":{"stanchion","stanchioned","stanchioning"},
"stand":{"stand","standing","stands","stood"},
"stand-in":{"stand-in","stand-ins"},
"standard":{"standard","standards"},
"standard-bearer":{"standard-bearer","standard-bearers"},
"standardisation":{"standardisation","standardisations"},
"standardization":{"standardization","standardizations"},
"standardize":{"standardize","standardized","standardizes","standardizing"},
"standby":{"standbies","standby","standbys"},
"standing":{"standing","standings"},
"standoff":{"standoff","standoffs"},
"standoffishness":{"standoffishness","standoffishnesses"},
"standpoint":{"standpoint","standpoints"},
"stands":{"stands","standses"},
"standstill":{"standstill","standstills"},
"stanford":{"stanford","stanfords"},
"stanleya":{"stanleya","stanleyas"},
"stannary":{"stannaries","stannary"},
"stannite":{"stannite","stannites"},
"stanza":{"stanza","stanzas"},
"stapelia":{"stapelia","stapelias"},
"stapes":{"stapedes","stapes","stapeses"},
"staph":{"staph","staphs"},
"staphylaceae":{"staphylaceae","staphylaceaes"},
"staphylea":{"staphylea","staphyleas"},
"staphylinidae":{"staphylinidae","staphylinidaes"},
"staphylococci":{"staphylococci","staphylococcis"},
"staphylococcus":{"staphylococci","staphylococcus","staphylococcuses"},
"staple":{"staple","stapled","staples","stapling"},
"stapler":{"stapler","staplers"},
"star":{"star","starred","starring","stars"},
"star-duckweed":{"star-duckweed","star-duckweeds"},
"star-glory":{"star-glories","star-glory"},
"star-thistle":{"star-thistle","star-thistles"},
"starboard":{"starboard","starboarded","starboarding"},
"starch":{"starch","starched","starches","starching"},
"starchy":{"starchier","starchiest","starchy"},
"stare":{"stare","stared","stares","staring"},
"starets":{"starets","startsy"},
"starfish":{"starfish","starfishes"},
"starflower":{"starflower","starflowers"},
"stargaze":{"stargaze","stargazed","stargazes","stargazing"},
"stargazer":{"stargazer","stargazers"},
"stark":{"stark","starker","starkest"},
"starkness":{"starkness","starknesses"},
"starlet":{"starlet","starlets"},
"starry":{"starrier","starriest","starry"},
"start":{"start","started","starting","starts"},
"start-off":{"start-off","start-offs"},
"starter":{"starter","starters"},
"starting":{"starting","startings"},
"startle":{"startle","startled","startles","startling"},
"startup":{"startup","startups"},
"starvation":{"starvation","starvations"},
"starve":{"starve","starved","starves","starving"},
"starving":{"starving","starvings"},
"starwort":{"starwort","starworts"},
"stash":{"stash","stashed","stashes","stashing"},
"stasis":{"stases","stasis"},
"state":{"state","stated","states","stating"},
"statecraft":{"statecraft","statecrafts"},
"stateliness":{"stateliness","statelinesses"},
"stately":{"statelier","stateliest","stately"},
"statement":{"statement","statements"},
"stateroom":{"stateroom","staterooms"},
"statesman":{"statesman","statesmen"},
"statesmanship":{"statesmanship","statesmanships"},
"stateswoman":{"stateswoman","stateswomen"},
"static":{"static","statics"},
"statice":{"statice","statices"},
"station":{"station","stationed","stationing","stations"},
"stationariness":{"stationariness","stationarinesses"},
"stationary":{"stationaries","stationary"},
"stationer":{"stationer","stationers"},
"stationery":{"stationeries","stationery"},
"stationmaster":{"stationmaster","stationmasters"},
"statistician":{"statistician","statisticians"},
"stator":{"stator","stators"},
"statuary":{"statuaries","statuary"},
"statue":{"statue","statues"},
"statuette":{"statuette","statuettes"},
"stature":{"stature","statures"},
"status":{"status","statuses"},
"statute":{"statute","statutes"},
"staunch":{"staunch","staunched","stauncher","staunchest","staunching"},
"staunchness":{"staunchness","staunchnesses"},
"staurikosaur":{"staurikosaur","staurikosaurs"},
"staurikosaurus":{"staurikosaurus","staurikosauruses"},
"stave":{"stave","staved","staves","staving","stove"},
"stay":{"staid","stay","stayed","staying","stays"},
"stay-at-home":{"stay-at-home","stay-at-homes"},
"stays":{"stays","stayses"},
"stead":{"stead","steads"},
"steadfastness":{"steadfastness","steadfastnesses"},
"steadiness":{"steadiness","steadinesses"},
"steady":{"steadied","steadier","steadies","steadiest","steady","steadying"},
"steak":{"steak","steaks"},
"steakhouse":{"steakhouse","steakhouses"},
"steal":{"steal","stealing","steals","stole","stolen"},
"stealing":{"stealing","stealings"},
"stealth":{"stealth","stealths"},
"stealthiness":{"stealthiness","stealthinesses"},
"stealthy":{"stealthier","stealthiest","stealthy"},
"steam":{"steam","steamed","steaming","steams"},
"steamboat":{"steamboat","steamboats"},
"steamer":{"steamer","steamers"},
"steamroller":{"steamroller","steamrollered","steamrollering","steamrollers"},
"steamship":{"steamship","steamships"},
"steamy":{"steamier","steamiest","steamy"},
"steatite":{"steatite","steatites"},
"steatocystoma":{"steatocystoma","steatocystomas"},
"steatornis":{"steatornis","steatornises"},
"steatornithidae":{"steatornithidae","steatornithidaes"},
"steed":{"steed","steeds"},
"steek":{"steek","steeked","steeking"},
"steel":{"steel","steeled","steeling","steels"},
"steelhead":{"steelhead","steelheads"},
"steelmaker":{"steelmaker","steelmakers"},
"steelman":{"steelman","steelmen"},
"steelworker":{"steelworker","steelworkers"},
"steelworks":{"steelworks","steelworkses"},
"steely":{"steelier","steeliest","steely"},
"steelyard":{"steelyard","steelyards"},
"steenbok":{"steenbok","steenboks"},
"steep":{"steep","steeped","steeper","steepest","steeping"},
"steepen":{"steepen","steepened","steepening"},
"steeple":{"steeple","steeples"},
"steepness":{"steepness","steepnesses"},
"steer":{"steer","steered","steering","steers"},
"steerage":{"steerage","steerages"},
"steering":{"steering","steerings"},
"steersman":{"steersman","steersmen"},
"steganopus":{"steganopus","steganopuses"},
"stegocephalia":{"stegocephalia","stegocephalias"},
"stegosaur":{"stegosaur","stegosaurs"},
"stegosaurus":{"stegosaurus","stegosauruses"},
"stein":{"stein","steins"},
"steinbok":{"steinbok","steinboks"},
"stela":{"stela","stelae","stelas"},
"stele":{"stele","steles"},
"stellaria":{"stellaria","stellarias"},
"stellify":{"stellified","stellifies","stellify","stellifying"},
"stem":{"stem","stemmed","stemming","stems"},
"stemma":{"stemma","stemmata"},
"stem_from":{"stems_from","stem_from"},
"stench":{"stench","stenches"},
"stencil":{"stencil","stenciled","stenciling","stencilled","stencilling","stencils"},
"stenciler":{"stenciler","stencilers"},
"steno":{"steno","stenos"},
"stenocarpus":{"stenocarpus","stenocarpuses"},
"stenochlaena":{"stenochlaena","stenochlaenas"},
"stenographer":{"stenographer","stenographers"},
"stenography":{"stenographies","stenography"},
"stenopelmatidae":{"stenopelmatidae","stenopelmatidaes"},
"stenopelmatus":{"stenopelmatus","stenopelmatuses"},
"stenopterygius":{"stenopterygius","stenopterygiuses"},
"stenosis":{"stenoses","stenosis"},
"stenotaphrum":{"stenotaphrum","stenotaphrums"},
"stenotomus":{"stenotomus","stenotomuses"},
"stenotus":{"stenotus","stenotuses"},
"step":{"step","stepped","stepping","steps"},
"step-down":{"step-down","step-downs"},
"step-in":{"step-in","step-ins"},
"step-up":{"step-up","step-ups"},
"stepbrother":{"stepbrother","stepbrothers"},
"stepchild":{"stepchild","stepchildren"},
"stepdaughter":{"stepdaughter","stepdaughters"},
"stepfather":{"stepfather","stepfathers"},
"stephanomeria":{"stephanomeria","stephanomerias"},
"stephead":{"stephead","stepheads"},
"stepladder":{"stepladder","stepladders"},
"stepmother":{"stepmother","stepmothers"},
"stepparent":{"stepparent","stepparents"},
"steppingstone":{"steppingstone","steppingstones"},
"steps":{"steps","stepses"},
"stepsister":{"stepsister","stepsisters"},
"stepson":{"stepson","stepsons"},
"steradian":{"steradian","steradians"},
"stercorariidae":{"stercorariidae","stercorariidaes"},
"stercorarius":{"stercorarius","stercorariuses"},
"sterculiaceae":{"sterculiaceae","sterculiaceaes"},
"stereo":{"stereo","stereos"},
"stereospondyli":{"stereospondyli","stereospondylis"},
"stereotype":{"stereotype","stereotyped","stereotypes","stereotyping"},
"sterileness":{"sterileness","sterilenesses"},
"sterilisation":{"sterilisation","sterilisations"},
"sterility":{"sterilities","sterility"},
"sterilization":{"sterilization","sterilizations"},
"sterilize":{"sterilize","sterilized","sterilizes","sterilizing"},
"sterilizer":{"sterilizer","sterilizers"},
"sterilsation":{"sterilsation","sterilsations"},
"stern":{"stern","sterner","sternest","sterns"},
"sterna":{"sterna","sternas"},
"sterninae":{"sterninae","sterninaes"},
"sternness":{"sternness","sternnesses"},
"sternocleidomastoid":{"sternocleidomastoid","sternocleidomastoids"},
"sternotherus":{"sternotherus","sternotheruses"},
"sternum":{"sterna","sternum","sternums"},
"sternutation":{"sternutation","sternutations"},
"sternutator":{"sternutator","sternutators"},
"sternutatory":{"sternutatories","sternutatory"},
"steroid":{"steroid","steroids"},
"sterol":{"sterol","sterols"},
"sterope":{"sterope","steropes"},
"stertor":{"stertor","stertors"},
"stet":{"stet","stets","stetted","stetting"},
"stetson":{"stetson","stetsons"},
"stevedore":{"stevedore","stevedored","stevedores","stevedoring"},
"stew":{"stew","stewed","stewing","stews"},
"steward":{"steward","stewarded","stewarding","stewards"},
"stewardess":{"stewardess","stewardesses"},
"stewing":{"stewing","stewings"},
"stewpan":{"stewpan","stewpans"},
"stichaeidae":{"stichaeidae","stichaeidaes"},
"sticherus":{"sticherus","sticheruses"},
"stick":{"stick","sticking","sticks","stuck"},
"stick-in-the-mud":{"stick-in-the-mud","stick-in-the-muds"},
"stickball":{"stickball","stickballs"},
"sticker":{"sticker","stickers"},
"stickful":{"stickful","stickfuls"},
"stickle":{"stickle","stickled","stickling"},
"stickleback":{"stickleback","sticklebacks"},
"stickman":{"stickman","stickmen"},
"sticktight":{"sticktight","sticktights"},
"stickup":{"stickup","stickups"},
"sticky":{"stickier","stickiest","sticky"},
"stictomys":{"stictomys","stictomyses"},
"stictopelia":{"stictopelia","stictopelias"},
"stiff":{"stiff","stiffs"},
"stiffen":{"stiffen","stiffened","stiffening","stiffens"},
"stiffener":{"stiffener","stiffeners"},
"stiffness":{"stiffness","stiffnesses"},
"stifle":{"stifle","stifled","stifles","stifling"},
"stifling":{"stifling","stiflings"},
"stigma":{"stigma","stigmas","stigmata"},
"stigmatic":{"stigmatic","stigmatics"},
"stigmatisation":{"stigmatisation","stigmatisations"},
"stigmatist":{"stigmatist","stigmatists"},
"stigmatization":{"stigmatization","stigmatizations"},
"stigmatize":{"stigmatize","stigmatized","stigmatizes","stigmatizing"},
"stilbestrol":{"stilbestrol","stilbestrols"},
"stilboestrol":{"stilboestrol","stilboestrols"},
"stile":{"stile","stiles"},
"stiletto":{"stiletto","stilettoed","stilettoeing","stilettoes","stilettos"},
"still":{"still","stilled","stiller","stillest","stilling","stills"},
"stillbirth":{"stillbirth","stillbirths"},
"stillness":{"stillness","stillnesses"},
"stillroom":{"stillroom","stillrooms"},
"stilt":{"stilt","stilts"},
"stiltbird":{"stiltbird","stiltbirds"},
"stimulant":{"stimulant","stimulants"},
"stimulate":{"stimulate","stimulated","stimulates","stimulating"},
"stimulation":{"stimulation","stimulations"},
"stimulus":{"stimuli","stimulus","stimuluses"},
"stimy":{"stimied","stimies","stimy","stimying"},
"sting":{"sting","stinging","stings","stung"},
"stingaree-bush":{"stingaree-bush","stingaree-bushes"},
"stinger":{"stinger","stingers"},
"stinging":{"stinging","stingings"},
"stingy":{"stingier","stingies","stingiest","stingy"},
"stink":{"stank","stink","stinking","stinks","stunk"},
"stinkbird":{"stinkbird","stinkbirds"},
"stinker":{"stinker","stinkers"},
"stinkhorn":{"stinkhorn","stinkhorns"},
"stinkiness":{"stinkiness","stinkinesses"},
"stinkpot":{"stinkpot","stinkpots"},
"stinkweed":{"stinkweed","stinkweeds"},
"stint":{"stint","stinted","stinting","stints"},
"stipendiary":{"stipendiaries","stipendiary"},
"stipes":{"stipes","stipites"},
"stipple":{"stipple","stippled","stipples","stippling"},
"stipulate":{"stipulate","stipulated","stipulates","stipulating"},
"stipulation":{"stipulation","stipulations"},
"stir":{"stir","stirred","stirring","stirs"},
"stirps":{"stirpes","stirps"},
"stirrer":{"stirrer","stirrers"},
"stirring":{"stirring","stirrings"},
"stirrup":{"stirrup","stirrups"},
"stitch":{"stitch","stitched","stitches","stitching"},
"stitcher":{"stitcher","stitchers"},
"stitchery":{"stitcheries","stitchery"},
"stitching":{"stitching","stitchings"},
"stitchwort":{"stitchwort","stitchworts"},
"stizidae":{"stizidae","stizidaes"},
"stizolobium":{"stizolobium","stizolobiums"},
"stizostedion":{"stizostedion","stizostedions"},
"stm":{"stm","stms"},
"stoa":{"stoa","stoae","stoai","stoas"},
"stock":{"stock","stocked","stocking","stocks"},
"stockade":{"stockade","stockaded","stockades","stockading"},
"stockbroker":{"stockbroker","stockbrokers"},
"stockfish":{"stockfish","stockfishes"},
"stockholder":{"stockholder","stockholders"},
"stockholding":{"stockholding","stockholdings"},
"stockholdings":{"stockholdings","stockholdingses"},
"stockholm":{"stockholm","stockholms"},
"stockhorn":{"stockhorn","stockhorns"},
"stockinet":{"stockinet","stockinets"},
"stockinette":{"stockinette","stockinettes"},
"stocking":{"stocking","stockings"},
"stockman":{"stockman","stockmen"},
"stockpile":{"stockpile","stockpiled","stockpiles","stockpiling"},
"stockroom":{"stockroom","stockrooms"},
"stocks":{"stocks","stockses"},
"stocktaking":{"stocktaking","stocktakings"},
"stocky":{"stockier","stockiest","stocky"},
"stockyard":{"stockyard","stockyards"},
"stodge":{"stodge","stodged","stodging"},
"stodginess":{"stodginess","stodginesses"},
"stodgy":{"stodgier","stodgiest","stodgy"},
"stoep":{"stoep","stoeps"},
"stogey":{"stogey","stogies"},
"stogy":{"stogies","stogy"},
"stoic":{"stoic","stoics"},
"stoicism":{"stoicism","stoicisms"},
"stoke":{"stoke","stoked","stoking"},
"stokehold":{"stokehold","stokeholds"},
"stokehole":{"stokehole","stokeholes"},
"stoker":{"stoker","stokers"},
"stokesia":{"stokesia","stokesias"},
"stole":{"stole","stoles"},
"stolidity":{"stolidities","stolidity"},
"stolidness":{"stolidness","stolidnesses"},
"stolon":{"stolon","stolons"},
"stoma":{"stoma","stomas"},
"stomach":{"stomach","stomached","stomaches","stomaching","stomachs"},
"stomachache":{"stomachache","stomachaches"},
"stomatopod":{"stomatopod","stomatopods"},
"stomatopoda":{"stomatopoda","stomatopodas"},
"stomodaeum":{"stomodaea","stomodaeum"},
"stomodeum":{"stomodea","stomodeum"},
"stone":{"stone","stoned","stones","stoning"},
"stonechat":{"stonechat","stonechats"},
"stonecress":{"stonecress","stonecresses"},
"stonecutter":{"stonecutter","stonecutters"},
"stoneface":{"stoneface","stonefaces"},
"stonefish":{"stonefish","stonefishes"},
"stonefly":{"stoneflies","stonefly"},
"stonemason":{"stonemason","stonemasons"},
"stoneroot":{"stoneroot","stoneroots"},
"stonewall":{"stonewall","stonewalled","stonewalling"},
"stonework":{"stonework","stoneworks"},
"stony":{"stonier","stoniest","stony"},
"stooge":{"stooge","stooged","stooges","stooging"},
"stool":{"stool","stooled","stooling","stools"},
"stoolie":{"stoolie","stoolies"},
"stoolpigeon":{"stoolpigeon","stoolpigeons"},
"stoop":{"stoop","stooped","stooping","stoops"},
"stop":{"stop","stopped","stopping","stops"},
"stopcock":{"stopcock","stopcocks"},
"stopgap":{"stopgap","stopgaps"},
"stoplight":{"stoplight","stoplights"},
"stopover":{"stopover","stopovers"},
"stoppage":{"stoppage","stoppages"},
"stopper":{"stopper","stoppered","stoppering","stoppers"},
"stopping":{"stopping","stoppings"},
"stopple":{"stopple","stoppled","stopples","stoppling"},
"stops":{"stops","stopses"},
"stopwatch":{"stopwatch","stopwatches"},
"storage":{"storage","storages"},
"store":{"store","stored","stores","storing"},
"storefront":{"storefront","storefronts"},
"storehouse":{"storehouse","storehouses"},
"storekeeper":{"storekeeper","storekeepers"},
"storeria":{"storeria","storerias"},
"storeroom":{"storeroom","storerooms"},
"stores":{"stores","storeses"},
"storey":{"storey","storeys"},
"storing":{"storing","storings"},
"stork":{"stork","storks"},
"storksbill":{"storksbill","storksbills"},
"storm":{"storm","stormed","storming","storms"},
"stormy":{"stormier","stormiest","stormy"},
"story":{"storied","stories","story","storying"},
"storyline":{"storyline","storylines"},
"storyteller":{"storyteller","storytellers"},
"stot":{"stot","stots","stotted","stotting"},
"stotinka":{"stotinka","stotinki"},
"stoup":{"stoup","stoups"},
"stout":{"stout","stouter","stoutest"},
"stoutness":{"stoutness","stoutnesses"},
"stove":{"stove","stoves"},
"stovepipe":{"stovepipe","stovepipes"},
"stow":{"stow","stowed","stowing","stows"},
"stowage":{"stowage","stowages"},
"stowing":{"stowing","stowings"},
"strabismus":{"strabismus","strabismuses"},
"strabotomy":{"strabotomies","strabotomy"},
"straddle":{"straddle","straddled","straddles","straddling"},
"strafe":{"strafe","strafed","strafes","strafing"},
"straggle":{"straggle","straggled","straggles","straggling"},
"straggly":{"stragglier","straggliest","straggly"},
"straight":{"straight","straighter","straightest","straights"},
"straightaway":{"straightaway","straightaways"},
"straighten":{"straighten","straightened","straightening","straightens"},
"straightforwardness":{"straightforwardness","straightforwardnesses"},
"straightjacket":{"straightjacket","straightjackets"},
"straightness":{"straightness","straightnesses"},
"strain":{"strain","strained","straining","strains"},
"straining":{"straining","strainings"},
"strait":{"strait","straiter","straitest","straits"},
"strait-jacket":{"strait-jacket","strait-jacketed","strait-jacketing"},
"straiten":{"straiten","straitened","straitening"},
"straitjacket":{"straitjacket","straitjackets"},
"straits":{"straits","straitses"},
"strake":{"strake","strakes"},
"strand":{"strand","stranded","stranding","strands"},
"strange":{"strange","stranger","strangest"},
"strangeness":{"strangeness","strangenesses"},
"stranger":{"stranger","strangers"},
"strangle":{"strangle","strangled","strangles","strangling"},
"stranglehold":{"stranglehold","strangleholds"},
"strangler":{"strangler","stranglers"},
"strangles":{"strangles","strangleses"},
"strangling":{"strangling","stranglings"},
"strangulate":{"strangulate","strangulated","strangulates","strangulating"},
"strangulation":{"strangulation","strangulations"},
"strap":{"strap","strapped","strapping","straps"},
"strappado":{"strappado","strappadoes"},
"strapper":{"strapper","strappers"},
"stratagem":{"stratagem","stratagems"},
"strategian":{"strategian","strategians"},
"strategist":{"strategist","strategists"},
"strategy":{"strategies","strategy"},
"stratford-on-avon":{"stratford-on-avon","stratford-on-avons"},
"stratford-upon-avon":{"stratford-upon-avon","stratford-upon-avons"},
"stratification":{"stratification","stratifications"},
"stratify":{"stratified","stratifies","stratify","stratifying"},
"strato-cumulus":{"strato-cumuli","strato-cumulus"},
"stratocracy":{"stratocracies","stratocracy"},
"stratocumulus":{"stratocumuli","stratocumulus"},
"stratum":{"strata","stratum","stratums"},
"stratus":{"strati","stratus","stratuses"},
"stravage":{"stravage","stravaged","stravaging"},
"stravinsky":{"stravinskies","stravinsky"},
"straw":{"straw","strawed","strawing","straws"},
"strawberry":{"strawberries","strawberry"},
"strawflower":{"strawflower","strawflowers"},
"strawman":{"strawman","strawmen"},
"strawworm":{"strawworm","strawworms"},
"stray":{"stray","strayed","straying","strays"},
"streak":{"streak","streaked","streaking","streaks"},
"streaker":{"streaker","streakers"},
"streaky":{"streakier","streakiest","streaky"},
"stream":{"stream","streamed","streaming","streams"},
"streambed":{"streambed","streambeds"},
"streamer":{"streamer","streamers"},
"streaming":{"streaming","streamings"},
"streamlet":{"streamlet","streamlets"},
"streamline":{"streamline","streamlined","streamlining"},
"streamy":{"streamier","streamiest","streamy"},
"street":{"street","streets"},
"streetcar":{"streetcar","streetcars"},
"streetlight":{"streetlight","streetlights"},
"streetwalker":{"streetwalker","streetwalkers"},
"strekelia":{"strekelia","strekelias"},
"strelitzia":{"strelitzia","strelitzias"},
"strelitziaceae":{"strelitziaceae","strelitziaceaes"},
"strength":{"strength","strengths"},
"strengthen":{"strengthen","strengthened","strengthening","strengthens"},
"strengthener":{"strengthener","strengtheners"},
"strengthening":{"strengthening","strengthenings"},
"strenuosity":{"strenuosities","strenuosity"},
"strenuousness":{"strenuousness","strenuousnesses"},
"strep":{"strep","streps"},
"strepera":{"strepera","streperas"},
"strepsiceros":{"strepsiceros","strepsiceroses"},
"strepsirhini":{"strepsirhini","strepsirhinis"},
"streptococci":{"streptococci","streptococcis"},
"streptococcus":{"streptococci","streptococcus","streptococcuses"},
"streptomycetacaea":{"streptomycetacaea","streptomycetacaeas"},
"streptopelia":{"streptopelia","streptopelias"},
"streptosolen":{"streptosolen","streptosolens"},
"stress":{"stress","stressed","stresses","stressing"},
"stretch":{"stretch","stretched","stretches","stretching"},
"stretchability":{"stretchabilities","stretchability"},
"stretcher":{"stretcher","stretchers"},
"stretcher-bearer":{"stretcher-bearer","stretcher-bearers"},
"stretchiness":{"stretchiness","stretchinesses"},
"stretching":{"stretching","stretchings"},
"stretchy":{"stretchier","stretchiest","stretchy"},
"stretto":{"stretti","stretto","strettos"},
"strew":{"strew","strewed","strewing","strewn","strews"},
"strewing":{"strewing","strewings"},
"stria":{"stria","strias"},
"striation":{"striation","striations"},
"strict":{"strict","stricter","strictest"},
"strictness":{"strictness","strictnesses"},
"stricture":{"stricture","strictures"},
"stride":{"stridden","stride","strides","striding","strode"},
"stridence":{"stridence","stridences"},
"stridency":{"stridencies","stridency"},
"strife":{"strife","strifes"},
"strigidae":{"strigidae","strigidaes"},
"strigiformes":{"strigiformes","strigiformeses"},
"strike":{"stricken","strike","strikes","striking","struck"},
"strikebreaker":{"strikebreaker","strikebreakers"},
"striker":{"striker","strikers"},
"striking":{"striking","strikings"},
"strikingness":{"strikingness","strikingnesses"},
"string":{"string","stringing","strings","strung"},
"stringency":{"stringencies","stringency"},
"stringy":{"stringier","stringiest","stringy"},
"strip":{"strip","stripped","stripping","strips","stript"},
"stripe":{"stripe","striped","stripes","striping"},
"striper":{"striper","stripers"},
"stripes":{"stripes","stripeses"},
"stripling":{"stripling","striplings"},
"stripper":{"stripper","strippers"},
"stripping":{"stripping","strippings"},
"striptease":{"striptease","stripteases"},
"stripteaser":{"stripteaser","stripteasers"},
"stripy":{"stripier","stripiest","stripy"},
"strive":{"strive","strived","striven","strives","striving","strove"},
"striver":{"striver","strivers"},
"striving":{"striving","strivings"},
"strix":{"strix","strixes"},
"strobile":{"strobile","strobiles"},
"strobilomyces":{"strobilomyces","strobilomyceses"},
"strobilus":{"strobilus","strobiluses"},
"stroke":{"stroke","stroked","strokes","stroking"},
"stroking":{"stroking","strokings"},
"stroll":{"stroll","strolled","strolling","strolls"},
"stroller":{"stroller","strollers"},
"stroma":{"stroma","stromata"},
"stromateid":{"stromateid","stromateids"},
"stromateidae":{"stromateidae","stromateidaes"},
"strombidae":{"strombidae","strombidaes"},
"strombus":{"strombus","strombuses"},
"strong":{"strong","stronger","strongest"},
"strong-arm":{"strong-arm","strong-armed","strong-arming","strong-arms"},
"strongbox":{"strongbox","strongboxes"},
"stronghold":{"stronghold","strongholds"},
"strongman":{"strongman","strongmen"},
"strongylodon":{"strongylodon","strongylodons"},
"strontium":{"strontium","strontiums"},
"strop":{"strop","stropped","stropping","strops"},
"stropharia":{"stropharia","stropharias"},
"strophariaceae":{"strophariaceae","strophariaceaes"},
"strophe":{"strophe","strophes"},
"stroppy":{"stroppier","stroppiest","stroppy"},
"strow":{"strow","strowed","strowing","strown","strows"},
"structure":{"structure","structured","structures","structuring"},
"struggle":{"struggle","struggled","struggles","struggling"},
"struggler":{"struggler","strugglers"},
"strum":{"strum","strummed","strumming","strums"},
"struma":{"struma","strumas"},
"strumpet":{"strumpet","strumpets"},
"strut":{"strut","struts","strutted","strutting"},
"struthio":{"struthio","struthios"},
"struthionidae":{"struthionidae","struthionidaes"},
"struthioniformes":{"struthioniformes","struthioniformeses"},
"strymon":{"strymon","strymons"},
"stub":{"stub","stubbed","stubbing","stubs"},
"stubbiness":{"stubbiness","stubbinesses"},
"stubble":{"stubble","stubbles"},
"stubbornness":{"stubbornness","stubbornnesses"},
"stubby":{"stubbier","stubbiest","stubby"},
"stucco":{"stucco","stuccoed","stuccoes","stuccoing","stuccos"},
"stud":{"stud","studded","studding","studs"},
"student":{"student","students"},
"studhorse":{"studhorse","studhorses"},
"studio":{"studio","studios"},
"study":{"studied","studies","study","studying"},
"studying":{"studying","studyings"},
"stuff":{"stuff","stuffed","stuffing","stuffs"},
"stuffiness":{"stuffiness","stuffinesses"},
"stuffing":{"stuffing","stuffings"},
"stuffy":{"stuffier","stuffiest","stuffy"},
"stultification":{"stultification","stultifications"},
"stultify":{"stultified","stultifies","stultify","stultifying"},
"stum":{"stum","stummed","stumming","stums"},
"stumble":{"stumble","stumbled","stumbles","stumbling"},
"stumblebum":{"stumblebum","stumblebums"},
"stump":{"stump","stumped","stumping","stumps"},
"stumper":{"stumper","stumpers"},
"stumpknocker":{"stumpknocker","stumpknockers"},
"stumpy":{"stumpier","stumpiest","stumpy"},
"stun":{"stun","stunned","stunning","stuns"},
"stunner":{"stunner","stunners"},
"stunt":{"stunt","stunted","stunting","stunts"},
"stuntedness":{"stuntedness","stuntednesses"},
"stunting":{"stunting","stuntings"},
"stupa":{"stupa","stupas"},
"stupefaction":{"stupefaction","stupefactions"},
"stupefy":{"stupefied","stupefies","stupefy","stupefying"},
"stupid":{"stupid","stupider","stupidest","stupids"},
"stupidity":{"stupidities","stupidity"},
"stupor":{"stupor","stupors"},
"sturdy":{"sturdier","sturdiest","sturdy"},
"sturgeon":{"sturgeon","sturgeons"},
"sturnella":{"sturnella","sturnellas"},
"sturnidae":{"sturnidae","sturnidaes"},
"sturnus":{"sturnus","sturnuses"},
"stutter":{"stutter","stuttered","stuttering","stutters"},
"stutterer":{"stutterer","stutterers"},
"sty":{"stied","sties","sty","stying"},
"stye":{"stye","styes"},
"style":{"style","styled","styles","styling"},
"stylemark":{"stylemark","stylemarks"},
"stylisation":{"stylisation","stylisations"},
"stylishness":{"stylishness","stylishnesses"},
"stylist":{"stylist","stylists"},
"stylization":{"stylization","stylizations"},
"stylize":{"stylize","stylized","stylizes","stylizing"},
"stylomecon":{"stylomecon","stylomecons"},
"stylophorum":{"stylophorum","stylophorums"},
"stylopodium":{"stylopodia","stylopodium"},
"stylops":{"stylopes","stylops"},
"stylostixis":{"stylostixes","stylostixis"},
"stylus":{"styli","stylus","styluses"},
"stymie":{"stymie","stymied","stymieing","stymies","stymying"},
"styphelia":{"styphelia","styphelias"},
"stypsis":{"stypses","stypsis"},
"styptic":{"styptic","styptics"},
"styracaceae":{"styracaceae","styracaceaes"},
"styracosaur":{"styracosaur","styracosaurs"},
"styracosaurus":{"styracosaurus","styracosauruses"},
"styrene":{"styrene","styrenes"},
"styx":{"styx","styxes"},
"suasion":{"suasion","suasions"},
"suave":{"suave","suaver","suavest"},
"suaveness":{"suaveness","suavenesses"},
"suavity":{"suavities","suavity"},
"sub":{"sub","subbed","subbing","subs"},
"subassembly":{"subassemblies","subassembly"},
"subbing":{"subbing","subbings"},
"subconscious":{"subconscious","subconsciouses"},
"subcontract":{"subcontract","subcontracted","subcontracting","subcontracts"},
"subcontrary":{"subcontraries","subcontrary"},
"subcortex":{"subcortex","subcortices"},
"subdelirium":{"subdelirium","subdelirliria","subdelirliriums"},
"subdivide":{"subdivide","subdivided","subdivides","subdividing"},
"subdivision":{"subdivision","subdivisions"},
"subduct":{"subduct","subducted","subducting"},
"subdue":{"subdue","subdued","subdues","subduing"},
"subduedness":{"subduedness","subduednesses"},
"subedit":{"subedit","subedited","subediting","subedits"},
"subfamily":{"subfamilies","subfamily"},
"subgenus":{"subgegenera","subgegenuses","subgenera","subgenus","subgenuses"},
"subhead":{"subhead","subheads"},
"subheading":{"subheading","subheadings"},
"subindex":{"subindex","subindexes","subindices"},
"subject":{"subject","subjected","subjecting","subjects"},
"subjectify":{"subjectified","subjectifies","subjectify","subjectifying"},
"subjection":{"subjection","subjections"},
"subjectiveness":{"subjectiveness","subjectivenesses"},
"subjectivity":{"subjectivities","subjectivity"},
"subjoin":{"subjoin","subjoined","subjoining"},
"subjoining":{"subjoining","subjoinings"},
"subjugate":{"subjugate","subjugated","subjugates","subjugating"},
"subjugation":{"subjugation","subjugations"},
"subjunction":{"subjunction","subjunctions"},
"subjunctive":{"subjunctive","subjunctives"},
"sublease":{"sublease","subleased","subleases","subleasing"},
"sublet":{"sublet","sublets","subletting"},
"sublime":{"sublime","sublimed","sublimer","sublimest","subliming"},
"sublimity":{"sublimities","sublimity"},
"submarine":{"submarine","submarined","submarines","submarining"},
"submaxilla":{"submaxilla","submaxillas"},
"submenu":{"submenu","submenus"},
"submerge":{"submerge","submerged","submerges","submerging"},
"submergence":{"submergence","submergences"},
"submerging":{"submerging","submergings"},
"submerse":{"submerse","submersed","submersing"},
"submersion":{"submersion","submersions"},
"submission":{"submission","submissions"},
"submit":{"submit","submits","submitted","submitting"},
"submucosa":{"submucocosae","submucosa"},
"subnormality":{"subnormalities","subnormality"},
"subordinary":{"subordinaries","subordinary"},
"subordinate":{"subordinate","subordinated","subordinates","subordinating"},
"subordinateness":{"subordinateness","subordinatenesses"},
"subordination":{"subordination","subordinations"},
"suborn":{"suborn","suborned","suborning"},
"suborner":{"suborner","suborners"},
"subpena":{"subpena","subpenaed","subpenaing","subpenas"},
"subphylum":{"subphyla","subphylum"},
"subpoena":{"subpoena","subpoenaed","subpoenaing","subpoenas"},
"subprogram":{"subprogram","subprograms"},
"subrogate":{"subrogate","subrogated","subrogating"},
"subroutine":{"subroutine","subroutines"},
"subscribe":{"subscribe","subscribed","subscribes","subscribing"},
"subscriber":{"subscriber","subscribers"},
"subscript":{"subscript","subscripts"},
"subscription":{"subscription","subscriptions"},
"subsection":{"subsection","subsections"},
"subsequence":{"subsequence","subsequences"},
"subsequentness":{"subsequentness","subsequentnesses"},
"subserve":{"subserve","subserved","subserving"},
"subservience":{"subservience","subserviences"},
"subservientness":{"subservientness","subservientnesses"},
"subshrub":{"subshrub","subshrubs"},
"subside":{"subside","subsided","subsides","subsiding"},
"subsidence":{"subsidence","subsidences"},
"subsidiarity":{"subsidiarities","subsidiarity"},
"subsidiary":{"subsidiaries","subsidiary"},
"subsiding":{"subsiding","subsidings"},
"subsidisation":{"subsidisation","subsidisations"},
"subsidization":{"subsidization","subsidizations"},
"subsidize":{"subsidize","subsidized","subsidizing"},
"subsidy":{"subsidies","subsidy"},
"subsist":{"subsist","subsisted","subsisting","subsists"},
"subsoil":{"subsoil","subsoils"},
"subspecies":{"subspecies","subspecieses"},
"substance":{"substance","substances"},
"substantial":{"substantial","substantials"},
"substantiality":{"substantialities","substantiality"},
"substantialness":{"substantialness","substantialnesses"},
"substantiate":{"substantiate","substantiated","substantiates","substantiating"},
"substantiation":{"substantiation","substantiations"},
"substitutability":{"substitutabilities","substitutability"},
"substitute":{"substitute","substituted","substitutes","substituting"},
"substituting":{"substituting","substitutings"},
"substitution":{"substitution","substitutions"},
"substrate":{"substrate","substrates"},
"substratum":{"substrata","substratum","substratums"},
"substructure":{"substructure","substructures"},
"subsume":{"subsume","subsumed","subsumes","subsuming"},
"subsuming":{"subsuming","subsumings"},
"subsumption":{"subsumption","subsumptions"},
"subtend":{"subtend","subtended","subtending","subtends"},
"subterfuge":{"subterfuge","subterfuges"},
"subterranean":{"subterranean","subterraneans"},
"subtilize":{"subtilize","subtilized","subtilizes","subtilizing"},
"subtitle":{"subtitle","subtitled","subtitles","subtitling"},
"subtle":{"subtle","subtler","subtlest"},
"subtlety":{"subtleties","subtlety"},
"subtonic":{"subtonic","subtonics"},
"subtotal":{"subtotal","subtotaled","subtotaling","subtotalled","subtotalling","subtotals"},
"subtract":{"subtract","subtracted","subtracting","subtracts"},
"subtraction":{"subtraction","subtractions"},
"subtreasury":{"subtreasuries","subtreasury"},
"subtropics":{"subtropics","subtropicses"},
"subularia":{"subularia","subularias"},
"subunit":{"subunit","subunits"},
"suburb":{"suburb","suburbs"},
"suburbanite":{"suburbanite","suburbanites"},
"suburbia":{"suburbia","suburbias"},
"subvene":{"subvene","subvened","subvening"},
"subversion":{"subversion","subversions"},
"subversive":{"subversive","subversives"},
"subversiveness":{"subversiveness","subversivenesses"},
"subvert":{"subvert","subverted","subverting","subverts"},
"subverter":{"subverter","subverters"},
"subway":{"subway","subwayed","subwaying","subways"},
"succedaneum":{"succedanea","succedaneum"},
"succeed":{"succeed","succeeded","succeeding","succeeds"},
"success":{"success","successes"},
"successfulness":{"successfulness","successfulnesses"},
"succession":{"succession","successions"},
"successiveness":{"successiveness","successivenesses"},
"successor":{"successor","successors"},
"succinctness":{"succinctness","succinctnesses"},
"succor":{"succor","succored","succoring","succors"},
"succory":{"succories","succory"},
"succos":{"succos","succoses"},
"succour":{"succour","succoured","succouring","succours"},
"succuba":{"succuba","succubas"},
"succubus":{"succubi","succubus","succubuses"},
"succulence":{"succulence","succulences"},
"succumb":{"succumb","succumbed","succumbing","succumbs"},
"succus":{"succus","succuses"},
"suck":{"suck","sucked","sucking","sucks"},
"sucker":{"sucker","suckered","suckering","suckers"},
"suckerfish":{"suckerfish","suckerfishes"},
"suckfish":{"suckfish","suckfishes"},
"sucking":{"sucking","suckings"},
"suckle":{"suckle","suckled","suckles","suckling"},
"suckling":{"suckling","sucklings"},
"sucralfate":{"sucralfate","sucralfates"},
"sucrose":{"sucrose","sucroses"},
"suction":{"suction","suctions"},
"sudan":{"sudan","sudans"},
"sudarium":{"sudardaria","sudarium"},
"sudatorium":{"sudatoria","sudatorium","sudatotoria"},
"sudatory":{"sudatories","sudatory"},
"suddenness":{"suddenness","suddennesses"},
"sudor":{"sudor","sudors"},
"sudra":{"sudra","sudras"},
"suds":{"suds","sudses"},
"sudsy":{"sudsier","sudsiest","sudsy"},
"sue":{"sue","sued","sues","suing"},
"suede":{"suede","suedes"},
"suffer":{"suffer","suffered","suffering","suffers"},
"sufferance":{"sufferance","sufferances"},
"sufferer":{"sufferer","sufferers"},
"suffering":{"suffering","sufferings"},
"suffice":{"suffice","sufficed","suffices","sufficing"},
"sufficiency":{"sufficiencies","sufficiency"},
"suffix":{"suffix","suffixed","suffixes","suffixing"},
"suffocate":{"suffocate","suffocated","suffocates","suffocating"},
"suffocation":{"suffocation","suffocations"},
"suffragan":{"suffragan","suffragans"},
"suffrage":{"suffrage","suffrages"},
"suffragette":{"suffragette","suffragettes"},
"suffragist":{"suffragist","suffragists"},
"suffrutex":{"suffrutex","suffrutexes"},
"suffuse":{"suffuse","suffused","suffuses","suffusing"},
"suffusion":{"suffusion","suffusions"},
"sufi":{"sufi","sufis"},
"sugar":{"sugar","sugared","sugaring","sugars"},
"sugar-bush":{"sugar-bush","sugar-bushes"},
"sugar-coat":{"sugar-coat","sugar-coated","sugar-coating"},
"sugarberry":{"sugarberries","sugarberry"},
"sugarcane":{"sugarcane","sugarcanes"},
"sugargerry":{"sugargerries","sugargerry"},
"sugarhouse":{"sugarhouse","sugarhouses"},
"sugariness":{"sugariness","sugarinesses"},
"sugarloaf":{"sugarloaf","sugarloaves"},
"sugary":{"sugarier","sugariest","sugary"},
"suggest":{"suggest","suggested","suggesting","suggests"},
"suggestion":{"suggestion","suggestions"},
"sugi":{"sugi","sugis"},
"suicide":{"suicide","suicided","suicides","suiciding"},
"suidae":{"suidae","suidaes"},
"suillus":{"suillus","suilluses"},
"suing":{"suing","suings"},
"suisse":{"suisse","suisses"},
"suit":{"suit","suited","suiting","suits"},
"suitability":{"suitabilities","suitability"},
"suitableness":{"suitableness","suitablenesses"},
"suitcase":{"suitcase","suitcases"},
"suite":{"suite","suites"},
"suitor":{"suitor","suitors"},
"sukkoth":{"sukkoth","sukkoths"},
"sula":{"sula","sulas"},
"sulamyd":{"sulamyd","sulamyds"},
"sulawesi":{"sulawesi","sulawesis"},
"sulcus":{"sulci","sulcus"},
"sulfa":{"sulfa","sulfas"},
"sulfacetamide":{"sulfacetamide","sulfacetamides"},
"sulfamethazine":{"sulfamethazine","sulfamethazines"},
"sulfamezathine":{"sulfamezathine","sulfamezathines"},
"sulfate":{"sulfate","sulfated","sulfates","sulfating"},
"sulfide":{"sulfide","sulfides"},
"sulfonamide":{"sulfonamide","sulfonamides"},
"sulfur":{"sulfur","sulfured","sulfuring","sulfurs"},
"sulidae":{"sulidae","sulidaes"},
"sulindac":{"sulindac","sulindacs"},
"sulk":{"sulk","sulked","sulking","sulks"},
"sulkiness":{"sulkiness","sulkinesses"},
"sulky":{"sulkier","sulkies","sulkiest","sulky"},
"sulla":{"sulla","sullas"},
"sullen":{"sullen","sullener","sullenest"},
"sullenness":{"sullenness","sullennesses"},
"sullivan":{"sullivan","sullivans"},
"sully":{"sullied","sullies","sully","sullying"},
"sulpha":{"sulpha","sulphas"},
"sulphate":{"sulphate","sulphates"},
"sulphide":{"sulphide","sulphides"},
"sulphur":{"sulphur","sulphurs"},
"sulphuret":{"sulphuret","sulphureted","sulphureting","sulphurets","sulphuretted","sulphuretting"},
"sultan":{"sultan","sultans"},
"sultana":{"sultana","sultanas"},
"sultry":{"sultrier","sultriest","sultry"},
"sum":{"sum","summed","summing","sums"},
"sumac":{"sumac","sumacs"},
"sumach":{"sumach","sumaches"},
"summa":{"summa","summae","summas"},
"summarization":{"summarization","summarizations"},
"summarize":{"summarize","summarized","summarizes","summarizing"},
"summary":{"summaries","summary"},
"summation":{"summation","summations"},
"summer":{"summer","summered","summering","summers"},
"summerhouse":{"summerhouse","summerhouses"},
"summertime":{"summertime","summertimes"},
"summit":{"summit","summits"},
"summiteer":{"summiteer","summiteers"},
"summitry":{"summitries","summitry"},
"summon":{"summon","summoned","summoning","summons"},
"summoning":{"summoning","summonings"},
"summons":{"summons","summonsed","summonses","summonsing"},
"sump":{"sump","sumps"},
"sumpter":{"sumpter","sumpters"},
"sumptuosity":{"sumptuosities","sumptuosity"},
"sumptuousness":{"sumptuousness","sumptuousnesses"},
"sun":{"sun","sunned","sunning","suns"},
"sun-bathe":{"sun-bathe","sun-bathed","sun-bathing"},
"sun-worship":{"sun-worship","sun-worships"},
"sunbath":{"sunbath","sunbaths"},
"sunbeam":{"sunbeam","sunbeams"},
"sunberry":{"sunberries","sunberry"},
"sunblind":{"sunblind","sunblinds"},
"sunbonnet":{"sunbonnet","sunbonnets"},
"sunburn":{"sunburn","sunburned","sunburning","sunburns","sunburnt"},
"sunchoke":{"sunchoke","sunchokes"},
"sundacarpus":{"sundacarpus","sundacarpuses"},
"sundae":{"sundae","sundaes"},
"sunday":{"sunday","sundays"},
"sunder":{"sunder","sundered","sundering"},
"sundew":{"sundew","sundews"},
"sundog":{"sundog","sundogs"},
"sundown":{"sundown","sundowns"},
"sundowner":{"sundowner","sundowners"},
"sundries":{"sundries","sundrieses"},
"sundrops":{"sundrops","sundropses"},
"sundry":{"sundries","sundry"},
"sunfish":{"sunfish","sunfishes"},
"sunflower":{"sunflower","sunflowers"},
"sunglass":{"sunglass","sunglasses"},
"sunglasses":{"sunglasses","sunglasseses"},
"sunhat":{"sunhat","sunhats"},
"sunlamp":{"sunlamp","sunlamps"},
"sunlight":{"sunlight","sunlights"},
"sunni":{"sunni","sunnis"},
"sunnite":{"sunnite","sunnites"},
"sunny":{"sunnier","sunniest","sunny"},
"sunray":{"sunray","sunrays"},
"sunrise":{"sunrise","sunrises"},
"sunroof":{"sunroof","sunroofs"},
"sunroom":{"sunroom","sunrooms"},
"sunrose":{"sunrose","sunroses"},
"sunset":{"sunset","sunsets"},
"sunshade":{"sunshade","sunshades"},
"sunshine":{"sunshine","sunshines"},
"sunshine-roof":{"sunshine-roof","sunshine-roofs"},
"sunspot":{"sunspot","sunspots"},
"sunstone":{"sunstone","sunstones"},
"sunstroke":{"sunstroke","sunstrokes"},
"suntan":{"suntan","suntans"},
"suntrap":{"suntrap","suntraps"},
"sunup":{"sunup","sunups"},
"suomi":{"suomi","suomis"},
"sup":{"sup","supped","supping","sups"},
"super":{"super","supers"},
"superabound":{"superabound","superabounded","superabounding"},
"superabundance":{"superabundance","superabundances"},
"superadd":{"superadd","superadded","superadding"},
"superannuate":{"superannuate","superannuated","superannuating"},
"superannuation":{"superannuation","superannuations"},
"superbia":{"superbia","superbias"},
"superbug":{"superbug","superbugs"},
"supercargo":{"supercargo","supercargoes","supercargos"},
"supercharge":{"supercharge","supercharged","supercharges","supercharging"},
"superciliousness":{"superciliousness","superciliousnesses"},
"supercilium":{"supercilium","superciliums"},
"supercool":{"supercool","supercooled","supercooling"},
"superego":{"superego","superegos"},
"supererogate":{"supererogate","supererogated","supererogating"},
"superfamily":{"superfamilies","superfamily"},
"superficiality":{"superficialities","superficiality"},
"superfluity":{"superfluities","superfluity"},
"superfuse":{"superfuse","superfused","superfusing"},
"superheat":{"superheat","superheated","superheating"},
"superhero":{"superhero","superheroes"},
"superhet":{"superhet","superhets"},
"superhighway":{"superhighway","superhighways"},
"superimpose":{"superimpose","superimposed","superimposes","superimposing"},
"superinduce":{"superinduce","superinduced","superinducing"},
"superintend":{"superintend","superintended","superintending","superintends"},
"superintendence":{"superintendence","superintendences"},
"superintendency":{"superintendencies","superintendency"},
"superintendent":{"superintendent","superintendents"},
"superior":{"superior","superiors"},
"superiority":{"superiorities","superiority"},
"superlative":{"superlative","superlatives"},
"superload":{"superload","superloads"},
"superman":{"superman","supermen"},
"supermarket":{"supermarket","supermarkets"},
"supermolecule":{"supermolecule","supermolecules"},
"supernatural":{"supernatural","supernaturals"},
"supernaturalism":{"supernaturalism","supernaturalisms"},
"supernaturalist":{"supernaturalist","supernaturalists"},
"supernaturalness":{"supernaturalness","supernaturalnesses"},
"supernova":{"supernova","supernovae","supernovas"},
"supernumerary":{"supernumeraries","supernumerary"},
"superordinate":{"superordinate","superordinated","superordinates","superordinating"},
"superordination":{"superordination","superordinations"},
"superpatriotism":{"superpatriotism","superpatriotisms"},
"superpose":{"superpose","superposed","superposing"},
"superpower":{"superpower","superpowers"},
"supersaturate":{"supersaturate","supersaturated","supersaturating"},
"superscribe":{"superscribe","superscribed","superscribing"},
"superscript":{"superscript","superscripts"},
"supersede":{"supersede","superseded","supersedes","superseding"},
"supersedure":{"supersedure","supersedures"},
"supersession":{"supersession","supersessions"},
"superslasher":{"superslasher","superslashers"},
"superstition":{"superstition","superstitions"},
"superstratum":{"superstrata","superstratum","superstratums"},
"supertax":{"supertax","supertaxes"},
"supertitle":{"supertitle","supertitles"},
"supervene":{"supervene","supervened","supervening"},
"supervise":{"supervise","supervised","supervises","supervising"},
"supervising":{"supervising","supervisings"},
"supervision":{"supervision","supervisions"},
"supervisor":{"supervisor","supervisors"},
"superwoman":{"superwoman","superwomen"},
"supper":{"supper","suppers"},
"suppertime":{"suppertime","suppertimes"},
"supplant":{"supplant","supplanted","supplanting","supplants"},
"supplanter":{"supplanter","supplanters"},
"supplanting":{"supplanting","supplantings"},
"supple":{"supple","suppled","suppler","supplest","suppling"},
"supplement":{"supplement","supplemented","supplementing","supplements"},
"supplementary":{"supplementaries","supplementary"},
"supplementation":{"supplementation","supplementations"},
"suppleness":{"suppleness","supplenesses"},
"suppliant":{"suppliant","suppliants"},
"supplicant":{"supplicant","supplicants"},
"supplicate":{"supplicate","supplicated","supplicating"},
"supplication":{"supplication","supplications"},
"supplier":{"supplier","suppliers"},
"supplies":{"supplies","supplieses"},
"supply":{"supplied","supplies","supply","supplying"},
"supplying":{"supplying","supplyings"},
"support":{"support","supported","supporting","supports"},
"supporter":{"supporter","supporters"},
"supporting":{"supporting","supportings"},
"supposal":{"supposal","supposals"},
"suppose":{"suppose","supposed","supposes","supposing"},
"supposition":{"supposition","suppositions"},
"suppository":{"suppositories","suppository"},
"suppress":{"suppress","suppressed","suppresses","suppressing"},
"suppresser":{"suppresser","suppressers"},
"suppression":{"suppression","suppressions"},
"suppressor":{"suppressor","suppressors"},
"suppurate":{"suppurate","suppurated","suppurates","suppurating"},
"suppuration":{"suppuration","suppurations"},
"suprarenalectomy":{"suprarenalectomies","suprarenalectomy"},
"supremacy":{"supremacies","supremacy"},
"supremo":{"supremo","supremos"},
"sura":{"sura","suras"},
"surcease":{"surcease","surceased","surceases","surceasing"},
"surcharge":{"surcharge","surcharged","surcharges","surcharging"},
"surcoat":{"surcoat","surcoats"},
"surd":{"surd","surds"},
"sure":{"sure","surer","surest"},
"sureness":{"sureness","surenesses"},
"surety":{"sureties","surety"},
"surf":{"surf","surfed","surfing","surfs","surves"},
"surface":{"surface","surfaced","surfaces","surfacing"},
"surfactant":{"surfactant","surfactants"},
"surfbird":{"surfbird","surfbirds"},
"surfboard":{"surfboard","surfboarded","surfboarding"},
"surfboarder":{"surfboarder","surfboarders"},
"surfboarding":{"surfboarding","surfboardings"},
"surfeit":{"surfeit","surfeited","surfeiting","surfeits"},
"surfer":{"surfer","surfers"},
"surffish":{"surffish","surffishes"},
"surfing":{"surfing","surfings"},
"surfperch":{"surfperch","surfperches"},
"surfriding":{"surfriding","surfridings"},
"surfy":{"surfier","surfiest","surfy"},
"surge":{"surge","surged","surges","surging"},
"surgeon":{"surgeon","surgeons"},
"surgeoncy":{"surgeoncies","surgeoncy"},
"surgeonfish":{"surgeonfish","surgeonfishes"},
"surgery":{"surgeries","surgery"},
"suricata":{"suricata","suricatas"},
"suricate":{"suricate","suricates"},
"surinam":{"surinam","surinams"},
"suriname":{"suriname","surinames"},
"surliness":{"surliness","surlinesses"},
"surly":{"surlier","surliest","surly"},
"surmise":{"surmise","surmised","surmises","surmising"},
"surmount":{"surmount","surmounted","surmounting","surmounts"},
"surmullet":{"surmullet","surmullets"},
"surname":{"surname","surnamed","surnames","surnaming"},
"surnia":{"surnia","surnias"},
"surpass":{"surpass","surpassed","surpasses","surpassing"},
"surplus":{"surplus","surpluses"},
"surplusage":{"surplusage","surplusages"},
"surprint":{"surprint","surprints"},
"surprisal":{"surprisal","surprisals"},
"surprise":{"surprise","surprised","surprises","surprising"},
"surprising":{"surprising","surprisings"},
"surprisingness":{"surprisingness","surprisingnesses"},
"surrebuttal":{"surrebuttal","surrebuttals"},
"surrebutter":{"surrebutter","surrebutters"},
"surrender":{"surrender","surrendered","surrendering","surrenders"},
"surrogate":{"surrogate","surrogates"},
"surround":{"surround","surrounded","surrounding","surrounds"},
"surrounding":{"surrounding","surroundings"},
"surroundings":{"surroundings","surroundingses"},
"surtax":{"surtax","surtaxed","surtaxes","surtaxing"},
"surtitle":{"surtitle","surtitles"},
"survey":{"survey","surveyed","surveying","surveys"},
"surveyor":{"surveyor","surveyors"},
"survival":{"survival","survivals"},
"survive":{"survive","survived","survives","surviving"},
"survivor":{"survivor","survivors"},
"sus":{"sus","suses"},
"susceptibility":{"susceptibilities","susceptibility"},
"susceptibleness":{"susceptibleness","susceptiblenesses"},
"susian":{"susian","susians"},
"suslik":{"suslik","susliks"},
"suspect":{"suspect","suspected","suspecting","suspects"},
"suspend":{"suspend","suspended","suspending","suspends"},
"suspender":{"suspender","suspenders"},
"suspension":{"suspension","suspensions"},
"suspensor":{"suspensor","suspensors"},
"suspensory":{"suspensories","suspensory"},
"suspicion":{"suspicion","suspicioned","suspicioning","suspicions"},
"suspiciousness":{"suspiciousness","suspiciousnesses"},
"susquehanna":{"susquehanna","susquehannas"},
"susso":{"susso","sussos"},
"sustain":{"sustain","sustained","sustaining","sustains"},
"sustainment":{"sustainment","sustainments"},
"sustenance":{"sustenance","sustenances"},
"sustentation":{"sustentation","sustentations"},
"susu":{"susu","susus"},
"sutler":{"sutler","sutlers"},
"sutra":{"sutra","sutras"},
"sutura":{"sutura","suturas"},
"suture":{"suture","sutured","sutures","suturing"},
"suzerainty":{"suzerainties","suzerainty"},
"svelte":{"svelte","svelter","sveltest"},
"sverige":{"sverige","sveriges"},
"svizzera":{"svizzera","svizzeras"},
"sw":{"sw","sws"},
"swab":{"swab","swabbed","swabbing","swabs"},
"swabbing":{"swabbing","swabbings"},
"swaddle":{"swaddle","swaddled","swaddles","swaddling"},
"swag":{"swag","swagged","swagging","swags"},
"swage":{"swage","swaged","swages","swaging"},
"swagger":{"swagger","swaggered","swaggering","swaggers"},
"swagman":{"swagman","swagmen"},
"swahili":{"swahili","swahilis"},
"swain":{"swain","swains"},
"swainsona":{"swainsona","swainsonas"},
"swallow":{"swallow","swallowed","swallowing","swallows"},
"swallowtail":{"swallowtail","swallowtails"},
"swallowwort":{"swallowwort","swallowworts"},
"swami":{"swami","swamies","swamis"},
"swamp":{"swamp","swamped","swamping","swamps"},
"swamphen":{"swamphen","swamphens"},
"swampy":{"swampier","swampiest","swampy"},
"swan":{"swan","swanned","swanning","swans"},
"swanflower":{"swanflower","swanflowers"},
"swank":{"swank","swanked","swanker","swankest","swanking","swanks"},
"swanky":{"swankier","swankiest","swanky"},
"swanneck":{"swanneck","swannecks"},
"swannery":{"swanneries","swannery"},
"swap":{"swap","swapped","swapping","swaps"},
"sward":{"sward","swards"},
"swarm":{"swarm","swarmed","swarming","swarms"},
"swarthiness":{"swarthiness","swarthinesses"},
"swarthy":{"swarthier","swarthiest","swarthy"},
"swash":{"swash","swashed","swashes","swashing"},
"swashbuckler":{"swashbuckler","swashbucklers"},
"swastika":{"swastika","swastikas"},
"swat":{"swat","swats","swatted","swatting"},
"swath":{"swath","swaths"},
"swathe":{"swathe","swathed","swathes","swathing"},
"swatter":{"swatter","swatters"},
"sway":{"sway","swayed","swaying","sways"},
"swazi":{"swazi","swazis"},
"swbs":{"swbs","swbses"},
"swbw":{"swbw","swbws"},
"swear":{"swear","swearing","swears","swore","sworn"},
"swearer":{"swearer","swearers"},
"swearing":{"swearing","swearings"},
"swearword":{"swearword","swearwords"},
"sweat":{"sweat","sweated","sweating","sweats"},
"sweater":{"sweater","sweaters"},
"sweating":{"sweating","sweatings"},
"sweats":{"sweats","sweatses"},
"sweatshop":{"sweatshop","sweatshops"},
"sweaty":{"sweatier","sweatiest","sweaty"},
"swede":{"swede","swedes"},
"sweden":{"sweden","swedens"},
"sweep":{"sweep","sweeping","sweeps","swept"},
"sweep-second":{"sweep-second","sweep-seconds"},
"sweeper":{"sweeper","sweepers"},
"sweeping":{"sweeping","sweepings"},
"sweepstake":{"sweepstake","sweepstakes"},
"sweepstakes":{"sweepstakes","sweepstakeses"},
"sweet":{"sweet","sweeter","sweetest","sweets"},
"sweet-talk":{"sweet-talk","sweet-talked","sweet-talking","sweet-talks"},
"sweetbread":{"sweetbread","sweetbreads"},
"sweetbreads":{"sweetbreads","sweetbreadses"},
"sweetbriar":{"sweetbriar","sweetbriars"},
"sweetbrier":{"sweetbrier","sweetbriers"},
"sweeten":{"sweeten","sweetened","sweetening","sweetens"},
"sweetener":{"sweetener","sweeteners"},
"sweetening":{"sweetening","sweetenings"},
"sweetheart":{"sweetheart","sweethearted","sweethearting","sweethearts"},
"sweetie":{"sweetie","sweeties"},
"sweetiewife":{"sweetiewife","sweetiewives"},
"sweetleaf":{"sweetleaf","sweetleaves"},
"sweetman":{"sweetman","sweetmen"},
"sweetness":{"sweetness","sweetnesses"},
"sweetpea":{"sweetpea","sweetpeas"},
"sweetsop":{"sweetsop","sweetsops"},
"swell":{"swell","swelled","sweller","swellest","swelling","swells","swollen"},
"swellfish":{"swellfish","swellfishes"},
"swellhead":{"swellhead","swellheads"},
"swelling":{"swelling","swellings"},
"swelter":{"swelter","sweltered","sweltering"},
"swertia":{"swertia","swertias"},
"swerve":{"swerve","swerved","swerves","swerving"},
"swerving":{"swerving","swervings"},
"swietinia":{"swietinia","swietinias"},
"swift":{"swift","swifter","swiftest","swifts"},
"swiftlet":{"swiftlet","swiftlets"},
"swiftness":{"swiftness","swiftnesses"},
"swig":{"swig","swigged","swigging","swigs"},
"swill":{"swill","swilled","swilling","swills"},
"swilling":{"swilling","swillings"},
"swim":{"swam","swim","swimming","swims","swum"},
"swimmer":{"swimmer","swimmers"},
"swimmeret":{"swimmeret","swimmerets"},
"swimming":{"swimming","swimmings"},
"swimsuit":{"swimsuit","swimsuits"},
"swindle":{"swindle","swindled","swindles","swindling"},
"swindler":{"swindler","swindlers"},
"swineherd":{"swineherd","swineherds"},
"swing":{"swing","swinging","swings","swung"},
"swinge":{"swinge","swinged","swingeing","swinges"},
"swinging":{"swinging","swingings"},
"swingle":{"swingle","swingled","swingling"},
"swingletree":{"swingletree","swingletrees"},
"swink":{"swank","swink","swinking","swonk","swonken"},
"swipe":{"swipe","swiped","swipes","swiping"},
"swirl":{"swirl","swirled","swirling","swirls"},
"swirly":{"swirlier","swirliest","swirly"},
"swish":{"swish","swished","swishes","swishing"},
"swiss":{"swiss","swisses"},
"switch":{"switch","switched","switches","switching"},
"switch-ivy":{"switch-ivies","switch-ivy"},
"switchblade":{"switchblade","switchblades"},
"switchboard":{"switchboard","switchboards"},
"switching":{"switching","switchings"},
"switchman":{"switchman","switchmen"},
"swither":{"swither","swithers"},
"switzerland":{"switzerland","switzerlands"},
"swivel":{"swivel","swiveled","swiveling","swivelled","swivelling","swivels"},
"swob":{"swob","swobs"},
"swoon":{"swoon","swooned","swooning","swoons"},
"swoop":{"swoop","swooped","swooping","swoops"},
"swoosh":{"swoosh","swooshed","swooshing"},
"swop":{"swop","swops"},
"sword":{"sword","swords"},
"swordfish":{"swordfish","swordfishes"},
"swordman":{"swordman","swordmen"},
"swordplay":{"swordplay","swordplays"},
"swordsman":{"swordsman","swordsmen"},
"swordtail":{"swordtail","swordtails"},
"swot":{"swot","swots","swotted","swotting"},
"sybarite":{"sybarite","sybarites"},
"sycamore":{"sycamore","sycamores"},
"syconium":{"syconia","syconium"},
"sycophant":{"sycophant","sycophants"},
"sycosis":{"sycoses","sycosis"},
"syllabary":{"syllabaries","syllabary"},
"syllabicate":{"syllabicate","syllabicated","syllabicates","syllabicating"},
"syllabication":{"syllabication","syllabications"},
"syllabification":{"syllabification","syllabifications"},
"syllabify":{"syllabified","syllabifies","syllabify","syllabifying"},
"syllable":{"syllable","syllabled","syllables","syllabling"},
"syllabub":{"syllabub","syllabubs"},
"syllabus":{"syllabi","syllabus","syllabuses"},
"syllepsis":{"syllepses","syllepsis"},
"sylva":{"sylva","sylvas"},
"sylvan":{"sylvan","sylvans"},
"sylvanite":{"sylvanite","sylvanites"},
"sylvanus":{"sylvanus","sylvanuses"},
"sylviidae":{"sylviidae","sylviidaes"},
"sylviinae":{"sylviinae","sylviinaes"},
"sylvilagus":{"sylvilagus","sylvilaguses"},
"sylvine":{"sylvine","sylvines"},
"sylvite":{"sylvite","sylvites"},
"symbiosis":{"symbioses","symbiosis"},
"symbol":{"symbol","symbols"},
"symbol-worship":{"symbol-worship","symbol-worships"},
"symbolatry":{"symbolatries","symbolatry"},
"symbolization":{"symbolization","symbolizations"},
"symbolize":{"symbolize","symbolized","symbolizes","symbolizing"},
"symbolizing":{"symbolizing","symbolizings"},
"symbololatry":{"symbololatries","symbololatry"},
"symmetricalness":{"symmetricalness","symmetricalnesses"},
"symmetrize":{"symmetrize","symmetrized","symmetrizing"},
"symmetry":{"symmetries","symmetry"},
"sympathectomy":{"sympathectomies","sympathectomy"},
"sympathize":{"sympathize","sympathized","sympathizes","sympathizing"},
"sympathizer":{"sympathizer","sympathizers"},
"sympathy":{"sympathies","sympathy"},
"symphalangus":{"symphalangus","symphalanguses"},
"symphilid":{"symphilid","symphilids"},
"symphony":{"symphonies","symphony"},
"symphoricarpos":{"symphoricarpos","symphoricarposes"},
"symphyla":{"symphyla","symphylas"},
"symphysis":{"symphyses","symphysis"},
"symphytum":{"symphytum","symphytums"},
"symplocaceae":{"symplocaceae","symplocaceaes"},
"symplocarpus":{"symplocarpus","symplocarpuses"},
"symplocus":{"symplocus","symplocuses"},
"sympodium":{"sympodia","sympodium"},
"symposium":{"symposia","symposium","symposiums"},
"symptom":{"symptom","symptoms"},
"synaeresis":{"synaereses","synaeresis"},
"synaesthesia":{"synaesthesia","synaesthesias"},
"synagogue":{"synagogue","synagogues"},
"synagrops":{"synagrops","synagropses"},
"synanceja":{"synanceja","synancejas"},
"synapsid":{"synapsid","synapsids"},
"synapsida":{"synapsida","synapsidas"},
"synapsis":{"synapses","synapsis"},
"synaptomys":{"synaptomys","synaptomyses"},
"synarchy":{"synarchies","synarchy"},
"synarthrosis":{"synarthroses","synarthrosis"},
"syncarp":{"syncarp","syncarps"},
"synchro":{"synchro","synchros"},
"synchroneity":{"synchroneities","synchroneity"},
"synchronicity":{"synchronicities","synchronicity"},
"synchronisation":{"synchronisation","synchronisations"},
"synchronising":{"synchronising","synchronisings"},
"synchronism":{"synchronism","synchronisms"},
"synchronization":{"synchronization","synchronizations"},
"synchronize":{"synchronize","synchronized","synchronizes","synchronizing"},
"synchronizing":{"synchronizing","synchronizings"},
"synchrony":{"synchronies","synchrony"},
"synchytriaceae":{"synchytriaceae","synchytriaceaes"},
"synchytrium":{"synchytrium","synchytriums"},
"synclinorium":{"synclinoria","synclinorium"},
"syncopate":{"syncopate","syncopated","syncopating"},
"syncopation":{"syncopation","syncopations"},
"syncope":{"syncope","syncopes"},
"syncretize":{"syncretize","syncretized","syncretizing"},
"syncytium":{"syncytcytia","syncytium"},
"syndactylism":{"syndactylism","syndactylisms"},
"syndactyly":{"syndactylies","syndactyly"},
"syndesmosis":{"syndesmoses","syndesmosis"},
"syndicalist":{"syndicalist","syndicalists"},
"syndicate":{"syndicate","syndicated","syndicates","syndicating"},
"synentognathi":{"synentognathi","synentognathis"},
"synercus":{"synercus","synercuses"},
"syneresis":{"synereses","syneresis"},
"synergism":{"synergism","synergisms"},
"synergy":{"synergies","synergy"},
"synesthesia":{"synesthesia","synesthesias"},
"synezesis":{"synezeses","synezesis"},
"syngnathidae":{"syngnathidae","syngnathidaes"},
"syngnathus":{"syngnathus","syngnathuses"},
"syngonium":{"syngonium","syngoniums"},
"synizesis":{"synizeses","synizesis"},
"synodontidae":{"synodontidae","synodontidaes"},
"synonym":{"synonym","synonyms"},
"synonymity":{"synonymities","synonymity"},
"synonymousness":{"synonymousness","synonymousnesses"},
"synonymy":{"synonymies","synonymy"},
"synopsis":{"synopses","synopsis","synopsises"},
"synopsize":{"synopsize","synopsized","synopsizing"},
"synovia":{"synovia","synovias"},
"synovium":{"synovium","synoviums"},
"syntactician":{"syntactician","syntacticians"},
"syntagm":{"syntagm","syntagms"},
"syntagma":{"syntagma","syntagmata","syntagtagmata"},
"syntax":{"syntax","syntaxes"},
"synthesis":{"syntheses","synthesis","synthesises"},
"synthesize":{"synthesize","synthesized","synthesizes","synthesizing"},
"synthetic":{"synthetic","synthetics"},
"syph":{"syph","syphs"},
"syphilis":{"syphilis","syphilises"},
"syphiloma":{"syphiloma","syphilomas","syphilomata"},
"syphon":{"syphon","syphoned","syphoning","syphons"},
"syracuse":{"syracuse","syracuses"},
"syringa":{"syringa","syringas"},
"syringe":{"syringe","syringed","syringing"},
"syrinx":{"syringes","syrinx","syrinxes"},
"syrrhaptes":{"syrrhaptes","syrrhapteses"},
"syrup":{"syrup","syrups"},
"syssarcosis":{"syssarcoses","syssarcosis"},
"system":{"system","systems"},
"systematisation":{"systematisation","systematisations"},
"systematization":{"systematization","systematizations"},
"systematize":{"systematize","systematized","systematizes","systematizing"},
"systemize":{"systemize","systemized","systemizes","systemizing"},
"syzygium":{"syzygium","syzygiums"},
"syzygy":{"syzygies","syzygy"},
"szechuan":{"szechuan","szechuans"},
"szechwan":{"szechwan","szechwans"},
"t":{"t","ts"},
"t-bill":{"t-bill","t-bills"},
"t-man":{"t-man","t-men"},
"t-scope":{"t-scope","t-scopes"},
"t-shirt":{"t-shirt","t-shirts"},
"ta":{"ta","tas"},
"taal":{"taal","taals"},
"tab":{"tab","tabbed","tabbing","tabs"},
"tabanidae":{"tabanidae","tabanidaes"},
"tabasco":{"tabasco","tabascos"},
"tabbouleh":{"tabbouleh","tabboulehs"},
"tabby":{"tabbied","tabbies","tabby","tabbying"},
"tabernacle":{"tabernacle","tabernacled","tabernacles","tabernacling"},
"tabernacles":{"tabernacles","tabernacleses"},
"tabernaemontana":{"tabernaemontana","tabernaemontanas"},
"tabi":{"tabi","tabis"},
"tabis":{"tabis","tabises"},
"tabla":{"tabla","tablas"},
"table":{"table","tabled","tables","tabling"},
"tableau":{"tableau","tableaus","tableaux"},
"tablecloth":{"tablecloth","tablecloths"},
"tableland":{"tableland","tablelands"},
"tablemate":{"tablemate","tablemates"},
"tablespoon":{"tablespoon","tablespoons"},
"tablespoonful":{"tablespoonful","tablespoonfuls"},
"tablet":{"tablet","tablets"},
"tabloid":{"tabloid","tabloids"},
"taboo":{"taboo","tabooed","tabooing","taboos"},
"tabooli":{"tabooli","taboolis"},
"tabor":{"tabor","tabors"},
"taboret":{"taboret","taborets"},
"tabour":{"tabour","tabours"},
"tabouret":{"tabouret","tabourets"},
"tabu":{"tabu","tabus"},
"tabulate":{"tabulate","tabulated","tabulates","tabulating"},
"tabulation":{"tabulation","tabulations"},
"tabulator":{"tabulator","tabulators"},
"tacamahac":{"tacamahac","tacamahacs"},
"tacca":{"tacca","taccas"},
"taccaceae":{"taccaceae","taccaceaes"},
"tach":{"tach","taches"},
"tacheometer":{"tacheometer","tacheometers"},
"tachinidae":{"tachinidae","tachinidaes"},
"tachistoscope":{"tachistoscope","tachistoscopes"},
"tachometer":{"tachometer","tachometers"},
"tachyglossidae":{"tachyglossidae","tachyglossidaes"},
"tachyglossus":{"tachyglossus","tachyglossuses"},
"tachymeter":{"tachymeter","tachymeters"},
"tachypleus":{"tachypleus","tachypleuses"},
"taciturnity":{"taciturnities","taciturnity"},
"tack":{"tack","tacked","tacking","tacks"},
"tacker":{"tacker","tackers"},
"tackiness":{"tackiness","tackinesses"},
"tacking":{"tacking","tackings"},
"tackle":{"tackle","tackled","tackles","tackling"},
"tackling":{"tackling","tacklings"},
"tacky":{"tackier","tackiest","tacky"},
"taco":{"taco","tacos"},
"tact":{"tact","tacts"},
"tactfulness":{"tactfulness","tactfulnesses"},
"tactic":{"tactic","tactics"},
"tactility":{"tactilities","tactility"},
"tadarida":{"tadarida","tadaridas"},
"tadjik":{"tadjik","tadjiks"},
"tadorna":{"tadorna","tadornas"},
"tadpole":{"tadpole","tadpoles"},
"tadzhik":{"tadzhik","tadzhiks"},
"tadzhikistan":{"tadzhikistan","tadzhikistans"},
"taegu":{"taegu","taegus"},
"taenia":{"taenia","taeniae","taenias"},
"taeniidae":{"taeniidae","taeniidaes"},
"taffy":{"taffies","taffy"},
"taft":{"taft","tafts"},
"tag":{"tag","tagged","tagging","tags"},
"tagalog":{"tagalog","tagalogs"},
"tagalong":{"tagalong","tagalongs"},
"tagamet":{"tagamet","tagamets"},
"tagasaste":{"tagasaste","tagasastes"},
"tageteste":{"tageteste","tagetestes"},
"taguan":{"taguan","taguans"},
"tagus":{"tagus","taguses"},
"tai":{"tai","tais"},
"taiga":{"taiga","taigas"},
"tail":{"tail","tailed","tailing","tails"},
"tailboard":{"tailboard","tailboards"},
"tailcoat":{"tailcoat","tailcoats"},
"tailfin":{"tailfin","tailfins"},
"tailflower":{"tailflower","tailflowers"},
"tailgate":{"tailgate","tailgated","tailgates","tailgating"},
"tailing":{"tailing","tailings"},
"taille":{"taille","tailles"},
"taillight":{"taillight","taillights"},
"tailor":{"tailor","tailored","tailoring","tailors"},
"tailorbird":{"tailorbird","tailorbirds"},
"tailplane":{"tailplane","tailplanes"},
"tails":{"tails","tailses"},
"tailspin":{"tailspin","tailspins"},
"tailwort":{"tailwort","tailworts"},
"taino":{"taino","tainos"},
"taint":{"taint","tainted","tainting","taints"},
"taipan":{"taipan","taipans"},
"taipei":{"taipei","taipeis"},
"taira":{"taira","tairas"},
"taiwan":{"taiwan","taiwans"},
"taiwanese":{"taiwanese","taiwaneses"},
"tajik":{"tajik","tajiks"},
"tajikistan":{"tajikistan","tajikistans"},
"takahe":{"takahe","takahes"},
"take":{"take","taken","takes","taking","took"},
"takedown":{"takedown","takedowns"},
"takelma":{"takelma","takelmas"},
"takeoff":{"takeoff","takeoffs"},
"takeout":{"takeout","takeouts"},
"takeover":{"takeover","takeovers"},
"take_a_side":{"taken_a_side","takes_a_side","take_a_side","taking_a_side","took_a_side"},
"take_pains":{"taken_pains","takes_pains","take_pains","taking_pains","took_pains"},
"take_steps":{"taken_steps","takes_steps","take_steps","taking_steps","took_steps"},
"takilman":{"takilman","takilmen"},
"takin":{"takin","takins"},
"taking":{"taking","takings"},
"takings":{"takings","takingses"},
"talapoin":{"talapoin","talapoins"},
"talc":{"talc","talcs"},
"talcum":{"talcum","talcums"},
"tale":{"tale","tales"},
"talebearer":{"talebearer","talebearers"},
"talent":{"talent","talents"},
"taler":{"taler","talers"},
"talesman":{"talesman","talesmen"},
"taleteller":{"taleteller","taletellers"},
"talinum":{"talinum","talinums"},
"talipes":{"talipes","talipeses"},
"talipot":{"talipot","talipots"},
"talisman":{"talisman","talismans","talismen"},
"talk":{"talk","talked","talking","talks"},
"talkativeness":{"talkativeness","talkativenesses"},
"talker":{"talker","talkers"},
"talkie":{"talkie","talkies"},
"talking":{"talking","talkings"},
"talking-to":{"talking-to","talking-tos"},
"talks":{"talks","talkses"},
"talky":{"talkier","talkiest","talky"},
"tall":{"tall","taller","tallest"},
"tallahassee":{"tallahassee","tallahassees"},
"tallboy":{"tallboy","tallboys"},
"tallinn":{"tallinn","tallinns"},
"tallith":{"tallith","tallithim","talliths"},
"tallness":{"tallness","tallnesses"},
"tallow":{"tallow","tallowed","tallowing"},
"tally":{"tallied","tallies","tally","tallying"},
"tally-ho":{"tally-ho","tally-ho'd","tally-hoed","tally-hoing","tally-hos"},
"tallyho":{"tallyho","tallyhoed","tallyhoing","tallyhos"},
"tallyman":{"tallyman","tallymen"},
"talon":{"talon","talons"},
"talpidae":{"talpidae","talpidaes"},
"talus":{"tali","talus","taluses"},
"tam":{"tam","tams"},
"tam-tam":{"tam-tam","tam-tams"},
"tamale":{"tamale","tamales"},
"tamandu":{"tamandu","tamandus"},
"tamandua":{"tamandua","tamanduas"},
"tamanoir":{"tamanoir","tamanoirs"},
"tamarack":{"tamarack","tamaracks"},
"tamarao":{"tamarao","tamaraos"},
"tamarau":{"tamarau","tamaraus"},
"tamaricaceae":{"tamaricaceae","tamaricaceaes"},
"tamarillo":{"tamarillo","tamarillos"},
"tamarin":{"tamarin","tamarins"},
"tamarind":{"tamarind","tamarinds"},
"tamarindo":{"tamarindo","tamarindos"},
"tamarindus":{"tamarindus","tamarinduses"},
"tamarix":{"tamarix","tamarixes"},
"tamasha":{"tamasha","tamashas"},
"tambac":{"tambac","tambacs"},
"tambour":{"tambour","tamboured","tambouring","tambours"},
"tamburlaine":{"tamburlaine","tamburlaines"},
"tame":{"tame","tamed","tamer","tamest","taming"},
"tameness":{"tameness","tamenesses"},
"tamerlane":{"tamerlane","tamerlanes"},
"tamias":{"tamias","tamiases"},
"tamiasciurus":{"tamiasciurus","tamiasciuruses"},
"tamil":{"tamil","tamils"},
"tamis":{"tamis","tamises"},
"tammany":{"tammanies","tammany"},
"tammuz":{"tammuz","tammuzs"},
"tammy":{"tammies","tammy"},
"tamp":{"tamp","tamped","tamping","tamps"},
"tamper":{"tamper","tampered","tampering","tampers"},
"tampering":{"tampering","tamperings"},
"tampon":{"tampon","tamponed","tamponing"},
"tamus":{"tamus","tamuses"},
"tan":{"tan","tanned","tanner","tannest","tanning","tans"},
"tanacetum":{"tanacetum","tanacetums"},
"tandearil":{"tandearil","tandearils"},
"tandem":{"tandem","tandems"},
"tanekaha":{"tanekaha","tanekahas"},
"tang":{"tang","tanged","tanging","tangs"},
"tangelo":{"tangelo","tangelos","tanglos"},
"tangency":{"tangencies","tangency"},
"tangent":{"tangent","tangents"},
"tangerine":{"tangerine","tangerines"},
"tangibility":{"tangibilities","tangibility"},
"tangible":{"tangible","tangibles"},
"tangibleness":{"tangibleness","tangiblenesses"},
"tangier":{"tangier","tangiers"},
"tangiers":{"tangiers","tangierses"},
"tanginess":{"tanginess","tanginesses"},
"tangle":{"tangle","tangled","tangles","tangling"},
"tangleberry":{"tangleberries","tangleberry"},
"tanglebush":{"tanglebush","tanglebushes"},
"tango":{"tango","tangoed","tangoes","tangoing","tangos"},
"tangor":{"tangor","tangors"},
"tangy":{"tangier","tangiest","tangy"},
"tank":{"tank","tanked","tanking","tanks"},
"tanka":{"tanka","tankas"},
"tanker":{"tanker","tankers"},
"tankful":{"tankful","tankfuls"},
"tannenberg":{"tannenberg","tannenbergs"},
"tanner":{"tanner","tanners"},
"tannery":{"tanneries","tannery"},
"tannia":{"tannia","tannias"},
"tannin":{"tannin","tannins"},
"tanoan":{"tanoan","tanoans"},
"tansy":{"tansies","tansy"},
"tantalize":{"tantalize","tantalized","tantalizes","tantalizing"},
"tantalizer":{"tantalizer","tantalizers"},
"tantalum":{"tantalum","tantalums"},
"tantalus":{"tantalus","tantaluses"},
"tantara":{"tantara","tantaras"},
"tantilla":{"tantilla","tantillas"},
"tantivy":{"tantivies","tantivy"},
"tantra":{"tantra","tantras"},
"tantrism":{"tantrism","tantrisms"},
"tantrum":{"tantrum","tantrums"},
"tao":{"tao","taos"},
"taoism":{"taoism","taoisms"},
"taoist":{"taoist","taoists"},
"tap":{"tap","tapped","tapping","taps"},
"tap-off":{"tap-off","tap-offs"},
"tapa":{"tapa","tapas"},
"tape":{"tape","taped","tapes","taping"},
"tape-record":{"tape-record","tape-recorded","tape-recording"},
"tapeline":{"tapeline","tapelines"},
"taper":{"taper","tapered","tapering","tapers"},
"tapestry":{"tapestried","tapestries","tapestry","tapestrying"},
"tapetum":{"tapeta","tapetum"},
"tapeworm":{"tapeworm","tapeworms"},
"taphouse":{"taphouse","taphouses"},
"taping":{"taping","tapings"},
"tapir":{"tapir","tapirs"},
"tapiridae":{"tapiridae","tapiridaes"},
"tapirus":{"tapirus","tapiruses"},
"tapis":{"tapis","tapises"},
"tappa":{"tappa","tappas"},
"taproom":{"taproom","taprooms"},
"taproot":{"taproot","taproots"},
"taps":{"taps","tapses"},
"tapster":{"tapster","tapsters"},
"tar":{"tar","tarred","tarring","tars"},
"taradiddle":{"taradiddle","taradiddles"},
"taraktagenos":{"taraktagenos","taraktagenoses"},
"taraktogenos":{"taraktogenos","taraktogenoses"},
"tarantella":{"tarantella","tarantellas"},
"tarantelle":{"tarantelle","tarantelles"},
"tarantula":{"tarantula","tarantulae","tarantulas"},
"tarawa":{"tarawa","tarawas"},
"tarawa-makin":{"tarawa-makin","tarawa-makins"},
"taraxacum":{"taraxacum","taraxacums"},
"tarboosh":{"tarboosh","tarbooshes"},
"tardigrada":{"tardigrada","tardigradas"},
"tardy":{"tardier","tardiest","tardy"},
"tare":{"tare","tared","tares","taring"},
"target":{"target","targeted","targeting","targets"},
"targum":{"targum","targummim","targums"},
"taricha":{"taricha","tarichas"},
"tariff":{"tariff","tariffed","tariffing","tariffs"},
"tarmac":{"tarmac","tarmacs"},
"tarmacadam":{"tarmacadam","tarmacadams"},
"tarnish":{"tarnish","tarnished","tarnishes","tarnishing"},
"taro":{"taro","taros"},
"tarp":{"tarp","tarps"},
"tarpan":{"tarpan","tarpans"},
"tarpaulin":{"tarpaulin","tarpaulins"},
"tarpon":{"tarpon","tarpons"},
"tarradiddle":{"tarradiddle","tarradiddles"},
"tarragon":{"tarragon","tarragons"},
"tarriance":{"tarriance","tarriances"},
"tarrietia":{"tarrietia","tarrietias"},
"tarry":{"tarried","tarrier","tarries","tarriest","tarry","tarrying"},
"tarrying":{"tarrying","tarryings"},
"tarsal":{"tarsal","tarsals"},
"tarsiidae":{"tarsiidae","tarsiidaes"},
"tarsioidea":{"tarsioidea","tarsioideas"},
"tarsius":{"tarsius","tarsiuses"},
"tarsometatarsus":{"tarsometatarsi","tarsometatarsus"},
"tarsus":{"tarsi","tarsus","tarsusi"},
"tart":{"tart","tarter","tartest","tarts"},
"tartan":{"tartan","tartans"},
"tartar":{"tartar","tartars"},
"tartarus":{"tartarus","tartaruses"},
"tartness":{"tartness","tartnesses"},
"tartufe":{"tartufe","tartufes"},
"tartuffe":{"tartuffe","tartuffes"},
"tarweed":{"tarweed","tarweeds"},
"tarwood":{"tarwood","tarwoods"},
"tarzan":{"tarzan","tarzans"},
"tashkent":{"tashkent","tashkents"},
"tashmit":{"tashmit","tashmits"},
"tashmitum":{"tashmitum","tashmitums"},
"task":{"task","tasked","tasking","tasks"},
"taskent":{"taskent","taskents"},
"tasse":{"tasse","tasses"},
"tassel":{"tassel","tasseled","tasseling","tasselled","tasselling","tassels"},
"tasset":{"tasset","tassets"},
"taste":{"taste","tasted","tastes","tasting"},
"taste-maker":{"taste-maker","taste-makers"},
"tastelessness":{"tastelessness","tastelessnesses"},
"taster":{"taster","tasters"},
"tastetester":{"tastetester","tastetesters"},
"tastiness":{"tastiness","tastinesses"},
"tasting":{"tasting","tastings"},
"tasty":{"tastier","tastiest","tasty"},
"tat":{"tat","tats","tatted","tatting"},
"tatami":{"tatami","tatamis"},
"tatar":{"tatar","tatars"},
"tater":{"tater","taters"},
"tatou":{"tatou","tatous"},
"tatouay":{"tatouay","tatouays"},
"tatter":{"tatter","tattered","tattering","tatters"},
"tatterdemalion":{"tatterdemalion","tatterdemalions"},
"tatting":{"tatting","tattings"},
"tattle":{"tattle","tattled","tattles","tattling"},
"tattletale":{"tattletale","tattletales"},
"tattoo":{"tattoo","tattooed","tattooing","tattoos"},
"tatty":{"tattier","tattiest","tatty"},
"tatu":{"tatu","tatus"},
"tau":{"tau","taus"},
"taunt":{"taunt","taunted","taunting","taunts"},
"taunting":{"taunting","tauntings"},
"tauon":{"tauon","tauons"},
"taurotragus":{"taurotragus","taurotraguses"},
"taurus":{"taurus","tauruses"},
"taut":{"taut","tauter","tautest"},
"tauten":{"tauten","tautened","tautening","tautens"},
"tautness":{"tautness","tautnesses"},
"tautog":{"tautog","tautogs"},
"tautoga":{"tautoga","tautogas"},
"tautogolabrus":{"tautogolabrus","tautogolabruses"},
"tautologize":{"tautologize","tautologized","tautologizing"},
"tautology":{"tautologies","tautology"},
"tavern":{"tavern","taverns"},
"taw":{"taw","taws"},
"tawdriness":{"tawdriness","tawdrinesses"},
"tawdry":{"tawdrier","tawdriest","tawdry"},
"tawny":{"tawnier","tawniest","tawny"},
"tax":{"tax","taxed","taxes","taxing"},
"tax-increase":{"tax-increase","tax-increases"},
"taxaceae":{"taxaceae","taxaceaes"},
"taxales":{"taxales","taxaleses"},
"taxation":{"taxation","taxations"},
"taxi":{"taxi","taxied","taxies","taxiing","taxis","taxying"},
"taxicab":{"taxicab","taxicabs"},
"taxidea":{"taxidea","taxideas"},
"taxidermist":{"taxidermist","taxidermists"},
"taxidriver":{"taxidriver","taxidrivers"},
"taximan":{"taximan","taximen"},
"taxis":{"taxes","taxis"},
"taxistand":{"taxistand","taxistands"},
"taxiway":{"taxiway","taxiways"},
"taxman":{"taxman","taxmen"},
"taxodiaceae":{"taxodiaceae","taxodiaceaes"},
"taxodium":{"taxodium","taxodiums"},
"taxon":{"taxa","taxon","taxons"},
"taxophytina":{"taxophytina","taxophytinas"},
"taxopsida":{"taxopsida","taxopsidas"},
"taxpayer":{"taxpayer","taxpayers"},
"taxus":{"taxus","taxuses"},
"tay-sachs":{"tay-sachs","tay-sachses"},
"tayalic":{"tayalic","tayalics"},
"tayassu":{"tayassu","tayassus"},
"tayassuidae":{"tayassuidae","tayassuidaes"},
"taylor":{"taylor","taylors"},
"tayra":{"tayra","tayras"},
"tazicef":{"tazicef","tazicefs"},
"tb":{"tb","tbs"},
"tbilisi":{"tbilisi","tbilisis"},
"tc":{"tc","tcs"},
"tchad":{"tchad","tchads"},
"tcp":{"tcp","tcps"},
"tcp/ip":{"tcp/ip","tcp/ips"},
"tdt":{"tdt","tdts"},
"te":{"te","tes"},
"te-hee":{"te-hee","te-heed","te-heeing","te-hees","teheed","teheeing"},
"tea":{"tea","teas"},
"teaberry":{"teaberries","teaberry"},
"teacart":{"teacart","teacarts"},
"teach":{"taught","teach","teaches","teaching"},
"teach-in":{"teach-in","teach-ins"},
"teacher":{"teacher","teachers"},
"teaching":{"teaching","teachings"},
"teacup":{"teacup","teacups"},
"teacupful":{"teacupful","teacupfuls"},
"teahouse":{"teahouse","teahouses"},
"teak":{"teak","teaks"},
"teakwood":{"teakwood","teakwoods"},
"teal":{"teal","teals"},
"team":{"team","teamed","teaming","teams"},
"teammate":{"teammate","teammates"},
"teamster":{"teamster","teamsters"},
"teapot":{"teapot","teapots"},
"tear":{"tear","teared","tearing","tears","tore","torn"},
"tear-gas":{"tear-gas","tear-gassed","tear-gassing"},
"teardrop":{"teardrop","teardrops"},
"tearfulness":{"tearfulness","tearfulnesses"},
"tearing":{"tearing","tearings"},
"tearoom":{"tearoom","tearooms"},
"tears":{"tears","tearses"},
"teary":{"tearier","teariest","teary"},
"tease":{"tease","teased","teases","teasing"},
"teasel":{"teasel","teaseled","teaseling","teaselled","teaselling","teasels"},
"teaser":{"teaser","teasers"},
"teashop":{"teashop","teashops"},
"teasing":{"teasing","teasings"},
"teasle":{"teasle","teasles"},
"teaspoon":{"teaspoon","teaspoons"},
"teaspoonful":{"teaspoonful","teaspoonfuls"},
"teat":{"teat","teats"},
"teatime":{"teatime","teatimes"},
"teazel":{"teazel","teazels"},
"teazle":{"teazle","teazled","teazling"},
"tebet":{"tebet","tebets"},
"tec":{"tec","tecs"},
"tech":{"tech","teches"},
"technetium":{"technetium","technetiums"},
"technic":{"technic","technics"},
"technicality":{"technicalities","technicality"},
"technician":{"technician","technicians"},
"technique":{"technique","techniques"},
"technocracy":{"technocracies","technocracy"},
"technologist":{"technologist","technologists"},
"technology":{"technologies","technology"},
"techy":{"techier","techiest","techy"},
"tecophilaeacea":{"tecophilaeacea","tecophilaeaceas"},
"tectaria":{"tectaria","tectarias"},
"tectona":{"tectona","tectonas"},
"tectonics":{"tectonics","tectonicses"},
"tectrix":{"tectrices","tectrix"},
"ted":{"ted","tedded","tedding","teds"},
"teddies":{"teddies","teddieses"},
"teddy":{"teddies","teddy"},
"tediousness":{"tediousness","tediousnesses"},
"tedium":{"tedium","tediums"},
"tee":{"tee","teed","teeing","tees"},
"teem":{"teem","teemed","teeming","teems"},
"teemingness":{"teemingness","teemingnesses"},
"teen-ager":{"teen-ager","teen-agers","teens"},
"teenager":{"teenager","teenagers"},
"teensy":{"teensier","teensiest","teensy"},
"teeny":{"teenier","teeniest","teeny"},
"teepee":{"teepee","teepees"},
"teeter":{"teeter","teetered","teetering","teeters"},
"teeter-toter":{"teeter-toter","teeter-toters"},
"teeterboard":{"teeterboard","teeterboards"},
"teethe":{"teethe","teethed","teething"},
"teetotaler":{"teetotaler","teetotalers"},
"teetotaling":{"teetotaling","teetotalings"},
"teetotalism":{"teetotalism","teetotalisms"},
"teetotalist":{"teetotalist","teetotalists"},
"teetotaller":{"teetotaller","teetotallers"},
"teetotum":{"teetotum","teetotums"},
"teff":{"teff","teffs"},
"teflon":{"teflon","teflons"},
"tegmen":{"tegmen","tegmina"},
"tegu":{"tegu","tegus"},
"tegucigalpa":{"tegucigalpa","tegucigalpas"},
"tegument":{"tegument","teguments"},
"teheran":{"teheran","teherans"},
"teiid":{"teiid","teiids"},
"teiidae":{"teiidae","teiidaes"},
"tela":{"tela","telae"},
"telamon":{"telamon","telamones","telamons"},
"telangiectasia":{"telangiectases","telangiectasia","telangiectasias"},
"telangiectasis":{"telangiectases","telangiectasis"},
"telanthera":{"telanthera","telantheras"},
"telecast":{"telecast","telecasted","telecasting","telecasts"},
"telecasting":{"telecasting","telecastings"},
"teleconference":{"teleconference","teleconferences"},
"teleconferencing":{"teleconferencing","teleconferencings"},
"telegram":{"telegram","telegrammed","telegramming","telegrams"},
"telegraph":{"telegraph","telegraphed","telegraphing","telegraphs"},
"telegrapher":{"telegrapher","telegraphers"},
"telegraphist":{"telegraphist","telegraphists"},
"telegraphy":{"telegraphies","telegraphy"},
"telekinesis":{"telekineses","telekinesis"},
"telemarketing":{"telemarketing","telemarketings"},
"telemeter":{"telemeter","telemetered","telemetering"},
"telencephalon":{"telencephala","telencephalon","telencephalons"},
"teleost":{"teleost","teleosts"},
"teleostan":{"teleostan","teleostans"},
"teleostei":{"teleostei","teleosteis"},
"telepathist":{"telepathist","telepathists"},
"telepathy":{"telepathies","telepathy"},
"telephone":{"telephone","telephoned","telephones","telephoning"},
"telephoner":{"telephoner","telephoners"},
"telephonist":{"telephonist","telephonists"},
"telephony":{"telephonies","telephony"},
"telephoto":{"telephoto","telephotos"},
"telephotograph":{"telephotograph","telephotographs"},
"teleport":{"teleport","teleported","teleporting"},
"teleprinter":{"teleprinter","teleprinters"},
"teleprocessing":{"teleprocessing","teleprocessings"},
"telescope":{"telescope","telescoped","telescopes","telescoping"},
"teleselling":{"teleselling","telesellings"},
"teletype":{"teletype","teletyped","teletyping"},
"teletypewriter":{"teletypewriter","teletypewriters"},
"televise":{"televise","televised","televises","televising"},
"television":{"television","televisions"},
"telex":{"telex","telexes"},
"telfer":{"telfer","telfers"},
"telferage":{"telferage","telferages"},
"telint":{"telint","telints"},
"telium":{"telia","telium"},
"tell":{"tell","telling","tells","told"},
"teller":{"teller","tellers"},
"tellima":{"tellima","tellimas"},
"telling":{"telling","tellings"},
"telltale":{"telltale","telltales"},
"tellurian":{"tellurian","tellurians"},
"tellurium":{"tellurium","telluriums"},
"telly":{"tellies","telly"},
"telopea":{"telopea","telopeas"},
"telosporidia":{"telosporidia","telosporidias"},
"telpher":{"telpher","telphers"},
"telpherage":{"telpherage","telpherages"},
"telsontail":{"telsontail","telsontails"},
"telugu":{"telugu","telugus"},
"temblor":{"temblor","temblors"},
"temerity":{"temerities","temerity"},
"temne":{"temne","temnes"},
"temnospondyli":{"temnospondyli","temnospondylis"},
"temp":{"temp","temps"},
"temper":{"temper","tempered","tempering","tempers"},
"tempera":{"tempera","temperas"},
"temperament":{"temperament","temperaments"},
"temperance":{"temperance","temperances"},
"temperateness":{"temperateness","temperatenesses"},
"temperature":{"temperature","temperatures"},
"tempering":{"tempering","temperings"},
"tempest":{"tempest","tempested","tempesting","tempests"},
"templar":{"templar","templars"},
"template":{"template","templates"},
"temple":{"temple","temples"},
"templet":{"templet","templets"},
"templetonia":{"templetonia","templetonias"},
"tempo":{"tempi","tempo","tempos"},
"temporal":{"temporal","temporals"},
"temporality":{"temporalities","temporality"},
"temporalize":{"temporalize","temporalized","temporalizing"},
"temporalty":{"temporalties","temporalty"},
"temporary":{"temporaries","temporary"},
"temporize":{"temporize","temporized","temporizing"},
"tempra":{"tempra","tempras"},
"tempt":{"tempt","tempted","tempting","tempts"},
"temptation":{"temptation","temptations"},
"tempter":{"tempter","tempters"},
"temptingness":{"temptingness","temptingnesses"},
"temptress":{"temptress","temptresses"},
"ten":{"ten","tens"},
"ten-strike":{"ten-strike","ten-strikes"},
"tenability":{"tenabilities","tenability"},
"tenableness":{"tenableness","tenablenesses"},
"tenaciousness":{"tenaciousness","tenaciousnesses"},
"tenacity":{"tenacities","tenacity"},
"tenaculum":{"tenacula","tenaculum"},
"tenancy":{"tenancies","tenancy"},
"tenant":{"tenant","tenanted","tenanting","tenants"},
"tench":{"tench","tenches"},
"tend":{"tend","tended","tending","tends"},
"tendency":{"tendencies","tendency"},
"tender":{"tender","tendered","tenderer","tenderest","tendering","tenders"},
"tenderfoot":{"tenderfeet","tenderfoot","tenderfoots"},
"tendergreen":{"tendergreen","tendergreens"},
"tenderheartedness":{"tenderheartedness","tenderheartednesses"},
"tenderize":{"tenderize","tenderized","tenderizes","tenderizing"},
"tenderloin":{"tenderloin","tenderloins"},
"tenderness":{"tenderness","tendernesses"},
"tending":{"tending","tendings"},
"tendinitis":{"tendinitis","tendinitises"},
"tendon":{"tendon","tendons"},
"tendonitis":{"tendonitis","tendonitises"},
"tendrac":{"tendrac","tendracs"},
"tendril":{"tendril","tendrils"},
"tenebrionid":{"tenebrionid","tenebrionids"},
"tenebrionidae":{"tenebrionidae","tenebrionidaes"},
"tenement":{"tenement","tenements"},
"tenet":{"tenet","tenets"},
"tenia":{"tenia","tenias"},
"tenner":{"tenner","tenners"},
"tennessee":{"tennessee","tennessees"},
"tennis":{"tennis","tennises"},
"tenno":{"tenno","tennos"},
"tenon":{"tenon","tenoned","tenoning"},
"tenor":{"tenor","tenors"},
"tenormin":{"tenormin","tenormins"},
"tenorrhaphy":{"tenorrhaphies","tenorrhaphy"},
"tenotomy":{"tenotomies","tenotomy"},
"tenpin":{"tenpin","tenpins"},
"tenpins":{"tenpins","tenpinses"},
"tenpounder":{"tenpounder","tenpounders"},
"tenrec":{"tenrec","tenrecs"},
"tenrecidae":{"tenrecidae","tenrecidaes"},
"tense":{"tense","tensed","tenser","tenses","tensest","tensing"},
"tenseness":{"tenseness","tensenesses"},
"tension":{"tension","tensioned","tensioning","tensions"},
"tensity":{"tensities","tensity"},
"tent":{"tent","tented","tenting","tents"},
"tent-fly":{"tent-flies","tent-fly"},
"tentacle":{"tentacle","tentacles"},
"tentaculata":{"tentaculata","tentaculatas"},
"tenter":{"tenter","tentered","tentering"},
"tenth":{"tenth","tenths"},
"tenthredinidae":{"tenthredinidae","tenthredinidaes"},
"tenting":{"tenting","tentings"},
"tenuis":{"tenues","tenuis"},
"tenuity":{"tenuities","tenuity"},
"tenure":{"tenure","tenures"},
"teocalli":{"teocalli","teocallis"},
"tepee":{"tepee","tepees"},
"tepefy":{"tepefied","tepefies","tepefy","tepefying"},
"tephrosia":{"tephrosia","tephrosias"},
"tepidity":{"tepidities","tepidity"},
"tepidness":{"tepidness","tepidnesses"},
"tera":{"tera","teras"},
"terabyte":{"terabyte","terabytes"},
"teraph":{"teraph","teraphim"},
"teratoma":{"teratoma","teratomas","teratomata"},
"terbium":{"terbium","terbiums"},
"terce":{"terce","terces"},
"tercel":{"tercel","tercels"},
"tercelet":{"tercelet","tercelets"},
"tercentenary":{"tercentenaries","tercentenary"},
"tercentennial":{"tercentennial","tercentennials"},
"tercet":{"tercet","tercets"},
"terebella":{"terebella","terebellas"},
"terebellidae":{"terebellidae","terebellidaes"},
"terebinth":{"terebinth","terebinths"},
"teredinid":{"teredinid","teredinids"},
"teredinidae":{"teredinidae","teredinidaes"},
"teredo":{"teredines","teredo","teredos"},
"tergiversate":{"tergiversate","tergiversated","tergiversates","tergiversating"},
"tergiversation":{"tergiversation","tergiversations"},
"tergum":{"terga","tergum"},
"term":{"term","termed","terming","terms"},
"termagant":{"termagant","termagants"},
"termes":{"termes","termeses"},
"terminal":{"terminal","terminals"},
"terminate":{"terminate","terminated","terminates","terminating"},
"termination":{"termination","terminations"},
"terminator":{"terminator","terminators"},
"terminology":{"terminologies","terminology"},
"terminus":{"termini","terminus","terminuses"},
"termite":{"termite","termites"},
"termitidae":{"termitidae","termitidaes"},
"terms":{"terms","termses"},
"ternary":{"ternaries","ternary"},
"ternion":{"ternion","ternions"},
"terpsichore":{"terpsichore","terpsichores"},
"terra-cotta":{"terra-cotta","terra-cottas"},
"terrace":{"terrace","terraced","terraces","terracing"},
"terramycin":{"terramycin","terramycins"},
"terrapene":{"terrapene","terrapenes"},
"terrarium":{"terraria","terrarium","terrariums","terrarraria","terrarrariums"},
"terrestrial":{"terrestrial","terrestrials"},
"terribleness":{"terribleness","terriblenesses"},
"terrier":{"terrier","terriers"},
"terrietia":{"terrietia","terrietias"},
"terrify":{"terrified","terrifies","terrify","terrifying"},
"territorial":{"territorial","territorials"},
"territorialisation":{"territorialisation","territorialisations"},
"territorialization":{"territorialization","territorializations"},
"territorialize":{"territorialize","territorialized","territorializing"},
"territory":{"territories","territory"},
"terror":{"terror","terrors"},
"terrorisation":{"terrorisation","terrorisations"},
"terrorization":{"terrorization","terrorizations"},
"terrorize":{"terrorize","terrorized","terrorizes","terrorizing"},
"terry":{"terries","terry"},
"terrycloth":{"terrycloth","terrycloths"},
"terse":{"terse","terser","tersest"},
"tertiary":{"tertiaries","tertiary"},
"tertigravida":{"tertigravida","tertigravidas"},
"tertry":{"tertries","tertry"},
"terylene":{"terylene","terylenes"},
"terzetto":{"terzetto","terzettos"},
"tesla":{"tesla","teslas"},
"tessellate":{"tessellate","tessellated","tessellating"},
"tessera":{"tessera","tesserae"},
"tessin":{"tessin","tessins"},
"test":{"test","tested","testing","tests"},
"test-drive":{"test-drive","test-driven","test-driving","test-drove"},
"test-fly":{"test-flew","test-flown","test-fly","test-flying"},
"testa":{"testa","testae","testas"},
"testacea":{"testacea","testaceas"},
"testament":{"testament","testaments"},
"testate":{"testate","testates"},
"testator":{"testator","testators"},
"testatrix":{"testatrices","testatrix"},
"testee":{"testee","testees"},
"tester":{"tester","testers"},
"testicle":{"testicle","testicles"},
"testiere":{"testiere","testieres"},
"testifier":{"testifier","testifiers"},
"testify":{"testified","testifies","testify","testifying"},
"testimonial":{"testimonial","testimonials"},
"testimony":{"testimonies","testimony"},
"testiness":{"testiness","testinesses"},
"testing":{"testing","testings"},
"testis":{"testes","testis","testises"},
"testudinata":{"testudinata","testudinatas"},
"testudines":{"testudines","testudineses"},
"testudinidae":{"testudinidae","testudinidaes"},
"testudo":{"testudines","testudo","testudos"},
"testy":{"testier","testiest","testy"},
"tetanize":{"tetanize","tetanized","tetanizing"},
"tetanus":{"tetanus","tetanuses"},
"tetchiness":{"tetchiness","tetchinesses"},
"tetchy":{"tetchier","tetchiest","tetchy"},
"tete-a-tete":{"tete-a-tete","tete-a-tetes"},
"tether":{"tether","tethered","tethering","tethers"},
"tethyidae":{"tethyidae","tethyidaes"},
"tethys":{"tethys","tethyses"},
"tetra":{"tetra","tetras"},
"tetrabromo-phenolsulfonephthalein":{"tetrabromo-phenolsulfonephthalein","tetrabromo-phenolsulfonephthaleins"},
"tetrachloromethane":{"tetrachloromethane","tetrachloromethanes"},
"tetraclinis":{"tetraclinis","tetraclinises"},
"tetracycline":{"tetracycline","tetracyclines"},
"tetrad":{"tetrad","tetrads"},
"tetragon":{"tetragon","tetragons"},
"tetragonia":{"tetragonia","tetragonias"},
"tetragoniaceae":{"tetragoniaceae","tetragoniaceaes"},
"tetragonurus":{"tetragonurus","tetragonuruses"},
"tetrahedron":{"tetrahedra","tetrahedron","tetrahedrons"},
"tetralogy":{"tetralogies","tetralogy"},
"tetraneuris":{"tetraneuris","tetraneurises"},
"tetranychid":{"tetranychid","tetranychids"},
"tetranychidae":{"tetranychidae","tetranychidaes"},
"tetrao":{"tetrao","tetraos"},
"tetraodontidae":{"tetraodontidae","tetraodontidaes"},
"tetraonidae":{"tetraonidae","tetraonidaes"},
"tetrapody":{"tetrapodies","tetrapody"},
"tetrapturus":{"tetrapturus","tetrapturuses"},
"tetterwort":{"tetterwort","tetterworts"},
"tettigoniid":{"tettigoniid","tettigoniids"},
"tettigoniidae":{"tettigoniidae","tettigoniidaes"},
"teucrium":{"teucrium","teucriums"},
"teutonize":{"teutonize","teutonized","teutonizes","teutonizing"},
"tevere":{"tevere","teveres"},
"tevet":{"tevet","tevets"},
"texas":{"texas","texases"},
"text":{"text","texts"},
"textbook":{"textbook","textbooks"},
"textile":{"textile","textiles"},
"textuary":{"textuaries","textuary"},
"texture":{"texture","textures"},
"th":{"th","ths"},
"thai":{"thai","thais"},
"thailand":{"thailand","thailands"},
"thalamencephalon":{"thalamencephala","thalamencephalon","thalamencephalons"},
"thalamus":{"thalami","thalamus"},
"thalarctos":{"thalarctos","thalarctoses"},
"thalassaemia":{"thalassaemia","thalassaemias"},
"thalassemia":{"thalassemia","thalassemias"},
"thalassocracy":{"thalassocracies","thalassocracy"},
"thalassoma":{"thalassoma","thalassomas"},
"thaliacea":{"thaliacea","thaliaceas"},
"thalictrum":{"thalictrum","thalictrums"},
"thallium":{"thallium","thalliums"},
"thallus":{"thalli","thallus","thalluses"},
"thalmencephalon":{"thalmencephalon","thalmencephalons"},
"thames":{"thames","thameses"},
"thammuz":{"thammuz","thammuzs"},
"thamnophilus":{"thamnophilus","thamnophiluses"},
"thamnophis":{"thamnophis","thamnophises"},
"thank":{"thank","thanked","thanking","thanks"},
"thankfulness":{"thankfulness","thankfulnesses"},
"thanking":{"thanking","thankings"},
"thanks":{"thanks","thankses"},
"thanksgiving":{"thanksgiving","thanksgivings"},
"that":{"that","those"},
"thatch":{"thatch","thatched","thatches","thatching"},
"thatcher":{"thatcher","thatchers"},
"thaumatolatry":{"thaumatolatries","thaumatolatry"},
"thaw":{"thaw","thawed","thawing","thaws"},
"thawing":{"thawing","thawings"},
"thb":{"thb","thbs"},
"thd":{"thd","thds"},
"thea":{"thea","theas"},
"theaceae":{"theaceae","theaceaes"},
"theanthropism":{"theanthropism","theanthropisms"},
"thearchy":{"thearchies","thearchy"},
"theater":{"theater","theaters"},
"theatergoer":{"theatergoer","theatergoers"},
"theatre":{"theatre","theatres"},
"theatre-in-the-round":{"theatre-in-the-round","theatres-in-the-round"},
"theatregoer":{"theatregoer","theatregoers"},
"theatrical":{"theatrical","theatricals"},
"theatricality":{"theatricalities","theatricality"},
"theatricalize":{"theatricalize","theatricalized","theatricalizing"},
"theca":{"theca","thecae","thecas"},
"thecodont":{"thecodont","thecodonts"},
"thecodontia":{"thecodontia","thecodontias"},
"theft":{"theft","thefts"},
"theia":{"theia","theias"},
"thelephoraceae":{"thelephoraceae","thelephoraceaes"},
"thelypteridaceae":{"thelypteridaceae","thelypteridaceaes"},
"thelypteris":{"thelypteris","thelypterises"},
"theme":{"theme","themes"},
"theobroma":{"theobroma","theobromas"},
"theocracy":{"theocracies","theocracy"},
"theodicy":{"theodicies","theodicy"},
"theodolite":{"theodolite","theodolites"},
"theogony":{"theogonies","theogony"},
"theologian":{"theologian","theologians"},
"theologist":{"theologist","theologists"},
"theologize":{"theologize","theologized","theologizing"},
"theologizer":{"theologizer","theologizers"},
"theology":{"theologies","theology"},
"theomachy":{"theomachies","theomachy"},
"theophagy":{"theophagies","theophagy"},
"theophany":{"theophanies","theophany"},
"theophrastaceae":{"theophrastaceae","theophrastaceaes"},
"theorbo":{"theorbo","theorbos"},
"theorem":{"theorem","theorems"},
"theoretician":{"theoretician","theoreticians"},
"theorisation":{"theorisation","theorisations"},
"theorist":{"theorist","theorists"},
"theorization":{"theorization","theorizations"},
"theorize":{"theorize","theorized","theorizes","theorizing"},
"theory":{"theories","theory"},
"theraphosidae":{"theraphosidae","theraphosidaes"},
"therapist":{"therapist","therapists"},
"therapsid":{"therapsid","therapsids"},
"therapsida":{"therapsida","therapsidas"},
"therapy":{"therapies","therapy"},
"theridiid":{"theridiid","theridiids"},
"theridiidae":{"theridiidae","theridiidaes"},
"thermal":{"thermal","thermals"},
"thermel":{"thermel","thermels"},
"thermistor":{"thermistor","thermistors"},
"thermobia":{"thermobia","thermobias"},
"thermocouple":{"thermocouple","thermocouples"},
"thermoform":{"thermoform","thermoformed","thermoforming"},
"thermograph":{"thermograph","thermographs"},
"thermogravimeter":{"thermogravimeter","thermogravimeters"},
"thermohydrometer":{"thermohydrometer","thermohydrometers"},
"thermometrograph":{"thermometrograph","thermometrographs"},
"thermoplastic":{"thermoplastic","thermoplastics"},
"thermopsis":{"thermopses","thermopsis"},
"thermopylae":{"thermopylae","thermopylaes"},
"thermoregulator":{"thermoregulator","thermoregulators"},
"thermos":{"thermos","thermoses"},
"thermostat":{"thermostat","thermostats"},
"thermostatics":{"thermostatics","thermostaticses"},
"theropod":{"theropod","theropods"},
"theropoda":{"theropoda","theropodas"},
"thesaurus":{"thesauri","thesaurus","thesauruses"},
"thesis":{"theses","thesis"},
"thespesia":{"thespesia","thespesias"},
"thespian":{"thespian","thespians"},
"thessalia":{"thessalia","thessalias"},
"thessalonika":{"thessalonika","thessalonikas"},
"thessaly":{"thessalies","thessaly"},
"theurgy":{"theurgies","theurgy"},
"thevetia":{"thevetia","thevetias"},
"thiamin":{"thiamin","thiamins"},
"thiamine":{"thiamine","thiamines"},
"thibet":{"thibet","thibets"},
"thick":{"thick","thicker","thickest","thicks"},
"thick-knee":{"thick-knee","thick-knees"},
"thicken":{"thicken","thickened","thickening"},
"thickener":{"thickener","thickeners"},
"thickening":{"thickening","thickenings"},
"thicket":{"thicket","thickets"},
"thickhead":{"thickhead","thickheads"},
"thickleaf":{"thickleaf","thickleaves"},
"thickness":{"thickness","thicknesses"},
"thief":{"thief","thieves"},
"thielavia":{"thielavia","thielavias"},
"thieve":{"thieve","thieved","thieves","thieving"},
"thievery":{"thieveries","thievery"},
"thieving":{"thieving","thievings"},
"thievishness":{"thievishness","thievishnesses"},
"thigh":{"thigh","thighs"},
"thigh-slapper":{"thigh-slapper","thigh-slappers"},
"thighbone":{"thighbone","thighbones"},
"thimble":{"thimble","thimbles"},
"thimbleberry":{"thimbleberries","thimbleberry"},
"thimbleful":{"thimbleful","thimblefuls"},
"thimblerig":{"thimblerig","thimblerigged","thimblerigging","thimblerigs"},
"thimbleweed":{"thimbleweed","thimbleweeds"},
"thimerosal":{"thimerosal","thimerosals"},
"thin":{"thin","thinned","thinner","thinnest","thinning","thins"},
"thing":{"thing","things"},
"thing-in-itself":{"thing-in-itself","thing-in-itselfs","things-in-themselves"},
"thingamabob":{"thingamabob","thingamabobs"},
"thingamajig":{"thingamajig","thingamajigs"},
"thingmabob":{"thingmabob","thingmabobs"},
"thingmajig":{"thingmajig","thingmajigs"},
"thingumabob":{"thingumabob","thingumabobs"},
"thingumajig":{"thingumajig","thingumajigs"},
"thingummy":{"thingummies","thingummy"},
"think":{"think","thinking","thinks","thought"},
"thinker":{"thinker","thinkers"},
"thinking":{"thinking","thinkings"},
"thinner":{"thinner","thinners"},
"thinness":{"thinness","thinnesses"},
"thinning":{"thinning","thinnings"},
"thiobacteria":{"thiobacteria","thiobacterias"},
"thiobacteriaceae":{"thiobacteriaceae","thiobacteriaceaes"},
"thiodiphenylamine":{"thiodiphenylamine","thiodiphenylamines"},
"thiopental":{"thiopental","thiopentals"},
"thioridazine":{"thioridazine","thioridazines"},
"third":{"third","thirds"},
"third-degree":{"third-degree","third-degreed","third-degreeing"},
"third-dimensionality":{"third-dimensionalities","third-dimensionality"},
"thirst":{"thirst","thirsted","thirsting","thirsts"},
"thirsty":{"thirstier","thirstiest","thirsty"},
"thirteen":{"thirteen","thirteens"},
"thirteenth":{"thirteenth","thirteenths"},
"thirties":{"thirties","thirtieses"},
"thirtieth":{"thirtieth","thirtieths"},
"thirty":{"thirties","thirty"},
"thirty-something":{"thirty-something","thirty-somethings"},
"thirty-twomo":{"thirty-twomo","thirty-twomos"},
"this":{"these","this"},
"thistle":{"thistle","thistles"},
"thlaspi":{"thlaspi","thlaspis"},
"thm":{"thm","thms"},
"thole":{"thole","tholed","tholes","tholing"},
"tholepin":{"tholepin","tholepins"},
"tholos":{"tholoi","tholos"},
"thomas":{"thomas","thomases"},
"thomomys":{"thomomys","thomomyses"},
"thong":{"thong","thonged","thonging","thongs"},
"thoracoplasty":{"thoracoplasties","thoracoplasty"},
"thoracotomy":{"thoracotomies","thoracotomy"},
"thorax":{"thoraces","thorax","thoraxes"},
"thorazine":{"thorazine","thorazines"},
"thoreau":{"thoreau","thoreaus"},
"thorium":{"thorium","thoriums"},
"thorn":{"thorn","thorns"},
"thorny":{"thornier","thorniest","thorny"},
"thoroughbred":{"thoroughbred","thoroughbreds"},
"thoroughfare":{"thoroughfare","thoroughfares"},
"thoroughwort":{"thoroughwort","thoroughworts"},
"thou":{"thou","thous"},
"thought":{"thought","thoughts"},
"thought-image":{"thought-image","thought-images"},
"thought-reader":{"thought-reader","thought-readers"},
"thoughtfulness":{"thoughtfulness","thoughtfulnesses"},
"thoughtlessness":{"thoughtlessness","thoughtlessnesses"},
"thousand":{"thousand","thousands"},
"thousandth":{"thousandth","thousandths"},
"thraldom":{"thraldom","thraldoms"},
"thrall":{"thrall","thralls"},
"thralldom":{"thralldom","thralldoms"},
"thrash":{"thrash","thrashed","thrashes","thrashing"},
"thrasher":{"thrasher","thrashers"},
"thrashing":{"thrashing","thrashings"},
"thraupidae":{"thraupidae","thraupidaes"},
"thread":{"thread","threaded","threading","threads"},
"threadfin":{"threadfin","threadfins"},
"threadfish":{"threadfish","threadfishes"},
"threads":{"threads","threadses"},
"threadworm":{"threadworm","threadworms"},
"thready":{"threadier","threadiest","thready"},
"threap":{"threap","threaped","threaping"},
"threat":{"threat","threats"},
"threaten":{"threaten","threatened","threatening","threatens"},
"three":{"three","threes"},
"three-bagger":{"three-bagger","three-baggers"},
"three-d":{"three-d","three-ds"},
"three-decker":{"three-decker","three-deckers"},
"three-dimensionality":{"three-dimensionalities","three-dimensionality"},
"three-hitter":{"three-hitter","three-hitters"},
"three-sixty":{"three-sixties","three-sixty"},
"threepence":{"threepence","threepences"},
"threesome":{"threesome","threesomes"},
"threnode":{"threnode","threnodes"},
"threnody":{"threnodies","threnody"},
"thresh":{"thresh","threshed","threshes","threshing"},
"thresher":{"thresher","threshers"},
"threshold":{"threshold","thresholds"},
"threskiornis":{"threskiornis","threskiornises"},
"threskiornithidae":{"threskiornithidae","threskiornithidaes"},
"thrift":{"thrift","thrifts"},
"thriftiness":{"thriftiness","thriftinesses"},
"thriftlessness":{"thriftlessness","thriftlessnesses"},
"thriftshop":{"thriftshop","thriftshops"},
"thrifty":{"thriftier","thriftiest","thrifty"},
"thrill":{"thrill","thrilled","thrilling","thrills"},
"thrinax":{"thrinax","thrinaxes"},
"thrip":{"thrip","thrips"},
"thripid":{"thripid","thripids"},
"thripidae":{"thripidae","thripidaes"},
"thrips":{"thrips","thripses"},
"thrive":{"thrive","thrived","thriven","thrives","thriving","throve"},
"throat":{"throat","throats"},
"throatwort":{"throatwort","throatworts"},
"throaty":{"throatier","throatiest","throaty"},
"throb":{"throb","throbbed","throbbing","throbs"},
"throbbing":{"throbbing","throbbings"},
"thrombocyte":{"thrombocyte","thrombocytes"},
"thrombocytopenia":{"thrombocytopenia","thrombocytopenias"},
"thrombokinase":{"thrombokinase","thrombokinases"},
"thrombolytic":{"thrombolytic","thrombolytics"},
"thrombopenia":{"thrombopenia","thrombopenias"},
"thromboplastin":{"thromboplastin","thromboplastins"},
"thrombus":{"thrombi","thrombus"},
"throne":{"throne","throned","thrones","throning"},
"throng":{"throng","thronged","thronging","throngs"},
"throstle":{"throstle","throstles"},
"throttle":{"throttle","throttled","throttles","throttling"},
"throttlehold":{"throttlehold","throttleholds"},
"throttling":{"throttling","throttlings"},
"throughway":{"throughway","throughways"},
"throw":{"threw","throw","throwing","thrown","throws"},
"throwaway":{"throwaway","throwaways"},
"throwback":{"throwback","throwbacks"},
"throw_out":{"threw_out","throwing_out","thrown_out","throws_out","throw_out"},
"thrum":{"thrum","thrummed","thrumming","thrums"},
"thrummy":{"thrummier","thrummiest","thrummy"},
"thrush":{"thrush","thrushes"},
"thrust":{"thrust","thrusting","thrusts"},
"thruster":{"thruster","thrusters"},
"thrusting":{"thrusting","thrustings"},
"thruway":{"thruway","thruways"},
"thryothorus":{"thryothorus","thryothoruses"},
"thud":{"thud","thudded","thudding","thuds"},
"thug":{"thug","thugs"},
"thuja":{"thuja","thujas"},
"thujopsis":{"thujopses","thujopsis"},
"thule":{"thule","thules"},
"thulium":{"thulium","thuliums"},
"thumb":{"thumb","thumbed","thumbing","thumbs"},
"thumbnut":{"thumbnut","thumbnuts"},
"thumbtack":{"thumbtack","thumbtacked","thumbtacking","thumbtacks"},
"thump":{"thump","thumped","thumping","thumps"},
"thumper":{"thumper","thumpers"},
"thumping":{"thumping","thumpings"},
"thunbergia":{"thunbergia","thunbergias"},
"thunder":{"thunder","thundered","thundering","thunders"},
"thunderbolt":{"thunderbolt","thunderbolts"},
"thunderclap":{"thunderclap","thunderclaps"},
"thundercloud":{"thundercloud","thunderclouds"},
"thunderer":{"thunderer","thunderers"},
"thundershower":{"thundershower","thundershowers"},
"thunderstorm":{"thunderstorm","thunderstorms"},
"thunnus":{"thunnus","thunnuses"},
"thurible":{"thurible","thuribles"},
"thursday":{"thursday","thursdays"},
"thwack":{"thwack","thwacked","thwacking","thwacks"},
"thwart":{"thwart","thwarted","thwarting","thwarts"},
"thwarting":{"thwarting","thwartings"},
"thylacine":{"thylacine","thylacines"},
"thylacinus":{"thylacinus","thylacinuses"},
"thylogale":{"thylogale","thylogales"},
"thymelaeaceae":{"thymelaeaceae","thymelaeaceaes"},
"thymelaeales":{"thymelaeales","thymelaealeses"},
"thymol":{"thymol","thymols"},
"thymus":{"thymus","thymuses","thymusmi"},
"thymy":{"thymier","thymiest","thymy"},
"thyreophora":{"thyreophora","thyreophoras"},
"thyreophoran":{"thyreophoran","thyreophorans"},
"thyroid":{"thyroid","thyroids"},
"thyroidectomy":{"thyroidectomies","thyroidectomy"},
"thyrotoxicosis":{"thyrotoxicoses","thyrotoxicosis"},
"thyrotrophin":{"thyrotrophin","thyrotrophins"},
"thyroxin":{"thyroxin","thyroxins"},
"thyroxine":{"thyroxine","thyroxines"},
"thyrse":{"therses","thyrse"},
"thyrsopteris":{"thyrsopteris","thyrsopterises"},
"thyrsus":{"thyrsi","thyrsui","thyrsus"},
"thysanocarpus":{"thysanocarpus","thysanocarpuses"},
"thysanopter":{"thysanopter","thysanopters"},
"thysanoptera":{"thysanoptera","thysanopteras"},
"thysanopteron":{"thysanopteron","thysanopterons"},
"thysanura":{"thysanura","thysanuras"},
"thysanuron":{"thysanuron","thysanurons"},
"ti":{"ti","tis"},
"tianjin":{"tianjin","tianjins"},
"tiara":{"tiara","tiaras"},
"tiarella":{"tiarella","tiarellas"},
"tiber":{"tiber","tibers"},
"tibet":{"tibet","tibets"},
"tibeto-burman":{"tibeto-burman","tibeto-burmen"},
"tibia":{"tibia","tibiae","tibias"},
"tibialis":{"tibialis","tibialises"},
"tibicen":{"tibicen","tibicens"},
"tic-tac-toe":{"tic-tac-toe","tic-tac-toes"},
"tical":{"tical","ticals"},
"tichodroma":{"tichodroma","tichodromas"},
"tichodrome":{"tichodrome","tichodromes"},
"ticino":{"ticino","ticinos"},
"tick":{"tick","ticked","ticking","ticks"},
"ticker":{"ticker","tickers"},
"ticket":{"ticket","ticketed","ticketing","tickets"},
"ticking":{"ticking","tickings"},
"tickle":{"tickle","tickled","tickles","tickling"},
"tickler":{"tickler","ticklers"},
"tickling":{"tickling","ticklings"},
"tickseed":{"tickseed","tickseeds"},
"ticktacktoe":{"ticktacktoe","ticktacktoes"},
"ticktacktoo":{"ticktacktoo","ticktacktoos"},
"ticktock":{"ticktock","ticktocks"},
"tickweed":{"tickweed","tickweeds"},
"tictac":{"tictac","tictacs"},
"tidbit":{"tidbit","tidbits"},
"tiddler":{"tiddler","tiddlers"},
"tide":{"tide","tided","tides","tiding"},
"tidiness":{"tidiness","tidinesses"},
"tidings":{"tidings","tidingses"},
"tidy":{"tidied","tidier","tidies","tidiest","tidy","tidying"},
"tidytips":{"tidytips","tidytipses"},
"tie":{"tie","tied","ties","tying"},
"tie-dye":{"tie-dye","tie-dyed","tie-dyeing"},
"tie-in":{"tie-in","tie-ins"},
"tie-up":{"tie-up","tie-ups"},
"tien-pao":{"tien-pao","tien-paos"},
"tientsin":{"tientsin","tientsins"},
"tiepin":{"tiepin","tiepins"},
"tier":{"tier","tiered","tiering","tiers"},
"tierce":{"tierce","tierces"},
"tiercel":{"tiercel","tiercels"},
"tiff":{"tiff","tiffed","tiffing","tiffs"},
"tiffany":{"tiffanies","tiffany"},
"tiffin":{"tiffin","tiffins"},
"tiflis":{"tiflis","tiflises"},
"tiger":{"tiger","tigers"},
"tight":{"tight","tighter","tightest"},
"tighten":{"tighten","tightened","tightening","tightens"},
"tightfistedness":{"tightfistedness","tightfistednesses"},
"tightness":{"tightness","tightnesses"},
"tights":{"tights","tightses"},
"tightwad":{"tightwad","tightwads"},
"tiglon":{"tiglon","tiglons"},
"tigon":{"tigon","tigons"},
"tigris":{"tigris","tigrises"},
"tike":{"tike","tikes"},
"tilapia":{"tilapia","tilapias"},
"tilbury":{"tilburies","tilbury"},
"tilde":{"tilde","tildes"},
"tile":{"tile","tiled","tiles","tiling"},
"tilefish":{"tilefish","tilefishes"},
"tilia":{"tilia","tilias"},
"tiliaceae":{"tiliaceae","tiliaceaes"},
"tiliomycetes":{"tiliomycetes","tiliomyceteses"},
"till":{"till","tilled","tilling","tills"},
"tillage":{"tillage","tillages"},
"tillandsia":{"tillandsia","tillandsias"},
"tiller":{"tiller","tillered","tillering","tillers"},
"tilletia":{"tilletia","tilletias"},
"tilletiaceae":{"tilletiaceae","tilletiaceaes"},
"tilt":{"tilt","tilted","tilting","tilts"},
"tilth":{"tilth","tilths"},
"timalia":{"timalia","timalias"},
"timaliidae":{"timaliidae","timaliidaes"},
"timbale":{"timbale","timbales"},
"timber":{"timber","timbered","timbering","timbers"},
"timberland":{"timberland","timberlands"},
"timberline":{"timberline","timberlines"},
"timberman":{"timberman","timbermen"},
"timbre":{"timbre","timbres"},
"time":{"time","timed","times","timing"},
"time-out":{"time-out","time-outs"},
"timekeeper":{"timekeeper","timekeepers"},
"timelessness":{"timelessness","timelessnesses"},
"timeliness":{"timeliness","timelinesses"},
"timely":{"timelier","timeliest","timely"},
"timepiece":{"timepiece","timepieces"},
"times":{"times","timeses"},
"timetable":{"timetable","timetables"},
"timid":{"timid","timider","timidest","timids"},
"timidity":{"timidities","timidity"},
"timidness":{"timidness","timidnesses"},
"timocracy":{"timocracies","timocracy"},
"timorousness":{"timorousness","timorousnesses"},
"timothy":{"timothies","timothy"},
"timpani":{"timpani","timpanis"},
"timpanist":{"timpanist","timpanists"},
"timpano":{"timpani","timpano"},
"timur":{"timur","timurs"},
"tin":{"tin","tinned","tinning","tins"},
"tin-plating":{"tin-plating","tin-platings"},
"tinamidae":{"tinamidae","tinamidaes"},
"tinamiformes":{"tinamiformes","tinamiformeses"},
"tinamou":{"tinamou","tinamous"},
"tinca":{"tinca","tincas"},
"tincture":{"tincture","tinctured","tinctures","tincturing"},
"tinder":{"tinder","tinders"},
"tinea":{"tinea","tineas"},
"tineid":{"tineid","tineids"},
"tineidae":{"tineidae","tineidaes"},
"tineoid":{"tineoid","tineoids"},
"tineoidea":{"tineoidea","tineoideas"},
"tineola":{"tineola","tineolas"},
"tinfoil":{"tinfoil","tinfoils"},
"ting":{"ting","tinged","tinging","tings"},
"tinge":{"tinge","tinged","tingeing","tinges","tinging"},
"tingidae":{"tingidae","tingidaes"},
"tingle":{"tingle","tingled","tingles","tingling"},
"tingling":{"tingling","tinglings"},
"tinker":{"tinker","tinkered","tinkering","tinkers"},
"tinkle":{"tinkle","tinkled","tinkles","tinkling"},
"tinning":{"tinning","tinnings"},
"tinny":{"tinnier","tinniest","tinny"},
"tinsel":{"tinsel","tinseled","tinseling","tinselled","tinselling","tinsels"},
"tinsnips":{"tinsnips","tinsnipses"},
"tint":{"tint","tinted","tinting","tints"},
"tintinnabulation":{"tintinnabulation","tintinnabulations"},
"tintinnabulum":{"tintinnabula","tintinnabulum"},
"tintometer":{"tintometer","tintometers"},
"tiny":{"tinier","tiniest","tiny"},
"tinyness":{"tinyness","tinynesses"},
"tip":{"tip","tipped","tipping","tips"},
"tip-off":{"tip-off","tip-offs"},
"tip-top":{"tip-top","tip-tops"},
"tipi":{"tipi","tipis"},
"tipple":{"tipple","tippled","tipples","tippling"},
"tippler":{"tippler","tipplers"},
"tippy":{"tippier","tippiest","tippy"},
"tipsiness":{"tipsiness","tipsinesses"},
"tipstaff":{"tipstaff","tipstaffs","tipstaves"},
"tipster":{"tipster","tipsters"},
"tipsy":{"tipsier","tipsiest","tipsy"},
"tiptoe":{"tiptoe","tiptoed","tiptoeing","tiptoes"},
"tipu":{"tipu","tipus"},
"tipuana":{"tipuana","tipuanas"},
"tipulidae":{"tipulidae","tipulidaes"},
"tirade":{"tirade","tirades"},
"tirana":{"tirana","tiranas"},
"tire":{"tire","tired","tires","tiring"},
"tiredness":{"tiredness","tirednesses"},
"tirelessness":{"tirelessness","tirelessnesses"},
"tiresomeness":{"tiresomeness","tiresomenesses"},
"tirewoman":{"tirewoman","tirewomen"},
"tiro":{"tiro","tiros"},
"tirol":{"tirol","tirols"},
"tissue":{"tissue","tissued","tissues","tissuing"},
"tit":{"tit","tits"},
"tit-tat-toe":{"tit-tat-toe","tit-tat-toes"},
"titan":{"titan","titans"},
"titania":{"titania","titanias"},
"titanium":{"titanium","titaniums"},
"titanosaur":{"titanosaur","titanosaurs"},
"titanosaurian":{"titanosaurian","titanosaurians"},
"titanosauridae":{"titanosauridae","titanosauridaes"},
"titanosaurus":{"titanosaurus","titanosauruses"},
"titbit":{"titbit","titbits"},
"titer":{"titer","titers"},
"tithe":{"tithe","tithed","tithes","tithing"},
"tither":{"tither","tithers"},
"tithonia":{"tithonia","tithonias"},
"titi":{"titi","titis"},
"titian":{"titian","titians"},
"titillate":{"titillate","titillated","titillates","titillating"},
"titivate":{"titivate","titivated","titivates","titivating"},
"titlark":{"titlark","titlarks"},
"title":{"title","titled","titles","titling"},
"title-holder":{"title-holder","title-holders"},
"titman":{"titman","titmen"},
"titmouse":{"titmice","titmouse"},
"titrate":{"titrate","titrated","titrating"},
"titre":{"titre","titres"},
"titter":{"titter","tittered","tittering","titters"},
"tittivate":{"tittivate","tittivated","tittivates","tittivating"},
"tittle":{"tittle","tittles"},
"tittle-tattle":{"tittle-tattle","tittle-tattled","tittle-tattles","tittle-tattling"},
"tittup":{"tittup","tittuped","tittuping","tittupped","tittupping","tittups"},
"titty":{"titties","titty"},
"titular":{"titular","titulars"},
"titulary":{"titularies","titulary"},
"tiv":{"tiv","tivs"},
"tizzy":{"tizzies","tizzy"},
"tko":{"tko","tkos"},
"tl":{"tl","tls"},
"tlc":{"tlc","tlcs"},
"tlingit":{"tlingit","tlingits"},
"tm":{"tm","tms"},
"tmv":{"tmv","tmvs"},
"tnt":{"tnt","tnts"},
"to-do":{"to-do","to-dos"},
"toad":{"toad","toads"},
"toadfish":{"toadfish","toadfishes"},
"toadflax":{"toadflax","toadflaxes"},
"toadfrog":{"toadfrog","toadfrogs"},
"toadshade":{"toadshade","toadshades"},
"toadstool":{"toadstool","toadstools"},
"toady":{"toadied","toadies","toady","toadying"},
"toast":{"toast","toasted","toasting","toasts"},
"toasting":{"toasting","toastings"},
"toasty":{"toastier","toastiest","toasty"},
"tobacco":{"tobacco","tobaccoes","tobaccos"},
"tobacconist":{"tobacconist","tobacconists"},
"toboggan":{"toboggan","tobogganed","tobogganing","toboggans"},
"toby":{"tobies","toby"},
"toccata":{"toccata","toccatas","toccate"},
"tocktact":{"tocktact","tocktacts"},
"tocology":{"tocologies","tocology"},
"tocopherol":{"tocopherol","tocopherols"},
"tocsin":{"tocsin","tocsins"},
"toddle":{"toddle","toddled","toddles","toddling"},
"toddler":{"toddler","toddlers"},
"toddy":{"toddies","toddy"},
"todea":{"todea","todeas"},
"todidae":{"todidae","todidaes"},
"todus":{"todus","toduses"},
"tody":{"todies","tody"},
"toe":{"toe","toed","toeing","toes"},
"toetoe":{"toetoe","toetoes"},
"toff":{"toff","toffs"},
"toffee":{"toffee","toffees"},
"toffy":{"toffies","toffy"},
"tofieldia":{"tofieldia","tofieldias"},
"tofu":{"tofu","tofus"},
"tog":{"tog","togged","togging","togs"},
"toga":{"toga","togae","togas"},
"toggle":{"toggle","toggled","toggles","toggling"},
"togs":{"togs","togses"},
"toil":{"toil","toiled","toiling","toils"},
"toilet":{"toilet","toilets"},
"toiletries":{"toiletries","toiletrieses"},
"toiletry":{"toiletries","toiletry"},
"toilsomeness":{"toilsomeness","toilsomenesses"},
"toitoi":{"toitoi","toitois"},
"token":{"token","tokens"},
"tokio":{"tokio","tokios"},
"tokyo":{"tokyo","tokyos"},
"tolazamide":{"tolazamide","tolazamides"},
"tolbooth":{"tolbooth","tolbooths"},
"tolectin":{"tolectin","tolectins"},
"tolerance":{"tolerance","tolerances"},
"tolerate":{"tolerate","tolerated","tolerates","tolerating"},
"toleration":{"toleration","tolerations"},
"tolinase":{"tolinase","tolinases"},
"toll":{"toll","tolled","tolling","tolls"},
"tollbar":{"tollbar","tollbars"},
"tollbooth":{"tollbooth","tollbooths"},
"toller":{"toller","tollers"},
"tollgate":{"tollgate","tollgates"},
"tollgatherer":{"tollgatherer","tollgatherers"},
"tollhouse":{"tollhouse","tollhouses"},
"tollie":{"tollie","tollies"},
"tollkeeper":{"tollkeeper","tollkeepers"},
"tollman":{"tollman","tollmen"},
"tollon":{"tollon","tollons"},
"tolltaker":{"tolltaker","tolltakers"},
"tolly":{"tollies","tolly"},
"tolmiea":{"tolmiea","tolmieas"},
"tolstoy":{"tolstoy","tolstoys"},
"toltec":{"toltec","toltecs"},
"tolu":{"tolu","tolus"},
"toluene":{"toluene","toluenes"},
"tolypeutes":{"tolypeutes","tolypeuteses"},
"tom":{"tom","toms"},
"tom-tom":{"tom-tom","tom-toms"},
"tomahawk":{"tomahawk","tomahawked","tomahawking","tomahawks"},
"tomalley":{"tomalley","tomalleys"},
"tomatillo":{"tomatillo","tomatillos"},
"tomato":{"tomato","tomatoes"},
"tomb":{"tomb","tombed","tombing","tombs"},
"tombac":{"tombac","tombacs"},
"tombak":{"tombak","tombaks"},
"tombigbee":{"tombigbee","tombigbees"},
"tombolo":{"tombolo","tombolos"},
"tomboy":{"tomboy","tomboys"},
"tomboyishness":{"tomboyishness","tomboyishnesses"},
"tombstone":{"tombstone","tombstones"},
"tomcat":{"tomcat","tomcats"},
"tomcod":{"tomcod","tomcods"},
"tomentum":{"tomenta","tomentum","tomentums"},
"tomfool":{"tomfool","tomfools"},
"tomfoolery":{"tomfooleries","tomfoolery"},
"tomistoma":{"tomistoma","tomistomas"},
"tommy":{"tommies","tommy"},
"tommyrot":{"tommyrot","tommyrots"},
"tomography":{"tomographies","tomography"},
"tomorrow":{"tomorrow","tomorrows"},
"tomtate":{"tomtate","tomtates"},
"tomtit":{"tomtit","tomtits"},
"tomtom":{"tomtom","tomtoms"},
"ton":{"ton","tons"},
"tonality":{"tonalities","tonality"},
"tondo":{"tondi","tondo"},
"tone":{"tone","toned","tones","toning"},
"tone-beginning":{"tone-beginning","tone-beginnings"},
"tong":{"tong","tonged","tonging"},
"tonga":{"tonga","tongas"},
"tongs":{"tongs","tongses"},
"tongue":{"tongue","tongued","tongues","tonguing"},
"tongue-lash":{"tongue-lash","tongue-lashed","tongue-lashing"},
"tonic":{"tonic","tonics"},
"tonicity":{"tonicities","tonicity"},
"tonnage":{"tonnage","tonnages"},
"tonne":{"tonne","tonnes"},
"tonneau":{"tonneau","tonneaus","tonneaux"},
"tons":{"tons","tonses"},
"tonsil":{"tonsil","tonsils"},
"tonsillectomy":{"tonsillectomies","tonsillectomy"},
"tonsillotomy":{"tonsillotomies","tonsillotomy"},
"tonsure":{"tonsure","tonsured","tonsuring"},
"tontine":{"tontine","tontines"},
"tonus":{"tonus","tonuses"},
"tony":{"tonier","toniest","tony"},
"tool":{"tool","tooled","tooling","tools"},
"toolbox":{"toolbox","toolboxes"},
"toolhouse":{"toolhouse","toolhouses"},
"toona":{"toona","toonas"},
"tooshie":{"tooshie","tooshies"},
"toot":{"toot","tooted","tooting","toots"},
"tooth":{"teeth","tooth","toothed","toothing"},
"toothache":{"toothache","toothaches"},
"toothbrush":{"toothbrush","toothbrushes"},
"toothpick":{"toothpick","toothpicks"},
"toothpowder":{"toothpowder","toothpowders"},
"toothsomeness":{"toothsomeness","toothsomenesses"},
"toothwort":{"toothwort","toothworts"},
"toothy":{"toothier","toothiest","toothy"},
"tootle":{"tootle","tootled","tootling"},
"toots":{"toots","tootses"},
"tootsie":{"tootsie","tootsies"},
"tootsy":{"tootsies","tootsy"},
"tootsy-wootsy":{"tootsy-wootsies","tootsy-wootsy"},
"top":{"top","topped","topping","tops"},
"topaz":{"topaz","topazes","topazs"},
"topcoat":{"topcoat","topcoats"},
"topdress":{"topdress","topdressed","topdressing"},
"tope":{"tope","toped","topes","toping"},
"topee":{"topee","topees"},
"topeka":{"topeka","topekas"},
"toper":{"toper","topers"},
"topgallant":{"topgallant","topgallants"},
"tophus":{"tophi","tophus"},
"topi":{"topees","topi","topis"},
"topiary":{"topiaries","topiary"},
"topic":{"topic","topics"},
"topminnow":{"topminnow","topminnows"},
"topognosia":{"topognosia","topognosias"},
"topognosis":{"topognoses","topognosis"},
"topography":{"topographies","topography"},
"topolatry":{"topolatries","topolatry"},
"topology":{"topologies","topology"},
"toponym":{"toponym","toponyms"},
"topos":{"topoi","topos"},
"topper":{"topper","toppers"},
"topping":{"topping","toppings"},
"topple":{"topple","toppled","topples","toppling"},
"topsoil":{"topsoil","topsoils"},
"topstitch":{"topstitch","topstitched","topstitching"},
"topsy-turvy":{"topsy-turvied","topsy-turvies","topsy-turvy","topsy-turvying"},
"topsy-turvydom":{"topsy-turvydom","topsy-turvydoms"},
"topsy-turvyness":{"topsy-turvyness","topsy-turvynesses"},
"topv":{"topv","topvs"},
"toque":{"toque","toques"},
"toradol":{"toradol","toradols"},
"torah":{"torah","torahs"},
"torch":{"torch","torches"},
"torchy":{"torchier","torchiest","torchy"},
"tore":{"tore","tores"},
"toreador":{"toreador","toreadors"},
"torero":{"torero","toreros"},
"torino":{"torino","torinos"},
"torment":{"torment","tormented","tormenting","torments"},
"tormenter":{"tormenter","tormenters"},
"tormentor":{"tormentor","tormentors"},
"tornado":{"tornado","tornadoes","tornados"},
"tornillo":{"tornillo","tornillos"},
"toro":{"toro","toros"},
"torodal":{"torodal","torodals"},
"toroid":{"toroid","toroids"},
"torpedinidae":{"torpedinidae","torpedinidaes"},
"torpediniformes":{"torpediniformes","torpediniformeses"},
"torpedo":{"torpedo","torpedoed","torpedoes","torpedoing"},
"torpidity":{"torpidities","torpidity"},
"torpidness":{"torpidness","torpidnesses"},
"torpor":{"torpor","torpors"},
"torque":{"torque","torques"},
"torr":{"torr","torrs"},
"torrefy":{"torrefied","torrefies","torrefy","torrefying","torrify"},
"torrent":{"torrent","torrents"},
"torreya":{"torreya","torreyas"},
"torricelli":{"torricelli","torricellis"},
"torsion":{"torsion","torsions"},
"torsk":{"torsk","torsks"},
"torso":{"torsi","torso","torsos"},
"tort":{"tort","torts"},
"torticollis":{"torticollis","torticollises"},
"tortilla":{"tortilla","tortillas"},
"tortoise":{"tortoise","tortoises"},
"tortoiseshell":{"tortoiseshell","tortoiseshells"},
"tortoiseshell-cat":{"tortoiseshell-cat","tortoiseshell-cats"},
"tortricid":{"tortricid","tortricids"},
"tortricidae":{"tortricidae","tortricidaes"},
"tortrix":{"tortrix","tortrixes"},
"tortuosity":{"tortuosities","tortuosity"},
"tortuousness":{"tortuousness","tortuousnesses"},
"torture":{"torture","tortured","tortures","torturing"},
"torturing":{"torturing","torturings"},
"torus":{"tori","torus","toruses"},
"tory":{"tories","tory"},
"toscana":{"toscana","toscanas"},
"tosh":{"tosh","toshes"},
"tosk":{"tosk","tosks"},
"toss":{"tose","toss","tossed","tosses","tossing","tost"},
"toss-up":{"toss-up","toss-ups"},
"tostada":{"tostada","tostadas"},
"tot":{"tot","tots","totted","totting"},
"total":{"total","totaled","totaling","totalled","totalling","totals"},
"totalisator":{"totalisator","totalisators"},
"totaliser":{"totaliser","totalisers"},
"totalism":{"totalism","totalisms"},
"totalitarian":{"totalitarian","totalitarians"},
"totalitarianism":{"totalitarianism","totalitarianisms"},
"totality":{"totalities","totality"},
"totalizator":{"totalizator","totalizators"},
"totalize":{"totalize","totalized","totalizing"},
"totalizer":{"totalizer","totalizers"},
"totara":{"totara","totaras"},
"tote":{"tote","toted","totes","toting"},
"toter":{"toter","toters"},
"totter":{"totter","tottered","tottering","totters"},
"touch":{"touch","touched","touches","touching"},
"touch-me-not":{"touch-me-not","touch-me-nots"},
"touch-type":{"touch-type","touch-typed","touch-typing"},
"touchiness":{"touchiness","touchinesses"},
"touching":{"touching","touchings"},
"touchstone":{"touchstone","touchstones"},
"touchwood":{"touchwood","touchwoods"},
"touchy":{"touchier","touchiest","touchy"},
"tough":{"tough","tougher","toughest","toughs"},
"toughen":{"toughen","toughened","toughening"},
"toughie":{"toughie","toughies"},
"toughness":{"toughness","toughnesses"},
"toupe":{"toupe","toupes"},
"toupee":{"toupee","toupees"},
"tour":{"tour","toured","touring","tours"},
"touraco":{"touraco","touracos"},
"tourer":{"tourer","tourers"},
"touring":{"touring","tourings"},
"tourism":{"tourism","tourisms"},
"tourist":{"tourist","tourists"},
"touristry":{"touristries","touristry"},
"tournament":{"tournament","tournaments"},
"tourney":{"tourney","tourneyed","tourneying","tourneys"},
"tourniquet":{"tourniquet","tourniquets"},
"tousle":{"tousle","tousled","tousles","tousling"},
"tout":{"tout","touted","touting","touts"},
"tow":{"tow","towed","towing","tows"},
"towage":{"towage","towages"},
"towboat":{"towboat","towboats"},
"towel":{"towel","toweled","toweling","towelled","towelling","towels"},
"toweling":{"toweling","towelings"},
"towelling":{"towelling","towellings"},
"tower":{"tower","towered","towering","towers"},
"towline":{"towline","towlines"},
"town":{"town","towns"},
"townee":{"townee","townees","townies"},
"towner":{"towner","towners"},
"townie":{"townie","townies"},
"townsendia":{"townsendia","townsendias"},
"townsfolk":{"townsfolk","townsfolks"},
"township":{"township","townships"},
"townsman":{"townsman","townsmen"},
"townspeople":{"townspeople","townspeoples"},
"townswoman":{"townswoman","townswomen"},
"towny":{"townies","towny"},
"towpath":{"towpath","towpaths"},
"towrope":{"towrope","towropes"},
"toxaemia":{"toxaemia","toxaemias"},
"toxemia":{"toxemia","toxemias"},
"toxicity":{"toxicities","toxicity"},
"toxicodendron":{"toxicodendron","toxicodendrons"},
"toxostoma":{"toxostoma","toxostomas"},
"toxotes":{"toxotes","toxoteses"},
"toxotidae":{"toxotidae","toxotidaes"},
"toy":{"toy","toyed","toying","toys"},
"toying":{"toying","toyings"},
"toyon":{"toyon","toyons"},
"tra-la":{"tra-la","tra-las"},
"tra-la-la":{"tra-la-la","tra-la-las"},
"trabecula":{"trabecula","trabeculae"},
"trace":{"trace","traced","traces","tracing"},
"tracer":{"tracer","tracers"},
"tracery":{"traceries","tracery"},
"trachea":{"trachea","tracheae","tracheas"},
"trachelospermum":{"trachelospermum","trachelospermums"},
"tracheophyta":{"tracheophyta","tracheophytas"},
"tracheophyte":{"tracheophyte","tracheophytes"},
"tracheostomy":{"tracheostomies","tracheostomy"},
"tracheotomy":{"tracheotomies","tracheotomy"},
"trachinotus":{"trachinotus","trachinotuses"},
"trachipteridae":{"trachipteridae","trachipteridaes"},
"trachipterus":{"trachipterus","trachipteruses"},
"trachodon":{"trachodon","trachodons"},
"trachodont":{"trachodont","trachodonts"},
"trachurus":{"trachurus","trachuruses"},
"tracing":{"tracing","tracings"},
"track":{"track","tracked","tracking","tracks"},
"tracking":{"tracking","trackings"},
"tracklayer":{"tracklayer","tracklayers"},
"trackman":{"trackman","trackmen"},
"tract":{"tract","tracts"},
"tractability":{"tractabilities","tractability"},
"tractableness":{"tractableness","tractablenesses"},
"tractarianism":{"tractarianism","tractarianisms"},
"traction":{"traction","tractions"},
"tractor":{"tractor","tractors"},
"trade":{"trade","traded","trades","trading"},
"trademark":{"trademark","trademarked","trademarking","trademarks"},
"trader":{"trader","traders"},
"tradescantia":{"tradescantia","tradescantias"},
"tradesman":{"tradesman","tradesmen"},
"tradeswoman":{"tradeswoman","tradeswomen"},
"tradition":{"tradition","traditions"},
"traditionalism":{"traditionalism","traditionalisms"},
"traditionalist":{"traditionalist","traditionalists"},
"traditionality":{"traditionalities","traditionality"},
"traditor":{"traditor","traditores","traditors"},
"traduce":{"traduce","traduced","traduces","traducing"},
"traducement":{"traducement","traducements"},
"traducer":{"traducer","traducers"},
"trafalgar":{"trafalgar","trafalgars"},
"traffic":{"traffic","trafficked","trafficking","traffics"},
"trafficator":{"trafficator","trafficators"},
"trafficker":{"trafficker","traffickers"},
"tragedy":{"tragedies","tragedy"},
"tragelaphus":{"tragelaphus","tragelaphuses"},
"tragicomedy":{"tragicomedies","tragicomedy"},
"tragopogon":{"tragopogon","tragopogons"},
"tragulidae":{"tragulidae","tragulidaes"},
"tragulus":{"tragulus","traguluses"},
"tragus":{"tragi","tragus"},
"trail":{"trail","trailed","trailing","trails"},
"trailer":{"trailer","trailers"},
"trailing":{"trailing","trailings"},
"train":{"train","trained","training","trains"},
"trainer":{"trainer","trainers"},
"training":{"training","trainings"},
"trainman":{"trainman","trainmen"},
"trainmaster":{"trainmaster","trainmasters"},
"traipse":{"traipse","traipsed","traipses","traipsesd","traipsing"},
"trait":{"trait","traits"},
"traitor":{"traitor","traitors"},
"traitorousness":{"traitorousness","traitorousnesses"},
"trajectory":{"trajectories","trajectory"},
"tram":{"tram","trammed","tramming","trams"},
"tramcar":{"tramcar","tramcars"},
"tramline":{"tramline","tramlines"},
"trammel":{"trammel","trammeled","trammeling","trammelled","trammelling","trammels"},
"trammels":{"trammels","trammelses"},
"tramontana":{"tramontana","tramontanas"},
"tramontane":{"tramontane","tramontanes"},
"tramp":{"tramp","tramped","tramping","tramps"},
"trample":{"trample","trampled","tramples","trampling"},
"trampling":{"trampling","tramplings"},
"tramway":{"tramway","tramways"},
"trance":{"trance","tranced","trances","trancing"},
"tranquil":{"tranquil","tranquiler","tranquilest","tranquiller","tranquillest"},
"tranquility":{"tranquilities","tranquility"},
"tranquilize":{"tranquilize","tranquilized","tranquilizes","tranquilizing"},
"tranquilizer":{"tranquilizer","tranquilizers"},
"tranquillity":{"tranquillities","tranquillity"},
"tranquillize":{"tranquillize","tranquillized","tranquillizes","tranquillizing"},
"tranquillizer":{"tranquillizer","tranquillizers"},
"transact":{"transact","transacted","transacting"},
"transaction":{"transaction","transactions"},
"transactions":{"transactions","transactionses"},
"transactor":{"transactor","transactors"},
"transcend":{"transcend","transcended","transcending","transcends"},
"transcendence":{"transcendence","transcendences"},
"transcendency":{"transcendencies","transcendency"},
"transcendentalism":{"transcendentalism","transcendentalisms"},
"transcribe":{"transcribe","transcribed","transcribes","transcribing"},
"transcript":{"transcript","transcripts"},
"transcription":{"transcription","transcriptions"},
"transduce":{"transduce","transduced","transducing"},
"transect":{"transect","transected","transecting"},
"transfer":{"transfer","transferred","transferring","transfers"},
"transference":{"transference","transferences"},
"transferral":{"transferral","transferrals"},
"transfigure":{"transfigure","transfigured","transfigures","transfiguring"},
"transfix":{"transfix","transfixed","transfixes","transfixing","transfixt"},
"transform":{"transform","transformed","transforming","transforms"},
"transformation":{"transformation","transformations"},
"transformer":{"transformer","transformers"},
"transfuse":{"transfuse","transfused","transfuses","transfusing"},
"transfusion":{"transfusion","transfusions"},
"transgress":{"transgress","transgressed","transgresses","transgressing"},
"transgression":{"transgression","transgressions"},
"transgressor":{"transgressor","transgressors"},
"tranship":{"tranship","transhipped","transhipping","tranships"},
"transience":{"transience","transiences"},
"transiency":{"transiencies","transiency"},
"transient":{"transient","transients"},
"transistor":{"transistor","transistors"},
"transistorize":{"transistorize","transistorized","transistorizing"},
"transit":{"transit","transited","transiting","transits"},
"transition":{"transition","transitions"},
"transitiveness":{"transitiveness","transitivenesses"},
"transitivity":{"transitivities","transitivity"},
"transitoriness":{"transitoriness","transitorinesses"},
"translate":{"translate","translated","translates","translating"},
"translation":{"translation","translations"},
"translator":{"translator","translators"},
"transliterate":{"transliterate","transliterated","transliterates","transliterating"},
"translocate":{"translocate","translocated","translocating"},
"translucence":{"translucence","translucences"},
"translucency":{"translucencies","translucency"},
"transmigrate":{"transmigrate","transmigrated","transmigrating"},
"transmission":{"transmission","transmissions"},
"transmit":{"transmit","transmits","transmitted","transmitting"},
"transmittal":{"transmittal","transmittals"},
"transmittance":{"transmittance","transmittances"},
"transmitter":{"transmitter","transmitters"},
"transmitting":{"transmitting","transmittings"},
"transmogrify":{"transmogrified","transmogrifies","transmogrify","transmogrifying"},
"transmutability":{"transmutabilities","transmutability"},
"transmutation":{"transmutation","transmutations"},
"transmute":{"transmute","transmuted","transmutes","transmuting"},
"transom":{"transom","transoms"},
"transparence":{"transparence","transparences"},
"transparency":{"transparencies","transparency"},
"transparentness":{"transparentness","transparentnesses"},
"transpierce":{"transpierce","transpierced","transpiercing"},
"transpiration":{"transpiration","transpirations"},
"transpire":{"transpire","transpired","transpires","transpiring"},
"transplant":{"transplant","transplanted","transplanting","transplants"},
"transplantation":{"transplantation","transplantations"},
"transplanter":{"transplanter","transplanters"},
"transplanting":{"transplanting","transplantings"},
"transport":{"transport","transported","transporting","transports"},
"transportation":{"transportation","transportations"},
"transporter":{"transporter","transporters"},
"transposability":{"transposabilities","transposability"},
"transpose":{"transpose","transposed","transposes","transposing"},
"transposition":{"transposition","transpositions"},
"transship":{"tranship","transship","transshipped","transshipping","transships"},
"transubstantiate":{"transubstantiate","transubstantiated","transubstantiating"},
"transubstantiation":{"transubstantiation","transubstantiations"},
"transudation":{"transudation","transudations"},
"transvalue":{"transvalue","transvalued","transvalues","transvaluing"},
"transversalis":{"transversalis","transversalises"},
"transverse":{"transverse","transverses"},
"transversus":{"transversus","transversuses"},
"transvestism":{"transvestism","transvestisms"},
"transvestite":{"transvestite","transvestites"},
"transvestitism":{"transvestitism","transvestitisms"},
"trap":{"trap","trapped","trapping","traps"},
"trapa":{"trapa","trapas"},
"trapaceae":{"trapaceae","trapaceaes"},
"trapan":{"trapan","trapanned","trapanning","trapans"},
"trapes":{"trapes","trapesed","trapesing"},
"trapezium":{"trapezia","trapezium","trapeziums"},
"trapezius":{"trapezius","trapeziuses"},
"trapezohedron":{"trapezohedra","trapezohedron","trapezohedrons"},
"trapezoid":{"trapezoid","trapezoids"},
"trapper":{"trapper","trappers"},
"trapping":{"trapping","trappings"},
"trappings":{"trappings","trappingses"},
"trappist":{"trappist","trappists"},
"trappy":{"trappier","trappiest","trappy"},
"trapshooting":{"trapshooting","trapshootings"},
"trapunto":{"trapunto","trapuntos"},
"trash":{"trash","trashed","trashes","trashing"},
"trashiness":{"trashiness","trashinesses"},
"trashy":{"trashier","trashiest","trashy"},
"trattoria":{"trattoria","trattorias"},
"trauma":{"trauma","traumas","traumata"},
"traumatize":{"traumatize","traumatized","traumatizes","traumatizing"},
"trautvetteria":{"trautvetteria","trautvetterias"},
"travail":{"travail","travailed","travailing","travails"},
"trave":{"trave","traves"},
"travel":{"travel","traveled","traveling","travelled","travelling","travels"},
"traveler":{"traveler","travelers"},
"traveling":{"traveling","travelings"},
"traveller":{"traveller","travellers"},
"travelling":{"travelling","travellings"},
"travelog":{"travelog","travelogs"},
"travelogue":{"travelogue","travelogues"},
"traversal":{"traversal","traversals"},
"traverse":{"traverse","traversed","traverses","traversing"},
"traverser":{"traverser","traversers"},
"travesty":{"travestied","travesties","travesty","travestying"},
"trawl":{"trawl","trawled","trawling","trawls"},
"trawler":{"trawler","trawlers"},
"tray":{"tray","trays"},
"treachery":{"treacheries","treachery"},
"treacle":{"treacle","treacles"},
"tread":{"tread","treading","treads","trod","trodden"},
"tread-softly":{"tread-softlies","tread-softly"},
"treadle":{"treadle","treadled","treadles","treadling"},
"treadmill":{"treadmill","treadmills"},
"treadwheel":{"treadwheel","treadwheels"},
"treason":{"treason","treasons"},
"treasonist":{"treasonist","treasonists"},
"treasure":{"treasure","treasured","treasures","treasuring"},
"treasurer":{"treasurer","treasurers"},
"treasuries":{"treasuries","treasurieses"},
"treasury":{"treasuries","treasury"},
"treat":{"treat","treated","treating","treats"},
"treatise":{"treatise","treatises"},
"treatment":{"treatment","treatments"},
"treaty":{"treaties","treaty"},
"treble":{"treble","trebled","trebles","trebling"},
"tredecillion":{"tredecillion","tredecillions"},
"tree":{"tree","treed","treeing","trees"},
"tree-worship":{"tree-worship","tree-worships"},
"treefrog":{"treefrog","treefrogs"},
"treenail":{"treenail","treenails"},
"treetop":{"treetop","treetops"},
"trefoil":{"trefoil","trefoils"},
"treillage":{"treillage","treillages"},
"trek":{"trek","trekked","trekking","treks"},
"trellis":{"trellis","trellised","trellises","trellising"},
"trematoda":{"trematoda","trematodas"},
"trematode":{"trematode","trematodes"},
"tremble":{"tremble","trembled","trembles","trembling"},
"trembles":{"trembles","trembleses"},
"trembling":{"trembling","tremblings"},
"trembly":{"tremblier","trembliest","trembly"},
"tremella":{"tremella","tremellas"},
"tremellaceae":{"tremellaceae","tremellaceaes"},
"tremellales":{"tremellales","tremellaleses"},
"tremolo":{"tremolo","tremolos"},
"tremor":{"tremor","tremored","tremoring","tremors"},
"trenail":{"trenail","trenails"},
"trench":{"trench","trenched","trenches","trenching"},
"trenchancy":{"trenchancies","trenchancy"},
"trencher":{"trencher","trenchers"},
"trencherman":{"trencherman","trenchermen"},
"trenchfoot":{"trenchfeet","trenchfoot"},
"trend":{"trend","trended","trending","trends"},
"trend-setter":{"trend-setter","trend-setters"},
"trendy":{"trendier","trendiest","trendy"},
"trente-et-quarante":{"trente-et-quarante","trente-et-quarantes"},
"trenton":{"trenton","trentons"},
"trepan":{"trepan","trepanned","trepanning","trepans"},
"trepang":{"trepang","trepangs"},
"trephine":{"trephine","trephined","trephines","trephining"},
"trephritidae":{"trephritidae","trephritidaes"},
"treponema":{"nemata","trepnemata","treponema","treponemas","treponemata"},
"treponemataceae":{"treponemataceae","treponemataceaes"},
"treponeme":{"treponeme","treponemes"},
"trespass":{"trespass","trespassed","trespasses","trespassing"},
"trespasser":{"trespasser","trespassers"},
"tress":{"tress","tresses"},
"trey":{"trey","treys"},
"triacetate":{"triacetate","triacetates"},
"triad":{"triad","triads"},
"triaenodon":{"triaenodon","triaenodons"},
"triakidae":{"triakidae","triakidaes"},
"trial":{"trial","trials"},
"trialeurodes":{"trialeurodes","trialeurodeses"},
"triangle":{"triangle","triangles"},
"triangulate":{"triangulate","triangulated","triangulating"},
"triarchy":{"triarchies","triarchy"},
"triassic":{"triassic","triassics"},
"triatoma":{"triatoma","triatomas"},
"tribe":{"tribe","tribes"},
"tribesman":{"tribesman","tribesmen"},
"tribolium":{"tribolium","triboliums"},
"tribonema":{"tribonema","tribonemas"},
"tribonemaceae":{"tribonemaceae","tribonemaceaes"},
"tribromoethanol":{"tribromoethanol","tribromoethanols"},
"tribulation":{"tribulation","tribulations"},
"tribulus":{"tribulus","tribuluses"},
"tribunal":{"tribunal","tribunals"},
"tribune":{"tribune","tribunes"},
"tributary":{"tributaries","tributary"},
"tribute":{"tribute","tributes"},
"trice":{"trice","triced","trices","tricing"},
"triceps":{"triceps","tricepses"},
"trichechidae":{"trichechidae","trichechidaes"},
"trichechus":{"trichechus","trichechuses"},
"trichina":{"trichina","trichinae"},
"trichion":{"trichion","trichions"},
"trichiuridae":{"trichiuridae","trichiuridaes"},
"trichloromethane":{"trichloromethane","trichloromethanes"},
"trichoceros":{"trichoceros","trichoceroses"},
"trichodontidae":{"trichodontidae","trichodontidaes"},
"trichoglossus":{"trichoglossus","trichoglossuses"},
"tricholoma":{"tricholoma","tricholomas"},
"tricholomataceae":{"tricholomataceae","tricholomataceaes"},
"trichomanes":{"trichomanes","trichomaneses"},
"trichophaga":{"trichophaga","trichophagas"},
"trichophyton":{"trichophyton","trichophytons"},
"trichoptera":{"trichoptera","trichopteras"},
"trichopteran":{"trichopteran","trichopterans"},
"trichopteron":{"trichopteron","trichopterons"},
"trichostema":{"trichostema","trichostemas"},
"trichosurus":{"trichosurus","trichosuruses"},
"trichotomy":{"trichotomies","trichotomy"},
"trichys":{"trichys","trichyses"},
"trick":{"trick","tricked","tricking","tricks"},
"trick-or-treat":{"trick-or-treat","trick-or-treated","trick-or-treating"},
"trickery":{"trickeries","trickery"},
"trickiness":{"trickiness","trickinesses"},
"trickle":{"trickle","trickled","trickles","trickling"},
"trickster":{"trickster","tricksters"},
"tricksy":{"tricksier","tricksiest","tricksy"},
"tricky":{"trickier","trickiest","tricky"},
"triclinium":{"triclinia","tricliniia","triclinium"},
"tricolor":{"tricolor","tricolors"},
"tricolour":{"tricolour","tricolours"},
"tricorn":{"tricorn","tricorns"},
"tricorne":{"tricorne","tricornes"},
"tricycle":{"tricycle","tricycles"},
"tricyclic":{"tricyclic","tricyclics"},
"tridacna":{"tridacna","tridacnas"},
"tridacnidae":{"tridacnidae","tridacnidaes"},
"triennial":{"triennial","triennials"},
"triennium":{"triennia","triennium","trienniums"},
"trierarchy":{"trierarchies","trierarchy"},
"trifle":{"trifle","trifled","trifles","trifling"},
"trifling":{"trifling","triflings"},
"trifoliata":{"trifoliata","trifoliatas"},
"trifolium":{"trifolium","trifoliums"},
"triforium":{"triforia","triforium"},
"trig":{"trig","trigs"},
"triga":{"triga","trigas"},
"trigeminal":{"trigeminal","trigeminals"},
"trigger":{"trigger","triggered","triggering","triggers"},
"triggerfish":{"triggerfish","triggerfishes"},
"triggerman":{"triggerman","triggermen"},
"triglidae":{"triglidae","triglidaes"},
"triglinae":{"triglinae","triglinaes"},
"triglochin":{"triglochin","triglochins"},
"trigon":{"trigon","trigons"},
"trigonella":{"trigonella","trigonellas"},
"trigonometry":{"trigonometries","trigonometry"},
"trihedron":{"trihedra","trihedron","trihedrons"},
"triiodomethane":{"triiodomethane","triiodomethanes"},
"trike":{"trike","trikes"},
"trilateral":{"trilateral","trilaterals"},
"trilby":{"trilbies","trilby"},
"trilisa":{"trilisa","trilisas"},
"trill":{"trill","trilled","trilling","trills"},
"trilliaceae":{"trilliaceae","trilliaceaes"},
"trillion":{"trillion","trillions"},
"trillions":{"trillions","trillionses"},
"trillionth":{"trillionth","trillionths"},
"trillium":{"trillium","trilliums"},
"trilogy":{"trilogies","trilogy"},
"trim":{"trim","trimmed","trimmer","trimmest","trimming","trims"},
"trimmer":{"trimmer","trimmers"},
"trimming":{"trimming","trimmings"},
"trimness":{"trimness","trimnesses"},
"trimorphodon":{"trimorphodon","trimorphodons"},
"trine":{"trine","trines"},
"trinectes":{"trinectes","trinecteses"},
"tringa":{"tringa","tringas"},
"trinitroglycerin":{"trinitroglycerin","trinitroglycerins"},
"trinitrotoluene":{"trinitrotoluene","trinitrotoluenes"},
"trinity":{"trinities","trinity"},
"trinket":{"trinket","trinkets"},
"trio":{"trio","trios"},
"triolein":{"triolein","trioleins"},
"trionychidae":{"trionychidae","trionychidaes"},
"trionyx":{"trionyx","trionyxes"},
"triopidae":{"triopidae","triopidaes"},
"triops":{"triops","triopses"},
"triostium":{"triostium","triostiums"},
"trip":{"trip","tripped","tripping","trips"},
"tripalmitin":{"tripalmitin","tripalmitins"},
"tripe":{"tripe","tripes"},
"triple":{"triple","tripled","triples","tripling"},
"triplet":{"triplet","triplets"},
"tripletail":{"tripletail","tripletails"},
"tripleurospermum":{"tripleurospermum","tripleurospermums"},
"triplicate":{"triplicate","triplicated","triplicating"},
"triplicity":{"triplicities","triplicity"},
"triplochiton":{"triplochiton","triplochitons"},
"tripod":{"tripod","tripods"},
"tripody":{"tripodies","tripody"},
"tripoli":{"tripoli","tripolis"},
"tripos":{"tripos","triposes"},
"tripper":{"tripper","trippers"},
"tripple-decker":{"tripple-decker","tripple-deckers"},
"triquetral":{"triquetral","triquetrals"},
"trisect":{"trisect","trisected","trisecting"},
"triskele":{"triskele","triskeles"},
"triskelion":{"triskelia","triskelion"},
"trisoctahedron":{"trisoctahedra","trisoctahedron","trisoctahedrons"},
"tristan":{"tristan","tristans"},
"tristearin":{"tristearin","tristearins"},
"tristram":{"tristram","tristrams"},
"tritanopia":{"tritanopia","tritanopias"},
"trite":{"trite","triter","tritest"},
"triteness":{"triteness","tritenesses"},
"triticum":{"triticum","triticums"},
"tritoma":{"tritoma","tritomas"},
"triton":{"triton","tritons"},
"triturate":{"triturate","triturated","triturating"},
"triturus":{"triturus","trituruses"},
"triumph":{"triumph","triumphed","triumphing","triumphs"},
"triumvir":{"triumvir","triumviri","triumvirs"},
"trivia":{"trivia","trivias"},
"triviality":{"trivialities","triviality"},
"trivialize":{"trivialize","trivialized","trivializing"},
"trivium":{"triviia","trivium"},
"triweekly":{"triweeklies","triweekly"},
"trm":{"trm","trms"},
"trna":{"trna","trnas"},
"troche":{"troche","troches"},
"trochilidae":{"trochilidae","trochilidaes"},
"trochlea":{"trochlea","trochleae"},
"trochlear":{"trochlear","trochlears"},
"trochlearis":{"trochlearis","trochlearises"},
"trog":{"trog","trogged","trogging","trogs"},
"trogium":{"trogium","trogiums"},
"troglodyte":{"troglodyte","troglodytes"},
"troglodytes":{"troglodytes","troglodyteses"},
"troglodytidae":{"troglodytidae","troglodytidaes"},
"trogonidae":{"trogonidae","trogonidaes"},
"trogoniformes":{"trogoniformes","trogoniformeses"},
"troika":{"troika","troikas"},
"troll":{"troll","trolled","trolling","trolls"},
"troller":{"troller","trollers"},
"trolley":{"trolley","trolleyed","trolleying","trolleys"},
"trolleybus":{"trolleybus","trolleybuses"},
"trollius":{"trollius","trolliuses"},
"trollop":{"trollop","trollops"},
"trombicula":{"trombicula","trombiculas"},
"trombiculidae":{"trombiculidae","trombiculidaes"},
"trombidiidae":{"trombidiidae","trombidiidaes"},
"trombonist":{"trombonist","trombonists"},
"trompillo":{"trompillo","trompillos"},
"trondheim":{"trondheim","trondheims"},
"troop":{"troop","trooped","trooping","troops"},
"trooper":{"trooper","troopers"},
"troops":{"troops","troopses"},
"tropaeolaceae":{"tropaeolaceae","tropaeolaceaes"},
"tropaeolum":{"tropaeolum","tropaeolums"},
"trope":{"trope","tropes"},
"trophy":{"trophies","trophy"},
"tropic":{"tropic","tropics"},
"tropicbird":{"tropicbird","tropicbirds"},
"tropics":{"tropics","tropicses"},
"tropidoclonion":{"tropidoclonion","tropidoclonions"},
"tropology":{"tropologies","tropology"},
"troponym":{"troponym","troponyms"},
"trot":{"trot","trots","trotted","trotting"},
"troth":{"troth","trothed","trothing","troths"},
"trotter":{"trotter","trotters"},
"trou-de-loup":{"trou-de-loup","trous-de-loup"},
"troubadour":{"troubadour","troubadours"},
"trouble":{"trouble","troubled","troubles","troubling"},
"troublemaker":{"troublemaker","troublemakers"},
"troubleshooter":{"troubleshooter","troubleshooters"},
"troublesomeness":{"troublesomeness","troublesomenesses"},
"troubling":{"troubling","troublings"},
"trough":{"trough","troughs"},
"trounce":{"trounce","trounced","trounces","trouncing"},
"trouncing":{"trouncing","trouncings"},
"troupe":{"troupe","trouped","troupes","trouping"},
"trouper":{"trouper","troupers"},
"trousering":{"trousering","trouserings"},
"trousers":{"trousers","trouserses"},
"trousseau":{"trousseau","trousseaus","trousseaux"},
"trout":{"trout","trouts"},
"trove":{"trove","troves"},
"trow":{"trow","trowed","trowing"},
"trowel":{"trowel","troweled","troweling","trowelled","trowelling","trowels"},
"troy":{"troy","troys"},
"truancy":{"truancies","truancy"},
"truant":{"truant","truanted","truanting","truants"},
"truce":{"truce","truces"},
"truck":{"truck","trucked","trucking","trucks"},
"trucker":{"trucker","truckers"},
"trucking":{"trucking","truckings"},
"truckle":{"truckle","truckled","truckles","truckling"},
"truckler":{"truckler","trucklers"},
"truckman":{"truckman","truckmen"},
"truculence":{"truculence","truculences"},
"truculency":{"truculencies","truculency"},
"trudge":{"trudge","trudged","trudges","trudging"},
"true":{"true","trued","trueing","truer","trues","truest","truing"},
"truelove":{"truelove","trueloves"},
"truffle":{"truffle","truffles"},
"truman":{"truman","trumen"},
"trump":{"trump","trumped","trumping","trumps"},
"trumpery":{"trumperies","trumpery"},
"trumpet":{"trumpet","trumpeted","trumpeting","trumpets"},
"trumpeter":{"trumpeter","trumpeters"},
"trumpetfish":{"trumpetfish","trumpetfishes"},
"trumpets":{"trumpets","trumpetses"},
"trumpetwood":{"trumpetwood","trumpetwoods"},
"trumping":{"trumping","trumpings"},
"truncate":{"truncate","truncated","truncates","truncating"},
"truncation":{"truncation","truncations"},
"truncheon":{"truncheon","truncheoned","truncheoning","truncheons"},
"truncocolumella":{"truncocolumella","truncocolumellas"},
"trundle":{"trundle","trundled","trundles","trundling"},
"trunk":{"trunk","trunked","trunking","trunks"},
"trunkfish":{"trunkfish","trunkfishes"},
"trunks":{"trunks","trunkses"},
"trunnel":{"trunnel","trunnels"},
"truss":{"truss","trussed","trusses","trussing"},
"trust":{"trust","trusted","trusting","trusts"},
"trustee":{"trustee","trusteed","trusteeing","trustees"},
"trusteeship":{"trusteeship","trusteeships"},
"trustfulness":{"trustfulness","trustfulnesses"},
"trustiness":{"trustiness","trustinesses"},
"trustingness":{"trustingness","trustingnesses"},
"trustworthiness":{"trustworthiness","trustworthinesses"},
"trustworthy":{"trustworthier","trustworthiest","trustworthy"},
"trusty":{"trustier","trusties","trustiest","trusty"},
"truth":{"truth","truths"},
"try":{"tried","tries","try","trying"},
"try-on":{"try-on","try-ons"},
"tryma":{"tryma","trymata"},
"tryout":{"tryout","tryouts"},
"trypetidae":{"trypetidae","trypetidaes"},
"tryptophan":{"tryptophan","tryptophans"},
"tryptophane":{"tryptophane","tryptophanes"},
"tryst":{"tryst","trysted","trysting","trysts"},
"tsar":{"tsar","tsars"},
"tsarina":{"tsarina","tsarinas"},
"tsaritsa":{"tsaritsa","tsaritsas"},
"tsaritsyn":{"tsaritsyn","tsaritsyns"},
"tsetse":{"tsetse","tsetses"},
"tsh":{"tsh","tshes"},
"tsine":{"tsine","tsines"},
"tsonga":{"tsonga","tsongas"},
"tsuga":{"tsuga","tsugas"},
"tsunami":{"tsunami","tsunamis"},
"tswana":{"tswana","tswanas"},
"tt":{"tt","tts"},
"tuareg":{"tuareg","tuaregs"},
"tuatara":{"tuatara","tuataras"},
"tub":{"tub","tubbed","tubbing","tubs"},
"tub-cart":{"tub-cart","tub-carts"},
"tuba":{"tuba","tubas"},
"tubbiness":{"tubbiness","tubbinesses"},
"tubby":{"tubbier","tubbiest","tubby"},
"tube":{"tube","tubed","tubes","tubing"},
"tubeless":{"tubeless","tubelesses"},
"tuber":{"tuber","tubers"},
"tuberaceae":{"tuberaceae","tuberaceaes"},
"tuberales":{"tuberales","tuberaleses"},
"tubercle":{"tubercle","tubercles"},
"tubercularia":{"tubercularia","tubercularias"},
"tuberculariaceae":{"tuberculariaceae","tuberculariaceaes"},
"tuberculosis":{"tuberculoses","tuberculosis"},
"tuberose":{"tuberose","tuberoses"},
"tuberosity":{"tuberosities","tuberosity"},
"tubful":{"tubful","tubfuls"},
"tubifex":{"tubifex","tubifexes"},
"tubing":{"tubing","tubings"},
"tubocurarine":{"tubocurarine","tubocurarines"},
"tubulidentata":{"tubulidentata","tubulidentatas"},
"tuck":{"tuck","tucked","tucking","tucks"},
"tuckahoe":{"tuckahoe","tuckahoes"},
"tucker":{"tucker","tuckered","tuckering","tuckers"},
"tudor":{"tudor","tudors"},
"tues":{"tues","tueses"},
"tuesday":{"tuesday","tuesdays"},
"tuft":{"tuft","tufted","tufting","tufts"},
"tug":{"tug","tugged","tugging","tugs"},
"tugboat":{"tugboat","tugboats"},
"tugela":{"tugela","tugelas"},
"tughrik":{"tughrik","tughriks"},
"tugrik":{"tugrik","tugriks"},
"tuition":{"tuition","tuitions"},
"tularaemia":{"tularaemia","tularaemias"},
"tularemia":{"tularemia","tularemias"},
"tulestoma":{"tulestoma","tulestomas"},
"tulip":{"tulip","tulips"},
"tulipa":{"tulipa","tulipas"},
"tulipwood":{"tulipwood","tulipwoods"},
"tully":{"tullies","tully"},
"tulostoma":{"tulostoma","tulostomas"},
"tulostomaceae":{"tulostomaceae","tulostomaceaes"},
"tulostomataceae":{"tulostomataceae","tulostomataceaes"},
"tulostomatales":{"tulostomatales","tulostomataleses"},
"tum":{"tum","tums"},
"tumble":{"tumble","tumbled","tumbles","tumbling"},
"tumbler":{"tumbler","tumblers"},
"tumblewed":{"tumblewed","tumbleweds"},
"tumbleweed":{"tumbleweed","tumbleweeds"},
"tumbling":{"tumbling","tumblings"},
"tumbrel":{"tumbrel","tumbrels"},
"tumbril":{"tumbril","tumbrils"},
"tumefy":{"tumefied","tumefies","tumefy","tumefying"},
"tumescence":{"tumescence","tumescences"},
"tumidity":{"tumidities","tumidity"},
"tumidness":{"tumidness","tumidnesses"},
"tummy":{"tummies","tummy"},
"tumor":{"tumor","tumors"},
"tumour":{"tumour","tumours"},
"tumult":{"tumult","tumults"},
"tumultuousness":{"tumultuousness","tumultuousnesses"},
"tumulus":{"tumuli","tumulus","tumuluses"},
"tun":{"tun","tunned","tunning","tuns"},
"tuna":{"tuna","tunas"},
"tundra":{"tundra","tundras"},
"tune":{"tune","tuned","tunes","tuning"},
"tune-up":{"tune-up","tune-ups"},
"tunefulness":{"tunefulness","tunefulnesses"},
"tuner":{"tuner","tuners"},
"tung":{"tung","tungs"},
"tunga":{"tunga","tungas"},
"tungsten":{"tungsten","tungstens"},
"tungus":{"tungus","tunguses"},
"tungusic":{"tungusic","tungusics"},
"tunguz":{"tunguz","tunguzs"},
"tunic":{"tunic","tunics"},
"tunica":{"tunica","tunicas"},
"tunicata":{"tunicata","tunicatas"},
"tunicate":{"tunicate","tunicates"},
"tunis":{"tunis","tunises"},
"tunker":{"tunker","tunkers"},
"tunnage":{"tunnage","tunnages"},
"tunnel":{"tunnel","tunneled","tunneling","tunnelled","tunnelling","tunnels"},
"tunny":{"tunnies","tunny"},
"tup":{"tup","tups"},
"tupaia":{"tupaia","tupaias"},
"tupaiidae":{"tupaiidae","tupaiidaes"},
"tupamaro":{"tupamaro","tupamaros"},
"tupek":{"tupek","tupeks"},
"tupelo":{"tupelo","tupelos"},
"tupi":{"tupi","tupis"},
"tupi-guarani":{"tupi-guarani","tupi-guaranis"},
"tupik":{"tupik","tupiks"},
"tupinambis":{"tupinambis","tupinambises"},
"tuppence":{"tuppence","tuppences"},
"turaco":{"turaco","turacos"},
"turacou":{"turacou","turacous"},
"turakoo":{"turakoo","turakoos"},
"turban":{"turban","turbans"},
"turbary":{"turbaries","turbary"},
"turbatrix":{"turbatrix","turbatrixes"},
"turbellaria":{"turbellaria","turbellarias"},
"turbidity":{"turbidities","turbidity"},
"turbidness":{"turbidness","turbidnesses"},
"turbinal":{"turbinal","turbinals"},
"turbinate":{"turbinate","turbinates"},
"turbofan":{"turbofan","turbofans"},
"turbojet":{"turbojet","turbojets"},
"turboprop":{"turboprop","turboprops"},
"turbot":{"turbot","turbots"},
"turbulence":{"turbulence","turbulences"},
"turbulency":{"turbulencies","turbulency"},
"turco":{"turco","turcos"},
"turcoman":{"turcoman","turcomen"},
"turd":{"turd","turds"},
"turdidae":{"turdidae","turdidaes"},
"turdinae":{"turdinae","turdinaes"},
"turdus":{"turdus","turduses"},
"turf":{"turf","turfed","turfing","turfs","turves"},
"turfan":{"turfan","turfans"},
"turfman":{"turfman","turfmen"},
"turfy":{"turfier","turfiest","turfy"},
"turgidity":{"turgidities","turgidity"},
"turgidness":{"turgidness","turgidnesses"},
"turin":{"turin","turins"},
"turkestan":{"turkestan","turkestans"},
"turkey":{"turkey","turkeys"},
"turki":{"turki","turkis"},
"turkic":{"turkic","turkics"},
"turkistan":{"turkistan","turkistans"},
"turkman":{"turkman","turkmen"},
"turkmen":{"turkmen","turkmens"},
"turkmenia":{"turkmenia","turkmenias"},
"turkmenistan":{"turkmenistan","turkmenistans"},
"turko-tatar":{"turko-tatar","turko-tatars"},
"turkoman":{"turkoman","turkomen"},
"turkomen":{"turkomen","turkomens"},
"turmeric":{"turmeric","turmerics"},
"turmoil":{"turmoil","turmoils"},
"turn":{"turn","turned","turning","turns"},
"turnabout":{"turnabout","turnabouts"},
"turnaround":{"turnaround","turnarounds"},
"turncoat":{"turncoat","turncoats"},
"turncock":{"turncock","turncocks"},
"turndown":{"turndown","turndowns"},
"turner":{"turner","turners"},
"turnery":{"turneries","turnery"},
"turnicidae":{"turnicidae","turnicidaes"},
"turning":{"turning","turnings"},
"turnip":{"turnip","turnips"},
"turnix":{"turnix","turnixes"},
"turnkey":{"turnkey","turnkeys"},
"turnoff":{"turnoff","turnoffs"},
"turnout":{"turnout","turnouts"},
"turnover":{"turnover","turnovers"},
"turnpike":{"turnpike","turnpikes"},
"turnround":{"turnround","turnrounds"},
"turntable":{"turntable","turntables"},
"turnup":{"turnup","turnups"},
"turpentine":{"turpentine","turpentined","turpentines","turpentining"},
"turpitude":{"turpitude","turpitudes"},
"turps":{"turps","turpses"},
"turquoise":{"turquoise","turquoises"},
"turret":{"turret","turrets"},
"turritis":{"turritis","turritises"},
"tursiops":{"tursiops","tursiopses"},
"turtle":{"turtle","turtles"},
"turtledove":{"turtledove","turtledoves"},
"turtlehead":{"turtlehead","turtleheads"},
"turtleneck":{"turtleneck","turtlenecks"},
"tuscany":{"tuscanies","tuscany"},
"tuscarora":{"tuscarora","tuscaroras"},
"tush":{"tush","tushes"},
"tusk":{"tusk","tusked","tusking","tusks"},
"tussah":{"tussah","tussahs"},
"tusseh":{"tusseh","tussehs"},
"tusser":{"tusser","tussers"},
"tussilago":{"tussilago","tussilagos"},
"tussle":{"tussle","tussled","tussles","tussling"},
"tussock":{"tussock","tussocks"},
"tussore":{"tussore","tussores"},
"tussur":{"tussur","tussurs"},
"tut":{"tut","tuts","tutted","tutting"},
"tut-tut":{"tut-tut","tut-tuts","tut-tutted","tut-tutting"},
"tutelage":{"tutelage","tutelages"},
"tutelar":{"tutelar","tutelars"},
"tutelary":{"tutelaries","tutelarlaries","tutelary"},
"tutor":{"tutor","tutored","tutoring","tutors"},
"tutoring":{"tutoring","tutorings"},
"tutorship":{"tutorship","tutorships"},
"tutsan":{"tutsan","tutsans"},
"tutsi":{"tutsi","tutsis"},
"tutti":{"tutti","tuttis"},
"tutu":{"tutu","tutus"},
"tuvalu":{"tuvalu","tuvalus"},
"tux":{"tux","tuxes"},
"tuxedo":{"tuxedo","tuxedoes","tuxedos"},
"tv":{"tv","tvs"},
"tv-antenna":{"tv-antenna","tv-antennas"},
"twaddle":{"twaddle","twaddled","twaddles","twaddling"},
"twain":{"twain","twains"},
"twang":{"twang","twanged","twanging","twangs"},
"twayblade":{"twayblade","twayblades"},
"tweak":{"tweak","tweaked","tweaking","tweaks"},
"tweed":{"tweed","tweeds"},
"tweediness":{"tweediness","tweedinesses"},
"tweedy":{"tweedier","tweediest","tweedy"},
"tweeny":{"tweenies","tweeny"},
"tweet":{"tweet","tweeted","tweeting","tweets"},
"tweezer":{"tweezer","tweezers"},
"twelfth":{"twelfth","twelfths"},
"twelve":{"twelve","twelves"},
"twelvemo":{"twelvemo","twelvemos"},
"twelvemonth":{"twelvemonth","twelvemonths"},
"twenties":{"twenties","twentieses"},
"twentieth":{"twentieth","twentieths"},
"twenty":{"twenties","twenty"},
"twenty-eight":{"twenty-eight","twenty-eights"},
"twenty-five":{"twenty-five","twenty-fives"},
"twenty-four":{"twenty-four","twenty-fours"},
"twenty-nine":{"twenty-nine","twenty-nines"},
"twenty-one":{"twenty-one","twenty-ones"},
"twenty-seven":{"twenty-seven","twenty-sevens"},
"twenty-six":{"twenty-six","twenty-sixes"},
"twenty-three":{"twenty-three","twenty-threes"},
"twenty-two":{"twenty-two","twenty-twos"},
"twerp":{"twerp","twerps"},
"twi":{"twi","twis"},
"twiddle":{"twiddle","twiddled","twiddles","twiddling"},
"twig":{"twig","twigged","twigging","twigs"},
"twiggy":{"twiggier","twiggiest","twiggy"},
"twilight":{"twilight","twilights"},
"twill":{"twill","twilled","twilling","twills"},
"twin":{"twin","twinned","twinning","twins"},
"twin-prop":{"twin-prop","twin-props"},
"twin-propeller-plane":{"twin-propeller-plane","twin-propeller-planes"},
"twinberry":{"twinberries","twinberry"},
"twine":{"twine","twined","twines","twining"},
"twinflower":{"twinflower","twinflowers"},
"twinge":{"twinge","twinged","twinges","twinging"},
"twinkle":{"twinkle","twinkled","twinkles","twinkling"},
"twinkling":{"twinkling","twinklings"},
"twirl":{"twirl","twirled","twirling","twirls"},
"twirler":{"twirler","twirlers"},
"twirp":{"twirp","twirps"},
"twist":{"twist","twisted","twisting","twists"},
"twister":{"twister","twisters"},
"twisting":{"twisting","twistings"},
"twistwood":{"twistwood","twistwoods"},
"twit":{"twit","twits","twitted","twitting"},
"twitch":{"twitch","twitched","twitches","twitching"},
"twitching":{"twitching","twitchings"},
"twitter":{"twitter","twittered","twittering","twitters"},
"twitting":{"twitting","twittings"},
"two":{"two","twos"},
"two-bagger":{"two-bagger","two-baggers"},
"two-baser":{"two-baser","two-basers"},
"two-dimensionality":{"two-dimensionalities","two-dimensionality"},
"two-hitter":{"two-hitter","two-hitters"},
"two-piece":{"two-piece","two-pieces"},
"two-ply":{"two-plies","two-ply"},
"two-seater":{"two-seater","two-seaters"},
"two-time":{"two-time","two-timed","two-timing"},
"twopence":{"twopence","twopences"},
"twosome":{"twosome","twosomes"},
"tycoon":{"tycoon","tycoons"},
"tyke":{"tyke","tykes"},
"tylenchidae":{"tylenchidae","tylenchidaes"},
"tylenchus":{"tylenchus","tylenchuses"},
"tylenol":{"tylenol","tylenols"},
"tyler":{"tyler","tylers"},
"tympan":{"tympan","tympans"},
"tympani":{"tympani","tympanis"},
"tympanist":{"tympanist","tympanists"},
"tympanuchus":{"tympanuchus","tympanuchuses"},
"tympanum":{"tympana","tympanum","tympanums"},
"tympany":{"tympanies","tympany"},
"tyne":{"tyne","tynes"},
"type":{"type","typed","types","typing"},
"typecast":{"typecast","typecasting","typecasts","typecastsa"},
"typeface":{"typeface","typefaces"},
"typeset":{"typeset","typesets","typesetting"},
"typesetter":{"typesetter","typesetters"},
"typewrite":{"typewrite","typewrites","typewriting","typewritten","typewrote"},
"typewriter":{"typewriter","typewriters"},
"typewriting":{"typewriting","typewritings"},
"typha":{"typha","typhas"},
"typhaceae":{"typhaceae","typhaceaes"},
"typhlopidae":{"typhlopidae","typhlopidaes"},
"typhoid":{"typhoid","typhoids"},
"typhoon":{"typhoon","typhoons"},
"typhus":{"typhus","typhuses"},
"typification":{"typification","typifications"},
"typify":{"typified","typifies","typify","typifying"},
"typifying":{"typifying","typifyings"},
"typing":{"typing","typings"},
"typist":{"typist","typists"},
"typo":{"typo","typos"},
"typographer":{"typographer","typographers"},
"typography":{"typographies","typography"},
"tyr":{"tyr","tyrs"},
"tyranni":{"tyranni","tyrannis"},
"tyrannidae":{"tyrannidae","tyrannidaes"},
"tyrannize":{"tyrannize","tyrannized","tyrannizes","tyrannizing"},
"tyrannosaur":{"tyrannosaur","tyrannosaurs"},
"tyrannosaurus":{"tyrannosaurus","tyrannosauruses"},
"tyrannus":{"tyrannus","tyrannuses"},
"tyranny":{"tyrannies","tyranny"},
"tyrant":{"tyrant","tyrants"},
"tyre":{"tyre","tyred","tyres","tyring"},
"tyro":{"tyro","tyros"},
"tyrocidin":{"tyrocidin","tyrocidins"},
"tyrocidine":{"tyrocidine","tyrocidines"},
"tyrol":{"tyrol","tyrols"},
"tyrr":{"tyrr","tyrrs"},
"tyto":{"tyto","tytos"},
"tytonidae":{"tytonidae","tytonidaes"},
"tzar":{"tzar","tzars"},
"tzarina":{"tzarina","tzarinas"},
"tzetze":{"tzetze","tzetzes"},
"u":{"u","us"},
"u-boat":{"u-boat","u-boats"},
"ubermensch":{"ubermensch","ubermensches"},
"ubiquitousness":{"ubiquitousness","ubiquitousnesses"},
"ubiquity":{"ubiquities","ubiquity"},
"uca":{"uca","ucas"},
"udder":{"udder","udders"},
"udmurt":{"udmurt","udmurts"},
"udo":{"udo","udos"},
"ufo":{"ufo","ufos"},
"ugli":{"ugli","uglis"},
"uglify":{"uglified","uglifies","uglify","uglifying"},
"ugly":{"uglier","ugliest","ugly"},
"ugrian":{"ugrian","ugrians"},
"ugric":{"ugric","ugrics"},
"uhf":{"uhf","uhfs"},
"uighur":{"uighur","uighurs"},
"uigur":{"uigur","uigurs"},
"uintathere":{"uintathere","uintatheres"},
"uintatheriidae":{"uintatheriidae","uintatheriidaes"},
"uintatherium":{"uintatherium","uintatheriums"},
"uk":{"uk","uks"},
"uke":{"uke","ukes"},
"ukraine":{"ukraine","ukraines"},
"ukrayina":{"ukrayina","ukrayinas"},
"ukulele":{"ukulele","ukuleles"},
"ulaanbaatar":{"ulaanbaatar","ulaanbaatars"},
"ulcer":{"ulcer","ulcers"},
"ulcerate":{"ulcerate","ulcerated","ulcerating"},
"ulceration":{"ulceration","ulcerations"},
"ulex":{"ulex","ulexes"},
"ulfila":{"ulfila","ulfilas"},
"ulfilas":{"ulfilas","ulfilases"},
"ull":{"ull","ulls"},
"ullr":{"ullr","ullrs"},
"ulmaceae":{"ulmaceae","ulmaceaes"},
"ulmus":{"ulmus","ulmuses"},
"ulna":{"ulna","ulnae","ulnas"},
"ulsterman":{"ulsterman","ulstermen"},
"ultima":{"ultima","ultimas"},
"ultimacy":{"ultimacies","ultimacy"},
"ultimate":{"ultimate","ultimates"},
"ultimateness":{"ultimateness","ultimatenesses"},
"ultimatum":{"ultimata","ultimatum","ultimatums"},
"ultra":{"ultra","ultras"},
"ultracentrifuge":{"ultracentrifuge","ultracentrifuged","ultracentrifuging"},
"ultraconservative":{"ultraconservative","ultraconservatives"},
"ultramarine":{"ultramarine","ultramarines"},
"ultramicroscope":{"ultramicroscope","ultramicroscopes"},
"ultranationalism":{"ultranationalism","ultranationalisms"},
"ultrasonography":{"ultrasonographies","ultrasonography"},
"ultrasuede":{"ultrasuede","ultrasuedes"},
"ultraviolet":{"ultraviolet","ultraviolets"},
"ululate":{"ululate","ululated","ululates","ululating"},
"ululation":{"ululation","ululations"},
"ulva":{"ulva","ulvas"},
"ulvaceae":{"ulvaceae","ulvaceaes"},
"ulvales":{"ulvales","ulvaleses"},
"ulvophyceae":{"ulvophyceae","ulvophyceaes"},
"ulysses":{"ulysses","ulysseses"},
"uma":{"uma","umas"},
"umbellales":{"umbellales","umbellaleses"},
"umbellifer":{"umbellifer","umbellifers"},
"umbelliferae":{"umbelliferae","umbelliferaes"},
"umbellularia":{"umbellularia","umbellularias"},
"umber":{"umber","umbers"},
"umbilicus":{"umbilici","umbilicus","umbilicuses"},
"umbo":{"umbo","umbones","umbos"},
"umbra":{"umbra","umbrae","umbras"},
"umbrage":{"umbrage","umbrages"},
"umbrella":{"umbrella","umbrellas"},
"umbrina":{"umbrina","umbrinas"},
"umlaut":{"umlaut","umlauted","umlauting","umlauts"},
"ump":{"ump","umps"},
"umpirage":{"umpirage","umpirages"},
"umpire":{"umpire","umpired","umpires","umpiring"},
"umpiring":{"umpiring","umpirings"},
"umpy":{"umpies","umpy"},
"un":{"un","uns"},
"unacceptability":{"unacceptabilities","unacceptability"},
"unacceptableness":{"unacceptableness","unacceptablenesses"},
"unalterability":{"unalterabilities","unalterability"},
"unambiguity":{"unambiguities","unambiguity"},
"unarm":{"unarm","unarmed","unarming","unarms"},
"unassumingness":{"unassumingness","unassumingnesses"},
"unau":{"unau","unaus"},
"unavailability":{"unavailabilities","unavailability"},
"unawareness":{"unawareness","unawarenesses"},
"unbalance":{"unbalance","unbalanced","unbalances","unbalancing"},
"unbar":{"unbar","unbarred","unbarring","unbars"},
"unbelief":{"unbelief","unbeliefs","unbelieves"},
"unbeliever":{"unbeliever","unbelievers"},
"unbend":{"unbend","unbending","unbends","unbent"},
"unbind":{"unbind","unbinding","unbinds","unbound"},
"unbolt":{"unbolt","unbolted","unbolting"},
"unbosom":{"unbosom","unbosomed","unbosoming","unbosoms"},
"unboundedness":{"unboundedness","unboundednesses"},
"unbrace":{"unbrace","unbraced","unbraces","unbracing"},
"unbraid":{"unbraid","unbraided","unbraiding"},
"unbuckle":{"unbuckle","unbuckled","unbuckling"},
"unbuild":{"unbuild","unbuilding","unbuilt"},
"unburden":{"unburden","unburdened","unburdening","unburdens"},
"unbutton":{"unbutton","unbuttoned","unbuttoning"},
"uncage":{"uncage","uncaged","uncaging"},
"uncanny":{"uncannier","uncanniest","uncanny"},
"uncap":{"uncap","uncapped","uncapping","uncaps"},
"uncertainness":{"uncertainness","uncertainnesses"},
"uncertainty":{"uncertainties","uncertainty"},
"unchain":{"unchain","unchained","unchaining"},
"unchangeability":{"unchangeabilities","unchangeability"},
"unchangeableness":{"unchangeableness","unchangeablenesses"},
"unchangingness":{"unchangingness","unchangingnesses"},
"uncheerfulness":{"uncheerfulness","uncheerfulnesses"},
"uncinus":{"uncicini","uncinus"},
"unclasp":{"unclasp","unclasped","unclasping"},
"uncle":{"uncle","uncles"},
"unclean":{"unclean","uncleaner","uncleanest"},
"uncleanly":{"uncleanlier","uncleanliest","uncleanly"},
"uncleanness":{"uncleanness","uncleannesses"},
"uncloak":{"uncloak","uncloaked","uncloaking","uncloaks"},
"unclog":{"unclog","unclogged","unclogging","unclogs"},
"unclose":{"unclose","unclosed","unclosing"},
"unclothe":{"unclad","unclothe","unclothed","unclothes","unclothing"},
"uncloudedness":{"uncloudedness","uncloudednesses"},
"unco":{"unco","uncoes","uncos"},
"uncoil":{"uncoil","uncoiled","uncoiling"},
"uncomfortableness":{"uncomfortableness","uncomfortablenesses"},
"uncommon":{"uncommon","uncommoner","uncommonest"},
"unconcern":{"unconcern","unconcerns"},
"unconformity":{"unconformities","unconformity"},
"unconscious":{"unconscious","unconsciouses"},
"unconstraint":{"unconstraint","unconstraints"},
"uncork":{"uncork","uncorked","uncorking"},
"uncouple":{"uncouple","uncoupled","uncoupling"},
"uncouthness":{"uncouthness","uncouthnesses"},
"uncover":{"uncover","uncovered","uncovering","uncovers"},
"uncovering":{"uncovering","uncoverings"},
"uncross":{"uncross","uncrossed","uncrossing"},
"unction":{"unction","unctions"},
"unctuousness":{"unctuousness","unctuousnesses"},
"uncurl":{"uncurl","uncurled","uncurling"},
"uncus":{"unci","uncus"},
"undeceive":{"undeceive","undeceived","undeceiving"},
"undecillion":{"undecillion","undecillions"},
"undependability":{"undependabilities","undependability"},
"undependableness":{"undependableness","undependablenesses"},
"underachieve":{"underachieve","underachieved","underachieving"},
"underact":{"underact","underacted","underacting","underacts"},
"underbelly":{"underbellies","underbelly"},
"underbid":{"underbid","underbidding","underbids"},
"underbodice":{"underbodice","underbodices"},
"underbody":{"underbodies","underbody"},
"underbrush":{"underbrush","underbrushes"},
"underbuy":{"underbought","underbuy","underbuying","underbuys"},
"undercapitalize":{"undercapitalize","undercapitalized","undercapitalizing"},
"undercharge":{"undercharge","undercharged","undercharging"},
"underclassman":{"underclassman","underclassmen"},
"underclothes":{"underclothes","underclotheses"},
"underclothing":{"underclothing","underclothings"},
"undercoat":{"undercoat","undercoats"},
"undercurrent":{"undercurrent","undercurrents"},
"undercut":{"undercut","undercuts","undercutting"},
"underdevelop":{"underdevelop","underdeveloped","underdeveloping"},
"underdo":{"underdid","underdo","underdoing","underdone"},
"underdog":{"underdog","underdogs"},
"underdress":{"underdress","underdressed","underdresses","underdressing"},
"underemphasize":{"underemphasize","underemphasized","underemphasizing"},
"underestimate":{"underestimate","underestimated","underestimates","underestimating"},
"underestimation":{"underestimation","underestimations"},
"underexpose":{"underexpose","underexposed","underexposing"},
"underfeed":{"underfed","underfeed","underfeeding","underfeeds"},
"underframe":{"underframe","underframes"},
"underfur":{"underfur","underfurs"},
"undergird":{"undergird","undergirded","undergirding","undergirds","undergirt","undergurded"},
"undergo":{"undergo","undergoes","undergoing","undergone","underwent"},
"undergrad":{"undergrad","undergrads"},
"undergraduate":{"undergraduate","undergraduates"},
"underground":{"underground","undergrounds"},
"undergrowth":{"undergrowth","undergrowths"},
"underlap":{"underlap","underlapped","underlapping"},
"underlay":{"underlaid","underlay","underlaying","underlays"},
"underlayment":{"underlayment","underlayments"},
"underlet":{"underlet","underlets","underletting"},
"underlie":{"underlain","underlay","underlie","underlies","underlying"},
"underline":{"underline","underlined","underlines","underlining"},
"underling":{"underling","underlings"},
"undermine":{"undermine","undermined","undermines","undermining"},
"undernourishment":{"undernourishment","undernourishments"},
"underpass":{"underpass","underpasses"},
"underpay":{"underpaid","underpay","underpaying","underpays"},
"underpin":{"underpin","underpinned","underpinning","underpins"},
"underplay":{"underplay","underplayed","underplaying","underplays"},
"underprop":{"underprop","underpropped","underpropping","underprops"},
"underrate":{"underrate","underrated","underrates","underrating"},
"underrating":{"underrating","underratings"},
"underreckoning":{"underreckoning","underreckonings"},
"underrun":{"underran","underrun","underrunning"},
"underscore":{"underscore","underscored","underscores","underscoring"},
"underseal":{"underseal","underseals"},
"undersecretary":{"undersecretaries","undersecretary"},
"undersell":{"undersell","underselling","undersells","undersold"},
"underset":{"underset","undersets","undersetting"},
"undershirt":{"undershirt","undershirts"},
"undershoot":{"undershoot","undershooting","undershoots","undershot"},
"underside":{"underside","undersides"},
"undersign":{"undersign","undersigned","undersigning"},
"underskirt":{"underskirt","underskirts"},
"undersoil":{"undersoil","undersoils"},
"understand":{"understand","understanding","understands","understood"},
"understandability":{"understandabilities","understandability"},
"understanding":{"understanding","understandings"},
"understate":{"understate","understated","understates","understating"},
"understeer":{"understeer","understeered","understeering"},
"understock":{"understock","understocked","understocking"},
"understructure":{"understructure","understructures"},
"understudy":{"understudied","understudies","understudy","understudying"},
"undersurface":{"undersurface","undersurfaces"},
"undertake":{"undertake","undertaken","undertakes","undertaking","undertook"},
"undertaker":{"undertaker","undertakers"},
"undertaking":{"undertaking","undertakings"},
"undertide":{"undertide","undertides"},
"undertone":{"undertone","undertones"},
"undertow":{"undertow","undertows"},
"undervalue":{"undervalue","undervalued","undervalues","undervaluing"},
"underwear":{"underwear","underwears"},
"underwood":{"underwood","underwoods"},
"underwork":{"underwork","underworked","underworking"},
"underworld":{"underworld","underworlds"},
"underwrite":{"underwrite","underwrites","underwriting","underwritten","underwrote"},
"underwriter":{"underwriter","underwriters"},
"undesirable":{"undesirable","undesirables"},
"undiscipline":{"undiscipline","undisciplines"},
"undo":{"undid","undo","undoes","undoing","undone"},
"undock":{"undock","undocked","undocking"},
"undoer":{"undoer","undoers"},
"undoing":{"undoing","undoings"},
"undrape":{"undrape","undraped","undraping"},
"undraw":{"undraw","undrawing","undrawn","undrew"},
"undress":{"undress","undressed","undresses","undressing"},
"undulate":{"undulate","undulated","undulates","undulating"},
"undulation":{"undulation","undulations"},
"unearth":{"unearth","unearthed","unearthing"},
"unease":{"unease","uneases"},
"uneasiness":{"uneasiness","uneasinesses"},
"uneasy":{"uneasier","uneasiest","uneasy"},
"unemotionality":{"unemotionalities","unemotionality"},
"unequal":{"unequal","unequals"},
"unequivocalness":{"unequivocalness","unequivocalnesses"},
"unevenness":{"unevenness","unevennesses"},
"unexpectedness":{"unexpectedness","unexpectednesses"},
"unfairness":{"unfairness","unfairnesses"},
"unfaithfulness":{"unfaithfulness","unfaithfulnesses"},
"unfamiliarity":{"unfamiliarities","unfamiliarity"},
"unfasten":{"unfasten","unfastened","unfastening"},
"unfastening":{"unfastening","unfastenings"},
"unfavorableness":{"unfavorableness","unfavorablenesses"},
"unfavourableness":{"unfavourableness","unfavourablenesses"},
"unfeasibility":{"unfeasibilities","unfeasibility"},
"unfeelingness":{"unfeelingness","unfeelingnesses"},
"unfetter":{"unfetter","unfettered","unfettering"},
"unfit":{"unfit","unfits","unfitted","unfitting"},
"unfitness":{"unfitness","unfitnesses"},
"unfix":{"unfix","unfixed","unfixing"},
"unfold":{"unfold","unfolded","unfolding","unfolds"},
"unfolding":{"unfolding","unfoldings"},
"unfortunate":{"unfortunate","unfortunates"},
"unfreeze":{"unfreeze","unfreezes","unfreezing","unfroze","unfrozen"},
"unfriendly":{"unfriendlier","unfriendliest","unfriendly"},
"unfrock":{"unfrock","unfrocked","unfrocking","unfrocks"},
"unfurl":{"unfurl","unfurled","unfurling","unfurls"},
"ungainliness":{"ungainliness","ungainlinesses"},
"ungainly":{"ungainlier","ungainliest","ungainly"},
"ungird":{"ungird","ungirded","ungirding","ungirt"},
"unglue":{"unglue","unglued","ungluing"},
"ungodliness":{"ungodliness","ungodlinesses"},
"ungodly":{"ungodlier","ungodliest","ungodly","ungoliest"},
"ungracefulness":{"ungracefulness","ungracefulnesses"},
"ungratefulness":{"ungratefulness","ungratefulnesses"},
"unguent":{"unguent","unguents"},
"unguiculate":{"unguiculate","unguiculates"},
"unguis":{"unguis","unguises"},
"ungula":{"ungula","ungulae"},
"ungulate":{"ungulate","ungulates"},
"unh":{"unh","unhs"},
"unhair":{"unhair","unhaired","unhairing"},
"unhand":{"unhand","unhanded","unhanding"},
"unhandy":{"unhandier","unhandiest","unhandy"},
"unhappiness":{"unhappiness","unhappinesses"},
"unhappy":{"unhappier","unhappiest","unhappy"},
"unharness":{"unharness","unharnessed","unharnessing"},
"unhealthiness":{"unhealthiness","unhealthinesses"},
"unhealthy":{"unhealthier","unhealthiest","unhealthy"},
"unhinge":{"unhinge","unhinged","unhinges","unhinging"},
"unhitch":{"unhitch","unhitched","unhitching"},
"unholy":{"unholier","unholiest","unholy"},
"unhook":{"unhook","unhooked","unhooking"},
"unhorse":{"unhorse","unhorsed","unhorses","unhorsing"},
"unhurriedness":{"unhurriedness","unhurriednesses"},
"uniat":{"uniat","uniats"},
"uniate":{"uniate","uniates"},
"unicycle":{"unicycle","unicycles"},
"unification":{"unification","unifications"},
"uniform":{"uniform","uniformed","uniforming","uniforms"},
"uniformity":{"uniformities","uniformity"},
"uniformness":{"uniformness","uniformnesses"},
"unify":{"unified","unifies","unify","unifying"},
"unimportance":{"unimportance","unimportances"},
"unintelligibility":{"unintelligibilities","unintelligibility"},
"unio":{"unio","unios"},
"union":{"union","unions"},
"unionidae":{"unionidae","unionidaes"},
"unionisation":{"unionisation","unionisations"},
"unionism":{"unionism","unionisms"},
"unionist":{"unionist","unionists"},
"unionization":{"unionization","unionizations"},
"unionize":{"unionize","unionized","unionizes","unionizing"},
"uniqueness":{"uniqueness","uniquenesses"},
"unit":{"unit","units"},
"unite":{"unite","united","unites","uniting"},
"uniting":{"uniting","unitings"},
"unity":{"unities","unity"},
"univalve":{"univalve","univalves"},
"universal":{"universal","universals"},
"universality":{"universalities","universality"},
"universalize":{"universalize","universalized","universalizing"},
"universe":{"universe","universes"},
"university":{"universities","university"},
"unix":{"unix","unixes"},
"unjustness":{"unjustness","unjustnesses"},
"unkemptness":{"unkemptness","unkemptnesses"},
"unkennel":{"unkenelled","unkennel","unkenneled","unkenneling","unkennelled","unkennelling","unkennels"},
"unkind":{"unkind","unkinder","unkindest"},
"unknit":{"unknit","unknits","unknitted","unknitting"},
"unknowing":{"unknowing","unknowings"},
"unknowingness":{"unknowingness","unknowingnesses"},
"unknown":{"unknown","unknowns"},
"unlace":{"unlace","unlaced","unlaces","unlacing"},
"unlade":{"unlade","unladed","unlading"},
"unlatch":{"unlatch","unlatched","unlatching"},
"unlay":{"unlaid","unlay","unlaying","unlays"},
"unlearn":{"unlearn","unlearned","unlearning","unlearns","unlearnt"},
"unleash":{"unleash","unleashed","unleashes","unleashing"},
"unlikelihood":{"unlikelihood","unlikelihoods"},
"unlikeliness":{"unlikeliness","unlikelinesses"},
"unlikeness":{"unlikeness","unlikenesses"},
"unlimber":{"unlimber","unlimbered","unlimbering"},
"unlink":{"unlink","unlinked","unlinking"},
"unload":{"unload","unloaded","unloading","unloads"},
"unlock":{"unlock","unlocked","unlocking"},
"unloose":{"unloose","unloosed","unlooses","unloosing"},
"unlucky":{"unluckier","unluckiest","unlucky"},
"unmake":{"unmade","unmake","unmakes","unmaking"},
"unman":{"unman","unmanned","unmanning","unmans"},
"unmanageableness":{"unmanageableness","unmanageablenesses"},
"unmanliness":{"unmanliness","unmanlinesses"},
"unmanly":{"unmanlier","unmanliest","unmanly"},
"unmask":{"unmask","unmasked","unmasking","unmasks"},
"unmasking":{"unmasking","unmaskings"},
"unmercifulness":{"unmercifulness","unmercifulnesses"},
"unmindfulness":{"unmindfulness","unmindfulnesses"},
"unmuzzle":{"unmuzzle","unmuzzled","unmuzzling"},
"unnerve":{"unnerve","unnerved","unnerves","unnerving"},
"unnilhexium":{"unnilhexium","unnilhexiums"},
"unnilpentium":{"unnilpentium","unnilpentiums"},
"unnilquadium":{"unnilquadium","unnilquadiums"},
"unnilquintium":{"unnilquintium","unnilquintiums"},
"unnilseptium":{"unnilseptium","unnilseptiums"},
"unorthodoxy":{"unorthodoxies","unorthodoxy"},
"unp":{"unp","unps"},
"unpack":{"unpack","unpacked","unpacking","unpacks"},
"unpalatability":{"unpalatabilities","unpalatability"},
"unpalatableness":{"unpalatableness","unpalatablenesses"},
"unpeg":{"unpeg","unpegged","unpegging","unpegs"},
"unpen":{"unpen","unpenned","unpenning"},
"unpeople":{"unpeople","unpeopled","unpeopling"},
"unpick":{"unpick","unpicked","unpicking","unpicks"},
"unpin":{"unpin","unpinned","unpinning","unpins"},
"unplug":{"unplug","unplugged","unplugging","unplugs"},
"unpredictability":{"unpredictabilities","unpredictability"},
"unprofitability":{"unprofitabilities","unprofitability"},
"unprofitableness":{"unprofitableness","unprofitablenesses"},
"unpropitiousness":{"unpropitiousness","unpropitiousnesses"},
"unprotectedness":{"unprotectedness","unprotectednesses"},
"unq":{"unq","unqs"},
"unquestionability":{"unquestionabilities","unquestionability"},
"unquestionableness":{"unquestionableness","unquestionablenesses"},
"unquote":{"unquote","unquoted","unquoting"},
"unravel":{"unravel","unraveled","unraveling","unravelled","unravelling","unravels"},
"unrealism":{"unrealism","unrealisms"},
"unreality":{"unrealities","unreality"},
"unreason":{"unreason","unreasons"},
"unreel":{"unreel","unreeled","unreeling"},
"unreeve":{"unreeve","unreeved","unreeves","unreeving","unrove"},
"unregularity":{"unregularities","unregularity"},
"unreliability":{"unreliabilities","unreliability"},
"unreliableness":{"unreliableness","unreliablenesses"},
"unrespectability":{"unrespectabilities","unrespectability"},
"unrest":{"unrest","unrests"},
"unriddle":{"unriddle","unriddled","unriddling"},
"unrig":{"unrig","unrigged","unrigging","unrigs"},
"unrip":{"unrip","unripped","unripping","unrips"},
"unroll":{"unroll","unrolled","unrolling","unrolls"},
"unroof":{"unroof","unroofed","unroofing"},
"unroot":{"unroot","unrooted","unrooting"},
"unround":{"unround","unrounded","unrounding"},
"unruliness":{"unruliness","unrulinesses"},
"unruly":{"unrulier","unruliest","unruly"},
"uns":{"uns","unses"},
"unsaddle":{"unsaddle","unsaddled","unsaddles","unsaddling"},
"unsanctification":{"unsanctification","unsanctifications"},
"unsavoriness":{"unsavoriness","unsavorinesses"},
"unsay":{"unsaid","unsay","unsaying","unsays"},
"unscramble":{"unscramble","unscrambled","unscrambles","unscrambling"},
"unscrew":{"unscrew","unscrewed","unscrewing"},
"unseal":{"unseal","unsealed","unsealing"},
"unseam":{"unseam","unseamed","unseaming"},
"unseasonableness":{"unseasonableness","unseasonablenesses"},
"unseat":{"unseat","unseated","unseating"},
"unseemly":{"unseemlier","unseemliest","unseemly"},
"unseen":{"unseen","unseens"},
"unselfishness":{"unselfishness","unselfishnesses"},
"unsell":{"unsell","unselling","unsold"},
"unsettle":{"unsettle","unsettled","unsettles","unsettling"},
"unsex":{"unsex","unsexed","unsexes","unsexing"},
"unshackle":{"unshackle","unshackled","unshackling"},
"unsheathe":{"unsheathe","unsheathed","unsheathing"},
"unshell":{"unshell","unshelled","unshelling"},
"unship":{"unship","unshipped","unshipping","unships"},
"unsightly":{"unsightlier","unsightliest","unsightly"},
"unsimilarity":{"unsimilarities","unsimilarity"},
"unsling":{"unsling","unslinging","unslings","unslung"},
"unsnap":{"unsnap","unsnapped","unsnapping","unsnaps"},
"unsnarl":{"unsnarl","unsnarled","unsnarling","unsnarls"},
"unsnarling":{"unsnarling","unsnarlings"},
"unsociability":{"unsociabilities","unsociability"},
"unsociableness":{"unsociableness","unsociablenesses"},
"unspeak":{"unspeak","unspeaking","unspeaks","unspoke","unspoken"},
"unstableness":{"unstableness","unstablenesses"},
"unsteady":{"unsteadied","unsteadies","unsteady","unsteadying"},
"unstep":{"unstep","unstepped","unstepping","unsteps"},
"unstick":{"unstick","unsticking","unsticks","unstuck"},
"unstop":{"unstop","unstopped","unstopping","unstops"},
"unstrap":{"unstrap","unstrapped","unstrapping"},
"unstring":{"unstring","unstringing","unstrings","unstrung"},
"unsuitability":{"unsuitabilities","unsuitability"},
"unsuitableness":{"unsuitableness","unsuitablenesses"},
"unsusceptibility":{"unsusceptibilities","unsusceptibility"},
"unswear":{"unswear","unswearing","unswears","unswore","unsworn"},
"untangle":{"untangle","untangled","untangles","untangling"},
"untangling":{"untangling","untanglings"},
"unteach":{"untaught","unteach","unteaches","unteaching"},
"unthink":{"unthink","unthinking","unthinks","unthought"},
"unthoughtfulness":{"unthoughtfulness","unthoughtfulnesses"},
"unthread":{"unthread","unthreaded","unthreading"},
"untidiness":{"untidiness","untidinesses"},
"untidy":{"untidied","untidier","untidies","untidiest","untidy","untidying"},
"untie":{"untie","untied","unties","untying"},
"untimeliness":{"untimeliness","untimelinesses"},
"untread":{"untread","untreading","untreads","untrod","untrodden"},
"untrue":{"untrue","untruer","untruest"},
"untruss":{"untruss","untrussed","untrussing"},
"untrustiness":{"untrustiness","untrustinesses"},
"untrustworthiness":{"untrustworthiness","untrustworthinesses"},
"untruth":{"untruth","untruths"},
"untuck":{"untuck","untucked","untucking"},
"untwine":{"untwine","untwined","untwining"},
"untwist":{"untwist","untwisted","untwisting"},
"untying":{"untying","untyings"},
"untypicality":{"untypicalities","untypicality"},
"unusefulness":{"unusefulness","unusefulnesses"},
"unveil":{"unveil","unveiled","unveiling","unveils"},
"unveiling":{"unveiling","unveilings"},
"unvoice":{"unvoice","unvoiced","unvoicing"},
"unweave":{"unweave","unweaving","unwove","unwoven"},
"unwholesomeness":{"unwholesomeness","unwholesomenesses"},
"unwieldiness":{"unwieldiness","unwieldinesses"},
"unwieldy":{"unwieldier","unwieldiest","unwieldy"},
"unwind":{"unwind","unwinding","unwinds","unwound"},
"unwise":{"unwise","unwiser","unwisest"},
"unwiseness":{"unwiseness","unwisenesses"},
"unworthy":{"unworthier","unworthiest","unworthy"},
"unwrap":{"unwrap","unwrapped","unwrapping","unwraps"},
"unyieldingness":{"unyieldingness","unyieldingnesses"},
"unyoke":{"unyoke","unyoked","unyoking"},
"unzip":{"unzip","unzipped","unzipping","unzips"},
"up":{"up","upped","upping","ups"},
"up-to-dateness":{"up-to-dateness","up-to-datenesses"},
"upbeat":{"upbeat","upbeats"},
"upbraid":{"upbraid","upbraided","upbraiding","upbraids"},
"upbraiding":{"upbraiding","upbraidings"},
"upbringing":{"upbringing","upbringings"},
"upbuild":{"upbuild","upbuilding","upbuilds","upbuilt"},
"upcast":{"upcast","upcasting","upcasts"},
"update":{"update","updated","updating"},
"upend":{"upend","upended","upending"},
"upending":{"upending","upendings"},
"upgrade":{"upgrade","upgraded","upgrades","upgrading"},
"upheaval":{"upheaval","upheavals"},
"upheave":{"upheave","upheaved","upheaves","upheaving","uphove"},
"uphold":{"upheld","uphold","upholding","upholds"},
"upholster":{"upholster","upholstered","upholstering"},
"upholsterer":{"upholsterer","upholsterers"},
"upholstery":{"upholsteries","upholstery"},
"upkeep":{"upkeep","upkeeps"},
"upland":{"upland","uplands"},
"uplift":{"uplift","uplifted","uplifting","uplifts"},
"upper":{"upper","uppers"},
"upper-case":{"upper-case","upper-cased","upper-casing"},
"upper-normandy":{"upper-normandies","upper-normandy"},
"uppercut":{"uppercut","uppercuts","uppercutting"},
"uppishness":{"uppishness","uppishnesses"},
"uppityness":{"uppityness","uppitynesses"},
"upraise":{"upraise","upraised","upraises","upraising"},
"uprear":{"uprear","upreared","uprearing"},
"upright":{"upright","uprighted","uprighting","uprights"},
"uprightness":{"uprightness","uprightnesses"},
"uprise":{"uprise","uprisen","uprises","uprising","uprose"},
"uprising":{"uprising","uprisings"},
"uproar":{"uproar","uproars"},
"uproot":{"uproot","uprooted","uprooting","uproots"},
"upset":{"upset","upsets","upsetting"},
"upshot":{"upshot","upshots"},
"upside":{"upside","upsides"},
"upspring":{"upsprang","upspring","upspringing","upsprings","upsprung"},
"upstage":{"upstage","upstaged","upstaging"},
"upstart":{"upstart","upstarts"},
"upsurge":{"upsurge","upsurged","upsurges","upsurging"},
"upsweep":{"upsweep","upsweeping","upsweeps","upswept"},
"upswell":{"upswell","upswelled","upswelling","upswells","upswollen"},
"upswing":{"upswing","upswinging","upswings","upswung"},
"uptake":{"uptake","uptakes"},
"upthrow":{"upthrow","upthrows"},
"upthrust":{"upthrust","upthrusts"},
"upturn":{"upturn","upturned","upturning","upturns"},
"upupa":{"upupa","upupas"},
"upupidae":{"upupidae","upupidaes"},
"upwell":{"upwell","upwelled","upwelling"},
"uraemia":{"uraemia","uraemias"},
"uraeus":{"uraeus","uraeuses"},
"uralic":{"uralic","uralics"},
"urals":{"urals","uralses"},
"uranalysis":{"uranalyses","uranalysis"},
"urania":{"urania","uranias"},
"uraninite":{"uraninite","uraninites"},
"uranium":{"uranium","uraniums"},
"uranologist":{"uranologist","uranologists"},
"uranology":{"uranologies","uranology"},
"uranoscopidae":{"uranoscopidae","uranoscopidaes"},
"uranus":{"uranus","uranuses"},
"uranyl":{"uranyl","uranyls"},
"urarthritis":{"urarthritis","urarthritises"},
"urbanity":{"urbanities","urbanity"},
"urchin":{"urchin","urchins"},
"urd":{"urd","urds"},
"urea":{"urea","ureas"},
"uredinales":{"uredinales","uredinaleses"},
"uredinium":{"uredinia","uredinidinia","uredinium"},
"uredium":{"uredidia","uredium"},
"uredo":{"uredines","uredo"},
"uredosorus":{"uredosorus","uredososori"},
"uremia":{"uremia","uremias"},
"urethra":{"urethra","urethrae","urethras"},
"urge":{"urge","urged","urges","urging"},
"urgency":{"urgencies","urgency"},
"urginea":{"urginea","urgineas"},
"urging":{"urging","urgings"},
"uria":{"uria","urias"},
"urial":{"urial","urials"},
"urinalysis":{"urinalyses","urinalysis"},
"urinary":{"urinaries","urinary"},
"urinate":{"urinate","urinated","urinates","urinating"},
"urination":{"urination","urinations"},
"urine":{"urine","urines"},
"urn":{"urn","urns"},
"urochord":{"urochord","urochords"},
"urochorda":{"urochorda","urochordas"},
"urochordata":{"urochordata","urochordatas"},
"urochordate":{"urochordate","urochordates"},
"urocyon":{"urocyon","urocyons"},
"urocystis":{"urocystis","urocystises"},
"urodele":{"urodele","urodeles"},
"urodella":{"urodella","urodellas"},
"urology":{"urologies","urology"},
"urophycis":{"urophycis","urophycises"},
"uropsilus":{"uropsilus","uropsiluses"},
"uropygi":{"uropygi","uropygis"},
"urosaurus":{"urosaurus","urosauruses"},
"ursidae":{"ursidae","ursidaes"},
"ursus":{"ursus","ursuses"},
"urth":{"urth","urths"},
"urtica":{"urtica","urticas"},
"urticaceae":{"urticaceae","urticaceaes"},
"urticales":{"urticales","urticaleses"},
"urticaria":{"urticaria","urticarias"},
"urticate":{"urticate","urticated","urticating"},
"urtication":{"urtication","urtications"},
"urubupunga":{"urubupunga","urubupungas"},
"urus":{"urus","uruses"},
"us":{"us","uses"},
"usa":{"usa","usas"},
"usableness":{"usableness","usablenesses"},
"usage":{"usage","usages"},
"usance":{"usance","usances"},
"usbeg":{"usbeg","usbegs"},
"usbek":{"usbek","usbeks"},
"use":{"use","used","uses","using"},
"usefulness":{"usefulness","usefulnesses"},
"uselessness":{"uselessness","uselessnesses"},
"user":{"user","users"},
"usher":{"usher","ushered","ushering","ushers"},
"using":{"using","usings"},
"usnea":{"usnea","usneas"},
"usneaceae":{"usneaceae","usneaceaes"},
"ussr":{"ussr","ussrs"},
"ustilaginaceae":{"ustilaginaceae","ustilaginaceaes"},
"ustilaginales":{"ustilaginales","ustilaginaleses"},
"ustilaginoidea":{"ustilaginoidea","ustilaginoideas"},
"ustilago":{"ustilago","ustilagos"},
"usufructuary":{"usufructuaries","usufructuary"},
"usumbura":{"usumbura","usumburas"},
"usurer":{"usurer","usurers"},
"usurp":{"usurp","usurped","usurping","usurps"},
"usurper":{"usurper","usurpers"},
"usury":{"usuries","usury"},
"ut":{"ut","uts"},
"ut1":{"ut1","ut1s"},
"uta":{"uta","utas"},
"utah":{"utah","utahs"},
"utahraptor":{"utahraptor","utahraptors"},
"utc":{"utc","utcs"},
"ute":{"ute","utes"},
"utensil":{"utensil","utensils"},
"uterus":{"uteri","uterus","uteruses"},
"utilisation":{"utilisation","utilisations"},
"utility":{"utilities","utility"},
"utilization":{"utilization","utilizations"},
"utilize":{"utilize","utilized","utilizes","utilizing"},
"utmost":{"utmost","utmosts"},
"uto-aztecan":{"uto-aztecan","uto-aztecans"},
"utopia":{"utopia","utopias"},
"utopian":{"utopian","utopians"},
"utricle":{"utricle","utricles"},
"utricularia":{"utricularia","utricularias"},
"utriculus":{"utriculus","utriculuses"},
"utrillo":{"utrillo","utrillos"},
"utter":{"utter","uttered","uttering","utters"},
"utterance":{"utterance","utterances"},
"uttermost":{"uttermost","uttermosts"},
"utu":{"utu","utus"},
"utug":{"utug","utugs"},
"uv":{"uv","uvs"},
"uvula":{"uvula","uvulae","uvulas"},
"uvularia":{"uvularia","uvularias"},
"uvulariaceae":{"uvulariaceae","uvulariaceaes"},
"ux":{"ux","uxes"},
"uxor":{"uxor","uxors"},
"uzbak":{"uzbak","uzbaks"},
"uzbeg":{"uzbeg","uzbegs"},
"uzbek":{"uzbek","uzbeks"},
"uzbekistan":{"uzbekistan","uzbekistans"},
"uzbekiston":{"uzbekiston","uzbekistons"},
"v":{"v","vs"},
"v-1":{"v-1","v-1s"},
"v-day":{"v-day","v-days"},
"vacancy":{"vacancies","vacancy"},
"vacate":{"vacate","vacated","vacates","vacating"},
"vacation":{"vacation","vacationed","vacationing","vacations"},
"vacationer":{"vacationer","vacationers"},
"vacationist":{"vacationist","vacationists"},
"vaccaria":{"vaccaria","vaccarias"},
"vaccinate":{"vaccinate","vaccinated","vaccinates","vaccinating"},
"vaccinating":{"vaccinating","vaccinatings"},
"vaccination":{"vaccination","vaccinations"},
"vaccinia":{"vaccinia","vaccinias"},
"vaccinium":{"vaccinium","vacciniums"},
"vacillate":{"vacillate","vacillated","vacillates","vacillating"},
"vacillation":{"vacillation","vacillations"},
"vacillator":{"vacillator","vacillators"},
"vacuity":{"vacuities","vacuity"},
"vacuolation":{"vacuolation","vacuolations"},
"vacuolization":{"vacuolization","vacuolizations"},
"vacuousness":{"vacuousness","vacuousnesses"},
"vacuum":{"vacua","vacuum","vacuumed","vacuuming","vacuums"},
"vaduz":{"vaduz","vaduzs"},
"vag":{"vag","vagged","vagging","vags"},
"vagabond":{"vagabond","vagabonded","vagabonding","vagabonds"},
"vagabondage":{"vagabondage","vagabondages"},
"vagary":{"vagaries","vagary"},
"vagina":{"vagina","vaginae","vaginas"},
"vaginocele":{"vaginocele","vaginoceles"},
"vagotomy":{"vagotomies","vagotomy"},
"vagrancy":{"vagrancies","vagrancy"},
"vagrant":{"vagrant","vagrants"},
"vague":{"vague","vaguer","vaguest"},
"vagus":{"vagi","vagus","vaguses"},
"vail":{"vail","vailed","vailing"},
"vain":{"vain","vainer","vainest"},
"vainglory":{"vainglories","vainglory"},
"vaishnavism":{"vaishnavism","vaishnavisms"},
"vaisnavism":{"vaisnavism","vaisnavisms"},
"valance":{"valance","valances"},
"vale":{"vale","vales"},
"valediction":{"valediction","valedictions"},
"valedictorian":{"valedictorian","valedictorians"},
"valedictory":{"valedictories","valedictory"},
"valence":{"valence","valences"},
"valency":{"valencies","valency"},
"valentine":{"valentine","valentines"},
"valeriana":{"valeriana","valerianas"},
"valerianaceae":{"valerianaceae","valerianaceaes"},
"valerianella":{"valerianella","valerianellas"},
"valet":{"valet","valeted","valeting","valets"},
"valetta":{"valetta","valettas"},
"valetudinarian":{"valetudinarian","valetudinarians","valetudinarnarians"},
"valetudinary":{"valetudinaries","valetudinary"},
"valgus":{"valgus","valguses"},
"valhalla":{"valhalla","valhallas"},
"valiance":{"valiance","valiances"},
"valiancy":{"valiancies","valiancy"},
"valiant":{"valiant","valiants"},
"validate":{"validate","validated","validates","validating"},
"validating":{"validating","validatings"},
"validation":{"validation","validations"},
"validity":{"validities","validity"},
"validness":{"validness","validnesses"},
"valise":{"valise","valises"},
"valium":{"valium","valiums"},
"vallecula":{"vallecula","valleculae"},
"valletta":{"valletta","vallettas"},
"valley":{"valley","valleys"},
"vallisneria":{"vallisneria","vallisnerias"},
"valmy":{"valmies","valmy"},
"valor":{"valor","valors"},
"valorize":{"valorize","valorized","valorizing"},
"valorousness":{"valorousness","valorousnesses"},
"valour":{"valour","valours"},
"valourousness":{"valourousness","valourousnesses"},
"valse":{"valse","valses"},
"valuable":{"valuable","valuables"},
"valuableness":{"valuableness","valuablenesses"},
"valuate":{"valuate","valuated","valuating"},
"valuation":{"valuation","valuations"},
"valuator":{"valuator","valuators"},
"value":{"value","valued","values","valuing"},
"value-system":{"value-system","value-systems"},
"valve":{"valve","valved","valves","valving"},
"vambrace":{"vambrace","vambraces"},
"vamoose":{"vamoose","vamoosed","vamooses","vamoosing"},
"vamp":{"vamp","vamped","vamping","vamps"},
"vamper":{"vamper","vampers"},
"vampire":{"vampire","vampires"},
"van":{"van","vanned","vanning","vans"},
"vanadium":{"vanadium","vanadiums"},
"vancocin":{"vancocin","vancocins"},
"vancomycin":{"vancomycin","vancomycins"},
"vandal":{"vandal","vandals"},
"vandalism":{"vandalism","vandalisms"},
"vandalize":{"vandalize","vandalized","vandalizes","vandalizing"},
"vane":{"vane","vanes"},
"vanellus":{"vanellus","vanelluses"},
"vanessa":{"vanessa","vanessas"},
"vanguard":{"vanguard","vanguards"},
"vangueria":{"vangueria","vanguerias"},
"vanilla":{"vanilla","vanillas"},
"vanish":{"vanish","vanished","vanishes","vanishing"},
"vanity":{"vanities","vanity"},
"vanquish":{"vanquish","vanquished","vanquishes","vanquishing"},
"vanquisher":{"vanquisher","vanquishers"},
"vantage":{"vantage","vantages"},
"vanuatu":{"vanuatu","vanuatus"},
"vapidity":{"vapidities","vapidity"},
"vapidness":{"vapidness","vapidnesses"},
"vapor":{"vapor","vapored","vaporing","vapors"},
"vaporetto":{"vaporetti","vaporetto","vaporettos"},
"vaporing":{"vaporing","vaporings"},
"vaporisation":{"vaporisation","vaporisations"},
"vaporization":{"vaporization","vaporizations"},
"vaporize":{"vaporize","vaporized","vaporizes","vaporizing"},
"vapour":{"vapour","vapoured","vapouring","vapours"},
"vaquero":{"vaquero","vaqueros"},
"var":{"var","vars"},
"varan":{"varan","varans"},
"varanidae":{"varanidae","varanidaes"},
"varanus":{"varanus","varanuses"},
"variability":{"variabilities","variability"},
"variable":{"variable","variables"},
"variableness":{"variableness","variablenesses"},
"variance":{"variance","variances"},
"variant":{"variant","variants"},
"variate":{"variate","variates"},
"variation":{"variation","variations"},
"variational":{"variational","variationals"},
"varicella":{"varicella","varicellas"},
"varicosity":{"varicosities","varicosity","varicosties"},
"varicotomy":{"varicotomies","varicotomy"},
"variedness":{"variedness","variednesses"},
"variegate":{"variegate","variegated","variegates","variegating"},
"variety":{"varieties","variety"},
"variola":{"variola","variolas"},
"variorum":{"variorum","variorums"},
"varix":{"varices","varix"},
"varlet":{"varlet","varlets"},
"varment":{"varment","varments"},
"varmint":{"varmint","varmints"},
"varna":{"varna","varnas"},
"varnish":{"varnish","varnished","varnishes","varnishing"},
"varsity":{"varsities","varsity"},
"vary":{"varied","varies","vary","varying"},
"vas":{"vas","vasa","vases"},
"vascularize":{"vascularize","vascularized","vascularizing"},
"vasculum":{"vascula","vasculum","vasculums"},
"vase":{"vase","vases"},
"vase-fine":{"vase-fine","vase-fines"},
"vasectomy":{"vasectomies","vasectomy"},
"vasopressin":{"vasopressin","vasopressins"},
"vassal":{"vassal","vassals"},
"vassalage":{"vassalage","vassalages"},
"vast":{"vast","vaster","vastest"},
"vastness":{"vastness","vastnesses"},
"vasty":{"vastier","vastiest","vasty"},
"vat":{"vat","vats","vatted","vatting"},
"vatican":{"vatican","vaticans"},
"vaticination":{"vaticination","vaticinations"},
"vaudeville":{"vaudeville","vaudevilles"},
"vault":{"vault","vaulted","vaulting","vaults"},
"vaulter":{"vaulter","vaulters"},
"vaulting":{"vaulting","vaultings"},
"vaunt":{"vaunt","vaunted","vaunting","vaunts"},
"vaunter":{"vaunter","vaunters"},
"vcr":{"vcr","vcrs"},
"vd":{"vd","vds"},
"veadar":{"veadar","veadars"},
"veal":{"veal","veals"},
"veau":{"veau","veaus"},
"vector":{"vector","vectored","vectoring"},
"veda":{"veda","vedas"},
"vedalia":{"vedalia","vedalias"},
"vedda":{"vedda","veddas"},
"veer":{"veer","veered","veering","veers"},
"veering":{"veering","veerings"},
"veery":{"veeries","veery"},
"vegetable":{"vegetable","vegetables"},
"vegetate":{"vegetate","vegetated","vegetating"},
"vegetation":{"vegetation","vegetations"},
"veggie":{"veggie","veggies"},
"vehemence":{"vehemence","vehemences"},
"vehicle":{"vehicle","vehicles"},
"veil":{"veil","veiled","veiling","veils"},
"veiling":{"veiling","veilings"},
"vein":{"vein","veined","veining","veins"},
"veiny":{"veinier","veiniest","veiny"},
"velamen":{"velalamina","velamen","velamina"},
"velarium":{"velarium","velarlaria"},
"velarize":{"velarize","velarized","velarizing"},
"velban":{"velban","velbans"},
"veld":{"veld","velds"},
"veldt":{"veldt","veldts"},
"velleity":{"velleities","velleity"},
"velocipede":{"velocipede","velocipedes"},
"velocity":{"velocities","velocity"},
"velour":{"velour","velours"},
"velours":{"velours","velourses"},
"velum":{"vela","velum","velums"},
"velveteen":{"velveteen","velveteens"},
"velvetleaf":{"velvetleaf","velvetleaves"},
"velvetweed":{"velvetweed","velvetweeds"},
"vena":{"vena","venae","venas"},
"vend":{"vend","vended","vending","vends"},
"venda":{"venda","vendas"},
"vendace":{"vendace","vendaces"},
"vendee":{"vendee","vendees"},
"vender":{"vender","venders"},
"vendetta":{"vendetta","vendettas"},
"vending":{"vending","vendings"},
"vendition":{"vendition","venditions"},
"vendor":{"vendor","vendors"},
"vendue":{"vendue","vendues"},
"veneer":{"veneer","veneered","veneering","veneers"},
"veneering":{"veneering","veneerings"},
"venerate":{"venerate","venerated","venerates","venerating"},
"veneration":{"veneration","venerations"},
"venerator":{"venerator","venerators"},
"veneridae":{"veneridae","veneridaes"},
"venesection":{"venesection","venesections"},
"venetia":{"venetia","venetias"},
"veneto":{"veneto","venetos"},
"venezia":{"venezia","venezias"},
"venezia-euganea":{"venezia-euganea","venezia-euganeas"},
"vengeance":{"vengeance","vengeances"},
"vengefulness":{"vengefulness","vengefulnesses"},
"venice":{"venice","venices"},
"venireman":{"venireman","veniremen"},
"venogram":{"venogram","venograms"},
"venom":{"venom","venoms"},
"vent":{"vent","vented","venting","vents"},
"ventail":{"ventail","ventails"},
"venter":{"venter","venters"},
"venthole":{"venthole","ventholes"},
"ventilate":{"ventilate","ventilated","ventilates","ventilating"},
"ventilation":{"ventilation","ventilations"},
"venting":{"venting","ventings"},
"ventolin":{"ventolin","ventolins"},
"ventricle":{"ventricle","ventricles"},
"ventriculus":{"ventriculi","ventriculus","ventriculuses"},
"ventriloquism":{"ventriloquism","ventriloquisms"},
"ventriloquize":{"ventriloquize","ventriloquized","ventriloquizing"},
"ventriloquy":{"ventriloquy","ventriloquys"},
"venture":{"venture","ventured","ventures","venturing"},
"venturesomeness":{"venturesomeness","venturesomenesses"},
"venue":{"venue","venues"},
"venula":{"venula","venulas"},
"venule":{"venule","venules"},
"venus":{"venus","venuses"},
"venushair":{"venushair","venushairs"},
"veps":{"veps","vepses"},
"vepse":{"vepse","vepses"},
"vepsian":{"vepsian","vepsians"},
"veracity":{"veracities","veracity"},
"veranda":{"veranda","verandas"},
"verandah":{"verandah","verandahs"},
"verapamil":{"verapamil","verapamils"},
"veratrum":{"veratrum","veratrums"},
"verb":{"verb","verbs"},
"verbal":{"verbal","verbals"},
"verbalize":{"verbalize","verbalized","verbalizes","verbalizing"},
"verbascum":{"verbascum","verbascums"},
"verbena":{"verbena","verbenas"},
"verbenaceae":{"verbenaceae","verbenaceaes"},
"verbesina":{"verbesina","verbesinas"},
"verbiage":{"verbiage","verbiages"},
"verbify":{"verbified","verbifies","verbify","verbifying"},
"verbolatry":{"verbolatries","verbolatry"},
"verboseness":{"verboseness","verbosenesses"},
"verbosity":{"verbosities","verbosity"},
"verdancy":{"verdancies","verdancy"},
"verdandi":{"verdandi","verdandis"},
"verdict":{"verdict","verdicts"},
"verdigris":{"verdigris","verdigrises"},
"verdin":{"verdin","verdins"},
"verdolagas":{"verdolagas","verdolagases"},
"verdun":{"verdun","verduns"},
"verdure":{"verdure","verdures"},
"verge":{"verge","verged","verges","verging"},
"vergil":{"vergil","vergils"},
"verification":{"verification","verifications"},
"verify":{"verified","verifies","verify","verifying"},
"verity":{"verities","verity"},
"vermiculate":{"vermiculate","vermiculated","vermiculating"},
"vermiculation":{"vermiculation","vermiculations"},
"vermifuge":{"vermifuge","vermifuges"},
"vermilion":{"vermilion","vermilions"},
"vermin":{"vermin","vermins"},
"vermis":{"vermes","vermis"},
"vermont":{"vermont","vermonts"},
"vernacular":{"vernacular","vernaculars"},
"vernalize":{"vernalize","vernalized","vernalizing"},
"vernier":{"vernier","verniers"},
"vernonia":{"vernonia","vernonias"},
"veronal":{"veronal","veronals"},
"veronica":{"veronica","veronicas"},
"verpa":{"verpa","verpas"},
"verrazano":{"verrazano","verrazanos"},
"verrazzano":{"verrazzano","verrazzanos"},
"verruca":{"verruca","verrucae","verrucas"},
"verse":{"verse","versed","verses","versing"},
"versifier":{"versifier","versifiers"},
"versify":{"versified","versifies","versify","versifying"},
"version":{"version","versions"},
"verso":{"verso","versos"},
"vertebra":{"vertebra","vertebrae","vertebras"},
"vertebrata":{"vertebrata","vertebratas"},
"vertebrate":{"vertebrate","vertebrates"},
"vertex":{"vertex","vertexes","vertices"},
"verthandi":{"verthandi","verthandis"},
"vertical":{"vertical","verticals"},
"verticality":{"verticalities","verticality"},
"verticalness":{"verticalness","verticalnesses"},
"vertigo":{"vertigines","vertigo","vertigoes","vertigos"},
"vertu":{"vertu","vertus"},
"vervain":{"vervain","vervains"},
"verve":{"verve","verves"},
"vervet":{"vervet","vervets"},
"vesalius":{"vesalius","vesaliuses"},
"vesica":{"vesica","vesicae","vesicas"},
"vesicant":{"vesicant","vesicants"},
"vesicaria":{"vesicaria","vesicarias"},
"vesicate":{"vesicate","vesicated","vesicating"},
"vesicatory":{"vesicatories","vesicatory"},
"vesicle":{"vesicle","vesicles"},
"vesiculate":{"vesiculate","vesiculated","vesiculating"},
"vespa":{"vespa","vespas"},
"vesper":{"vesper","vespers"},
"vespers":{"vespers","vesperses"},
"vespertilio":{"vespertilio","vespertilios"},
"vespertilionid":{"vespertilionid","vespertilionids"},
"vespertilionidae":{"vespertilionidae","vespertilionidaes"},
"vespiary":{"vespiaries","vespiary"},
"vespid":{"vespid","vespids"},
"vespidae":{"vespidae","vespidaes"},
"vespucci":{"vespucci","vespuccis"},
"vespula":{"vespula","vespulas"},
"vessel":{"vessel","vessels"},
"vest":{"vest","vested","vesting","vests"},
"vestibule":{"vestibule","vestibuled","vestibules","vestibuling"},
"vestige":{"vestige","vestiges"},
"vestment":{"vestment","vestments"},
"vestry":{"vestries","vestry"},
"vestryman":{"vestryman","vestrymen"},
"vesture":{"vesture","vestured","vestures","vesturing"},
"vesuvian":{"vesuvian","vesuvians"},
"vesuvianite":{"vesuvianite","vesuvianites"},
"vesuvius":{"vesuvius","vesuviuses"},
"vet":{"vet","vets","vetted","vetting"},
"vetchworm":{"vetchworm","vetchworms"},
"veteran":{"veteran","veterans"},
"veterinarian":{"veterinarian","veterinarians"},
"veterinary":{"veterinaries","veterinary"},
"veto":{"veto","vetoed","vetoes","vetoing"},
"vex":{"vex","vexed","vexes","vexing"},
"vexation":{"vexation","vexations"},
"vexillum":{"vexilia","vexilla","vexillum"},
"vfw":{"vfw","vfws"},
"vhf":{"vhf","vhfs"},
"vi":{"vi","vis"},
"vial":{"vial","vials"},
"viands":{"viands","viandses"},
"viatication":{"viatication","viatications"},
"viaticum":{"viatica","viaticum","viaticums"},
"viaticus":{"viaticus","viaticuses"},
"viator":{"viator","viatores"},
"vibes":{"vibes","vibeses"},
"vibraculum":{"vibracula","vibraculum"},
"vibraharp":{"vibraharp","vibraharps"},
"vibramycin":{"vibramycin","vibramycins"},
"vibrancy":{"vibrancies","vibrancy"},
"vibraphone":{"vibraphone","vibraphones"},
"vibrate":{"vibrate","vibrated","vibrates","vibrating"},
"vibration":{"vibration","vibrations"},
"vibrations":{"vibrations","vibrationses"},
"vibrato":{"vibrato","vibratos"},
"vibrio":{"vibrio","vibrios"},
"vibrion":{"vibrion","vibrions"},
"vibrissa":{"vibrissa","vibrissae","vibrissas"},
"viburnum":{"viburnum","viburnums"},
"vicar":{"vicar","vicars"},
"vicarage":{"vicarage","vicarages"},
"vicariate":{"vicariate","vicariates"},
"vicarship":{"vicarship","vicarships"},
"vice":{"vice","viced","vices","vicing"},
"vice-chairman":{"vice-chairman","vice-chairmann"},
"vicegerency":{"vicegerencies","vicegerency"},
"vicereine":{"vicereine","vicereines"},
"viceroy":{"viceroy","viceroys"},
"viceroyalty":{"viceroyalties","viceroyalty"},
"vicia":{"vicia","vicias"},
"vicinity":{"vicinities","vicinity"},
"viciousness":{"viciousness","viciousnesses"},
"vicissitude":{"vicissitude","vicissitudes"},
"vicksburg":{"vicksburg","vicksburgs"},
"victim":{"victim","victims"},
"victimisation":{"victimisation","victimisations"},
"victimization":{"victimization","victimizations"},
"victimize":{"victimize","victimized","victimizes","victimizing"},
"victor":{"victor","victors"},
"victoria":{"victoria","victorias"},
"victory":{"victories","victory"},
"victual":{"victual","victualed","victualing","victualled","victualling","victuals"},
"victualer":{"victualer","victualers"},
"victualler":{"victualler","victuallers"},
"victuals":{"victuals","victualses"},
"vicugna":{"vicugna","vicugnas"},
"vicuna":{"vicuna","vicunas"},
"vidar":{"vidar","vidars"},
"vide":{"vide","vided","viding"},
"video":{"video","videos"},
"vidua":{"vidua","viduas"},
"vie":{"vie","vied","vies","vying"},
"vienna":{"vienna","viennas"},
"vientiane":{"vientiane","vientianes"},
"vietnam":{"vietnam","vietnams"},
"vietnamese":{"vietnamese","vietnameses"},
"view":{"view","viewed","viewing","views"},
"viewer":{"viewer","viewers"},
"viewers":{"viewers","viewerses"},
"viewfinder":{"viewfinder","viewfinders"},
"viewgraph":{"viewgraph","viewgraphs"},
"viewing":{"viewing","viewings"},
"viewpoint":{"viewpoint","viewpoints"},
"viewy":{"viewier","viewiest","viewy"},
"vigil":{"vigil","vigils"},
"vigilance":{"vigilance","vigilances"},
"vigilante":{"vigilante","vigilantes"},
"vigna":{"vigna","vignas"},
"vignette":{"vignette","vignettes"},
"vigor":{"vigor","vigors"},
"vigour":{"vigour","vigours"},
"vii":{"vii","viis"},
"viii":{"viii","viiis"},
"vila":{"vila","vilas"},
"vile":{"vile","viler","vilest"},
"vileness":{"vileness","vilenesses"},
"vilification":{"vilification","vilifications"},
"vilify":{"vilified","vilifies","vilify","vilifying"},
"vilipend":{"vilipend","vilipended","vilipending"},
"villa":{"villa","villas"},
"village":{"village","villages"},
"villager":{"villager","villagers"},
"villain":{"villain","villains"},
"villainage":{"villainage","villainages"},
"villainousness":{"villainousness","villainousnesses"},
"villainy":{"villainies","villainy"},
"villanella":{"villanella","villanellas","villanelle"},
"villein":{"villein","villeins"},
"villeinage":{"villeinage","villeinages"},
"villoma":{"villoma","villomas"},
"villosity":{"villosities","villosity"},
"villus":{"villi","villus"},
"vilna":{"vilna","vilnas"},
"vilnius":{"vilnius","vilniuses"},
"vilno":{"vilno","vilnos"},
"vim":{"vim","vims"},
"vimen":{"vimen","vimina"},
"viminaria":{"viminaria","viminarias"},
"vina":{"vina","vinas"},
"vinaigrette":{"vinaigrette","vinaigrettes"},
"vinblastine":{"vinblastine","vinblastines"},
"vinca":{"vinca","vincas"},
"vincetoxicum":{"vincetoxicum","vincetoxicums"},
"vincristine":{"vincristine","vincristines"},
"vinculum":{"vincula","vinculum"},
"vindicate":{"vindicate","vindicated","vindicates","vindicating"},
"vindication":{"vindication","vindications"},
"vindicator":{"vindicator","vindicators"},
"vindictiveness":{"vindictiveness","vindictivenesses"},
"vine":{"vine","vined","vines","vining"},
"vinegariness":{"vinegariness","vinegarinesses"},
"vinegarishness":{"vinegarishness","vinegarishnesses"},
"vinegarroon":{"vinegarroon","vinegarroons"},
"vinegarweed":{"vinegarweed","vinegarweeds"},
"vinery":{"vineries","vinery"},
"vineyard":{"vineyard","vineyards"},
"vingt-et-un":{"vingt-et-un","vingt-et-uns"},
"vinifera":{"vinifera","viniferas"},
"vino":{"vino","vinos"},
"vintage":{"vintage","vintages"},
"vintner":{"vintner","vintners"},
"vinyl":{"vinyl","vinyls"},
"vinylbenzene":{"vinylbenzene","vinylbenzenes"},
"viocin":{"viocin","viocins"},
"viola":{"viola","violas"},
"violaceae":{"violaceae","violaceaes"},
"violate":{"violate","violated","violates","violating"},
"violation":{"violation","violations"},
"violator":{"violator","violators"},
"violence":{"violence","violences"},
"violet":{"violet","violets"},
"violin":{"violin","violins"},
"violinist":{"violinist","violinists"},
"violoncello":{"violoncello","violoncellos"},
"viomycin":{"viomycin","viomycins"},
"vip":{"vip","vips"},
"viper":{"viper","vipers"},
"vipera":{"vipera","viperas"},
"viperidae":{"viperidae","viperidaes"},
"virago":{"virago","viragoes","viragos"},
"vireo":{"vireo","vireos"},
"vireonidae":{"vireonidae","vireonidaes"},
"virgil":{"virgil","virgils"},
"virgilia":{"virgilia","virgilias"},
"virgin":{"virgin","virgins"},
"virginal":{"virginal","virginals"},
"virginia":{"virginia","virginias"},
"virgo":{"virgo","virgos"},
"virgule":{"virgule","virgules"},
"viricide":{"viricide","viricides"},
"viridity":{"viridities","viridity"},
"virility":{"virilities","virility"},
"virilization":{"virilization","virilizations"},
"virilize":{"virilize","virilized","virilizing"},
"viroid":{"viroid","viroids"},
"virtu":{"virtu","virtus"},
"virtue":{"virtue","virtues"},
"virtuoso":{"virtuosi","virtuoso","virtuosos"},
"virtuousness":{"virtuousness","virtuousnesses"},
"virucide":{"virucide","virucides"},
"virus":{"virus","viruses"},
"virusoid":{"virusoid","virusoids"},
"vis":{"vires","vis"},
"vis-a-vis":{"vis-a-vis","vis-a-vises"},
"visa":{"visa","visaed","visaing","visas"},
"visage":{"visage","visages"},
"visayan":{"visayan","visayans"},
"viscaceae":{"viscaceae","viscaceaes"},
"viscacha":{"viscacha","viscachas"},
"viscera":{"viscera","visceras"},
"viscidity":{"viscidities","viscidity"},
"viscidness":{"viscidness","viscidnesses"},
"viscometer":{"viscometer","viscometers"},
"viscose":{"viscose","viscoses"},
"viscosimeter":{"viscosimeter","viscosimeters"},
"viscosity":{"viscosities","viscosity"},
"viscount":{"viscount","viscounts"},
"viscountcy":{"viscountcies","viscountcy"},
"viscounty":{"viscounties","viscounty"},
"viscousness":{"viscousness","viscousnesses"},
"viscum":{"viscum","viscums"},
"viscus":{"viscera","viscus"},
"vise":{"vise","vised","vises","vising"},
"vishnuism":{"vishnuism","vishnuisms"},
"visibility":{"visibilities","visibility"},
"visibleness":{"visibleness","visiblenesses"},
"vision":{"vision","visioned","visioning","visions"},
"visionary":{"visionaries","visionary"},
"visit":{"visit","visited","visiting","visits"},
"visitant":{"visitant","visitants"},
"visitation":{"visitation","visitations"},
"visitor":{"visitor","visitors"},
"visor":{"visor","visors"},
"vista":{"vista","vistas"},
"vistula":{"vistula","vistulas"},
"visualisation":{"visualisation","visualisations"},
"visualization":{"visualization","visualizations"},
"visualize":{"visualize","visualized","visualizes","visualizing"},
"vita":{"vita","vitae"},
"vitaceae":{"vitaceae","vitaceaes"},
"vital":{"vital","vitals"},
"vitality":{"vitalities","vitality"},
"vitalize":{"vitalize","vitalized","vitalizes","vitalizing"},
"vitalness":{"vitalness","vitalnesses"},
"vitals":{"vitals","vitalses"},
"vitamin":{"vitamin","vitamins"},
"vitamine":{"vitamine","vitamines"},
"vitellus":{"vitelli","vitellus","vitelluses"},
"vithar":{"vithar","vithars"},
"vitharr":{"vitharr","vitharrs"},
"vitiate":{"vitiate","vitiated","vitiates","vitiating"},
"vitidaceae":{"vitidaceae","vitidaceaes"},
"vitis":{"vitis","vitises"},
"vitrectomy":{"vitrectomies","vitrectomy"},
"vitrify":{"vitrified","vitrifies","vitrify","vitrifying"},
"vitriol":{"vitriol","vitriols"},
"vitta":{"vitta","vittae"},
"vittaria":{"vittaria","vittarias"},
"vittariaceae":{"vittariaceae","vittariaceaes"},
"vituperate":{"vituperate","vituperated","vituperates","vituperating"},
"vituperation":{"vituperation","vituperations"},
"viva":{"viva","vivaed","vivaing","vivas"},
"vivacity":{"vivacities","vivacity"},
"vivarium":{"vivaria","vivarium","vivariums"},
"viverra":{"viverra","viverras"},
"viverricula":{"viverricula","viverriculas"},
"viverridae":{"viverridae","viverridaes"},
"viverrinae":{"viverrinae","viverrinaes"},
"viverrine":{"viverrine","viverrines"},
"vividness":{"vividness","vividnesses"},
"vivification":{"vivification","vivifications"},
"vivify":{"vivified","vivifies","vivify","vivifying"},
"vivifying":{"vivifying","vivifyings"},
"vivisect":{"vivisect","vivisected","vivisecting"},
"vixen":{"vixen","vixens"},
"vizla":{"vizla","vizlas"},
"vizor":{"vizor","vizored","vizoring","vizors","vozored"},
"vlf":{"vlf","vlfs"},
"vocable":{"vocable","vocables"},
"vocabulary":{"vocabularies","vocabulary"},
"vocal":{"vocal","vocals"},
"vocalist":{"vocalist","vocalists"},
"vocalization":{"vocalization","vocalizations"},
"vocalize":{"vocalize","vocalized","vocalizes","vocalizing"},
"vocalizing":{"vocalizing","vocalizings"},
"vocation":{"vocation","vocations"},
"vocative":{"vocative","vocatives"},
"vociferate":{"vociferate","vociferated","vociferates","vociferating"},
"vociferation":{"vociferation","vociferations"},
"vodoun":{"vodoun","vodouns"},
"vogue":{"vogue","vogues"},
"vogul":{"vogul","voguls"},
"voice":{"voice","voiced","voices","voicing"},
"voicelessness":{"voicelessness","voicelessnesses"},
"void":{"void","voided","voider","voidest","voiding","voids"},
"voidance":{"voidance","voidances"},
"voiding":{"voiding","voidings"},
"volaille":{"volaille","volailles"},
"volary":{"volaries","volary"},
"volatility":{"volatilities","volatility"},
"volatilize":{"volatilize","volatilized","volatilizing"},
"volcano":{"volcano","volcanoes","volcanos"},
"volcanology":{"volcanologies","volcanology"},
"vole":{"vole","voles"},
"volga":{"volga","volgas"},
"volgograd":{"volgograd","volgograds"},
"volition":{"volition","volitions"},
"volkslied":{"volkslied","volkslieder"},
"volley":{"volley","volleyed","volleying","volleys"},
"volleyball":{"volleyball","volleyballs"},
"volplane":{"volplane","volplaned","volplaning"},
"volt":{"volt","volts"},
"volt-ampere":{"volt-ampere","volt-amperes"},
"volta":{"volta","volte"},
"voltage":{"voltage","voltages"},
"voltaic":{"voltaic","voltaics"},
"voltaire":{"voltaire","voltaires"},
"voltaren":{"voltaren","voltarens"},
"volte-face":{"volte-face","volte-faces"},
"volubility":{"volubilities","volubility"},
"volume":{"volume","volumes"},
"voluminosity":{"voluminosities","voluminosity"},
"voluminousness":{"voluminousness","voluminousnesses"},
"voluntary":{"voluntaries","voluntary"},
"volunteer":{"volunteer","volunteered","volunteering","volunteers"},
"voluptuary":{"voluptuaries","voluptuary"},
"voluptuousness":{"voluptuousness","voluptuousnesses"},
"volute":{"volute","volutes"},
"volva":{"volva","volvae","volvas"},
"volvaria":{"volvaria","volvarias"},
"volvariaceae":{"volvariaceae","volvariaceaes"},
"volvariella":{"volvariella","volvariellas"},
"volvocaceae":{"volvocaceae","volvocaceaes"},
"volvocales":{"volvocales","volvocaleses"},
"volvox":{"volvox","volvoxes"},
"volvulus":{"volvulus","volvuluses"},
"vombatidae":{"vombatidae","vombatidaes"},
"vomit":{"vomit","vomited","vomiting","vomits"},
"vomiting":{"vomiting","vomitings"},
"vomitive":{"vomitive","vomitives"},
"vomitorium":{"vomitoria","vomitorium"},
"vomitory":{"vomitories","vomitory"},
"vomitus":{"vomitus","vomituses"},
"voodoo":{"voodoo","voodooed","voodooing","voodoos"},
"voodooism":{"voodooism","voodooisms"},
"voraciousness":{"voraciousness","voraciousnesses"},
"voracity":{"voracities","voracity"},
"vortex":{"vortex","vortexes","vortices"},
"vorticella":{"vorticella","vorticellae","vorticellas"},
"votary":{"votaries","votary"},
"vote":{"vote","voted","votes","voting"},
"voter":{"voter","voters"},
"voting":{"voting","votings"},
"votyak":{"votyak","votyaks"},
"vouch":{"vouch","vouched","vouches","vouching"},
"voucher":{"voucher","vouchers"},
"vouchsafe":{"vouchsafe","vouchsafed","vouchsafing"},
"vow":{"vow","vowed","vowing","vows"},
"vowel":{"vowel","vowels"},
"vox":{"voces","vox"},
"voyage":{"voyage","voyaged","voyages","voyaging"},
"voyeur":{"voyeur","voyeurs"},
"vroom":{"vroom","vroomed","vrooming"},
"vulcanisation":{"vulcanisation","vulcanisations"},
"vulcanite":{"vulcanite","vulcanites"},
"vulcanization":{"vulcanization","vulcanizations"},
"vulcanize":{"vulcanize","vulcanized","vulcanizing"},
"vulcanology":{"vulcanologies","vulcanology"},
"vulgarisation":{"vulgarisation","vulgarisations"},
"vulgarism":{"vulgarism","vulgarisms"},
"vulgarity":{"vulgarities","vulgarity"},
"vulgarization":{"vulgarization","vulgarizations"},
"vulgarize":{"vulgarize","vulgarized","vulgarizes","vulgarizing"},
"vulnerability":{"vulnerabilities","vulnerability"},
"vulnerary":{"vulneraries","vulnerary"},
"vulpes":{"vulpes","vulpeses"},
"vultur":{"vultur","vulturs"},
"vulture":{"vulture","vultures"},
"vulva":{"vulva","vulvae","vulvas"},
"w":{"w","ws"},
"wabash":{"wabash","wabashes"},
"wabble":{"wabble","wabbled","wabbling"},
"wacky":{"wackier","wackiest","wacky"},
"wad":{"wad","wadded","wadding","wads"},
"wadding":{"wadding","waddings"},
"waddle":{"waddle","waddled","waddles","waddling"},
"waddy":{"waddied","waddies","waddy","waddying"},
"wade":{"wade","waded","wading"},
"wader":{"wader","waders"},
"wadi":{"wadi","wadies","wadis"},
"wads":{"wads","wadses"},
"wadset":{"wadset","wadsets","wadsetted","wadsetting"},
"wafer":{"wafer","wafered","wafering","wafers"},
"waffle":{"waffle","waffled","waffles","waffling"},
"waft":{"waft","wafted","wafting","wafts"},
"wafture":{"wafture","waftures"},
"wag":{"wag","wagged","wagging","wags"},
"wage":{"wage","waged","wages","waging"},
"wager":{"wager","wagered","wagering","wagers"},
"wagerer":{"wagerer","wagerers"},
"wages":{"wages","wageses"},
"waggery":{"waggeries","waggery"},
"waggishness":{"waggishness","waggishnesses"},
"waggle":{"waggle","waggled","waggles","waggling"},
"waggly":{"wagglier","waggliest","waggly"},
"waggon":{"waggon","waggons"},
"waggoner":{"waggoner","waggoners"},
"waggonwright":{"waggonwright","waggonwrights"},
"wagner":{"wagner","wagners"},
"wagon":{"wagon","wagoned","wagoning","wagons"},
"wagon-lit":{"wagon-lit","wagon-lits","wagons-lits"},
"wagoner":{"wagoner","wagoners"},
"wagonwright":{"wagonwright","wagonwrights"},
"wagram":{"wagram","wagrams"},
"wahabi":{"wahabi","wahhabis"},
"wahhabi":{"wahhabi","wahhabis"},
"wahoo":{"wahoo","wahoos"},
"wahunsonacock":{"wahunsonacock","wahunsonacocks"},
"wahvey":{"wahvey","wahveys"},
"wail":{"wail","wailed","wailing","wails"},
"wailing":{"wailing","wailings"},
"wainscot":{"wainscot","wainscoted","wainscoting","wainscots","wainscotted","wainscotting"},
"wainscoting":{"wainscoting","wainscotings"},
"wainscotting":{"wainscotting","wainscottings"},
"wainwright":{"wainwright","wainwrights"},
"waist":{"waist","waists"},
"waistband":{"waistband","waistbands"},
"waistcloth":{"waistcloth","waistcloths"},
"waistcoat":{"waistcoat","waistcoats"},
"waistline":{"waistline","waistlines"},
"wait":{"wait","waited","waiting","waits"},
"waiter":{"waiter","waiters"},
"waiting":{"waiting","waitings"},
"waitress":{"waitress","waitressed","waitresses","waitressing"},
"waive":{"waive","waived","waives","waiving"},
"waiver":{"waiver","waivers"},
"wakashan":{"wakashan","wakashans"},
"wake":{"wake","waked","wakes","waking","woke","woken"},
"wake-robin":{"wake-robin","wake-robins"},
"wakefulness":{"wakefulness","wakefulnesses"},
"waken":{"waken","wakened","wakening","wakens"},
"wakening":{"wakening","wakenings"},
"walapai":{"walapai","walapais"},
"walbiri":{"walbiri","walbiris"},
"waldmeister":{"waldmeister","waldmeisters"},
"wale":{"wale","waled","wales","waling"},
"wales":{"wales","waleses"},
"walk":{"walk","walked","walking","walks"},
"walk-up":{"walk-up","walk-ups"},
"walkaway":{"walkaway","walkaways"},
"walker":{"walker","walkers"},
"walkie-talkie":{"walkie-talkie","walkie-talkies"},
"walking":{"walking","walkings"},
"walkingstick":{"walkingstick","walkingsticks"},
"walkover":{"walkover","walkovers"},
"walkway":{"walkway","walkways"},
"walky-talky":{"walky-talkies","walky-talky"},
"wall":{"wall","walled","walling","walls"},
"wallaby":{"wallabies","wallaby"},
"wallah":{"wallah","wallahs"},
"wallaroo":{"wallaroo","wallaroos"},
"wallet":{"wallet","wallets"},
"walleye":{"walleye","walleyes"},
"wallflower":{"wallflower","wallflowers"},
"wallop":{"wallop","walloped","walloping","wallops"},
"walloping":{"walloping","wallopings"},
"wallow":{"wallow","wallowed","wallowing","wallows"},
"wallpaper":{"wallpaper","wallpapered","wallpapering","wallpapers"},
"wally":{"wallies","wally"},
"walnut":{"walnut","walnuts"},
"walpole":{"walpole","walpoles"},
"walrus":{"walrus","walruses"},
"waltz":{"waltz","waltzed","waltzes","waltzing","waltzs"},
"wamble":{"wamble","wambled","wambles","wambling"},
"wampanoag":{"wampanoag","wampanoags"},
"wampee":{"wampee","wampees"},
"wampum":{"wampum","wampums"},
"wan":{"wan","wanned","wanner","wannest","wanning","wans"},
"wand":{"wand","wands"},
"wandala":{"wandala","wandalas"},
"wander":{"wander","wandered","wandering","wanders"},
"wanderer":{"wanderer","wanderers"},
"wandering":{"wandering","wanderings"},
"wanderjahr":{"wanderjahr","wanderjahre"},
"wanderoo":{"wanderoo","wanderoos"},
"wandflower":{"wandflower","wandflowers"},
"wane":{"wane","waned","wanes","waning"},
"wangle":{"wangle","wangled","wangles","wangling"},
"wangling":{"wangling","wanglings"},
"wank":{"wank","wanks"},
"wannabe":{"wannabe","wannabes"},
"wannabee":{"wannabee","wannabees"},
"wanness":{"wanness","wannesses"},
"want":{"want","wanted","wanting","wants"},
"wanton":{"wanton","wantoned","wantoning","wantons"},
"wantonness":{"wantonness","wantonnesses"},
"wapiti":{"wapiti","wapitis"},
"war":{"war","warred","warring","wars"},
"waratah":{"waratah","waratahs"},
"warble":{"warble","warbled","warbles","warbling"},
"warbler":{"warbler","warblers"},
"ward":{"ward","warded","warding","wards"},
"ward-heeler":{"ward-heeler","ward-heelers"},
"warden":{"warden","wardens"},
"warder":{"warder","warders"},
"wardrobe":{"wardrobe","wardrobes"},
"ware":{"ware","wared","wares","waring"},
"warehouse":{"warehouse","warehoused","warehouses","warehousing"},
"warehouseman":{"warehouseman","warehousemen"},
"warehouser":{"warehouser","warehousers"},
"warehousing":{"warehousing","warehousings"},
"wares":{"wares","wareses"},
"warfare":{"warfare","warfares"},
"warfarin":{"warfarin","warfarins"},
"warhead":{"warhead","warheads"},
"warhorse":{"warhorse","warhorses"},
"wariness":{"wariness","warinesses"},
"warlord":{"warlord","warlords"},
"warlpiri":{"warlpiri","warlpiris"},
"warm":{"warm","warmed","warmer","warmest","warming"},
"warm-up":{"warm-up","warm-ups"},
"warmer":{"warmer","warmers"},
"warmheartedness":{"warmheartedness","warmheartednesses"},
"warming":{"warming","warmings"},
"warmness":{"warmness","warmnesses"},
"warmonger":{"warmonger","warmongers"},
"warmongering":{"warmongering","warmongerings"},
"warmth":{"warmth","warmths"},
"warn":{"warn","warned","warning","warns"},
"warning":{"warning","warnings"},
"warp":{"warp","warped","warping","warps"},
"warpath":{"warpath","warpaths"},
"warping":{"warping","warpings"},
"warragal":{"warragal","warragals"},
"warrant":{"warrant","warranted","warranting","warrants"},
"warrantor":{"warrantor","warrantors"},
"warranty":{"warranties","warranty"},
"warren":{"warren","warrens"},
"warrigal":{"warrigal","warrigals"},
"warrior":{"warrior","warriors"},
"warsaw":{"warsaw","warsaws"},
"warship":{"warship","warships"},
"warsle":{"warsle","warsled","warsling","warstled"},
"wart":{"wart","warts"},
"wartweed":{"wartweed","wartweeds"},
"wartwort":{"wartwort","wartworts"},
"warty":{"wartier","wartiest","warty"},
"wary":{"warier","wariest","wary"},
"wash":{"wash","washed","washes","washing"},
"wash-and-wear":{"wash-and-wear","wash-and-wears"},
"washable":{"washable","washables"},
"washables":{"washables","washableses"},
"washbasin":{"washbasin","washbasins"},
"washboard":{"washboard","washboards"},
"washbowl":{"washbowl","washbowls"},
"washcloth":{"washcloth","washcloths"},
"washday":{"washday","washdays"},
"washer":{"washer","washers"},
"washerman":{"washerman","washermen"},
"washerwoman":{"washerwoman","washerwomen"},
"washing":{"washing","washings"},
"washington":{"washington","washingtons"},
"washout":{"washout","washouts"},
"washrag":{"washrag","washrags"},
"washstand":{"washstand","washstands"},
"washup":{"washup","washups"},
"washwoman":{"washwoman","washwomen"},
"washy":{"washier","washiest","washy"},
"wasp":{"wasp","wasps"},
"waspy":{"waspier","waspiest","waspy"},
"wassail":{"wassail","wassailed","wassailing","wassails"},
"wassailer":{"wassailer","wassailers"},
"waste":{"waste","wasted","wastes","wasting"},
"wastebasket":{"wastebasket","wastebaskets"},
"wastebin":{"wastebin","wastebins"},
"wastefulness":{"wastefulness","wastefulnesses"},
"wasteland":{"wasteland","wastelands"},
"waster":{"waster","wasters"},
"wastewater":{"wastewater","wastewaters"},
"wasteweir":{"wasteweir","wasteweirs"},
"wasteyard":{"wasteyard","wasteyards"},
"wasting":{"wasting","wastings"},
"wastrel":{"wastrel","wastrels"},
"watch":{"watch","watched","watches","watching"},
"watchband":{"watchband","watchbands"},
"watchdog":{"watchdog","watchdogs"},
"watcher":{"watcher","watchers"},
"watchfulness":{"watchfulness","watchfulnesses"},
"watching":{"watching","watchings"},
"watchmaker":{"watchmaker","watchmakers"},
"watchman":{"watchman","watchmen"},
"watchstrap":{"watchstrap","watchstraps"},
"watchword":{"watchword","watchwords"},
"water":{"water","watered","watering","waters"},
"water-cool":{"water-cool","water-cooled","water-cooling"},
"water-shield":{"water-shield","water-shields"},
"water-ski":{"water-ski","water-ski'd","water-skied","water-skiing","water-skis"},
"water-soak":{"water-soak","water-soaked","water-soaking"},
"water-target":{"water-target","water-targets"},
"water-wave":{"water-wave","water-waved","water-waving"},
"waterbird":{"waterbird","waterbirds"},
"watercannon":{"watercannon","watercannons"},
"watercolor":{"watercolor","watercolors"},
"watercolorist":{"watercolorist","watercolorists"},
"watercolourist":{"watercolourist","watercolourists"},
"watercolous":{"watercolous","watercolouses"},
"watercourse":{"watercourse","watercourses"},
"watercraft":{"watercraft","watercrafts"},
"watered-silk":{"watered-silk","watered-silks"},
"waterfall":{"waterfall","waterfalls"},
"waterfinder":{"waterfinder","waterfinders"},
"waterfowl":{"waterfowl","waterfowls"},
"waterfront":{"waterfront","waterfronts"},
"watering":{"watering","waterings"},
"waterlessness":{"waterlessness","waterlessnesses"},
"waterline":{"waterline","waterlines"},
"waterloo":{"waterloo","waterloos"},
"waterman":{"waterman","watermen"},
"watermark":{"watermark","watermarks"},
"watermelon":{"watermelon","watermelons"},
"watermint":{"watermint","watermints"},
"waterproof":{"waterproof","waterproofed","waterproofing","waterproofs"},
"waterproofing":{"waterproofing","waterproofings"},
"waters":{"waters","waterses"},
"watershed":{"watershed","watersheds"},
"waterskin":{"waterskin","waterskins"},
"waterspout":{"waterspout","waterspouts"},
"waterway":{"waterway","waterways"},
"waterwheel":{"waterwheel","waterwheels"},
"waterworks":{"waterworks","waterworkses"},
"watery":{"waterier","wateriest","watery"},
"wats":{"wats","watses"},
"watt":{"watt","watts"},
"wattage":{"wattage","wattages"},
"wattle":{"wattle","wattled","wattles","wattling"},
"watusi":{"watusi","watusis"},
"wave":{"wave","waved","waves","waving"},
"wave-off":{"wave-off","wave-offs"},
"waveform":{"waveform","waveforms"},
"waveguide":{"waveguide","waveguides"},
"wavelength":{"wavelength","wavelengths"},
"wavelet":{"wavelet","wavelets"},
"waver":{"waver","wavered","wavering","wavers"},
"waverer":{"waverer","waverers"},
"wavering":{"wavering","waverings"},
"waving":{"waving","wavings"},
"wavy":{"wavier","waviest","wavy"},
"wax":{"wax","waxed","waxes","waxing"},
"waxberry":{"waxberries","waxberry"},
"waxflower":{"waxflower","waxflowers"},
"waxflowerl":{"waxflowerl","waxflowerls"},
"waxmallow":{"waxmallow","waxmallows"},
"waxwork":{"waxwork","waxworks"},
"waxy":{"waxier","waxiest","waxy"},
"way":{"way","ways"},
"waybill":{"waybill","waybills"},
"wayfarer":{"wayfarer","wayfarers"},
"wayland":{"wayland","waylands"},
"waylay":{"waylaid","waylay","waylaying","waylays"},
"ways":{"ways","wayses"},
"wayside":{"wayside","waysides"},
"wb":{"wb","wbs"},
"wbn":{"wbn","wbns"},
"wbs":{"wbs","wbses"},
"weak":{"weak","weaker","weakest"},
"weaken":{"weaken","weakened","weakening","weakens"},
"weakfish":{"weakfish","weakfishes"},
"weakling":{"weakling","weaklings"},
"weakly":{"weaklier","weakliest","weakly"},
"weakness":{"weakness","weaknesses"},
"weal":{"weal","weals"},
"wealth":{"wealth","wealths"},
"wealthiness":{"wealthiness","wealthinesses"},
"wealthy":{"wealthier","wealthiest","wealthy"},
"wean":{"wean","weaned","weaning"},
"weaning":{"weaning","weanings"},
"weapon":{"weapon","weapons"},
"weaponry":{"weaponries","weaponry"},
"wear":{"wear","wearing","wears","wore","worn"},
"weariness":{"weariness","wearinesses"},
"wearing":{"wearing","wearings"},
"weary":{"wearied","wearier","wearies","weariest","weary","wearying"},
"weasel":{"weasel","weaseled","weaseling","weasels"},
"weather":{"weather","weathered","weathering","weathers"},
"weatherboard":{"weatherboard","weatherboarded","weatherboarding","weatherboards"},
"weatherboarding":{"weatherboarding","weatherboardings"},
"weathercock":{"weathercock","weathercocks"},
"weatherman":{"weatherman","weathermen"},
"weatherproof":{"weatherproof","weatherproofed","weatherproofing"},
"weathervane":{"weathervane","weathervanes"},
"weave":{"weave","weaved","weaves","weaving","wove","woven"},
"weaver":{"weaver","weavers"},
"weaverbird":{"weaverbird","weaverbirds"},
"web":{"web","webbed","webbing","webs"},
"webby":{"webbier","webbiest","webby"},
"weber":{"weber","webers"},
"webfoot":{"webfeet","webfoot"},
"webster":{"webster","websters"},
"wed":{"wed","wedded","wedding","weds"},
"wedding":{"wedding","weddings"},
"wedge":{"wedge","wedged","wedges","wedging"},
"wedgie":{"wedgie","wedgies"},
"wedgies":{"wedgies","wedgieses"},
"wedgy":{"wedgier","wedgiest","wedgy"},
"wedlock":{"wedlock","wedlocks"},
"wednesday":{"wednesday","wednesdays"},
"wee":{"wee","weer","wees","weest"},
"weed":{"weed","weeded","weeding","weeds"},
"weeds":{"weeds","weedses"},
"weedy":{"weedier","weediest","weedy"},
"week":{"week","weeks"},
"weekday":{"weekday","weekdays"},
"weekend":{"weekend","weekended","weekending","weekends"},
"weekly":{"weeklies","weekly"},
"ween":{"ween","weened","weening"},
"weeness":{"weeness","weenesses"},
"weenie":{"weenie","weenies"},
"weensy":{"weensier","weensiest","weensy"},
"weeny":{"weenier","weeniest","weeny"},
"weep":{"weep","weeping","weeps","wept"},
"weeper":{"weeper","weepers"},
"weepiness":{"weepiness","weepinesses"},
"weeping":{"weeping","weepings"},
"weepy":{"weepier","weepies","weepiest","weepy"},
"weevil":{"weevil","weevils"},
"weewee":{"weewee","weeweed","weeweeing","weewees"},
"weft":{"weft","wefts"},
"weigela":{"weigela","weigelas"},
"weigh":{"weigh","weighed","weighing","weighs"},
"weighing":{"weighing","weighings"},
"weight":{"weight","weighted","weighting","weights"},
"weightiness":{"weightiness","weightinesses"},
"weighting":{"weighting","weightings"},
"weightlessness":{"weightlessness","weightlessnesses"},
"weightlifter":{"weightlifter","weightlifters"},
"weighty":{"weightier","weightiest","weighty"},
"weird":{"weird","weirder","weirdest","weirds"},
"weirdie":{"weirdie","weirdies"},
"weirdness":{"weirdness","weirdnesses"},
"weirdo":{"weirdo","weirdoes"},
"weirdy":{"weirdies","weirdy"},
"weisenheimer":{"weisenheimer","weisenheimers"},
"weka":{"weka","wekas"},
"welch":{"welch","welched","welching"},
"welcher":{"welcher","welchers"},
"welcome":{"welcome","welcomed","welcomes","welcoming"},
"welcoming":{"welcoming","welcomings"},
"weld":{"weld","welded","welding","welds"},
"welder":{"welder","welders"},
"welfare":{"welfare","welfares"},
"welkin":{"welkin","welkins"},
"well":{"bes","best","better","well","welled","welling","wells"},
"well-being":{"well-being","well-beings"},
"well-off":{"best-off","better-off","well-off"},
"well-wisher":{"well-wisher","well-wishers"},
"wellhead":{"wellhead","wellheads"},
"wellington":{"wellington","wellingtons"},
"wellpoint":{"wellpoint","wellpoints"},
"wellspring":{"wellspring","wellsprings"},
"welsh":{"welsh","welshed","welshes","welshing"},
"welsher":{"welsher","welshers"},
"welshman":{"welshman","welshmen"},
"welshmen":{"welshmen","welshwomen"},
"welshwoman":{"welshwoman","welshwomen"},
"welt":{"welt","welted","welting","welts"},
"weltanschauung":{"weltanschauung","weltanschauungs"},
"welter":{"welter","weltered","weltering","welters"},
"weltschmerz":{"weltschmerz","weltschmerzs"},
"welwitschia":{"welwitschia","welwitschias"},
"welwitschiaceae":{"welwitschiaceae","welwitschiaceaes"},
"wen":{"wen","wens"},
"wen-ti":{"wen-ti","wen-tis"},
"wench":{"wench","wenched","wenches","wenching"},
"wend":{"wend","wended","wending"},
"werewolf":{"werewolf","werewolves"},
"wesley":{"wesley","wesleys"},
"wesleyanism":{"wesleyanism","wesleyanisms"},
"wesleyism":{"wesleyism","wesleyisms"},
"west":{"west","wests"},
"wester":{"wester","westers"},
"westerly":{"westerlies","westerly"},
"western":{"western","westerns"},
"westernize":{"westernize","westernized","westernizes","westernizing"},
"wet":{"wet","wets","wetted","wetter","wettest","wetting"},
"wetback":{"wetback","wetbacks"},
"wetting":{"wetting","wettings"},
"whack":{"whack","whacked","whacking","whacks"},
"whacker":{"whacker","whackers"},
"whacking":{"whacking","whackings"},
"whacky":{"whackier","whackiest","whacky"},
"whale":{"whale","whaled","whales","whaling"},
"whalebone":{"whalebone","whalebones"},
"whaler":{"whaler","whalers"},
"whalesucker":{"whalesucker","whalesuckers"},
"wham":{"wham","whammed","whamming","whams"},
"whammy":{"whammies","whammy"},
"whang":{"whang","whanged","whanging","whangs"},
"whap":{"whap","whapped","whapping","whaps"},
"wharf":{"wharf","wharfed","wharfing","wharfs","wharves"},
"wharfage":{"wharfage","wharfages"},
"whatchamacallit":{"whatchamacallit","whatchamacallits"},
"whatnot":{"whatnot","whatnots"},
"whatsis":{"whatses","whatsis"},
"wheal":{"wheal","wheals"},
"wheat":{"wheat","wheats"},
"wheatworm":{"wheatworm","wheatworms"},
"wheedle":{"wheedle","wheedled","wheedles","wheedling"},
"wheedling":{"wheedling","wheedlings"},
"wheel":{"wheel","wheeled","wheeling","wheels"},
"wheelbarrow":{"wheelbarrow","wheelbarrows"},
"wheeler":{"wheeler","wheelers"},
"wheelhouse":{"wheelhouse","wheelhouses"},
"wheelie":{"wheelie","wheelies"},
"wheeling":{"wheeling","wheelings"},
"wheelman":{"wheelman","wheelmen"},
"wheeze":{"wheeze","wheezed","wheezes","wheezing"},
"wheezy":{"wheezier","wheeziest","wheezy"},
"whelm":{"whelm","whelmed","whelming","whelms"},
"whelp":{"whelp","whelped","whelping","whelps"},
"wherefore":{"wherefore","wherefores"},
"wherry":{"wherries","wherry"},
"whet":{"whet","whets","whetted","whetting"},
"whetter":{"whetter","whetters"},
"whey":{"whey","wheys"},
"whicker":{"whicker","whickered","whickering","whickers"},
"whidah":{"whidah","whidahs"},
"whiff":{"whiff","whiffed","whiffing","whiffs"},
"whiffle":{"whiffle","whiffled","whiffling"},
"whiffletree":{"whiffletree","whiffletrees"},
"whigmaleerie":{"whigmaleerie","whigmaleeries"},
"while":{"while","whiled","whiles","whiling"},
"whim":{"whim","whims"},
"whimper":{"whimper","whimpered","whimpering","whimpers"},
"whimsey":{"whimsey","whimseys"},
"whimsicality":{"whimsicalities","whimsicality"},
"whimsy":{"whimsies","whimsy"},
"whin":{"whin","whins"},
"whinberry":{"whinberries","whinberry"},
"whinchat":{"whinchat","whinchats"},
"whine":{"whine","whined","whines","whining"},
"whiner":{"whiner","whiners"},
"whinny":{"whinnied","whinnies","whinny","whinnying"},
"whiny":{"whinier","whiniest","whiny"},
"whip":{"whip","whipped","whipping","whips","whipt"},
"whiplash":{"whiplash","whiplashes"},
"whipper-in":{"whipper-in","whippers-in"},
"whippersnapper":{"whippersnapper","whippersnappers"},
"whipping":{"whipping","whippings"},
"whippletree":{"whippletree","whippletrees"},
"whippoorwill":{"whippoorwill","whippoorwills"},
"whippy":{"whippier","whippiest","whippy"},
"whipsaw":{"whipsaw","whipsawed","whipsawing","whipsawn","whipsaws"},
"whipscorpion":{"whipscorpion","whipscorpions"},
"whipsnake":{"whipsnake","whipsnakes"},
"whipstitch":{"whipstitch","whipstitched","whipstitches","whipstitching"},
"whipstitching":{"whipstitching","whipstitchings"},
"whiptail":{"whiptail","whiptails"},
"whir":{"whir","whirred","whirring","whirs"},
"whirl":{"whirl","whirled","whirling","whirls"},
"whirligig":{"whirligig","whirligigs"},
"whirling":{"whirling","whirlings"},
"whirlpool":{"whirlpool","whirlpooled","whirlpooling","whirlpools"},
"whirlwind":{"whirlwind","whirlwinds"},
"whirly":{"whirlies","whirly"},
"whirlybird":{"whirlybird","whirlybirds"},
"whirr":{"whirr","whirrs"},
"whirring":{"whirring","whirrings"},
"whirry":{"whirried","whirry","whirrying"},
"whish":{"whish","whished","whishing"},
"whisk":{"whisk","whisked","whisking","whisks"},
"whiskbroom":{"whiskbroom","whiskbrooms"},
"whisker":{"whisker","whiskered","whiskering","whiskers"},
"whiskers":{"whiskers","whiskerses"},
"whiskey":{"whiskey","whiskeys"},
"whisky":{"whiskies","whisky"},
"whisper":{"whisper","whispered","whispering","whispers"},
"whispering":{"whispering","whisperings"},
"whist":{"whist","whists"},
"whistle":{"whistle","whistled","whistles","whistling"},
"whistle-stop":{"whistle-stop","whistle-stopped","whistle-stopping","whistle-stops"},
"whistler":{"whistler","whistlers"},
"whistling":{"whistling","whistlings"},
"whit":{"whit","whits"},
"whit-tuesday":{"whit-tuesday","whit-tuesdays"},
"white":{"white","whiter","whites","whitest"},
"whitecap":{"whitecap","whitecaps"},
"whitecup":{"whitecup","whitecups"},
"whiteface":{"whiteface","whitefaces"},
"whitefish":{"whitefish","whitefishes"},
"whitefly":{"whiteflies","whitefly"},
"whitehead":{"whitehead","whiteheads"},
"whitelash":{"whitelash","whitelashes"},
"whiten":{"whiten","whitened","whitening","whitens"},
"whitener":{"whitener","whiteners"},
"whiteness":{"whiteness","whitenesses"},
"whitening":{"whitening","whitenings"},
"whitetail":{"whitetail","whitetails"},
"whitethorn":{"whitethorn","whitethorns"},
"whitethroat":{"whitethroat","whitethroats"},
"whitewash":{"whitewash","whitewashed","whitewashes","whitewashing"},
"whitewood":{"whitewood","whitewoods"},
"whitey":{"whitey","whiteys"},
"whiting":{"whiting","whitings"},
"whitlavia":{"whitlavia","whitlavias"},
"whitlow":{"whitlow","whitlows"},
"whitmonday":{"whitmonday","whitmondays"},
"whitney":{"whitney","whitneys"},
"whitsun":{"whitsun","whitsuns"},
"whitsunday":{"whitsunday","whitsundays"},
"whitsuntide":{"whitsuntide","whitsuntides"},
"whittle":{"whittle","whittled","whittles","whittling"},
"whitweek":{"whitweek","whitweeks"},
"whity":{"whitier","whities","whitiest","whity"},
"whiz":{"whiz","whizs","whizzed","whizzes","whizzing"},
"whiz-kid":{"whiz-kid","whiz-kids"},
"whizbang":{"whizbang","whizbangs"},
"whizz":{"whizz","whizzed","whizzing","whizzs"},
"whizz-kid":{"whizz-kid","whizz-kids"},
"whizzbang":{"whizzbang","whizzbangs"},
"who":{"who","whos"},
"whodunit":{"whodunit","whodunits"},
"whole":{"whole","wholes"},
"wholeheartedness":{"wholeheartedness","wholeheartednesses"},
"wholeness":{"wholeness","wholenesses"},
"wholesale":{"wholesale","wholesaled","wholesaling"},
"wholesaler":{"wholesaler","wholesalers"},
"whomp":{"whomp","whomped","whomping","whomps"},
"whoop":{"whoop","whooped","whooping","whoops"},
"whooper":{"whooper","whoopers"},
"whoosh":{"whoosh","whooshed","whooshes","whooshing"},
"whop":{"whop","whopped","whopping","whops"},
"whopper":{"whopper","whoppers"},
"whore":{"whore","whored","whores","whoring"},
"whoredom":{"whoredom","whoredoms"},
"whorehouse":{"whorehouse","whorehouses"},
"whoremaster":{"whoremaster","whoremasters"},
"whoremonger":{"whoremonger","whoremongers"},
"whorl":{"whorl","whorls"},
"whorlywort":{"whorlywort","whorlyworts"},
"whortleberry":{"whortleberries","whortleberry"},
"why":{"whies","why","whys"},
"whydah":{"whydah","whydahs"},
"wick":{"wick","wicks"},
"wicked":{"wicked","wickeder","wickedest"},
"wickedness":{"wickedness","wickednesses"},
"wicker":{"wicker","wickers"},
"wickerwork":{"wickerwork","wickerworks"},
"wicket":{"wicket","wickets"},
"wickup":{"wickup","wickups"},
"wicopy":{"wicopies","wicopy"},
"wide":{"wide","wider","widest"},
"wide-awake":{"wide-awake","wide-awakes"},
"widen":{"widen","widened","widening","widens"},
"wideness":{"wideness","widenesses"},
"widening":{"widening","widenings"},
"widgeon":{"widgeon","widgeons"},
"widget":{"widget","widgets"},
"widow":{"widow","widowed","widowing","widows"},
"widower":{"widower","widowers"},
"widowman":{"widowman","widowmen"},
"width":{"width","widths"},
"wieland":{"wieland","wielands"},
"wield":{"wield","wielded","wielding","wields"},
"wieldy":{"wieldier","wieldiest","wieldy"},
"wiener":{"wiener","wieners"},
"wienerwurst":{"wienerwurst","wienerwursts"},
"wife":{"wife","wives"},
"wifely":{"wifelier","wifeliest","wifely"},
"wiffle":{"wiffle","wiffles"},
"wig":{"wig","wigged","wigging","wigs"},
"wigeon":{"wigeon","wigeons"},
"wigging":{"wigging","wiggings"},
"wiggle":{"wiggle","wiggled","wiggles","wiggling"},
"wiggler":{"wiggler","wigglers"},
"wiggly":{"wigglier","wiggliest","wiggly"},
"wight":{"wight","wights"},
"wigwag":{"wigwag","wigwagged","wigwagging","wigwags"},
"wigwam":{"wigwam","wigwams"},
"wild":{"wild","wilder","wildest","wilds"},
"wildcat":{"wildcat","wildcats","wildcatted","wildcatting"},
"wildebeest":{"wildebeest","wildebeests"},
"wilder":{"wilder","wildered","wildering"},
"wilderness":{"wilderness","wildernesses"},
"wildflower":{"wildflower","wildflowers"},
"wildness":{"wildness","wildnesses"},
"wile":{"wile","wiled","wiles","wiling"},
"wilfulness":{"wilfulness","wilfulnesses"},
"wiliness":{"wiliness","wilinesses"},
"will":{"will","willed","willing","wills"},
"willet":{"willet","willets"},
"willfulness":{"willfulness","willfulnesses"},
"willing":{"willing","willings"},
"willow":{"willow","willowed","willowing","willows"},
"willow-pattern":{"willow-pattern","willow-patterns"},
"willowware":{"willowware","willowwares"},
"willowy":{"willowier","willowiest","willowy"},
"willpower":{"willpower","willpowers"},
"wilson":{"wilson","wilsons"},
"wilt":{"wilt","wilted","wilting","wilts"},
"wilting":{"wilting","wiltings"},
"wily":{"wilier","wiliest","wily"},
"wimble":{"wimble","wimbles"},
"wimp":{"wimp","wimps"},
"wimple":{"wimple","wimpled","wimpling"},
"win":{"win","winning","wins","won"},
"wince":{"wince","winced","winces","wincing"},
"winch":{"winch","winched","winches","winching"},
"wind":{"wind","winded","winding","winds","wound"},
"windage":{"windage","windages"},
"windbag":{"windbag","windbags"},
"windbreak":{"windbreak","windbreaks"},
"windbreaker":{"windbreaker","windbreakers"},
"windcheater":{"windcheater","windcheaters"},
"winder":{"winder","winders"},
"windfall":{"windfall","windfalls"},
"windflower":{"windflower","windflowers"},
"windiness":{"windiness","windinesses"},
"winding":{"winding","windings"},
"winding-clothes":{"winding-clothes","winding-clotheses"},
"winding-sheet":{"winding-sheet","winding-sheets"},
"windlass":{"windlass","windlassed","windlasses","windlassing"},
"windlessness":{"windlessness","windlessnesses"},
"windmill":{"windmill","windmills"},
"window":{"window","windowed","windowing","windows"},
"window-shop":{"window-shop","window-shopped","window-shopping","window-shops"},
"windowpane":{"windowpane","windowpanes"},
"windpipe":{"windpipe","windpipes"},
"windrow":{"windrow","windrowed","windrowing"},
"windscreen":{"windscreen","windscreens"},
"windshield":{"windshield","windshields"},
"windsock":{"windsock","windsocks"},
"windsor":{"windsor","windsors"},
"windup":{"windup","windups"},
"windy":{"windier","windiest","windy"},
"wine":{"wine","wined","wines","wining"},
"wine-colored":{"wine-colored","wine-coloreds"},
"wineberry":{"wineberries","wineberry"},
"winemaker":{"winemaker","winemakers"},
"winery":{"wineries","winery"},
"wing":{"wing","winged","winging","wings"},
"wingspan":{"wingspan","wingspans"},
"wingspread":{"wingspread","wingspreads"},
"wingstem":{"wingstem","wingstems"},
"wingy":{"wingier","wingiest","wingy"},
"wink":{"wink","winked","winking","winks"},
"winker":{"winker","winkers"},
"winkle":{"winkle","winkled","winkles","winkling"},
"winnebago":{"winnebago","winnebagoes","winnebagos"},
"winner":{"winner","winners"},
"winning":{"winning","winnings"},
"winnings":{"winnings","winningses"},
"winnow":{"winnow","winnowed","winnowing","winnows"},
"winnowing":{"winnowing","winnowings"},
"wino":{"wino","winos"},
"winter":{"winter","wintered","wintering","winters"},
"wintera":{"wintera","winteras"},
"winteraceae":{"winteraceae","winteraceaes"},
"winterberry":{"winterberries","winterberry"},
"winterfeed":{"winterfed","winterfeed","winterfeeding","winterfeeds"},
"wintergreen":{"wintergreen","wintergreens"},
"winterize":{"winterize","winterized","winterizing"},
"winterkill":{"winterkill","winterkilled","winterkilling"},
"wintertime":{"wintertime","wintertimes"},
"wintery":{"winterier","winteriest","wintery"},
"wintry":{"wintrier","wintriest","wintry"},
"winy":{"winier","winiest","winy"},
"wipe":{"wipe","wiped","wipes","wiping"},
"wiper":{"wiper","wipers"},
"wire":{"wire","wired","wires","wiring"},
"wiredraw":{"wiredraw","wiredrawing","wiredrawn","wiredraws","wiredrew"},
"wirehair":{"wirehair","wirehairs"},
"wireless":{"wireless","wirelessed","wirelesses","wirelessing"},
"wireman":{"wireman","wiremen"},
"wirephoto":{"wirephoto","wirephotos"},
"wiretap":{"wiretap","wiretapped","wiretapping","wiretaps"},
"wirework":{"wirework","wireworks"},
"wiry":{"wirier","wiriest","wiry"},
"wisconsin":{"wisconsin","wisconsins"},
"wisdom":{"wisdom","wisdoms"},
"wise":{"wise","wiser","wises","wisest"},
"wiseacre":{"wiseacre","wiseacres"},
"wisecrack":{"wisecrack","wisecracked","wisecracking","wisecracks"},
"wiseness":{"wiseness","wisenesses"},
"wisenheimer":{"wisenheimer","wisenheimers"},
"wisent":{"wisent","wisents"},
"wish":{"wish","wished","wishes","wishing"},
"wish-wash":{"wish-wash","wish-washes"},
"wishbone":{"wishbone","wishbones"},
"wishing":{"wishing","wishings"},
"wishy-washy":{"wishy-washier","wishy-washiest","wishy-washy"},
"wisp":{"wisp","wisped","wisping","wisps"},
"wispy":{"wispier","wispiest","wispy"},
"wistaria":{"wistaria","wistarias"},
"wisteria":{"wisteria","wisterias"},
"wit":{"wist","wit","wits","witting"},
"witch":{"witch","witched","witches","witching"},
"witchcraft":{"witchcraft","witchcrafts"},
"witchery":{"witcheries","witchery"},
"witchgrass":{"witchgrass","witchgrasses"},
"witchy":{"witchier","witchiest","witchy"},
"withdraw":{"withdraw","withdrawing","withdrawn","withdrew"},
"withdrawal":{"withdrawal","withdrawals","withdraws"},
"withdrawnness":{"withdrawnness","withdrawnnesses"},
"withe":{"withe","withed","withes","withing"},
"wither":{"wither","withered","withering","withers"},
"withering":{"withering","witherings"},
"withhold":{"withheld","withhold","withholding","withholds"},
"withholding":{"withholding","withholdings"},
"withstand":{"withstand","withstanding","withstands","withstood"},
"withy":{"withies","withy"},
"witloof":{"witloof","witloofs"},
"witness":{"witness","witnessed","witnesses","witnessing"},
"wittgenstein":{"wittgenstein","wittgensteins"},
"witticism":{"witticism","witticisms"},
"wittiness":{"wittiness","wittinesses"},
"witty":{"wittier","wittiest","witty"},
"wive":{"wive","wived","wiving"},
"wivern":{"wivern","wiverns"},
"wiz":{"wiz","wizs"},
"wizard":{"wizard","wizards"},
"wizardry":{"wizardries","wizardry"},
"wmo":{"wmo","wmos"},
"wnw":{"wnw","wnws"},
"wo":{"wo","wos"},
"woadwaxen":{"woadwaxen","woadwaxens"},
"wobble":{"wobble","wobbled","wobbles","wobbling"},
"wobbly":{"wobblier","wobblies","wobbliest","wobbly"},
"wodan":{"wodan","wodans"},
"woden":{"woden","wodens"},
"woe":{"woe","woes"},
"woefulness":{"woefulness","woefulnesses"},
"wold":{"wold","wolds"},
"wolf":{"wolf","wolfed","wolfing","wolfs","wolves"},
"wolfbane":{"wolfbane","wolfbanes"},
"wolffia":{"wolffia","wolffias"},
"wolffiella":{"wolffiella","wolffiellas"},
"wolffish":{"wolffish","wolffishes"},
"wolfman":{"wolfman","wolfmen"},
"wolfram":{"wolfram","wolframs"},
"wolframite":{"wolframite","wolframites"},
"wolfsbane":{"wolfsbane","wolfsbanes"},
"wolly":{"wollies","wolly"},
"wolof":{"wolof","wolofs"},
"wolverine":{"wolverine","wolverines"},
"woman":{"woman","women"},
"woman-worship":{"woman-worship","woman-worships"},
"womanhood":{"womanhood","womanhoods"},
"womaniser":{"womaniser","womanisers"},
"womanishness":{"womanishness","womanishnesses"},
"womanize":{"womanize","womanized","womanizes","womanizing"},
"womanizer":{"womanizer","womanizers"},
"womanlike":{"womanlike","womanlikes"},
"womanliness":{"womanliness","womanlinesses"},
"womanly":{"womanlier","womanliest","womanly"},
"womb":{"womb","wombs"},
"won":{"won","wons"},
"wonder":{"wonder","wondered","wondering","wonders"},
"wonderberry":{"wonderberries","wonderberry"},
"wonderfulness":{"wonderfulness","wonderfulnesses"},
"wonderment":{"wonderment","wonderments"},
"wonk":{"wonk","wonks"},
"wonky":{"wonkier","wonkiest","wonky"},
"wont":{"wont","wonted","wonting","wonts"},
"wonton":{"wonton","wontons"},
"woo":{"woo","wooed","wooing","woos"},
"wood":{"wood","wooded","wooding","woods"},
"wood-fern":{"wood-fern","wood-ferns"},
"woodbine":{"woodbine","woodbines"},
"woodborer":{"woodborer","woodborers"},
"woodcarver":{"woodcarver","woodcarvers"},
"woodchuck":{"woodchuck","woodchucks"},
"woodcock":{"woodcock","woodcocks"},
"woodcreeper":{"woodcreeper","woodcreepers"},
"woodcut":{"woodcut","woodcuts"},
"woodcutter":{"woodcutter","woodcutters"},
"woodfern":{"woodfern","woodferns"},
"woodfrog":{"woodfrog","woodfrogs"},
"woodgraining":{"woodgraining","woodgrainings"},
"woodhewer":{"woodhewer","woodhewers"},
"woodland":{"woodland","woodlands"},
"woodlet":{"woodlet","woodlets"},
"woodlouse":{"woodlouse","woodlouses"},
"woodman":{"woodman","woodmen"},
"woodpecker":{"woodpecker","woodpeckers"},
"woodrat":{"woodrat","woodrats"},
"woodruff":{"woodruff","woodruffs"},
"woods":{"woods","woodses"},
"woodshed":{"woodshed","woodshedded","woodshedding"},
"woodsman":{"woodsman","woodsmen"},
"woodsy":{"woodsier","woodsiest","woodsy"},
"woodwardia":{"woodwardia","woodwardias"},
"woodwaxen":{"woodwaxen","woodwaxens"},
"woodwind":{"woodwind","woodwinds"},
"woodwork":{"woodwork","woodworks"},
"woodworker":{"woodworker","woodworkers"},
"woodworking":{"woodworking","woodworkings"},
"woody":{"woodier","woodiest","woody"},
"wooer":{"wooer","wooers"},
"woof":{"woof","woofed","woofing","woofs"},
"wooing":{"wooing","wooings"},
"wool":{"wool","wools"},
"woolen":{"woolen","woolens"},
"woolgatherer":{"woolgatherer","woolgatherers"},
"woollen":{"woollen","woollens"},
"woolly":{"woollier","woollies","woolliest","woolly"},
"wooly":{"woolier","wooliest","wooly"},
"woomera":{"woomera","woomeras"},
"woozy":{"woozier","wooziest","woozy"},
"wop":{"wop","wops"},
"word":{"word","worded","wording","words"},
"word-painting":{"word-painting","word-paintings"},
"word-splitting":{"word-splitting","word-splittings"},
"word-worship":{"word-worship","word-worships"},
"wordiness":{"wordiness","wordinesses"},
"wording":{"wording","wordings"},
"wordplay":{"wordplay","wordplays"},
"words":{"words","wordses"},
"wordsworth":{"wordsworth","wordsworths"},
"wordy":{"wordier","wordiest","wordy"},
"work":{"work","worked","working","works","wrought"},
"work-clothes":{"work-clothes","work-clotheses"},
"work-clothing":{"work-clothing","work-clothings"},
"workbag":{"workbag","workbags"},
"workbasket":{"workbasket","workbaskets"},
"workbench":{"workbench","workbenches"},
"workbox":{"workbox","workboxes"},
"workday":{"workday","workdays"},
"worker":{"worker","workers"},
"workfellow":{"workfellow","workfellows"},
"workforce":{"workforce","workforces"},
"workhouse":{"workhouse","workhouses"},
"working":{"working","workings"},
"workingman":{"workingman","workingmen"},
"workings":{"workings","workingses"},
"workingwoman":{"workingwoman","workingwomen"},
"workman":{"workman","workmen"},
"workmanship":{"workmanship","workmanships"},
"workout":{"workout","workouts"},
"workplace":{"workplace","workplaces"},
"works":{"works","workses"},
"workshop":{"workshop","workshops"},
"worktable":{"worktable","worktables"},
"workweek":{"workweek","workweeks"},
"workwoman":{"workwoman","workwomen"},
"world":{"world","worlds"},
"world-beater":{"world-beater","world-beaters"},
"world-weariness":{"world-weariness","world-wearinesses"},
"worldliness":{"worldliness","worldlinesses"},
"worldly":{"worldlier","worldliest","worldly"},
"worm":{"worm","wormed","worming","worms"},
"wormseed":{"wormseed","wormseeds"},
"wormy":{"wormier","wormiest","wormy"},
"worrier":{"worrier","worriers"},
"worriment":{"worriment","worriments"},
"worry":{"worried","worries","worry","worrying"},
"worrying":{"worrying","worryings"},
"worrywart":{"worrywart","worrywarts"},
"worsen":{"worsen","worsened","worsening","worsens"},
"worsening":{"worsening","worsenings"},
"worship":{"worship","worshiped","worshiping","worshipped","worshipping","worships"},
"worshiper":{"worshiper","worshipers"},
"worshipper":{"worshipper","worshippers"},
"worthy":{"worthier","worthies","worthiest","worthy"},
"wound":{"wound","wounded","wounding","wounds"},
"wounded":{"wounded","woundeds"},
"wounding":{"wounding","woundings"},
"wow":{"wow","wowed","wowing","wows"},
"wpm":{"wpm","wpms"},
"wrack":{"wrack","wracks"},
"wraith":{"wraith","wraiths"},
"wrangle":{"wrangle","wrangled","wrangles","wrangling"},
"wrangler":{"wrangler","wranglers"},
"wrangling":{"wrangling","wranglings"},
"wrap":{"wrap","wrapped","wrapping","wraps","wrapt"},
"wrapper":{"wrapper","wrappers"},
"wrapping":{"wrapping","wrappings"},
"wrath":{"wrath","wraths"},
"wreak":{"wreak","wreaked","wreaking","wreaks"},
"wreath":{"wreath","wreathed","wreathing","wreaths"},
"wreathe":{"wreathe","wreathed","wreathes","wreathing"},
"wreck":{"wreck","wrecked","wrecking","wrecks"},
"wrecker":{"wrecker","wreckers"},
"wreckfish":{"wreckfish","wreckfishes"},
"wrecking":{"wrecking","wreckings"},
"wren":{"wren","wrens"},
"wren-tit":{"wren-tit","wren-tits"},
"wrench":{"wrench","wrenched","wrenches","wrenching"},
"wrest":{"wrest","wrested","wresting","wrests"},
"wrestle":{"wrestle","wrestled","wrestles","wrestling"},
"wrestler":{"wrestler","wrestlers"},
"wrestling":{"wrestling","wrestlings"},
"wretch":{"wretch","wretches"},
"wretchedness":{"wretchedness","wretchednesses"},
"wrick":{"wrick","wricked","wricking","wricks"},
"wriggle":{"wriggle","wriggled","wriggles","wriggling"},
"wriggler":{"wriggler","wrigglers"},
"wriggly":{"wrigglier","wriggliest","wriggly"},
"wring":{"wring","wringing","wrings","wrung"},
"wrinkle":{"wrinkle","wrinkled","wrinkles","wrinkling"},
"wrinkly":{"wrinklier","wrinkliest","wrinkly"},
"wrist":{"wrist","wrists"},
"wristband":{"wristband","wristbands"},
"wristlet":{"wristlet","wristlets"},
"wristwatch":{"wristwatch","wristwatches"},
"writ":{"writ","writs"},
"write":{"write","writes","writing","written","wrote"},
"write-down":{"write-down","write-downs"},
"write-off":{"write-off","write-offs"},
"writer":{"writer","writers"},
"writhe":{"writhe","writhed","writhes","writhing"},
"writing":{"writing","writings"},
"writings":{"writings","writingses"},
"wroclaw":{"wroclaw","wroclaws"},
"wrong":{"wrong","wronged","wronging","wrongs"},
"wrongdoer":{"wrongdoer","wrongdoers"},
"wrongdoing":{"wrongdoing","wrongdoings"},
"wrongfulness":{"wrongfulness","wrongfulnesses"},
"wrongness":{"wrongness","wrongnesses"},
"wry":{"wried","wrier","wries","wriest","wry","wryer","wryest","wrying"},
"wrymouth":{"wrymouth","wrymouths"},
"wryneck":{"wryneck","wrynecks"},
"wsw":{"wsw","wsws"},
"wtv":{"wtv","wtvs"},
"wu":{"wu","wus"},
"wuerzburg":{"wuerzburg","wuerzburgs"},
"wulfila":{"wulfila","wulfilas"},
"wunderkind":{"wunderkind","wunderkinder","wunderkinds"},
"wurzburg":{"wurzburg","wurzburgs"},
"www":{"www","wwws"},
"wyandot":{"wyandot","wyandots"},
"wyethia":{"wyethia","wyethias"},
"wynnea":{"wynnea","wynneas"},
"wyoming":{"wyoming","wyomings"},
"wyrd":{"wyrd","wyrds"},
"wyvern":{"wyvern","wyverns"},
"x":{"x","xes"},
"x-radiation":{"x-radiation","x-radiations"},
"x-ray":{"x-ray","x-rayed","x-raying","x-rays"},
"x-raying":{"x-raying","x-rayings"},
"xanadu":{"xanadu","xanadus"},
"xanax":{"xanax","xanaxes"},
"xanthemia":{"xanthemia","xanthemias"},
"xanthium":{"xanthium","xanthiums"},
"xanthoma":{"xanthoma","xanthomas","xanthomata"},
"xanthomonas":{"xanthomonas","xanthomonases"},
"xanthophyceae":{"xanthophyceae","xanthophyceaes"},
"xanthophyl":{"xanthophyl","xanthophyls"},
"xanthophyll":{"xanthophyll","xanthophylls"},
"xanthorrhoeaceae":{"xanthorrhoeaceae","xanthorrhoeaceaes"},
"xanthorroea":{"xanthorroea","xanthorroeas"},
"xanthosoma":{"xanthosoma","xanthosomas"},
"xantusiidae":{"xantusiidae","xantusiidaes"},
"xc":{"xc","xcs"},
"xe":{"xe","xes"},
"xenarthra":{"xenarthra","xenarthras"},
"xenicidae":{"xenicidae","xenicidaes"},
"xenicus":{"xenicus","xenicuses"},
"xenogenesis":{"xenogeneses","xenogenesis"},
"xenograft":{"xenograft","xenografts"},
"xenon":{"xenon","xenons"},
"xenopodidae":{"xenopodidae","xenopodidaes"},
"xenopus":{"xenopus","xenopuses"},
"xenorhyncus":{"xenorhyncus","xenorhyncuses"},
"xenosauridae":{"xenosauridae","xenosauridaes"},
"xenosaurus":{"xenosaurus","xenosauruses"},
"xerobates":{"xerobates","xerobateses"},
"xerophile":{"xerophile","xerophiles"},
"xerophyllum":{"xerophyllum","xerophyllums"},
"xerophyte":{"xerophyte","xerophytes"},
"xerox":{"xerox","xeroxed","xeroxes","xeroxing"},
"xhosa":{"xhosa","xhosas"},
"xi":{"xi","xis"},
"xian":{"xian","xians"},
"xii":{"xii","xiis"},
"xiii":{"xiii","xiiis"},
"xiphias":{"xiphias","xiphiases"},
"xiphiidae":{"xiphiidae","xiphiidaes"},
"xiphisternum":{"xiphisterna","xiphisternum"},
"xiphosura":{"xiphosura","xiphosuras"},
"xiv":{"xiv","xivs"},
"xix":{"xix","xixes"},
"xl":{"xl","xls"},
"xmas":{"xmas","xmases"},
"xt":{"xt","xts"},
"xv":{"xv","xvs"},
"xvi":{"xvi","xvis"},
"xvii":{"xvii","xviis"},
"xviii":{"xviii","xviiis"},
"xx":{"xx","xxes"},
"xxi":{"xxi","xxis"},
"xxii":{"xxii","xxiis"},
"xxiii":{"xxiii","xxiiis"},
"xxiv":{"xxiv","xxivs"},
"xxix":{"xxix","xxixes"},
"xxv":{"xxv","xxvs"},
"xxvi":{"xxvi","xxvis"},
"xxvii":{"xxvii","xxviis"},
"xxviii":{"xxviii","xxviiis"},
"xxx":{"xxx","xxxes"},
"xylaria":{"xylaria","xylarias"},
"xylariaceae":{"xylariaceae","xylariaceaes"},
"xylene":{"xylene","xylenes"},
"xylocaine":{"xylocaine","xylocaines"},
"xylocopa":{"xylocopa","xylocopas"},
"xylol":{"xylol","xylols"},
"xylomelum":{"xylomelum","xylomelums"},
"xylophone":{"xylophone","xylophones"},
"xylophonist":{"xylophonist","xylophonists"},
"xylopia":{"xylopia","xylopias"},
"xylose":{"xylose","xyloses"},
"xylosma":{"xylosma","xylosmas"},
"xyphophorus":{"xyphophorus","xyphophoruses"},
"xyridaceae":{"xyridaceae","xyridaceaes"},
"xyridales":{"xyridales","xyridaleses"},
"xyris":{"xyris","xyrises"},
"y-axis":{"y-axes","y-axis"},
"yabber":{"yabber","yabbered","yabbering"},
"yabbie":{"yabbie","yabbies"},
"yabby":{"yabbies","yabby"},
"yacca":{"yacca","yaccas"},
"yacht":{"yacht","yachted","yachting","yachts"},
"yachting":{"yachting","yachtings"},
"yachtsman":{"yachtsman","yachtsmen"},
"yachtswoman":{"yachtswoman","yachtswomen"},
"yack":{"yack","yacks"},
"yafo":{"yafo","yafos"},
"yagi":{"yagi","yagis"},
"yahoo":{"yahoo","yahoos"},
"yahve":{"yahve","yahves"},
"yahveh":{"yahveh","yahvehs"},
"yahwe":{"yahwe","yahwes"},
"yahweh":{"yahweh","yahwehs"},
"yak":{"yak","yakked","yakking","yaks"},
"yakety-yak":{"yakety-yak","yakety-yaks"},
"yakut":{"yakut","yakuts"},
"yale":{"yale","yales"},
"yaltopya":{"yaltopya","yaltopyas"},
"yalu":{"yalu","yalus"},
"yam":{"yam","yams"},
"yamaltu":{"yamaltu","yamaltus"},
"yammer":{"yammer","yammered","yammering","yammers"},
"yangon":{"yangon","yangons"},
"yangtze":{"yangtze","yangtzes"},
"yank":{"yank","yanked","yanking","yanks"},
"yankee":{"yankee","yankees"},
"yankee-doddle":{"yankee-doddle","yankee-doddles"},
"yankeefy":{"yankeefied","yankeefy","yankeefying"},
"yanquapin":{"yanquapin","yanquapins"},
"yanqui":{"yanqui","yanquis"},
"yaounde":{"yaounde","yaoundes"},
"yap":{"yap","yapped","yapping","yaps"},
"yard":{"yard","yarded","yarding","yards"},
"yardgrass":{"yardgrass","yardgrasses"},
"yardman":{"yardman","yardmen"},
"yardmaster":{"yardmaster","yardmasters"},
"yardstick":{"yardstick","yardsticks"},
"yare":{"yare","yarer","yarest"},
"yarmelke":{"yarmelke","yarmelkes"},
"yarmulka":{"yarmulka","yarmulkas"},
"yarmulke":{"yarmulke","yarmulkes"},
"yarn":{"yarn","yarned","yarning","yarns"},
"yarrow":{"yarrow","yarrows"},
"yashmac":{"yashmac","yashmacs"},
"yashmak":{"yashmak","yashmaks"},
"yautia":{"yautia","yautias"},
"yaw":{"yaw","yawed","yawing","yaws"},
"yawn":{"yawn","yawned","yawning","yawns"},
"yaws":{"yaws","yawses"},
"yb":{"yb","ybs"},
"yea":{"yea","yeas"},
"yean":{"yean","yeaned","yeaning"},
"year":{"year","years"},
"yearbook":{"yearbook","yearbooks"},
"yearling":{"yearling","yearlings"},
"yearly":{"yearlies","yearly"},
"yearn":{"yearn","yearned","yearning","yearns"},
"yearning":{"yearning","yearnings"},
"years":{"years","yearses"},
"yeast":{"yeast","yeasts"},
"yeasty":{"yeastier","yeastiest","yeasty"},
"yeats":{"yeats","yeatses"},
"yeddo":{"yeddo","yeddos"},
"yedo":{"yedo","yedos"},
"yell":{"yell","yelled","yelling","yells"},
"yeller":{"yeller","yellers"},
"yelling":{"yelling","yellings"},
"yellow":{"yellow","yellowed","yellower","yellowest","yellowing","yellows"},
"yellow-belly":{"yellow-bellies","yellow-belly"},
"yellowbelly":{"yellowbellies","yellowbelly"},
"yellowbird":{"yellowbird","yellowbirds"},
"yellowfin":{"yellowfin","yellowfins"},
"yellowhammer":{"yellowhammer","yellowhammers"},
"yellowness":{"yellowness","yellownesses"},
"yellowstone":{"yellowstone","yellowstones"},
"yellowtail":{"yellowtail","yellowtails"},
"yellowwood":{"yellowwood","yellowwoods"},
"yelp":{"yelp","yelped","yelping","yelps"},
"yelping":{"yelping","yelpings"},
"yemen":{"yemen","yemens"},
"yen":{"yen","yenned","yenning","yens"},
"yenisei":{"yenisei","yeniseis"},
"yenisei-samoyed":{"yenisei-samoyed","yenisei-samoyeds"},
"yeniseian":{"yeniseian","yeniseians"},
"yenisey":{"yenisey","yeniseys"},
"yenta":{"yenta","yentas"},
"yeoman":{"yeoman","yeomen"},
"yes":{"yes","yeses","yessed","yessing"},
"yes-man":{"yes-man","yes-men"},
"yeshiva":{"yeshiva","yeshivahs","yeshivoth"},
"yesterday":{"yesterday","yesterdays"},
"yesteryear":{"yesteryear","yesteryears"},
"yeti":{"yeti","yetis"},
"yew":{"yew","yews"},
"yezo":{"yezo","yezos"},
"yi":{"yi","yis"},
"yield":{"yield","yielded","yielding","yields"},
"yielding":{"yielding","yieldings"},
"yip":{"yip","yipped","yipping","yips"},
"yisrael":{"yisrael","yisraels"},
"ylang-ylang":{"ylang-ylang","ylang-ylangs"},
"yo-yo":{"yo-yo","yo-yos"},
"yob":{"yob","yobs"},
"yobbo":{"yobbo","yobbos"},
"yobo":{"yobo","yobos"},
"yock":{"yock","yocked","yocking"},
"yodel":{"yodel","yodeled","yodeling","yodelled","yodelling","yodels"},
"yoghourt":{"yoghourt","yoghourts"},
"yoghurt":{"yoghurt","yoghurts"},
"yogi":{"yogi","yogin","yogis"},
"yogurt":{"yogurt","yogurts"},
"yoke":{"yoke","yoked","yokes","yoking"},
"yokel":{"yokel","yokels"},
"yokuts":{"yokuts","yokutses"},
"yolk":{"yolk","yolks"},
"yoni":{"yoni","yonis"},
"yore":{"yore","yores"},
"york":{"york","yorks"},
"yoruba":{"yoruba","yorubas"},
"yosemite":{"yosemite","yosemites"},
"young":{"young","younger","youngest","youngs"},
"youngberry":{"youngberries","youngberry"},
"youngster":{"youngster","youngsters"},
"younker":{"younker","younkers"},
"yourself":{"yourself","yourselves"},
"youth":{"youth","youths"},
"youth-on-age":{"youth-on-age","youth-on-ages"},
"youthfulness":{"youthfulness","youthfulnesses"},
"yowl":{"yowl","yowled","yowling","yowls"},
"yowling":{"yowling","yowlings"},
"ypres":{"ypres","ypreses"},
"yr":{"yr","yrs"},
"ytterbite":{"ytterbite","ytterbites"},
"ytterbium":{"ytterbium","ytterbiums"},
"yttrium":{"yttrium","yttriums"},
"yuan":{"yuan","yuans"},
"yucatan":{"yucatan","yucatans"},
"yucatec":{"yucatec","yucatecs"},
"yucateco":{"yucateco","yucatecos"},
"yucca":{"yucca","yuccas"},
"yue":{"yue","yues"},
"yugoslav":{"yugoslav","yugoslavs"},
"yugoslavia":{"yugoslavia","yugoslavias"},
"yugoslavian":{"yugoslavian","yugoslavians"},
"yuk":{"yuk","yukked","yukking"},
"yukon":{"yukon","yukons"},
"yule":{"yule","yules"},
"yuletide":{"yuletide","yuletides"},
"yummy":{"yummier","yummiest","yummy"},
"yurak-samoyed":{"yurak-samoyed","yurak-samoyeds"},
"z":{"z","zs"},
"z-axis":{"z-axes","z-axis"},
"zaar":{"zaar","zaars"},
"zabaglione":{"zabaglione","zabagliones"},
"zag":{"zag","zags"},
"zaglossus":{"zaglossus","zaglossuses"},
"zaire":{"zaire","zaires"},
"zairean":{"zairean","zaireans"},
"zairese":{"zairese","zaireses"},
"zalophus":{"zalophus","zalophuses"},
"zama":{"zama","zamas"},
"zaman":{"zaman","zamen"},
"zamang":{"zamang","zamangs"},
"zambezi":{"zambezi","zambezis"},
"zamia":{"zamia","zamias"},
"zamiaceae":{"zamiaceae","zamiaceaes"},
"zamindari":{"zamindari","zamindaris"},
"zannichellia":{"zannichellia","zannichellias"},
"zannichelliaceae":{"zannichelliaceae","zannichelliaceaes"},
"zantac":{"zantac","zantacs"},
"zantedeschia":{"zantedeschia","zantedeschias"},
"zanthoxylum":{"zanthoxylum","zanthoxylums"},
"zany":{"zanies","zany"},
"zap":{"zap","zapped","zapping","zaps"},
"zapateado":{"zapateado","zapateados"},
"zapodidae":{"zapodidae","zapodidaes"},
"zapotec":{"zapotec","zapotecs"},
"zapus":{"zapus","zapuses"},
"zaragoza":{"zaragoza","zaragozas"},
"zarathustra":{"zarathustra","zarathustras"},
"zareba":{"zareba","zarebas"},
"zarontin":{"zarontin","zarontins"},
"zarpanit":{"zarpanit","zarpanits"},
"zarzuela":{"zarzuela","zarzuelas"},
"zea":{"zea","zeas"},
"zeal":{"zeal","zeals"},
"zealand":{"zealand","zealands"},
"zealot":{"zealot","zealots"},
"zealotry":{"zealotries","zealotry"},
"zebra":{"zebra","zebras"},
"zebrawood":{"zebrawood","zebrawoods"},
"zebu":{"zebu","zebus"},
"zecchino":{"zecchini","zecchino"},
"zed":{"zed","zeds"},
"zee":{"zee","zees"},
"zeidae":{"zeidae","zeidaes"},
"zelkova":{"zelkova","zelkovas"},
"zemindari":{"zamindaris","zemindari"},
"zemstvo":{"zemstvo","zemstvos"},
"zen":{"zen","zens"},
"zenaidura":{"zenaidura","zenaiduras"},
"zenana":{"zenana","zenanas"},
"zend":{"zend","zends"},
"zend-avesta":{"zend-avesta","zend-avestas"},
"zendo":{"zendo","zendos"},
"zenith":{"zenith","zeniths"},
"zeno":{"zeno","zenos"},
"zeomorphi":{"zeomorphi","zeomorphis"},
"zep":{"zep","zeps"},
"zephyr":{"zephyr","zephyrs"},
"zeppelin":{"zeppelin","zeppelins"},
"zero":{"zero","zeroed","zeroes","zeroing","zeros"},
"zest":{"zest","zests"},
"zestfulness":{"zestfulness","zestfulnesses"},
"zestril":{"zestril","zestrils"},
"zesty":{"zestier","zestiest","zesty"},
"zeta":{"zeta","zetas"},
"zetland":{"zetland","zetlands"},
"zeus":{"zeus","zeuses"},
"zho":{"zho","zhos"},
"zidovudine":{"zidovudine","zidovudines"},
"zig":{"zig","zigs"},
"zigadene":{"zigadene","zigadenes"},
"zigadenus":{"zigadenus","zigadenuses"},
"zigzag":{"zigzag","zigzagged","zigzagging","zigzags"},
"zilch":{"zilch","zilches"},
"zillion":{"zillion","zillions"},
"zillions":{"zillions","zillionses"},
"zimbabwe":{"zimbabwe","zimbabwes"},
"zinacef":{"zinacef","zinacefs"},
"zinc":{"zinc","zinced","zincing","zincked","zincking","zincs"},
"zing":{"zing","zinged","zinging","zings"},
"zingiber":{"zingiber","zingibers"},
"zingiberaceae":{"zingiberaceae","zingiberaceaes"},
"zingy":{"zingier","zingiest","zingy"},
"zinjanthropus":{"zinjanthropus","zinjanthropuses"},
"zinnia":{"zinnia","zinnias"},
"zion":{"zion","zions"},
"zip":{"zip","zipped","zipping","zips"},
"zip-fastener":{"zip-fastener","zip-fasteners"},
"ziphiidae":{"ziphiidae","ziphiidaes"},
"zipper":{"zipper","zippers"},
"zippy":{"zippier","zippies","zippiest","zippy"},
"zirbanit":{"zirbanit","zirbanits"},
"zircon":{"zircon","zircons"},
"zirconia":{"zirconia","zirconias"},
"zirconium":{"zirconium","zirconiums"},
"zither":{"zither","zithers"},
"zithern":{"zithern","zitherns"},
"zizania":{"zizania","zizanias"},
"ziziphus":{"ziziphus","ziziphuses"},
"zloty":{"zloty","zlotys"},
"zn":{"zn","zns"},
"zo":{"zo","zos"},
"zoaea":{"zoaea","zoaeae","zoaeas"},
"zoarces":{"zoarces","zoarceses"},
"zoarcidae":{"zoarcidae","zoarcidaes"},
"zoea":{"zoaeae","zoea","zoeae","zoeas"},
"zoisia":{"zoisia","zoisias"},
"zola":{"zola","zolas"},
"zombi":{"zombi","zombis"},
"zombie":{"zombie","zombies"},
"zone":{"zone","zoned","zones","zoning"},
"zonotrichia":{"zonotrichia","zonotrichias"},
"zoo":{"zoo","zoos"},
"zooerastia":{"zooerastia","zooerastias"},
"zooerasty":{"zooerasties","zooerasty"},
"zooflagellate":{"zooflagellate","zooflagellates"},
"zoogloea":{"zoogloea","zoogloeae","zoogloeas"},
"zoolatry":{"zoolatries","zoolatry"},
"zoologist":{"zoologist","zoologists"},
"zoology":{"zoologies","zoology"},
"zoom":{"zoom","zoomed","zooming","zooms"},
"zoomastigina":{"zoomastigina","zoomastiginas"},
"zoomastigote":{"zoomastigote","zoomastigotes"},
"zoon":{"zoa","zoon","zoons"},
"zoonosis":{"zoonoses","zoonosis"},
"zooplasty":{"zooplasties","zooplasty"},
"zoosporangium":{"zoosporangia","zoosporangium"},
"zori":{"zori","zoris"},
"zoril":{"zoril","zorils"},
"zorille":{"zorille","zorilles"},
"zoroaster":{"zoroaster","zoroasters"},
"zoroastrianism":{"zoroastrianism","zoroastrianisms"},
"zoster":{"zoster","zosters"},
"zostera":{"zostera","zosteras"},
"zosteraceae":{"zosteraceae","zosteraceaes"},
"zovirax":{"zovirax","zoviraxes"},
"zr":{"zr","zrs"},
"zu":{"zu","zus"},
"zubird":{"zubird","zubirds"},
"zucchetto":{"zucchetti","zucchetto","zucchettos"},
"zucchini":{"zucchini","zucchinis"},
"zulu":{"zulu","zulus"},
"zwieback":{"zwieback","zwiebacks"},
"zygapophysis":{"zygapophyses","zygapophysis"},
"zygnema":{"zygnema","zygnemas"},
"zygnemales":{"zygnemales","zygnemaleses"},
"zygnemataceae":{"zygnemataceae","zygnemataceaes"},
"zygnematales":{"zygnematales","zygnemataleses"},
"zygocactus":{"zygocactus","zygocactuses"},
"zygoma":{"zygoma","zygomas","zygomata"},
"zygomycetes":{"zygomycetes","zygomyceteses"},
"zygomycota":{"zygomycota","zygomycotas"},
"zygomycotina":{"zygomycotina","zygomycotinas"},
"zygophyllaceae":{"zygophyllaceae","zygophyllaceaes"},
"zygophyllum":{"zygophyllum","zygophyllums"},
"zygoptera":{"zygoptera","zygopteras"},
"zygote":{"zygote","zygotes"},
"zyloprim":{"zyloprim","zyloprims"},
"zymolysis":{"zymolyses","zymolysis"},
"zymosis":{"zymoses","zymosis"},
"zyrian":{"zyrian","zyrians"}
}