confu_set = {
"able":{"ability"},
"ability":{"abilities","able"},
"abler":{"ably","ablest","able"},
"ablest":{"ably","able"},
"ably":{"abler","inability","unable","ably","ablest","abilities","ability","able"},
"abilities":{"abler","inability","unable","ably","ablest","abilities","ability","able"},
"unable":{"inability"},
"inability":{"unable"},
"accept":{"accepts","accepting","accepted","acceptance","acceptability","acceptable"},
"acceptability":{"accepts","accepting","accepted","acceptance","unacceptable","accept","acceptability","acceptable"},
"acceptable":{"accepts","accepting","accepted","acceptance","accept","acceptability"},
"acceptance":{"accepts","accepting","accepted","accept","acceptability","acceptable"},
"accepted":{"accepts","accepting","acceptance","accept","acceptability","acceptable"},
"accepting":{"accepts","accepting","accepted","acceptance","accept","acceptability","acceptable"},
"accepts":{"accepting","accepted","acceptance","accept","acceptability","acceptable"},
"accord":{"accord","accorded","accordance","according","accordingly","accords"},
"accorded":{"accord","accordance","according","accordingly","accords"},
"accordance":{"accord","accorded","according","accordingly","accords"},
"according":{"accord","accorded","accordance","accordingly","accords"},
"accordingly":{"accord","accorded","accordance","according","accords"},
"accords":{"accord","accorded","accordance","according","accordingly"},
"account":{"accountants","accounts","accountant","accounting","accountancy","accounted"},
"accounted":{"accountants","accounts","accountant","account","accounting","accountancy"},
"accounting":{"accountants","accounts","accountant","account","accountancy","accounted"},
"accounts":{"accountants","accountant","account","accounting","accountancy","accounted"},
"accountant":{"accountants","accounts","account","accounting","accountancy","accounted"},
"accountants":{"accounts","accountant","account","accounting","accountancy","accounted"},
"accountancy":{"accountants","accounts","accountant","account","accounting","accounted"},
"accountable":{"accountability"},
"accountability":{"accountable"},
"act":{"acts","actions","action","acting","acted"},
"acted":{"acts","actions","action","acting","act"},
"acting":{"acts","action","acted","act"},
"action":{"acts","actions","acting","acted","act"},
"actions":{"acts","action","acting","acted","act"},
"acts":{"actions","action","acting","acted","act"},
"active":{"activity","activities","actively"},
"actively":{"activity","activities","active"},
"activities":{"activity","actively","active"},
"activity":{"activities","actively","active"},
"actor":{"actors"},
"actors":{"actor"},
"actress":{"actresses"},
"actresses":{"actress"},
"actual":{"actually"},
"actually":{"actual"},
"add":{"additions","adding","added","adds"},
"added":{"adding","add","adds"},
"adding":{"added","add","adds","addition"},
"addition":{"additions","adding","added","add","adds"},
"additional":{"additions","additive","additional","adding","added","add","adds","addition"},
"additive":{"additional"},
"additions":{"adding","added","add","adds","addition"},
"adds":{"additions","adding","added","add","adds","addition"},
"address":{"addressed","address","addresses","addressing"},
"addressed":{"addressed","address","addresses","addressing"},
"addresses":{"addressed","address","addresses","addressing"},
"addressing":{"addressed","address","addresses","addressing"},
"admit":{"admitting","admit","admission","admittedly","admits","admitted"},
"admission":{"admitting","admit","admittedly","admits","admitted"},
"admittedly":{"admitting","admit","admission","admits","admitted"},
"admits":{"admitting","admit","admission","admittedly","admitted"},
"admitted":{"admitting","admit","admission","admittedly","admits",""},
"admitting":{"admit","admission","admittedly","admits","admitted"},
"adopt":{"adopts","adoptions","adoption","adopting","adopted"},
"adopted":{"adopts","adoptions","adoption","adopting","adopt"},
"adopting":{"adopts","adoptions","adoption","adopted","adopt"},
"adoption":{"adopts","adoptions","adopting","adopted","adopt"},
"adoptions":{"adopts","adoption","adopting","adopted","adopt"},
"adopts":{"adoptions","adoption","adopting","adopted","adopt"},
"advance":{"advanced","advances","advancement","advancing"},
"advanced":{"advance","advances","advancement","advancing"},
"advances":{"advance","advanced","advancement","advancing"},
"advancement":{"advance","advanced","advances","advancing"},
"advancing":{"advance","advanced","advances","advancement"},
"advantage":{"disadvantaged","advantaged","advantaging","advantages","advantage"},
"advantages":{"disadvantaged","advantaged","advantaging","disadvantage","advantages","advantage"},
"disadvantage":{"disadvantaged","disadvantages"},
"disadvantages":{"advantaged","advantaging","disadvantage","advantages","advantage"},
"advantaging":{"advantaged","advantages","advantage"},
"advantaged":{"advantaging","advantages"},
"disadvantaged":{"disadvantages","disadvantage"},
"adventure":{"adventures","adventurer","adventurers","adventurous"},
"adventures":{"adventure","adventures","adventurer","adventurous"},
"adventurer":{"adventure","adventures","adventurers","adventurous"},
"adventurers":{"adventure","adventurer","adventurers","adventurous"},
"adventurous":{"adventure","adventures","adventurer","adventurers"},
"affair":{"affairs"},
"affairs":{"affair"},
"after":{"afterwards"},
"afterwards":{"after"},
"age":{"aged","ages","aging"},
"aged":{"age","ages","aging"},
"ages":{"age","aged","aging"},
"aging":{"age","aged","ages"},
"agent":{"agents","agencies","agency"},
"agency":{"agents","agencies","agent"},
"agencies":{"agents","agency","agent"},
"agents":{"agencies","agency","agent"},
"agree":{"agrees","agreed","agreeing","agreement","disagrees","agreements","agreeable"},
"agreed":{"agrees","agree","agreeing","agreement","agreements","disagreeable","agreeable"},
"agreeing":{"agrees","agree","agreed","agreement","agreements","disagreeable","agreeable"},
"agreement":{"agrees","agree","agreed","agreeing","agreements","disagreeable","agreeable"},
"agreements":{"agrees","agree","agreed","agreeing","agreement","agreeable"},
"agrees":{"agrees","agree","agreed","agreeing","agreement","agreements","agreeable"},
"agreeable":{"agrees","agree","agreed","agreeing","agreement","agreements","agreeable"},
"disagreements":{"disagreement","disagrees","disagreeable","disagree","disagreed","disagreeing","disagreements"},
"disagree":{"disagreement","disagrees","disagreeable","disagree","disagreed","disagreeing","disagreements"},
"disagreeable":{"disagreement","disagrees","disagreeable","disagree","disagreed","disagreeing","disagreements"},
"disagreed":{"disagreement","disagrees","disagreeable","disagree","disagreed","disagreeing","disagreements"},
"disagreeing":{"disagreement","disagrees","disagreeable","disagree","disagreed","disagreeing","disagreements"},
"disagreement":{"disagreement","disagrees","disagreeable","disagree","disagreed","disagreeing","disagreements"},
"disagrees":{"disagreement","disagreeable","disagree","disagreed","disagreeing","disagreements"},
"allow":{"allowed","allows","allowing"},
"allowance":{"allowances"},
"allowances":{"allowance","allowances"},
"allowed":{"allows","allowing","allow"},
"allowing":{"allowed","allows","allow"},
"allows":{"allowed","allowing","allow"},
"among":{"amongst"},
"amongst":{"among"},
"amount":{"amounting","amounts","amounted"},
"amounted":{"amounting","amounts","amount"},
"amounting":{"amounts","amounted","amount"},
"amounts":{"amounting","amounted","amount"},
"animal":{"animals"},
"animals":{"animal"},
"answer":{"answered","answering","answers"},
"answered":{"answering","answers","answer"},
"answering":{"answered","answers","answer"},
"answers":{"answered","answering","answer"},
"any":{"anywhere","anyway","anything","anyone","anyhow","anybody","anymore"},
"anybody":{"anywhere","anyway","anything","anyone","anyhow","anymore","any"},
"anyhow":{"anywhere","anyway","anything","anyone","anybody","anymore","any"},
"anymore":{"anywhere","anyway","anything","anyone","anyhow","anybody","any"},
"anyone":{"anywhere","anyway","anything","anyhow","anybody","anymore","any"},
"anything":{"anywhere","anyway","anyone","anyhow","anybody","anymore","any"},
"anyway":{"anywhere","anything","anyone","anyhow","anybody","anymore","any"},
"anywhere":{"anyway","anything","anyone","anyhow","anybody","anymore","any"},
"appear":{"appearing","appeared","appears","appearances","appearance",""},
"appearance":{"appearing","appeared","appears","appearances","appearance","appear"},
"appeared":{"appearing","appears","appearances","appearance","appear"},
"appearing":{"appeared","appears","appearances","disappearances","appearance","appear"},
"appears":{"appearing","appeared","appearances","appearance","appear"},
"appearances":{"appearing","appeared","appears","appearance","appear"},
"disappearances":{"disappearing","disappears","disappearances","disappear","disappearance","disappeared"},
"disappear":{"disappearing","disappears","disappearances","disappear","disappearance","disappeared"},
"disappearance":{"disappearing","disappears","disappearances","disappear","disappearance","disappeared"},
"disappeared":{"disappearing","disappears","disappearances","disappear","disappearance","disappeared"},
"disappearing":{"disappears","disappearances","disappear","disappearance","disappeared"},
"disappears":{"disappearing","disappearances","disappear","disappearance","disappeared"},
"apply":{"applicable","applicant","applying","applicability","applies","applied","applications","application"},
"application":{"applicable","applicant","applying","applicability","applies","applied","applications","apply"},
"applications":{"applicable","applicant","applying","applicability","applies","applied","application","apply"},
"applied":{"applying","applicability","applies","applications","application","apply"},
"applies":{"applicable","applying","applicability","applied","apply"},
"applicable":{"applying","applicability","applies","applied","apply"},
"applying":{"applicable","applicability","applies","applied","apply"},
"applicant":{"applications","application","applicants"},
"applicants":{"applicant","application"},
"applicability":{"applicable","applying","applies","applied","apply"},
"appoint":{"appointment","appoints","appointments","appointing","appointed"},
"appointed":{"appointment","appoints","appointments","appointing","appoint"},
"appointing":{"appointment","appoints","appointments","appointed","appoint"},
"appointments":{"appointment","appoints","appointing","appointed","appoint"},
"appointment":{"appoints","appointments","appointing","appointed","appoint"},
"appoints":{"appointment","appointments","appointing","appointed","appoint"},
"arise":{"arose","arising","arises","arisen"},
"arisen":{"arose","arising","arises","arise"},
"arises":{"arose","arising","arisen","arise"},
"arose":{"arising","arises","arisen","arise"},
"arising":{"arose","arises","arisen","arise"},
"arm":{"armed","arms","arm"},
"armed":{"armed","arms","arm"},
"arms":{"armed","arm"},
"unarmed":{"armed","arms","arm"},
"army":{"armies"},
"armies":{"army"},
"arrive":{"arrives","arrival","arrivals","arrived","arriving"},
"arrival":{"arrives","arrive","arrivals","arrived","arriving"},
"arrivals":{"arrives","arrive","arrival","arrived","arriving"},
"arrived":{"arrives","arrive","arrival","arrivals","arriving"},
"arrives":{"arrive","arrival","arrivals","arrived","arriving"},
"arriving":{"arrives","arrive","arrival","arrivals","arrived"},
"art":{"artists","artistic","arts","artist"},
"arts":{"artists","artistic","art","artist"},
"artist":{"artists","artistic","arts","art"},
"artistic":{"artists","arts","art","artist"},
"artists":{"artistic","arts","art","artist"},
"artistically":{"artists","artistic","arts","art","artist"},
"article":{"articles"},
"articles":{"article"},
"ask":{"asks","asked","asking"},
"asked":{"asks","ask","asking"},
"asking":{"asks","ask","asked"},
"asks":{"ask","asked","asking"},
"associate":{"associated","association","associating","associates","associations"},
"associations":{"associated","associate","association","associating","associates"},
"association":{"associated","associate","associating","associates","associations"},
"associating":{"associated","associate","association","associates","associations"},
"associates":{"associated","associate","association","associating","associations"},
"associated":{"associate","association","associating","associates","associations"},
"disassociate":{"disassociated"},
"disassociated":{"disassociate"},
"attack":{"attacked","attacking","attacks"},
"attacked":{"attack","attacking","attacks"},
"attacking":{"attack","attacked","attacks"},
"attacks":{"attack","attacked","attacking"},
"attempt":{"attempting","attempts","attempted"},
"attempted":{"attempting","attempts","attempt"},
"attempting":{"attempts","attempted","attempt"},
"attempts":{"attempting","attempted","attempt"},
"average":{"averaged","averages","averaging"},
"averaged":{"averages","average","averaging"},
"averages":{"averaged","average","averaging"},
"averaging":{"averaged","averages","average"},
"back":{"backs"},
"backed":{"back","backed","backing","backs"},
"background":{"backgrounds"},
"backing":{"back","backed","backs","backwards","backward"},
"backs":{"","back","backed","backing"},
"backbone":{"back","backs"},
"backgrounds":{"background"},
"backwards":{"back","backwards","backward"},
"backward":{"backbone","back","backed","background","backing","backs","backgrounds","backwards","backward"},
"bad":{"badly","badness"},
"badly":{"badness","bad"},
"badness":{"badly","bad"},
"ball":{"balls"},
"balls":{"ball"},
"bank":{"bankers","banking","banker","banks","banked"},
"banked":{"bankers","banking","banker","banks","bank"},
"banker":{"bankers","banking","banks","banked","bank"},
"bankers":{"banking","banker","banks","banked","bank"},
"banking":{"bankers","banker","banks","banked","bank"},
"banks":{"bankers","banking","banker","banked","bank"},
"bar":{"barred","barring","bars"},
"bars":{"barred","bar","barring"},
"barred":{"bar","barring","bars"},
"barring":{"barred","bar","bars"},
"base":{"basing","basis","basic","based","basically","bases"},
"based":{"basing","basis","basic","basically","base","bases"},
"bases":{"basing","basis","basic","based","basically","base"},
"basic":{"basing","basis","based","basically","base","bases"},
"basically":{"basing","basis","basic","based","base","bases"},
"basing":{"basis","basic","based","basically","base","bases"},
"basis":{"basing","basic","based","basically","base","bases"},
"battle":{"battling","battled","battles"},
"battled":{"battle","battling","battles"},
"battles":{"battle","battling","battled"},
"battling":{"battle","battling","battled","battles"},
"be":{"beings","are","being","were","is","been","am","be","was"},
"am":{"beings","are","isn","being","weren","were","is","been","aren","re","s","am","be","was","wasn"},
"are":{"beings","being","were","is","been","am","be","was"},
"been":{"beings","are","being","were","is","am","be","was"},
"is":{"beings","are","being","were","been","am","be","was"},
"was":{"beings","are","being","weren","were","is","been","aren","am","be"},
"were":{"beings","are","being","is","been","am","be","was"},
"being":{"are","were","is","been","am","be","was"},
"beings":{"are","being","were","is","been","am","be","was"},
"bear":{"born","bears","bearings","bearing","borne","bore"},
"bearing":{"born","bears","borne","bear","bore"},
"bearings":{"born","bears","borne","bear","bore"},
"bears":{"born","bearings","bearing","borne","bear","bore"},
"bore":{"born","bears","bearings","bearing","borne","bear"},
"born":{"bears","bearings","bearing","borne","bear","bore"},
"borne":{"born","bears","bear","bore"},
"beauty":{"beautiful"},
"beautiful":{"beauty","beautifully"},
"beautifully":{"beautiful","beauty"},
"become":{"became","becomes","becoming"},
"became":{"become","becomes","becoming"},
"becomes":{"become","became","becoming"},
"becoming":{"become","became","becomes"},
"bed":{"bedding","beds","bedroom","bedrooms"},
"bedroom":{"bedding","beds","bed","bedrooms"},
"bedrooms":{"bedding","beds","bedroom","bed"},
"bedding":{"beds","bedroom","bed","bedrooms"},
"beds":{"bedding","bedroom","bed","bedrooms"},
"begin":{"beginnings","began","beginner","beginners","begins","beginning","begun"},
"began":{"beginnings","begin","beginner","beginners","begins","beginning","begun"},
"beginner":{"beginnings","begin","began","beginners","begins","beginning","begun"},
"beginners":{"beginnings","begin","began","beginner","begins","beginning","begun"},
"beginning":{"beginnings","begin","began","beginner","beginners","begins","begun"},
"beginnings":{"begin","began","beginner","beginners","begins","beginning","begun"},
"begins":{"beginnings","begin","began","beginner","beginners","beginning","begun"},
"begun":{"beginnings","begin","began","beginner","beginners","begins","beginning"},
"believe":{"belief","believes","believed","believing","disbelief","beliefs"},
"belief":{"believe","believes","believed","believing","beliefs"},
"beliefs":{"believe","belief","believes","believed","believing"},
"believed":{"believe","belief","believes","believing","disbelief","beliefs"},
"believes":{"believe","belief","believed","believing","disbelief","beliefs"},
"believing":{"believe","belief","believes","believed","disbelief","beliefs"},
"belong":{"belongings","belonged","belonging","belongs"},
"belonged":{"belong","belongings","belonging","belongs"},
"belonging":{"belong","belongings","belonged","belonging","belongs"},
"belongings":{"belong","belonged","belonging","belongs"},
"belongs":{"belong","belongings","belonged","belonging"},
"beside":{"besides"},
"besides":{"beside"},
"best":{"better"},
"better":{"best"},
"big":{"bigger","biggest","biggish"},
"bigger":{"big","biggest","biggish"},
"biggest":{"big","bigger","biggish"},
"biggish":{"big","bigger","biggest"},
"bill":{"billing","billed","bills"},
"bills":{"billing","billed","bill"},
"billed":{"billing","bills","bill"},
"billing":{"billed","bills","bill"},
"bird":{"birds"},
"birds":{"bird"},
"black":{"blackish","blacks","blackness","blacken","blackly","blackest","blacker"},
"blacker":{"blackish","blacks","blackness","blacken","blackly","blackest","black"},
"blackest":{"blackish","blacks","blackness","blacken","blackly","blacker","black"},
"blackly":{"blackish","blacks","blackness","blacken","blackest","blacker","black"},
"blacken":{"blackish","blacks","blackness","blackly","blackest","blacker","black"},
"blackness":{"blackish","blacks","blacken","blackly","blackest","blacker","black"},
"blacks":{"blackish","blackness","blacken","blackly","blackest","blacker","black"},
"blackish":{"blacks","blackness","blacken","blackly","blackest","blacker","black"},
"blood":{"bleed","bleeding","bleeds","bloody","bled"},
"bled":{"blood","bleed","bleeding","bleeds","bloody"},
"bleed":{"blood","bbleeding","bleeds","bloody","bled"},
"bleeding":{"blood","bleed","bleeds","bloody","bled"},
"bleeds":{"blood","bleed","bleeding","bloody","bled"},
"bloody":{"blood","bleed","bleeding","bleeds","bled"},
"blow":{"blown","blows","blowing","blew"},
"blew":{"blown","blows","blowing","blow"},
"blowing":{"blown","blows","blew","blow"},
"blows":{"blown","blowing","blew","blow"},
"blown":{"blows","blowing","blew","blow"},
"blue":{"bluest","bluer","blueness"},
"blueness":{"bluest","bluer","","blue"},
"bluer":{"bluest","blueness","blue"},
"bluest":{"bluer","blueness","blue"},
"board":{"boarded","boarding","boards"},
"boarded":{"boarding","boards","board"},
"boarding":{"boarded","boards","board"},
"boards":{"boarded","boarding","board"},
"boat":{"boats"},
"boats":{"boat"},
"body":{"bodies","bodily"},
"bodies":{"body","bodily"},
"bodily":{"bodies","body"},
"book":{"books"},
"books":{"book"},
"box":{"boxes"},
"boxes":{"box"},
"boy":{"boys","boyhood"},
"boyhood":{"boy","boys"},
"boys":{"boy","boyhood"},
"branch":{"branches","branching","branched"},
"branches":{"branching","branched","branch"},
"branched":{"branches","branching","branch"},
"branching":{"branches","branched","branch"},
"break":{"breaking","outbreaks","unbreakable","broken","broke","breaks","breakage","unbroken","outbreak"},
"breaking":{"outbreaks","broken","broke","breaks","breakage","break","outbreak"},
"breakage":{"breaking","outbreaks","unbreakable","broken","broke","breaks","break","outbreak"},
"breaks":{"breaking","outbreaks","unbreakable","broken","broke","breakage","break","outbreak"},
"broke":{"breaking","outbreaks","unbreakable","broken","breaks","breakage","break","outbreak"},
"broken":{"breaking","outbreaks","broken","broke","breaks","breakage","break","outbreak"},
"unbreakable":{"unbroken"},
"outbreaks":{"breaking","broken","broke","breaks","breakage","break","outbreak"},
"outbreak":{"breaking","outbreaks","broken","broke","breaks","breakage","break"},
"unbroken":{"breaking","outbreaks","unbreakable","broken","broke","breaks","breakage","break","outbreak"},
"bridge":{"bridges"},
"bridges":{"bridge"},
"bright":{"brighter","brighten","brightened","brightening","brightens","brightest","brightly","brightness"},
"brighten":{"bright","brighter","brightened","brightening","brightens","brightest","brightly","brightness"},
"brightened":{"bright","brighter","brighten","rightening","brightens","brightest","brightly","brightness"},
"brightening":{"bright","brighter","brighten","brightened","brightens","brightest","brightly","brightness"},
"brightens":{"bright","brighter","brightened","brightening","brightens","brightest","brightly","brightness"},
"brighter":{"bright","brighten","brightened","brightening","brightens","brightest","brightly","brightness"},
"brightest":{"bright","brighter","brighten","brightened","brightening","brightens","brightly","brightness"},
"brightly":{"bright","brighter","brighten","brightened","brightening","brightens","brightest","brightness"},
"brightness":{"bright","brighter","brighten","brightened","brightening","brightens","brightest","brightly",""},
"bring":{"brought","bringing","brings"},
"bringing":{"brought","brings","bring"},
"brings":{"brought","bringing","bring"},
"brought":{"bringing","brings","bring"},
"broad":{"broadest","broader","breadth","broadly"},
"broadly":{"broadest","broader","breadth","broad"},
"breadth":{"broadest","broader","broadly","broad"},
"broader":{"broadest","breadth","broadly","broad"},
"broadest":{"broader","breadth","broadly","broad"},
"brother":{"brothers","brotherly"},
"brothers":{"brotherly","brother"},
"brotherly":{"brothers","brother"},
"build":{"build-up","built","builds","buildings","builders","building"},
"build-up":{"built","builds","buildings","builders","build","building"},
"builders":{"build-up","built","builds","buildings","build","building"},
"building":{"build-up","built","builds","buildings","build"},
"buildings":{"build-up","built","builds","builders","build","building"},
"builds":{"build-up","built","buildings","builders","build","building"},
"built":{"build-up","builds","buildings","builders","build","building"},
"burn":{"burned","burnt","burns","burning"},
"burned":{"burnt","burns","burn","burning"},
"burning":{"burned","burnt","burns","burn"},
"burns":{"burned","burnt","burn","burning"},
"burnt":{"burned","burns","burn","burning"},
"business":{"businesses","businesslike"},
"businesses":{"business","businesses","","businesslike"},
"businessmen":{"businesswoman","businessmen","businessman","businesswomen"},
"businesslike":{"business","businesses"},
"businessman":{"businesswoman","business","businesses","businessmen","businesswomen"},
"businesswoman":{"businessmen","businessman"},
"businesswomen":{"businesswoman","business","businesses","businessmen","businessman"},
"buy":{"bought","buying","buys","buyer","buyers"},
"bought":{"buy","buying","buys","buyer","buyers"},
"buying":{"buy","bought","buys","buyer","buyers"},
"buys":{"buy","bought","buying","buyer","buyers"},
"buyer":{"buy","bought","buying","buys","buyer"},
"buyers":{"buy","bought","buying","buys","buyer"},
"call":{"calls","calling","called"},
"called":{"call","calls","calling"},
"calling":{"call","calls","called"},
"calls":{"call","calling","called"},
"can":{"canning","canned","cannot"},
"cannot":{"canning","canned","can"},
"cans":{"can"},
"canned":{"canning","canned","cannot","can"},
"canning":{"canning","canned","cannot","can"},
"capital":{"capitals"},
"capitals":{"capital"},
"captain":{"captains"},
"captains":{"captain"},
"car":{"cars"},
"cars":{"cars"},
"care":{"cares","carefully","careful","cared","carin"},
"cared":{"cares","carefully","careful","caring","care"},
"careful":{"cares","carefully","cared","caring","care"},
"carefully":{"cares","careful","cared","caring","care"},
"careless":{"carelessly"},
"cares":{"carefully","careful","cared","caring","care"},
"caring":{"cares","carefully","careful","cared","care"},
"carelessly":{"carelessly","careless"},
"carry":{"carries","carrying","carried"},
"carried":{"carries","carrying","carry"},
"carries":{"carrying","carried","carry"},
"carrying":{"carries","carried","carry"},
"case":{"cases"},
"cases":{"case"},
"castle":{"castles"},
"castles":{"castle"},
"catch":{"caught","catching","catches"},
"catches":{"caught","catching","catch"},
"catching":{"caught","catch","catches"},
"caught":{"catching","catch","catches"},
"cause":{"caused","causes","causing"},
"caused":{"cause","causes","causing"},
"causes":{"cause","caused","causing"},
"causing":{"cause","caused","causes"},
"centre":{"centred","centres","central","centered","centers"},
"center":{"centred","centres","centralization","central","centered","centers"},
"centers":{"centred","center","centres","centralization","central","centered","centre"},
"centred":{"center","centres","centralization","central","centers","centre"},
"centered":{"center","centres","centralization","central","centered","centers","centre"},
"central":{"centred","center","centres","centralization","centered","center"},
"centralization":{"centred","center","centres","central","centered","centers","centre"},
"centres":{"centred","center","centralization","central","centered","centers","centre"},
"centrist":{"centred","center","centres","centralization","central","centered","centers","centre"},
"centrists":{"centred","center","centres","centralization","central","centered","centers","centerists","centre"},
"certain":{"certainty","certainly"},
"certainly":{"certainty","certain"},
"certainty":{"certain","certainly"},
"uncertain":{"uncertainty","uncertainties"},
"uncertainties":{"uncertainty","uncertainties","uncertain"},
"uncertainty":{"certainty","certain","certainly","uncertainty","uncertainties","uncertain"},
"chance":{"chanced","chances","chancing"},
"chanced":{"chance","chances","chancing"},
"chances":{"chance","chanced","chancing"},
"chancing":{"chance","chanced","chances"},
"change":{"changing","changed","changes"},
"changed":{"changing","changes","change"},
"changes":{"changing","","changed","change"},
"changing":{"changed","changes","change"},
"unchanged":{"unchanged","unchangeable","unchanging"},
"unchangeable":{"unchangeable","unchanging"},
"unchanging":{"unchanged","unchangeable","unchanging"},
"character":{"characters","characteristic","characteristically","characteristics","characterize","characterized","characterization","characterised","characterises","characterizes","characterise"},
"characteristic":{"characters","character","characteristically","characteristics","characterize","characterized","characterization","characterised","characterises","characterizes","characterise"},
"characteristically":{"characters","character","characteristic","characteristics","characterize","characterized","characterization","characterised","characterises","characterizes","characterise"},
"characteristics":{"characters","character","characteristic","characteristically","characterize","characterized","characterization","characterised","characterises","characterizes","characterise"},
"characterize":{"characters","character","characteristic","characteristically","characteristics","characterized","characterization","characterised","characterises","characterizes","characterise"},
"characterized":{"characters","character","characteristic","characteristically","characteristics","characterize","characterized","characterization","characterises","characterizes","characterise"},
"characterization":{"characters","character","characteristic","characteristically","characteristics","characterize","characterized","characterised","characterises","characterizes","characterise"},
"characterizes":{"characters","character","characteristic","characteristically","characteristics","characterize","characterized","characterization","characterised","characterise"},
"characterise":{"characters","character","characteristic","characteristically","characteristics","characterized","characterization","characterised","characterises","characterizes"},
"characterised":{"characters","character","characteristic","characteristically","characteristics","characterize","characterization","characterises","characterizes","characterise"},
"characterises":{"characters","character","characteristic","characteristically","characteristics","characterize","characterized","characterization","characterised","characterises","characterizes","characterise"},
"characters":{"characters","character","characteristic","characteristically","characteristics","characterize","characterized","characterization","characterised","characterises","characterizes","characterise"},
"charge":{"charging","charges","charged"},
"charged":{"charge","charging","charges"},
"charges":{"charge","charging","charged"},
"charging":{"charge","charges","charged"},
"chief":{"chiefs","chiefly"},
"chiefs":{"chiefly","chief"},
"chiefly":{"chiefs","chief"},
"child":{"childhood","childish","children"},
"children":{"childhood","child"},
"childish":{"childlike"},
"childhood":{"children","child"},
"childlike":{"childish"},
"choose":{"choice","chooses","choices","choosing","chose","chosen"},
"choice":{"chooses","choose","choices","choosing","chose","chosen"},
"choices":{"choice","choose","choices","choosing","chose","chosen"},
"chooses":{"choice","choose","choices","choosing","chose","chosen"},
"choosing":{"choice","chooses","choose","choices","chose","chosen"},
"chose":{"choice","chooses","choose","choices","choosing","chosen"},
"chosen":{"choice","chooses","choose","choices","choosing","chose"},
"church":{"churches"},
"churches":{"church"},
"circle":{"circles","circling","circular","circled"},
"circled":{"circles","circling","circular","circle"},
"circles":{"circling","circular","circled","circle"},
"circling":{"circles","circular","circled","circle"},
"circular":{"circles","circling","circled","circle"},
"city":{"citizens","cities"},
"cities":{"citizens","citizen","city"},
"citizen":{"citizens","cities","city"},
"citizens":{"cities","citizen","city"},
"claim":{"claims","unclaimed","claiming","claimed"},
"claimed":{"claims","claim","unclaimed","claiming"},
"claiming":{"claims","claim","claimed"},
"claims":{"claim","unclaimed","claiming","claimed"},
"class":{"classify","classifying","classified","classifies","classed","classification","classing","classes"},
"classed":{"classify","classifying","classified","classifications","classifies","classification","class","classing","classes"},
"classes":{"classify","classifying","classified","classifications","classifies","classed","classification","class","classing"},
"classing":{"classify","classifying","classified","classifies","classed","classes"},
"classify":{"classify","classifying","classified","classifications","classifies","classed","classification","class","classing","classes"},
"classifying":{"classify","classified","classifications","classifies","classed","classification","class","classing","classes"},
"classified":{"classify","classifying","classified","classifications","classifies","classed","classification","class","classing","classes"},
"classifies":{"classify","classifying","classified","classifications","classed","classification","class","classing","classes"},
"classification":{"classify","classifying","classified","classifications","classifies","classed","class","classing","classes"},
"classifications":{"classify","classifying","classified","classifies","classed","classification","class","classing","classes"},
"clear":{"clears","cleared","clearer","clearest","clearings","clearly","clearness","clearing"},
"cleared":{"clears","clear","clearer","clearest","clearings","clearly","clearness","clearing"},
"clearer":{"clears","clear","cleared","clearest","clearings","clearly","clearness","clearing"},
"clearest":{"clears","clear","cleared","clearer","clearings","clearly","clearness","clearing"},
"clearing":{"clears","clear","cleared","clearer","clearest","clearly","clearness","clearing"},
"clearings":{"clears","clear","cleared","clearer","clearest","clearly","clearness","clearing"},
"clearly":{"clears","clear","cleared","clearer","clearest","clearings","clearness","clearing"},
"clearness":{"clears","clear","cleared","clearer","clearest","clearings","clearly","clearing"},
"clears":{"clear","cleared","clearer","clearest","clearings","clearly","clearness","clearing"},
"close":{"closer","closed","closely","closeness","closes","closest","closure","closing"},
"closed":{"closer","close","closely","closeness","closes","closest","closure","closing"},
"closely":{"closer","close","closed","closeness","closes","closest","closure","closing"},
"closeness":{"closer","close","closed","closely","closes","closest","closure","closing"},
"closer":{"close","closed","closely","closeness","closes","closest","closure","closing"},
"closes":{"closer","close","closed","closely","closeness","closest","closure","closing"},
"closest":{"closer","close","closed","closely","closeness","closes","closure","closing"},
"closure":{"closer","close","closed","closely","closeness","closes","closest","closing"},
"closing":{"closer","close","closed","closely","closeness","closes","closest","closure"},
"cloud":{"cloudy","clouded","clouds"},
"cloudy":{"clouded","clouds","cloud"},
"clouded":{"cloudy","clouds","cloud"},
"clouds":{"cloudy","clouded","cloud"},
"coast":{"coasts"},
"coasts":{"coast"},
"coin":{"coins"},
"coins":{"coin"},
"cold":{"coldness","colds","coldest","coldly","colder"},
"colder":{"coldness","colds","coldest","coldly","cold"},
"coldest":{"coldness","colds","coldly","colder","cold"},
"coldly":{"coldness","colds","coldest","colder","cold"},
"coldness":{"colds","coldest","coldly","colder","cold"},
"colds":{"coldness","coldest","coldly","colder","cold"},
"college":{"colleges"},
"colleges":{"college"},
"colony":{"colonials","colonized","colonising","colonization","colonial","colonies","colonize"},
"colonial":{"colonials","colonized","colonising","colonization","colony","colonies","colonize"},
"colonies":{"colonials","colonized","colonising","colonization","colony","colonial","colonize"},
"colonials":{"colonists","colonising","colonization","colony","colonial","colonies","colonize"},
"colonize":{"colonials","colonized","colonising","colonization","colony","colonial","colonies"},
"colonization":{"colonials","colonized","colonising","colony","colonial","colonies","colonize"},
"colonized":{"colonials","colonising","colonization","colony","colonial","colonies","colonize"},
"colonising":{"colonials","colonized","colonising","colonization","colony","colonial","colonies","colonize"},
"colonist":{"colonists"},
"colonists":{"colonist"},
"colour":{"colouring","colourful","coloured","colors","colorless","coloring","colorful","colored","colours"},
"color":{"colouring","colourful","coloured","colors","coloring","colorful","colored","colour","colours"},
"colored":{"colouring","colourful","coloured","colors","coloring","colorful","color","colour","colours"},
"colorful":{"colouring","coloured","colors","colorless","coloring","colorful","colored","color","colour","colours"},
"coloring":{"colourless","colourful","coloured","colors","colorless","coloring","colorful","colored","color","colour","colours"},
"colors":{"colourless","clouring","colourful","coloured","colors","coloring","colorful","colored","color","colour","colours"},
"coloured":{"colouring","colourful","colors","coloring","colorful","color","colour","colours"},
"colourful":{"colouring","coloured","colors","coloring","colorful","colored","color","colour","colours"},
"colouring":{"colourful","coloured","colors","coloring","colorful","colored","color","colour","colours"},
"colours":{"colourless","colouring","colourful","coloured","coloring","colorful","colored","color","colour","colours"},
"come":{"came","comes","coming"},
"came":{"comes","coming","come"},
"comes":{"came","coming","come"},
"coming":{"came","comes","come"},
"command":{"commanded","commanding","commanders","commander","commands"},
"commanded":{"commanding","commanders","commands","command"},
"commanding":{"commanded","commanders","commands","command"},
"commands":{"commanded","commanding","commands","command"},
"commander":{"commanders"},
"commanders":{"commanded","commanding","commander","commands","command"},
"committee":{"committees"},
"committees":{"committee"},
"common":{"commons"},
"commoner":{"commonest"},
"commonest":{"commoner"},
"commonly":{"commonness","common","commons"},
"commonness":{"commonness","common","commons"},
"commons":{"common","commonly"},
"uncommon":{"uncommonly"},
"uncommonly":{"uncommon"},
"company":{"companies"},
"companies":{"company"},
"complete":{"completely","completion","completions","completes","completeness","completing","completed"},
"completed":{"complete","completely","completion","completions","completes","completeness","completing"},
"completely":{"complete","completion","completions","completes","completeness","completing","completed"},
"completion":{"complete","completely","completions","completes","completeness","completing","completed"},
"completions":{"complete","completely","completion","completes","completeness","completing","completed"},
"completes":{"complete","completely","completion","completions","completeness","completing","completed"},
"completeness":{"complete","completely","completion","completions","completes","completing","completed"},
"completing":{"complete","completely","completion","completions","completes","completeness","completed"},
"concern":{"concerns","concerning","concerned"},
"concerned":{"concerns","concerning","concern"},
"concerning":{"concerns","concerned","concern"},
"concerns":{"concerning","concerned","unconcerned","concern"},
"condition":{"conditions","conditional"},
"conditional":{"conditions","condition"},
"conditions":{"conditional","condition"},
"consider":{"consideration","considers","considering","considered","considerations"},
"consideration":{"consider","considers","considering","considered","considerations"},
"considerations":{"consider","consideration","considers","considering","considered"},
"considered":{"consider","consideration","considers","considering","considerations"},
"considering":{"consider","consideration","considers","considered","considerations"},
"considers":{"consider","consideration","considering","considered","considerations"},
"reconsider":{"reconsideration","reconsidering"},
"reconsidering":{"reconsider"},
"reconsideration":{"reconsider","reconsidering"},
"contain":{"contains","containing","container","contained","containers"},
"contained":{"contains","containing","contain","container","containers"},
"container":{"contains","containing","contain","contained"},
"containers":{"contains","containing","contain","container","contained"},
"containing":{"contains","contain","container","contained"},
"contains":{"containing","contain","container","contained"},
"content":{"contented","contenting","contentment","contents"},
"contented":{"content","contenting","contentment","contents"},
"contenting":{"content","contented","contentment","contents"},
"contentment":{"content","contented","contenting","contents"},
"contents":{"content","contented","contenting","contentment"},
"discontent":{"discontentment"},
"discontentment":{"discontent"},
"continue":{"continuously","continuous","continuing","continues","continued","continuance","continuity"},
"continuance":{"continuously","continuous","continuing","continues","continued","continuity","continue"},
"continued":{"continuously","continuous","continuing","continues","continuance","continuity","continue"},
"continuity":{"continuously","continuous","continuing","continues","continued","continuance","continue"},
"continues":{"continuously","continuous","continuing","continued","continuance","continuity","continue"},
"continuing":{"continuously","continuous","continues","continued","continuance","continuity","continue"},
"continuous":{"continuously","continuing","continues","continued","continuance","continuity","continue"},
"continuously":{"continuous","continuing","continues","continued","continuance","continuity","continue"},
"control":{"controlled","controller","controlling","controls"},
"controlled":{"control","controller","controlling","controls"},
"controller":{"controlled","control","controlling","controls"},
"controlling":{"controlled","control","controller","controls"},
"controls":{"controlled","control","controller","controlling"},
"uncontrollable":{"uncontrollably","uncontrolled"},
"uncontrollably":{"uncontrollable","uncontrolled"},
"uncontrolled":{"uncontrollably","uncontrollable"},
"cost":{"costly","costs","costing"},
"costing":{"cost","costly","costs"},
"costs":{"cost","costly","costing"},
"costly":{"cost","costs","costing"},
"council":{"councillor","councilor","councillors","councils"},
"councillor":{"councillors"},
"councillors":{"councillor"},
"councilor":{"council","councillors","councils"},
"councils":{"council","councillor","councilor","councillors"},
"count":{"counts","counting","","countable","counted"},
"counted":{"counts","counting","count","countable"},
"counting":{"counts","count","countable","counted"},
"counts":{"counting","count","countable","counted"},
"countable":{"counts","counting","count","counted"},
"uncountable":{"countless"},
"country":{"countries"},
"countries":{"country"},
"course":{"courses"},
"courses":{"course"},
"court":{"courts"},
"courts":{"court"},
"cover":{"covers","coverage","covering","covered"},
"covered":{"covers","coverage","covering","cover"},
"covering":{"covers","coverage","covered","cover"},
"coverage":{"covers","covering","covered","cover"},
"covers":{"coverage","covering","covered","cover"},
"uncover":{"uncovers","uncovered"},
"uncovered":{"uncovers","uncover"},
"uncovers":{"uncovered","uncover"},
"cross":{"crossed","crossing","crosses"},
"crossed":{"crossing","cross","crosses"},
"crosses":{"crossed","crossing","cross"},
"crossing":{"crossed","cross","crosses"},
"crowd":{"crowded","crowding"},
"crowded":{"crowd","crowding","crowds"},
"crowding":{"crowd","crowded","crowds"},
"crowds":{"crowd","crowded","crowding"},
"crown":{"crowned","crowning","crowns"},
"crowns":{"crowned","crowning","crown"},
"crowned":{"crowning","crowns","crown"},
"crowning":{"crowned","crowns","crown"},
"cry":{"crying","cries","cried"},
"cried":{"crying","cries","cry"},
"cries":{"crying","cried","cry"},
"crying":{"cries","cried","cry"},
"current":{"currently"},
"currently":{"current"},
"cut":{"cutting","cuts","uncut"},
"cuts":{"cutting","cut"},
"cutting":{"cut","cuts"},
"danger":{"dangerously","dangers","dangerous"},
"dangerous":{"dangerously","dangers","danger"},
"dangerously":{"dangers","danger","dangerous"},
"dangers":{"dangerously","danger","dangerous"},
"dark":{"darkness","darker","darkest"},
"darkest":{"darkness","darker","dark"},
"darkness":{"darker","darkest","dark"},
"date":{"dating","dated","dates"},
"dates":{"dating","dated","date"},
"dated":{"dating","dates","date"},
"dating":{"dated","dates","date"},
"daughter":{"daughters"},
"daughters":{"daughter"},
"day":{"daily","daylight","days"},
"daily":{"day","daylight","days"},
"daylight":{"day","daily","days"},
"days":{"day","daily","daylight"},
"dead":{"deaths","death"},
"death":{"dead","deaths"},
"deaths":{"dead","death"},
"deal":{"deals","dealings","dealt","dealing"},
"dealer":{"dealers"},
"dealers":{"dealer"},
"dealing":{"deals","dealings","dealt"},
"dealings":{"deals","dealt","dealing","deal"},
"deals":{"dealings","dealt","dealing","deal"},
"dealt":{"deals","dealings","dealing","deal"},
"dear":{"dears"},
"dears":{"dear"},
"decide":{"decisive","decisions","decision","deciding","decides","decided","decidedly"},
"decided":{"decisive","decisions","decision","deciding","decides","decide","decidedly"},
"decidedly":{"decisive","decisions","decision","deciding","decides","decided","decide"},
"decides":{"decisive","decisions","decision","deciding","decided","decide","decidedly"},
"deciding":{"decisive","decisions","decision","decides","decided","decide","decidedly"},
"decision":{"decisive","decisions","deciding","decides","decided","decide","decidedly"},
"decisions":{"decisive","decision","deciding","decides","decided","decide","decidedly"},
"decisive":{"decisions","decision","deciding","decides","decided","decide","decidedly"},
"declare":{"declared","declaring","declares","declarations","declaration"},
"declaration":{"declared","declaring","declares","declarations","declare"},
"declarations":{"declared","declaring","declares","declaration","declare"},
"declared":{"declaring","declares","declarations","declaration","declare"},
"declares":{"declared","declaring","declarations","declaration","declare"},
"declaring":{"declared","declares","declarations","declaration","declare"},
"deep":{"depths","depth","deeper","deeply"},
"deepen":{"deepened","deepening"},
"deepened":{"deepen","deepening"},
"deeper":{"deepen","deep","deepened","deepening","depths","deeply"},
"deepest":{"deepen","deep","depths","depth","deeply"},
"deeply":{"deepen","deep","deepened","deepening","depth"},
"depth":{"deepen","deep","depths"},
"depths":{"deepen","deep","deepened","deepening","depth","deeper","deeply"},
"deepening":{"deepen","deep","deepened","depths","depth","deeper","deeply"},
"defeat":{"defeating","defeats","defeated"},
"defeated":{"defeating","defeats","defeat"},
"defeats":{"defeat","defeated"},
"defeating":{"defeats","defeat","defeated"},
"undefeated":{"defeating","defeats","defeat"},
"degree":{"degrees"},
"degrees":{"degree"},
"demand":{"demands","demanding","demanded"},
"demanded":{"demands","demanding","demand"},
"demanding":{"demands","demanded","demand"},
"demands":{"demanding","demanded","demand"},
"department":{"departmental","departments"},
"departments":{"departmental","department"},
"departmental":{"departments","department"},
"depend":{"depends","depending","dependant","depended","dependants","dependent"},
"depends":{"depend","depending","dependant","depended","dependants","dependent"},
"depended":{"depends","depend","depending","dependant","dependants","dependent"},
"depending":{"depends","depend","dependant","depended","dependants","dependent"},
"dependant":{"depends","depend","depending","depended","dependants"},
"dependants":{"depends","depend","depending","dependant","depended","dependent"},
"dependent":{"depends","depend","depending","depended","dependants"},
"describe":{"descriptive","described","describes","describing","description","descriptions"},
"described":{"descriptive","describe","describes","describing","description","descriptions"},
"describes":{"descriptive","describe","described","describing","description","descriptions"},
"describing":{"descriptive","describe","described","describes","description","descriptions"},
"description":{"descriptive","describe","described","describes","describing","descriptions"},
"descriptions":{"descriptive","describe","described","describes","describing","description"},
"descriptive":{"describe","described","describes","describing","description","descriptions"},
"desert":{"deserted","deserting","deserts"},
"deserted":{"deserting","deserts","desert"},
"deserting":{"deserted","deserts","desert"},
"deserts":{"deserted","deserting","desert"},
"desire":{"desirable","desires","desiring","desirability","desired"},
"desired":{"desirable","desires","desiring","desirability","desire"},
"desirability":{"desirable","desires","desiring","desired","desire"},
"desirable":{"desires","desiring","desirability","desired","desire"},
"desires":{"desirable","desiring","undesirable","desirability","desired","desire"},
"desiring":{"desirable","desires","desirability","desired","desire"},
"destroy":{"destroyed","destroying","destroys","destruction","destructive"},
"destroyed":{"destroying","destroys","destruction","destructive","destroy"},
"destroying":{"destroyed","destroys","destruction","destructive","destroy"},
"destroys":{"destroyed","destroying","destruction","destructive","destroy"},
"destruction":{"destroyed","destroying","destroys","destructive","destroy"},
"destructive":{"destroyed","destroying","destroys","destruction","destroy"},
"detail":{"detailed","detailing","details"},
"detailed":{"detail","detailing","details"},
"detailing":{"detailed","detail","details"},
"details":{"detailed","detail","detailing"},
"determine":{"determines","determined","determination","determining","determinate"},
"determination":{"determines","indeterminate","determined","determining","determine","determinate"},
"determined":{"determines","determination","determining","determine","determinate"},
"determinate":{"determines","determined","determination","determining","determine"},
"determines":{"determined","determination","determining","determine","determinate"},
"determining":{"determines","determined","determination","determine","determinate"},
"develop":{"develops","developed","developers","development","developments","developing"},
"developed":{"develops","develop","developers","development","developments","developing"},
"developers":{"develops","develop","developed","development","developments","developing"},
"developing":{"develops","develop","developed","developers","development","developments"},
"development":{"develops","develop","developed","developers","developments"},
"developments":{"develops","develop","developed","developers","development","developing"},
"develops":{"develop","developed","developers","development","developments","developing"},
"die":{"died","dying","dies"},
"died":{"dying","dies","die"},
"dies":{"died","dying","die"},
"dying":{"died","dies","die"},
"difference":{"differs","differ","differing","differences","different","differently"},
"differ":{"differs","differing","difference","differences","different","differently"},
"differences":{"differs","differ","differing","difference","different","differently"},
"different":{"differs","differ","differing","difference","differences","differently"},
"differs":{"differ","differing","difference","differences","different","differently"},
"differing":{"differs","differ","difference","differences","different","differently"},
"differently":{"differs","differ","differing","difference","differences","different"},
"difficult":{"difficulty","difficulties"},
"difficulties":{"difficult","difficulty"},
"difficulty":{"difficult","difficulties"},
"direct":{"directed","directing","directly","directs"},
"directed":{"direct","directing","directs"},
"directing":{"direct","directed","direction","directions","directs"},
"direction":{"direct","directed","directing","directions","directs"},
"directions":{"direct","directed","directing","direction","directs"},
"directly":{"direct","directed","directing","direction","directions","directs"},
"director":{"directors"},
"directors":{"director"},
"directs":{"direct","directed","directing","direction","directions"},
"indirect":{"indirectly"},
"indirectly":{"indirect"},
"discover":{"discovery","discovered","discovering","discoveries","discovers"},
"discovered":{"discovery","discovering","discoveries","discover","discovers"},
"discoveries":{"discovery","discovered","discovering","discover","discovers"},
"discovering":{"discovery","discovered","discoveries","discover","discovers"},
"discovers":{"discovery","discovered","discovering","discoveries","discover"},
"discovery":{"discovered","discovering","discoveries","discover","discovers"},
"distance":{"distanced","distant","distancing","distances"},
"distances":{"distanced","distant","distance","distancing"},
"distant":{"distanced","distance","distancing","distances"},
"distanced":{"distant","distance","distancing","distances"},
"distancing":{"distanced","distant","distance","distances"},
"distinguish":{"distinguished","distinguishing","distinguishes","distinguishable"},
"distinguished":{"distinguish","distinguishing","distinguishes","distinguishable"},
"distinguishes":{"distinguished","distinguish","distinguishing","distinguishable"},
"distinguishing":{"distinguished","distinguish","distinguishes","distinguishable"},
"distinguishable":{"distinguished","distinguish","distinguishing","distinguishes"},
"district":{"districts"},
"districts":{"district"},
"divide":{"division","dividing","divisions","divided","divides"},
"divided":{"division","dividing","divide","divisions","divides"},
"divides":{"division","dividing","divide","divisions","undivided","divided"},
"dividing":{"division","divide","divisions","divided","divides"},
"division":{"dividing","divide","divisions","divided","divides"},
"divisions":{"division","dividing","divide","divided","divides"},
"do":{"did","does","doing","done","be"},
"did":{"do","does","doing","done"},
"does":{"do","did","","doing","done"},
"doing":{"do","did","does","done"},
"done":{"do","did","does","doing"},
"doctor":{"doctors"},
"doctors":{"doctor"},
"dog":{"dogs"},
"dogs":{"dog"},
"dogged":{"dog","dogs"},
"dollar":{"dollars"},
"dollars":{"dollar"},
"door":{"doors"},
"doors":{"door"},
"doubt":{"doubted","doubtful","doubts","doubting"},
"doubted":{"doubtful","doubt","doubts","doubting"},
"doubtful":{"doubted","doubt","doubts","doubting"},
"doubting":{"doubted","doubtful","doubt","doubts"},
"doubtless":{"undoubtedly"},
"undoubtedly":{"doubtless"},
"doubts":{"doubted","doubtful","doubt","doubts","doubting"},
"down":{"downwards"},
"downwards":{"down"},
"draw":{"drawing","drawn","drew","draws"},
"drawing":{"drawn","drew","draw","draws"},
"drawn":{"drawing","drew","draw","draws"},
"draws":{"drawing","drawn","drew","draw"},
"drew":{"drawing","drawn","draw","draws"},
"dream":{"dreamed","dreaming","dreams","dreamt","dreamy"},
"dreamed":{"dream","dreaming","dreams","dreamt","dreamy"},
"dreaming":{"dreamed","dream","dreams","dreamt","dreamy"},
"dreams":{"dreamed","dream","dreaming","dreamt","dreamy"},
"dreamt":{"dreamed","dream","dreaming","dreams","dreamy"},
"dreamy":{"dreamed","dream","dreaming","dreams","dreamt"},
"dress":{"dressing","dressed","dresses"},
"dressed":{"dress","dressing","dresses"},
"dressing":{"dress","dressed","dresses"},
"drink":{"drinking","drunk","drank","drinker","drinks"},
"drinks":{"drinking","drunk","drink","drank"},
"drinker":{"drinkers"},
"drinkers":{"drinker"},
"drank":{"drinking","drunk","drink","drank","drinks"},
"drunk":{"drinking","drunk","drink","drank","drinker","drinkers","drinks"},
"drinking":{"drunk","drink","drank","drinks"},
"drive":{"driving","driven","drove","drives"},
"driven":{"driving","drive","drove","driveway","drives"},
"driver":{"drivers"},
"drivers":{"driver"},
"drives":{"driving","driven","drive","drove"},
"driveway":{"driving","driven","drive","drove","drives"},
"driving":{"driven","drive","drove","drives"},
"drove":{"driving","driven","drive","driveway","drives"},
"drop":{"drops","dropping","dropped"},
"dropped":{"drops","dropping","drop"},
"dropping":{"drops","dropped","drop"},
"drops":{"dropping","dropped","drop"},
"dry":{"dryness","dryly","dried","dries","driest","drying"},
"dried":{"dry","dryness","dryly","dries","driest","drying"},
"dries":{"dry","dryness","dryly","dried","driest","drying"},
"driest":{"dry","dryness","dryly","dried","dries","drying"},
"dryer":{"dryness"},
"drying":{"dry","dryness","dryly","dryer","dried","dries","driest"},
"dryly":{"dry","dried","dries","driest","drying"},
"dryness":{"dryer"},
"duty":{"duties"},
"duties":{"duty"},
"ear":{"ears"},
"ears":{"ear"},
"early":{"earlier","earliest"},
"earlier":{"earliest","early"},
"earliest":{"earlier","early"},
"earliness":{"earlier","earliest","early"},
"earth":{"earthy"},
"earthy":{"earth"},
"earthquake":{"earth","earthquakes"},
"earthquakes":{"earth","earthquake"},
"east":{"eastern"},
"eastern":{"east"},
"easy":{"easiest","easiness","easily","easier"},
"easier":{"easiest","easiness","easily","easy"},
"easiest":{"easiness","easily","easier","easy"},
"easily":{"easiest","easiness","easier","easy"},
"easiness":{"easiest","easily","easier","easy"},
"eat":{"eating","eat","eats","eaten"},
"ate":{"eating","eats","eaten","ate"},
"eaten":{"eating","eat","eats","ate"},
"eating":{"eat","eats","eaten","ate"},
"eats":{"eating","eat","eaten","ate"},
"effect":{"effects","effectiveness","effectively","effective","effecting","effected","affect"},
"effected":{"effects","effectiveness","effectively","effective","effecting","effect"},
"effecting":{"effects","effectiveness","effectively","effective","effected","effect"},
"effective":{"ineffectively","ineffective","effects","effectiveness","effectively","effective","effecting","effected","effect"},
"effectively":{"ineffectively","ineffective","effects","effectiveness","effectively","effective","effecting","effected","effect"},
"effectiveness":{"effects","effectively","effective","effecting","effected","effect"},
"effects":{"effectiveness","effectively","effective","effecting","effected","effect"},
"ineffective":{"ineffectively"},
"ineffectively":{"ineffective"},
"efficient":{"efficiency"},
"efficiency":{"efficient"},
"effort":{"efforts"},
"efforts":{"effort"},
"egg":{"eggs"},
"eggs":{"egg"},
"eight":{"eighth","eightieth","eights"},
"eighteen":{"eightieth"},
"eighteenth":{"eightieth"},
"eighth":{"eighties"},
"eighties":{"eightieth"},
"eightieth":{"eighty"},
"eighty":{"eighties","eightieth"},
"eights":{"eighth","eight"},
"elect":{"election","elects","elections","electing","elected"},
"elected":{"election","elect","electoral","elects","elections","electing"},
"electing":{"election","elect","electoral","elects","elections","elected"},
"election":{"elect","electoral","elects","elections","electing","elected"},
"elections":{"election","elect","electoral","elects","electing","elected"},
"elects":{"election","elect","electoral","elects","elections","electing","elected"},
"electors":{"election","elect","electoral","electors","elects","elections","electing","elected"},
"electoral":{"election","elect","elects","elections","electing","elected"},
"eleven":{"elevens","eleventh"},
"elevens":{"eleven","eleventh"},
"eleventh":{"eleven","elevens"},
"else":{"else"},
"elsewhere":{"else"},
"empire":{"empires"},
"empires":{"empire"},
"employ":{"employees","employee","employed","employing","employment","employs","employers","employer"},
"employed":{"employees","employee","employ","employing","employment","employs","employers","employer"},
"employee":{"employees","unemployment","employed","employ","employing","employment","employs","employers","employer"},
"employees":{"employee","employed","employ","employing","employment","employs","employers","employer"},
"employer":{"employees","employee","employed","employ","employing","employment","employs","employer"},
"employers":{"employees","employee","employed","employ","employing","employment","employs","employer"},
"employing":{"employees","employee","employed","employ","employment","employs","employers","employer"},
"employment":{"employees","employee","employed","employ","employing","employs","employers","employer"},
"employs":{"employees","employee","employed","employ","employing","employment","employers","employer"},
"unemployment":{"unemployed"},
"end":{"ends","ended","ending"},
"ended":{"ends","end","ending"},
"ending":{"ends","end","ended"},
"endless":{"endlessly"},
"endlessly":{"endless"},
"ends":{"end","ended","ending"},
"enemy":{"enemies"},
"enemies":{"enemy"},
"enjoy":{"enjoyed","enjoyable","enjoys","enjoyment","enjoying"},
"enjoyed":{"enjoyable","enjoys","enjoyment","enjoying","enjoy"},
"enjoying":{"enjoyed","enjoyable","enjoys","enjoyment","enjoy"},
"enjoyment":{"enjoyed","enjoyable","enjoys","enjoying","enjoy"},
"enjoys":{"enjoyed","enjoyable","enjoyment","enjoying","enjoy"},
"enjoyable":{"enjoyed","enjoys","enjoyment","enjoying","enjoy"},
"enter":{"entries","entering","entered","enters","entry","entrance","entrances"},
"entered":{"entries","enter","entering","enters","entry","entrance","entrances"},
"entering":{"entries","enter","entered","enters","entry","entrance","entrances"},
"enters":{"entries","enter","entering","entered","entry","entrance","entrances"},
"entrance":{"entries","enter","entering","entered","enters","entry","entrances"},
"entrances":{"entries","enter","entering","entered","enters","entry","entrance"},
"entries":{"enter","entering","entered","enters","entry","entrance","entrances"},
"entry":{"entries","enter","entering","entered","enters","entrance","entrances"},
"equal":{"equally","equals","equalling","equalled","equality","equaling","equaled"},
"equaled":{"equal","equally","equals","equalling","equality","equaling","equaled"},
"equaling":{"equal","equally","equals","equalled","equality","equaling","equaled"},
"equality":{"equal","equally","equals","equalling","equalled","equaling","equaled"},
"equalled":{"equal","equally","equals","equalling","equality","equaling","equaled"},
"equalling":{"equal","equally","equals","equalled","equality","equaling","equaled"},
"equally":{"equal","equals","equalling","equalled","equality","equaling","equaled"},
"equals":{"equal","equally","equalling","equalled","equality","equaling","equaled"},
"inequality":{"unequal"},
"unequal":{"inequality"},
"escape":{"escaped","escapes","escaping"},
"escaped":{"escaped"},
"escapes":{"escape","escaped","escaping"},
"escaping":{"escape","escaped","escapes"},
"even":{"evenly"},
"evenly":{"even"},
"evening":{"evenings"},
"evenings":{"evening"},
"event":{"events"},
"events":{"event"},
"every":{"everything","everybody","everyday","everyone","everywhere"},
"everybody":{"everything","every","everyday","everyone","everywhere"},
"everyday":{"everything","every","everybody","everyone","everywhere"},
"everyone":{"everything","every","everybody","everyday","everywhere"},
"everything":{"every","everybody","everyday","everyone","everywhere"},
"everywhere":{"everything","every","everybody","everyday","everyone"},
"example":{"examples"},
"examples":{"example"},
"except":{"exceptions","exceptional","exception"},
"exception":{"exceptions","exceptional","except"},
"exceptional":{"exceptions","exception","except"},
"exceptions":{"exceptional","exception","except"},
"exchange":{"exchanged","exchanges","exchanging"},
"exchanged":{"exchange","exchanges","exchanging"},
"exchanges":{"exchange","exchanged","exchanging"},
"exchanging":{"exchange","exchanged","exchanges"},
"exercise":{"exercising","exercises","exercised"},
"exercised":{"exercise","exercising","exercises"},
"exercises":{"exercise","exercising","exercised"},
"exercising":{"exercise","exercises","exercised"},
"exist":{"existed","existence","existing","exists"},
"existed":{"exist","existence","existing","exists"},
"existence":{"exist","existed","existing","exists"},
"existing":{"exist","existed","existence","exists"},
"exists":{"exist","existed","existence","existing"},
"expect":{"expectancy","expects","expecting","expected","expectations","expectation"},
"expectancy":{"expect","expects","expecting","expected","expectations","expectation"},
"expectation":{"expect","expectancy","expects","expecting","expected","expectations"},
"expectations":{"expect","expectancy","expects","expecting","expected","expectation"},
"expected":{"expect","expectancy","expects","expecting","expectations","expectation"},
"expecting":{"expect","expectancy","expects","expected","expectations","expectation"},
"expects":{"expect","expectancy","expecting","expected","expectations","expectation"},
"expense":{"expenses","expensive"},
"expenses":{"expense","expensive"},
"expensive":{"expense","expenses"},
"experience":{"experiencing","experienced","experiences"},
"experienced":{"experiencing","experience","experiences"},
"experiences":{"experiencing","experience","experienced"},
"experiencing":{"experience","experienced","experiences"},
"experiment":{"experimental","experimentation","experiments","experimenting","experimented"},
"experimental":{"experiment","experimentation","experiments","experimenting","experimented"},
"experimentation":{"experiment","experimental","experiments","experimenting","experimented"},
"experimented":{"experiment","experimental","experimentation","experiments","experimenting"},
"experimenting":{"experiment","experimental","experimentation","experiments","experimented"},
"experiments":{"experiment","experimental","experimentation","experimenting","experimented"},
"explain":{"explained","explanation","explanatory","explanations","explains","explaining"},
"explained":{"explanation","explanatory","explanations","explains","explain","explaining"},
"explaining":{"explained","explanation","explanatory","explanations","explains","explain"},
"explains":{"explained","explanation","explanatory","explanations","explain","explaining"},
"explanation":{"explained","explanatory","explanations","explains","explain","explaining"},
"explanatory":{"explained","explanation","explanations","explains","explain","explaining"},
"explanations":{"explained","explanation","explanatory","explanations","explain","explaining"},
"express":{"expressions","expressive","expresses","expression","expressed","expressing"},
"expressed":{"expressions","expressive","expresses","express","expression","expressing"},
"expresses":{"expressions","expressive","express","expression","expressed","expressing"},
"expressing":{"expressions","expressive","expresses","express","expression","expressed"},
"expression":{"expressions","expressive","expresses","express","expressed","expressing"},
"expressions":{"expressive","expresses","express","expression","expressed","expressing"},
"expressive":{"expressions","expresses","express","expression","expressed","expressing"},
"extend":{"extensively","extent","extensions","extension","extended","extending","extensive","extends"},
"extended":{"extensively","extent","extensions","extension","extending","extensive","extend","extends"},
"extending":{"extensively","extent","extensions","extension","extended","extensive","extend","extends"},
"extends":{"extensively","extent","extensions","extension","extended","extending","extensive","extend"},
"extension":{"extensively","extent","extensions","extended","extending","extensive","extend","extends"},
"extensions":{"extensively","extent","extension","extended","extending","extensive","extend","extends"},
"extensive":{"extensively","extent","extensions","extension","extended","extending","extend","extends"},
"extensively":{"extent","extensions","extension","extended","extending","extensive","extend","extends"},
"extent":{"extensively","extensions","extension","extended","extending","extensive","extend","extends"},
"eye":{"eyes"},
"eyes":{"eye"},
"face":{"faced","faces","facing"},
"faced":{"faces","facing","face"},
"faces":{"faced","facing","face"},
"facing":{"faced","faces","face"},
"fact":{"facts","factual"},
"facts":{"fact","factual"},
"factual":{"fact","facts"},
"factory":{"factories"},
"factories":{"factory"},
"fail":{"failures","failure","failed","fails","failing"},
"failed":{"failures","failure","fails","failing","fail"},
"failing":{"failures","failure","failed","fails","fail"},
"fails":{"failures","failure","failed","failing","fail"},
"failure":{"failures","failed","fails","failing","fail"},
"failures":{"failure","failed","fails","failing","fail"},
"fair":{"fairness","fairly","fairest","fairer"},
"fairer":{"fairness","fairly","fairest","fair"},
"fairest":{"fairness","fairly","fair","fairer"},
"fairly":{"fairness","fairest","fair","fairer"},
"fairness":{"fairly","fairest","fair","fairer"},
"unfair":{"unfairly"},
"unfairly":{"unfair"},
"faith":{"faithfully","faiths","faithful"},
"faithful":{"faithfully","faith","faiths"},
"faithfully":{"faith","faiths","faithful"},
"faiths":{"faithfully","faith","faithful"},
"fall":{"falling","falls","fell","fallen"},
"fallen":{"falling","falls","fall","fell"},
"falling":{"falls","fall","fell","fallen"},
"falls":{"falling","fall","fell","fallen"},
"fell":{"falling","falls","fall","fallen","feel"},
"familiar":{"familiarity","familiarly"},
"familiarity":{"familiar","familiarly"},
"unfamiliar":{"unfamiliarity"},
"unfamiliarity":{"unfamiliar"},
"familiarly":{"familiar","familiarity"},
"family":{"families"},
"families":{"family"},
"far":{"farther","farthest","further","furthest"},
"farther":{"far","farthest","further","furthest"},
"farthest":{"farther","far","further"},
"further":{"far","farthest","furthest"},
"furthest":{"farther","far"},
"farm":{"farmer","farms","farmers","farming"},
"farmer":{"farms","farmers","farm","farming"},
"farmers":{"farmer","farms","farm","farming"},
"farms":{"farmer","farmers","farm","farming"},
"farming":{"farmer","farms","farmers","farm"},
"fast":{"fastness","faster","fastest"},
"faster":{"fastness","fast","fastest"},
"fastest":{"fastness","faster","fast"},
"fastness":{"faster","fast","fastest"},
"father":{"fathers"},
"fathers":{"father"},
"dad":{"dads"},
"dads":{"dad"},
"favour":{"favoured","favouring","favourites","favours","favourably","favourite","favorite","favourable"},
"favor":{"favoured","favouring","favourites","favours","favourably","favourite","favorite","favourable"},
"favorite":{"favour","favor","favoured","favouring","favourites","favours","favourably","favourable"},
"favourite":{"favour","favor","favoured","favouring","favourites","favours","favourably","favourite","favorite","favourable"},
"favourable":{"favour","favor","favoured","favouring","favourites","favours","favourably","favourable"},
"favourably":{"favour","favor","favoured","favouring","favourites","favours","favourite","favorite","favourable"},
"favoured":{"favour","favor","favouring","favourites","favours","favourably","favourite","favorite","favourable"},
"favouring":{"favour","favor","favoured","favourites","favours","favourably","favourite","favorite","favourable"},
"favourites":{"favour","favor","favoured","favouring","favours","favourably","favourite","favorite","favourable"},
"favours":{"favour","favor","favoured","favouring","favourites","favourably","favourite","favorite","favourable"},
"fear":{"feared","fears","fearing","fearful"},
"feared":{"fear","fears","fearing","fearful"},
"fearful":{"feared","fear","fears","fearing"},
"fearing":{"feared","fear","fears","fearful"},
"fears":{"feared","fear","fearing","fearful"},
"feel":{"feels","feelings","feeling","felt"},
"feeling":{"feels","feelings","feel","felt"},
"feelings":{"feels","feeling","feel","felt"},
"feels":{"feelings","feeling","feel","felt"},
"felt":{"feels","feelings","feeling","feel"},
"fellow":{"fellow"},
"fellows":{"fellow"},
"few":{"fewer","fewest"},
"fewer":{"few","fewest"},
"fewest":{"few","fewer"},
"field":{"fields"},
"fields":{"field"},
"fight":{"fighter","fighters","fights","fought","fighting"},
"fighter":{"fighters","fight","fights","fought","fighting"},
"fighters":{"fighter","fight","fights","fought","fighting"},
"fighting":{"fighter","fighters","fight","fights","fought"},
"fought":{"fighter","fighters","fight","fights","fighting"},
"fights":{"fighter","fighters","fight","fought","fighting"},
"figure":{"figures"},
"figures":{"figure"},
"fill":{"filled","filling","fills"},
"filled":{"fill","filling","fills"},
"filling":{"fill","filled","fills"},
"fills":{"fill","filled","filling"},
"find":{"found","finding","findings","finds"},
"finding":{"found","find","findings","finds"},
"findings":{"found","find","finding","finds"},
"finds":{"found","find","finding","findings"},
"found":{"find","finding","findings","finds"},
"fine":{"fineness","finer","finest","finely"},
"finely":{"fineness","finer","finest","fine"},
"fineness":{"finer","finest","fine","finely"},
"finer":{"fineness","finest","fine","finely"},
"finest":{"fineness","finer","fine","finely"},
"finish":{"finishes","finished","unfinished","finishing"},
"finished":{"finish","finishes","finishing"},
"finishes":{"finish","","finished","finishing"},
"finishing":{"finish","finishes","finished"},
"fire":{"fires","firing","fired"},
"fired":{"fire","fires","firing"},
"fires":{"fire","firing","fired"},
"firing":{"fire","fires","fired"},
"first":{"firstly"},
"firstly":{"first"},
"fish":{"fishes","fished","fishing","fisherman"},
"fished":{"fishes","fish","fishing","fisherman"},
"fishes":{"fish","fished","fishing","fisherman"},
"fishing":{"fishes","fish","fished","fisherman"},
"fisherman":{"fishes","fish","fished","fishing"},
"fit":{"fitter","fitted","fittest","fitness","fits","fitting"},
"fitness":{"fitter","fitted","fittest","fit","fits","fitting"},
"fits":{"fitter","fitted","fittest","fit","fitness","fitting"},
"fitted":{"fitter","fittest","fit","fitness","fits","fitting"},
"fitter":{"fitted","fittest","fit","fitness","fits","fitting"},
"fittest":{"fitter","fitted","fit","fitness","fits","fitting"},
"fitting":{"fitter","fitted","fittest","fit","fitness","fits"},
"five":{"fifth"},
"fives":{"fifth","five"},
"fifteen":{"fifteenth"},
"fifteenth":{"fifteenth"},
"fifth":{"fives","five"},
"fifthly":{"fifth","fives","five"},
"fifties":{"fifty","fiftieth"},
"fiftieth":{"fifty","fifties"},
"fifty":{"fiftieth","fifties"},
"fix":{"fixable","fixing","fixes","fixed","fix"},
"fixed":{"fixable","fixing","fixes","fix"},
"fixes":{"fixable","fixing","fixes","fixed","fix"},
"fixing":{"fixable","fixes","fixed","fix"},
"fixable":{"fixing","fixes","fixed","fix"},
"floor":{"floors"},
"floors":{"floor"},
"flow":{"flowing","flowed","flows"},
"flowed":{"flowing","flow","flows"},
"flows":{"flowing","flow","flowed"},
"flowing":{"flow","flowed","flows"},
"flower":{"flowers"},
"flowers":{"flower"},
"fly":{"flight","flies","flown","flights","flew","flying"},
"flew":{"flight","flies","flown","flights","fly","flying"},
"flown":{"flight","flies","flights","fly","flew","flying"},
"flying":{"flight","flies","flown","flights","fly","flew"},
"flight":{"flies","flights","fly"},
"flights":{"flight","flies"},
"flies":{"flies","flown","fly","flew","flying"},
"follow":{"follow","followed","following","follows"},
"followed":{"follow","followed","following","follows"},
"follower":{"followers"},
"followers":{"follower"},
"following":{"follow","followed","follows"},
"follows":{"follow","followed","following","follows"},
"food":{"foods"},
"foods":{"food"},
"force":{"forced","forcing","forceful","forces","forcefully"},
"forced":{"force","forcing","forceful","forces","forcefully"},
"forces":{"force","forced","forcing","forceful","forcefully"},
"forcing":{"force","forced","forceful","forces","forcefully"},
"forceful":{"force","forced","forcing","forces","forcefully"},
"forcefully":{"force","forced","forcing","forceful","forces"},
"foreign":{"foreigners","foreigner"},
"foreigner":{"foreigners","foreigner"},
"foreigners":{"foreign","foreigner"},
"forest":{"forested","forests","foresting"},
"forests":{"forested","forest","foresting"},
"foresting":{"forested","forest","forests"},
"forested":{"forest","forests","foresting"},
"forget":{"forgets","forgotten","forgot","forgetting"},
"forgets":{"forgotten","forgot","forgetting","forget"},
"forgetting":{"forgets","forgotten","forgot","forget"},
"forgot":{"forgets","forgotten","forgetting","forget"},
"forgotten":{"forgets","forgot","forgetting","forget"},
"form":{"formation","formed","forming","forms","from"},
"formation":{"form","formed","forming","forms"},
"formed":{"formation","form","forming","forms"},
"forming":{"formation","form","formed","forming","forms"},
"forms":{"formation","form","formed","forming"},
"former":{"formerly"},
"formerly":{"former"},
"fortune":{"fortunate","unfortunately","fortunately","fortunes"},
"fortunate":{"fortune","fortunately","fortunes"},
"fortunately":{"fortune","fortunate","fortunes"},
"fortunes":{"fortune","fortunate","fortunately","fortunes"},
"unfortunately":{"unfortunate"},
"unfortunate":{"unfortunately"},
"four":{"fours","fourth"},
"fours":{"four","fourth"},
"forties":{"fortieth"},
"forty":{"forties","fortieth"},
"fourteen":{"fourteenth"},
"fourteenth":{"fourteen"},
"fourth":{"fours","forties","fortieth"},
"fourthly":{"fourth","fortieth"},
"fortieth":{"forty"},
"free":{"freed","freedom","freedoms","freest","freely","freer","freeing"},
"freed":{"freedom","freedoms","freest","freely","freer","freeing","free"},
"freedom":{"freed","freedoms","freest","freely","freer","freeing","free"},
"freedoms":{"freed","freedom","freest","freely","freer","freeing","free"},
"freeing":{"freed","freedom","freedoms","freest","freely","freer","free"},
"freely":{"freed","freedom","freedoms","freest","freer","freeing","free"},
"freer":{"freed","freedom","freedoms","freest","freely","freeing","free"},
"freest":{"freed","freedom","freedoms","freely","freer","freeing","free"},
"fresh":{"freshly","freshness","fresher","freshest"},
"freshness":{"fresh","freshness","fresher","freshest","fresh"},
"fresher":{"freshly","freshness","freshest","fresh"},
"freshest":{"freshly","freshness","fresher","fresh"},
"freshly":{"fresh"},
"friday":{"fridays"},
"fridays":{"friday"},
"friend":{"friendly","friends"},
"friendly":{"friend","friends","friendships","friendship"},
"friends":{"friendly","friend","friendships","friendship"},
"friendship":{"friendly","friend","friends","friendships"},
"friendships":{"friendly","friend","friends","friendship"},
"full":{"fullness","fullest","fully","fuller"},
"fuller":{"full","fullest","fully"},
"fullest":{"full","fully","fuller"},
"fullness":{"full","fullest","fully","fuller"},
"fully":{"fullness","full","fullest","fully","fuller"},
"furnish":{"furnishing","furniture","furnishes","furnished"},
"furnishes":{"furnishing","furnish","furniture","furnished"},
"furnished":{"furnishing","furnish","furniture","furnishes"},
"furnishing":{"furnish","furniture","furnishes","furnished"},
"furniture":{"furnishing","furnish","furnishes","furnished"},
"future":{"future","futures"},
"futures":{"future","futures"},
"gain":{"gains","gaining","gained"},
"gained":{"gains","gaining","gain"},
"gaining":{"gains","gaining","gained","gain"},
"gains":{"gains","gaining","gained","gain"},
"game":{"games"},
"games":{"game"},
"garden":{"gardens","gardeners","gardener"},
"gardener":{"gardens","gardeners","garden"},
"gardeners":{"gardens","garden","gardener"},
"gardens":{"gardeners","garden","gardener"},
"gas":{"gases"},
"gases":{"gas"},
"gate":{"gates"},
"gates":{"gate"},
"gather":{"gatherings","gathers","gathering","gathered"},
"gathered":{"gatherings","gathers","gather","gathering"},
"gathering":{"gatherings","gathers","gather","gathered"},
"gatherings":{"gathers","gather","gathering","gathered"},
"gathers":{"gatherings","gather","gathering","gathered"},
"general":{"generalizations","generalisable","generality","generalisations","generalisation","generalised","generalise","generals","generally"},
"generally":{"generalizations","generalisable","generality","generalisations","generalisation","generalised","generalise","generals","general"},
"generals":{"generalizations","generalisable","generality","generalisations","generalisation","generalised","generalise","generally","general"},
"generalise":{"generalizations","generalisable","generality","generalisations","generalisation","generalised","generals","generally","general"},
"generalisable":{"generalizations","generality","generalisations","generalisation","generalised","generalise","generals","generally","general"},
"generalised":{"generalizations","generalisable","generality","generalisations","generalisation","generalise","generals","generally","general"},
"generalisation":{"generalizations","generalisable","generality","generalisations","generalised","generalise","generals","generally","general"},
"generalisations":{"eneralisable","generality","generalisations","generalisation","generalised","generalise","generals","generally","general"},
"generality":{"generalizations","generalisable","generalisations","generalisation","generalised","generalise","generals","generally","general"},
"generalizations":{"generalisable","generality","generalisations","generalisation","generalised","generalise","generals","generally","general"},
"gentle":{"gently","gentlemen","gentleman"},
"gentleman":{"gently","gentlemen","gentle"},
"gentlemen":{"gently","gentleman","gentle"},
"gently":{"gentlemen","gentleman","gentle"},
"get":{"gets","getting","got","gotten"},
"gets":{"get","getting","got","gotten"},
"getting":{"get","gets","got","gotten"},
"got":{"get","gets","getting","gotten"},
"gotten":{"get","gets","getting","got"},
"gift":{"gifted","gifts"},
"gifts":{"gifted","gift"},
"gifted":{"gifts","gift"},
"girl":{"girls"},
"girls":{"girl"},
"give":{"giving","gives","given","gave"},
"gave":{"giving","gives","give","gave"},
"given":{"giving","gives","give","gave"},
"gives":{"giving","given","give","gave"},
"giving":{"gives","given","give","gave"},
"glad":{"gladder","gladdest","gladly","gladness"},
"gladder":{"gladdest","gladly","gladness","glad"},
"gladdest":{"gladder","gladly","gladness","glad"},
"gladly":{"gladder","gladdest","gladness","glad"},
"gladness":{"gladder","gladdest","gladly","glad"},
"glass":{"glasses"},
"glasses":{"glass"},
"go":{"goes","going","gone","went"},
"goes":{"go","going","gone","went"},
"going":{"go","goes","gone","went"},
"gone":{"go","goes","going","went"},
"went":{"go","goes","going","gone"},
"god":{"goddess","gods"},
"gods":{"goddess","god"},
"goddess":{"gods","god"},
"gold":{"golden"},
"golden":{"gold"},
"good":{"goodness","goodbyes","goodbye","well"},
"goodbye":{"goodness","goodbye","good"},
"goodbyes":{"goodness","goodbye","good"},
"goodness":{"goodbyes","goodbye","good"},
"great":{"greatly","greatest","greater","greatness"},
"greater":{"greatly","greatest","greatness","great"},
"greatest":{"greatly","greater","greatness","great"},
"greatly":{"greatest","greater","greatness","great"},
"greatness":{"greatly","greatest","greater","great"},
"green":{"greenness","greenish","greenest","greener"},
"greener":{"greenness","greenish","greenest","green"},
"greenest":{"greenness","greenish","green","greener"},
"greenness":{"greenish","greenest","green","greener"},
"greenish":{"greenness","greenest","green","greener"},
"ground":{"grounds","grounding","grounded"},
"grounded":{"grounds","grounding","ground"},
"grounds":{"grounding","ground","grounded"},
"grounding":{"grounds","ground","grounded"},
"group":{"groups","groupings","grouping","grouped"},
"grouped":{"groups","group","groupings","grouping"},
"grouping":{"groups","group","groupings","grouped"},
"groupings":{"groups","group","grouping","grouped"},
"groups":{"group","groupings","grouping","grouped"},
"grow":{"grown","grew","growth","grows","growing"},
"grew":{"grown","grow","growth","grows","growing"},
"growing":{"grown","grew","grow","growth","grows"},
"grown":{"grew","grow","growth","grows","growing"},
"grows":{"grown","grew","grow","growth","growing"},
"growth":{"grown","grew","grow","grows","growing"},
"half":{"halves"},
"halves":{"half"},
"hand":{"handwriting","hands","handing","handfuls","handful","handed"},
"handed":{"handwriting","hands","handing","handfuls","handful","hand"},
"handful":{"handwriting","hands","handing","handfuls","hand","handed"},
"handfuls":{"handwriting","hands","handing","handful","hand","handed"},
"handing":{"handwriting","hands","handfuls","handful","hand","handed"},
"hands":{"handwriting","handing","handfuls","handful","hand","handed"},
"handwriting":{"hands","handing","handfuls","handful","hand","handed"},
"hang":{"hanging","hanged","hang","hangs"},
"hanged":{"hung","hanging","hang","hangs"},
"hanging":{"hung","hanged","hang","hangs"},
"hangs":{"hung","hanging","hanged","hang"},
"hung":{"hanging","hanged","hang","hangs"},
"happen":{"happened","happens","happening"},
"happened":{"happen","happens","happening"},
"happening":{"happened","happen","happens"},
"happens":{"happened","happen","happening"},
"happy":{"happily","happiness","happier","happiest"},
"happier":{"happily","happiness","happy","happiest"},
"happiest":{"happily","happiness","happy","happier"},
"happily":{"happiness","happy","happier","happiest"},
"happiness":{"happily","happy","happier","happiest"},
"hard":{"hardening","hardness","hardest","hardships","hardship","harder","hardens","hardened","harden","hardly"},
"harden":{"hardening","hardness","hardest","hardships","hardship","harder","hardens","hard","hardened"},
"hardened":{"hardening","hardness","hardest","hardships","hardship","harder","hardens","hard","hardened","harden"},
"hardening":{"hardness","hardest","hardships","hardship","harder","hardens","hard","hardened","harden"},
"hardens":{"hardening","hardness","hardest","hardships","hardship","harder","hard","hardened","harden"},
"harder":{"hardening","hardness","hardest","hardships","hardship","hardens","hard","hardened","harden"},
"hardest":{"hardening","hardness","hardships","hardship","harder","hardens","hard","hardened","harden"},
"hardness":{"hardening","hardest","hardships","hardship","harder","hardens","hard","hardened","harden"},
"hardship":{"hardening","hardness","hardest","hardships","harder","hardens","hard","hardened","harden"},
"hardships":{"hardening","hardness","hardest","hardship","harder","hardens","hard","hardened","harden"},
"have":{"has","had","having"},
"had":{"has","have","having"},
"has":{"has","had","have","having","is"},
"haven":{"has","had","have","having"},
"haves":{"has","had","have","having"},
"having":{"has","had","have","having"},
"he":{"his","him","himself"},
"him":{"he","himself","his"},
"himself":{"he","him","his"},
"his":{"he","him","himself"},
"head":{"headed","heads","heading"},
"headed":{"heads","heading","head"},
"heading":{"headed","heads","head"},
"heads":{"headed","heading","head"},
"hear":{"heard","hearer","hears","hearing"},
"heard":{"hear","hearer","hears","hearing"},
"hearer":{"heard","hear","hears","hearing"},
"hearing":{"heard","hear","hearer","hears"},
"hears":{"heard","hear","hearer","hearing"},
"heart":{"hearts"},
"hearts":{"heart"},
"heat":{"heating","heated","heats"},
"heated":{"heating","heat","heats"},
"heating":{"heat","heated","heats"},
"heats":{"heating","heat","heated"},
"heaven":{"heavens","heavenly"},
"heavenly":{"heavens","heaven"},
"heavens":{"heaven","heavenly"},
"heavy":{"heavier","heaviest","heavily"},
"heavier":{"heavy","heaviest","heavily"},
"heaviest":{"heavy","heavier","heavily"},
"heavily":{"heavy","heavier","heaviest"},
"help":{"helps","helped","helpful","helping","helpless","helplessly"},
"helped":{"helps","help","helpful","helping","helpless","helplessly"},
"helpful":{"helps","help","helped","helping","helpless","helplessly"},
"helping":{"helps","help","helped","helpful","helpless","helplessly",""},
"helpless":{"helplessly"},
"helplessly":{"helpless"},
"helps":{"help","helped","helpful","helping"},
"helper":{"helpers"},
"helpers":{"helper"},
"high":{"highway","highly","highness","highest","higher","highways"},
"higher":{"highway","highly","highness","highest","high","highways"},
"highest":{"highway","highly","highness","higher","high","highways"},
"highly":{"highway","highness","highest","higher","high","highways"},
"highness":{"highway","highly","highest","higher","high","highways"},
"highway":{"highly","highness","highest","higher","high","highways"},
"highways":{"highway","highly","highness","highest","higher","high"},
"hill":{"hillside","hills","hilly"},
"hills":{"hillside","hilly","hill"},
"hillside":{"hills","hilly","hill"},
"hilly":{"hillside","hills","hill"},
"history":{"histories","historian","historical","historic"},
"historian":{"history","histories","historical","historic"},
"historic":{"history","histories","historian","historical"},
"historical":{"history","histories","historian","historic"},
"histories":{"history","historian","historical","historic"},
"hold":{"holds","holders","holding","held"},
"held":{"holds","holders","hold","holding"},
"holders":{"holds","hold","holding","held"},
"holding":{"holds","holders","hold","held"},
"holds":{"holders","hold","holding","held"},
"home":{"homeless","homes"},
"homeless":{"homes","home"},
"homes":{"homeless","home"},
"honour":{"honoring","honourably","honourable","honors","honorary","honorably","honorable","honored"},
"dishonour":{"dishonourable"},
"dishonourable":{"dishonour"},
"honor":{"honoring","honourably","honourable","honors","honorary","honorably","honorable","honored"},
"honorable":{"honoring","honour","honourably","honors","honorary","honorably","honor","honored"},
"honorably":{"honoring","honour","honourable","honors","honorary","honorably","honor","honored"},
"honorary":{"honoring","honour","honourably","honourable","honors","honorary","honorably","honorable","honor","honored"},
"honored":{"honoring","honour","honourably","honourable","honors","honorary","honorably","honorable","honor","honored"},
"honoring":{"honour","honourably","honourable","honors","honorary","honorably","honorable","honor","honored"},
"honors":{"honoring","honour","honourably","honourable","honorary","honorably","honorable","honor","honored"},
"honourable":{"honoring","honour","honourably","honors","honorary","honorably","honor","honored"},
"honourably":{"honoring","honour","honourable","honors","honorary","honorably","honorable","honor","honored"},
"hope":{"hopeful","hopes","hopelessness","hopeless","hoped","hoping"},
"hoped":{"hopeful","hopes","hopelessness","hopeless","hope","hoping"},
"hopeful":{"hopes","hopelessness","hopeless","hoped","hope","hoping"},
"hopeless":{"hopeful","hopes","hopelessness","hoped","hope","hoping"},
"hopelessness":{"hopelessness","hopeless"},
"hopes":{"hopeful","hopelessness","hopeless","hoped","hope","hoping"},
"hoping":{"hopeful","hopes","hopelessness","hopeless","hoped","hope"},
"horse":{"horses"},
"horses":{"horse"},
"hot":{"hottest","hotness","hotly","hotter"},
"hotly":{"hottest","hotness","hot","hotter"},
"hotness":{"hottest","hotly","hot","hotter"},
"hotter":{"hottest","hotness","hotly","hot"},
"hottest":{"hotness","hotly","hot","hotter"},
"hour":{"hours","hourly"},
"hourly":{"hours","hour"},
"hours":{"hour","hourly"},
"house":{"housed","houses","housing"},
"housed":{"houses","house","housing"},
"housing":{"housed","houses","house"},
"houses":{"housed","house","housing"},
"human":{"humans"},
"humans":{"human"},
"hundred":{"hundredth","hundreds"},
"hundreds":{"hundredth","hundred"},
"hundredth":{"hundreds","hundred"},
"husband":{"husbands"},
"husbands":{"husband"},
"i":{"mine","myself","me"},
"me":{"mine","i","myself","my"},
"mine":{"mine","i","myself","me"},
"my":{"mine","i","myself","me"},
"myself":{"mine","i","myself","me","my"},
"idea":{"ideas",""},
"ideas":{"idea"},
"ill":{"illnesses","illness"},
"illness":{"illnesses","ill"},
"illnesses":{"illness","ill"},
"important":{"importance","importantly"},
"importance":{"important","importantly"},
"unimportant":{"unimportance"},
"unimportance":{"unimportant"},
"importantly":{"importance","important","importantly"},
"in":{"for","of","on","to","with","at","by","from","about"},
"inner":{"in"},
"inch":{"inches"},
"inches":{"inch"},
"include":{"inclusion","inclusive","including","includes","included"},
"included":{"inclusion","inclusive","including","includes","include"},
"includes":{"inclusion","inclusive","including","included","include"},
"including":{"inclusion","inclusive","ncludes","included","include"},
"inclusive":{"inclusion","including","includes","included","include"},
"inclusion":{"inclusive","including","includes","included","include"},
"increase":{"increasing","increases","increased","increasingly"},
"increased":{"increasing","increases","increase","increasingly"},
"increases":{"increasing","increased","increase","increasingly"},
"increasing":{"increases","increased","increase","increasingly"},
"increasingly":{"increasing","increases","increased","increase"},
"independent":{"independently","independence"},
"independently":{"independent","independence"},
"independence":{"independently","independent"},
"industry":{"industries","industrial","industrially"},
"industrial":{"industry","industries","industrially"},
"industrially":{"industry","industries","industrial"},
"industries":{"industry","industrial","industrially"},
"influence":{"influencing","influential","influences","influenced"},
"influenced":{"influencing","influential","influences","influence"},
"influences":{"influencing","influential","influenced","influence"},
"influencing":{"influential","influences","influenced","influence"},
"influential":{"influencing","influences","influenced","influence"},
"interest":{"interested","interests","interesting"},
"interested":{"interests","interesting","interest"},
"interesting":{"interested","interests","interest"},
"interests":{"interested","interesting","interest"},
"introduce":{"introduces","introduced","introduction","introductions","introducing","introductory"},
"introduced":{"introduces","introduction","introduce","introductions","introducing","introductory"},
"introduces":{"introduced","introduction","introduce","introductions","introducing","introductory"},
"introducing":{"introduces","introduced","introduction","introduce","introductions","introductory"},
"introduction":{"introduces","introduced","introduce","introductions","introducing","introductory"},
"introductions":{"introduces","introduced","introduction","introduce","introducing","introductory"},
"introductory":{"introduces","introduced","introduction","introduce","introductions","introducing"},
"it":{"its","itself"},
"its":{"it","its","itself"},
"itself":{"it","its"},
"join":{"oined","joining","joins"},
"joined":{"join","joining","joins"},
"joining":{"join","joined","joins"},
"joins":{"join","joined","joining"},
"joint":{"jointed","disjointed","jointly","joints"},
"jointed":{"joint","jointly","joints"},
"joints":{"joint","jointed","jointly"},
"jointly":{"joint","jointed","joints"},
"joy":{"joyful","joyfully","joys"},
"joyful":{"joy","joyfully","joys"},
"joyfully":{"joy","joyful","joys"},
"joys":{"joy","joyful","joyfully"},
"judge":{"judging","judgments","judged","judgement","judgements","judgemental","judges","judgment"},
"judged":{"judging","judgments","judge","judgement","judgements","judgemental","judges","judgment"},
"judges":{"judging","judgments","judged","judge","judgement","judgements","judgemental","judgment"},
"judging":{"judgments","judged","judge","judgement","judgements","judgemental","judges","judgment"},
"judgment":{"judging","judgments","judged","judge","judgements","judgemental","judges","judgment"},
"judgments":{"judging","judged","judge","judgement","judgements","judgemental","judges","judgment"},
"judgement":{"judging","judgments","judged","judge","judgements","judgemental","judges","judgment"},
"judgements":{"judging","judged","judge","judgement","judgements","judgemental","judges","judgment"},
"judgemental":{"judging","judgments","judged","judge","judgement","judgements","judges","judgment"},
"just":{"justly","unjustly"},
"justly":{"ust"},
"unjust":{"unjustly"},
"unjustly":{"unjust"},
"keep":{"kept","keeps","keeping","keepers"},
"keepers":{"kept","keeps","keeping","keep"},
"keeping":{"kept","keeps","keepers","keep"},
"keeps":{"kept","keeping","keepers","keep"},
"kept":{"keeps","keeping","keepers","keep"},
"kill":{"killers","kills","killer","killed","killing"},
"killed":{"killers","kills","killer","killing","kill"},
"killer":{"killers","kills","killed","killing","kill"},
"killers":{"kills","killer","killed","killing","kill"},
"killing":{"killers","kills","killer","killed","kill"},
"kills":{"killers","killer","killed","killing","kill"},
"kind":{"kindly","kinds","kindness"},
"kindly":{"kind","kinds","kindness"},
"kindness":{"kindly","kind","kinds"},
"kinds":{"kindly","kind","kindness"},
"king":{"kingdoms","kings","kingdom"},
"kings":{"kingdoms","king","kingdom"},
"kingdom":{"kingdoms","kings","king"},
"kingdoms":{"kings","king","kingdom"},
"know":{"known","knew","knowing","knows"},
"knew":{"known","know","knowing","knows"},
"knowing":{"known","know","knew","knows"},
"knowledge":{"knowledgeable"},
"known":{"know","knew","knowing","knows"},
"knows":{"known","know","knew","knowing"},
"knowledgeable":{"knowledge"},
"lack":{"lacks","lacking","lacked"},
"lacked":{"lacks","lacking","lack"},
"lacking":{"lacks","lacked","lack"},
"lacks":{"lacking","lacked","lack"},
"lady":{"ladies"},
"ladies":{"lady"},
"lake":{"lakes"},
"lakes":{"lakes"},
"land":{"lands","landlords","landing","landed"},
"landed":{"lands","landlords","land","landing"},
"landing":{"lands","landlords","land","landed"},
"lands":{"landlords","land","landing","landed"},
"landlords":{"lands","land","landing","landed"},
"language":{"languages"},
"languages":{"language"},
"large":{"largest","largely","larger"},
"largely":{"large","largest","larger"},
"larger":{"largest","largely","larger"},
"largest":{"large","largely","larger"},
"last":{"lasts","lasted","lasting","lastly"},
"lasted":{"lasts","last","lasting","lastly"},
"lasting":{"lasts","last","lasted","lastly"},
"lasts":{"last","lasted","lasting","lastly"},
"lastly":{"lasts","last","lasted","lasting"},
"late":{"lately","latest","lateness","later"},
"lately":{"late","latest","lateness","later"},
"lateness":{"late","lately"},
"later":{"late","lately","latest","lateness"},
"latest":{"late","lately","lateness"},
"laugh":{"laugh","laughs","laughed","laughing","laughable"},
"laughs":{"laugh","laughs","laughed","laughing","laughable"},
"laughed":{"laugh","laughs","laughed","laughing","laughable"},
"laughing":{"laugh","laughs","laughed","laughing","laughable"},
"laughable":{"laugh","laughs","laughed","laughing","laughable"},
"law":{"lawyers","lawful","lawfully","unlawful","lawless","laws","lawyer","law"},
"laws":{"lawyers","lawful","lawfully","unlawful","lawless","laws","lawyer","law"},
"lawyer":{"lawyers","lawful","lawfully","unlawful","lawless","laws","lawyer","law"},
"lawyers":{"lawyers","lawful","lawfully","unlawful","lawless","laws","lawyer","law"},
"lawful":{"lawyers","lawful","lawfully","unlawful","lawless","laws","lawyer","law"},
"lawfully":{"lawyers","lawful","lawfully","unlawful","lawless","laws","lawyer","law"},
"unlawful":{"lawyers","lawful","lawfully","unlawful","lawless","laws","lawyer","law"},
"lawless":{"lawyers","lawful","lawfully","unlawful","lawless","laws","lawyer","law"},
"lay":{"laid","lays","lay","laying"},
"laid":{"laid","lays","lay","laying"},
"laying":{"laid","lays","lay","laying"},
"lays":{"laid","lays","lay","laying"},
"lead":{"led","leads","misled","leading","leadership","leaders","mislead","leaded","lead","misleading","leader"},
"leaded":{"led","leads","misled","leading","leadership","leaders","mislead","leaded","lead","misleading","leader"},
"leader":{"led","leads","misled","leading","leadership","leaders","mislead","leaded","lead","misleading","leader"},
"leaders":{"led","leads","misled","leading","leadership","leaders","mislead","leaded","lead","misleading","leader"},
"leadership":{"led","leads","misled","leading","leadership","leaders","mislead","leaded","lead","misleading","leader"},
"leading":{"led","leads","misled","leading","leadership","leaders","mislead","leaded","lead","misleading","leader"},
"leads":{"led","leads","misled","leading","leadership","leaders","mislead","leaded","lead","misleading","leader"},
"mislead":{"led","leads","misled","leading","leadership","leaders","mislead","leaded","lead","misleading","leader"},
"misleading":{"led","leads","misled","leading","leadership","leaders","mislead","leaded","lead","misleading","leader"},
"misled":{"led","leads","misled","leading","leadership","leaders","mislead","leaded","lead","misleading","leader"},
"led":{"led","leads","misled","leading","leadership","leaders","mislead","leaded","lead","misleading","leader"},
"learn":{"learnt","learns","learning","learners","learner","learned","learn"},
"learned":{"learnt","learns","learning","learners","learner","learned","learn"},
"learner":{"learnt","learns","learning","learners","learner","learned","learn"},
"learners":{"learnt","learns","learning","learners","learner","learned","learn"},
"learning":{"learnt","learns","learning","learners","learner","learned","learn"},
"learns":{"learnt","learns","learning","learners","learner","learned","learn"},
"learnt":{"learnt","learns","learning","learners","learner","learned","learn"},
"leave":{"leave","leaves","leaving"},
"leaves":{"leave","leaves","leaving"},
"leaving":{"leave","leaves","leaving"},
"left":{"leftists","left","leftist"},
"leftist":{"leftists","left","leftist"},
"leftists":{"leftists","left","leftist"},
"length":{"lengthy","lengths","lengthening","length","lengthen"},
"lengthening":{"lengthy","lengths","lengthening","length","lengthen"},
"lengths":{"lengthy","lengths","lengthening","length","lengthen"},
"lengthy":{"lengthy","lengths","lengthening","length","lengthen"},
"lengthen":{"lengthy","lengths","lengthening","length","lengthen"},
"less":{"lesser","less","lessen","lessened","lessening","least"},
"lessen":{"lesser","less","lessen","lessened","lessening","least"},
"lessened":{"lesser","less","lessen","lessened","lessening","least"},
"lessening":{"lesser","less","lessen","lessened","lessening","least"},
"lesser":{"lesser","less","lessen","lessened","lessening","least"},
"least":{"lesser","less","lessen","lessened","lessening","least"},
"let":{"lets","letting","let"},
"lets":{"lets","letting","let"},
"letting":{"lets","letting","let"},
"letter":{"letter","letters"},
"letters":{"letter","letters"},
"level":{"levelled","level","levels","leveller","levelling"},
"levelled":{"levelled","level","levels","leveller","levelling"},
"leveller":{"levelled","level","levels","leveller","levelling"},
"levelling":{"levelled","level","levels","leveller","levelling"},
"levels":{"levelled","level","levels","leveller","levelling"},
"library":{"librarian","library","libraries","librarians"},
"librarian":{"librarian","library","libraries","librarians"},
"librarians":{"librarian","library","libraries","librarians"},
"libraries":{"librarian","library","libraries","librarians"},
"lie":{"lies","lying","lied","liars","lie","liar"},
"liar":{"lies","lying","lied","liars","lie","liar"},
"liars":{"lies","lying","lied","liars","lie","liar"},
"lied":{"lies","lying","lied","liars","lie","liar"},
"lies":{"lies","lying","lied","liars","lie","liar"},
"lying":{"lies","lying","lied","liars","lie","liar"},
"life":{"lifetimes","lifelike","lifesize","lifetime","lifelong","lives"},
"lifetime":{"lifetimes","lifelike","lifesize","lifetime","lifelong","life"},
"lifetimes":{"lifetimes","lifelike","lifesize","lifetime","lifelong","life"},
"lifelike":{"lifetimes","lifelike","lifesize","lifetime","lifelong","life"},
"lifelong":{"lifetimes","lifelike","lifesize","lifetime","lifelong","life"},
"lift":{"lifting","lifted","lift","lifts"},
"lifted":{"lifting","lifted","lift","lifts"},
"lifting":{"lifting","lifted","lift","lifts"},
"lifts":{"lifting","lifted","lift","lifts"},
"light":{"lightest","lit","lighten","lightweight","lights","lightly","lighting","light","lighted","lighter","lightness"},
"lighted":{"lightest","lit","lighten","lightweight","lights","lightly","lighting","light","lighted","lighter","lightness"},
"lighten":{"lightest","lit","lighten","lightweight","lights","lightly","lighting","light","lighted","lighter","lightness"},
"lighter":{"lightest","lit","lighten","lightweight","lights","lightly","lighting","light","lighted","lighter","lightness"},
"lightest":{"lightest","lit","lighten","lightweight","lights","lightly","lighting","light","lighted","lighter","lightness"},
"lighting":{"lightest","lit","lighten","lightweight","lights","lightly","lighting","light","lighted","lighter","lightness"},
"lightly":{"lightest","lit","lighten","lightweight","lights","lightly","lighting","light","lighted","lighter","lightness"},
"lightness":{"lightest","lit","lighten","lightweight","lights","lightly","lighting","light","lighted","lighter","lightness"},
"lights":{"lightest","lit","lighten","lightweight","lights","lightly","lighting","light","lighted","lighter","lightness"},
"lightweight":{"lightest","lit","lighten","lightweight","lights","lightly","lighting","light","lighted","lighter","lightness"},
"lit":{"lightest","lit","lighten","lightweight","lights","lightly","lighting","light","lighted","lighter","lightness"},
"like":{"liked","disliked","disliking","dislikes","dislike","unlike","liking","like","likes"},
"liked":{"liked","disliked","disliking","dislikes","dislike","unlike","liking","like","likes"},
"likes":{"liked","disliked","disliking","dislikes","dislike","unlike","liking","like","likes"},
"liking":{"liked","disliked","disliking","dislikes","dislike","unlike","liking","like","likes"},
"unlike":{"liked","disliked","disliking","dislikes","dislike","unlike","liking","like","likes"},
"dislike":{"liked","disliked","disliking","dislikes","dislike","unlike","liking","like","likes"},
"dislikes":{"liked","disliked","disliking","dislikes","dislike","unlike","liking","like","likes"},
"disliked":{"liked","disliked","disliking","dislikes","dislike","unlike","liking","like","likes"},
"disliking":{"liked","disliked","disliking","dislikes","dislike","unlike","liking","like","likes"},
"likely":{"unlikely","likeliest","likely","likelier","likelihood"},
"likelier":{"unlikely","likeliest","likely","likelier","likelihood"},
"likeliest":{"unlikely","likeliest","likely","likelier","likelihood"},
"likelihood":{"unlikely","likeliest","likely","likelier","likelihood"},
"unlikely":{"unlikely","likeliest","likely","likelier","likelihood"},
"limit":{"limit","limitation","limitations","limiting","limits","unlimited","limited"},
"limitation":{"limit","limitation","limitations","limiting","limits","unlimited","limited"},
"limitations":{"limit","limitation","limitations","limiting","limits","unlimited","limited"},
"limited":{"limit","limitation","limitations","limiting","limits","unlimited","limited"},
"limiting":{"limit","limitation","limitations","limiting","limits","unlimited","limited"},
"limits":{"limit","limitation","limitations","limiting","limits","unlimited","limited"},
"unlimited":{"limit","limitation","limitations","limiting","limits","unlimited","limited"},
"line":{"lining","lined","line","lines"},
"lines":{"lining","lined","line","lines"},
"lined":{"lining","lined","line","lines"},
"lining":{"lining","lined","line","lines"},
"lip":{"lip","lips"},
"lips":{"lip","lips"},
"listen":{"listen","listeners","listener","listened","listens","listening"},
"listened":{"listen","listeners","listener","listened","listens","listening"},
"listener":{"listen","listeners","listener","listened","listens","listening"},
"listeners":{"listen","listeners","listener","listened","listens","listening"},
"listening":{"listen","listeners","listener","listened","listens","listening"},
"listens":{"listen","listeners","listener","listened","listens","listening"},
"literature":{"literary","literature"},
"literary":{"literary","literature"},
"little":{"little","littlest","littler"},
"littler":{"little","littlest","littler"},
"littlest":{"little","littlest","littler"},
"live":{"living","lively","liveliest","lived","live","lives"},
"lived":{"living","lively","liveliest","lived","live","lives"},
"liveliest":{"living","lively","liveliest","lived","live","lives"},
"lively":{"living","lively","liveliest","lived","live","lives"},
"lives":{"living","lively","liveliest","lived","live","lives"},
"living":{"living","lively","liveliest","lived","live","lives"},
"local":{"local","locals","locally"},
"locally":{"local","locals","locally"},
"locals":{"local","locals","locally"},
"long":{"long","longer","longest"},
"longer":{"long","longer","longest"},
"longest":{"long","longer","longest"},
"look":{"looked","looking","look","looks","outlook"},
"looked":{"looked","looking","look","looks","outlook"},
"looking":{"looked","looking","look","looks","outlook"},
"looks":{"looked","looking","look","looks","outlook"},
"outlook":{"looked","looking","look","looks","outlook"},
"lord":{"lordship","lords","lord","lordships"},
"lords":{"lordship","lords","lord","lordships"},
"lordship":{"lordship","lords","lord","lordships"},
"lordships":{"lordship","lords","lord","lordships"},
"lose":{"loses","lost","losing","lose","losers"},
"losers":{"loses","lost","losing","lose","losers"},
"loses":{"loses","lost","losing","lose","losers"},
"losing":{"loses","lost","losing","lose","losers"},
"lost":{"loses","lost","losing","lose","losers"},
"loss":{"losses","loss"},
"losses":{"losses","loss"},
"love":{"lover","lovable","loving","lovely","loved","love","loves"},
"loved":{"lover","lovable","loving","lovely","loved","love","loves"},
"lovely":{"lover","lovable","loving","lovely","loved","love","loves"},
"loves":{"lover","lovable","loving","lovely","loved","love","loves"},
"loving":{"lover","lovable","loving","lovely","loved","love","loves"},
"lovable":{"lover","lovable","loving","lovely","loved","love","loves"},
"lover":{"lover","lovable","loving","lovely","loved","love","loves"},
"low":{"lowering","lower","lowered","lowest","low"},
"lower":{"lowering","lower","lowered","lowest","low"},
"lowered":{"lowering","lower","lowered","lowest","low"},
"lowest":{"lowering","lower","lowered","lowest","low"},
"lowering":{"lowering","lower","lowered","lowest","low"},
"machine":{"machine","machinery","machines"},
"machinery":{"machine","machinery","machines"},
"machines":{"machine","machinery","machines"},
"main":{"mainly","main"},
"mainly":{"mainly","main"},
"make":{"made","make","makers","makes","making","maker"},
"made":{"made","make","makers","makes","making","maker"},
"maker":{"made","make","makers","makes","making","maker"},
"makers":{"made","make","makers","makes","making","maker"},
"makes":{"made","make","makers","makes","making","maker"},
"making":{"made","make","makers","makes","making","maker"},
"man":{"man","mankind","men","manly","manhood","manliness"},
"mankind":{"man","mankind","men","manly","manhood","manliness"},
"men":{"man","mankind","men","manly","manhood","manliness"},
"manly":{"man","mankind","men","manly","manhood","manliness"},
"manhood":{"man","mankind","men","manly","manhood","manliness"},
"manliness":{"man","mankind","men","manly","manhood","manliness"},
"manner":{"manner","manners"},
"manners":{"manner","manners"},
"manufacture":{"manufacture","manufacturers","manufactures","manufacturing","manufactured","manufacturer"},
"manufactured":{"manufacture","manufacturers","manufactures","manufacturing","manufactured","manufacturer"},
"manufacturing":{"manufacture","manufacturers","manufactures","manufacturing","manufactured","manufacturer"},
"manufactures":{"manufacture","manufacturers","manufactures","manufacturing","manufactured","manufacturer"},
"manufacturers":{"manufacture","manufacturers","manufactures","manufacturing","manufactured","manufacturer"},
"manufacturer":{"manufacture","manufacturers","manufactures","manufacturing","manufactured","manufacturer"},
"march":{"march","marching","marches","marchers","marched"},
"marched":{"march","marching","marches","marchers","marched"},
"marchers":{"march","marching","marches","marchers","marched"},
"marches":{"march","marching","marches","marchers","marched"},
"marching":{"march","marching","marches","marchers","marched"},
"mark":{"marks","marking","markers","mark","marked","marker"},
"marked":{"marks","marking","markers","mark","marked","marker"},
"marker":{"marks","marking","markers","mark","marked","marker"},
"markers":{"marks","marking","markers","mark","marked","marker"},
"marking":{"marks","marking","markers","mark","marked","marker"},
"marks":{"marks","marking","markers","mark","marked","marker"},
"market":{"markets","marketing","marketed","market"},
"marketed":{"markets","marketing","marketed","market"},
"marketing":{"markets","marketing","marketed","market"},
"markets":{"markets","marketing","marketed","market"},
"marry":{"marrying","marries","married","marriages","marriage","marry"},
"marriage":{"marrying","marries","married","marriages","marriage","marry"},
"marriages":{"marrying","marries","married","marriages","marriage","marry"},
"married":{"marrying","marries","married","marriages","marriage","marry"},
"marries":{"marrying","marries","married","marriages","marriage","marry"},
"marrying":{"marrying","marries","married","marriages","marriage","marry"},
"mass":{"mass","masses"},
"masses":{"mass","masses"},
"master":{"mastered","masters","mastery","masterful","mastering","master"},
"masters":{"mastered","masters","mastery","masterful","mastering","master"},
"mastered":{"mastered","masters","mastery","masterful","mastering","master"},
"mastering":{"mastered","masters","mastery","masterful","mastering","master"},
"masterful":{"mastered","masters","mastery","masterful","mastering","master"},
"mastery":{"mastered","masters","mastery","masterful","mastering","master"},
"material":{"material","materialistically","materialistic","materials","materially"},
"materialistic":{"material","materialistically","materialistic","materials","materially"},
"materialistically":{"material","materialistically","materialistic","materials","materially"},
"materially":{"material","materialistically","materialistic","materials","materially"},
"materials":{"material","materialistically","materialistic","materials","materially"},
"matter":{"mattered","matters","matter","mattering"},
"mattered":{"matters","matter","mattering"},
"mattering":{"mattered","matters","matter"},
"matters":{"mattered","matter","mattering"},
"mean":{"meanly","meanest","meant","means","meaner","meanings","meanness","meaning","meaningful"},
"meaner":{"meanly","meant","means","mean","meanings","meanness","meaning","meaningful"},
"meanest":{"meanly","meant","means","mean","meaner","meanings","meanness","meaning","meaningful"},
"meaning":{"meanly","meanest","meant","means","mean","meaner","meanings","meanness","meaningful"},
"meaningful":{"meanly","meanest","meant","means","mean","meaner","meanings","meanness","meaning"},
"meaningless":{"meanness"},
"meanings":{"meanly","meanest","meant","means","mean","meaner","meanness","meaning","meaningful"},
"meanly":{"meanest","meant","means","mean","meaner","meanings","meanness","meaning","meaningful"},
"meanness":{"meanly","meanest","meant","means","mean","meaner","meanings","meaning","meaningful"},
"means":{"meanly","meanest","meant","mean","meaner","meanings","meanness","meaning","meaningful"},
"meant":{"meanly","meanest","means","mean","meaner","meanings","meanness","meaning","meaningful"},
"measure":{"measured","measurable","measuring","measurement","measurably","measures","measurements"},
"measured":{"measurable","measuring","measure","measurement","measurably","measures","measurements"},
"measurement":{"measured","measurable","measuring","measure","measurably","measures","measurements"},
"measurements":{"measured","measurable","measuring","measure","measurement","measurably","measures"},
"measures":{"measured","measurable","measuring","measure","measurement","measurably","measurements"},
"measurable":{"measured","measuring","measure","measurement","measurably","measures","measurements"},
"measurably":{"measured","measurable","measuring","measure","measurement","measures","measurements"},
"measuring":{"measured","measurable","measure","measurement","measurably","measures","measurements"},
"meet":{"met","meetings","meets","meeting"},
"meeting":{"met","meetings","meet","meets"},
"meetings":{"met","meet","meets","meeting"},
"meets":{"met","meetings","meet","meeting"},
"met":{"meetings","meet","meets","meeting"},
"member":{"memberships","membership","members"},
"members":{"memberships","membership","member"},
"membership":{"memberships","members","member"},
"memberships":{"membership","members","member"},
"memory":{"memorials","memorizing","memorise","memorized","memorial","memories","memorizes","memorised","memorises","memorising","memorize"},
"memorial":{"memorials","memorizing","memorise","memorized","memories","memorizes","memorised","memorises","memorising","memorize","memory"},
"memories":{"memorials","memorizing","memorized","memorial","memories","memorizes","memorised","memorises","memorising","memorize","memory"},
"memorise":{"memorials","memorizing","memorized","memorial","memories","memorizes","memorised","memorises","memorising","memorize","memory"},
"memorised":{"memorials","memorizing","memorise","memorial","memories","memorizes","memorised","memorises","memorising","memorize","memory"},
"memorises":{"memorials","memorizing","memorise","memorized","memorial","memories","memorizes","memorised","memorising","memorize","memory"},
"memorising":{"memorials","memorizing","memorise","memorized","memorial","memories","memorizes","memorised","memorises","memorize","memory"},
"memorize":{"memorials","memorizing","memorise","memorized","memorial","memories","memorizes","memorised","memorises","memorising","memory"},
"memorized":{"memorials","memorizing","memorise","memorial","memories","memorizes","memorised","memorises","memorising","memorize","memory"},
"memorizes":{"memorials","memorizing","memorise","memorized","memorial","memories","memorised","memorises","memorising","memorize","memory"},
"memorizing":{"memorials","memorise","memorized","memorial","memories","memorizes","memorised","memorises","memorising","memorize","memory"},
"memorials":{"memorizing","memorise","memorized","memorial","memories","memorizes","memorised","memorises","memorising","memorize","memory"},
"mention":{"mentions","mentioning","mentioned"},
"mentioned":{"mentions","mentioning","mention"},
"mentioning":{"mentions","mentioned","mention"},
"mentions":{"mentioning","mentioned","mention"},
"unmentioned":{"mentioning","mentioned"},
"mere":{"merely","merest"},
"merely":{"mere","merest"},
"merest":{"mere","merely"},
"metal":{"metals"},
"metals":{"metal"},
"middle":{"midst","mid"},
"mid":{"midst","middle"},
"midnight":{"midst","mid","middle"},
"midst":{"mid","midnight","middle"},
"might":{"mightn"},
"mile":{"miles"},
"miles":{"mile"},
"milk":{"milking","milks","milked","milky"},
"milky":{"milking","milks","milked","milk"},
"milked":{"milking","milks","milky","milk"},
"milks":{"milking","milked","milky","milk"},
"milking":{"milks","milked","milky","milk"},
"million":{"millions","millionth"},
"millions":{"millionth","million"},
"millionth":{"millions","million"},
"mind":{"minding","minds","minded"},
"minded":{"minding","minds","mind"},
"minding":{"minds","mind","minded"},
"minds":{"minding","mind","minded"},
"miner":{"mining","mines","miners","mined"},
"miners":{"mining","mines","mined","miner"},
"mined":{"mining","mines","miners","miner"},
"mining":{"mines","miners","mined","miner"},
"mines":{"mining","miners","mined","miner"},
"minister":{"ministers"},
"ministers":{"minister"},
"minute":{"minutes"},
"minutes":{"minute"},
"miss":{"missed","misses","missing"},
"missed":{"miss","misses","missing"},
"misses":{"miss","missed","missing"},
"missing":{"miss","missed","misses"},
"mister":{"mr"},
"mr":{"mister"},
"modern":{"modernise","modernisation"},
"modernise":{"modern","modernisation"},
"modernisation":{"modern","modernise"},
"moment":{"moments","momentary"},
"momentary":{"moment","moments"},
"moments":{"moment","%RDmomentary"},
"monday":{"mondays","mon"},
"mon":{"mondays","monday"},
"mondays":{"mon","monday"},
"month":{"months","monthly"},
"monthly":{"months","month"},
"months":{"monthly","month"},
"moon":{"moons","moonlight"},
"moons":{"moon","moonlight"},
"moonlight":{"moon","moons"},
"moral":{"morals","morally","morality"},
"morals":{"morally","morality","moral"},
"morally":{"morals","morality","moral"},
"morality":{"morals","morally","moral"},
"morning":{"mornings"},
"mornings":{"morning"},
"most":{"mostly"},
"mostly":{"most"},
"mother":{"mother-in-law","mom","motherhood","mum","mothers"},
"mother-in-law":{"mom","motherhood","mum","mother","mothers"},
"mothers":{"mother-in-law","mom","motherhood","mum","mother"},
"mom":{"mother-in-law","motherhood","mum","mother","mothers"},
"motherhood":{"mother-in-law","mom","mum","mother","mothers"},
"mum":{"mother-in-law","motherhood","mum","mother","mothers"},
"motor":{"motors","motorists","motorist"},
"motorist":{"motors","motorists","motor"},
"motorists":{"motors","motorist","motor"},
"motors":{"motorists","motorist","motor"},
"mountain":{"mountains","mountainside","mt"},
"mountains":{"mountain","mountainside","mt"},
"mountainside":{"mountain","mountains","mt"},
"mt":{"mountain","mountains","mountainside"},
"mouth":{"mouths","mouthful"},
"mouthful":{"mouths","mouth"},
"mouths":{"mouthful","mouth"},
"move":{"moved","movements","moving","moves","movement"},
"moved":{"movements","moving","moves","movement","move"},
"movement":{"moved","movements","moving","moves","move"},
"moves":{"moved","movements","moving","movement","move"},
"moving":{"moved","movements","moves","movement","move"},
"movements":{"moved","moving","moves","movement","move"},
"mrs":{"ms"},
"ms":{"mrs"},
"music":{"musicians","musical","musically","musician"},
"musical":{"musicians","music","musically","musician"},
"musician":{"musicians","music","musical","musically"},
"musicians":{"music","musical","musically","musician"},
"musically":{"musicians","music","musical","musician"},
"name":{"named","naming","namely","nameless","names"},
"named":{"name","naming","namely","nameless","names"},
"names":{"named","name","naming","namely"},
"naming":{"named","name","namely","names"},
"namely":{"named","name","naming","names"},
"nameless":{"names"},
"nation":{"nations","nationwide","nationally","national"},
"national":{"nations","nationwide","nationally","nation"},
"nationally":{"nations","nationwide","national","nation"},
"nationwide":{"nations","nationally","national","nation"},
"nations":{"nationwide","nationally","national","nation"},
"native":{"natives"},
"natives":{"native"},
"nature":{"natural","naturally","natures"},
"natural":{"nature","naturally","natures"},
"naturally":{"nature","natural","natures"},
"natures":{"nature","natural","naturally"},
"near":{"nearness","nearly","nearest","nearer","nearby"},
"nearby":{"nearness","nearly","nearest","nearer","near"},
"nearer":{"nearness","nearly","nearest","near","nearby"},
"nearest":{"nearness","nearly","nearer","near","nearby"},
"nearly":{"nearness","nearest","nearer","near","nearby"},
"nearness":{"nearly","nearest","nearer","near","nearby"},
"necessary":{"necessarily"},
"necessarily":{"necessary"},
"unnecessarily":{"unnecessary"},
"unnecessary":{"unnecessarily"},
"necessity":{"necessities"},
"necessities":{"necessity"},
"need":{"needn","needs","needing","needed"},
"needed":{"needn","needs","needing","need"},
"needing":{"needn","needs","needed","need"},
"needless":{"needs"},
"needs":{"needn","needing","needed","need"},
"neighbour":{"neighbours","neighbourhood","neighbors","neighborhood","neighbor","neighborhoods","neighbourhoods"},
"neighbor":{"neighbours","neighbourhood","neighbors","neighborhood","neighbour","neighborhoods","neighbourhoods"},
"neighborhood":{"neighbours","neighbourhood","neighbors","neighbour","neighbor","neighborhoods","neighbourhoods"},
"neighborhoods":{"neighbours","neighbourhood","neighbors","neighborhood","neighbour","neighbor","neighbourhoods"},
"neighbors":{"neighbours","neighbourhood","neighborhood","neighbour","neighbor","neighborhoods","neighbourhoods"},
"neighbourhood":{"neighbours","neighbors","neighborhood","neighbour","neighbor","neighborhoods","neighbourhoods"},
"neighbourhoods":{"neighbours","neighbourhood","neighbors","neighborhood","neighbour","neighbor","neighborhoods"},
"neighbours":{"neighbourhood","neighbors","neighborhood","neighbour","neighbor","neighborhoods","neighbourhoods"},
"new":{"renew","renewing","renews","renewed","newness","newly","newest","newer"},
"newer":{"renew","renewing","renews","renewed","newness","new","newly","newest"},
"newest":{"renew","renewing","renews","renewed","newness","new","newly","newer"},
"newly":{"renew","renewing","renews","renewed","newness","new","newest","newer"},
"newness":{"renew","renewing","renews","renewed","new","newly","newest","newer"},
"renew":{"renewing","renews","renewed","newness","new","newly","newest","newer"},
"renewed":{"renew","renewing","renews","newness","new","newly","newest","newer"},
"renews":{"renew","renewing","renewed","newness","new","newly","newest","newer"},
"renewing":{"renew","renews","renewed","newness","new","newly","newest","newer"},
"newspaper":{"newspapers"},
"newspapers":{"newspaper"},
"night":{"nightly","nights"},
"nightly":{"night","nights"},
"nights":{"night","nightly"},
"nine":{"nines","ninth"},
"nines":{"nine","ninth"},
"nineteen":{"nineties","nineteenth"},
"nineteenth":{"ninetieth","nineties","nineteen"},
"nineties":{"ninetieth","nineteenth","ninety"},
"ninetieth":{"nineties","nineteenth","ninety"},
"ninety":{"ninetieth","nineties"},
"ninth":{"ninetieth","nineties","nines","nine","ninety"},
"no":{"noone","nobody","nothing","nowhere"},
"nobody":{"noone","no","nothing","nowhere"},
"nothing":{"noone","no","nobody","nowhere"},
"nowhere":{"noone","no","nobody","nothing"},
"noble":{"nobler","nobility","nobly","noblest","nobles"},
"nobility":{"nobler","noble","nobly","noblest","nobles"},
"nobler":{"noble","nobility","nobly","noblest","nobles"},
"noblest":{"nobler","noble","nobility","nobly","nobles"},
"nobly":{"nobler","noble","nobility","noblest","nobles"},
"nobles":{"nobler","noble","nobility","nobly","noblest"},
"north":{"northern","northeast","northwards"},
"north-east":{"northern","northeast","northwards"},
"north-west":{"northwest","northern","northwards"},
"northeast":{"north-east","northern","north","northwards"},
"northern":{"north","northwards"},
"northwards":{"northern","north"},
"northwest":{"northern","north-west","northwards"},
"note":{"notable","notes","noted","notably","noting"},
"notable":{"note","notes","noted","notably","noting"},
"notes":{"note","notable","noted","notably","noting"},
"noting":{"note","notable","notes","noted","notably"},
"notably":{"note","notable","notes","noted","noting"},
"noted":{"note","notable","notes","notably","noting"},
"notice":{"noticeable","noticeably","noticed","notices","noticing"},
"noticeable":{"noticeably","noticed","notices","noticing","notice"},
"noticeably":{"noticeable","noticed","notices","noticing","notice"},
"noticed":{"noticeable","noticeably","notices","noticing","notice"},
"notices":{"noticeable","noticeably","noticed","noticing","notice"},
"noticing":{"noticeable","noticeably","noticed","notices","notice"},
"november":{"nov"},
"nov":{"november"},
"now":{"nowadays"},
"nowadays":{"now"},
"number":{"numbering","numbered","numbers"},
"numbered":{"numbering","number","numbers"},
"numbering":{"numbered","number","numbers"},
"numbers":{"numbering","numbered","number"},
"numerical":{"numerically"},
"numerically":{"numerical"},
"object":{"objecting","objections","objected","objection","objectionable","objects"},
"objected":{"objecting","objections","object","objection","objectionable","objects"},
"objection":{"objecting","objections","object","objected","objectionable","objects"},
"objecting":{"objections","object","objected","objection","objectionable","objects"},
"objects":{"objecting","objections","object","objected","objection","objectionable"},
"objectionable":{"objecting","objections","object","objected","objection","objects"},
"objections":{"objecting","object","objected","objection","objectionable","objects"},
"observe":{"observing","observes","observers","observer","observed","observatory","observations","observation","observable"},
"observable":{"observing","observes","observers","observer","observed","observatory","observations","observation","observe"},
"observation":{"observing","observes","observers","observer","observed","observatory","observations","observable","observe"},
"observations":{"observing","observes","observers","observer","observed","observatory","observation","observable","observe"},
"observatory":{"observing","observes","observers","observer","observed","observations","observation","observable","observe"},
"observed":{"observing","observes","observers","observer","observatory","observations","observation","observable","observe"},
"observer":{"observing","observes","observers","observed","observatory","observations","observation","observable","observe"},
"observers":{"observing","observes","observer","observed","observatory","observations","observation","observable","observe"},
"observes":{"observing","observers","observer","observed","observatory","observations","observation","observable","observe"},
"observing":{"observes","observers","observer","observed","observatory","observations","observation","observable","observe"},
"occasion":{"occasions","occasional","occasionally"},
"occasional":{"occasions","occasion","occasionally"},
"occasionally":{"occasions","occasional","occasion"},
"occasions":{"occasional","occasion","occasionally"},
"october":{"oct"},
"oct":{"october"},
"offer":{"offers","offerings","offering","offered"},
"offered":{"offers","offerings","offering","offer"},
"offering":{"offers","offerings","offered","offer"},
"offerings":{"offers","offering","offered","offer"},
"offers":{"offerings","offering","offered","offer"},
"office":{"officers","offices","officer"},
"officer":{"officers","office","offices"},
"officers":{"office","offices","officer"},
"offices":{"officers","office","officer"},
"official":{"officialdom","officially","officials"},
"officially":{"officialdom","officials","official"},
"officialdom":{"officially","officials","official"},
"officials":{"officialdom","officially","official"},
"oil":{"oily","oiliness","oils","oiled"},
"oily":{"oil","oiliness","oils","oiled"},
"oiliness":{"oil","oily","oils","oiled"},
"oils":{"oil","oily","oiliness","oiled"},
"oiled":{"oil","oily","oiliness","oils"},
"old":{"older","oldest"},
"older":{"old","oldest"},
"oldest":{"older","old"},
"on":{"onto","in","for","of","to","with","at","by","from","about"},
"onto":{"on"},
"one":{"ones"},
"ones":{"one"},
"open":{"opened","opens","openness","openly","opening"},
"opening":{"opened","opens","openness","openly","open"},
"openly":{"opened","opens","openness","open","opening"},
"openness":{"opened","opens","openly","open","opening"},
"opens":{"opened","openness","openly","open","opening"},
"opened":{"opens","openness","openly","open","opening"},
"operate":{"operated","operates","operators","operation","operating","operations","operator","operational","operative"},
"operated":{"operates","operate","operators","operation","operating","operations","operator","operational","operative"},
"operates":{"operated","operate","operators","operation","operating","operations","operator","operational","operative"},
"operating":{"operated","operates","operate","operators","operation","operations","operator","operational","operative"},
"operation":{"operated","operates","operate","operators","operating","operations","operator","operational","operative"},
"operations":{"operated","operates","operate","operators","operation","operating","operator","operational","operative"},
"operator":{"operated","operates","operate","operators","operation","operating","operations","operational","operative"},
"operators":{"operated","operates","operate","operation","operating","operations","operator","operational","operative"},
"operational":{"operated","operates","operate","operators","operation","operating","operations","operator","operative"},
"operative":{"operated","operates","operate","operators","operation","operating","operations","operator","operational"},
"opinion":{"opinions","opinionated"},
"opinions":{"opinion","opinionated"},
"opinionated":{"opinion","opinions"},
"opportunity":{"opportunities"},
"opportunities":{"opportunity"},
"order":{"ordering","orderly","orders","ordered"},
"ordered":{"ordering","orderly","orders","order"},
"ordering":{"orderly","orders","order","ordered"},
"orderly":{"ordering","orders","order","ordered"},
"orders":{"ordering","orderly","order","ordered"},
"ordinary":{"ordinarily"},
"ordinarily":{"ordinary"},
"organize":{"organises","organization","organising","organised","organise","organizations","organizes","organizing","organisational","organisations","organisation","organized"},
"organisation":{"organises","organization","organising","organised","organise","organizations","organizes","organizing","organisational","organisations","organize","organized"},
"organisations":{"organises","organization","organising","organised","organise","organizations","organizes","organizing","organisational","organisation","organize","organized"},
"organise":{"organises","organization","organising","organised","organizations","organizes","organizing","organisational","organisations","organisation","organize","organized"},
"organised":{"organises","organization","organising","organise","organizations","organizes","organizing","organisational","organisations","organisation","organize","organized"},
"organises":{"organization","organising","organised","organise","organizations","organizes","organizing","organisational","organisations","organisation","organize","organized"},
"organising":{"organises","organization","organised","organise","organizations","organizes","organizing","organisational","organisations","organisation","organize","organized"},
"organization":{"organises","organising","organised","organise","organizations","organizes","organizing","organisational","organisations","organisation","organize","organized"},
"organizations":{"organises","organization","organising","organised","organise","organizes","organizing","organisational","organisations","organisation","organize","organized"},
"organized":{"organises","organization","organising","organised","organise","organizations","organizes","organizing","organisational","organisations","organisation","organize"},
"organizes":{"organises","organization","organising","organised","organise","organizations","organizing","organisational","organisations","organisation","organize","organized"},
"organizing":{"organises","organization","organising","organised","organise","organizations","organizes","organisational","organisations","organisation","organize","organized"},
"organisational":{"organises","organization","organising","organised","organise","organizations","organizes","organizing","organisations","organisation","organize","organized"},
"other":{"others"},
"others":{"other"},
"ought":{"oughtn"},
"out":{"outer","outwards","outside","outward","outsiders","outsider"},
"outer":{"out","outwards","outside","outward","outsiders","outsider"},
"outside":{"out","outer","outwards","outward","outsiders","outsider"},
"outsider":{"out","outer","outwards","outside","outward","outsiders"},
"outsiders":{"out","outer","outwards","outside","outward","outsider"},
"outward":{"out","outer","outwards","outside","outsiders","outsider"},
"outwards":{"out","outer","outside","outward","outsiders","outsider"},
"owe":{"owed","owing","owes"},
"owed":{"owe","owing","owes"},
"owes":{"owe","owed","owing"},
"owing":{"owe","owed","owes"},
"own":{"owning","owners","ownership","owner","owned","owns"},
"owned":{"owning","own","owners","ownership","owner","owns"},
"owner":{"owning","own","owners","ownership","owned","owns"},
"owners":{"owning","own","ownership","owner","owned","owns"},
"ownership":{"owning","own","owners","owner","owned","owns"},
"owning":{"own","owners","ownership","owner","owned","owns"},
"owns":{"owning","own","owners","ownership","owner","owned"},
"page":{"pages"},
"pages":{"page"},
"paint":{"paintings","paints","painting","painters","painter","painted"},
"painted":{"paintings","paints","painting","painters","painter","paint"},
"painter":{"paintings","paints","painting","painters","paint","painted"},
"painters":{"paintings","paints","painting","painter","paint","painted"},
"painting":{"paintings","paints","painters","painter","paint","painted"},
"paintings":{"paints","painting","painters","painter","paint","painted"},
"paints":{"paintings","painting","painters","painter","paint","painted"},
"paper":{"papering","papered","papers"},
"papers":{"papering","papered","paper"},
"papered":{"papering","paper","papers"},
"papering":{"papered","paper","papers"},
"part":{"parted","partially","particles","particle","parting","partly","parts","partial"},
"parted":{"part","partially","particles","particle","parting","partly","parts","partial"},
"parting":{"part","parted","partially","particles","particle","partly","parts","partial"},
"partly":{"part","parted","partially","particles","particle","parting","parts","partial"},
"parts":{"part","parted","partially","particles","particle","parting","partly","partial"},
"partial":{"part","parted","partially","particles","particle","parting","partly","parts"},
"partially":{"part","parted","particles","particle","parting","partly","parts","partial"},
"particle":{"part","parted","partially","particles","parting","partly","parts","partial"},
"particles":{"part","parted","partially","particle","parting","partly","parts","partial"},
"particular":{"particularly"},
"particularly":{"particular"},
"party":{"parties"},
"parties":{"party"},
"pass":{"passing","passed","passes"},
"passed":{"pass","passing","passes"},
"passes":{"pass","passing","passed"},
"passing":{"pass","passed","passes"},
"pay":{"repaid","paid","unpaid","pays","payments","payment","paying"},
"paid":{"repaid","unpaid","pays","payments","payment","paying","pay"},
"paying":{"repaid","paid","pays","payments","payment","pay"},
"payment":{"repaid","paid","pays","payments","paying","pay"},
"payments":{"repaid","paid","pays","payment","paying","pay"},
"pays":{"repaid","paid","payments","payment","paying","pay"},
"repaid":{"paid","pays","payments","payment","paying","pay"},
"unpaid":{"paid"},
"peace":{"peaceful","peacefully"},
"peaceful":{"peacefully","peace"},
"peacefully":{"peaceful","peace"},
"people":{"peoples"},
"peoples":{"people"},
"permit":{"permitted","permits","permission","permitting"},
"permission":{"permitted","permits","permitting","permit"},
"permits":{"permitted","permission","permitting","permit"},
"permitted":{"permits","permission","permitting","permit"},
"permitting":{"permitted","permits","permission","permit"},
"person":{"personal","personally","personalities","persons","personality"},
"personal":{"person","personally","personalities","persons"},
"personalities":{"person","personal","personally","persons"},
"personally":{"person","personal","personalities","persons"},
"persons":{"person","personal","personally","personalities"},
"picture":{"picturing","pictures","pictured"},
"pictured":{"picturing","pictures","picture"},
"pictures":{"picturing","picture","pictured"},
"picturing":{"pictures","picture","pictured"},
"piece":{"pieces"},
"pieces":{"piece"},
"place":{"placed","places","placing"},
"placed":{"place","places","placing"},
"places":{"place","placed","placing"},
"placing":{"place","placed","places"},
"plain":{"plainly","plains"},
"plainly":{"plain","plains"},
"plains":{"plain","plainly"},
"plan":{"plans","planning","planned"},
"planned":{"plans","planning","plan"},
"planner":{"plans","planning","planners","plan","planned"},
"planners":{"plans","planning","plan","planned","planner"},
"planning":{"plans","planners","plan","planned","planner"},
"plans":{"planning","planners","plan","planned","planner"},
"plant":{"planting","plants","planted"},
"planted":{"planting","plants","plant"},
"planting":{"plants","planted","plant"},
"plants":{"planting","planted","plant"},
"play":{"replayed","replaying","replays","players","replay","plays","playing","player","played"},
"played":{"replayed","replaying","replays","players","replay","plays","playing","player","play"},
"player":{"replayed","replaying","replays","players","replay","plays","playing","played","play"},
"players":{"replayed","replaying","replays","replay","plays","playing","player","played","play"},
"playing":{"replayed","replaying","replays","players","replay","plays","player","played","play"},
"plays":{"replayed","replaying","replays","players","replay","playing","player","played","play"},
"replay":{"replayed","replaying","replays","players","plays","playing","player","played","play"},
"replays":{"replayed","replaying","players","replay","plays","playing","player","played","play"},
"replaying":{"replayed","replays","players","replay","plays","playing","player","played","play"},
"replayed":{"replaying","replays","players","replay","plays","playing","player","played","play"},
"please":{"pleasantness","pleasure","pleasantly","pleasing","pleases","pleasant","pleased"},
"pleasant":{"please","pleasantness","pleasure","pleasantly","pleasing","pleases","pleased"},
"pleasantly":{"please","pleasantness","pleasure","pleasing","pleases","pleasant","pleased"},
"pleasantness":{"please","pleasure","pleasantly","pleasing","pleases","pleasant","pleased"},
"pleased":{"please","pleasantness","pleasure","pleasantly","pleasing","pleases","pleasant"},
"pleases":{"please","pleasantness","pleasure","pleasantly","pleasing","pleasant","pleased"},
"pleasing":{"please","pleasantness","pleasure","pleasantly","pleases","pleasant","pleased"},
"pleasure":{"please","pleasantness","pleasantly","pleasing","pleases","pleasant","pleased"},
"unpleasant":{"displeasure","displeasing","displeased","displease","unpleasantly"},
"unpleasantly":{"displeasing","displeasure","displeased","displease","unpleasant"},
"displease":{"displeasing","displeasure","displeased","unpleasantly","unpleasant"},
"displeased":{"displeasing","displeasure","displease","unpleasantly","unpleasant"},
"displeasing":{"displeasure","displeased","displease","unpleasantly","unpleasant"},
"displeasure":{"displeasing","displeased","displease","unpleasantly","unpleasant"},
"point":{"points","pointing","pointed"},
"pointed":{"pointers","pointing","pointed","point"},
"pointing":{"points","pointed","point"},
"points":{"pointing","pointed","point"},
"pointer":{"pointers","points","pointing","pointed","point"},
"pointers":{"pointer","points","pointing","pointed","point"},
"political":{"politics","politically"},
"politically":{"political","politics"},
"politician":{"politicians","political","politics","politically"},
"politicians":{"politician","political","politics","politically"},
"politics":{"politicians","politician","political","politically"},
"poor":{"poorly","poorer","poorest"},
"poorer":{"poorly","poor","poorest"},
"poorest":{"poorly","poor","poorer"},
"poorly":{"poor","poorer","poorest"},
"popular":{"popularity","popularly"},
"popularity":{"popular","popularly"},
"popularly":{"popular","popularity"},
"population":{"populates","populated","populating","populate","populations"},
"populations":{"populates","populated","populating","populate","population"},
"populate":{"populates","populated","populating","populations","population"},
"populating":{"populates","populated","populate","populations","population"},
"populated":{"populates","populating","populate","populations","population"},
"populates":{"populated","populating","populate","populations","population"},
"position":{"positions","positioning","positioned"},
"positions":{"position","positioning","positioned"},
"positioning":{"positions","position","positioned"},
"positioned":{"positions","position","positioning"},
"possess":{"possessions","possession","possessing","possesses","possessed"},
"possessed":{"possessions","possession","possessing","possesses","possess"},
"possesses":{"possessions","possession","possessing","possessed","possess"},
"possessing":{"possessions","possession","possesses","possessed","possess"},
"possession":{"possessions","possessing","possesses","possessed","possess"},
"possessions":{"possession","possessing","possesses","possessed","possess"},
"possible":{"possibilities","possibility","possibly"},
"possibilities":{"possibility","possibly","possible"},
"possibility":{"possibilities","possibly","possible"},
"possibly":{"possibilities","possibility","possible"},
"impossibility":{"impossible","impossibly"},
"impossible":{"impossibility","impossibly"},
"impossibly":{"impossibility","impossible"},
"post":{"posts","posting","poster","posted","posters"},
"posted":{"post","posts","posting","poster","posters"},
"poster":{"post","posts","posting","posted","posters"},
"posters":{"post","posts","posting","poster","posted"},
"posting":{"post","posts","poster","posted","posters"},
"posts":{"post","posting","poster","posted","posters"},
"pound":{"pounds"},
"pounds":{"pound"},
"power":{"powered","powerful","powers"},
"powered":{"power","powerful","powers"},
"powerful":{"power","powered","powers"},
"powers":{"power","powered","powerful"},
"prepare":{"prepares","preparations","preparation","prepared","preparing"},
"preparation":{"prepare","prepares","preparations","prepared","preparing"},
"preparations":{"prepare","prepares","preparation","prepared","preparing"},
"prepared":{"prepare","prepares","preparations","preparation","preparing"},
"prepares":{"prepare","preparations","preparation","prepared","preparing"},
"preparing":{"prepare","prepares","preparations","preparation","prepared"},
"present":{"presently","presence","presentation","presented","presenting","presents"},
"presence":{"presently","present","presentation","presented","presenting","presents"},
"presentation":{"presently","present","presence","presented","presenting","presents"},
"presented":{"presently","present","presence","presentation","presenting","presents"},
"presenting":{"presently","present","presence","presentation","presented","presents"},
"presently":{"present","presence","presentation","presented","presenting","presents"},
"presents":{"presently","present","presence","presentation","presented","presenting"},
"president":{"presidential","presidents"},
"presidents":{"presidential","president"},
"presidential":{"presidents","president"},
"press":{"pressing","presses","pressed"},
"pressed":{"pressing","presses","press"},
"presses":{"pressing","pressed","press"},
"pressing":{"presses","pressed","press"},
"pressure":{"pressures","pressuring","pressured"},
"pressured":{"pressures","pressuring","pressure"},
"pressures":{"pressuring","pressured","pressure"},
"pressuring":{"pressures","pressured","pressure"},
"pretty":{"prettiest","prettily","prettiness","prettier"},
"prettier":{"prettiest","pretty","prettily","prettiness"},
"prettiest":{"pretty","prettily","prettiness","prettier"},
"prettily":{"prettiest","pretty","prettiness","prettier"},
"prettiness":{"prettiest","pretty","prettily","prettier"},
"prevent":{"preventative","preventable","prevention","prevented","preventing","prevents"},
"prevented":{"preventative","preventable","prevention","preventing","prevent","prevents"},
"preventing":{"preventative","preventable","prevention","prevented","prevent","prevents"},
"prevention":{"preventative","preventable","prevented","preventing","prevent","prevents"},
"prevents":{"preventative","preventable","prevention","prevented","preventing","prevent"},
"preventable":{"preventative","prevention","prevented","preventing","prevent","prevents"},
"preventative":{"preventable","prevention","prevented","preventing","prevent","prevents"},
"price":{"prices","priced","pricing"},
"priced":{"prices","price","pricing"},
"prices":{"priced","price","pricing"},
"pricing":{"prices","priced","price"},
"private":{"privately"},
"privately":{"private"},
"problem":{"problems","problematic"},
"problems":{"problem","problematic"},
"problematic":{"problem","problems"},
"produce":{"producing","produced","producer","producers","produces"},
"produced":{"produce","producing","producer","producers","produces"},
"producer":{"produce","producing","produced","producers","produces"},
"producers":{"produce","producing","produced","producer","produces"},
"produces":{"produce","producing","produced","producer","producers"},
"producing":{"produce","produced","producer","producers","produces"},
"product":{"productivity","productive","productions","production","products"},
"products":{"productivity","productive","productions","production","product"},
"production":{"productivity","productive","productions","products","product"},
"productions":{"productivity","productive","production","products","product"},
"productive":{"productivity","productions","production","products","product"},
"productivity":{"productive","productions","production","products","product"},
"profit":{"profited","profiting","profits","profitable"},
"profited":{"profit","profiting","profits","profitable"},
"profiting":{"profit","profited","profits","profitable"},
"profits":{"profit","profited","profiting","profitable"},
"profitable":{"profit","profited","profiting","profits"},
"progress":{"progressed","progresses","progressing","progressively","progressive"},
"progressed":{"progress","progresses","progressing","progressively","progressive"},
"progresses":{"progress","progressed","progressing","progressively","progressive"},
"progressing":{"progress","progressed","progresses","progressively","progressive"},
"progressive":{"progress","progressed","progresses","progressing","progressively"},
"progressively":{"progress","progressed","progresses","progressing","progressive"},
"promise":{"promises","promised","promising"},
"promised":{"promises","promise","promising"},
"promises":{"promised","promise","promising"},
"promising":{"promises","promised","promise"},
"proper":{"properly"},
"properly":{"proper",""},
"improper":{"improperly"},
"improperly":{"improper"},
"property":{"properties"},
"properties":{"property"},
"propose":{"proposing","proposes","proposed","proposals","proposal"},
"proposal":{"propose","proposing","proposes","proposed","proposals"},
"proposals":{"propose","proposing","proposes","proposed","proposal"},
"proposed":{"propose","proposing","proposes","proposals","proposal"},
"proposes":{"propose","proposing","proposed","proposals","proposal"},
"proposing":{"propose","proposes","proposed","proposals","proposal"},
"protect":{"protects","protective","protections","protected","protecting","protection"},
"protected":{"protects","protective","protections","protect","protecting","protection"},
"protecting":{"protects","protective","protections","protect","protected","protection"},
"protection":{"protects","protective","protections","protect","protected","protecting"},
"protections":{"protects","protective","protect","protected","protecting","protection"},
"protective":{"protects","protections","protect","protected","protecting","protection"},
"protects":{"protective","protections","protect","protected","protecting","protection"},
"prove":{"proving","proved","proven","proves"},
"proved":{"proving","prove","proven","proves"},
"proves":{"proving","prove","proved","proven"},
"proving":{"prove","proved","proven","proves"},
"provide":{"provides","provider","providing","providers","provided"},
"provided":{"provide","provides","provider","providing","providers"},
"provides":{"provide","provider","providing","providers","provided"},
"providing":{"provide","provides","provider","providers","provided"},
"provider":{"provide","provides","providing","providers","provided"},
"providers":{"provide","provides","provider","providing","provided"},
"public":{"publicity","publicly"},
"publicity":{"public","publicly"},
"publicly":{"public","publicity"},
"pull":{"pulls","pulled","pulling"},
"pulled":{"pulls","pull","pulling"},
"pulling":{"pulls","pull","pulled"},
"pulls":{"pull","pulled","pulling"},
"put":{"putting","puts"},
"puts":{"putting","put"},
"putting":{"puts","put"},
"quality":{"qualities"},
"qualities":{"quality"},
"quantity":{"quantities"},
"quantities":{"quantity"},
"quarter":{"quarters","quarterly"},
"quarterly":{"quarters","quarter"},
"quarters":{"quarter","quarterly"},
"queen":{"queens"},
"queens":{"queen"},
"question":{"questionable","questioning","questioned","questions"},
"questions":{"questionable","questioning","questioned","question"},
"questioned":{"questionable","questioning","questions","question"},
"questioning":{"questionable","questioned","questions","question"},
"questionable":{"questioning","questioned","questions","question"},
"race":{"racing","racecourse","raced","races"},
"racecourse":{"racing","raced","race","races"},
"raced":{"racing","racecourse","race","races"},
"races":{"racing","racecourse","raced","race"},
"racing":{"racecourse","raced","race","races"},
"raise":{"raising","raises","raised"},
"raised":{"raising","raises","raise"},
"raises":{"raising","raised","raise"},
"raising":{"raises","raised","raise"},
"rank":{"ranked","ranking","ranks"},
"ranked":{"rank","ranking","ranks"},
"ranking":{"rank","ranked","ranks"},
"ranks":{"rank","ranked","ranking"},
"rate":{"rating","rates","rated"},
"rated":{"rating","rates","rate"},
"rates":{"rating","rated","rate"},
"rating":{"rates","rated","rate"},
"reach":{"reaches","reaching","reached"},
"reached":{"reaches","reaching","reach"},
"reaches":{"reaching","reach","reached"},
"reaching":{"reaches","reach","reached"},
"read":{"reads","reading","reader","readers","readings"},
"reader":{"reads","reading","read","readers","readings"},
"readers":{"reads","reading","reader","read","readings"},
"reading":{"reads","reader","read","readers","readings"},
"readings":{"reads","reading","reader","read","readers"},
"reads":{"reading","reader","read","readers","readings"},
"ready":{"readily"},
"readily":{"ready"},
"real":{"reality","realistic"},
"realistic":{"reality","real"},
"reality":{"realistic","real"},
"realise":{"realising","realisations","realisation","realizing","realizes","realized","realization","realize","realised","realises"},
"realize":{"realising","realisations","realisation","realizing","realizes","realized","realization","realise","realised","realises"},
"realization":{"realising","realisations","realizing","realizes","realized","realization","realize","realise","realised","realises"},
"realized":{"realising","realisations","realisation","realizing","realizes","realization","realize","realise","realised","realises"},
"realizes":{"realising","realisations","realisation","realizing","realized","realization","realize","realise","realised","realises"},
"realizing":{"realising","realisations","realisation","realizes","realized","realization","realize","realise","realised","realises"},
"realisation":{"realising","realisations","realizing","realizes","realized","realization","realize","realise","realised","realises"},
"realisations":{"realising","realisation","realizing","realizes","realized","realization","realize","realise","realised","realises"},
"realised":{"realising","realisations","realisation","realizing","realizes","realized","realization","realize","realise","realises"},
"realising":{"realisations","realisation","realizing","realizes","realized","realization","realize","realise","realised","realises"},
"realises":{"realising","realisations","realisation","realizing","realizes","realized","realization","realize","realise","realised"},
"reason":{"reasonable","reasonably","reasoned","reasoning","reasons"},
"reasonable":{"reason","reasonably","reasoned","reasoning","reasons"},
"reasonably":{"reason","reasonable","reasoned","reasoning","reasons"},
"reasoned":{"reason","reasonable","reasonably","reasoning","reasons"},
"reasoning":{"reason","reasonable","reasonably","reasoned","reasons"},
"reasons":{"reason","reasonable","reasonably","reasoned","reasoning"},
"receive":{"receiving","receives","received","receiver","receipt"},
"received":{"receiving","receives","receive","receiver"},
"receiver":{"receiving","receives","received","receive"},
"receives":{"receiving","received","receive","receiver"},
"receiving":{"receives","received","receive","receiver"},
"receipt":{"receipts","receive"},
"receipts":{"receipt"},
"recent":{"recently"},
"recently":{"recent"},
"recognize":{"recognises","recognised","recognise","recognizing","recognizes","recognition","recognized","recognising"},
"recognise":{"recognises","recognised","recognizing","recognizes","recognition","recognized","recognising","recognize"},
"recognised":{"recognises","recognise","recognizing","recognizes","recognition","recognized","recognising","recognize"},
"recognises":{"recognised","recognise","recognizing","recognizes","recognition","recognized","recognising","recognize"},
"recognising":{"recognises","recognised","recognise","recognizing","recognizes","recognition","recognized","recognize"},
"recognition":{"recognises","recognised","recognise","recognizing","recognizes","recognized","recognising","recognize"},
"recognized":{"recognises","recognised","recognise","recognizing","recognizes","recognition","recognising","recognize"},
"recognizes":{"recognises","recognised","recognise","recognizing","recognition","recognized","recognising","recognize"},
"recognizing":{"recognises","recognised","recognise","recognizes","recognition","recognized","recognising","recognize"},
"record":{"recorded","records","recording"},
"recorded":{"record","records","recording"},
"recording":{"recorded","record","records"},
"records":{"recorded","record","recording"},
"red":{"reddest","redness","reddish","redden","redder"},
"redder":{"reddest","redness","reddish","red","redden"},
"reddest":{"redness","reddish","red","redden","redder"},
"redness":{"reddest","reddish","red","redden","redder"},
"redden":{"reddest","redness","reddish","red","redder"},
"reddish":{"reddest","redness","red","redden","redder"},
"reduce":{"reduced","reducing","reductions","reduction","reduces"},
"reduced":{"reduce","reducing","reductions","reduction","reduces"},
"reduces":{"reduced","reduce","reducing","reductions","reduction"},
"reducing":{"reduced","reduce","reductions","reduction","reduces"},
"reduction":{"reduced","reduce","reducing","reductions","reduces"},
"reductions":{"reduced","reduce","reducing","reduction","reduces"},
"refuse":{"refused","refusing","refuses","refusals","refusal"},
"refusal":{"refused","refusing","refuses","refusals","refuse"},
"refusals":{"refused","refusing","refuses","refusal","refuse"},
"refused":{"refusing","refuses","refusals","refusal","refuse"},
"refuses":{"refused","refusing","refusals","refusal","refuse"},
"refusing":{"refused","refuses","refusals","refusal","refuse"},
"regard":{"regarding","regarded","regards"},
"disregard":{"disregards","disregarding","disregarded","regardless"},
"disregarded":{"disregards","disregarding","disregard","regardless"},
"disregarding":{"disregards","disregarded","disregard","regardless"},
"disregards":{"disregarding","disregarded","disregard","regardless"},
"regarded":{"regarding","regards","regard"},
"regarding":{"regarded","regards","regard"},
"regardless":{"disregards","disregarding","disregarded","disregard"},
"regards":{"regarding","regarded","regard"},
"relation":{"related","relationships","relationship","relations","relating","relates","relate"},
"relate":{"related","relationships","relationship","relations","relating","relates","relation"},
"related":{"relationships","relationship","relations","relating","relates","relate","relation"},
"relates":{"related","relationships","relationship","relations","relating","relate","relation"},
"relating":{"related","relationships","relationship","relations","relates","relate","relation"},
"relations":{"related","relationships","relationship","relating","relates","relate","relation"},
"relationship":{"related","relationships","relations","relating","relates","relate","relation"},
"relationships":{"related","relationship","relations","relating","relates","relate","relation"},
"relative":{"relatively","relatives"},
"relatively":{"relative","relatives"},
"relatives":{"relatively","relative"},
"religion":{"religions","religious"},
"religions":{"religion","religious"},
"religious":{"religion","religions"},
"remain":{"remained","remaining","remainder","remainders","remains"},
"remained":{"remaining","remainder","remainders","remains","remain"},
"remaining":{"remained","remainder","remainders","remains","remain"},
"remainder":{"remained","remaining","remainders","remains","remain"},
"remainders":{"remained","remaining","remainder","remains","remain"},
"remains":{"remained","remaining","remainder","remainders","remain"},
"remark":{"remarkably","remarkable","remarks","remarking","remarked"},
"remarked":{"remark","remarkably","remarkable","remarks","remarking"},
"remarking":{"remark","remarkably","remarkable","remarks","remarked"},
"remarks":{"remark","remarkably","remarkable","remarking","remarked"},
"remarkable":{"remark","remarkably","remarks","remarking","remarked"},
"remarkably":{"remark","remarkable","remarks","remarking","remarked"},
"remember":{"remembers","remembered","remembering"},
"remembered":{"remembers","remember","remembering"},
"remembering":{"remembers","remember","remembered"},
"remembers":{"remember","remembered","remembering"},
"reply":{"replies","replied","replying"},
"replied":{"replies","reply","replying"},
"replies":{"replied","reply","replying"},
"replying":{"replies","replied","reply"},
"report":{"reports","reported","reporter","reporters","reporting"},
"reported":{"reports","reporter","reporters","reporting","report"},
"reporter":{"reports","reported","reporters","reporting","report"},
"reporters":{"reports","reported","reporter","reporting","report"},
"reporting":{"reports","reported","reporter","reporters","report"},
"reports":{"reported","reporter","reporters","reporting","report"},
"represent":{"representations","representation","represents","represented","representing","representatives","representative"},
"representative":{"representations","representation","represents","represented","representing","representatives","represent"},
"representatives":{"representations","representation","represents","represented","representing","representative","represent"},
"represented":{"representations","representation","represents","representing","representatives","representative","represent"},
"representing":{"representations","representation","represents","represented","representatives","representative","represent"},
"represents":{"representations","representation","represented","representing","representatives","representative","represent"},
"representation":{"representations","represents","represented","representing","representatives","representative","represent"},
"representations":{"representation","represents","represented","representing","representatives","representative","represent"},
"republic":{"republicanism","republicans","republican","republics"},
"republics":{"republicanism","republicans","republican","republic"},
"republican":{"republicanism","republicans","republics","republic"},
"republicans":{"republicanism","republican","republics","republic"},
"republicanism":{"republicans","republican","republics","republic"},
"reserve":{"reserving","reservation","reserved","reservations","reserves"},
"reserves":{"reserving","reservation","reserved","reservations","reserve"},
"reservation":{"reserving","reserved","reservations","reserves","reserve"},
"reservations":{"reserving","reservation","reserved","reserves","reserve"},
"reserved":{"reserving","reservation","reservations","reserves","reserve"},
"reserving":{"reservation","reserved","reservations","reserves","reserve"},
"respect":{"respects","respecting","respected","respectable","respectful","respectfully","respective","respectively"},
"disrespect":{"disrespectful","irrespective","irrespectively"},
"disrespectful":{"disrespect","irrespective","irrespectively"},
"respected":{"respects","respecting","respectable","respectful","respectfully","respective","respectively","respect"},
"respecting":{"respects","respected","respectable","respectful","respectfully","respective","respectively","respect"},
"respects":{"respecting","respected","respectable","respectful","respectfully","respective","respectively","respect"},
"respectful":{"respects","respecting","respected","respectable","respectfully","respective","respectively","respect"},
"respectable":{"respects","respecting","respected","respectful","respectfully","respective","respectively","respect"},
"respectfully":{"respects","respecting","respected","respectable","respectful","respective","respectively","respect"},
"respective":{"respects","respecting","respected","respectable","respectful","respectfully","respectively","respect"},
"respectively":{"respects","respecting","respected","respectable","respectful","respectfully","respective","respect"},
"irrespective":{"disrespectful","disrespect","irrespectively"},
"irrespectively":{"disrespectful","disrespect","irrespective"},
"rest":{"rests","resting","rested"},
"rested":{"rests","rest","resting"},
"resting":{"rests","rest","rested"},
"restless":{"restlessness"},
"restlessness":{"restless"},
"rests":{"rest","resting","rested"},
"result":{"resulted","resulting","results"},
"resulted":{"result","resulting","results"},
"resulting":{"result","resulted","results"},
"results":{"result","resulted","resulting"},
"return":{"returns","returned","returning"},
"returned":{"returns","return","returning"},
"returning":{"returns","return","returned"},
"returns":{"return","returned","returning"},
"rich":{"richness","riches","richest","richly","richer","richen"},
"richer":{"richness","riches","rich","richest","richly"},
"richest":{"richness","riches","rich","richly","richer"},
"richly":{"richness","riches","rich","richest","richer"},
"richness":{"riches","rich","richest","richly","richer"},
"riches":{"richness","rich","richest","richly","richer"},
"ride":{"rode","riding","rides","riders","rider","ridden"},
"ridden":{"rode","riding","rides","riders","rider","ride"},
"rider":{"rode","riding","rides","riders","ridden","ride"},
"riders":{"rode","riding","rides","rider","ridden","ride"},
"rides":{"rode","riding","riders","rider","ridden","ride"},
"riding":{"rode","rides","riders","rider","ridden","ride"},
"rode":{"riding","rides","riders","rider","ridden","ride"},
"right":{"rightful","rightfully","rightist","rightists","rightly","rights"},
"rightful":{"rightfully","right","rightist","rightists","rightly","rights"},
"rightfully":{"rightful","right","rightist","rightists","rightly","rights"},
"rightist":{"rightful","rightfully","right","rightists","rightly","rights"},
"rightists":{"rightful","rightfully","right","rightist","rightly","rights"},
"rightly":{"rightful","rightfully","right","rightist","rightists","rights"},
"rights":{"rightful","rightfully","right","rightist","rightists","rightly"},
"ring":{"rang","ringed","ringing","rings","rung"},
"rang":{"ring","ringed","ringing","rings","rung"},
"ringed":{"ring","rang","ringing","rings","rung"},
"ringing":{"ring","rang","ringed","rings","rung"},
"rings":{"ring","rang","ringed","ringing","rung"},
"rung":{"ring","rang","ringed","ringing","rings"},
"rise":{"rose","rising","rises"},
"rises":{"rose","rising","rise"},
"rising":{"rose","rises","rise"},
"rose":{"rising","rises","rise"},
"river":{"rivers","riverside"},
"rivers":{"rivers","riverside"},
"riverside":{"rivers","river"},
"road":{"roads","roadside"},
"roads":{"road","roadside"},
"roadside":{"road","roads"},
"rock":{"rocky","rocked","rocks","rocking"},
"rocky":{"rock","rocked","rocks","rocking"},
"rocked":{"rocky","rock","rocks","rocking"},
"rocking":{"rocky","rock","rocked","rocks"},
"rocks":{"rocky","rock","rocked","rocking"},
"roll":{"rollers","rolled","roller","rolling","rolls"},
"rolled":{"rollers","roll","roller","rolling","rolls"},
"rolling":{"rollers","roll","rolled","roller","rolls"},
"rolls":{"rollers","roll","rolled","roller","rolling"},
"roller":{"rollers","roll","rolled","rolling","rolls"},
"rollers":{"roll","rolled","roller","rolling","rolls"},
"room":{"rooms"},
"rooms":{"room"},
"rough":{"roughly","roughness"},
"roughly":{"rough","roughness"},
"roughness":{"roughly","rough"},
"round":{"rounder","roundest","roundness","roundly","rounded","rounds","roundabout"},
"rounded":{"rounder","roundest","roundness","roundly","rounds","roundabout","round"},
"rounder":{"roundest","roundness","roundly","rounded","rounds","roundabout","round"},
"roundest":{"rounder","roundness","roundly","rounded","rounds","roundabout","round"},
"roundly":{"rounder","roundest","roundness","rounded","rounds","roundabout","round"},
"roundness":{"rounder","roundest","roundly","rounded","rounds","roundabout","round"},
"rounds":{"rounder","roundest","roundness","roundly","rounded","roundabout","round"},
"roundabout":{"rounder","roundest","roundness","roundly","rounded","rounds","round"},
"royal":{"royally","royalty"},
"royalty":{"royally","royal"},
"royally":{"royalty","royal"},
"rule":{"ruled","ruler","rulers","rules","ruling"},
"ruled":{"rule","ruler","rulers","rules","ruling"},
"ruler":{"rule","ruled","rulers","rules","ruling"},
"rulers":{"rule","ruled","ruler","rules","ruling"},
"rules":{"rule","ruled","ruler","rulers","ruling"},
"ruling":{"rule","ruled","ruler","rulers","rules"},
"run":{"ran","runner","runners","running","runs"},
"ran":{"run","runner","runners","running","runs"},
"runner":{"run","ran","runners","running","runs"},
"runners":{"run","ran","runner","running","runs"},
"running":{"run","ran","runner","runners","runs"},
"runs":{"run","ran","runner","runners","running"},
"safe":{"safest","safety","safeness","safely","safer"},
"safely":{"safest","safety","safeness","safe","safer"},
"safeness":{"safest","safety","safely","safe","safer"},
"safer":{"safest","safety","safeness","safely","safe"},
"safest":{"safety","safeness","safely","safe","safer"},
"safety":{"safest","safeness","safely","safe","safer"},
"sail":{"sailor","sailings","sails","sailing","sailors","sailed"},
"sailed":{"sailor","sailings","sails","sail","sailing","sailors"},
"sailing":{"sailor","sailings","sails","sail","sailors","sailed"},
"sailings":{"sailor","sails","sail","sailing","sailors","sailed"},
"sailor":{"sailings","sails","sail","sailing","sailors","sailed"},
"sailors":{"sailor","sailings","sails","sail","sailing","sailed"},
"sails":{"sailor","sailings","sail","sailing","sailors","sailed"},
"sale":{"sales"},
"sales":{"sale"},
"salt":{"salty"},
"salty":{"salt"},
"same":{"sameness"},
"sameness":{"same"},
"saturday":{"saturdays"},
"saturdays":{"saturday"},
"save":{"savings","saves","saving","saved"},
"saved":{"save","savings","saves","saving"},
"saves":{"save","savings","saving","saved"},
"saving":{"save","savings","saves","saved"},
"savings":{"save","saves","saving","saved"},
"say":{"said","saying","says"},
"said":{"say","saying","says"},
"saying":{"say","said","says"},
"says":{"say","said","saying"},
"scarce":{"scarcer","scarcest","scarcity","scarcely"},
"scarcely":{"scarcer","scarcest","scarcity","scarce"},
"scarcer":{"scarcest","scarcity","scarce","scarcely"},
"scarcest":{"scarcer","scarcity","scarce","scarcely"},
"scarcity":{"scarcer","scarcest","scarce","scarcely"},
"scene":{"scenery","scenes"},
"scenery":{"scene","scenes"},
"scenes":{"scene","scenery"},
"school":{"schools","schooling"},
"schooling":{"schools","school"},
"schools":{"schooling","school"},
"science":{"sciences","scientific","scientist","scientists","scientifically"},
"sciences":{"science","scientific","scientist","scientists","scientifically"},
"scientific":{"sciences","science","scientist","scientists","scientifically"},
"scientist":{"sciences","science","scientific","scientists","scientifically"},
"scientists":{"sciences","science","scientific","scientist","scientifically"},
"scientifically":{"sciences","science","scientific","scientist","scientists"},
"sea":{"seaside","seas"},
"seaman":{"seamen"},
"seaside":{"sea","seas"},
"seamen":{"seaman"},
"seas":{"sea","seaside","seas"},
"season":{"seasons"},
"seasons":{"season"},
"seat":{"seats","seating","seated","sit"},
"seated":{"seats","seating","seat"},
"seating":{"seats","seated","seat"},
"seats":{"seating","seated","seat"},
"second":{"secondary","seconds","secondly"},
"secondary":{"seconds","secondly","second"},
"secondly":{"secondary","seconds","second"},
"seconds":{"secondary","secondly","second"},
"secret":{"secrets","secrecy","secretly"},
"secrecy":{"secrets","secret","secretly"},
"secretly":{"secrets","secret","secrecy"},
"secrets":{"secret","secrecy","secretly"},
"secretary":{"secretaries"},
"secretaries":{"secretary"},
"see":{"seen","saw","seeing","sees"},
"saw":{"seen","see","saw","seeing","sees"},
"seeing":{"seen","see","saw","sees"},
"seen":{"see","saw","seeing","sees"},
"sees":{"seen","see","saw","seeing",""},
"seem":{"seemed","seeming","seems"},
"seemed":{"seeming","seems","seem"},
"seeming":{"seeming","seems","seem"},
"seems":{"seemed","seeming","seem"},
"sell":{"selling","sold","sells","sellers","seller"},
"seller":{"selling","sold","sells","sellers","sell"},
"sellers":{"selling","sold","sells","seller","sell"},
"selling":{"sold","sells","sellers","seller","sell"},
"sells":{"selling","sold","sellers","seller","sell"},
"sold":{"selling","sells","sellers","seller","sell"},
"resell":{"resold","reselling"},
"reselling":{"resell","resold"},
"resold":{"resell","reselling"},
"send":{"senders","sending","sends","sent","sender"},
"sender":{"send","senders","sending","sends","sent"},
"senders":{"send","sending","sends","sent","sender"},
"sending":{"send","senders","sends","sent","sender"},
"sends":{"send","senders","sending","sent","sender"},
"sent":{"send","senders","sending","sends","sender"},
"sense":{"sensible","senses"},
"senseless":{"senselessness"},
"senselessness":{"senseless"},
"senses":{"sensible","sense"},
"sensible":{"senses","sense"},
"sensitive":{"sensitivity"},
"sensitivity":{"sensitive"},
"separate":{"separations","separated","separately","separates","separating","separation"},
"separated":{"separate","separations","separately","separates","separating","separation"},
"separately":{"separate","separations","separated","separates","separating","separation"},
"separates":{"separate","separations","separated","separately","separating","separation"},
"separating":{"separate","separations","separated","separately","separates","separation"},
"separation":{"separate","separations","separated","separately","separates","separating"},
"separations":{"separate","separated","separately","separates","separating","separation"},
"separatist":{"separatists"},
"separatists":{"separatist"},
"september":{"sept"},
"sept":{"september"},
"serious":{"seriously","seriousness"},
"seriously":{"serious","seriousness"},
"seriousness":{"serious","seriously"},
"serve":{"servants","serves","servant","serving","servings","served","service"},
"servant":{"servants","serves","serve","serving","servings","served"},
"servants":{"serves","servant","serve","serving","servings","served"},
"served":{"servants","serves","servant","serve","serving","servings"},
"serves":{"servants","servant","serve","serving","servings","served"},
"serving":{"servants","serves","servant","serve","servings","served"},
"servings":{"servants","serves","servant","serve","serving","served"},
"service":{"services","serviced","servicing","serve"},
"services":{"serviced","servicing","service"},
"serviced":{"services","servicing","service"},
"servicing":{"services","serviced","service"},
"set":{"sets","setting"},
"sets":{"setting","set"},
"setting":{"sets","set"},
"settle":{"settlers","settler","settlements","settlement","settled","settling","settles"},
"settled":{"settlers","settler","settlements","settlement","settle","settling","settles"},
"settlement":{"settlers","settler","settlements","settled","settle","settling","settles"},
"settlements":{"settlers","settler","settlement","settled","settle","settling","settles"},
"settler":{"settlers","settlements","settlement","settled","settle","settling","settles"},
"settlers":{"settler","settlements","settlement","settled","settle","settling","settles"},
"settles":{"settlers","settler","settlements","settlement","settled","settle","settling"},
"settling":{"settlers","settler","settlements","settlement","settled","settle","settles"},
"seven":{"seventeen","seventh","seventy","seventieth","seventies","seventeenth"},
"seventeen":{"seventh","seventy","seventieth","seventies","seventeenth","seven"},
"seventeenth":{"seventeen","seventh","seventy","seventieth","seventies","seven"},
"seventh":{"seventeen","seventy","seventieth","seventies","seventeenth","seven"},
"seventies":{"seventeen","seventh","seventy","seventieth","seventeenth","seven"},
"seventieth":{"seventeen","seventh","seventy","seventies","seventeenth","seven"},
"seventy":{"seventeen","seventh","seventieth","seventies","seventeenth","seven"},
"shadow":{"shadowed","shadowy","shadows","shadowing"},
"shadowed":{"shadowy","shadows","shadowing","shadow"},
"shadowing":{"shadowed","shadowy","shadows","shadow"},
"shadows":{"shadowed","shadowy","shadowing","shadow"},
"shadowy":{"shadowed","shadows","shadowing","shadow"},
"shake":{"shaking","shook","shaky","shaken","shakes","shakily"},
"shaken":{"shaking","shook","shaky","shake","shakes","shakily"},
"shakes":{"shaking","shook","shaky","shake","shaken","shakily"},
"shakily":{"shaking","shook","shaky","shake","shaken","shakes"},
"shaking":{"shook","shaky","shake","shaken","shakes","shakily"},
"shaky":{"shaking","shook","shake","shaken","shakes","shakily"},
"shook":{"shaking","shaky","shake","shaken","shakes","shakily"},
"shall":{"shan"},
"shan":{"shall"},
"shape":{"shapes","shaping","shaped"},
"shaped":{"shapes","shaping","shape"},
"shapes":{"shaping","shaped","shape"},
"shaping":{"shapes","shaped","shape"},
"share":{"shared","shares","sharing"},
"shared":{"share","shares","sharing"},
"shares":{"share","shared","sharing"},
"sharing":{"share","shared","shares"},
"she":{"herself","hers","her"},
"her":{"herself","hers","she"},
"hers":{"herself","she","her"},
"herself":{"hers","she","her"},
"shine":{"shines","shining","shined","shone","shiny"},
"shined":{"shines","shining","shine","shone","shiny"},
"shines":{"shining","shined","shine","shone","shiny"},
"shining":{"shines","shined","shine","shone","shiny"},
"shone":{"shines","shining","shined","shine","shiny"},
"shiny":{"shines","shining","shined","shine","shone"},
"ship":{"ships","shipped","shipment","shipments","shipping"},
"ships":{"ship","shipped","shipment","shipments","shipping"},
"shipping":{"ships","ship","shipped","shipment","shipments"},
"shipped":{"ships","ship","shipment","shipments","shipping"},
"shipments":{"ships","ship","shipped","shipment","shipping"},
"shipment":{"ships","ship","shipped","shipments","shipping"},
"shoot":{"shots","shot","shoots","shooting","shootings"},
"shooting":{"shots","shot","shoots","shoot","shootings"},
"shootings":{"shots","shot","shoots","shoot","shooting"},
"shoots":{"shots","shot","shoot","shooting","shootings"},
"shot":{"shots","shoots","shoot","shooting","shootings"},
"shots":{"shot","shoots","shoot","shooting","shootings"},
"shore":{"shores"},
"shores":{"shore"},
"short":{"shortened","shorter","shorten","shortage","shortly","shortness","shortest","shortening","shortens"},
"shortage":{"shortened","shorter","shorten","short","shortly","shortness","shortest","shortening","shortens"},
"shorten":{"shortened","shorter","shortage","short","shortly","shortness","shortest","shortening","shortens"},
"shortened":{"shorter","shorten","shortage","short","shortly","shortness","shortest","shortening","shortens"},
"shortening":{"shortened","shorter","shorten","shortage","short","shortly","shortness","shortest","shortens"},
"shortens":{"shortened","shorter","shorten","shortage","short","shortly","shortness","shortest","shortening"},
"shorter":{"shortened","shorten","shortage","short","shortly","shortness","shortest","shortening","shortens"},
"shortest":{"shortened","shorter","shorten","shortage","short","shortly","shortness","shortening","shortens"},
"shortly":{"shortened","shorter","shorten","shortage","short","shortness","shortest","shortening","shortens"},
"shortness":{"shortened","shorter","shorten","shortage","short","shortly","shortest","shortening","shortens"},
"should":{"shouldn"},
"shoulder":{"shoulders"},
"shoulders":{"shoulder"},
"show":{"shown","showed","showing","shows"},
"showed":{"show","shown","showing","shows"},
"showing":{"show","shown","showed","shows"},
"shown":{"show","showed","showing","shows"},
"shows":{"show","shown","showed","showing"},
"side":{"sides"},
"sides":{"side"},
"sight":{"sights"},
"sights":{"sight"},
"sign":{"signature","signing","signatures","signed","signs"},
"signature":{"signing","signatures","signed","signs","sign"},
"signatures":{"signature","signing","signed","signs","sign"},
"signed":{"signature","signing","signatures","signs","sign"},
"signing":{"signature","signatures","signed","signs","sign"},
"signs":{"signature","signing","signatures","signed","sign"},
"silence":{"silenced","silences","silently","silent","silencing"},
"silenced":{"silence","silences","silently","silent","silencing"},
"silences":{"silence","silenced","silently","silent","silencing"},
"silencing":{"silence","silenced","silences","silently","silent"},
"silent":{"silence","silenced","silences","silently","silencing"},
"silently":{"silence","silenced","silences","silent","silencing"},
"simple":{"simplicity","simplest","simpler","simpleness","simplification","simplified","simply","simplify"},
"simpleness":{"simplicity","simplest","simpler","simple","simplification","simplified","simply","simplify"},
"simpler":{"simplicity","simplest","simpleness","simple","simplification","simplified","simply","simplify"},
"simplest":{"simplicity","simpler","simpleness","simple","simplification","simplified","simply","simplify"},
"simplicity":{"simplest","simpler","simpleness","simple","simplification","simplified","simply","simplify"},
"simplification":{"simplicity","simplest","simpler","simpleness","simple","simplified","simply","simplify"},
"simplified":{"simplicity","simplest","simpler","simpleness","simple","simplification","simply","simplify"},
"simplify":{"simplicity","simplest","simpler","simpleness","simple","simplification","simplified","simply"},
"simply":{"simplicity","simplest","simpler","simpleness","simple","simplification","simplified","simplify"},
"sing":{"singing","song","songs","singers","sang","sung","sings","singer"},
"sings":{"singing","song","songs","singers","sang","sung","sing","singer"},
"sung":{"singing","song","songs","singers","sang","sings","sing","singer"},
"sang":{"singing","song","songs","singers","sung","sings","sing","singer"},
"singer":{"singing","song","songs","singers","sang","sung","sings","sing"},
"singers":{"singing","song","songs","sang","sung","sings","sing","singer"},
"singing":{"song","songs","singers","sang","sung","sings","sing","singer"},
"song":{"singing","songs","singers","sang","sung","sings","sing","singer"},
"songs":{"singing","song","singers","sang","sung","sings","sing","singer"},
"single":{"singled"},
"singled":{"single"},
"sister":{"sisterly","sisters"},
"sisters":{"sister","sisterly"},
"sisterly":{"sister","sisters"},
"sit":{"sitting","sits","sat","seat"},
"sat":{"sit","sitting","sits"},
"sits":{"sit","sitting","sat"},
"sitting":{"sit","sits","sat"},
"situation":{"situations","situated","situate"},
"situations":{"situated","situate","situation"},
"situate":{"situations","situated","situation"},
"situated":{"situations","situate","situation"},
"six":{"sixths","sixth","sixes","six","sixthly"},
"sixes":{"sixths","sixth","sixes","six","sixthly"},
"sixteen":{"sixteenths","sixteenth","sixthly"},
"sixteenth":{"sixteenths","sixteen","sixthly"},
"sixteenths":{"sixteenth","sixteen"},
"sixth":{"sixty","sixtieth","sixties","sixths","sixes","six","sixthly"},
"sixthly":{"sixty","sixtieth","sixties","sixths","sixth","sixtieths","six"},
"sixths":{"sixty","sixtieth","sixties","sixth","sixes","six","sixthly"},
"sixties":{"sixty","sixtieth","sixths","sixth","sixtieths","sixes","six","sixthly"},
"sixtieth":{"sixty","sixties","sixths","sixth","sixtieths","sixes","six","sixthly"},
"sixtieths":{"sixty","sixtieth","sixties","sixths","sixth","sixes","six","sixthly"},
"sixty":{"sixtieth","sixties","sixths","sixth","sixtieths","sixes","six","sixthly"},
"size":{"sizes","sized","sizing"},
"sizes":{"size","sized","sizing"},
"sizing":{"sizes","size","sized"},
"sized":{"sizes","size","sizing"},
"sky":{"skies"},
"skies":{"sky"},
"sleep":{"slept","sleepy","sleeps","sleeping"},
"sleeping":{"slept","sleepy","sleeps","sleep"},
"sleeps":{"slept","sleepy","sleeping","sleep"},
"sleepy":{"slept","sleeps","sleeping","sleep"},
"slept":{"sleepy","sleeps","sleeping","sleep"},
"small":{"smallness","small","smallest","smaller"},
"smaller":{"smallness","small","smallest"},
"smallest":{"smallness","small","smaller"},
"smallness":{"small","smallest","smaller"},
"smile":{"smiles","smiling","smiled"},
"smiled":{"smiles","smiling","smile"},
"smiles":{"smiling","smiled","smile"},
"smiling":{"smiles","smiled","smile"},
"snow":{"snowing","snowed","snows"},
"snows":{"snowing","snowed","snow"},
"snowed":{"snowing","snow","snows"},
"snowing":{"snowed","snow","snows"},
"social":{"socially"},
"socially":{"social"},
"society":{"societies"},
"societies":{"society"},
"soft":{"softness","softly","softest","softer","softening","softened","soften","softens"},
"soften":{"softness","softly","softest","softer","softening","softened","soft","softens"},
"softened":{"softness","softly","softest","softer","softening","soften","soft","softens"},
"softening":{"softness","softly","softest","softer","softened","soften","soft","softens"},
"softens":{"softness","softly","softest","softer","softening","softened","soften","soft"},
"softer":{"softness","softly","softest","softening","softened","soften","soft","softens"},
"softest":{"softness","softly","softer","softening","softened","soften","soft","softens"},
"softly":{"softness","softest","softer","softening","softened","soften","soft","softens"},
"softness":{"softly","softest","softer","softening","softened","soften","soft","softens"},
"soldier":{"soldiers"},
"soldiers":{"soldier"},
"some":{"something","someone","somehow","somebody","sometimes","sometime","somewhere"},
"somebody":{"something","someone","somehow","some","sometimes","sometime","somewhere"},
"somehow":{"something","someone","somebody","some","sometimes","sometime","somewhere"},
"someone":{"something","somehow","somebody","some","sometimes","sometime","somewhere"},
"something":{"someone","somehow","somebody","some","sometimes","sometime","somewhere"},
"sometime":{"something","someone","somehow","somebody","some","sometimes","somewhere"},
"sometimes":{"something","someone","somehow","somebody","some","sometime","somewhere"},
"somewhere":{"something","someone","somehow","somebody","some","sometimes","sometime"},
"son":{"sons"},
"sons":{"sons"},
"soon":{"sooner","soonest"},
"sooner":{"soonest","soon"},
"soonest":{"sooner","soon"},
"sort":{"sorted","sorting","sorts"},
"sorted":{"sort","sorting","sorts"},
"sorting":{"sort","sorted","sorts"},
"sorts":{"sort","sorted","sorting"},
"soul":{"souls"},
"souls":{"soul"},
"sound":{"sounded","sounding","sounds"},
"sounds":{"sounded","sounding","sound"},
"sounded":{"sounding","sounds","sound"},
"sounding":{"sounded","sounds","sound"},
"south":{"southerners","southeast","southward","southern","southwest","southwards"},
"southeast":{"southerners","south","southward","southern","southwards"},
"southern":{"southerners","south","southeast","southward","southwest","southwards"},
"southerners":{"south","southeast","southward","southern","southwest","southwards"},
"southward":{"southerners","south","southeast","southern","southwest","southwards"},
"southwards":{"southerners","south","southeast","southward","southern","southwest"},
"southwest":{"southerners","south","southward","southern","southwards"},
"space":{"spaces","spaced","spacing"},
"spaced":{"spaces","space","spacing"},
"spaces":{"spaced","space","spacing"},
"spacing":{"spaces","spaced","space"},
"speak":{"spoken","spoke","speech","speeches","speaks","speaker","speaking","speakers"},
"speaker":{"spoken","spoke","speech","speeches","speak","speaks","speaking","speakers"},
"speakers":{"spoken","spoke","speech","speeches","speak","speaks","speaker","speaking"},
"speaking":{"spoken","spoke","speech","speeches","speak","speaks","speaker","speakers"},
"speaks":{"spoken","spoke","speech","speeches","speak","speaker","speaking","speakers"},
"speech":{"spoken","spoke","speeches","speak","speaks","speaker","speaking","speakers"},
"speeches":{"spoken","spoke","speech","speak","speaks","speaker","speaking","speakers"},
"spoke":{"spoken","speech","speeches","speak","speaks","speaker","speaking","speakers"},
"spoken":{"spoke","speech","speeches","speak","speaks","speaker","speaking","speakers"},
"special":{"specialization","specialists","specialities","specially","specialist","specialize","specialized","specializations","speciality"},
"specially":{"specialization","specialists","specialities","special","specialist","specialize","specialized","specializations","speciality"},
"specialist":{"specialization","specialists","specialities","special","specially","specialize","specialized","specializations","speciality"},
"speciality":{"specialization","specialists","specialities","special","specially","specialist","specialize","specialized","specializations"},
"specialities":{"specialization","specialists","special","specially","specialist","specialize","specialized","specializations","speciality"},
"specialists":{"specialization","specialities","special","specially","specialist","specialize","specialized","specializations","speciality"},
"specialize":{"specialization","specialists","specialities","special","specially","specialist","specialized","specializations","speciality"},
"specialization":{"specialists","specialities","special","specially","specialist","specialize","specialized","specializations","speciality"},
"specialized":{"specialization","specialists","specialities","special","specially","specialist","specialize","specializations","speciality"},
"specializations":{"specialization","specialists","specialities","special","specially","specialist","specialize","specialized","speciality"},
"speed":{"sped","speeds","speeding","speedy"},
"sped":{"speed","speeds","speeding","speedy"},
"speeding":{"sped","speed","speeds","speedy"},
"speeds":{"sped","speed","speeding","speedy"},
"speedy":{"sped","speed","speeds","speeding"},
"spend":{"spends","spending","spent"},
"spending":{"spend","spends","spent"},
"spends":{"spend","spending","spent"},
"spent":{"spend","spends","spending"},
"spirit":{"spirits","spiritual"},
"spirits":{"spirit","spiritual"},
"spiritual":{"spirit","spirits"},
"spot":{"spotting","spots","spotted"},
"spots":{"spot","spotting","spotted"},
"spotted":{"spot","spotting","spots"},
"spotting":{"spot","spots","spotted"},
"spread":{"spreads","spreading"},
"spreading":{"spreads","spread"},
"spreads":{"spread","spreading"},
"spring":{"springs","sprung","sprang","springing"},
"sprang":{"spring","springs","sprung","springing"},
"springing":{"spring","springs","sprung","sprang"},
"springs":{"spring","sprung","sprang","springing"},
"sprung":{"spring","springs","sprang","springing"},
"square":{"squarely","squares","squarer","squarest","squareness"},
"squarely":{"squares","square","squarer","squarest","squareness"},
"squareness":{"squarely","squares","square","squarer","squarest"},
"squarer":{"squarely","squares","square","squarest","squareness"},
"squares":{"squarely","square","squarer","squarest","squareness"},
"squarest":{"squarely","squares","square","squarer","squareness"},
"stage":{"staged","stages","staging"},
"staging":{"stage","staged","stages"},
"staged":{"stage","stages","staging"},
"stages":{"stage","staged","staging"},
"stand":{"stood","stands","standing"},
"outstanding":{"standing"},
"standing":{"stood","stands","stand"},
"stands":{"stood","stand","standing"},
"stood":{"stands","stand","standing"},
"standard":{"standards"},
"standards":{"standard"},
"star":{"starred","stars","starring"},
"starred":{"star","stars","starring"},
"stars":{"star","starred","starring"},
"starring":{"star","starred","stars"},
"start":{"starts","starting","started"},
"started":{"start","starts","starting"},
"starting":{"start","starts","started"},
"starts":{"start","starting","started"},
"state":{"statements","states","stating","stated","statement"},
"stated":{"statements","state","states","stating","statement"},
"statement":{"statements","state","states","stating","stated"},
"statements":{"state","states","stating","stated","statement"},
"states":{"statements","state","stating","stated","statement"},
"stating":{"statements","state","states","stated","statement"},
"station":{"stations"},
"stations":{"station"},
"stay":{"stayed","staying","stays"},
"stayed":{"staying","stays","stay"},
"staying":{"stayed","stays","stay"},
"stays":{"stayed","staying","stay"},
"step":{"steps","stepped","stepping"},
"stepped":{"steps","step","stepping"},
"stepping":{"steps","stepped","step"},
"steps":{"stepped","step","stepping"},
"still":{"stiller","stillest","stillness","till"},
"stiller":{"still","stillest","stillness"},
"stillest":{"still","stiller","stillness"},
"stillness":{"still","stiller","stillest"},
"stock":{"stocked","stocks"},
"stocked":{"stocks","stock"},
"stocks":{"stocked","stock"},
"stone":{"stony","stoning","stones","stoned"},
"stoned":{"stony","stoning","stone","stones"},
"stones":{"stony","stoning","stone","stoned"},
"stoning":{"stony","stone","stones","stoned"},
"stony":{"stoning","stone","stones","stoned"},
"stop":{"stopped","stopping","stops"},
"stopped":{"stopping","stops","stop"},
"stopping":{"stopped","stops","stop"},
"stops":{"stopped","stopping","stop"},
"store":{"stored","stores","storing"},
"stored":{"stores","storing","store"},
"stores":{"stored","storing","store"},
"storing":{"stored","stores","store"},
"story":{"stories"},
"stories":{"story"},
"strange":{"strangers","strangest","strangeness","stranger","strangely"},
"strangely":{"strangers","strangest","strangeness","stranger","strange"},
"strangeness":{"strangers","strangest","stranger","strangely","strange"},
"stranger":{"strangers","strangest","strangeness","strangely","strange"},
"strangers":{"strangest","strangeness","stranger","strangely","strange"},
"strangest":{"strangers","strangeness","stranger","strangely","strange"},
"stream":{"streaming","streams","streamed"},
"streamed":{"streaming","streams","stream"},
"streaming":{"streams","stream","streamed"},
"streams":{"streaming","stream","streamed"},
"street":{"streets"},
"streets":{"street"},
"strength":{"strengthened","strengthen","strengthening","strengthens"},
"strengthen":{"strengthened","strengthen","strengthening","strengthens"},
"strengthened":{"strength","strengthen","strengthening","strengthens"},
"strengthening":{"strengthened","strength","strengthen","strengthens"},
"strengthens":{"strengthened","strength","strengthen","strengthening"},
"strike":{"stroke","struck","strikes","striking"},
"strikes":{"strike","stroke","struck","striking"},
"striking":{"strike","stroke","struck","strikes"},
"struck":{"strike","stroke","strikes","striking"},
"stroke":{"strike","struck","strikes","striking"},
"strong":{"strongly","strongest","stronger"},
"stronger":{"strong","strongly","strongest"},
"strongest":{"strong","strongly","stronger"},
"strongly":{"strong","strongest","stronger"},
"struggle":{"struggled","struggles","struggling"},
"struggled":{"struggle","struggles","struggling"},
"struggles":{"struggle","struggled","struggling"},
"struggling":{"struggle","struggled","struggles"},
"study":{"studying","studies","studied"},
"studied":{"studying","studies","study"},
"studies":{"studying","studied","study"},
"studying":{"studies","studied","study"},
"student":{"students"},
"students":{"student"},
"subject":{"subjecting","subjected","subjects"},
"subjected":{"subjecting","subject","subjects"},
"subjecting":{"subject","subjected","subjects"},
"subjects":{"subjecting","subject","subjected"},
"substance":{"substantive","substantial","substances","substantially"},
"substances":{"substantive","substantial","substance","substantially"},
"substantial":{"substantive","substances","substance","substantially"},
"substantially":{"substantive","substantial","substances","substance"},
"substantive":{"substantial","substances","substance","substantially"},
"succeed":{"successfully","success","succeeds","succeeded","succeeding","successful"},
"succeeded":{"successfully","success","succeeds","succeed","succeeding","successful"},
"succeeding":{"successfully","success","succeeds","succeeded","succeed","successful"},
"succeeds":{"successfully","success","succeeded","succeed","succeeding","successful"},
"success":{"successfully","succeeds","succeeded","succeed","succeeding","successful"},
"successful":{"successfully","success","succeeds","succeeded","succeed","succeeding"},
"successfully":{"success","succeeds","succeeded","succeed","succeeding","successful"},
"suffer":{"suffers","suffering","suffered"},
"suffered":{"suffer","suffers","suffering"},
"suffering":{"suffer","suffers","suffered"},
"suffers":{"suffer","suffering","suffered"},
"suggest":{"suggests","suggestions","suggested","suggestion","suggesting"},
"suggested":{"suggests","suggest","suggestions","suggestion","suggesting"},
"suggesting":{"suggests","suggest","suggestions","suggested","suggestion"},
"suggestion":{"suggests","suggest","suggestions","suggested","suggesting"},
"suggestions":{"suggests","suggest","suggested","suggestion","suggesting"},
"suggests":{"suggest","suggestions","suggested","suggestion","suggesting"},
"summer":{"summers"},
"summers":{"summer"},
"sun":{"sunshine","suns","sunny","sunlight"},
"sunlight":{"sunshine","suns","sunny","sun"},
"sunny":{"sunshine","suns","sunlight","sun"},
"suns":{"sunshine","sunny","sunlight","sun"},
"sunshine":{"suns","sunny","sunlight","sun"},
"sunday":{"sundays"},
"sundays":{"sunday"},
"supply":{"supplying","supplies","suppliers","supplier","supplied"},
"supplied":{"supplying","supplies","suppliers","supplier","supply"},
"supplier":{"supplying","supplies","suppliers","supply","supplied"},
"suppliers":{"supplying","supplies","supplier","supply","supplied"},
"supplies":{"supplying","suppliers","supplier","supply","supplied"},
"supplying":{"supplies","suppliers","supplier","supply","supplied"},
"support":{"supportive","supports","supporters","supporting","supported"},
"supported":{"supportive","supports","supporters","supporting","support"},
"supporters":{"supportive","supports","supporting","supported","support"},
"supporting":{"supportive","supports","supporters","supported","support"},
"supports":{"supportive","supporters","supporting","supported","support"},
"supportive":{"supports","supporters","supporting","supported","support"},
"suppose":{"supposing","supposes","supposed"},
"supposed":{"supposing","supposes","suppose"},
"supposes":{"supposing","supposed","suppose"},
"supposing":{"supposes","supposed","suppose"},
"sure":{"surest","surer","sureness","surely"},
"surely":{"surest","surer","sureness","sure"},
"sureness":{"surest","surer","surely","sure"},
"surer":{"surest","sureness","surely","sure"},
"surest":{"surer","sureness","surely","sure"},
"surface":{"surfaced","surfaces","surfacing"},
"surfaced":{"surface","surfaces","surfacing"},
"surfaces":{"surface","surfaced","surfacing"},
"surfacing":{"surface","surfaced","surfaces"},
"surprise":{"surprised","surprises","surprising","surprisingly"},
"surprised":{"surprise","surprises","surprising","surprisingly"},
"surprises":{"surprise","surprised","surprising","surprisingly"},
"surprising":{"surprise","surprised","surprises","surprisingly"},
"surprisingly":{"surprise","surprised","surprises","surprising"},
"surround":{"surrounds","surrounding","surrounded"},
"surrounded":{"surrounds","surrounding","surround"},
"surrounding":{"surrounds","surrounded","surround"},
"surrounds":{"surrounding","surrounded","surround"},
"sweet":{"sweetly","sweets","sweetness"},
"sweetness":{"sweetly","sweets","sweet"},
"sweetly":{"sweets","sweet","sweetness"},
"sweets":{"sweetly","sweet","sweetness"},
"sword":{"swords"},
"swords":{"sword"},
"system":{"systematically","systematic","systems"},
"systematic":{"systematically","system","systems"},
"systems":{"systematically","systematic","system"},
"systematically":{"systematic","system","systems"},
"table":{"tablecloth","tables"},
"tablecloth":{"table","tables"},
"tables":{"table","tablecloth"},
"take":{"taking","taken","takes","took"},
"taken":{"taking","take","takes","took"},
"takes":{"taking","take","taken","took"},
"taking":{"take","taken","takes","took"},
"took":{"taking","take","taken","takes"},
"talk":{"talked","talks","talking"},
"talked":{"talk","talks","talking"},
"talking":{"talked","talk","talks"},
"talks":{"talked","talk","talking"},
"tax":{"taxing","taxpayer","taxpayers","taxed","taxes"},
"taxes":{"taxing","taxpayer","taxpayers","taxed","tax"},
"taxed":{"taxing","taxpayer","taxpayers","taxes","tax"},
"taxing":{"taxpayer","taxpayers","taxed","taxes","tax"},
"taxpayer":{"taxing","taxpayers","taxed","taxes","tax"},
"taxpayers":{"taxing","taxpayer","taxed","taxes","tax"},
"teach":{"teaches","teachers","teacher","taught","teaching","teachings"},
"taught":{"teaches","teachers","teacher","teach","teaching","teachings"},
"teacher":{"teaches","teachers","teach","taught","teaching","teachings"},
"teachers":{"teaches","teacher","teach","taught","teaching","teachings"},
"teaches":{"teachers","teacher","teach","taught","teaching","teachings"},
"teaching":{"teaches","teachers","teacher","teach","taught","teachings"},
"teachings":{"teaches","teachers","teacher","teach","taught","teaching"},
"tear":{"tearing","tears","torn","tore"},
"tearing":{"tear","tears","torn","tore"},
"tears":{"tear","tearing","torn","tore"},
"tore":{"tear","tearing","tears","torn"},
"torn":{"tear","tearing","tears","tore"},
"tell":{"told","tells","telling"},
"retell":{"retelling"},
"retelling":{"retell"},
"telling":{"tell","told","tells"},
"tells":{"tell","told","telling"},
"told":{"tell","tells","telling","retelling","retell"},
"temple":{"temples"},
"temples":{"temple"},
"ten":{"tenths","tenth","tens"},
"tens":{"tenths","tenth","ten"},
"tenth":{"tenths","tens","ten"},
"tenths":{"tenth","tens","ten"},
"term":{"terms"},
"terms":{"term"},
"test":{"tests","testing","tested"},
"tested":{"tests","testing","test"},
"testing":{"tests","tested","test"},
"tests":{"testing","tested","test"},
"they":{"their","theirs","them","themselves"},
"their":{"theirs","them","themselves","they"},
"theirs":{"them","themselves","they"},
"them":{"theirs","themselves","they","their"},
"themselves":{"theirs","their","them","they"},
"thing":{"things"},
"things":{"thing"},
"think":{"thoughtfulness","thoughtfully","thoughtful","thought","thinks","thinking","thoughts"},
"thinking":{"thoughtfulness","thoughtfully","thoughtful","thought","thinks","think","thoughts"},
"thinks":{"thoughtfulness","thoughtfully","thoughtful","thought","thinking","think","thoughts"},
"thought":{"thoughtfulness","thoughtfully","thoughtful","thinks","thinking","think","thoughts"},
"thoughts":{"thoughtfulness","thoughtfully","thoughtful","thought","thinks","thinking","think"},
"thoughtful":{"thoughtfulness","thoughtfully","thought","thinks","thinking","think","thoughts"},
"thoughtfully":{"thoughtfulness","thoughtful","thought","thinks","thinking","think","thoughts"},
"thoughtfulness":{"thoughtfully","thoughtful","thought","thinks","thinking","think","thoughts"},
"thirteen":{"thirteenths","thirteenth"},
"thirteenth":{"thirteenths","thirteen"},
"thirteenths":{"thirteenth","thirteen"},
"thirty":{"thirties","thirtieth","thirtieths"},
"thirties":{"thirty","thirtieth","thirtieths"},
"thirtieth":{"thirties","thirty","thirtieths"},
"thirtieths":{"thirties","thirty","thirtieth"},
"this":{"that","those","these"},
"these":{"that","those","this"},
"those":{"that","these","this"},
"that":{"those","these","this","who","which"},
"thousand":{"thousands","thousandth","thousandths"},
"thousands":{"thousand","thousandth","thousandths"},
"thousandth":{"thousand","thousands","thousandths"},
"thousandths":{"thousand","thousands","thousandth"},
"three":{"third","thirdly","thirds","threes"},
"threes":{"three","third","thirdly","thirds"},
"third":{"three","thirdly","thirds","threes"},
"thirdly":{"three","third","thirds","threes"},
"thirds":{"three","third","thirdly","threes"},
"through":{"throughout"},
"throughout":{"through"},
"throw":{"throws","thrown","throwing","threw"},
"threw":{"throws","thrown","throwing","throw"},
"throwing":{"throws","thrown","threw","throw"},
"thrown":{"throws","throwing","threw","throw"},
"throws":{"thrown","throwing","threw","throw"},
"thursday":{"thursdays","thurs"},
"thurs":{"thursdays","thursday"},
"thursdays":{"thurs","thursday"},
"time":{"timely","timer","times"},
"timer":{"timely","time","times"},
"times":{"timely","time","timer"},
"timeless":{"timely"},
"timely":{"time","timer","times"},
"ton":{"tons"},
"tons":{"ton"},
"top":{"topping","tops","topped"},
"topped":{"topping","tops","top"},
"topping":{"tops","topped","top"},
"tops":{"topping","topped","top"},
"total":{"totality","totals","totalling","totally","totaling","totalled","totaled"},
"totaled":{"totality","totals","totalling","totally","totaling","totalled","total"},
"totaling":{"totality","totals","totalling","totally","totalled","total","totaled"},
"totalled":{"totality","totals","totalling","totally","totaling","total","totaled"},
"totalling":{"totality","totals","totally","totaling","totalled","total","totaled"},
"totally":{"totality","totals","totalling","totaling","totalled","total","totaled"},
"totals":{"totality","totalling","totally","totaling","totalled","total","totaled"},
"totality":{"totals","totalling","totally","totaling","totalled","total","totaled"},
"touch":{"touching","touches","touched"},
"touched":{"touch","touching","touches"},
"touches":{"touch","touching","touched"},
"touching":{"touch","touches","touched"},
"toward":{"towards"},
"towards":{"toward"},
"town":{"towns"},
"towns":{"town"},
"trade":{"traders","trader","trading","traded","trades"},
"traded":{"traders","trader","trading","trade","trades"},
"trades":{"traders","trader","trading","traded","trade"},
"trading":{"traders","trader","traded","trade","trades"},
"trader":{"traders","trading","traded","trade","trades"},
"traders":{"trader","trading","traded","trade","trades"},
"train":{"trainers","trained","trains","training"},
"trained":{"trainers","trains","training","train"},
"trainers":{"trained","trains","training","train"},
"training":{"trainers","trained","trains","train"},
"trains":{"trainers","trained","training","train"},
"travel":{"traveled","travels","travellers","travelled","traveling","travelling"},
"traveled":{"travels","travellers","travelled","traveling","travel","travelling"},
"traveling":{"traveled","travels","travellers","travelled","travel","travelling"},
"travelled":{"traveled","travels","travellers","traveling","travel","travelling"},
"travellers":{"traveled","travels","travelled","traveling","travel","travelling"},
"travelling":{"traveled","travels","travellers","travelled","traveling","travel"},
"travels":{"traveled","travellers","travelled","traveling","travel","travelling"},
"tree":{"trees"},
"trees":{"tree"},
"trouble":{"troubled","troubles","troubling","troublesome"},
"troubled":{"trouble","troubles","troubling","troublesome"},
"troubles":{"trouble","troubled","troubling","troublesome"},
"troubling":{"trouble","troubled","troubles","troublesome"},
"troublesome":{"trouble","troubled","troubles","troubling"},
"true":{"truly","truthful","truths","truthfulness","truth","truest","truer"},
"truthful":{"truly","true","truths","truthfulness","truth","truest","truer"},
"truth":{"truly","true","truthful","truths","truthfulness","truest","truer"},
"truest":{"truly","true","truthful","truths","truthfulness","truth","truer"},
"truer":{"truly","true","truthful","truths","truthfulness","truth","truest"},
"truthfulness":{"truly","true","truthful","truths","truth","truest","truer"},
"truly":{"true","truthful","truths","truthfulness","truth","truest","truer"},
"truths":{"truly","true","truthful","truthfulness","truth","truest","truer"},
"trust":{"trusts","trusted","trusting"},
"trusted":{"trusts","entrust","trust","trusting"},
"trusting":{"trusts","entrust","trust","trusted"},
"entrust":{"trusts","trust","trusted","trusting"},
"trusts":{"entrust","trust","trusted","trusting"},
"try":{"trialed","trialing","trying","tries","tried","trials","trial"},
"tried":{"trialed","trialing","trying","tries","try","trials","trial"},
"tries":{"trialed","trialing","trying","tried","try","trials","trial"},
"trying":{"trialed","trialing","tries","tried","try","trials","trial"},
"trial":{"trialed","trialing","trying","tries","tried","try","trials"},
"trials":{"trialed","trialing","trying","tries","tried","try","trial"},
"trialing":{"trialed","trying","tries","tried","try","trials","trial"},
"trialed":{"trialing","trying","tries","tried","try","trials","trial"},
"tuesday":{"tuesdays","tues"},
"tues":{"tuesday","tuesdays"},
"tuesdays":{"tuesday","tues"},
"turn":{"turned","turning","turns"},
"turned":{"turning","turn","turns"},
"turning":{"turned","turn","turns"},
"turns":{"turned","turning","turn"},
"twelve":{"twelfths","twelfth","twelves"},
"twelves":{"twelfths","twelfth","twelve"},
"twelfth":{"twelfths","twelves","twelve"},
"twelfths":{"twelfth","twelves","twelve"},
"twenty":{"twenties","twentieth"},
"twenties":{"twenty","twentieth"},
"twentieth":{"twenty","twenties"},
"two":{"twice"},
"twice":{"two"},
"type":{"typing","types","typed","typists","typist"},
"typed":{"typing","types","type","typists","typist"},
"types":{"typing","type","typed","typists","typist"},
"typing":{"types","type","typed","typists","typist"},
"typist":{"typing","types","type","typed","typists"},
"typists":{"typing","types","type","typed","typist"},
"under":{"underneath"},
"underneath":{"under"},
"understand":{"understands","understanding","understood"},
"understanding":{"understands","understand","understood"},
"understands":{"understand","understanding","understood"},
"understood":{"understands","understand","understanding"},
"union":{"unions"},
"unions":{"union"},
"unite":{"unit","units","unity","uniting","unites","united"},
"united":{"unit","unite","units","unity","uniting","unites"},
"unites":{"unit","unite","units","unity","uniting","united"},
"uniting":{"unit","unite","units","unity","unites","united"},
"unity":{"unit","unite","units","uniting","unites","united"},
"unit":{"unite","units","unity","uniting","unites","united"},
"units":{"unit","unite","unity","uniting","unites","united"},
"university":{"universities"},
"universities":{"university"},
"up":{"upside"},
"upside":{"up"},
"use":{"user","usefully","using","uses","usefulness","useful","used","users"},
"misused":{"usefulness","useless"},
"used":{"use","user","usefully","using","uses","usefulness","useful","users"},
"useful":{"use","user","usefully","using","uses","usefulness","","used","users"},
"usefulness":{"use","user","usefully","using","uses","useful","used","useless","users"},
"useless":{"usefulness","misused"},
"uses":{"use","user","usefully","using","usefulness","useful","used","users"},
"using":{"use","user","usefully","uses","usefulness","useful","used","users"},
"usefully":{"use","user","using","uses","usefulness","useful","used","users"},
"user":{"use","usefully","using","uses","usefulness","useful","used","users"},
"users":{"use","user","usefully","using","uses","usefulness","useful","used"},
"usual":{"usually",""},
"usually":{"usual"},
"unusual":{"unusually"},
"unusually":{"unusual"},
"valley":{"valleys"},
"valleys":{"valley"},
"value":{"valuable","valuation","valuer","values","valuing","valued","valuables"},
"valuable":{"value","valuation","valuer","values","valuing","valued","valuables"},
"valuables":{"value","valuable","valuation","valuer","values","valuing","valued"},
"valuation":{"value","valuable","valuer","values","valuing","valued","valuables"},
"valued":{"value","valuable","valuation","valuer","values","valuing","valuables"},
"valuer":{"value","valuable","valuation","values","valuing","valued","valuables"},
"valueless":{"invaluable","invaluably"},
"values":{"value","valuable","valuation","valuer","valuing","valued","valuables"},
"valuing":{"value","valuable","valuation","valuer","values","valued","valuables"},
"invaluable":{"valueless","invaluable","invaluably"},
"invaluably":{"valueless","invaluable"},
"variety":{"varieties"},
"varieties":{"variety"},
"various":{"variously"},
"variously":{"various"},
"vessel":{"vessels"},
"vessels":{"vessel"},
"victory":{"victories","victorious"},
"victories":{"victorious","victory"},
"victorious":{"victories","victory"},
"view":{"viewing","viewed","views"},
"viewed":{"viewing","view","views"},
"viewing":{"viewed","view","views"},
"views":{"viewing","viewed","view"},
"village":{"villager","villagers","villages"},
"villager":{"village","villagers","villages"},
"villagers":{"village","villager","villages"},
"villages":{"village","villager","villagers"},
"virtue":{"virtuous","virtues"},
"virtues":{"virtuous","virtue"},
"virtuous":{"virtues","virtue"},
"visit":{"visitation","visited","visiting","visitor","visitors","visits"},
"visited":{"visitation","visit","visiting","visitor","visitors","visits"},
"visiting":{"visitation","visited","visit","visitor","visitors","visits"},
"visitor":{"visitation","visited","visit","visiting","visitors","visits"},
"visitors":{"visitation","visited","visit","visiting","visitor","visits"},
"visits":{"visitation","visited","visit","visiting","visitor","visitors"},
"visitation":{"visited","visit","visiting","visitor","visitors","visits"},
"voice":{"voiced","voices","voicing"},
"voiced":{"voices","voicing","voice"},
"voices":{"voiced","voicing","voice"},
"voicing":{"voiced","voices","voice"},
"vote":{"voting","votes","voters","voter","voted"},
"voted":{"voting","votes","voters","voter","vote"},
"voter":{"voting","votes","voters","voted","vote"},
"voters":{"voting","votes","voter","voted","vote"},
"votes":{"voting","voters","voter","voted","vote"},
"voting":{"votes","voters","voter","voted","vote"},
"wage":{"wages"},
"wages":{"wages"},
"wait":{"waitresses","waitress","waiters","waiter","waits","waiting","waited"},
"waited":{"waitresses","waitress","waiters","waiter","waits","waiting","wait"},
"waiting":{"waitresses","waitress","waiters","waiter","waits","waited","wait"},
"waits":{"waitresses","waitress","waiters","waiter","waiting","waited","wait"},
"waiter":{"waitresses","waitress","waiters","waits","waiting","waited","wait"},
"waiters":{"waitresses","waitress","waiter","waits","waiting","waited","wait"},
"waitress":{"waitresses","waiters","waiter","waits","waiting","waited","wait"},
"waitresses":{"waitress","waiters","waiter","waits","waiting","waited","wait"},
"walk":{"walked","walking","walks"},
"walked":{"walk","walking","walks"},
"walking":{"walk","walked","walks"},
"walks":{"walk","walked","walking"},
"wall":{"walls","walled"},
"walled":{"walls","wall"},
"walls":{"walled","wall"},
"want":{"wanted","wanting","wants"},
"wanted":{"want","wanting","wants"},
"wanting":{"want","wanted","wants"},
"wants":{"want","wanted","wanting"},
"war":{"wars","warring","warred"},
"warred":{"wars","warring","war"},
"warring":{"wars","war","warred"},
"wars":{"warring","war","warred"},
"watch":{"watched","watches","watching"},
"watched":{"watch","watches","watching"},
"watches":{"watch","watched","watching"},
"watching":{"watch","watched","watches"},
"water":{"watering","waters","watered"},
"watered":{"watering","waters","water"},
"waters":{"watering","watered","water"},
"watering":{"waters","watered","water"},
"wave":{"waving","waves","waved"},
"waved":{"waving","waves","wave"},
"waves":{"waving","waved","wave"},
"waving":{"waves","waved","wave"},
"way":{"ways"},
"ways":{"way"},
"we":{"our","ours","ourselves","us"},
"our":{"we","ours","ourselves","us"},
"ours":{"we","our","ourselves","us"},
"ourselves":{"we","our","ours","us"},
"us":{"we","our","ours","ourselves"},
"wealth":{"wealthy"},
"wealthy":{"wealthy"},
"wear":{"wears","wore","worn","wearing"},
"wearing":{"wears","wore","worn","wear"},
"wears":{"wore","worn","wearing","wear"},
"wore":{"wears","worn","wearing","wear"},
"worn":{"wears","wore","wearing","wear"},
"wednesday":{"wednesdays"},
"wednesdays":{"wednesday"},
"week":{"weekend","weekends","weekly","weeks"},
"weekend":{"week","weekends","weekly","weeks"},
"weekends":{"week","weekend","weekly","weeks"},
"weekly":{"week","weekend","weekends","weeks"},
"weeks":{"week","weekend","weekends","weekly"},
"welcome":{"welcoming","welcomes","welcomed"},
"welcomed":{"welcoming","welcomes","welcome"},
"welcomes":{"welcoming","welcomed","welcome"},
"welcoming":{"welcomes","welcomed","welcome"},
"well":{"wells","good"},
"wells":{"well"},
"west":{"westwards","westward"},
"westward":{"westwards","west"},
"westwards":{"west","westward"},
"western":{"westerns"},
"westerns":{"western"},
"what":{"whatever"},
"whatever":{"what"},
"when":{"whenever"},
"whenever":{"when"},
"where":{"wherever"},
"wherever":{"where"},
"which":{"whichever","that","who"},
"whichever":{"which"},
"while":{"whilst"},
"whilst":{"while"},
"white":{"whitish","whitest","whiter","whiteness"},
"whiteness":{"white","whitish","whitest","whiter"},
"whiter":{"white","whitish","whitest","whiteness"},
"whitest":{"white","whitish","whiter","whiteness"},
"whitish":{"white","whitest","whiter","whiteness"},
"who":{"whoever","whom","whose","which","that"},
"whoever":{"whom","whose","who"},
"whom":{"whoever","whose","who"},
"whose":{"whoever","whom","who"},
"whole":{"wholeness","wholly"},
"wholeness":{"whole","wholly"},
"wholly":{"whole","wholeness"},
"wide":{"widest","wider","widening","width","wideness","widened","widely"},
"widely":{"widest","wider","widening","width","wideness","widened","wide"},
"widened":{"widest","wider","widening","width","wideness","widely","wide"},
"wideness":{"widest","wider","widening","width","widened","widely","wide"},
"widening":{"widest","wider","width","wideness","widened","widely","wide"},
"wider":{"widest","widening","width","wideness","widened","widely","wide"},
"widest":{"wider","widening","width","wideness","widened","widely","wide"},
"width":{"widest","wider","widening","wideness","widened","widely","wide"},
"wife":{"wives"},
"wives":{"wife"},
"wild":{"wildness","wildly","wilder","wildest"},
"wilder":{"wildness","wildly","wildest","wild"},
"wildest":{"wildness","wildly","wilder","wild"},
"wildly":{"wildness","wilder","wildest","wild"},
"wildness":{"wildly","wilder","wildest","wild"},
"will":{"willing","willingly","willingness"},
"willing":{"willingly","will","willingness"},
"willingness":{"willing","willingly","will"},
"willingly":{"willing","will","willingness"},
"unwilling":{"unwillingly"},
"unwillingly":{"unwilling"},
"win":{"won","wins","winning","winners","winner"},
"winner":{"won","wins","winning","winners","win"},
"winners":{"won","wins","winning","winner","win"},
"winning":{"won","wins","winners","winner","win"},
"wins":{"won","winning","winners","winner","win"},
"won":{"wins","winning","winners","winner","win"},
"wind":{"winding","winds","windy","winded"},
"winded":{"wind","winding","winds","windy"},
"winding":{"wind","winds","windy","winded"},
"winds":{"wind","winding","windy","winded"},
"windy":{"wind","winding","winds","winded"},
"window":{"windows"},
"windows":{"window"},
"winter":{"winters","wintry"},
"winters":{"winter","wintry"},
"wintry":{"winter","winters"},
"wise":{"wisely","wisest","wisdom","wiser","wiseness"},
"wisdom":{"wisely","wise","wisest","wiser","wiseness"},
"wisely":{"unwise","wise","wisest","wisdom","wiser","wiseness"},
"wiser":{"wisely","wise","wisest","wisdom","wiseness"},
"wisest":{"wisely","wise","wisdom","wiser","wiseness"},
"wish":{"wishes","wished","wishing"},
"wished":{"wishes","wish","wishing"},
"wishes":{"wished","wish","wishing"},
"wishing":{"wishes","wished","wish"},
"woman":{"women"},
"women":{"woman"},
"wonder":{"wonderful","wondered","wonderfully","wonders","wondering"},
"wondered":{"wonderful","wonderfully","wonders","wondering","wonder"},
"wonderful":{"wondered","wonderfully","wonders","wondering","wonder"},
"wondering":{"wonderful","wondered","wonderfully","wonders","wonder"},
"wonders":{"wonderful","wondered","wonderfully","wondering","wonder"},
"wonderfully":{"wonderful","wondered","wonders","wondering","wonder"},
"wood":{"woods","woody","woodland","wooden"},
"woods":{"wood","woody","woodland","wooden"},
"wooden":{"woods","wood","woody","woodland"},
"woodland":{"woods","wood","woody","wooden"},
"woody":{"woods","wood","woodland","wooden"},
"word":{"wording","words","world"},
"words":{"wording","word"},
"wording":{"words","word"},
"work":{"workmen","works","workman","worked","worker","workers","working"},
"worked":{"workmen","works","workman","work","worker","workers","working"},
"worker":{"workmen","works","workman","work","worked","workers","working"},
"workers":{"workmen","works","workman","work","worked","worker","working"},
"working":{"workmen","works","workman","work","worked","worker","workers"},
"works":{"workmen","workman","work","worked","worker","workers","working"},
"workman":{"workmen","works","work","worked","worker","workers","working"},
"workmen":{"works","workman","work","worked","worker","workers","working"},
"world":{"worlds"},
"worlds":{"world"},
"worth":{"worthy"},
"worthy":{"worth"},
"would":{"wouldn"},
"wound":{"wounds","wounding","wounded"},
"wounds":{"wound","wounding","wounded"},
"wounded":{"wounds","wound","wounding"},
"wounding":{"wounds","wound","wounded"},
"write":{"writing","wrote","written","writes","writer","writings","writers"},
"writer":{"writing","wrote","written","writes","write","writings","writers"},
"writers":{"writing","wrote","written","writes","writer","write","writings"},
"writes":{"writing","wrote","written","writer","write","writings","writers"},
"writing":{"wrote","written","writes","writer","write","writings","writers"},
"writings":{"writing","wrote","written","writes","writer","write","writers"},
"written":{"writing","wrote","writes","writer","write","writings","writers"},
"wrote":{"writing","written","writes","writer","write","writings","writers"},
"wrong":{"wrongly","wrongs","wronging","wronged"},
"wronged":{"wrongly","wrongs","wronging","wrong"},
"wronging":{"wrongly","wrongs","wronged","wrong"},
"wrongs":{"wrongly","wronging","wronged","wrong"},
"wrongly":{"wrongs","wronging","wronged","wrong"},
"year":{"yearly","years"},
"years":{"yearly","year"},
"yearly":{"years","year"},
"yield":{"yielding","yielded","yields"},
"yields":{"yielding","yielded","yield"},
"yielded":{"yielding","yield","yields"},
"yielding":{"yielded","yield","yields"},
"you":{"your","yours","yourselves","yourself"},
"your":{"you","yours","yourselves","yourself"},
"yourselves":{"you","your","yours","yourself"},
"yourself":{"you","your","yours","yourselves"},
"yours":{"you","your","yourselves","yourself"},
"young":{"youngest","youngsters","youngster","younger"},
"younger":{"young","youngest","youngsters","youngster"},
"youngster":{"young","youngest","youngsters","younger"},
"youngest":{"young","youngsters","youngster","younger"},
"youngsters":{"young","youngest","youngster","younger"},
"youth":{"youthful","youths"},
"youths":{"youthful","youth"},
"youthful":{"youth","youths"},
"absence":{"absences"},
"absences":{"absence"},
"accident":{"accidents","accidental","accidentally"},
"accidents":{"accident","accidental","accidentally"},
"accidental":{"accident","accidents","accidentally"},
"accidentally":{"accident","accidents","accidental"},
"accuse":{"accusing","accuses","accused"},
"accusing":{"accuse","accuses","accused"},
"accuses":{"accusing","accuse","accused"},
"accused":{"accusing","accuse","accuses"},
"accustom":{"accustomed","accustoming","accustoms"},
"accustoms":{"accustomed","accustoming","accustom"},
"accustoming":{"accustomed","accustoms","accustom"},
"accustomed":{"accustoming","accustoms","accustom"},
"ache":{"aching","aches","ached"},
"aching":{"ache","aches","ached"},
"aches":{"aching","ache","ached"},
"ached":{"aching","ache","aches"},
"admire":{"admiring","admires","admired","admirable","admiration"},
"admiring":{"admire","admires","admired","admirable","admiration"},
"admires":{"admire","admiring","admired","admirable","admiration"},
"admired":{"admire","admiring","admires","admirable","admiration"},
"admirable":{"admire","admiring","admires","admired","admiration"},
"admiration":{"admire","admiring","admires","admired","admirable"},
"advertise":{"advertiser","advertises","advertised","advertisement","advertisements","advertising"},
"advertising":{"advertiser","advertises","advertised","advertisement","advertisements","advertise"},
"advertises":{"advertiser","advertised","advertisement","advertisements","advertise","advertising"},
"advertiser":{"advertises","advertised","advertisement","advertisements","advertise","advertising"},
"advertised":{"advertiser","advertises","advertisement","advertisements","advertise","advertising"},
"advertisement":{"advertiser","advertises","advertised","advertisements","advertise","advertising"},
"advertisements":{"advertiser","advertises","advertised","advertisement","advertise","advertising"},
"advice":{"advisory","advise","advised","advisors","adviser","advisers","advises","advising"},
"advising":{"advisory","advise","advised","advisors","adviser","advisers","advises","advice"},
"advises":{"advisory","advise","advised","advisors","adviser","advisers","advice","advising"},
"advisers":{"advisory","advise","advised","advisors","adviser","advises","advice","advising"},
"adviser":{"advisory","advise","advised","advisors","advisers","advises","advice","advising"},
"advised":{"advisory","advise","advisors","adviser","advisers","advises","advice","advising"},
"advise":{"advisory","advised","advisors","adviser","advisers","advises","advice","advising"},
"advisory":{"advise","advised","advisors","adviser","advisers","advises","advice","advising"},
"aeroplane":{"aeroplanes"},
"aeroplanes":{"aeroplane"},
"afford":{"affording","affordable","affords","afforded"},
"afforded":{"afford","affording","affordable","affords"},
"affording":{"afford","affordable","affords","afforded"},
"affords":{"afford","affording","affordable","afforded"},
"affordable":{"afford","affording","affords","afforded"},
"afternoon":{"afternoons"},
"afternoons":{"afternoon"},
"agriculture":{"agricultural"},
"agricultural":{"agriculture"},
"aim":{"aiming","aims","aimed"},
"aims":{"aiming","aim","aimed"},
"aiming":{"aims","aim","aimed"},
"aimed":{"aiming","aims","aim"},
"aimless":{"aimlessness"},
"aimlessness":{"aimless"},
"airplane":{"airplanes"},
"airplanes":{"airplane"},
"ambition":{"ambitions","ambitious","ambitiously"},
"ambitions":{"ambition","ambitious","ambitiously"},
"ambitious":{"ambition","ambitions","ambitiously"},
"ambitiously":{"ambition","ambitions","ambitious"},
"amuse":{"amusement","amusing","amusements","amused","amuses"},
"amusing":{"amusement","amusements","amused","amuses","amuse"},
"amuses":{"amusement","amusing","amusements","amused","amuse"},
"amused":{"amusement","amusing","amusements","amuses","amuse"},
"amusement":{"amusing","amusements","amused","amuses","amuse"},
"amusements":{"amusement","amusing","amused","amuses","amuse"},
"anger":{"angering","angriest","angrier","angrily","angered","angers","angry"},
"angers":{"angering","angriest","anger","angrier","angrily","angered","angry"},
"angering":{"angriest","anger","angrier","angrily","angered","angers","angry"},
"angered":{"angering","angriest","anger","angrier","angrily","angers","angry"},
"angry":{"angering","angriest","anger","angrier","angrily","angered","angers"},
"angrily":{"angering","angriest","anger","angrier","angered","angers","angry"},
"angrier":{"angering","angriest","anger","angrily","angered","angers","angry"},
"angriest":{"angering","anger","angrier","angrily","angered","angers","angry"},
"angle":{"angles","angling","angled"},
"angles":{"angle","angling","angled"},
"angling":{"angle","angles","angled"},
"angled":{"angle","angles","angling"},
"annoy":{"annoys","annoyed","annoyance","annoying"},
"annoys":{"annoy","annoyed","annoyance","annoying"},
"annoying":{"annoy","annoys","annoyed","annoyance"},
"annoyed":{"annoy","annoys","annoyance","annoying"},
"annoyance":{"annoy","annoys","annoyed","annoying"},
"anxiety":{"anxiously","anxious","anxieties"},
"anxieties":{"anxiously","anxious","anxiety"},
"anxious":{"anxiously","anxieties","anxiety"},
"anxiously":{"anxious","anxieties","anxiety"},
"apologize":{"apologised","apologising","apologise","apologized","apologizes","apologises"},
"apologizes":{"apologised","apologising","apologise","apologized","apologize","apologises"},
"apologized":{"apologised","apologising","apologise","apologizes","apologize","apologises"},
"apologise":{"apologised","apologising","apologized","apologizes","apologize","apologises"},
"apologising":{"apologised","apologise","apologized","apologizes","apologize","apologises"},
"apologises":{"apologised","apologising","apologise","apologized","apologizes","apologize"},
"apologised":{"apologising","apologise","apologized","apologizes","apologize","apologises"},
"apology":{"apologies","apologetic"},
"apologies":{"apologetic","apology"},
"apologetic":{"apologies","apology"},
"applaud":{"applauding","applauded","applauds"},
"applauds":{"applauding","applauded","applaud"},
"applauding":{"applauded","applaud","applauds"},
"applauded":{"applauding","applaud","applauds"},
"apple":{"apples"},
"apples":{"apple"},
"approve":{"approval","approved","approves","approving"},
"approving":{"approve","approval","approved","approves"},
"approves":{"approve","approval","approved","approving"},
"approved":{"approve","approval","approves","approving"},
"approval":{"approve","approved","approves","approving"},
"disapprove":{"disapproval","disapproved","disapproving","disapproves"},
"disapproving":{"disapproval","disapproved","disapprove","disapproves"},
"disapproves":{"disapproval","disapproved","disapproving","disapprove"},
"disapproved":{"disapproval","disapproving","disapprove","disapproves"},
"disapproval":{"disapproved","disapproving","disapprove","disapproves"},
"arch":{"arches","arched","arching"},
"arching":{"arches","arch","arched"},
"arches":{"arch","arched","arching"},
"arched":{"arches","arch","arching"},
"argue":{"arguments","argument","arguable","argued","argues","arguing"},
"arguing":{"arguments","argument","arguable","argued","argues","argue"},
"argues":{"arguments","argument","arguable","argued","argue","arguing"},
"argued":{"arguments","argument","arguable","argues","argue","arguing"},
"arguable":{"arguments","argument","argued","argues","argue","arguing"},
"argument":{"arguments","arguable","argued","argues","argue","arguing"},
"arguments":{"argument","arguable","argued","argues","argue","arguing"},
"arrange":{"arranges","arrangements","arrangement","arranging","arranged"},
"arranged":{"arranges","arrangements","arrangement","arranging","arrange"},
"arranging":{"arranges","arrangements","arrangement","arranged","arrange"},
"arranges":{"arrangements","arrangement","arranging","arranged","arrange"},
"arrangement":{"arranges","arrangements","arranging","arranged","arrange"},
"arrangements":{"arranges","arrangement","arranging","arranged","arrange"},
"arrest":{"arrests","arresting","arrested"},
"arrests":{"arresting","arrested","arrest"},
"arresting":{"arrests","arrested","arrest"},
"arrested":{"arrests","arresting","arrest"},
"arrow":{"arrows"},
"arrows":{"arrow"},
"artificial":{"artificially"},
"artificially":{"artificial"},
"ash":{"ashes"},
"ashes":{"ash"},
"ashamed":{"ashamedly"},
"ashamedly":{"ashamed"},
"astonish":{"astonishment","astonishing","astonishes","astonished"},
"astonishing":{"astonishment","astonish","astonishes","astonished"},
"astonishes":{"astonishment","astonish","astonishing","astonished"},
"astonished":{"astonishment","astonish","astonishing","astonishes"},
"astonishment":{"astonish","astonishing","astonishes","astonished"},
"attend":{"attends","attendances","attendance","attendant","attended","attending"},
"attends":{"attend","attendances","attendance","attendant","attended","attending"},
"attending":{"attends","attend","attendances","attendance","attendant","attended"},
"attended":{"attends","attend","attendances","attendance","attendant","attending"},
"attendant":{"attends","attend","attendances","attendance","attended","attending"},
"attendance":{"attends","attend","attendances","attendant","attended","attending"},
"attendances":{"attends","attend","attendance","attendant","attended","attending"},
"attract":{"attractiveness","attractively","attractions","attraction","attracted","attracting","attracts","attractive"},
"attracts":{"attractiveness","attractively","attractions","attraction","attracted","attracting","attract","attractive"},
"attracting":{"attractiveness","attractively","attractions","attraction","attracted","attracts","attract","attractive"},
"attracted":{"attractiveness","attractively","attractions","attraction","attracting","attracts","attract","attractive"},
"attractive":{"attractiveness","attractively","attractions","attraction","attracted","attracting","attracts","attract"},
"attraction":{"attractiveness","attractively","attractions","attracted","attracting","attracts","attract","attractive"},
"attractions":{"attractiveness","attractively","attraction","attracted","attracting","attracts","attract","attractive"},
"attractively":{"attractiveness","attractions","attraction","attracted","attracting","attracts","attract","attractive"},
"attractiveness":{"attractively","attractions","attraction","attracted","attracting","attracts","attract","attractive"},
"audience":{"audiences"},
"audiences":{"audience"},
"aunt":{"aunty","aunts"},
"aunts":{"aunt","aunty"},
"avenue":{"avenues"},
"avenues":{"avenue"},
"avoid":{"avoidable","avoiding","avoidance","avoided","avoids"},
"avoids":{"avoidable","avoiding","avoidance","avoided","avoid"},
"avoiding":{"avoidable","avoidance","avoided","avoids","avoid"},
"avoided":{"avoidable","avoiding","avoidance","avoids","avoid"},
"avoidance":{"avoidable","avoiding","avoided","avoids","avoid"},
"avoidable":{"avoiding","avoidance","avoided","avoids","avoid"},
"awake":{"awoken","awaken"},
"awaken":{"awoken","awake"},
"awoken":{"awake","awaken"},
"awkward":{"awkwardly"},
"awkwardly":{"awkward"},
"axe":{"axing","ax","axed","axes"},
"axing":{"ax","axed","axes","axe"},
"axes":{"axing","ax","axed","axe"},
"axed":{"axing","ax","axes","axe"},
"ax":{"axing","axed","axes","axe"},
"baby":{"babies"},
"babies":{"baby"},
"bag":{"bagging","bagged","bags"},
"bags":{"bagging","bagged","bag"},
"bagging":{"bagged","bag","bags"},
"bagged":{"bagging","bag","bags"},
"bake":{"baking","bakers","baker","baked","bakes"},
"baking":{"bake","bakers","baker","baked","bakes"},
"bakes":{"baking","bake","bakers","baker","baked"},
"bakers":{"baking","bake","baker","baked","bakes"},
"baker":{"baking","bake","bakers","baked","bakes"},
"baked":{"baking","bake","bakers","baker","bakes"},
"balance":{"balanced","balances","balancing"},
"balancing":{"balanced","balances","balance"},
"balances":{"balanced","balancing","balance"},
"balanced":{"balances","balancing","balance"},
"band":{"banding","banded","bands"},
"banded":{"banding","band","bands"},
"banding":{"band","banded","bands"},
"bands":{"banding","band","banded"},
"barber":{"barbers"},
"barbers":{"barber"},
"bare":{"baring","bared","bares"},
"baring":{"bared","bares","bare"},
"bares":{"baring","bared","bare"},
"bared":{"baring","bares","bare"},
"bargain":{"bargained","bargains","bargaining"},
"bargains":{"bargain","bargained","bargaining"},
"bargaining":{"bargain","bargained","bargains"},
"bargained":{"bargain","bargains","bargaining"},
"barrel":{"barrels"},
"barrels":{"barrel"},
"basin":{"basins"},
"basins":{"basin"},
"basket":{"baskets"},
"baskets":{"basket"},
"bath":{"baths"},
"baths":{"bath"},
"bathe":{"bathing","bathed","bathes"},
"bathing":{"bathe","bathed","bathes"},
"bathes":{"bathing","bathe","bathed"},
"bathed":{"bathing","bathe","bathes"},
"bay":{"bays"},
"bays":{"bay"},
"beak":{"beaked","beaks"},
"beaks":{"beaked","beak"},
"beaked":{"beaks","beak"},
"beam":{"beaming","beams","beamed"},
"beams":{"beaming","beam","beamed"},
"beamed":{"beaming","beam","beams"},
"beaming":{"beam","beams","beamed"},
"bean":{"beans"},
"beans":{"bean"},
"beard":{"bearded","beards"},
"beards":{"bearded","beard"},
"bearded":{"beards","beard"},
"beast":{"beasts"},
"beasts":{"beast"},
"beat":{"beating","beaten","beats","best"},
"beats":{"beating","beaten","beat"},
"beating":{"beaten","beat","beats"},
"beaten":{"beating","beat","beats"},
"beg":{"beggars","begged","begging","begs","beggar"},
"begs":{"beggars","begged","begging","beg","beggar"},
"begging":{"beggars","begged","begs","beg","beggar"},
"begged":{"beggars","begging","begs","beg","beggar"},
"beggars":{"begged","begging","begs","beg","beggar"},
"beggar":{"beggars","begged","begging","begs","beg"},
"behave":{"behaves","behaved","behaving"},
"behaves":{"behaved","behave","behaving","behaviors"},
"behaved":{"behaves","behave","behaving"},
"behaving":{"behaves","behaved","behave"},
"behaviour":{"behavioral","behavior","behavioural","behaviors","behaviours"},
"behaviours":{"behavioral","behavior","behavioural","behaviors","behaviour"},
"behaviors":{"behavioral","behavior","behavioural","behaviours","behaviour"},
"behavioural":{"behavior","behavioural","behaviors","behaviours","behaviour"},
"behavior":{"behavioral","behavioural","behaviors","behaviours","behaviour"},
"behavioral":{"behavior","behavioural","behaviors","behaviours","behaviour"},
"bell":{"bells"},
"bells":{"bell"},
"belt":{"belted","belting","belts"},
"belts":{"belted","belting","belt"},
"belting":{"belted","belts","belt"},
"belted":{"belting","belts","belt"},
"bend":{"bent","bends","bending"},
"bent":{"bend","bends","bending"},
"bends":{"bend","bent","bending"},
"bending":{"bend","bent","bends"},
"berry":{"berries"},
"berries":{"berry"},
"bicycle":{"bicycles","bicycled","bicycling"},
"bicycling":{"bicycles","bicycled","bicycle"},
"bicycles":{"bicycled","bicycling","bicycle"},
"bicycled":{"bicycles","bicycling","bicycle"},
"billion":{"billions"},
"billions":{"billion"},
"bind":{"binds","binding","binders","binder"},
"binds":{"bind","binding","binders","binder"},
"binding":{"bind","binds","binders","binder"},
"binders":{"bind","binds","binding","binder"},
"binder":{"bind","binds","binding","binders"},
"birth":{"births","birthdays","birthday"},
"births":{"birthdays","birth","birthday"},
"birthdays":{"births","birth","birthday"},
"birthday":{"births","birthdays","birth"},
"bit":{"bits"},
"bits":{"bit"},
"bite":{"bitten","bites","biting"},
"bites":{"bitten","bite","biting"},
"biting":{"bitten","bite","bites"},
"bitten":{"bite","bites","biting"},
"bitter":{"bitterness","bitterest","bitterer","bitterly"},
"bitterness":{"bitterest","bitterer","bitterly","bitter"},
"bitterly":{"bitterness","bitterest","bitterer","bitter"},
"bitterest":{"bitterness","bitterer","bitterly","bitter"},
"bitterer":{"bitterness","bitterest","bitterly","bitter"},
"blade":{"blades"},
"blades":{"blade"},
"blame":{"blaming","blames","blamed"},
"blaming":{"blame","blames","blamed"},
"blames":{"blame","blaming","blamed"},
"blamed":{"blame","blaming","blames"},
"bless":{"blesses","blessings","blessing","blessed"},
"blessed":{"blesses","blessings","bless","blessing"},
"blesses":{"blessings","bless","blessing","blessed"},
"blessing":{"blesses","blessings","bless","blessed"},
"blessings":{"blesses","bless","blessing","blessed"},
"blind":{"blindness","blinded","blinding","blindly","blinds"},
"blinds":{"blind","blindness","blinded","blinding","blindly"},
"blindly":{"blind","blindness","blinded","blinding","blinds"},
"blinding":{"blind","blindness","blinded","blindly","blinds"},
"blinded":{"blind","blindness","blinding","blindly","blinds"},
"blindness":{"blind","blinded","blinding","blindly","blinds"},
"block":{"blocks","blocking","blocked"},
"blocks":{"block","blocking","blocked"},
"blocking":{"block","blocks","blocked"},
"blocked":{"block","blocks","blocking"},
"boast":{"boastful","boasts","boasted","boasting"},
"boasts":{"boastful","boasted","boast","boasting"},
"boasting":{"boastful","boasts","boasted","boast"},
"boasted":{"boastful","boasts","boast","boasting"},
"boastful":{"boasts","boasted","boast","boasting"},
"boil":{"boiler","boiled","boilers","boiling","boils"},
"boils":{"boiler","boiled","boilers","boiling","boil"},
"boiling":{"boiler","boiled","boilers","boils","boil"},
"boilers":{"boiler","boiled","boiling","boils","boil"},
"boiler":{"boiled","boilers","boiling","boils","boil"},
"boiled":{"boiler","boilers","boiling","boils","boil"},
"bold":{"boldly","bolder","boldest","boldness"},
"boldness":{"boldly","bolder","bold","boldest"},
"boldly":{"bolder","bold","boldest","boldness"},
"boldest":{"boldly","bolder","bold","boldness"},
"bolder":{"boldly","bold","boldest","boldness"},
"bone":{"boning","bones","boned"},
"boning":{"bone","bones","boned"},
"bones":{"bone","boning","boned"},
"boned":{"bone","boning","bones"},
"border":{"bordering","bordered","borders"},
"borders":{"bordering","border","bordered"},
"bordering":{"border","bordered","borders"},
"bordered":{"bordering","border","borders"},
"borrow":{"borrowing","borrowed","borrows"},
"borrows":{"borrow","borrowing","borrowed"},
"borrowing":{"borrow","borrowed","borrows"},
"borrowed":{"borrow","borrowing","borrows"},
"bottle":{"bottles","bottling","bottled"},
"bottling":{"bottles","bottle","bottled"},
"bottles":{"bottle","bottling","bottled"},
"bottled":{"bottles","bottle","bottling"},
"bottom":{"bottoms"},
"bottoms":{"bottom"},
"bound":{"bounding","bounds","bounded"},
"bounds":{"bounding","bound","bounded"},
"bounding":{"bound","bounds","bounded"},
"bounded":{"bounding","bound","bounds"},
"boundary":{"boundaries"},
"boundaries":{"boundary"},
"bow":{"bowed","bowing","bows"},
"bows":{"bowed","bowing","bow"},
"bowing":{"bowed","bows","bow"},
"bowed":{"bowing","bows","bow"},
"bowl":{"bowls","bowling","bowled"},
"bowls":{"bowl","bowling","bowled"},
"bowling":{"bowl","bowls","bowled"},
"bowled":{"bowl","bowls","bowling"},
"brain":{"brains"},
"brains":{"brain"},
"brave":{"braving","bravery","braved","bravely","braves"},
"braving":{"bravery","braved","bravely","braves","brave"},
"braves":{"braving","bravery","braved","bravely","brave"},
"bravely":{"braving","bravery","braved","braves","brave"},
"braved":{"braving","bravery","bravely","braves","brave"},
"bravery":{"braving","braved","bravely","braves","brave"},
"breakfast":{"breakfasts","breakfasting","breakfasted"},
"breakfasts":{"breakfast","breakfasting","breakfasted"},
"breakfasting":{"breakfast","breakfasts","breakfasted"},
"breakfasted":{"breakfast","breakfasts","breakfasting"},
"breath":{"breaths"},
"breaths":{"breath"},
"breathlessly":{"breathless"},
"breathless":{"breathlessly"},
"breathe":{"breathing","breathes","breathed"},
"breathing":{"breathe","breathes","breathed"},
"breathes":{"breathe","breathing","breathed"},
"breathed":{"breathe","breathing","breathes"},
"bribe":{"bribery","bribed","bribes","bribing"},
"bribing":{"bribery","bribed","bribes","bribe"},
"bribes":{"bribery","bribed","bribing","bribe"},
"bribed":{"bribery","bribes","bribing","bribe"},
"bribery":{"bribed","bribes","bribing","bribe"},
"brick":{"bricks"},
"bricks":{"brick"},
"broadcast":{"broadcasts","broadcasting","broadcasted"},
"broadcasting":{"broadcasts","broadcasted","broadcast"},
"broadcasts":{"broadcasting","broadcasted","broadcast"},
"brown":{"browns","browning","browned"},
"browns":{"brown","browning","browned"},
"browning":{"brown","browns","browned"},
"browned":{"brown","browns","browning"},
"brush":{"brushed","brushing","brushes"},
"brushing":{"brushed","brush","brushes"},
"brushes":{"brushed","brush","brushing"},
"brushed":{"brush","brushing","brushes"},
"bucket":{"buckets"},
"buckets":{"bucket"},
"bunch":{"bunches"},
"bunches":{"bunch"},
"bundle":{"bundled","bundling","bundles"},
"bundling":{"bundled","bundles","bundle"},
"bundles":{"bundled","bundling","bundle"},
"bundled":{"bundling","bundles","bundle"},
"burst":{"bursts","bursting"},
"bursts":{"burst","bursting"},
"bursting":{"bursts","burst"},
"bury":{"burying","buries","buried"},
"burying":{"bury","buries","buried"},
"buries":{"bury","burying","buried"},
"buried":{"bury","burying","buries"},
"burial":{"burials"},
"burials":{"burial"},
"bus":{"bussed","buses","bussing"},
"buses":{"bussed","bus","bussing"},
"bussed":{"buses","bus","bussing"},
"bush":{"bushes","bushy"},
"bushes":{"bush","bushy"},
"bushy":{"bush","bushes"},
"busy":{"busiest","busier","busily"},
"busily":{"busy","busiest","busier"},
"busiest":{"busy","busier","busily"},
"busier":{"busy","busiest","busily"},
"butter":{"buttered","butters","buttering"},
"butters":{"buttered","butter","buttering"},
"buttering":{"buttered","butters","butter"},
"buttered":{"butters","butter","buttering"},
"button":{"buttoning","buttons","buttoned"},
"buttons":{"buttoning","button","buttoned"},
"buttoning":{"buttons","button","buttoned"},
"buttoned":{"buttoning","buttons","button"},
"cage":{"caging","cages","caged"},
"caging":{"cage","cages","caged"},
"cages":{"cage","caging","caged"},
"caged":{"cage","caging","cages"},
"cake":{"cakes"},
"cakes":{"cake"},
"calculate":{"calculator","calculated","calculations","calculation","calculates","calculating"},
"calculator":{"calculated","calculations","calculation","calculate","calculates","calculating"},
"calculating":{"calculator","calculated","calculations","calculation","calculate","calculates"},
"calculates":{"calculator","calculated","calculations","calculation","calculate","calculating"},
"calculated":{"calculator","calculations","calculation","calculate","calculates","calculating"},
"calculation":{"calculator","calculated","calculations","calculate","calculates","calculating"},
"calculations":{"calculator","calculated","calculation","calculate","calculates","calculating"},
"calm":{"calmed","calmly","calms","calming","calmness"},
"calms":{"calmed","calmly","calming","calmness","calm"},
"calmly":{"calmed","calms","calming","calmness","calm"},
"calming":{"calmed","calmly","calms","calmness","calm"},
"calmed":{"calmly","calms","calming","calmness","calm"},
"calmness":{"calmed","calmly","calms","calming","calm"},
"camera":{"cameras"},
"cameras":{"camera"},
"camp":{"camped","camping","camps"},
"camped":{"camp","camping","camps"},
"camping":{"camp","camped","camps"},
"camps":{"camp","camped","camping"},
"canal":{"canals"},
"canals":{"canal"},
"cap":{"capped","cappings","caps","capping"},
"caps":{"capped","cappings","cap","capping"},
"capping":{"capped","cappings","caps","cap"},
"capped":{"cappings","caps","cap","capping"},
"cape":{"capes","caped"},
"capes":{"caped","cape"},
"caped":{"capes","cape"},
"card":{"cards"},
"cards":{"card"},
"carriage":{"carriages"},
"carriages":{"carriage"},
"cart":{"carts","carting","carted"},
"carts":{"carting","carted","cart"},
"carting":{"carts","carted","cart"},
"carted":{"carts","carting","cart"},
"cat":{"cats"},
"cats":{"cat"},
"caution":{"cautioned","cautioning","cautious","cautiously","cautions"},
"cautions":{"cautioned","cautioning","cautious","cautiously","caution"},
"cautioning":{"cautioned","cautious","cautiously","cautions","caution"},
"cautioned":{"cautioning","cautious","cautiously","cautions","caution"},
"cautious":{"cautioned","cautioning","cautiously","cautions","caution"},
"cautiously":{"cautioned","cautioning","cautious","cautions","caution"},
"cave":{"caved","caves","caving"},
"caving":{"caved","caves","cave"},
"caves":{"caved","caving","cave"},
"caved":{"caves","caving","cave"},
"cent":{"cents"},
"cents":{"cent"},
"centimetre":{"centimetres"},
"centimetres":{"centimetre"},
"century":{"centuries"},
"centuries":{"century"},
"ceremony":{"ceremonial","ceremonies"},
"ceremonies":{"ceremonial","ceremony"},
"ceremonial":{"ceremony","ceremonies"},
"chain":{"chained","chaining","chains"},
"chains":{"chained","chaining","chain"},
"chaining":{"chained","chains","chain"},
"chained":{"chaining","chains","chain"},
"chair":{"chairs","chairman"},
"chairs":{"chair","chairman"},
"chairman":{"chair","chairs"},
"chalk":{"chalks"},
"chalks":{"chalk"},
"charm":{"charms","charmed","charming"},
"charms":{"charmed","charming","charm"},
"charming":{"charms","charmed","charm"},
"charmed":{"charms","charming","charm"},
"cheap":{"cheaper","cheapest","cheapness","cheaply"},
"cheapness":{"cheaper","cheapest","cheap","cheaply"},
"cheaply":{"cheaper","cheapest","cheapness","cheap"},
"cheapest":{"cheaper","cheapness","cheap","cheaply"},
"cheaper":{"cheapest","cheapness","cheap","cheaply"},
"cheat":{"cheated","cheats","cheating"},
"cheats":{"cheat","cheated","cheating"},
"cheating":{"cheat","cheated","cheats"},
"cheated":{"cheat","cheats","cheating"},
"check":{"checked","checking","checks"},
"checks":{"checked","checking","check"},
"checking":{"checked","check","checks"},
"checked":{"checking","check","checks"},
"cheer":{"cheered","cheerful","cheering","cheery","cheers"},
"cheery":{"cheered","cheerful","cheering","cheer","cheers"},
"cheers":{"cheered","cheerful","cheering","cheery","cheer"},
"cheering":{"cheered","cheerful","cheery","cheer","cheers"},
"cheerful":{"cheered","cheering","cheery","cheer","cheers"},
"cheered":{"cheerful","cheering","cheery","cheer","cheers"},
"cheese":{"cheeses"},
"cheeses":{"cheese"},
"cheque":{"cheques"},
"cheques":{"cheque"},
"chest":{"chests"},
"chests":{"chest"},
"chicken":{"chickens"},
"chickens":{"chicken"},
"chimney":{"chimneys",""},
"chimneys":{"chimney"},
"christmas":{"christmases"},
"christmases":{"christmas"},
"civilise":{"civilizes","civilized","civilize","civilises","civilised","civilisation","civilising","civilisations","civilizing"},
"civilizing":{"civilise","civilizes","civilized","civilize","civilises","civilised","civilisation","civilising","civilisations"},
"civilizes":{"civilise","civilized","civilize","civilises","civilised","civilisation","civilising","civilisations","civilizing"},
"civilized":{"civilise","civilizes","civilize","civilises","civilised","civilisation","civilising","civilisations","civilizing"},
"civilize":{"civilise","civilizes","civilized","civilises","civilised","civilisation","civilising","civilisations","civilizing"},
"civilising":{"civilise","civilizes","civilized","civilize","civilises","civilised","civilisation","civilisations","civilizing"},
"civilises":{"civilise","civilizes","civilized","civilize","civilised","civilisation","civilising","civilisations","civilizing"},
"civilised":{"civilise","civilizes","civilized","civilize","civilises","civilisation","civilising","civilisations","civilizing"},
"civilisation":{"civilise","civilizes","civilized","civilize","civilises","civilised","civilising","civilisations","civilizing"},
"civilisations":{"civilise","civilizes","civilized","civilize","civilises","civilised","civilisation","civilising","civilizing"},
"clay":{"clays"},
"clays":{"clay"},
"clean":{"cleaned","cleanness","cleans","cleanly","cleaning","cleanest","cleaners","cleaner"},
"cleaned":{"clean","cleanness","cleans","cleanly","cleaning","cleanest","cleaners","cleaner"},
"cleaner":{"cleaned","clean","cleanness","cleans","cleanly","cleaning","cleanest","cleaners"},
"cleaners":{"cleaned","clean","cleanness","cleans","cleanly","cleaning","cleanest","cleaner"},
"cleanest":{"cleaned","clean","cleanness","cleans","cleanly","cleaning","cleaners","cleaner"},
"cleaning":{"cleaned","clean","cleanness","cleans","cleanly","cleanest","cleaners","cleaner"},
"cleanly":{"cleaned","clean","cleanness","cleans","cleaning","cleanest","cleaners","cleaner"},
"cleans":{"cleaned","clean","cleanness","cleanly","cleaning","cleanest","cleaners","cleaner"},
"cleanness":{"cleaned","clean","cleans","cleanly","cleaning","cleanest","cleaners","cleaner"},
"clerk":{"clerks"},
"clerks":{"clerk"},
"clever":{"cleverer","cleverly","cleverness","cleverest"},
"cleverness":{"cleverer","cleverly","cleverest","clever"},
"cleverly":{"cleverer","cleverness","cleverest","clever"},
"cleverest":{"cleverer","cleverly","cleverness","clever"},
"cleverer":{"cleverly","cleverness","cleverest","clever"},
"cliff":{"cliffs"},
"cliffs":{"cliff"},
"climb":{"climbers","climbs","climbing","climbed","climber"},
"climbs":{"climb","climbers","climbing","climbed","climber"},
"climbing":{"climb","climbers","climbs","climbed","climber"},
"climbers":{"climb","climbs","climbing","climbed","climber"},
"climber":{"climb","climbers","climbs","climbing","climbed"},
"climbed":{"climb","climbers","climbs","climbing","climber"},
"clock":{"clocks"},
"clocks":{"clock"},
"cloth":{"cloths","clothes","clothing"},
"cloths":{"clothes","clothing","cloth"},
"clothing":{"cloths","clothes","cloth"},
"clothes":{"cloths","clothing","cloth"},
"club":{"clubs","clubbing","clubbed"},
"clubbed":{"clubs","clubbing","club"},
"clubbing":{"clubs","club","clubbed"},
"clubs":{"clubbing","club","clubbed"},
"coarse":{"coarsely","coarseness","coarser","coarsest"},
"coarsest":{"coarse","coarsely","coarseness","coarser"},
"coarser":{"coarse","coarsely","coarseness","coarsest"},
"coarseness":{"coarse","coarsely","coarser","coarsest"},
"coarsely":{"coarse","coarseness","coarser","coarsest"},
"coat":{"coats"},
"coats":{"coat"},
"coffee":{"coffees"},
"coffees":{"coffee"},
"collar":{"collars"},
"collars":{"collar"},
"collect":{"collected","collections","collecting","collects","collectively","collector","collectors","collection","collective"},
"collects":{"collected","collections","collecting","collect","collectively","collector","collectors","collection","collective"},
"collecting":{"collected","collections","collects","collect","collectively","collector","collectors","collection","collective"},
"collected":{"collections","collecting","collects","collect","collectively","collector","collectors","collection","collective"},
"collective":{"collected","collections","collecting","collects","collect","collectively","collector","collectors","collection"},
"collectively":{"collected","collections","collecting","collects","collect","collector","collectors","collection","collective"},
"collector":{"collected","collections","collecting","collects","collect","collectively","collectors","collection","collective"},
"collectors":{"collected","collections","collecting","collects","collect","collectively","collector","collection","collective"},
"collection":{"collected","collections","collecting","collects","collect","collectively","collector","collectors","collective"},
"collections":{"collected","collecting","collects","collect","collectively","collector","collectors","collection","collective"},
"comb":{"combs","combing","combed"},
"combs":{"comb","combing","combed"},
"combing":{"comb","combs","combed"},
"combed":{"comb","combs","combing"},
"combine":{"combining","combinations","combines","combined","combination"},
"combining":{"combine","combinations","combines","combined","combination"},
"combines":{"combine","combining","combinations","combined","combination"},
"combined":{"combine","combining","combinations","combines","combination"},
"combination":{"combine","combining","combinations","combines","combined"},
"combinations":{"combine","combining","combines","combined","combination"},
"comfort":{"comfortably","comforting","comforts","comfortable","comforted"},
"uncomfortable":{"discomfort"},
"discomfort":{"uncomfortable"},
"comforts":{"comfortably","comforting","comfort","comfortable","comforted"},
"comforting":{"comfortably","comforts","comfort","comfortable","comforted"},
"comforted":{"comfortably","comforting","comforts","comfort","comfortable"},
"comfortably":{"comforting","comforts","comfort","comfortable","comforted"},
"comfortable":{"comfortably","comforting","comforts","comfort","comforted"},
"commerce":{"commercial","commercially"},
"commercial":{"commerce","commercially"},
"commercially":{"commerce","commercial"},
"companion":{"companionship","companions"},
"companions":{"companionship","companion"},
"companionship":{"companions","companion"},
"compare":{"comparisons","comparison","compares","comparative","comparing","comparatively","compared","comparable"},
"comparable":{"comparisons","comparison","compares","comparative","comparing","comparatively","compare","compared"},
"compared":{"comparisons","comparison","compares","comparative","comparing","comparatively","compare","comparable"},
"compares":{"comparisons","comparison","comparative","comparing","comparatively","compare","compared","comparable"},
"comparative":{"comparisons","comparison","compares","comparing","comparatively","compare","compared","comparable"},
"comparison":{"comparisons","compares","comparative","comparing","comparatively","compare","compared","comparable"},
"comparisons":{"comparison","compares","comparative","comparing","comparatively","compare","compared","comparable"},
"comparing":{"comparisons","comparison","compares","comparative","comparatively","compare","compared","comparable"},
"comparatively":{"comparisons","comparison","compares","comparative","comparing","compare","compared","comparable"},
"compete":{"competes","competed","competing","competition"},
"competing":{"compete","competes","competed"},
"competes":{"compete","competed","competing"},
"competed":{"compete","competes","competing"},
"competition":{"competitions","compete"},
"competitions":{"competition"},
"complain":{"complaints","complained","complaining","complains","complaint"},
"complaints":{"complain","complained","complaining","complains","complaint"},
"complaint":{"complain","complaints","complained","complaining","complains"},
"complains":{"complain","complaints","complained","complaining","complaint"},
"complaining":{"complain","complaints","complained","complains","complaint"},
"complained":{"complain","complaints","complaining","complains","complaint"},
"complicate":{"complication","complicates","complicating","complications","complicated"},
"complicated":{"complication","complicates","complicating","complications","complicate"},
"complicates":{"complication","complicating","complications","complicated","complicate"},
"complicating":{"complication","complicates","complications","complicated","complicate"},
"complication":{"complicates","complicating","complications","complicated","complicate"},
"complications":{"complication","complicates","complicating","complicated","complicate"},
"compose":{"composition","composed","composite","composing","composes","composer"},
"composing":{"composition","composed","composite","compose","composes","composer"},
"composes":{"composition","composed","composite","compose","composing","composer"},
"composer":{"composition","composed","composite","compose","composing","composes"},
"composed":{"composition","composite","compose","composing","composes","composer"},
"composite":{"composition","composed","compose","composing","composes","composer"},
"composition":{"composed","composite","compose","composing","composes","composer"},
"confess":{"confessed","confessions","confession","confessing","confesses"},
"confessing":{"confessed","confess","confessions","confession","confesses"},
"confesses":{"confessed","confess","confessions","confession","confessing"},
"confessed":{"confess","confessions","confession","confessing","confesses"},
"confession":{"confessed","confess","confessions","confessing","confesses"},
"confessions":{"confessed","confess","confession","confessing","confesses"},
"confidence":{"confident","confidences","confidently"},
"confidences":{"confident","confidence","confidently"},
"confident":{"confidences","confidence","confidently"},
"confidently":{"confident","confidences","confidence"},
"confuse":{"confusion","confused","confuses","confusing"},
"confusing":{"confusion","confused","confuses","confuse"},
"confuses":{"confusion","confused","confusing","confuse"},
"confused":{"confusion","confuses","confusing","confuse"},
"confusion":{"confused","confuses","confusing","confuse"},
"congratulate":{"congratulating","congratulates","congratulated","congratulations"},
"congratulating":{"congratulate","congratulates","congratulated","congratulations"},
"congratulates":{"congratulate","congratulating","congratulated","congratulations"},
"congratulated":{"congratulate","congratulating","congratulates","congratulations"},
"congratulations":{"congratulate","congratulating","congratulates","congratulated"},
"connect":{"connects","connecting","connected","connection","connections"},
"connected":{"connects","connecting","connect","connection","connections"},
"connecting":{"connects","connected","connect","connection","connections"},
"connects":{"connecting","connected","connect","connection","connections"},
"connection":{"connects","connecting","connected","connect","connections"},
"connections":{"connects","connecting","connected","connect","connection"},
"conquer":{"conquers","conquerors","conqueror","conquering","conquered","conquest","conquests"},
"conquers":{"conquer","conquerors","conqueror","conquering","conquered","conquest","conquests"},
"conquerors":{"conquer","conquers","conqueror","conquering","conquered","conquest","conquests"},
"conqueror":{"conquer","conquers","conquerors","conquering","conquered","conquest","conquests"},
"conquering":{"conquer","conquers","conquerors","conqueror","conquered","conquest","conquests"},
"conquered":{"conquer","conquers","conquerors","conqueror","conquering","conquest","conquests"},
"conquest":{"conquer","conquers","conquerors","conqueror","conquering","conquered","conquests"},
"conquests":{"conquer","conquers","conquerors","conqueror","conquering","conquered","conquest"},
"conscience":{"consciences"},
"consciences":{"conscience"},
"conscious":{"consciously","consciousness"},
"consciousness":{"consciously","conscious"},
"unconscious":{"unconsciously"},
"unconsciously":{"unconscious"},
"consciously":{"consciousness","conscious"},
"convenience":{"conveniently","convenient","conveniences"},
"conveniences":{"conveniently","convenience","convenient"},
"convenient":{"conveniently","convenience","conveniences"},
"conveniently":{"convenience","convenient","conveniences"},
"conversation":{"conversations"},
"conversations":{"conversation"},
"cook":{"cooks","cookers","cooker","cooked","cooking"},
"cooks":{"cookers","cooker","cooked","cooking","cook"},
"cooking":{"cooks","cookers","cooker","cooked","cook"},
"cookers":{"cooks","cooker","cooked","cooking","cook"},
"cooker":{"cooks","cookers","cooked","cooking","cook"},
"cooked":{"cooks","cookers","cooker","cooking","cook"},
"cool":{"cools","coolest","cooled","coolly","coolness","cooler","cooling"},
"cools":{"coolest","cooled","coolly","coolness","cooler","cooling","cool"},
"coolness":{"cools","coolest","cooled","coolly","cooler","cooling","cool"},
"coolly":{"cools","coolest","cooled","coolness","cooler","cooling","cool"},
"cooling":{"cools","coolest","cooled","coolly","coolness","cooler","cool"},
"coolest":{"cools","cooled","coolly","coolness","cooler","cooling","cool"},
"cooler":{"cools","coolest","cooled","coolly","coolness","cooling","cool"},
"cooled":{"cools","coolest","coolly","coolness","cooler","cooling","cool"},
"copy":{"copying","copies","copied"},
"copying":{"copy","copies","copied"},
"copies":{"copying","copy","copied"},
"copied":{"copying","copy","copies"},
"cork":{"corking","corked","corks"},
"corks":{"cork","corking","corked"},
"corking":{"cork","corked","corks"},
"corked":{"cork","corking","corks"},
"corner":{"cornering","cornered","corners"},
"corners":{"cornering","cornered","corner"},
"cornered":{"cornering","corners","corner"},
"cornering":{"cornered","corners","corner"},
"correct":{"corrected","corrections","correction","correctness","correcting","correctly","corrects"},
"corrects":{"corrected","corrections","correction","correctness","correcting","correctly","correct"},
"correctly":{"corrected","corrections","correction","correctness","correcting","corrects","correct"},
"correcting":{"corrected","corrections","correction","correctness","correctly","corrects","correct"},
"corrected":{"corrections","correction","correctness","correcting","correctly","corrects","correct"},
"correctness":{"corrected","corrections","correction","correcting","correctly","corrects","correct"},
"correction":{"corrected","corrections","correctness","correcting","correctly","corrects","correct"},
"corrections":{"corrected","correction","correctness","correcting","correctly","corrects","correct"},
"incorrect":{"incorrectly"},
"incorrectly":{"incorrect"},
"cottage":{"cottages"},
"cottages":{"cottage"},
"cough":{"coughs","coughing","coughed"},
"coughs":{"cough","coughing","coughed"},
"coughing":{"cough","coughs","coughed"},
"coughed":{"cough","coughs","coughing"},
"courage":{"courageous"},
"courageous":{"courage"},
"cousin":{"cousins"},
"cousins":{"cousin"},
"cow":{"cows"},
"cows":{"cow"},
"coward":{"cowardly","cowards","cowardice"},
"cowards":{"cowardly","coward","cowardice"},
"cowardly":{"cowards","coward","cowardice"},
"cowardice":{"cowardly","cowards","coward"},
"crack":{"cracking","cracked","cracks"},
"cracks":{"cracking","cracked","crack"},
"cracking":{"cracked","crack","cracks"},
"cracked":{"cracking","crack","cracks"},
"crash":{"crashes","crashing","crashed"},
"crashing":{"crashes","crash","crashed"},
"crashes":{"crashing","crash","crashed"},
"crashed":{"crashes","crashing","crash"},
"cream":{"creams","creaming","creamed"},
"creams":{"cream","creaming","creamed"},
"creaming":{"cream","creams","creamed"},
"creamed":{"cream","creams","creaming"},
"creature":{"creatures"},
"creatures":{"creature"},
"creep":{"creeping","crept","creeps"},
"crept":{"creeping","creep","creeps"},
"creeps":{"creeping","creep","crept"},
"creeping":{"creep","crept","creeps"},
"crime":{"crimes"},
"crimes":{"crime"},
"criminal":{"criminally"},
"criminally":{"criminal"},
"critic":{"critical","critically","critics"},
"critics":{"critic","critical","critically"},
"critically":{"critic","critical","critics"},
"critical":{"critic","critically","critics"},
"crop":{"cropping","crops","cropped"},
"crops":{"crop","cropping","cropped"},
"cropping":{"crop","crops","cropped"},
"cropped":{"crop","cropping","crops"},
"cruel":{"cruelties","cruelty","crueller","cruellest","cruelness","cruelly"},
"cruelly":{"cruel","cruelties","cruelty","crueller","cruellest","cruelness"},
"cruelness":{"cruel","cruelties","cruelty","crueller","cruellest","cruelly"},
"cruelty":{"cruel","cruelties","crueller","cruellest","cruelness","cruelly"},
"cruelties":{"cruel","cruelty","crueller","cruellest","cruelness","cruelly"},
"crush":{"crushing","crushes","crushed"},
"crushing":{"crush","crushes","crushed"},
"crushes":{"crush","crushing","crushed"},
"crushed":{"crush","crushing","crushes"},
"cultivate":{"cultivates","cultivating","cultivated","cultivation"},
"cultivating":{"cultivates","cultivated","cultivation","cultivate"},
"cultivates":{"cultivating","cultivated","cultivation","cultivate"},
"cultivated":{"cultivates","cultivating","cultivation","cultivate"},
"cultivation":{"cultivates","cultivating","cultivated","cultivate"},
"cup":{"cups"},
"cups":{"cup"},
"cupboards":{"cupboard"},
"cupboard":{"cupboards"},
"cure":{"cured","cures","curing","curable"},
"curing":{"cured","cure","cures","curable"},
"cures":{"cured","cure","curing","curable"},
"cured":{"cure","cures","curing","curable"},
"curable":{"cured","cure","cures","curing",""},
"curious":{"curiously","curiosity"},
"curiously":{"curious","curiosity"},
"curiosity":{"curious","curiously"},
"curl":{"curled","curls","curling","curly"},
"curls":{"curled","curling","curl","curly"},
"curling":{"curled","curls","curl","curly"},
"curled":{"curls","curling","curl","curly"},
"curly":{"curled","curls","curling","curl"},
"curse":{"cursed","curses","cursing"},
"cursing":{"cursed","curses","curse"},
"curses":{"cursed","curse","cursing"},
"cursed":{"curses","curse","cursing"},
"curtain":{"curtains"},
"curtains":{"curtain"},
"curve":{"curved","curving","curves"},
"curving":{"curve","curved","curves"},
"curves":{"curve","curved","curving"},
"curved":{"curve","curving","curves"},
"cushion":{"cushions","cushioned","cushioning"},
"cushions":{"cushioned","cushion","cushioning"},
"cushioned":{"cushions","cushion","cushioning"},
"cushioning":{"cushions","cushioned","cushion"},
"custom":{"customs","customary"},
"customs":{"custom","customary"},
"customary":{"custom","customs"},
"customer":{"customers"},
"customers":{"customer"},
"damage":{"damaged","damaging","damages"},
"damaging":{"damaged","damage","damages"},
"damages":{"damaged","damage","damaging"},
"damaged":{"damage","damaging","undamaged","damages"},
"damp":{"dampest","dampness","damper"},
"dampness":{"dampest","damp","damper"},
"dampest":{"damp","dampness","damper"},
"damper":{"dampest","damp","dampness"},
"dance":{"danced","dancing","dances","dancers","dancer"},
"danced":{"dance","dancing","dances","dancers","dancer"},
"dancer":{"danced","dance","dancing","dances","dancers"},
"dancers":{"danced","dance","dancing","dances","dancer"},
"dances":{"danced","dance","dancing","dancers","dancer"},
"dancing":{"danced","dance","dances","dancers","dancer"},
"dare":{"dared","daring","dares"},
"dared":{"daring","dares","dare"},
"dares":{"dared","daring","dare"},
"daring":{"dared","dares","dare"},
"deaf":{"deafest","deafer","deafness"},
"deafness":{"deafest","deafer","deaf"},
"deafest":{"deafer","deaf","deafness"},
"deafer":{"deafest","deaf","deafness"},
"debt":{"debts"},
"debts":{"debt"},
"decay":{"decays","decayed","decaying"},
"decays":{"decay","decayed","decaying"},
"decaying":{"decays","decay","decayed"},
"decayed":{"decays","decay","decaying"},
"deceive":{"deceives","deceiving","deceived","deception"},
"deceiving":{"deceives","deceived","deceive","deception"},
"deceives":{"deceiving","deceived","deceive","deception"},
"deceived":{"deceives","deceiving","deceive","deception"},
"deception":{"deceives","deceiving","deceived","deceive"},
"decrease":{"decreasing","decreases","decreased"},
"decreasing":{"decrease","decreases","decreased"},
"decreases":{"decrease","decreasing","decreased"},
"decreased":{"decrease","decreasing","decreases"},
"deed":{"deeds"},
"deeds":{"deed"},
"defend":{"defence","defends","defending","defenders","defender","defended"},
"defence":{"defends","defending","defenders","defend","defender","defended"},
"defends":{"defence","defending","defenders","defend","defender","defended"},
"defending":{"defence","defends","defenders","defend","defender","defended"},
"defenders":{"defence","defends","defending","defend","defender","defended"},
"defender":{"defence","defends","defending","defenders","defend","defended"},
"defended":{"defence","defends","defending","defenders","defend","defender"},
"delay":{"delayed","delays","delaying"},
"delays":{"delayed","delay","delaying"},
"delaying":{"delayed","delay","delays"},
"delayed":{"delay","delays","delaying"},
"delicate":{"delicacy","delicacies","delicately"},
"delicately":{"delicacy","delicacies","delicate"},
"delicacy":{"delicacies","delicate","delicately"},
"delicacies":{"delicacy","delicate","delicately"},
"delight":{"delights","delighting","delightfully","delightful","delighted"},
"delights":{"delight","delighting","delightfully","delightful","delighted"},
"delighting":{"delight","delights","delightfully","delightful","delighted"},
"delightfully":{"delight","delights","delighting","delightful","delighted"},
"delightful":{"delight","delights","delighting","delightfully","delighted"},
"delighted":{"delight","delights","delighting","delightfully","delightful"},
"deliver":{"delivered","deliveries","delivering","delivers","delivery"},
"delivered":{"deliver","deliveries","delivering","delivers","delivery"},
"deliveries":{"deliver","delivered","delivering","delivers","delivery"},
"delivering":{"deliver","delivered","deliveries","delivers","delivery"},
"delivers":{"deliver","delivered","deliveries","delivering","delivery"},
"delivery":{"deliver","delivered","deliveries","delivering","delivers"},
"descend":{"descended","descending","descends"},
"descends":{"descended","descending","descend"},
"descending":{"descended","descends","descend"},
"descended":{"descending","descends","descend"},
"deserve":{"deservedly","deserving","deserves","deserved"},
"deserving":{"deservedly","deserve","deserves","deserved"},
"deserves":{"deservedly","deserving","deserve","deserved"},
"deservedly":{"deserving","deserve","deserves","deserved"},
"deserved":{"deservedly","deserving","deserve","deserves"},
"desk":{"desks"},
"desks":{"desk"},
"despair":{"despairingly","despairing","despairs","despaired"},
"despairs":{"despairingly","despairing","despair","despaired"},
"despairingly":{"despairing","despairs","despair","despaired"},
"despairing":{"despairingly","despairs","despair","despaired"},
"despaired":{"despairingly","despairing","despairs","despair"},
"devil":{"devils"},
"devils":{"devil"},
"diamond":{"diamonds"},
"diamonds":{"diamond"},
"dictionary":{"dictionaries"},
"dictionaries":{"dictionary"},
"dig":{"dug","digs","digging"},
"dug":{"digs","digging","dig"},
"digs":{"dug","digging","dig"},
"digging":{"dug","digs","dig"},
"dinner":{"dine","dined","dines","dining","dinners"},
"dinners":{"dine","dined","dines","dining","dinner"},
"dining":{"dine","dined","dines","dinners","dinner"},
"dines":{"dine","dined","dining","dinners","dinner"},
"dined":{"dine","dines","dining","dinners","dinner"},
"dine":{"dined","dines","dining","dinners","dinner"},
"dip":{"dipping","dipped","dips"},
"dips":{"dipping","dipped","dip"},
"dipping":{"dipped","dips","dip"},
"dipped":{"dipping","dips","dip"},
"dirt":{"dirty"},
"dirty":{"dirt"},
"disappoint":{"disappointing","disappoints","disappointed","disappointment","disappointments"},
"disappoints":{"disappointing","disappoint","disappointed","disappointment","disappointments"},
"disappointing":{"disappoints","disappoint","disappointed","disappointment","disappointments"},
"disappointed":{"disappointing","disappoints","disappoint","disappointment","disappointments"},
"disappointment":{"disappointing","disappoints","disappoint","disappointed","disappointments"},
"disappointments":{"disappointing","disappoints","disappoint","disappointed","disappointment"},
"discipline":{"disciplines","disciplining","disciplined","disciplinary"},
"disciplining":{"disciplines","disciplined","disciplinary","discipline"},
"disciplines":{"disciplining","disciplined","disciplinary","discipline"},
"disciplined":{"disciplines","disciplining","disciplinary","discipline"},
"disciplinary":{"disciplines","disciplining","disciplined","discipline"},
"discuss":{"discussion","discussions","discussing","discussed","discusses"},
"discussing":{"discussion","discussions","discuss","discussed","discusses"},
"discusses":{"discussion","discussions","discuss","discussing","discussed"},
"discussed":{"discussion","discussions","discuss","discussing","discusses"},
"discussion":{"discussions","discuss","discussing","discussed","discusses"},
"discussions":{"discussion","discuss","discussing","discussed","discusses"},
"disease":{"diseased","diseases"},
"diseases":{"diseased","disease"},
"diseased":{"diseases","disease"},
"disgust":{"disgusts","disgusted","disgusting"},
"disgusts":{"disgust","disgusted","disgusting"},
"disgusting":{"disgusts","disgust","disgusted"},
"disgusted":{"disgusts","disgust","disgusting"},
"dish":{"dishes"},
"dishes":{"dish"},
"dismiss":{"dismissively","dismissed","dismisses","dismissing","dismissive"},
"dismissing":{"dismissively","dismissed","dismisses","dismiss","dismissive"},
"dismisses":{"dismissively","dismissed","dismissing","dismiss","dismissive"},
"dismissed":{"dismissively","dismisses","dismissing","dismiss","dismissive"},
"dismissive":{"dismissively","dismissed","dismisses","dismissing","dismiss"},
"dismissively":{"dismissed","dismisses","dismissing","dismiss","dismissive"},
"disturb":{"disturbances","disturbed","disturbing","disturbs","disturbance"},
"disturbs":{"disturbances","disturbed","disturbing","disturb","disturbance"},
"disturbing":{"disturbances","disturbed","disturbs","disturb","disturbance"},
"disturbed":{"disturbances","disturbing","disturbs","disturb","disturbance"},
"disturbance":{"disturbances","disturbed","disturbing","disturbs","disturb"},
"disturbances":{"disturbed","disturbing","disturbs","disturb","disturbance"},
"ditch":{"ditched","ditches","ditching"},
"ditching":{"ditched","ditches","ditch"},
"ditches":{"ditched","ditching","ditch"},
"ditched":{"ditches","ditching","ditch"},
"dive":{"dove","diving","divers","diver","dives","dived"},
"diving":{"dove","divers","diver","dive","dives","dived"},
"dives":{"dove","diving","divers","diver","dive","dived"},
"dived":{"dove","diving","divers","diver","dive","dives"},
"dove":{"diving","divers","diver","dive","dives","dived"},
"diver":{"dove","diving","divers","dive","dives","dived"},
"divers":{"dove","diving","diver","dive","dives","dived"},
"donkey":{"donkeys"},
"donkeys":{"donkey"},
"dot":{"dots"},
"dots":{"dot"},
"double":{"doubling","doubles","doubled"},
"doubled":{"double","doubling","doubles"},
"doubles":{"double","doubling","doubled"},
"doubling":{"double","doubles","doubled"},
"dozen":{"dozens"},
"dozens":{"dozen"},
"drag":{"drags","dragging","dragged"},
"drags":{"drag","dragging","dragged"},
"dragging":{"drag","drags","dragged"},
"dragged":{"drag","drags","dragging"},
"drawer":{"drawers"},
"drawers":{"drawer"},
"drown":{"drowns","drowning","drowned"},
"drowns":{"drown","drowning","drowned"},
"drowning":{"drown","drowns","drowned"},
"drowned":{"drown","drowns","drowning"},
"drum":{"drummed","drumming","drums"},
"drums":{"drummed","drumming","drum"},
"drumming":{"drummed","drums","drum"},
"drummed":{"drumming","drums","drum"},
"duck":{"ducks","ducked","ducking"},
"ducks":{"ducked","ducking","duck"},
"ducking":{"ducks","ducked","duck"},
"ducked":{"ducks","ducking","duck"},
"dull":{"dullest","dullness","duller"},
"dullness":{"dullest","dull","duller"},
"dullest":{"dull","dullness","duller"},
"duller":{"dullest","dull","dullness"},
"dust":{"dusting","duster","dusted","dusters","dusts"},
"dusts":{"dusting","duster","dusted","dust","dusters"},
"dusting":{"duster","dusted","dust","dusters","dusts"},
"dusted":{"dusting","duster","dust","dusters","dusts"},
"duster":{"dusting","dusted","dust","dusters","dusts"},
"dusters":{"dusting","duster","dusted","dust","dusts"},
"eager":{"eagerness","eagerly"},
"eagerness":{"eagerly","eager"},
"eagerly":{"eagerness","eager"},
"earn":{"earnings","earned","earning","earns"},
"earns":{"earnings","earned","earning","earn"},
"earning":{"earnings","earned","earns","earn"},
"earned":{"earnings","earning","earns","earn"},
"earnings":{"earned","earning","earns","earn"},
"earnest":{"earnestly"},
"earnestly":{"earnest"},
"ease":{"easing","eases","eased"},
"easing":{"ease","eases","eased"},
"eases":{"easing","ease","eased"},
"eased":{"easing","ease","eases"},
"unease":{"uneasy"},
"uneasy":{"unease"},
"edge":{"edged","edges","edging"},
"edged":{"edges","edge","edging"},
"edges":{"edged","edge","edging"},
"edging":{"edged","edges","edge"},
"educate":{"educated","educating","educates","educator","educators","education","educational"},
"educating":{"educated","educate","educates","educator","educators","education","educational"},
"educates":{"educated","educate","educating","educator","educators","education","educational"},
"educated":{"educate","educating","educates","educator","educators","education","educational"},
"educator":{"educated","educate","educating","educates","educators","education","educational"},
"educators":{"educated","educate","educating","educates","educator","education","educational"},
"education":{"educated","educate","educating","educates","educator","educators","educational"},
"educational":{"educated","educate","educating","educates","educator","educators","education"},
"elastic":{"elasticity","elastics"},
"elastics":{"elasticity","elastic"},
"elasticity":{"elastics","elastic"},
"elder":{"elderly"},
"elderly":{"elder"},
"electric":{"electrician","electrical","electricians","electricity","electrically"},
"electricity":{"electrician","electric","electrical","electricians","electrically"},
"electricians":{"electrician","electric","electrical","electricity","electrically"},
"electrician":{"electric","electrical","electricians","electricity","electrically"},
"electrical":{"electrician","electric","electricians","electricity","electrically"},
"electrically":{"electrician","electric","electrical","electricians","electricity"},
"elephant":{"elephants"},
"elephants":{"elephant"},
"empty":{"emptied","empties","emptying"},
"emptying":{"emptied","empty","empties"},
"empties":{"emptied","empty","emptying"},
"emptied":{"empty","empties","emptying"},
"enclose":{"enclosure","enclosed","encloses","enclosing"},
"enclosing":{"enclosure","enclosed","encloses","enclose"},
"encloses":{"enclosure","enclosed","enclosing","enclose"},
"enclosed":{"enclosure","encloses","enclosing","enclose"},
"enclosure":{"enclosed","encloses","enclosing","enclose"},
"encourage":{"encouragingly","encouraging","encourages","encouragement","encouraged"},
"encouragingly":{"encourage","encouraging","encourages","encouragement","encouraged"},
"encouraging":{"encourage","encouragingly","encourages","encouragement","encouraged"},
"encourages":{"encourage","encouragingly","encouraging","encouragement","encouraged"},
"encouraged":{"encourage","encouragingly","encouraging","encourages","encouragement"},
"encouragement":{"encourage","encouragingly","encouraging","encourages","encouraged"},
"engine":{"engines"},
"engines":{"engine"},
"engineer":{"engineering","engineers"},
"engineering":{"engineer","engineers"},
"engineers":{"engineer","engineering"},
"entertain":{"entertainment","entertaining","entertained","entertains"},
"entertains":{"entertain","entertainment","entertaining","entertained"},
"entertaining":{"entertain","entertainment","entertained","entertains"},
"entertained":{"entertain","entertainment","entertaining","entertains"},
"entertainment":{"entertain","entertaining","entertained","entertains"},
"entire":{"entirely"},
"entirely":{"entire"},
"envelope":{"envelopes"},
"envelopes":{"envelope"},
"envy":{"envying","envies","envied","envious"},
"envying":{"envy","envies","envied","envious"},
"envies":{"envy","envying","envied","envious"},
"envied":{"envy","envying","envies","envious"},
"envious":{"envy","envying","envies","envied"},
"especial":{"especially"},
"especially":{"especial"},
"essence":{"essences"},
"essences":{"essence"},
"essential":{"essentially","essentials"},
"essentials":{"essentially","essential"},
"essentially":{"essentials","essential"},
"evil":{"eviler","evilest","evilly","evilness","evils"},
"eviler":{"evilest","evilly","evilness","evils","evil"},
"evilest":{"eviler","evilly","evilness","evils","evil"},
"evilly":{"eviler","evilest","evilness","evils","evil"},
"evilness":{"eviler","evilest","evilly","evils","evil"},
"evils":{"eviler","evilest","evilly","evilness","evil"},
"exact":{"exactly"},
"exactly":{"exact"},
"examining":{"examiners","examiner","examine","examined","examines","examinations","examination"},
"examines":{"examiners","examiner","examine","examined","examining","examinations","examination"},
"examined":{"examiners","examiner","examine","examines","examining","examinations","examination"},
"examine":{"examiners","examiner","examined","examines","examining","examinations","examination"},
"examiner":{"examiners","examine","examined","examines","examining","examinations","examination"},
"examiners":{"examiner","examine","examined","examines","examining","examinations","examination"},
"examination":{"examiners","examiner","examine","examined","examines","examining","examinations"},
"examinations":{"examiners","examiner","examine","examined","examines","examining","examination"},
"excellent":{"excellence"},
"excellence":{"excellent"},
"excess":{"excessive","excessively"},
"excessive":{"excess","excessively"},
"excessively":{"excess","excessive"},
"excite":{"exciting","excites","excitedly","excitement","excited"},
"exciting":{"excite","excites","excitedly","excitement","excited"},
"excites":{"exciting","excite","excitedly","excitement","excited"},
"excitedly":{"exciting","excite","excites","excitement","excited"},
"excited":{"exciting","excite","excites","excitedly","excitement"},
"excitement":{"exciting","excite","excites","excitedly","excited"},
"excuse":{"excusing","excuses","excused"},
"excusing":{"excuse","excuses","excused"},
"excuses":{"excuse","excusing","excused"},
"excused":{"excuse","excusing","excuses"},
"explode":{"exploded","exploding","explosions","explodes","explosion","explosive"},
"exploding":{"exploded","explosions","explode","explodes","explosion","explosive"},
"explodes":{"exploded","exploding","explosions","explode","explosion","explosive"},
"exploded":{"exploding","explosions","explode","explodes","explosion","explosive"},
"explosion":{"exploded","exploding","explosions","explode","explodes","explosive"},
"explosions":{"exploded","exploding","explode","explodes","explosion","explosive"},
"explosive":{"exploded","exploding","explosions","explode","explodes","explosion"},
"explore":{"exploration","exploratory","explored","explorers","explorations","exploring","explores","explorer"},
"exploring":{"exploration","exploratory","explored","explorers","explorations","explore","explores","explorer"},
"exploration":{"exploratory","explored","explorers","explorations","explore","exploring","explores","explorer"},
"explores":{"exploration","exploratory","explored","explorers","explorations","explore","exploring","explorer"},
"explored":{"exploration","exploratory","explorers","explorations","explore","exploring","explores","explorer"},
"exploratory":{"exploration","explored","explorers","explorations","explore","exploring","explores","explorer"},
"explorer":{"exploration","exploratory","explored","explorers","explorations","explore","exploring","explores"},
"explorers":{"exploration","exploratory","explored","explorers","explorations","explore","exploring","explorer"},
"explorations":{"exploration","exploratory","explored","explorers","explore","exploring","explores","explorer"},
"extra":{"extras"},
"extras":{"extra"},
"extraordinary":{"extraordinarily"},
"extraordinarily":{"extraordinary"},
"extreme":{"extremely"},
"extremely":{"extreme"},
"fade":{"faded","fades","fading"},
"fading":{"fade","faded","fades"},
"fades":{"fade","faded","fading"},
"faded":{"fade","fades","fading"},
"faint":{"faints","faintness","faintly","fainting","fainted","fainter"},
"faints":{"faintness","faint","faintly","fainting","fainted","fainter"},
"faintly":{"faints","faintness","faint","fainting","fainted","fainter"},
"fainting":{"faints","faintness","faint","faintly","fainted","fainter"},
"fainter":{"faints","faintness","faint","faintly","fainting","fainted"},
"fainted":{"faints","faintness","faint","faintly","fainting","fainter"},
"faintness":{"faints","faint","faintly","fainting","fainted","fainter"},
"false":{"falsely","falsehood"},
"falsely":{"false","falsehood"},
"falsehood":{"falsely","false"},
"fan":{"fanning","fans","fanned"},
"fans":{"fanning","fanned","fan"},
"fanning":{"fans","fanned","fan"},
"fanned":{"fanning","fans","fan"},
"fancy":{"fanciest","fanciness","fancily","fancied","fancying","fancies","fancier"},
"fancied":{"fanciest","fanciness","fancily","fancying","fancy","fancies","fancier"},
"fancier":{"fanciest","fanciness","fancily","fancied","fancying","fancy","fancies"},
"fancies":{"fanciest","fanciness","fancily","fancied","fancying","fancy","fancier"},
"fanciest":{"fanciness","fancily","fancied","fancying","fancy","fancies","fancier"},
"fancily":{"fanciest","fanciness","fancied","fancying","fancy","fancies","fancier"},
"fanciness":{"fanciest","fancily","fancied","fancying","fancy","fancies","fancier"},
"fancying":{"fanciest","fanciness","fancily","fancied","fancy","fancies","fancier"},
"fashion":{"fashioning","fashions","fashionable","fashioned"},
"fashionable":{"fashioning","fashions","fashion","fashioned"},
"fashioned":{"fashioning","fashions","fashion","fashionable"},
"fashioning":{"fashions","fashion","fashionable","fashioned"},
"fashions":{"fashioning","fashion","fashionable","fashioned"},
"fasten":{"fastens","fastening","fasteners","fastener","fastened"},
"fastened":{"fastens","fastening","fasteners","fastener","fasten"},
"fastener":{"fastens","fastening","fasteners","fastened","fasten"},
"fasteners":{"fastens","fastening","fastener","fastened","fasten"},
"fastening":{"fastens","fasteners","fastener","fastened","fasten"},
"fastens":{"fastening","fasteners","fastener","fastened","fasten"},
"fat":{"fats","fatten","fatty"},
"fats":{"fat","fatten","fatty"},
"fatten":{"fat","fats","fatty"},
"fatty":{"fat","fats","fatten"},
"fate":{"fates"},
"fates":{"fate"},
"fault":{"faulty","faults"},
"faulty":{"faults","fault"},
"faults":{"faulty","fault"},
"feast":{"feasting","feasts","feasted"},
"feasts":{"feasting","feast","feasted"},
"feasting":{"feast","feasts","feasted"},
"feasted":{"feasting","feast","feasts"},
"feather":{"feathered","feathers","feathering"},
"feathers":{"feathered","feather","feathering"},
"feathering":{"feathered","feather","feathers"},
"feathered":{"feather","feathers","feathering"},
"female":{"females"},
"females":{"female"},
"fence":{"fencing","fences","fenced"},
"fencing":{"fences","fenced","fence"},
"fences":{"fencing","fenced","fence"},
"fenced":{"fencing","fences","fence"},
"fever":{"feverish","fevers"},
"feverish":{"fever","fevers"},
"fevers":{"fever","feverish"},
"fierce":{"fierceness","fiercely","fiercer","fiercest"},
"fiercest":{"fierceness","fiercely","fiercer","fierce"},
"fiercer":{"fierceness","fiercely","fiercest","fierce"},
"fierceness":{"fiercely","fiercer","fiercest","fierce"},
"fiercely":{"fierceness","fiercer","fiercest","fierce"},
"film":{"films","filming","filmed"},
"films":{"film","filming","filmed"},
"filming":{"film","films","filmed"},
"filmed":{"film","films","filming"},
"finger":{"fingers"},
"fingers":{"finger"},
"firm":{"firmly","firms","firmest","firmness"},
"firms":{"firmly","firm","firmest","firmness"},
"firmness":{"firmly","firms","firm","firmest"},
"firmly":{"firms","firm","firmest","firmness"},
"firmest":{"firmly","firms","firm","firmness"},
"flag":{"flags"},
"flags":{"flag"},
"flame":{"flames","flaming"},
"flames":{"flame","flaming"},
"flaming":{"flame","flames"},
"flash":{"flashed","flashes","flashing"},
"flashing":{"flashed","flashes","flashing","flash"},
"flashes":{"flashed","flashing","flash"},
"flashed":{"flashes","flashing","flash"},
"flat":{"flattening","flatten","flats"},
"flats":{"flat","flattening","flatten"},
"flatten":{"flat","flattening","flats"},
"flattening":{"flat","flatten","flats"},
"flavour":{"flavoured","flavours","flavors","flavoring","flavored","flavour","flavouring"},
"flavours":{"flavor","flavoured","flavors","flavoring","flavored","flavour","flavouring"},
"flavouring":{"flavor","flavoured","flavours","flavors","flavored","flavour","flavouring"},
"flavoured":{"flavor","flavours","flavors","flavoring","flavored","flavour","flavouring"},
"flavor":{"flavoured","flavours","flavors","flavoring","flavored","flavour","flavouring"},
"flavors":{"flavor","flavoured","flavours","flavoring","flavored","flavour","flavouring"},
"flavoring":{"flavor","flavoured","flavours","flavors","flavored","flavour","flavouring"},
"flavored":{"flavor","flavoured","flavours","flavors","flavoring","flavour","flavouring"},
"float":{"floating","floated","floats"},
"floats":{"float","floating","floated"},
"floating":{"float","floated","floats"},
"floated":{"float","floating","floats"},
"flood":{"flooded","flooding","floods"},
"floods":{"flooded","flood","flooding"},
"flooding":{"flooded","flood","floods"},
"flooded":{"flood","flooding","floods"},
"fold":{"folded","folding","folds"},
"folds":{"folded","fold","folding"},
"folding":{"folded","fold","folds"},
"folded":{"fold","folding","folds"},
"fond":{"fondness","fondly","fonder","fondest"},
"fondness":{"fond","fondly","fonder","fondest"},
"fondly":{"fond","fondness","fonder","fondest"},
"fondest":{"fond","fondness","fondly","fonder","fondest"},
"fonder":{"fond","fondness","fondly","fondest"},
"fool":{"foolishly","foolish","fooled","fools","foolishness","fooling"},
"fools":{"foolishly","foolish","fool","fooled","fools","foolishness","fooling"},
"foolishness":{"foolishly","foolish","fool","fooled","fools","fooling"},
"foolishly":{"foolish","fool","fooled","fools","foolishness","fooling"},
"foolish":{"foolishly","foolish","fool","fooled","fools","foolishness","fooling"},
"fooling":{"foolishly","foolish","fool","fooled","fools","foolishness"},
"fooled":{"foolishly","foolish","fool","fools","foolishness","fooling"},
"foot":{"footballs","feet","football"},
"feet":{"footballs","foot","football"},
"football":{"footballs","foot","feet"},
"footballs":{"foot","feet","football"},
"forbid":{"forbidding","forbidden","forbids"},
"forbids":{"forbidding","forbidden","forbid"},
"forbidding":{"forbidden","forbid","forbids"},
"forbidden":{"forbidding","forbid","forbids"},
"forgive":{"forgave","forgives","forgiving","forgiven"},
"forgiving":{"forgave","forgives","forgive","forgiven"},
"forgives":{"forgave","forgiving","forgive","forgiven"},
"forgiven":{"forgave","forgives","forgiving","forgive"},
"forgave":{"forgives","forgiving","forgive","forgiven"},
"fork":{"forks"},
"forks":{"fork"},
"formal":{"formality","formally"},
"formally":{"formality","formal"},
"formality":{"formally","formal"},
"forward":{"forwards"},
"forwards":{"forward"},
"frame":{"framed","framing","frames"},
"framing":{"frame","framed","frames"},
"frames":{"frame","framed","framing"},
"framed":{"frame","framing","frames"},
"freeze":{"freezing","frozen","freezes"},
"frozen":{"freezing","freezes","freeze"},
"freezing":{"frozen","freezes","freeze"},
"freezes":{"freezing","frozen","freeze"},
"frequent":{"frequency","frequently","frequents","frequenting","frequented"},
"frequents":{"frequency","frequently","frequent","frequenting","frequented"},
"frequently":{"frequency","frequents","frequent","frequenting","frequented"},
"frequenting":{"frequency","frequently","frequents","frequent","frequented"},
"frequented":{"frequency","frequently","frequents","frequent","frequenting"},
"frequency":{"frequently","frequents","frequent","frequenting","frequented"},
"infrequent":{"infrequently","infrequent"},
"infrequently":{"infrequently","infrequent"},
"fright":{"frights","frightful","frightens","frightening","frightened","frighten"},
"frights":{"frightful","frightens","frightening","fright","frightened","frighten"},
"frightful":{"frights","frightens","frightening","fright","frightened","frighten"},
"frightens":{"frights","frightful","frightening","fright","frightened","frighten"},
"frightening":{"frights","frightful","frightens","fright","frightened","frighten"},
"frightened":{"frights","frightful","frightens","frightening","fright","frighten"},
"frighten":{"frights","frightful","frightens","frightening","fright","frightened"},
"fruit":{"fruits"},
"fruits":{"fruit"},
"fry":{"fries","fried","frying"},
"frying":{"fries","fried","fry"},
"fries":{"fried","frying","fry"},
"fried":{"fries","frying","fry"},
"fun":{"funniest","funny","funnier"},
"funny":{"funniest","fun","funnier"},
"funniest":{"funny","fun","funnier"},
"funnier":{"funniest","funny","fun"},
"funeral":{"funerals"},
"funerals":{"funeral"},
"fur":{"furs"},
"furs":{"fur"},
"gallon":{"gallons"},
"gallons":{"gallon"},
"gap":{"gaps"},
"gaps":{"gap"},
"garage":{"garages"},
"garages":{"garage"},
"gay":{"gayer","gayest","gayness","gaily","gaiety"},
"gayness":{"gayer","gayest","gay","gaily","gaiety"},
"gayest":{"gayer","gayness","gay","gaily","gaiety"},
"gayer":{"gayest","gayness","gay","gaily","gaiety"},
"gaily":{"gayer","gayest","gayness","gay","gaiety"},
"gaiety":{"gayer","gayest","gayness","gay","gaily"},
"generous":{"generosity","generously"},
"generously":{"generosity","generous"},
"generosity":{"generously","generous"},
"glory":{"glories","glorious"},
"glories":{"glory","glorious"},
"glorious":{"glory","glories"},
"goat":{"goats"},
"goats":{"goat"},
"govern":{"governments","govt","governs","governor","governing","government","governmental","governed"},
"govt":{"governments","govern","governs","governor","governing","government","governmental","governed"},
"governs":{"governments","govern","govt","governor","governing","government","governmental","governed"},
"governor":{"governments","govern","govt","governs","governing","government","governmental","governed"},
"governing":{"governments","govern","govt","governs","governor","government","governmental","governed"},
"governed":{"governments","govern","govt","governs","governor","governing","government","governmental"},
"government":{"governments","govern","govt","governs","governor","governing","governmental","governed"},
"governments":{"govern","govt","governs","governor","governing","government","governmental","governed"},
"governmental":{"governments","govern","govt","governs","governor","governing","government","governed"},
"grace":{"graced","graceful","gracing","graces","gracefully"},
"gracing":{"graced","graceful","grace","graces","gracefully"},
"graces":{"graced","graceful","grace","gracing","gracefully"},
"gracefully":{"graced","graceful","grace","gracing","graces"},
"graceful":{"graced","grace","gracing","graces","gracefully"},
"graced":{"graceful","grace","gracing","graces","gracefully"},
"gradual":{"gradually"},
"gradually":{"gradual"},
"grain":{"grains"},
"grains":{"grain"},
"gram":{"grams"},
"grams":{"gram"},
"grammar":{"grammars"},
"grammars":{"grammar"},
"grand":{"grandpa","grandparents","grandsons","grandchild","granddaughter","granddaughters","grandfather","grandma","grandmother","grandparent","grandson","grandchildren"},
"grandsons":{"grandpa","grandparents","grand","grandchild","granddaughter","granddaughters","grandfather","grandma","grandmother","grandparent","grandson","grandchildren"},
"grandson":{"grandpa","grandparents","grand","grandchild","granddaughter","granddaughters","grandfather","grandma","grandmother","grandparent","grandson","grandchildren"},
"grandparents":{"grandpa","grand","grandsons","grandchild","granddaughter","granddaughters","grandfather","grandma","grandmother","grandparent","grandson","grandchildren"},
"grandparent":{"grandpa","grandparents","grand","grandsons","grandchild","granddaughter","granddaughters","grandfather","grandma","grandmother","grandson","grandchildren"},
"grandpa":{"grandparents","grand","grandsons","grandchild","granddaughter","granddaughters","grandfather","grandma","grandmother","grandparent","grandson","grandchildren"},
"grandmother":{"grandpa","grandparents","grand","grandsons","grandchild","granddaughter","granddaughters","grandfather","grandma","grandparent","grandson","grandchildren"},
"grandma":{"grandpa","grandparents","grand","grandsons","grandchild","granddaughter","granddaughters","grandfather","grandmother","grandparent","grandson","grandchildren"},
"grandfather":{"grandpa","grandparents","grand","grandsons","grandchild","granddaughter","granddaughters","grandma","grandmother","grandparent","grandson","grandchildren"},
"granddaughters":{"grandpa","grandparents","grand","grandsons","grandchild","granddaughter","grandfather","grandma","grandmother","grandparent","grandson","grandchildren"},
"granddaughter":{"grandpa","grandparents","grand","grandsons","grandchild","granddaughters","grandfather","grandma","grandmother","grandparent","grandson","grandchildren"},
"grandchildren":{"grandpa","grandparents","grand","grandsons","grandchild","granddaughter","granddaughters","grandfather","grandma","grandmother","grandparent","grandson"},
"grandchild":{"grandpa","grandparents","grand","grandsons","granddaughter","granddaughters","grandfather","grandma","grandmother","grandparent","grandson","grandchildren"},
"grass":{"grassy","grasses"},
"grasses":{"grassy","grass"},
"grassy":{"grass","grasses"},
"grateful":{"gratefully"},
"gratefully":{"grateful"},
"grave":{"graves"},
"graves":{"grave"},
"grease":{"greasy","greases","greasing","greased"},
"greasing":{"greasy","greases","grease","greased"},
"greases":{"greasy","greasing","grease","greased"},
"greased":{"greasy","greases","greasing","grease"},
"greasy":{"greases","greasing","grease","greased"},
"greed":{"greedy","greedily"},
"greedy":{"greed","greedily"},
"greedily":{"greed","greedy"},
"greet":{"greetings","greets","greeting","greeted"},
"greetings":{"greet","greets","greeting","greeted"},
"greets":{"greetings","greet","greeting","greeted"},
"greeting":{"greetings","greet","greets","greeted"},
"greeted":{"greetings","greet","greets","greeting"},
"grind":{"grinds","grinding"},
"grinds":{"grinding","grind"},
"grinding":{"grinds","grind"},
"guard":{"guarded","guarding","guards"},
"guarded":{"guard","guarding","guards"},
"guarding":{"guarded","guard","guards"},
"guards":{"guarded","guard","guarding"},
"guess":{"guessing","guessed","guesses"},
"guessing":{"guessed","guesses","guess"},
"guesses":{"guessing","guessed","guess"},
"guessed":{"guessing","guesses","guess"},
"guest":{"guests"},
"guests":{"guest"},
"guide":{"guided","guides","guiding"},
"guiding":{"guided","guides","guide"},
"guides":{"guided","guiding","guide"},
"guided":{"guides","guiding","guide"},
"guilty":{"guilt","guguilty"},
"guilt":{"guiltily","guilty"},
"gun":{"gunner","guns"},
"guns":{"gun","gunner"},
"gunner":{"gun","guns"},
"habit":{"habitual","habitually","habits"},
"habits":{"habitual","habitually","habit"},
"habitual":{"habitually","habit","habits"},
"habitually":{"habitual","habit","habits"},
"hair":{"hairy","hairs"},
"hairy":{"hairs","hair"},
"hairs":{"hairy","hair"},
"hall":{"halls"},
"halls":{"hall"},
"hammer":{"hammering","hammered","hammers"},
"hammers":{"hammering","hammered","hammer"},
"hammering":{"hammered","hammer","hammers"},
"hammered":{"hammering","hammer","hammers"},
"handkerchief":{"handkerchiefs"},
"handkerchiefs":{"handkerchief"},
"handle":{"handled","handling","handles"},
"handled":{"handling","handles","handle"},
"handles":{"handled","handling","handle"},
"handling":{"handled","handles","handle"},
"harbor":{"harbors","harbour","harbours"},
"harbours":{"harbors","harbor","harbour"},
"harbour":{"harbors","harbor","harbour","harbours"},
"harbors":{"harbor","harbour","harbours"},
"harm":{"harming","harms","harmful","harmed"},
"harms":{"harming","harm","harmless","harmful","harmed"},
"harmless":{"harming","harm","harms","harmful","harmed"},
"harming":{"harm","harms","harmless","harmful","harmed"},
"harmful":{"harming","harm","harms","harmless","harmed"},
"harmed":{"harming","harm","harms","harmless","harmful"},
"harvest":{"harvests","harvesting","harvester","harvested"},
"harvests":{"harvesting","harvester","harvest","harvested"},
"harvesting":{"harvests","harvester","harvest","harvested"},
"harvester":{"harvests","harvesting","harvest","harvested"},
"harvested":{"harvests","harvesting","harvester","harvest"},
"haste":{"hastens","hastily","hastening","hasten","hastened"},
"hastily":{"hastens","hastening","hasten","hastened","haste"},
"hastens":{"hastily","hastening","hasten","hastened","haste"},
"hastening":{"hastens","hastily","hasten","hastened","haste"},
"hastened":{"hastens","hastily","hastening","hasten","haste"},
"hasten":{"hastens","hastily","hastening","hastened","haste"},
"hat":{"hats"},
"hats":{"hat"},
"hate":{"hatred","hated","hates","hating"},
"hatred":{"hated","hate","hates","hating"},
"hating":{"hatred","hated","hate","hates"},
"hates":{"hatred","hated","hate","hating"},
"hated":{"hatred","hate","hates","hating"},
"heal":{"heals","healing","healed"},
"heals":{"heal","healing","healed"},
"healing":{"heal","heals","healed"},
"healed":{"heal","heals","healing"},
"health":{"healthier","healthiest","healthily","healthy"},
"healthier":{"health","healthiest","healthily","healthy"},
"healthiest":{"health","healthier","healthily","healthy"},
"healthily":{"health","healthier","healthiest","healthy"},
"healthy":{"health","healthier","healthiest","healthily"},
"heap":{"heaps","heaping","heaped"},
"heaps":{"heap","heaping","heaped"},
"heaping":{"heap","heaps","heaped"},
"heaped":{"heap","heaps","heaping"},
"hesitate":{"hesitations","hesitation","hesitated","hesitates","hesitating"},
"hesitating":{"hesitate","hesitations","hesitation","hesitated","hesitates"},
"hesitates":{"hesitate","hesitations","hesitation","hesitated","hesitating"},
"hesitated":{"hesitate","hesitations","hesitation","hesitates","hesitating"},
"hesitation":{"hesitate","hesitations","hesitated","hesitates","hesitating"},
"hesitations":{"hesitate","hesitation","hesitated","hesitates","hesitating"},
"hide":{"hides","hiding","hid","hidden"},
"hid":{"hides","hide","hiding","hidden"},
"hidden":{"hides","hide","hiding","hid"},
"hides":{"hide","hiding","hid","hidden"},
"hiding":{"hides","hide","hid","hidden"},
"hinder":{"hindering","hinders","hindered"},
"hinders":{"hindering","hinder","hindered"},
"hindering":{"hinder","hinders","hindered"},
"hindered":{"hindering","hinder","hinders"},
"hire":{"hiring","hired","hires"},
"hiring":{"hire","hired","hires"},
"hires":{"hire","hiring","hired"},
"hired":{"hire","hiring","hires"},
"hit":{"hits","hitting","hitter"},
"hitting":{"hits","hit","hitter"},
"hitter":{"hits","hitting","hit"},
"hits":{"hitting","hit","hitter"},
"hole":{"holes"},
"holes":{"hole"},
"holiday":{"holidays"},
"holidays":{"holiday"},
"hollow":{"hollowed","hollows","hollowing"},
"hollows":{"hollowed","hollowing","hollow"},
"hollowing":{"hollowed","hollows","hollow"},
"hollowed":{"hollows","hollowing","hollow"},
"holy":{"holiness","holier","holiest"},
"holiness":{"holier","holiest","holy"},
"holiest":{"holiness","holier","holy"},
"holier":{"holiness","holiest","holy"},
"honest":{"dishonest","honesty","honestly"},
"honesty":{"dishonest","honest","honestly"},
"honestly":{"dishonest","honest","honesty"},
"dishonest":{"honest","honesty","honestly"},
"hook":{"hooks","hooking","hooked"},
"hooks":{"hook","hooking","hooked"},
"hooking":{"hook","hooks","hooked"},
"hooked":{"hook","hooks","hooking"},
"horizon":{"horizons"},
"horizons":{"horizon"},
"hospital":{"hospitals"},
"hospitals":{"hospital"},
"host":{"hosted","hosting","hosts"},
"hosts":{"host","hosted","hosting"},
"hosting":{"host","hosted","hosts"},
"hosted":{"host","hosting","hosts"},
"hotel":{"hotels"},
"hotels":{"hotel"},
"hullo":{"hey","hello","hi"},
"hello":{"hullo","hey","hi"},
"hey":{"hullo","hello","hi"},
"hi":{"hullo","hey","hello","hi"},
"humble":{"humbled","humbly","humbling","humbles"},
"humbly":{"humbled","humble","humbling","humbles"},
"humbling":{"humbled","humble","humbly","humbles"},
"humbles":{"humbled","humble","humbly","humbling"},
"humbled":{"humble","humbly","humbling","humbles"},
"hunger":{"hungry","hungrily","hungering","hungers"},
"hungry":{"hunger","hungrily","hungering","hungers"},
"hungrily":{"hunger","hungry","hungering","hungers"},
"hungers":{"hunger","hungry","hungrily","hungering"},
"hungering":{"hunger","hungry","hungrily","hungers"},
"hunt":{"hunted","hunts","hunting","hunters","hunter"},
"hunts":{"hunted","hunting","hunters","hunter","hunt"},
"hunting":{"hunted","hunts","hunters","hunter","hunt"},
"hunters":{"hunted","hunts","hunting","hunter","hunt"},
"hunter":{"hunted","hunts","hunting","hunters","hunt"},
"hunted":{"hunts","hunting","hunters","hunter","hunt"},
"hurry":{"hurried","hurriedly","hurries","hurrying"},
"hurrying":{"hurried","hurriedly","hurries","hurry"},
"hurries":{"hurried","hurriedly","hurrying","hurry"},
"hurriedly":{"hurried","hurries","hurrying","hurry"},
"hurried":{"hurriedly","hurries","hurrying","hurry"},
"hurt":{"hurtful","hurting","hurts"},
"hurts":{"hurtful","hurting","hurt"},
"hurting":{"hurtful","hurts","hurt"},
"hurtful":{"hurting","hurts","hurt"},
"hut":{"huts"},
"huts":{"hut"},
"ice":{"icy","iced"},
"icy":{"ice","iced"},
"iced":{"icy","ice"},
"ideal":{"ideally","ideals"},
"ideals":{"ideally","ideal"},
"ideally":{"ideal","ideals"},
"idle":{"idly","idling","idles","idled"},
"idling":{"idly","idle","idles","idled"},
"idles":{"idly","idle","idling","idled"},
"idled":{"idly","idle","idling","idles"},
"idly":{"idle","idling","idles","idled"},
"imagine":{"imagination","imagined","imagines","imagining","imaginative","imaginations","imaginary","image"},
"imagining":{"imagination","imagined","imagines","imaginative","imagine","imaginations","imaginary"},
"imagines":{"imagination","imagined","imagining","imaginative","imagine","imaginations","imaginary"},
"imagined":{"imagination","imagines","imagining","imaginative","imagine","imaginations","imaginary"},
"imagination":{"imagined","imagines","imagining","imaginative","imagine","imaginations","imaginary"},
"imaginations":{"imagination","imagined","imagines","imagining","imaginative","imagine","imaginary"},
"imaginative":{"imagination","imagined","imagines","imagining","imagine","imaginations","imaginary"},
"imaginary":{"imagination","imagined","imagines","imagining","imaginative","imagine","imaginations"},
"imitate":{"imitation","imitations","imitated","imitates","imitating"},
"imitating":{"imitate","imitation","imitations","imitated","imitates"},
"imitates":{"imitate","imitation","imitations","imitated","imitating"},
"imitated":{"imitate","imitation","imitations","imitates","imitating"},
"imitation":{"imitate","imitations","imitated","imitates","imitating"},
"imitations":{"imitate","imitation","imitated","imitates","imitating"},
"immediate":{"immediately","immediacy"},
"immediacy":{"immediately","immediate"},
"immediately":{"immediacy","immediate"},
"immense":{"immensely"},
"immensely":{"immense"},
"improve":{"improves","improving","improved","improvement","improvements"},
"improving":{"improves","improve","improved","improvement","improvements"},
"improves":{"improve","improving","improved","improvement","improvements"},
"improved":{"improves","improve","improving","improvement","improvements"},
"improvement":{"improves","improve","improving","improved","improvements"},
"improvements":{"improves","improve","improving","improved","improvement"},
"inform":{"information","informed","informing","informs"},
"informs":{"information","informed","informing","inform"},
"informing":{"information","informed","inform","informs"},
"informed":{"information","informing","inform","informs"},
"information":{"informed","informing","inform","informs"},
"informal":{"informally"},
"informally":{"informal"},
"ink":{"inky","inks"},
"inks":{"inky","ink"},
"inky":{"inks","ink"},
"inn":{"inns"},
"inns":{"inn"},
"inquire":{"enquire","inquiries","enquiring","enquiry","inquired","inquires","inquiring","inquiry"},
"inquiry":{"enquire","inquiries","enquiring","enquiry","inquired","inquires","inquiring","inquire"},
"inquiring":{"enquire","inquiries","enquiring","enquiry","inquired","inquires","inquiry","inquire"},
"inquiries":{"enquire","enquiring","enquiry","inquired","inquires","inquiring","inquiry","inquire"},
"inquires":{"enquire","inquiries","enquiring","enquiry","inquired","inquiring","inquiry","inquire"},
"inquired":{"enquire","inquiries","enquiring","enquiry","inquires","inquiring","inquiry","inquire"},
"enquire":{"inquiries","enquiring","enquiry","inquired","inquires","inquiring","inquiry","inquire"},
"enquiry":{"enquire","inquiries","enquiring","inquired","inquires","inquiring","inquiry","inquire"},
"enquiring":{"enquire","inquiries","enquiry","inquired","inquires","inquiring","inquiry","inquire"},
"insect":{"insects"},
"insects":{"insect"},
"inside":{"insider","insiders"},
"insider":{"insiders","inside"},
"insiders":{"insider","inside"},
"instant":{"instantly"},
"instantly":{"instant"},
"instrument":{"instrumental","instruments"},
"instruments":{"instrumental","instrument"},
"instrumental":{"instrument","instruments"},
"insult":{"insulted","insulting","insults"},
"insults":{"insulted","insult","insulting"},
"insulting":{"insulted","insult","insults"},
"insulted":{"insult","insulting","insults"},
"insure":{"insurance","insured","insures","insuring"},
"insuring":{"insurance","insured","insures","insure"},
"insures":{"insurance","insured","insure","insuring"},
"insured":{"insurance","insures","insure","insuring"},
"insurance":{"insured","insures","insure","insuring"},
"intend":{"intently","intentional","intentions","intention","intent","intending","intended","intends","intentionally"},
"intended":{"intently","intentional","intentions","intention","intent","intending","intends","intentionally","intend"},
"intending":{"intently","intentional","intentions","intention","intent","intended","intends","intentionally","intend"},
"intends":{"intently","intentional","intentions","intention","intent","intending","intended","intentionally","intend"},
"intent":{"intently","intentional","intentions","intention","intending","intended","intends","intentionally","intend"},
"intently":{"intentional","intentions","intention","intent","intending","intended","intends","intentionally","intend"},
"intention":{"intently","intentional","intentions","intent","intending","intended","intends","intentionally","intend"},
"intentions":{"intently","intentional","intention","intent","intending","intended","intends","intentionally","intend"},
"intentional":{"intently","intentions","intention","intent","intending","intended","intends","intentionally","intend"},
"intentionally":{"intently","intentional","intentions","intention","intent","intending","intended","intends","intend"},
"interfere":{"interfering","interferes","interfered","interference"},
"interfering":{"interferes","interfered","interfere","interference"},
"interferes":{"interfering","interfered","interfere","interference"},
"interfered":{"interfering","interferes","interfere","interference"},
"interference":{"interfering","interferes","interfered","interfere"},
"international":{"internationally"},
"internationally":{"international"},
"interrupt":{"interrupting","interrupted","interrupts"},
"interrupts":{"interrupting","interrupted","interrupt"},
"interrupting":{"interrupted","interrupts","interrupt"},
"interrupted":{"interrupting","interrupts","interrupt"},
"invent":{"invention","inventions","invented","inventing","inventor","inventors","invents"},
"invents":{"invent","invention","inventions","invented","inventing","inventor","inventors"},
"inventors":{"invent","invention","inventions","invented","inventing","inventor","invents"},
"inventor":{"invent","invention","inventions","invented","inventing","inventors","invents"},
"inventing":{"invent","invention","inventions","invented","inventor","inventors","invents"},
"invented":{"invent","invention","inventions","inventing","inventor","inventors","invents"},
"invention":{"invent","inventions","invented","inventing","inventor","inventors","invents"},
"inventions":{"invent","invention","invented","inventing","inventor","inventors","invents"},
"invite":{"inviting","invites","invited","invitation","invitations"},
"inviting":{"invites","invite","invited","invitation","invitations"},
"invites":{"inviting","invite","invited","invitation","invitations"},
"invited":{"inviting","invites","invite","invitation","invitations"},
"invitation":{"inviting","invites","invite","invited","invitations"},
"invitations":{"inviting","invites","invite","invited","invitation"},
"inward":{"inwardly"},
"inwardly":{"inward"},
"island":{"islands"},
"islands":{"island"},
"jaw":{"jaws"},
"jaws":{"jaw"},
"jealous":{"jealousy","jealously"},
"jealously":{"jealousy","jealous"},
"jealousy":{"jealously","jealous"},
"jewel":{"jewellery","jeweller","jewellers","jewels"},
"jewels":{"jewellery","jeweller","jewellers","jewel"},
"jewellers":{"jewellery","jeweller","jewels","jewel"},
"jeweller":{"jewellery","jewellers","jewels","jewel"},
"jewellery":{"jeweller","jewellers","jewels","jewel"},
"joke":{"joking","joked","jokes"},
"jokes":{"joking","joked","joke"},
"joked":{"joking","jokes","joke"},
"joking":{"joked","jokes","joke"},
"journey":{"journeyed","journeys","journeying"},
"journeys":{"journeyed","journey","journeying"},
"journeying":{"journeyed","journeys","journey"},
"journeyed":{"journeys","journey","journeying"},
"juice":{"juicy","juices"},
"juices":{"juicy","juice"},
"juicy":{"juices","juice"},
"jump":{"jumping","jumped","jumps"},
"jumps":{"jumping","jumped","jump"},
"jumping":{"jumped","jumps","jump"},
"jumped":{"jumping","jumps","jump"},
"key":{"keys"},
"keys":{"key"},
"kick":{"kicks","kicking","kicked"},
"kicks":{"kick","kicking","kicked"},
"kicking":{"kick","kicks","kicked"},
"kicked":{"kick","kicks","kicking"},
"kilogram":{"kilograms"},
"kilograms":{"kilogram"},
"kilometre":{"kilometres"},
"kilometres":{"kilometre"},
"kiss":{"kisses","kissing","kissed"},
"kissing":{"kisses","kiss","kissed"},
"kisses":{"kissing","kiss","kissed"},
"kissed":{"kisses","kissing","kiss"},
"kitchen":{"kitchens"},
"kitchens":{"kitchen"},
"knee":{"knees"},
"knees":{"knee"},
"kneel":{"kneels","kneeled","kneeling"},
"kneels":{"kneel","kneeled","kneeling"},
"kneeling":{"kneel","kneels","kneeled"},
"knife":{"knives"},
"knives":{"knife"},
"knock":{"knocks","knocking","knocked"},
"knocks":{"knock","knocking","knocked"},
"knocking":{"knock","knocks","knocked"},
"knocked":{"knock","knocks","knocking"},
"knot":{"knotting","knots","knotted"},
"knotting":{"knot","knots","knotted"},
"knotted":{"knot","knotting","knots"},
"knots":{"knot","knotting","knotted"},
"ladder":{"ladders"},
"ladders":{"ladder"},
"lamp":{"lamps"},
"lamps":{"lamp"},
"lazy":{"laziness","lazily","laziest","lazier"},
"laziness":{"lazy","lazily","laziest","lazier"},
"lazily":{"lazy","laziness","laziest","lazier"},
"laziest":{"lazy","laziness","lazily","lazier"},
"lazier":{"lazy","laziness","lazily","laziest"},
"leaf":{"leafy"},
"leafy":{"leaf"},
"lean":{"leans","leaning","leaned"},
"leans":{"lean","leaning","leaned"},
"leaning":{"lean","leans","leaned"},
"leaned":{"lean","leans","leaning"},
"leather":{"leathers"},
"leathers":{"leather"},
"leg":{"legs"},
"legs":{"leg"},
"lend":{"lending","lends","lent"},
"lent":{"lend","lending","lends"},
"lends":{"lend","lending","lent"},
"lending":{"lend","lends","lent"},
"lesson":{"lessons"},
"lessons":{"lesson"},
"liberty":{"liberties"},
"liberties":{"liberty"},
"lid":{"lids"},
"lids":{"lid"},
"limb":{"limb"},
"limbs":{"limb"},
"liquid":{"liquids"},
"liquids":{"liquid"},
"list":{"listing","listed","lists"},
"lists":{"listing","listed","list"},
"listed":{"listing","lists","list"},
"listing":{"listed","lists","list"},
"litre":{"litres"},
"litres":{"litre"},
"load":{"loads","loading","loaded"},
"unloads":{"unloads","unloading","unloaded"},
"unloading":{"unloads","unloading","unloaded"},
"unloaded":{"unloads","unloading","unloaded"},
"loads":{"load","loading","loaded"},
"loading":{"load","loads","loaded"},
"loaded":{"load","loads","loading"},
"loaf":{"loaves"},
"loaves":{"loaf"},
"loan":{"loans"},
"loans":{"loan"},
"lock":{"locked","locks","locking"},
"unlocks":{"unlock","unlocked","unlocking","unlocks"},
"unlocking":{"unlock","unlocked","unlocking","unlocks"},
"unlocked":{"unlock","unlocked","unlocking","unlocks"},
"unlock":{"unlocked","unlocking","unlocks"},
"locks":{"locked","locking","lock"},
"locking":{"locked","locks","lock"},
"locked":{"locks","locking","lock"},
"lodging":{"lodgings"},
"lodgings":{"lodging"},
"log":{"logs"},
"logs":{"log"},
"lone":{"lonely","loneliness"},
"lonely":{"loneliness","lone"},
"loneliness":{"lonely","lone"},
"loose":{"loosen","loosely"},
"loosely":{"loosen","loose"},
"loosen":{"loose","loosely"},
"lot":{"lots"},
"lots":{"lot"},
"loud":{"louder","loudest","loudly","loudness"},
"loudness":{"loud","louder","loudest","loudly"},
"loudly":{"loud","louder","loudest","loudness"},
"loudest":{"loud","louder","loudly","loudness"},
"louder":{"loud","loudest","loudly","loudness"},
"loyal":{"loyalty","loyally"},
"loyalty":{"loyal","loyally"},
"loyally":{"loyal","loyalty"},
"luck":{"luckier","luckiest","luckily","lucky"},
"lucky":{"luckier","luckiest","luckily","luck"},
"luckily":{"luckier","luckiest","luckily","lucky","luck"},
"luckiest":{"luckier","luckily","lucky","luck"},
"luckier":{"luckiest","luckily","lucky","luck"},
"unlucky":{"unluckily","unlucky"},
"unluckily":{"unlucky"},
"lump":{"lumps"},
"lumps":{"lump"},
"lunch":{"lunches"},
"lunches":{"lunch"},
"lung":{"lungs"},
"lungs":{"lung"},
"mad":{"madly","maddest","madness","madman","madder"},
"madness":{"madly","mad","maddest","madman","madder"},
"madly":{"mad","maddest","madness","madman","madder"},
"maddest":{"madly","mad","madness","madman","madder"},
"madder":{"madly","mad","maddest","madness","madman"},
"madman":{"madly","mad","maddest","madness","madder"},
"mail":{"mailed","mailing","mails"},
"mails":{"mailed","mailing","mail"},
"mailing":{"mailed","mails","mail"},
"mailed":{"mailing","mails","mail"},
"male":{"males"},
"males":{"male"},
"manage":{"management","managed","managers","manages","managing","manager"},
"managing":{"management","managed","managers","manages","manager","manage"},
"manages":{"management","managed","managers","managing","manager","manage"},
"managers":{"management","managed","manages","managing","manager","manage"},
"manager":{"management","managed","managers","manages","managing","manage"},
"managed":{"management","managers","manages","managing","manager","manage"},
"management":{"managed","managers","manages","managing","manager","manage"},
"map":{"maps"},
"maps":{"map"},
"mat":{"mats"},
"mats":{"mat"},
"match":{"matched","matches","matching"},
"matching":{"match","matched","matches"},
"matches":{"match","matched","matching"},
"matched":{"match","matches","matching"},
"meal":{"meals"},
"meals":{"meal"},
"meat":{"meats"},
"meats":{"meat"},
"mechanic":{"mechanically","mechanical","mechanics"},
"mechanics":{"mechanically","mechanical","mechanic"},
"mechanical":{"mechanically","mechanic","mechanics"},
"mechanically":{"mechanical","mechanic","mechanics"},
"medicine":{"medicines","medic"},
"medicines":{"medicine","medic"},
"medic":{"medicine","medicines"},
"melt":{"melted","melting","melts"},
"melts":{"melted","melting","melt"},
"melting":{"melted","melts","melt"},
"melted":{"melting","melts","melt"},
"mend":{"mending","mends","mended"},
"mends":{"mend","mending","mended"},
"mending":{"mend","mends","mended"},
"mended":{"mend","mending","mends"},
"merchant":{"merchants"},
"merchants":{"merchant"},
"mercy":{"mercies","merciful"},
"merciful":{"mercies","mercy"},
"mercies":{"merciful","mercy"},
"merry":{"merrily","merriness","merriest","merrier"},
"merriness":{"merrily","merry","merriest","merrier"},
"merriest":{"merrily","merry","merriness","merrier"},
"merrier":{"merrily","merry","merriness","merriest"},
"merrily":{"merry","merriness","merriest","merrier"},
"message":{"messages"},
"messages":{"message"},
"messenger":{"messengers"},
"messengers":{"messenger"},
"metre":{"metres"},
"metres":{"metre"},
"mild":{"milder","mildly","mildness","mildest"},
"mildness":{"milder","mildly","mild","mildest"},
"mildly":{"milder","mildness","mild","mildest"},
"mildest":{"milder","mildly","mildness","mild"},
"milder":{"mildly","mildness","mild","mildest"},
"mill":{"miller","milled","milling","mills"},
"mills":{"miller","milled","milling","mill"},
"milling":{"miller","milled","mills","mill"},
"miller":{"milled","milling","mills","mill"},
"milled":{"miller","milling","mills","mill"},
"milligram":{"milligrams"},
"milligrams":{"milligram"},
"millilitre":{"millilitres"},
"millilitres":{"millilitre"},
"millimetre":{"millimetres"},
"millimetres":{"millimetre"},
"mineral":{"minerals"},
"minerals":{"mineral"},
"miserable":{"miserably"},
"miserably":{"miserable"},
"mistake":{"mistaken","mistakenly","mistakes","mistaking"},
"mistaking":{"mistaken","mistakenly","mistakes","mistake"},
"mistakes":{"mistaken","mistakenly","mistaking","mistake"},
"mistakenly":{"mistaken","mistakes","mistaking","mistake"},
"mistaken":{"mistakenly","mistakes","mistaking","mistake"},
"unmistakably":{"unmistakable"},
"unmistakable":{"unmistakably"},
"mix":{"mixture","mixed","mixes","mixing","mixtures"},
"mixtures":{"mixture","mix","mixed","mixes","mixing"},
"mixture":{"mix","mixed","mixes","mixing","mixtures"},
"mixing":{"mixture","mix","mixed","mixes","mixtures"},
"mixes":{"mixture","mix","mixed","mixing","mixtures"},
"mixed":{"mixture","mix","mixes","mixing","mixtures"},
"model":{"modeled","modeling","modelled","modelling","models"},
"models":{"modeled","model","modeling","modelled","modelling"},
"modelling":{"modeled","model","modeling","modelled","models"},
"modelled":{"modeled","model","modeling","modelling","models"},
"modeling":{"modeled","model","modelled","modelling","models"},
"modeled":{"model","modeling","modelled","modelling","models"},
"moderate":{"moderation","moderately"},
"moderately":{"moderation","moderate"},
"moderation":{"moderately","moderate"},
"modest":{"modesty","modestly"},
"modesty":{"modest","modestly"},
"modestly":{"modesty","modest"},
"monkey":{"monkeys"},
"monkeys":{"monkey"},
"motion":{"motioning","motionless","motions","motioned"},
"motions":{"motioning","motion","motionless","motioned"},
"motioning":{"motion","motionless","motions","motioned"},
"motioned":{"motioning","motion","motionless","motions"},
"motionless":{"motioning","motion","motions","motioned"},
"mouse":{"mice"},
"mice":{"mouse"},
"mud":{"muddy"},
"muddy":{"mud"},
"multiply":{"multiplies","multiple","multiplied","multiplication","multiplying"},
"multiplying":{"multiplies","multiply","multiple","multiplied","multiplication"},
"multiplies":{"multiply","multiple","multiplied","multiplication","multiplying"},
"multiplied":{"multiplies","multiply","multiple","multiplication","multiplying"},
"multiple":{"multiplies","multiply","multiplied","multiplication","multiplying"},
"multiplication":{"multiplies","multiply","multiple","multiplied","multiplying"},
"murder":{"murdered","murdering","murderers","murders","murderer"},
"murders":{"murder","murdered","murdering","murderers","murderer"},
"murdering":{"murder","murdered","murderers","murders","murderer"},
"murderers":{"murder","murdered","murdering","murders","murderer"},
"murderer":{"murder","murdered","murdering","murderers","murders"},
"murdered":{"murder","murdering","murderers","murders","murderer"},
"mystery":{"mysteries","mysteriously","mysterious"},
"mysteriously":{"mystery","mysteries","mysterious"},
"mysterious":{"mystery","mysteries","mysteriously"},
"mysteries":{"mystery","mysteriously","mysterious"},
"nail":{"nailed","nailing","nails"},
"nails":{"nail","nailed","nailing"},
"nailing":{"nail","nailed","nails"},
"nailed":{"nail","nailing","nails"},
"narrow":{"narrowest","narrowing","narrowly","narrowness","narrows","narrower","narrowed"},
"narrowed":{"narrow","narrowest","narrowing","narrowly","narrowness","narrows","narrower"},
"narrower":{"narrow","narrowest","narrowing","narrowly","narrowness","narrows","narrowed"},
"narrowest":{"narrow","narrowing","narrowly","narrowness","narrows","narrower","narrowed"},
"narrowing":{"narrow","narrowest","narrowly","narrowness","narrows","narrower","narrowed"},
"narrowly":{"narrow","narrowest","narrowing","narrowness","narrows","narrower","narrowed"},
"narrowness":{"narrow","narrowest","narrowing","narrowly","narrows","narrower","narrowed"},
"narrows":{"narrow","narrowest","narrowing","narrowly","narrowness","narrower","narrowed"},
"neat":{"neatly","neatest","neater","neatness"},
"neatness":{"neatly","neatest","neater","neat"},
"neatly":{"neatest","neater","neat","neatness"},
"neatest":{"neatly","neater","neat","neatness"},
"neater":{"neatly","neatest","neat","neatness"},
"neck":{"necks"},
"necks":{"neck"},
"needle":{"needles","needling","needled"},
"needling":{"needles","needle","needled"},
"needles":{"needling","needle","needled"},
"needled":{"needles","needling","needle"},
"neglect":{"neglected","neglecting","neglects"},
"neglects":{"neglected","neglecting","neglect"},
"neglecting":{"neglected","neglect","neglects"},
"neglected":{"neglecting","neglect","neglects"},
"nephew":{"nephews"},
"nephews":{"nephew"},
"nest":{"nests","nested","nesting"},
"nests":{"nest","nested","nesting"},
"nesting":{"nest","nests","nested"},
"nested":{"nest","nests","nesting"},
"net":{"nets"},
"nets":{"net"},
"nice":{"nicely","niceness","nicer","nicest"},
"nicest":{"nicely","niceness","nicer","nice"},
"nicer":{"nicely","niceness","nice","nicest"},
"niceness":{"nicely","nicer","nice","nicest"},
"nicely":{"niceness","nicer","nice","nicest"},
"niece":{"nieces"},
"nieces":{"niece"},
"noise":{"noisy","noisily","noises"},
"noisy":{"noise","noisily","noises"},
"noisily":{"noisy","noise","noises"},
"noises":{"noisy","noise","noisily"},
"nonsense":{"nonsensical"},
"nonsensical":{"nonsense"},
"nose":{"noses"},
"noses":{"nose"},
"noun":{"nouns"},
"nouns":{"noun"},
"nuisance":{"nuisances"},
"nuisances":{"nuisance"},
"nurse":{"nursed","nurses","nursing"},
"nursing":{"nursed","nurses","nurse"},
"nurses":{"nursed","nursing","nurse"},
"nursed":{"nurses","nursing","nurse"},
"nut":{"nuts"},
"nuts":{"nut"},
"oar":{"oars"},
"oars":{"oar"},
"obey":{"obediently","obedient","obeyed","obedience","obeys","obeying"},
"obeys":{"obediently","obedient","obeyed","obedience","obey","obeying"},
"obeying":{"obediently","obedient","obeyed","obedience","obey","obeys"},
"obeyed":{"obediently","obedient","obedience","obey","obeys","obeying"},
"obedience":{"obediently","obedient","obedience","obey","obeys","obeying"},
"obediently":{"obedient","obeyed","obedience","obey","obeys","obeying"},
"obedient":{"obediently","disobey","obeyed","obedience","obey","obeys","obeying"},
"disobey":{"disobeyed","disobeying","obedience"},
"disobeyed":{"disobeyed","disobey","disobeying"},
"disobeying":{"disobeyed","disobey","disobeying"},
"ocean":{"oceans"},
"oceans":{"ocean"},
"offend":{"offensive","offenses","offense","offends","offending","offended","offensively"},
"offenses":{"offend","offensive","offense","offends","offending","offended","offensively"},
"offense":{"offend","offensive","offenses","offends","offending","offended","offensively"},
"offends":{"offend","offensive","offenses","offense","offending","offended","offensively"},
"offending":{"offend","offensive","offenses","offense","offends","offended","offensively"},
"offended":{"offend","offensive","offenses","offense","offends","offending","offensively"},
"offensive":{"offend","offenses","offense","offends","offending","offended","offensively"},
"offensively":{"offend","offensive","offenses","offense","offends","offending","offended"},
"inoffensive":{"inoffensively"},
"inoffensively":{"inoffensive"},
"omit":{"omission","omissions","omitting","omitted","omits"},
"omitting":{"omission","omissions","omit","omitted","omits"},
"omitted":{"omission","omissions","omit","omitting","omits"},
"omits":{"omission","omissions","omit","omitting","omitted"},
"omission":{"omissions","omit","omitting","omitted","omits"},
"omissions":{"omission","omit","omitting","omitted","omits"},
"onwards":{"onward"},
"onward":{"onwards"},
"oppose":{"opposes","opposed","opposing"},
"opposing":{"opposes","oppose","opposed"},
"opposes":{"oppose","opposed","opposing"},
"opposed":{"opposes","oppose","opposing"},
"opposite":{"opposites"},
"opposites":{"opposite"},
"orange":{"orangish","oranges"},
"oranges":{"orangish","orange"},
"organ":{"organs"},
"organs":{"organ"},
"origin":{"originally","original","originality","origins","originated","originates"},
"origins":{"originally","original","originality","originated","origin","originates"},
"originates":{"originally","original","originality","origins","originated","origin"},
"originated":{"originally","original","originality","origins","origin","originates"},
"original":{"originally","originality","origins","originated","origin","originates"},
"originally":{"original","originality","origins","originated","origin","originates"},
"originality":{"originally","original","origins","originated","origin","originates"},
"ornament":{"ornaments","ornamental"},
"ornaments":{"ornament","ornamental"},
"ornamental":{"ornaments","ornament"},
"outline":{"outlined","outlines","outlining"},
"outlined":{"outline","outlines","outlining"},
"outlines":{"outline","outlined","outlining"},
"outlining":{"outline","outlined","outlines"},
"overcome":{"overcoming","overcomes","overcame"},
"overcoming":{"overcome","overcomes","overcame"},
"overcomes":{"overcome","overcoming","overcame"},
"overcame":{"overcome","overcoming","overcomes"},
"pack":{"packed","packing","package","packs","packages"},
"packs":{"pack","packed","packing","package","packages"},
"packing":{"pack","packed","package","packs","packages"},
"packed":{"pack","packing","package","packs","packages"},
"package":{"pack","packed","packing","packs","packages"},
"packages":{"pack","packed","packing","package","packs"},
"pad":{"padding","padded","pads"},
"pads":{"padding","pad","padded"},
"padding":{"pad","padded","pads"},
"padded":{"padding","pad","pads"},
"pain":{"painful","pains","painfully"},
"pains":{"painful","pain","painfully"},
"painful":{"pains","pain","painfully"},
"painfully":{"painful","pains","pain"},
"pair":{"pairs","paired","pairing"},
"pairs":{"pair","paired","pairing"},
"pairing":{"pair","pairs","paired"},
"paired":{"pair","pairs","pairing"},
"pale":{"paleness","paled","paling","pales"},
"paling":{"paleness","paled","pale","pales"},
"pales":{"paleness","paled","pale","paling"},
"paled":{"paleness","pale","paling","pales"},
"paleness":{"paled","pale","paling","pales"},
"pan":{"pans"},
"pans":{"pan"},
"parcel":{"parcels","parcelled"},
"parcels":{"parcelled","parcel"},
"parcelled":{"parcels","parcel"},
"pardon":{"pardons","pardoning","unpardonable","pardoned"},
"pardons":{"pardon","pardoning","unpardonable","pardoned"},
"pardoning":{"pardon","pardons","unpardonable","pardoned"},
"pardoned":{"pardon","pardons","pardoning"},
"parent":{"parental","parents","parentage"},
"parents":{"parent","parental","parentage"},
"parental":{"parent","parents","parentage"},
"parentage":{"parent","parental","parents"},
"park":{"parks","parking","parked"},
"parks":{"park","parking","parked"},
"parking":{"parks","park","parked"},
"parked":{"parks","park","parking"},
"permanent":{"permanently"},
"permanently":{"permanent"},
"passage":{"passages"},
"passages":{"passage"},
"passenger":{"passengers"},
"passengers":{"passenger"},
"paste":{"pastes","pasting","pasted"},
"pasting":{"pastes","pasted","paste"},
"pastes":{"pasting","pasted","paste"},
"pasted":{"pastes","pasting","paste"},
"path":{"paths"},
"paths":{"path"},
"patient":{"patience","patiently"},
"patiently":{"patience","patient"},
"patience":{"patient","patiently"},
"pattern":{"patterns","patterned"},
"patterns":{"patterned","pattern"},
"patterned":{"patterns","pattern"},
"pause":{"paused","pausing","pauses"},
"pausing":{"paused","pauses","pause"},
"pauses":{"paused","pausing","pause"},
"paused":{"pausing","pauses","pause"},
"paw":{"paws"},
"paws":{"paw"},
"pearl":{"pearls"},
"pearls":{"pearl"},
"peculiar":{"peculiarities","peculiarity","peculiarly"},
"peculiarly":{"peculiarities","peculiarity","peculiar"},
"peculiarity":{"peculiarities","peculiarly","peculiar"},
"peculiarities":{"peculiarity","peculiarly","peculiar"},
"pen":{"pens"},
"pens":{"pen"},
"pencil":{"pencils"},
"pencils":{"pencil"},
"penny":{"pennies"},
"pennies":{"penny"},
"perfect":{"perfected","perfectly","perfects","perfection","perfecting"},
"perfected":{"perfectly","perfects","perfection","perfect","perfecting"},
"perfecting":{"perfected","perfectly","perfects","perfection","perfect"},
"perfectly":{"perfected","perfects","perfection","perfect","perfecting"},
"perfects":{"perfected","perfectly","perfection","perfect","perfecting"},
"perfection":{"perfected","perfectly","perfects","perfect","perfecting"},
"perform":{"performers","performs","performing","performed","performance","performances"},
"performs":{"performers","perform","performing","performed","performance","performances"},
"performing":{"performers","perform","performs","performed","performance","performances"},
"performers":{"perform","performs","performing","performed","performance","performances"},
"performed":{"performers","perform","performs","performing","performance","performances"},
"performance":{"performers","perform","performs","performing","performed","performances"},
"performances":{"performers","perform","performs","performing","performed","performance"},
"persuade":{"persuaded","persuading","persuasive","persuasively","persuasion","persuades"},
"persuasion":{"persuaded","persuading","persuasive","persuasively","persuade","persuades"},
"persuades":{"persuaded","persuading","persuasive","persuasively","persuade","persuasion"},
"persuaded":{"persuading","persuasive","persuasively","persuade","persuasion","persuades"},
"persuading":{"persuaded","persuasive","persuasively","persuade","persuasion","persuades"},
"persuasive":{"persuaded","persuading","persuasively","persuade","persuasion","persuades"},
"persuasively":{"persuaded","persuading","persuasive","persuade","persuasion","persuades"},
"pet":{"pets"},
"pets":{"pet"},
"photograph":{"photographer","photographed","photographers","photographing","photographs","photography"},
"photography":{"photographer","photographed","photographers","photographing","photographs","photograph"},
"photographs":{"photographer","photographed","photographers","photographing","photography","photograph"},
"photographing":{"photographer","photographed","photographers","photographs","photography","photograph"},
"photographers":{"photographer","photographed","photographing","photographs","photography","photograph"},
"photographer":{"photographed","photographers","photographing","photographs","photography","photograph"},
"photographed":{"photographer","photographers","photographing","photographs","photography","photograph"},
"pick":{"picked","picker","pickers","picking","picks"},
"picks":{"picked","picker","pickers","picking","pick"},
"picking":{"picked","picker","pickers","picks","pick"},
"pickers":{"picked","picker","picking","picks","pick"},
"picker":{"picked","pickers","picking","picks","pick"},
"picked":{"picker","pickers","picking","picks","pick"},
"pig":{"pigs"},
"pigs":{"pig"},
"pigeon":{"pigeons"},
"pigeons":{"pigeon"},
"pile":{"piling","piles","piled"},
"piling":{"piles","piled","pile"},
"piles":{"piling","piled","pile"},
"piled":{"piling","piles","pile"},
"pin":{"pinned","pins","pinning"},
"pins":{"pinned","pin","pinning"},
"pinned":{"pins","pin","pinning"},
"pinning":{"pinned","pins","pin"},
"pinch":{"pinches","pinched","pinching"},
"pinching":{"pinches","pinched","pinch"},
"pinches":{"pinched","pinching","pinch"},
"pinched":{"pinches","pinching","pinch"},
"pink":{"pinker","pinkest","pinkness"},
"pinkness":{"pink","pinker","pinkest"},
"pinkest":{"pink","pinker","pinkness"},
"pinker":{"pink","pinkest","pinkness"},
"pint":{"pints"},
"pints":{"pint"},
"pipe":{"pipes"},
"pipes":{"pipe"},
"pity":{"pities","pitying","pitied"},
"pitying":{"pities","pity","pitied"},
"pities":{"pitying","pity","pitied"},
"pitied":{"pities","pitying","pity"},
"plane":{"planes"},
"planes":{"plane"},
"plaster":{"plastering","plasters","plastered"},
"plasters":{"plastering","plaster","plastered"},
"plastering":{"plasters","plaster","plastered"},
"plastered":{"plastering","plasters","plaster"},
"plate":{"plates"},
"plates":{"plate"},
"plenty":{"plentiful"},
"plentiful":{"plenty"},
"plough":{"ploughing","ploughs","ploughed"},
"ploughs":{"plough","ploughing","ploughed"},
"ploughing":{"plough","ploughs","ploughed"},
"ploughed":{"plough","ploughing","ploughs"},
"plural":{"plurals"},
"plurals":{"plural"},
"pocket":{"pockets"},
"pockets":{"pocket"},
"poem":{"poet","poems","poetry","poetic"},
"poetry":{"poet","poems","poem","poetic"},
"poetic":{"poet","poems","poem","poetry"},
"poet":{"poems","poem","poetry","poetic"},
"poems":{"poet","poem","poetry","poetic"},
"poison":{"poisonous","poisons","poisoning","poisoned"},
"poisons":{"poisonous","poison","poisoning","poisoned"},
"poisonous":{"poisons","poison","poisoning","poisoned"},
"poisoning":{"poisonous","poisons","poison","poisoned"},
"poisoned":{"poisonous","poisons","poison","poisoning"},
"police":{"polices","policewomen","policing","policemen","policed","policeman"},
"policing":{"polices","police","policewomen","policemen","policed","policeman"},
"policewomen":{"polices","police","policing","policemen","policed","policeman"},
"polices":{"police","policewomen","policing","policemen","policed","policeman"},
"policemen":{"polices","police","policewomen","policing","policed","policeman"},
"policeman":{"polices","police","policewomen","policing","policemen","policed"},
"policed":{"polices","police","policewomen","policing","policemen","policeman"},
"polish":{"polished","polishing","polishes"},
"polishing":{"polished","polishes","polish"},
"polishes":{"polished","polishing","polish"},
"polished":{"polishing","polishes","polish"},
"polite":{"politest","politer","politeness"},
"politest":{"polite","politer","politeness"},
"politer":{"politest","polite","politeness"},
"politeness":{"politest","polite","politer"},
"pool":{"pools","pooling"},
"pools":{"pool","pooling"},
"pooling":{"pool","pools"},
"postpone":{"postponing","postpones","postponed"},
"postponing":{"postpone","postpones","postponed"},
"postpones":{"postponing","postpone","postponed"},
"postponed":{"postponing","postpone","postpones"},
"pot":{"potted","pots","potting"},
"potting":{"potted","pot","pots"},
"potted":{"pot","pots","potting"},
"pots":{"potted","pot","potting"},
"pour":{"pours","poured","pouring"},
"pours":{"pour","poured","pouring"},
"pouring":{"pour","pours","poured"},
"poured":{"pour","pours","pouring"},
"powder":{"powders","powdery"},
"powders":{"powdery","powder"},
"powdery":{"powders","powder"},
"practical":{"practically"},
"practically":{"practical"},
"practise":{"practices","practice","practising","practised","practises"},
"practises":{"practices","practice","practising","practised","practise"},
"practised":{"practices","practice","practising","practises","practise"},
"practising":{"practices","practice","practised","practises","practise"},
"practice":{"practices","practising","practised","practises","practise"},
"practices":{"practice","practising","practised","practises","practise"},
"praise":{"praised","praises","praising"},
"praising":{"praised","praises","praise"},
"praises":{"praised","praising","praise"},
"praised":{"praises","praising","praise"},
"pray":{"prayer","praying","prayed","prays","prayers"},
"prays":{"prayer","praying","pray","prayed","prayers"},
"praying":{"prayer","pray","prayed","prays","prayers"},
"prayers":{"prayer","praying","pray","prayed","prays"},
"prayer":{"praying","pray","prayed","prays","prayers"},
"prayed":{"prayer","praying","pray","prays","prayers"},
"preach":{"preachers","preaching","preaches","preacher","preached"},
"preaching":{"preachers","preach","preaches","preacher","preached"},
"preaches":{"preachers","preach","preaching","preacher","preached"},
"preachers":{"preach","preaching","preaches","preacher","preached"},
"preacher":{"preachers","preach","preaching","preaches","preached"},
"preached":{"preachers","preach","preaching","preaches","preacher"},
"prefer":{"preferable","prefers","preferring","preferred","preference","preferences","preferential"},
"prefers":{"preferable","prefer","preferring","preferred","preference","preferences","preferential"},
"preferring":{"preferable","prefer","prefers","preferred","preference","preferences","preferential"},
"preferred":{"preferable","prefer","prefers","preferring","preference","preferences","preferential"},
"preferable":{"prefer","prefers","preferring","preferred","preference","preferences","preferential"},
"preference":{"preferable","prefer","prefers","preferring","preferred","preferences","preferential"},
"preferences":{"preferable","prefer","prefers","preferring","preferred","preference","preferential"},
"preferential":{"preferable","prefer","prefers","preferring","preferred","preference","preferences"},
"prejudice":{"prejudices","unprejudiced","prejudiced"},
"prejudices":{"prejudice","unprejudiced","prejudiced"},
"prejudiced":{"prejudice","prejudices","unprejudiced"},
"preserve":{"preservation","preserving","preserves","preserved"},
"preserved":{"preservation","preserving","preserves","preserve"},
"preserves":{"preservation","preserving","preserved","preserve"},
"preserving":{"preservation","preserves","preserved","preserve"},
"preservation":{"preserving","preserves","preserved","preserve"},
"pretend":{"pretence","pretends","pretending","pretended"},
"pretends":{"pretence","pretend","pretending","pretended"},
"pretending":{"pretence","pretend","pretends","pretended"},
"pretended":{"pretence","pretend","pretends","pretending"},
"pretence":{"pretend","pretends","pretending","pretended"},
"pride":{"prides","proud"},
"prides":{"pride"},
"priest":{"priests"},
"priests":{"priest"},
"print":{"reprinted","reprint","prints","printing","reprinting","reprints","printed","printers"},
"printed":{"print","reprinted","reprint","prints","printing","reprinting","reprints","printers"},
"printers":{"print","reprinted","reprint","prints","printing","reprinting","reprints","printed"},
"printing":{"print","reprinted","reprint","prints","reprinting","reprints","printed","printers"},
"prints":{"print","reprinted","reprint","printing","reprinting","reprints","printed","printers"},
"reprint":{"print","reprinted","prints","printing","reprinting","reprints","printed","printers"},
"reprints":{"print","reprinted","reprint","prints","printing","reprinting","printed","printers"},
"reprinting":{"print","reprinted","reprint","prints","printing","reprints","printed","printers"},
"reprinted":{"print","reprint","prints","printing","reprinting","reprints","printed","printers"},
"prison":{"prisoners","prisons","prisoner"},
"prisons":{"prisoners","prison","prisoner"},
"prisoners":{"prisons","prison","prisoner"},
"prisoner":{"prisoners","prisons","prison"},
"prize":{"prizes","prized"},
"prized":{"prize","prizes"},
"prizes":{"prize","prized"},
"probable":{"probability","probably","probabilities"},
"probably":{"probability","probabilities","probable"},
"probability":{"probably","probabilities","probable"},
"probabilities":{"probability","probably","probable"},
"procession":{"processions"},
"processions":{"procession"},
"profession":{"professions"},
"professions":{"profession"},
"programme":{"programmed","programs","programmes","programing","programed","programming","programme"},
"program":{"programmed","programs","programmes","programing","programed","programming","programme"},
"programed":{"programs","programmes","programing","programed","programming","program","programme"},
"programing":{"programmed","programs","programmes","programed","programming","program","programme"},
"programmed":{"programs","programmes","programing","programed","programming","program","programme"},
"programmes":{"programmed","programs","programing","programed","programming","program","programme"},
"programming":{"programmed","programs","programmes","programing","programed","program","programme"},
"programs":{"programmed","programmes","programing","programed","programming","program","programme"},
"prompt":{"prompts","prompting","prompted","promptly"},
"prompts":{"prompt","prompting","prompted","promptly"},
"promptly":{"prompts","prompt","prompting","prompted"},
"prompting":{"prompts","prompt","prompted","promptly"},
"prompted":{"prompts","prompt","prompting","promptly"},
"pronounce":{"pronounced","pronouncing","pronounces"},
"pronouncing":{"pronounced","pronounce","pronounces"},
"pronounces":{"pronounced","pronounce","pronouncing"},
"pronounced":{"pronounce","pronouncing","pronounces"},
"proud":{"prouder","proudest","proudly"},
"proudly":{"prouder","proudest","proud"},
"proudest":{"prouder","proud","proudly"},
"prouder":{"proudest","proud","proudly"},
"pump":{"pumping","pumps","pumped"},
"pumps":{"pumping","pumped","pump"},
"pumping":{"pumps","pumped","pump"},
"pumped":{"pumping","pumps","pump"},
"punctual":{"punctuality","punctually"},
"punctually":{"punctual","punctuality"},
"punctuality":{"punctual","punctually"},
"punish":{"punished","punishment","punishments","punishes","punishing"},
"punishing":{"punished","punishment","punishments","punishes","punish"},
"punishes":{"punished","punishment","punishments","punish","punishing"},
"punished":{"punishment","punishments","punishes","punish","punishing"},
"punishment":{"punished","punishments","punishes","punish","punishing"},
"punishments":{"punished","punishment","punishes","punish","punishing"},
"pupil":{"pupils"},
"pupils":{"pupil"},
"pure":{"purest","purely","pureness","purer"},
"purest":{"pure","purely","pureness","purer"},
"purer":{"purest","pure","purely","pureness"},
"pureness":{"purest","pure","purely","purer"},
"purely":{"purest","pure","pureness","purer"},
"impure":{"impurity"},
"impurity":{"impure"},
"purple":{"purplish"},
"purplish":{"purple"},
"push":{"pushes","pushed","pushing"},
"pushing":{"pushes","pushed","push"},
"pushes":{"pushed","push","pushing"},
"pushed":{"pushes","push","pushing"},
"puzzle":{"puzzling","puzzles","puzzled"},
"puzzling":{"puzzle","puzzles","puzzled"},
"puzzles":{"puzzling","puzzle","puzzled"},
"puzzled":{"puzzling","puzzle","puzzles"},
"qualify":{"qualifies","qualifications","qualification","qualified","qualifying"},
"qualifying":{"qualifies","qualifications","qualification","qualified","qualify"},
"qualifies":{"qualifications","qualification","qualified","qualifying","qualify"},
"qualified":{"qualifies","qualifications","qualification","qualifying","qualify"},
"qualification":{"qualifies","qualifications","qualified","qualifying","qualify"},
"qualifications":{"qualifies","qualification","qualified","qualifying","qualify"},
"quarrel":{"quarrelled","quarreled","quarreling","quarrelling","quarrels"},
"quarrels":{"quarrelled","quarreled","quarreling","quarrelling","quarrel"},
"quarrelling":{"quarrelled","quarreled","quarreling","quarrels","quarrel"},
"quarrelled":{"quarreled","quarreling","quarrelling","quarrels","quarrel"},
"quarreling":{"quarrelled","quarreled","quarrelling","quarrels","quarrel"},
"quarreled":{"quarrelled","quarreling","quarrelling","quarrels","quarrel"},
"quart":{"quarts"},
"quarts":{"quart"},
"quick":{"quicker","quickly","quickest","quickness"},
"quickness":{"quicker","quick","quickly","quickest"},
"quickly":{"quicker","quick","quickest","quickness"},
"quickest":{"quicker","quick","quickly","quickness"},
"quicker":{"quick","quickly","quickest","quickness"},
"quiet":{"quietly","quietest","quieter","quietness"},
"quieter":{"quietly","quietest","quiet","quietness"},
"quietest":{"quietly","quieter","quiet","quietness"},
"quietly":{"quietest","quieter","quiet","quietness"},
"quietness":{"quietly","quietest","quieter","quiet"},
"rabbit":{"rabbits"},
"rabbits":{"rabbit"},
"radio":{"radioed","radios"},
"radios":{"radio","radioed"},
"radioed":{"radio","radios"},
"rail":{"railroad","railways","railway","rails","railroads"},
"railways":{"railroad","rail","railway","rails","railroads"},
"railway":{"railroad","rail","railways","rails","railroads"},
"rails":{"railroad","rail","railways","railway","railroads"},
"railroads":{"railroad","rail","railways","railway","rails"},
"railroad":{"rail","railways","railway","rails","railroads"},
"rain":{"rained","raindrops","raindrop","raining","rains"},
"rains":{"rained","raindrops","raindrop","raining","rain"},
"raining":{"rained","raindrops","raindrop","rains","rain"},
"rained":{"raindrops","raindrop","raining","rains","rain"},
"raindrops":{"rained","raindrop","raining","rains","rain"},
"raindrop":{"rained","raindrops","raining","rains","rain"},
"rake":{"raking","raked","rakes"},
"raking":{"rake","raked","rakes"},
"rakes":{"rake","raking","raked"},
"raked":{"rake","raking","rakes"},
"rapid":{"rapidity","rapidly"},
"rapidly":{"rapidity","rapid"},
"rapidity":{"rapidly","rapid"},
"rare":{"rareness","rarely","rarest","rarer"},
"rarest":{"rare","rareness","rarely","rarer"},
"rarer":{"rare","rareness","rarely","rarest"},
"rareness":{"rare","rarely","rarest","rarer"},
"rarely":{"rare","rareness","rarest","rarer"},
"rat":{"rats"},
"rats":{"rat"},
"raw":{"rawness","rawest","rawer"},
"rawness":{"raw","rawest","rawer"},
"rawest":{"rawness","raw","rawer"},
"rawer":{"rawness","raw","rawest"},
"ray":{"rays"},
"rays":{"ray"},
"razor":{"razors"},
"razors":{"razor"},
"recommend":{"recommended","recommending","recommends","recommendation","recommendations"},
"recommends":{"recommended","recommend","recommending","recommendation","recommendations"},
"recommending":{"recommended","recommend","recommends","recommendation","recommendations"},
"recommended":{"recommend","recommending","recommends","recommendation","recommendations"},
"recommendation":{"recommended","recommend","recommending","recommends","recommendations"},
"recommendations":{"recommended","recommend","recommending","recommends","recommendation"},
"refer":{"refers","referring","referred"},
"refers":{"referring","referred","refer"},
"referring":{"refers","referred","refer"},
"referred":{"refers","referring","refer"},
"reflect":{"reflective","reflection","reflected","reflecting","reflects","reflections"},
"reflects":{"reflective","reflection","reflected","reflecting","reflections","reflect"},
"reflecting":{"reflective","reflection","reflected","reflects","reflections","reflect"},
"reflected":{"reflective","reflection","reflecting","reflects","reflections","reflect"},
"reflective":{"reflection","reflected","reflecting","reflects","reflections","reflect"},
"reflection":{"reflective","reflected","reflecting","reflects","reflections","reflect"},
"reflections":{"reflective","reflection","reflected","reflecting","reflects","reflect"},
"refresh":{"refreshing","refreshed","refreshment","refreshes"},
"refreshes":{"refreshing","refreshed","refreshment","refresh"},
"refreshing":{"refreshed","refreshment","refreshes","refresh"},
"refreshed":{"refreshing","refreshment","refreshes","refresh"},
"refreshment":{"refreshing","refreshed","refreshes","refresh"},
"regular":{"regularly"},
"irregular":{"irregularly"},
"regularly":{"regular"},
"irregularly":{"irregular"},
"regret":{"regrets","regretted","regretting","regretful"},
"regretting":{"regret","regrets","regretted","regretful"},
"regretful":{"regret","regrets","regretted","regretting"},
"regretted":{"regret","regrets","regretting","regretful"},
"regrets":{"regret","regretted","regretting","regretful"},
"rejoice":{"rejoicing","rejoiced","rejoices"},
"rejoicing":{"rejoice","rejoiced","rejoices"},
"rejoices":{"rejoice","rejoicing","rejoiced"},
"rejoiced":{"rejoice","rejoicing","rejoices"},
"relieve":{"relief","relieved","relieves","relieving"},
"relieving":{"relief","relieved","relieves","relieve"},
"relieves":{"relief","relieved","relieving","relieve"},
"relieved":{"relief","relieves","relieving","relieve"},
"relief":{"relieved","relieves","relieving","relieve"},
"remedy":{"remedies","remedied","remedying"},
"remedying":{"remedies","remedy","remedied"},
"remedies":{"remedy","remedied","remedying"},
"remedied":{"remedies","remedy","remedying"},
"remind":{"reminds","reminded","reminding","reminder"},
"reminds":{"reminded","remind","reminding","reminder"},
"reminding":{"reminds","reminded","remind","reminder"},
"reminded":{"reminds","remind","reminding","reminder"},
"reminder":{"reminds","reminded","remind","reminding"},
"rent":{"renting","rents","rented"},
"renting":{"rents","rent","rented"},
"rented":{"renting","rents","rent"},
"rents":{"renting","rent","rented"},
"repair":{"repairing","repaired","repairs"},
"repairs":{"repairing","repaired","repair"},
"repairing":{"repaired","repair","repairs"},
"repaired":{"repairing","repair","repairs"},
"repeat":{"repeats","repeating","repeated","repeatedly"},
"repeated":{"repeats","repeating","repeat","repeatedly"},
"repeatedly":{"repeats","repeating","repeat","repeated"},
"repeating":{"repeats","repeat","repeated","repeatedly"},
"repeats":{"repeating","repeat","repeated","repeatedly"},
"replace":{"replacing","replaces","replaced","replacement","replacements","replaceable"},
"replacing":{"replace","replaces","replaced","replacement","replacements","replaceable"},
"replaces":{"replace","replacing","replaced","replacement","replacements","replaceable"},
"replaced":{"replace","replacing","replaces","replacement","replacements","replaceable"},
"replacement":{"replace","replacing","replaces","replaced","replacements","replaceable"},
"replacements":{"replace","replacing","replaces","replaced","replacement","replaceable"},
"replaceable":{"replace","replacing","replaces","replaced","replacement","replacements"},
"reproduce":{"reproduces","reproducing","reproduced","reproduction","reproductions"},
"reproduces":{"reproducing","reproduced","reproduction","reproductions","reproduce"},
"reproducing":{"reproduces","reproduced","reproduction","reproductions","reproduce"},
"reproduced":{"reproduces","reproducing","reproduction","reproductions","reproduce"},
"reproduction":{"reproduces","reproducing","reproduced","reproductions","reproduce"},
"reproductions":{"reproduces","reproducing","reproduced","reproduction","reproduce"},
"reputation":{"reputations"},
"reputations":{"reputation"},
"request":{"requested","requesting","requests"},
"requests":{"request","requested","requesting"},
"requesting":{"request","requested","requests"},
"requested":{"request","requesting","requests"},
"rescue":{"rescued","rescues","rescuing"},
"rescuing":{"rescued","rescues","rescue"},
"rescues":{"rescued","rescuing","rescue"},
"rescued":{"rescues","rescuing","rescue"},
"resign":{"resignations","resigns","resigning","resignation","resigned"},
"resigns":{"resignations","resign","resigning","resignation","resigned"},
"resigning":{"resignations","resign","resigns","resignation","resigned"},
"resigned":{"resignations","resign","resigns","resigning","resignation"},
"resignation":{"resignations","resign","resigns","resigning","resigned"},
"resignations":{"resign","resigns","resigning","resignation","resigned"},
"resist":{"resistance","resistible","resisted","resisting","resists"},
"resists":{"resist","resistance","resistible","resisted","resisting"},
"resisting":{"resist","resistance","resistible","resisted","resists"},
"resisted":{"resist","resistance","resistible","resisting","resists"},
"resistible":{"resist","resistance","resisted","resisting","resists"},
"resistance":{"resist","resistible","resisted","resisting","resists"},
"responsible":{"responsibility","responsibilities"},
"responsibility":{"responsible","responsibilities"},
"responsibilities":{"responsible","responsibility"},
"restaurant":{"restaurants"},
"restaurants":{"restaurant"},
"retire":{"retires","retirement","retired","retiring"},
"retiring":{"retires","retirement","retired","retire"},
"retires":{"retirement","retired","retiring","retire"},
"retired":{"retires","retirement","retiring","retire"},
"retirement":{"retires","retired","retiring","retire"},
"revenge":{"revenges"},
"revenges":{"revenge"},
"review":{"reviews","reviewing","reviewed"},
"reviews":{"review","reviewing","reviewed"},
"reviewing":{"reviews","review","reviewed"},
"reviewed":{"reviews","review","reviewing"},
"reward":{"rewarding","rewards","rewarded"},
"rewards":{"rewarding","reward","rewarded"},
"rewarding":{"rewards","reward","rewarded"},
"rewarded":{"rewarding","rewards","reward"},
"ribbon":{"ribbons"},
"ribbons":{"ribbon"},
"rid":{"rids","ridded","ridding"},
"rids":{"rid","ridded","ridding"},
"ridding":{"rid","rids","ridded"},
"ripe":{"riper","ripest","ripeness"},
"ripest":{"riper","ripe","ripeness"},
"riper":{"ripest","ripe","ripeness"},
"ripeness":{"riper","ripest","ripe"},
"risk":{"risking","risky","risked","risks"},
"risks":{"risking","risk","risky","risked"},
"risking":{"risk","risky","risked","risks"},
"risked":{"risking","risk","risky","risks"},
"risky":{"risking","risk","risked","risks"},
"rival":{"rivals","rivalry","rivalling","rivalled","rivalries"},
"rivals":{"rival","rivalry","rivalling","rivalled","rivalries"},
"rivalry":{"rivals","rival","rivalling","rivalled","rivalries"},
"rivalries":{"rivals","rival","rivalry","rivalling","rivalled"},
"rivalling":{"rivals","rival","rivalry","rivalled","rivalries"},
"rivalled":{"rivals","rival","rivalry","rivalling","rivalries"},
"roar":{"roared","roaring","roars"},
"roars":{"roar","roared","roaring"},
"roaring":{"roar","roared","roars"},
"roared":{"roar","roaring","roars"},
"roast":{"roasted","roasts","roasting"},
"roasts":{"roast","roasted","roasting"},
"roasting":{"roast","roasted","roasts"},
"roasted":{"roast","roasts","roasting"},
"rob":{"robbed","robs","robbers","robbing","robber"},
"robs":{"robbed","robbers","robbing","rob","robber"},
"robbing":{"robbed","robs","robbers","rob","robber"},
"robber":{"robbed","robs","robbers","robbing","rob"},
"robbed":{"robs","robbers","robbing","rob","robber"},
"robbers":{"robbed","robs","robbing","rob","robber"},
"rod":{"rods"},
"rods":{"rod"},
"roof":{"roofs"},
"roofs":{"roof"},
"root":{"rooted","roots"},
"roots":{"rooted","root"},
"rooted":{"roots","root"},
"rope":{"ropes"},
"ropes":{"rope"},
"rot":{"rotting","rotted","rots","rotten"},
"rotting":{"rot","rotted","rots","rotten"},
"rotted":{"rot","rotting","rots","rotten"},
"rots":{"rot","rotting","rotted","rotten"},
"rotten":{"rot","rotting","rotted","rots"},
"row":{"rows","rowed","rowing"},
"rows":{"row","rowed","rowing"},
"rowing":{"row","rows","rowed"},
"rowed":{"row","rows","rowing"},
"rub":{"rubbing","rubbed","rubs"},
"rubs":{"rub","rubbing","rubbed"},
"rubbing":{"rub","rubbed","rubs"},
"rubbed":{"rub","rubbing","rubs"},
"rubber":{"rubbers"},
"rubbers":{"rubber"},
"rude":{"rudely","rudeness","ruder","rudest"},
"rudest":{"rudely","rudeness","ruder","rude"},
"ruder":{"rudely","rudeness","rudest","rude"},
"rudeness":{"rudely","ruder","rudest","rude"},
"rudely":{"rudeness","ruder","rudest","rude"},
"rug":{"rugs"},
"rugs":{"rug"},
"ruin":{"ruins","ruining","ruined"},
"ruined":{"ruins","ruining","ruin"},
"ruining":{"ruins","ruined","ruin"},
"ruins":{"ruining","ruined","ruin"},
"rush":{"rushed","rushes","rushing"},
"rushed":{"rushes","rushing","rush"},
"rushes":{"rushed","rushing","rush"},
"rushing":{"rushed","rushes","rush"},
"rust":{"rusting","rusted","rusts","rusty"},
"rusty":{"rusting","rusted","rusts","rust"},
"rusts":{"rusting","rusted","rusty","rust"},
"rusting":{"rusted","rusts","rusty","rust"},
"rusted":{"rusting","rusts","rusty","rust"},
"sacred":{"sacredness"},
"sacredness":{"sacred"},
"sacrifice":{"sacrificed","sacrificing","sacrificial","sacrifices"},
"sacrificing":{"sacrifice","sacrificed","sacrificial","sacrifices"},
"sacrifices":{"sacrifice","sacrificed","sacrificing","sacrificial"},
"sacrificed":{"sacrifice","sacrificing","sacrificial","sacrifices"},
"sacrificial":{"sacrifice","sacrificed","sacrificing","sacrifices"},
"sad":{"sadder","sadness","sadly","saddest","sadden"},
"sadness":{"sadder","sad","sadly","saddest","sadden"},
"sadly":{"sadder","sad","sadness","saddest","sadden"},
"saddest":{"sadder","sad","sadness","sadly","sadden"},
"sadder":{"sad","sadness","sadly","saddest","sadden"},
"sadden":{"sadder","sad","sadness","sadly","saddest"},
"saddle":{"saddled","saddles","saddling"},
"saddling":{"saddled","saddles","saddle"},
"saddles":{"saddled","saddling","saddle"},
"saddled":{"saddles","saddling","saddle"},
"sake":{"sakes"},
"sakes":{"sake"},
"salary":{"salaries"},
"salaries":{"salary"},
"sample":{"samples","sampled","sampling"},
"sampling":{"sample","samples","sampled"},
"samples":{"sample","sampled","sampling"},
"sampled":{"sample","samples","sampling"},
"sand":{"sands","sandy"},
"sandy":{"sand","sands"},
"sands":{"sand","sandy"},
"satisfy":{"satisfied","satisfactory","satisfaction","satisfies","satisfying"},
"satisfying":{"satisfied","satisfy","satisfactory","satisfaction","satisfies"},
"satisfies":{"satisfied","satisfy","satisfactory","satisfaction","satisfying"},
"satisfied":{"satisfy","satisfactory","satisfaction","satisfies","satisfying"},
"satisfactory":{"satisfied","satisfy","satisfaction","satisfies","satisfying"},
"satisfaction":{"satisfied","satisfy","satisfactory","satisfies","satisfying"},
"dissatisfaction":{"dissatisfying","dissatisfies","dissatisfy","dissatisfied"},
"dissatisfying":{"dissatisfaction","dissatisfies","dissatisfy","dissatisfied"},
"dissatisfy":{"dissatisfying","dissatisfaction","dissatisfies","dissatisfied"},
"dissatisfies":{"dissatisfying","dissatisfaction","dissatisfy","dissatisfied"},
"dissatisfied":{"dissatisfying","dissatisfaction","dissatisfies","dissatisfy"},
"sauce":{"sauces"},
"sauces":{"sauce"},
"saucer":{"saucers"},
"saucers":{"saucer"},
"saws":{"sawing","sawed"},
"sawing":{"sawed","saws"},
"sawed":{"sawing","saws"},
"scale":{"scales"},
"scales":{"scale"},
"scatter":{"scatters","scattering","scattered"},
"scatters":{"scattering","scattered","scatter"},
"scattering":{"scatters","scattered","scatter"},
"scattered":{"scatters","scattering","scatter"},
"scent":{"scents","scenting","scented"},
"scents":{"scent","scenting","scented"},
"scenting":{"scent","scents","scented"},
"scented":{"scent","scents","scenting"},
"scold":{"scolded","scolding","scolds"},
"scolds":{"scolded","scolding","scold"},
"scolding":{"scolded","scolds","scold"},
"scolded":{"scolding","scolds","scold"},
"scorn":{"scorning","scornfully","scornful","scorned","scorns"},
"scorns":{"scorning","scornfully","scornful","scorned","scorn"},
"scorning":{"scornfully","scornful","scorned","scorns","scorn"},
"scorned":{"scorning","scornfully","scornful","scorns","scorn"},
"scornful":{"scorning","scornfully","scorned","scorns","scorn"},
"scornfully":{"scorning","scornful","scorned","scorns","scorn"},
"scrape":{"scrapes","scraped","scraping"},
"scraping":{"scrapes","scraped","scrape"},
"scrapes":{"scraped","scraping","scrape"},
"scraped":{"scrapes","scraping","scrape"},
"scratch":{"scratched","scratches","scratching"},
"scratching":{"scratched","scratches","scratch"},
"scratches":{"scratched","scratching","scratch"},
"scratched":{"scratches","scratching","scratch"},
"screen":{"screened","screening","screens"},
"screens":{"screened","screening","screen"},
"screening":{"screened","screen","screens"},
"screened":{"screening","screen","screens"},
"screw":{"screwed","screws","screwing"},
"screws":{"screwed","screw","screwing"},
"screwing":{"screwed","screw","screws"},
"screwed":{"screw","screws","screwing"},
"search":{"searched","searches","searching"},
"searching":{"searched","searches","search"},
"searches":{"searched","search","searching"},
"searched":{"searches","search","searching"},
"seed":{"seedling","seeded","seeding","seeds"},
"seeds":{"seed","seedling","seeded","seeding"},
"seeding":{"seed","seedling","seeded","seeds"},
"seeded":{"seed","seedling","seeding","seeds"},
"seedling":{"seed","seeded","seeding","seeds"},
"seize":{"seizes","seized","seizing"},
"seized":{"seizes","seize","seizing"},
"seizes":{"seized","seize","seizing"},
"seizing":{"seizes","seized","seize"},
"self":{"selfishness","selfishly","selfish","selves"},
"selfishness":{"self","selfishly","selfish","selves"},
"selfishly":{"selfishness","self","selfish","selves"},
"selfish":{"selfishness","self","selfishly","selves"},
"selves":{"selfishness","self","selfishly","selfish"},
"sentence":{"sentences"},
"sentences":{"sentence"},
"severe":{"severeness","severely","severer","severest","severity"},
"severity":{"severe","severeness","severely","severer","severest"},
"severest":{"severe","severeness","severely","severer","severity"},
"severer":{"severe","severeness","severely","severest","severity"},
"severeness":{"severe","severely","severer","severest","severity"},
"severely":{"severe","severeness","severer","severest","severity"},
"sew":{"sewing","sewed","sews","sewn"},
"sews":{"sewing","sewed","sew","sewn"},
"sewn":{"sewing","sewed","sew","sews"},
"sewing":{"sewed","sew","sews","sewn"},
"sewed":{"sewing","sew","sews","sewn"},
"shade":{"shaded","shades","shading","shadings"},
"shadings":{"shade","shaded","shades","shading"},
"shading":{"shade","shaded","shades","shadings"},
"shades":{"shade","shaded","shading","shadings"},
"shaded":{"shade","shades","shading","shadings"},
"shallow":{"shallowest","shallowness","shallower"},
"shallowness":{"shallowest","shallow","shallower"},
"shallowest":{"shallowness","shallow","shallower"},
"shallower":{"shallowest","shallowness","shallow"},
"shame":{"shaming","shames","shameful","shamefully","shamed"},
"shaming":{"shame","shames","shameful","shamefully","shamed"},
"shames":{"shame","shaming","shameful","shamefully","shamed"},
"shameful":{"shame","shaming","shames","shamefully","shamed"},
"shamefully":{"shame","shaming","shames","shameful","shamed"},
"shamed":{"shame","shaming","shames","shameful","shamefully"},
"sharp":{"sharpens","sharpen","sharpened","sharpening","sharper","sharpest","sharply","sharpness"},
"sharpness":{"sharp","sharpens","sharpen","sharpened","sharpening","sharper","sharpest","sharply"},
"sharply":{"sharp","sharpens","sharpen","sharpened","sharpening","sharper","sharpest","sharpness"},
"sharpest":{"sharp","sharpens","sharpen","sharpened","sharpening","sharper","sharply","sharpness"},
"sharper":{"sharp","sharpens","sharpen","sharpened","sharpening","sharpest","sharply","sharpness"},
"sharpens":{"sharp","sharpen","sharpened","sharpening","sharper","sharpest","sharply","sharpness"},
"sharpening":{"sharp","sharpens","sharpen","sharpened","sharper","sharpest","sharply","sharpness"},
"sharpened":{"sharp","sharpens","sharpen","sharpening","sharper","sharpest","sharply","sharpness"},
"sharpen":{"sharp","sharpens","sharpened","sharpening","sharper","sharpest","sharply","sharpness"},
"shave":{"shaves","shaving","shaved"},
"shaved":{"shaves","shaving","shave"},
"shaving":{"shaves","shaved","shave"},
"shaves":{"shaving","shaved","shave"},
"sheet":{"sheets"},
"sheets":{"sheet"},
"shelf":{"shelves"},
"shelves":{"shelf"},
"shell":{"shelled","shelling","shells"},
"shells":{"shelled","shell","shelling"},
"shelling":{"shelled","shell","shells"},
"shelled":{"shell","shelling","shells"},
"shelter":{"sheltering","shelters","sheltered"},
"shelters":{"sheltering","shelter","sheltered"},
"sheltering":{"shelter","shelters","sheltered"},
"sheltered":{"sheltering","shelter","shelters"},
"shield":{"shielding","shielded","shields"},
"shields":{"shielding","shield","shielded"},
"shielding":{"shield","shielded","shields"},
"shielded":{"shielding","shield","shields"},
"shilling":{"shillings"},
"shillings":{"shilling"},
"shirt":{"shirts"},
"shirts":{"shirt"},
"shock":{"shocking","shocks","shocked"},
"shocks":{"shock","shocking","shocked"},
"shocking":{"shock","shocks","shocked"},
"shocked":{"shock","shocking","shocks"},
"shoe":{"shoes","shoeing","shoed"},
"shoeing":{"shoes","shoe","shoed"},
"shoes":{"shoeing","shoe","shoed"},
"shop":{"shopping","shoppers","shopper","shopped","shops"},
"shops":{"shop","shopping","shoppers","shopper","shopped"},
"shopping":{"shop","shoppers","shopper","shopped","shops"},
"shoppers":{"shop","shopping","shopper","shopped","shops"},
"shopper":{"shop","shopping","shoppers","shopped","shops"},
"shopped":{"shop","shopping","shoppers","shopper","shops"},
"shout":{"shouted","shouts","shouting"},
"shouted":{"shout","shouts","shouting"},
"shouting":{"shout","shouted","shouts"},
"shouts":{"shout","shouted","shouting"},
"shower":{"showered","showering","showers"},
"showers":{"showered","showering","shower"},
"showering":{"showered","showers","shower"},
"showered":{"showering","showers","shower"},
"shut":{"shuts","shutting"},
"shutting":{"shut","shuts"},
"shuts":{"shut","shutting"},
"sick":{"sicker","sickness","sickly","sickest"},
"sickness":{"sicker","sick","sickly","sickest"},
"sickly":{"sicker","sick","sickness","sickest"},
"sickest":{"sicker","sick","sickness","sickly"},
"sicker":{"sick","sickness","sickly","sickest"},
"signal":{"signalled","signals","signalling"},
"signals":{"signalled","signal","signalling"},
"signalling":{"signalled","signal","signals"},
"signalled":{"signal","signals","signalling"},
"silk":{"silks"},
"silks":{"silk"},
"sincere":{"sincerity","sincerely"},
"sincerely":{"sincere","sincerity"},
"sincerity":{"sincere","sincerely"},
"sink":{"sinking","sinks","sunk","sank"},
"sunk":{"sinking","sinks","sink","sank"},
"sinks":{"sinking","sunk","sink","sank"},
"sinking":{"sinks","sunk","sink","sank"},
"sank":{"sinking","sinks","sunk","sink"},
"skill":{"skilled","skilfully","skills","skilful"},
"skilled":{"skilfully","skill","skills","skilful"},
"skills":{"skilled","skilfully","skill","skilful"},
"skilfully":{"skilled","skill","skills","skilful"},
"skin":{"skins","skinning","skinned"},
"skins":{"skin","skinning","skinned"},
"skinning":{"skin","skins","skinned"},
"skinned":{"skin","skins","skinning"},
"skirt":{"skirts"},
"skirts":{"skirt"},
"slave":{"slaves","slavery"},
"slaves":{"slave","slavery"},
"slavery":{"slave","slaves"},
"slide":{"slid","sliding","slides"},
"sliding":{"slid","slide","slides"},
"slides":{"slid","slide","sliding"},
"slid":{"slide","sliding","slides"},
"slight":{"slighted","slights","slightly","slighting","slightest","slighter"},
"slighted":{"slights","slightly","slighting","slightest","slighter","slight"},
"slighter":{"slighted","slights","slightly","slighting","slightest","slight"},
"slightest":{"slighted","slights","slightly","slighting","slighter","slight"},
"slighting":{"slighted","slights","slightly","slightest","slighter","slight"},
"slightly":{"slighted","slights","slighting","slightest","slighter","slight"},
"slights":{"slighted","slightly","slighting","slightest","slighter","slight"},
"slow":{"slows","slowly","slowest","slowed","slowing","slower"},
"slowed":{"slows","slowly","slowest","slow","slowing","slower"},
"slower":{"slows","slowly","slowest","slow","slowed","slowing"},
"slowest":{"slows","slowly","slow","slowed","slowing","slower"},
"slowing":{"slows","slowly","slowest","slow","slowed","slower"},
"slowly":{"slows","slowest","slow","slowed","slowing","slower"},
"slows":{"slowly","slowest","slow","slowed","slowing","slower"},
"slip":{"slipping","slips","slipped"},
"slips":{"slipping","slips","slipped"},
"slipping":{"slip","slips","slipped"},
"slipped":{"slipping","slip","slips"},
"slope":{"sloping","sloped","slopes"},
"sloping":{"sloped","slope","slopes"},
"slopes":{"sloping","sloped","slope"},
"sloped":{"sloping","slope","slopes"},
"smell":{"smelt","smells","smelling","smelled"},
"smelt":{"smell","smells","smelling","smelled"},
"smells":{"smell","smelt","smelling","smelled"},
"smelling":{"smell","smelt","smells","smelled"},
"smelled":{"smell","smelt","smells","smelling"},
"smoke":{"smoked","smokes","smoking","smokers"},
"smoking":{"smoked","smokes","smoke","smokers"},
"smokes":{"smoked","smoking","smoke","smokers"},
"smokers":{"smoked","smokes","smoking","smoke"},
"smoked":{"smokes","smoking","smoke","smokers"},
"smooth":{"smoothed","smoothing","smoothly","smooths"},
"smooths":{"smoothed","smoothing","smoothly","smooth"},
"smoothly":{"smoothed","smoothing","smooths","smooth"},
"smoothing":{"smoothed","smoothly","smooths","smooth"},
"smoothed":{"smoothing","smoothly","smooths","smooth"},
"snake":{"snakes"},
"snakes":{"snake"},
"soap":{"soaps"},
"soaps":{"soap"},
"sock":{"socks"},
"socks":{"sock"},
"soil":{"soiled","soiling","soils"},
"soiled":{"soil","soiling","soils"},
"soiling":{"soiled","soil","soils"},
"soils":{"soiled","soil","soiling"},
"solemn":{"solemnly"},
"solemnly":{"solemn"},
"solid":{"solidly","solids","solidify"},
"solidify":{"solid","solidly","solids"},
"solidly":{"solid","solids","solidify"},
"solids":{"solid","solidly","solidify"},
"solve":{"solutions","solution","solved","solves","solving"},
"solving":{"solutions","solution","solved","solves","solve"},
"solves":{"solutions","solution","solved","solving","solve"},
"solved":{"solutions","solution","solves","solving","solve"},
"solution":{"solutions","solved","solves","solving","solve"},
"solutions":{"solution","solved","solves","solving","solve"},
"sore":{"sores"},
"sores":{"sore"},
"sorry":{"sorrier","sorriness","sorriest"},
"sorriness":{"sorrier","sorry","sorriest"},
"sorriest":{"sorrier","sorry","sorriness"},
"sorrier":{"sorry","sorriness","sorriest"},
"soup":{"soups"},
"soups":{"soup"},
"sour":{"soured","souring","sourly","sours"},
"sours":{"soured","souring","sourly","sour"},
"sourly":{"soured","souring","sour","sours"},
"souring":{"soured","sourly","sour","sours"},
"soured":{"souring","sourly","sour","sours"},
"sow":{"sows","sowing","sowed"},
"sows":{"sowing","sow","sowed"},
"sowing":{"sows","sow","sowed"},
"sowed":{"sows","sowing","sow"},
"spade":{"spades"},
"spades":{"spade"},
"spare":{"spares","spared","sparing"},
"sparing":{"spare","spares","spared"},
"spares":{"spare","spared","sparing"},
"spared":{"spare","spares","sparing"},
"spell":{"spelled","spells","spelling","spelt","misspelt"},
"spelt":{"spelled","spells","spelling","spell","misspelt"},
"spells":{"spelled","spelling","spelt","spell","misspelt"},
"spelling":{"spelled","spells","spelt","spell","misspelt"},
"spelled":{"spells","spelling","spelt","spell","misspelt"},
"spill":{"spilled","spills","spilling"},
"spills":{"spilled","spill","spilling"},
"spilling":{"spilled","spills","spill"},
"spilled":{"spills","spill","spilling"},
"spin":{"spinning","spins","spun"},
"spun":{"spinning","spins","spin"},
"spins":{"spinning","spin","spun"},
"spinning":{"spins","spin","spun"},
"spit":{"spitting","spits","spat"},
"spits":{"spitting","spit","spat"},
"spitting":{"spit","spits","spat"},
"spat":{"spitting","spit","spits"},
"splendid":{"splendidly"},
"splendidly":{"splendid"},
"split":{"splitting","splits"},
"splitting":{"split","splits"},
"splits":{"split","splitting"},
"spoil":{"spoiled","spoils","spoiling"},
"spoils":{"spoiled","spoil","spoiling"},
"spoiling":{"spoiled","spoil","spoils"},
"spoiled":{"spoil","spoils","spoiling"},
"spoon":{"spoonful","spoons"},
"spoons":{"spoonful","spoon"},
"spoonful":{"spoons","spoon"},
"sport":{"sporting","sports"},
"sporting":{"sport","sports"},
"sports":{"sporting","sport"},
"staff":{"staffs"},
"staffs":{"staff"},
"stain":{"stained","stains","staining"},
"stains":{"stained","stain","staining"},
"staining":{"stained","stains","stain"},
"stained":{"stains","stain","staining"},
"stairs":{"downstairs","upstairs"},
"upstairs":{"downstairs","stairs"},
"downstairs":{"stairs","upstairs"},
"stamp":{"stamping","stamped","stamps"},
"stamps":{"stamping","stamped","stamp"},
"stamping":{"stamped","stamp","stamps"},
"stamped":{"stamping","stamp","stamps"},
"steady":{"steadied","unsteady","steadying","steadily","steadies"},
"unsteady":{"unsteadily"},
"unsteadily":{"unsteady"},
"steadying":{"steadied","steady","unsteady","steadily","steadies"},
"steadily":{"steadied","steady","steadying","steadies"},
"steadies":{"steadied","steady","steadying","steadily"},
"steadied":{"steady","steadying","steadily","steadies"},
"steal":{"stealing","steals","stolen","stole"},
"stole":{"stealing","steals","stolen","steal"},
"stolen":{"stealing","steals","stole","steal"},
"steals":{"stealing","stolen","stole","steal"},
"stealing":{"steals","stolen","stole","steal"},
"steam":{"steams","steaming","steamed"},
"steams":{"steam","steaming","steamed"},
"steaming":{"steam","steams","steamed"},
"steamed":{"steam","steams","steaming"},
"steep":{"steepness","steepest","steeper"},
"steepness":{"steep","steepest","steeper"},
"steepest":{"steep","steepness","steeper"},
"steeper":{"steep","steepness","steepest"},
"steer":{"steering","steered","steers"},
"steers":{"steering","steered","steer"},
"steering":{"steered","steers","steer"},
"steered":{"steering","steers","steer"},
"stem":{"stems","stemmed"},
"stems":{"stem","stemmed"},
"stemmed":{"stem","stems"},
"stick":{"sticks","stuck","sticking"},
"sticking":{"sticks","stuck","stick"},
"sticks":{"stuck","stick","sticking"},
"stuck":{"sticks","stick","sticking"},
"stiff":{"stiffer","stiffest","stiffens","stiffening","stiffened","stiffen","stiffness"},
"stiffness":{"stiffer","stiffest","stiff","stiffens","stiffening","stiffened","stiffen"},
"stiffest":{"stiffer","stiff","stiffens","stiffening","stiffened","stiffen","stiffness"},
"stiffer":{"stiffest","stiff","stiffens","stiffening","stiffened","stiffen","stiffness"},
"stiffens":{"stiffer","stiffest","stiff","stiffening","stiffened","stiffen","stiffness"},
"stiffening":{"stiffer","stiffest","stiff","stiffens","stiffened","stiffen","stiffness"},
"stiffened":{"stiffer","stiffest","stiff","stiffens","stiffening","stiffen","stiffness"},
"stiffen":{"stiffer","stiffest","stiff","stiffens","stiffening","stiffened","stiffness"},
"sting":{"stung","stings","stinging"},
"stung":{"sting","stings","stinging"},
"stings":{"sting","stung","stinging"},
"stinging":{"sting","stung","stings"},
"stir":{"stirring","stirs","stirred"},
"stirs":{"stirring","stir","stirred"},
"stirring":{"stirs","stir","stirred"},
"stirred":{"stirring","stirs","stir"},
"stocking":{"stockings"},
"stockings":{"stocking"},
"stomach":{"stomachs"},
"stomachs":{"stomach"},
"storm":{"storms","storming","stormed"},
"stormed":{"storms","storming","storm"},
"storming":{"storms","stormed","storm"},
"storms":{"storming","stormed","storm"},
"stove":{"stoves"},
"stoves":{"stove"},
"straight":{"straightening","straightens","straightened","straighter","straightest"},
"straightened":{"straightening","straightens","straight","straighter","straightest"},
"straightening":{"straightens","straight","straightened","straighter","straightest"},
"straightens":{"straightening","straight","straightened","straighter","straightest"},
"straighter":{"straightening","straightens","straight","straightened","straightest"},
"straightest":{"straightening","straightens","straight","straightened","straighter"},
"strap":{"straps","strapping","strapped"},
"straps":{"strap","strapping","strapped"},
"strapping":{"strap","straps","strapped"},
"strapped":{"strap","straps","strapping"},
"straw":{"straws"},
"straws":{"straw"},
"stretch":{"stretching","stretches","stretched"},
"stretched":{"stretching","stretches","stretch"},
"stretches":{"stretching","stretched","stretch"},
"stretching":{"stretches","stretched","stretch"},
"strict":{"strictness","strictest","strictly","stricter"},
"strictness":{"strictest","strictly","stricter","strict"},
"strictly":{"strictness","strictest","stricter","strict"},
"strictest":{"strictness","strictly","stricter","strict"},
"stricter":{"strictness","strictest","strictly","strict"},
"string":{"strings","stringing","stringed"},
"strings":{"string","stringing","stringed"},
"stringing":{"string","strings","stringed"},
"stringed":{"string","strings","stringing"},
"strip":{"strips","stripped","stripping"},
"strips":{"strip","stripped","stripping"},
"stripped":{"strip","strips","stripping"},
"stripping":{"strip","strips","stripped"},
"stripe":{"striping","stripes","striped"},
"stripes":{"striping","stripe","striped"},
"striped":{"striping","stripes","stripe"},
"striping":{"stripes","stripe","striped"},
"stuff":{"stuffs","stuffing","stuffed"},
"stuffs":{"stuff","stuffing","stuffed"},
"stuffing":{"stuff","stuffs","stuffed"},
"stuffed":{"stuff","stuffs","stuffing"},
"stupid":{"stupidest","stupider","stupidly","stupidity"},
"stupidity":{"stupid","stupidest","stupider","stupidly"},
"stupidly":{"stupid","stupidest","stupider","stupidity"},
"stupidest":{"stupid","stupider","stupidly","stupidity"},
"stupider":{"stupid","stupidest","stupidly","stupidity"},
"suck":{"sucking","sucked","sucks"},
"sucks":{"sucking","sucked","suck"},
"sucking":{"sucked","sucks","suck"},
"sucked":{"sucking","sucks","suck"},
"sudden":{"suddenness","suddenly"},
"suddenly":{"suddenness","sudden"},
"suddenness":{"suddenly","sudden"},
"sugar":{"sugars","sugary"},
"sugars":{"sugar","sugary"},
"sugary":{"sugars","sugary"},
"suit":{"suited","suitable","suitability","suiting","suits"},
"suits":{"suited","suitable","suitability","suiting","suit"},
"suiting":{"suited","suitable","suitability","suits","suit"},
"suited":{"suitable","suitability","suiting","suits","suit"},
"suitability":{"suited","suitable","suiting","suits","suit"},
"suitable":{"suited","suitability","suiting","suits","suit"},
"supper":{"suppers"},
"suppers":{"supper"},
"suspect":{"suspects","suspecting","suspected","unsuspecting"},
"suspects":{"suspecting","suspected","unsuspecting","suspect"},
"suspecting":{"suspects","suspected","suspect"},
"suspected":{"suspects","suspecting","suspect"},
"suspicion":{"suspicious","suspicions","suspiciously"},
"suspicions":{"suspicious","suspiciously","suspicion"},
"suspicious":{"suspicions","suspiciously","suspicion"},
"suspiciously":{"suspicious","suspicions","suspicion"},
"swallow":{"swallowing","swallows","swallowed"},
"swallows":{"swallowing","swallow","swallowed"},
"swallowing":{"swallow","swallows","swallowed"},
"swallowed":{"swallowing","swallow","swallows"},
"swear":{"swears","swore","sworn","swearing"},
"sworn":{"swears","swore","swear","swearing"},
"swore":{"swears","sworn","swear","swearing"},
"swears":{"swore","sworn","swear","swearing"},
"swearing":{"swears","swore","sworn","swear"},
"sweat":{"sweats","sweating","sweated"},
"sweats":{"sweat","sweating","sweated"},
"sweating":{"sweat","sweats","sweated"},
"sweep":{"sweeping","sweeps","swept"},
"swept":{"sweeping","sweeps","sweep"},
"sweeps":{"sweeping","swept","sweep"},
"sweeping":{"sweeps","swept","sweep"},
"swell":{"swollen","swells","swelling","swelled"},
"swollen":{"swell","swells","swelling","swelled"},
"swells":{"swell","swollen","swelling","swelled"},
"swelling":{"swell","swollen","swells","swelled"},
"swelled":{"swell","swollen","swells","swelling"},
"swim":{"swam","swimming","swims","swum"},
"swum":{"swam","swimming","swims","swim"},
"swims":{"swam","swimming","swum","swim"},
"swimming":{"swam","swims","swum","swim"},
"swam":{"swimming","swims","swum","swim"},
"swing":{"swung","swings","swinging"},
"swung":{"swing","swings","swinging"},
"swings":{"swing","swung","swinging"},
"swinging":{"swing","swung","swings"},
"sympathy":{"sympathetically","sympathetic","sympathies"},
"sympathies":{"sympathetically","sympathetic","sympathy"},
"sympathetic":{"sympathetically","sympathies","sympathy"},
"sympathetically":{"sympathetic","sympathies","sympathy"},
"tail":{"tails"},
"tails":{"tail"},
"tailor":{"tailored","tailoring","tailors"},
"tailors":{"tailored","tailoring","tailor"},
"tailoring":{"tailored","tailors","tailor"},
"tailored":{"tailoring","tailors","tailor"},
"tall":{"tallest","taller"},
"tallest":{"tall","taller"},
"taller":{"tall","tallest"},
"tame":{"tamed","tames","taming"},
"taming":{"tamed","tames","tame"},
"tames":{"tamed","taming","tame"},
"tamed":{"tames","taming","tame"},
"tap":{"taps","tapping","tapped"},
"taps":{"tap","tapping","tapped"},
"tapping":{"tap","taps","tapped"},
"tapped":{"tap","taps","tapping"},
"taste":{"tasting","tastes","tasted"},
"tasted":{"tasting","tastes","taste"},
"tastes":{"tasting","tasted","taste"},
"tasting":{"tastes","tasted","taste"},
"taxi":{"taxis"},
"taxis":{"taxi"},
"tea":{"teas"},
"teas":{"tea"},
"telegraph":{"telegraphed","telegraphing","telegraphs"},
"telegraphs":{"telegraphed","telegraphing","telegraph"},
"telegraphing":{"telegraphed","telegraphs","telegraph"},
"telegraphed":{"telegraphing","telegraphs","telegraph"},
"telephone":{"phone","phoned","phoning","phones","telephoned","telephones","telephoning"},
"telephoning":{"phone","phoned","phoning","phones","telephoned","telephones","telephone"},
"telephones":{"phone","phoned","phoning","phones","telephoned","telephoning","telephone"},
"telephoned":{"phone","phoned","phoning","phones","telephones","telephoning","telephone"},
"phones":{"phone","phoned","phoning","telephoned","telephones","telephoning","telephone"},
"phoning":{"phone","phoned","phones","telephoned","telephones","telephoning","telephone"},
"phoned":{"phone","phoning","phones","telephoned","telephones","telephoning","telephone"},
"phone":{"phoned","phoning","phones","telephoned","telephones","telephoning","telephone"},
"temper":{"tempers"},
"tempers":{"temper"},
"temperature":{"temperatures"},
"temperatures":{"temperature"},
"tempt":{"tempts","tempting","tempted"},
"tempts":{"tempt","tempting","tempted"},
"tempting":{"tempt","tempts","tempted"},
"tempted":{"tempt","tempts","tempting"},
"tend":{"tendencies","tendency","tended","tends"},
"tends":{"tendencies","tendency","tended","tend"},
"tended":{"tendencies","tendency","tends","tend"},
"tendency":{"tendencies","tended","tends","tend"},
"tendencies":{"tendency","tended","tends","tend"},
"tender":{"tenderness","tenderly"},
"tenderness":{"tender","tenderly"},
"tenderly":{"tender","tenderness"},
"tent":{"tents"},
"tents":{"tent"},
"terrible":{"terribly"},
"terribly":{"terrible"},
"thank":{"thanked","thankful","thankfully","thanking","thanks"},
"thanks":{"thanked","thankful","thankfully","thanking","thank"},
"thanking":{"thanked","thankful","thankfully","thanks","thank"},
"thankfully":{"thanked","thankful","thanking","thanks","thank"},
"thankful":{"thanked","thankfully","thanking","thanks","thank"},
"thanked":{"thankful","thankfully","thanking","thanks","thank"},
"theatre":{"theatres","theatrical"},
"theatres":{"theatre","theatrical"},
"theatrical":{"theatre","theatres"},
"thick":{"thicker","thickest","thickly","thickness"},
"thickness":{"thicker","thickest","thickly","thick"},
"thickly":{"thicker","thickest","thickness","thick"},
"thickest":{"thicker","thickly","thickness","thick"},
"thicker":{"thickest","thickly","thickness","thick"},
"thief":{"thieves"},
"thieves":{"thief"},
"thin":{"thinly","thinned","thinner","thinness","thinnest","thinning","thins"},
"thins":{"thinly","thinned","thinner","thinness","thinnest","thinning","thin"},
"thinning":{"thinly","thinned","thinner","thinness","thinnest","thins","thin"},
"thinnest":{"thinly","thinned","thinner","thinness","thinning","thins","thin"},
"thinness":{"thinly","thinned","thinner","thinnest","thinning","thins","thin"},
"thinner":{"thinly","thinned","thinness","thinnest","thinning","thins","thin"},
"thinned":{"thinly","thinner","thinness","thinnest","thinning","thins","thin"},
"thinly":{"thinned","thinner","thinness","thinnest","thinning","thins","thin"},
"thirst":{"thirsts"},
"thirsts":{"thirst"},
"thorn":{"thorns"},
"thorns":{"thorn"},
"thorough":{"thoroughly","thoroughness"},
"thoroughness":{"thoroughly","thorough"},
"thoroughly":{"thoroughness","thorough"},
"thread":{"threads","threading","threaded"},
"threads":{"thread","threading","threaded"},
"threading":{"thread","threads","threaded"},
"threaded":{"thread","threads","threading"},
"threat":{"threaten","threatened","threatening","threatens","threats"},
"threats":{"threaten","threatened","threatening","threatens","threat"},
"threatens":{"threaten","threatened","threatening","threats","threat"},
"threatening":{"threaten","threatened","threatens","threats","threat"},
"threatened":{"threaten","threatening","threatens","threats","threat"},
"threaten":{"threatened","threatening","threatens","threats","threat"},
"throat":{"throats"},
"throats":{"throat"},
"thumb":{"thumbs"},
"thumbs":{"thumb"},
"thunder":{"thunders","thundering","thundered"},
"thunders":{"thunder","thundering","thundered"},
"thundering":{"thunder","thunders","thundered"},
"thundered":{"thunder","thunders","thundering"},
"ticket":{"tickets"},
"tickets":{"ticket"},
"tide":{"tides","tidal"},
"tides":{"tide","tidal"},
"tidal":{"tide","tides"},
"tidy":{"tidied","tidies","tidying"},
"tidying":{"tidied","tidies","tidy"},
"tidies":{"tidied","tidying","tidy"},
"tidied":{"tidies","tidying","tidy"},
"tie":{"tied","ties","tying"},
"untied":{"untie"},
"untie":{"untied"},
"tying":{"tied","ties","tie"},
"ties":{"tied","tying","tie"},
"tied":{"ties","tying","tie"},
"tight":{"tighten","tightened","tightening","tightens","tightly","tighter","tightest","tightness"},
"tightness":{"tighten","tightened","tightening","tightens","tightly","tighter","tightest","tight"},
"tightest":{"tighten","tightened","tightening","tightens","tightly","tighter","tightness","tight"},
"tighter":{"tighten","tightened","tightening","tightens","tightly","tightest","tightness","tight"},
"tightly":{"tighten","tightened","tightening","tightens","tighter","tightest","tightness","tight"},
"tightens":{"tighten","tightened","tightening","tightly","tighter","tightest","tightness","tight"},
"tightening":{"tighten","tightened","tightens","tightly","tighter","tightest","tightness","tight"},
"tightened":{"tighten","tightening","tightens","tightly","tighter","tightest","tightness","tight"},
"tighten":{"tightened","tightening","tightens","tightly","tighter","tightest","tightness","tight"},
"tin":{"tins"},
"tins":{"tin"},
"tip":{"tipped","tipping","tips"},
"tips":{"tipped","tipping","tip"},
"tipping":{"tipped","tips","tip"},
"tipped":{"tipping","tips","tip"},
"tire":{"tiring","tires","tired"},
"tiring":{"tire","tires","tired"},
"tires":{"tire","tiring","tired"},
"tired":{"tire","tiring","tires"},
"title":{"titles","titled"},
"titled":{"titles","title"},
"titles":{"titled","title"},
"tobacco":{"tobaccos"},
"tobaccos":{"tobacco"},
"toe":{"toes"},
"toes":{"toe"},
"tongue":{"tongues"},
"tongues":{"tongue"},
"tool":{"tools"},
"tools":{"tool"},
"tooth":{"teeth"},
"teeth":{"tooth"},
"tough":{"toughness","toughest","tougher"},
"toughness":{"tough","toughest","tougher"},
"toughest":{"tough","toughness","tougher"},
"tougher":{"tough","toughness","toughest"},
"tour":{"tourists","tourist","toured","touring","tours"},
"tours":{"tourists","tourist","toured","touring","tour"},
"touring":{"tourists","tourist","toured","tours","tour"},
"toured":{"tourists","tourist","touring","tours","tour"},
"tourist":{"tourists","toured","touring","tours","tour"},
"tourists":{"tourist","toured","touring","tours","tour"},
"towel":{"towels"},
"towels":{"towel"},
"tower":{"towering","towers"},
"towers":{"towering","tower"},
"towering":{"towers","tower"},
"toy":{"toys"},
"toys":{"toy"},
"track":{"tracked","tracking","tracks"},
"tracks":{"tracked","tracking","track"},
"tracking":{"tracked","tracks","track"},
"tracked":{"tracking","tracks","track"},
"translate":{"translations","translation","translated","translates","translating"},
"translating":{"translations","translation","translated","translates","translate"},
"translates":{"translations","translation","translated","translating","translate"},
"translated":{"translations","translation","translates","translating","translate"},
"translation":{"translations","translated","translates","translating","translate"},
"translations":{"translation","translated","translates","translating","translate"},
"trap":{"trapped","trapping","traps"},
"traps":{"trapped","trapping","trap"},
"trapping":{"trapped","traps","trap"},
"trapped":{"trapping","traps","trap"},
"tray":{"trays"},
"trays":{"tray"},
"treasure":{"treasurer","treasury","treasured","treasures","treasuring"},
"treasuring":{"treasurer","treasury","treasured","treasures","treasure"},
"treasures":{"treasurer","treasury","treasured","treasuring","treasure"},
"treasured":{"treasurer","treasury","treasures","treasuring","treasure"},
"treasury":{"treasurer","treasured","treasures","treasuring","treasure"},
"treasurer":{"treasury","treasured","treasures","treasuring","treasure"},
"treat":{"treatments","treatment","treated","treating","treats"},
"treats":{"treatments","treatment","treated","treating","treat"},
"treating":{"treatments","treatment","treated","treats","treat"},
"treated":{"treatments","treatment","treating","treats","treat"},
"treatment":{"treatments","treated","treating","treats","treat"},
"treatments":{"treatment","treated","treating","treats","treat"},
"tremble":{"trembling","trembles","trembled"},
"trembling":{"tremble","trembles","trembled"},
"trembles":{"tremble","trembling","trembled"},
"trembled":{"tremble","trembling","trembles"},
"tribe":{"tribes"},
"tribes":{"tribe"},
"trick":{"trickster","tricks","tricking","tricked"},
"trickster":{"trick","tricks","tricking","tricked"},
"tricks":{"trick","trickster","tricking","tricked"},
"tricking":{"trick","trickster","tricks","tricked"},
"tricked":{"trick","trickster","tricks","tricking"},
"trip":{"tripped","tripping","trips"},
"trips":{"tripped","tripping","trip"},
"tripping":{"tripped","trips","trip"},
"tripped":{"tripping","trips","trip"},
"trunk":{"trunks"},
"trunks":{"trunk"},
"tube":{"tubes"},
"tubes":{"tube"},
"tune":{"tuned","tunes","tuning"},
"tuning":{"tuned","tunes","tune"},
"tunes":{"tuned","tuning","tune"},
"tuned":{"tunes","tuning","tune"},
"twist":{"twisted","twisting","twists"},
"twists":{"twisted","twisting","twist"},
"twisting":{"twisted","twists","twist"},
"twisted":{"twisting","twists","twist"},
"typical":{"typically"},
"typically":{"typical"},
"ugly":{"uglier","ugliest","ugliness"},
"ugliness":{"uglier","ugliest","ugly"},
"ugliest":{"uglier","ugliness","ugly"},
"uglier":{"ugliest","ugliness","ugly"},
"umbrella":{"umbrellas"},
"umbrellas":{"umbrella"},
"uncle":{"uncles"},
"uncles":{"uncle"},
"universe":{"universal"},
"universal":{"universe"},
"upset":{"upsetting","upsets"},
"upsetting":{"upset","upsets"},
"upsets":{"upset","upsetting"},
"upwards":{"upward"},
"upward":{"upwards"},
"urge":{"urging","urges","urged"},
"urging":{"urge","urges","urged"},
"urges":{"urge","urging","urged"},
"urged":{"urge","urging","urges"},
"vain":{"vainer","vainest","vainly"},
"vainly":{"vainer","vainest","vain"},
"vainest":{"vainer","vainly","vain"},
"vainer":{"vainest","vainly","vain"},
"veil":{"veils","veiling","veiled"},
"veils":{"veil","veiling","veiled"},
"veiling":{"veil","veils","veiled"},
"veiled":{"veil","veils","veiling"},
"verb":{"verbs"},
"verbs":{"verb"},
"verse":{"verses"},
"verses":{"verse"},
"violent":{"violently","violence"},
"violently":{"violent","violence"},
"violence":{"violent","violently"},
"vowel":{"vowels"},
"vowels":{"vowel"},
"voyage":{"voyaging","voyages","voyaged"},
"voyaging":{"voyage","voyages","voyaged"},
"voyages":{"voyage","voyaging","voyaged"},
"voyaged":{"voyage","voyaging","voyages"},
"waist":{"waists"},
"waists":{"waist"},
"wake":{"woken","waken","wakes","waking","woke"},
"woke":{"woken","waken","wakes","waking","wake"},
"waking":{"woken","waken","wakes","woke","wake"},
"wakes":{"woken","waken","waking","woke","wake"},
"waken":{"woken","wakes","waking","woke","wake"},
"woken":{"waken","wakes","waking","woke","wake"},
"wander":{"wandered","wandering","wanders"},
"wanders":{"wandered","wandering","wander"},
"wandering":{"wandered","wanders","wander"},
"wandered":{"wandering","wanders","wander"},
"warm":{"warmth","warmed","warming","warmly","warms","warmness"},
"warms":{"warmth","warmed","warming","warmly","warm"},
"warmly":{"warmth","warmed","warming","warms","warm"},
"warming":{"warmth","warmed","warmly","warms","warm"},
"warmed":{"warmth","warming","warmly","warms","warm"},
"warmth":{"warmed","warming","warmly","warms","warm"},
"warn":{"warned","warning","warns"},
"warned":{"warn","warning","warns"},
"warning":{"warn","warned","warns"},
"warns":{"warn","warned","warning"},
"wash":{"washing","washes","washed"},
"washed":{"washing","washes","wash"},
"washes":{"washing","washed","wash"},
"washing":{"washes","washed","wash"},
"waste":{"wastefully","wasteful","wasting","wastes","wasted"},
"wasted":{"wastefully","wasteful","wasting","wastes","waste"},
"wastes":{"wastefully","wasteful","wasting","wasted","waste"},
"wasting":{"wastefully","wasteful","wastes","wasted","waste"},
"wasteful":{"wastefully","wasting","wastes","wasted","waste"},
"wastefully":{"wasteful","wasting","wastes","wasted","waste"},
"wax":{"waxing","waxes","waxed"},
"waxing":{"wax","waxes","waxed"},
"waxes":{"wax","waxing","waxed"},
"waxed":{"wax","waxing","waxes"},
"weak":{"weaken","weakness","weakly"},
"weakly":{"weaken","weakness","weak"},
"weakness":{"weaken","weakly","weak"},
"weaken":{"weakness","weakly","weak"},
"weapon":{"weapons"},
"weapons":{"weapon"},
"weather":{"weathered","weathering","weathers"},
"weathers":{"weathered","weathering","weather"},
"weathering":{"weathered","weathers","weather"},
"weathered":{"weathering","weathers","weather"},
"weave":{"wove","weaving","weaves","weaved"},
"wove":{"weave","weaving","weaves","weaved"},
"weaving":{"weave","wove","weaves","weaved"},
"weaves":{"weave","wove","weaving","weaved"},
"weaved":{"weave","wove","weaving","weaves"},
"weed":{"weeded","weeding","weeds"},
"weeds":{"weeded","weeding","weed"},
"weeding":{"weeded","weeds","weed"},
"weeded":{"weeding","weeds","weed"},
"weigh":{"weighed","weighing","weighs","weight","weights"},
"weights":{"weighed","weighing","weighs","weight","weigh"},
"weight":{"weighed","weighing","weighs","weights","weigh"},
"weighs":{"weighed","weighing","weight","weights","weigh"},
"weighing":{"weighed","weighs","weight","weights","weigh"},
"weighed":{"weighing","weighs","weight","weights","weigh"},
"wet":{"wetting","wets"},
"wetting":{"wet","wets"},
"wets":{"wet","wetting"},
"wheat":{"wheats"},
"wheel":{"wheels","wheeler","wheeled"},
"wheels":{"wheel","wheeler","wheeled"},
"wheeler":{"wheel","wheels","wheeled"},
"wheeled":{"wheel","wheels","wheeler"},
"whip":{"whipped","whipping","whips"},
"whips":{"whipped","whipping","whip"},
"whipping":{"whipped","whips","whip"},
"whipped":{"whipping","whips","whip"},
"whisper":{"whispers","whispering","whispered"},
"whispers":{"whisper","whispering","whispered"},
"whispering":{"whisper","whispers","whispered"},
"whispered":{"whisper","whispers","whispering"},
"whistle":{"whistled","whistles","whistling"},
"whistling":{"whistled","whistles","whistle"},
"whistles":{"whistled","whistling","whistle"},
"whistled":{"whistles","whistling","whistle"},
"wicked":{"wickedly","wickeder","wickedest","wickedness"},
"wickedness":{"wickedly","wickeder","wickedest","wicked"},
"wickedest":{"wickedly","wickeder","wickedness","wicked"},
"wickeder":{"wickedly","wickedest","wickedness","wicked"},
"wickedly":{"wickeder","wickedest","wickedness","wicked"},
"widow":{"widows","widower","widowed"},
"widows":{"widow","widower","widowed"},
"widower":{"widow","widows","widowed"},
"widowed":{"widow","widows","widower"},
"wine":{"wined","wines","wining"},
"wining":{"wined","wines","wine"},
"wines":{"wined","wining","wine"},
"wined":{"wines","wining","wine"},
"wing":{"wings","winging","winged"},
"wings":{"wing","winging","winged"},
"winging":{"wing","wings","winged"},
"winged":{"wing","wings","winging"},
"wipe":{"wipers","wiper","wiped","wipes","wiping"},
"wiping":{"wipers","wiper","wiped","wipes","wipe"},
"wipes":{"wipers","wiper","wiped","wiping","wipe"},
"wiped":{"wipers","wiper","wipes","wiping","wipe"},
"wiper":{"wipers","wiped","wipes","wiping","wipe"},
"wipers":{"wiper","wiped","wipes","wiping","wipe"},
"wire":{"wired","wires","wiring"},
"wiring":{"wired","wires","wire"},
"wires":{"wired","wiring","wire"},
"wired":{"wires","wiring","wire"},
"witness":{"witnessing","witnesses","witnessed"},
"witnessing":{"witness","witnesses","esses","witnessed"},
"witnesses":{"witness","witnessing","esses","witnessed"},
"wool":{"woolly","woollen","wools"},
"wools":{"woolly","woollen","wool"},
"woollen":{"woolly","wools","wool"},
"woolly":{"woollen","wools","wool"},
"worm":{"worms","worming","wormed"},
"worms":{"worm","worming","wormed"},
"worming":{"worm","worms","wormed"},
"wormed":{"worm","worms","worming"},
"worry":{"worried","worries","worrying"},
"worrying":{"worried","worries","worry"},
"worries":{"worried","worrying","worry"},
"worried":{"worries","worrying","worry"},
"worse":{"worst","worsen"},
"worst":{"worse","worsen"},
"worsen":{"worse","worst"},
"worship":{"worshipped","worships","worshipping"},
"worshipping":{"worshipped","worships","worship"},
"worships":{"worshipped","worshipping","worship"},
"worshipped":{"worships","worshipping","worship"},
"wrap":{"wrapped","wrappers","wrapper","wraps","wrapping"},
"wrapping":{"wrapped","wrappers","wrapper","wraps","wrap"},
"wraps":{"wrapped","wrappers","wrapper","wrapping","wrap"},
"wrapper":{"wrapped","wrappers","wraps","wrapping","wrap"},
"wrappers":{"wrapped","wrapper","wraps","wrapping","wrap"},
"wrapped":{"wrappers","wrapper","wraps","wrapping","wrap"},
"wreck":{"wrecked","wrecking","wrecks"},
"wrecked":{"wreck","wrecking","wrecks"},
"wrecking":{"wreck","wrecked","wrecks"},
"wrecks":{"wreck","wrecked","wrecking"},
"wrist":{"wrists"},
"wrists":{"wrist"},
"yard":{"yards"},
"yards":{"yard"},
"yellow":{"yellowish"},
"yellowish":{"yellow"},
"zero":{"zeros"},
"zeros":{"zero"},
"abandon":{"abandons","abandonment","abandoning","abandoned"},
"abandoned":{"abandon","abandons","abandonment","abandoning"},
"abandoning":{"abandon","abandons","abandonment","abandoned"},
"abandonment":{"abandon","abandons","abandoning","abandoned"},
"abandons":{"abandon","abandonment","abandoning","abandoned"},
"abstract":{"abstractly","abstraction","abstractions","abstracts"},
"abstraction":{"abstractly","abstract","abstractions","abstracts"},
"abstractions":{"abstractly","abstract","abstraction","abstracts"},
"abstractly":{"abstract","abstraction","abstractions","abstracts"},
"abstracts":{"abstractly","abstract","abstraction","abstractions"},
"academy":{"academics","academies","academically","academia","academic"},
"academia":{"academics","academies","academically","academic","academy"},
"academic":{"academics","academies","academically","academia","academy"},
"academically":{"academics","academies","academia","academic","academy"},
"academics":{"academies","academically","academia","academic","academy"},
"academies":{"academics","academically","academia","academic","academy"},
"access":{"accesses","accessed","accessing","accessible","accessibility"},
"accessed":{"accesses","access","accessing","accessible","accessibility"},
"accesses":{"access","accessed","accessing","accessible","accessibility"},
"accessibility":{"accesses","access","accessed","accessing","accessible"},
"accessible":{"accesses","access","accessed","accessing","accessibility"},
"accessing":{"accesses","access","accessed","accessible","accessibility"},
"accommodate":{"accommodating","accommodates","accommodation","accommodated"},
"accommodated":{"accommodate","accommodating","accommodates","accommodation"},
"accommodates":{"accommodate","accommodating","accommodation","accommodated"},
"accommodating":{"accommodate","accommodates","accommodation","accommodated"},
"accommodation":{"accommodate","accommodating","accommodates","accommodated"},
"accompany":{"accompanied","accompanies","accompaniment","accompanying"},
"accompanied":{"accompany","accompanies","accompaniment","accompanying"},
"accompanies":{"accompany","accompanied","accompaniment","accompanying"},
"accompaniment":{"accompany","accompanied","accompanies","accompanying"},
"accompanying":{"accompany","accompanied","accompanies","accompaniment"},
"accumulate":{"accumulation","accumulated","accumulating","accumulates"},
"accumulated":{"accumulate","accumulation","accumulating","accumulates"},
"accumulating":{"accumulate","accumulation","accumulated","accumulates"},
"accumulation":{"accumulate","accumulated","accumulating","accumulates"},
"accumulates":{"accumulate","accumulation","accumulated","accumulating"},
"accurate":{"accurately","accuracy"},
"accuracy":{"accurately","accurate"},
"accurately":{"accuracy","accurate"},
"inaccuracy":{"inaccuracies","inaccurate"},
"inaccuracies":{"inaccurate","inaccuracy"},
"inaccurate":{"inaccuracies","inaccuracy"},
"achieve":{"achieving","achievement","achieved","achievable","achieves","achievements"},
"achievable":{"achieving","achievement","achieved","achieves","achieve","achievements"},
"achieved":{"achieving","achievement","achievable","achieves","achieve","achievements"},
"achievement":{"achieving","achieved","achievable","achieves","achieve","achievements"},
"achievements":{"achieving","achievement","achieved","achievable","achieves","achieve"},
"achieves":{"achieving","achievement","achieved","achievable","achieve","achievements"},
"achieving":{"achievement","achieved","achievable","achieves","achieve","achievements"},
"acknowledge":{"acknowledged","acknowledges","acknowledgement","acknowledging","acknowledgements"},
"acknowledged":{"acknowledge","acknowledges","acknowledgement","acknowledging","acknowledgements"},
"acknowledges":{"acknowledge","acknowledged","acknowledgement","acknowledging","acknowledgements"},
"acknowledging":{"acknowledge","acknowledged","acknowledges","acknowledgement","acknowledgements"},
"acknowledgement":{"acknowledge","acknowledged","acknowledges","acknowledging","acknowledgements"},
"acknowledgements":{"acknowledge","acknowledged","acknowledges","acknowledgement","acknowledging"},
"acquire":{"acquisition","acquisitions","acquiring","acquires","acquired"},
"acquired":{"acquisition","acquisitions","acquiring","acquires","acquire"},
"acquires":{"acquisition","acquisitions","acquiring","acquired","acquire"},
"acquiring":{"acquisition","acquisitions","acquires","acquired","acquire"},
"acquisition":{"acquisitions","acquiring","acquires","acquired","acquire"},
"acquisitions":{"acquisition","acquiring","acquires","acquired","acquire"},
"adapt":{"adaptive","adapted","adapting","adaptation","adapts","adaptable","adaptability","adaptations"},
"adaptability":{"adaptive","adapted","adapting","adaptation","adapts","adaptable","adapt","adaptations"},
"adaptable":{"adaptive","adapted","adapting","adaptation","adapts","adaptability","adapt","adaptations"},
"adaptation":{"adaptive","adapted","adapting","adapts","adaptable","adaptability","adapt","adaptations"},
"adaptations":{"adaptive","adapted","adapting","adaptation","adapts","adaptable","adaptability","adapt"},
"adapted":{"adaptive","adapting","adaptation","adapts","adaptable","adaptability","adapt","adaptations"},
"adapting":{"adaptive","adapted","adaptation","adapts","adaptable","adaptability","adapt","adaptations"},
"adaptive":{"adapted","adapting","adaptation","adapts","adaptable","adaptability","adapt","adaptations"},
"adapts":{"adaptive","adapted","adapting","adaptation","adaptable","adaptability","adapt","adaptations"},
"adequate":{"adequacy","adequately"},
"adequacy":{"adequate","adequately"},
"adequately":{"adequate","adequacy"},
"inadequacies":{"inadequacy","inadequately","inadequate"},
"inadequacy":{"inadequately","inadequate","inadequacies"},
"inadequate":{"inadequacy","inadequately","inadequacies"},
"inadequately":{"inadequacy","inadequate","inadequacies"},
"adjust":{"adjustment","readjusts","readjustments","readjustment","readjusted","readjust","readjusting","adjusted","adjusting","adjustments","adjusts"},
"adjusted":{"adjustment","readjusts","readjustments","readjustment","readjust","adjust","readjusting","adjusting","adjustments","adjusts"},
"adjusting":{"adjustment","readjusts","readjustments","readjustment","readjusted","readjust","adjust","readjusting","adjusted","adjustments","adjusts"},
"adjustment":{"readjusts","readjustments","readjustment","readjusted","readjust","adjust","readjusting","adjusted","adjusting","adjustments","adjusts"},
"adjustments":{"adjustment","readjusts","readjustment","readjusted","readjust","adjust","readjusting","adjusted","adjusting","adjustments","adjusts"},
"adjusts":{"adjustment","readjusts","readjustments","readjustment","readjusted","readjust","adjust","readjusting","adjusted","adjusting","adjustments"},
"readjust":{"adjustment","readjusts","readjustments","readjustment","readjusted","adjust","readjusting","adjusted","adjusting","adjustments","adjusts"},
"readjusted":{"adjustment","readjusts","readjustments","readjustment","readjust","adjust","readjusting","adjusted","adjusting","adjustments","adjusts"},
"readjusting":{"adjustment","readjusts","readjustments","readjustment","readjusted","readjust","adjust","adjusted","adjusting","adjustments","adjusts"},
"readjustment":{"adjustment","readjusts","readjustments","readjusted","readjust","adjust","readjusting","adjusted","adjusting","adjustments","adjusts"},
"readjustments":{"adjustment","readjusts","readjustment","readjusted","readjust","adjust","readjusting","adjusted","adjusting","adjustments","adjusts"},
"readjusts":{"adjustment","readjustments","readjustment","readjusted","readjust","adjust","readjusting","adjusted","adjusting","adjustments","adjusts"},
"administrate":{"administrator","administratively","administrative","administrators","administrations","administration","administrates"},
"administrates":{"administrator","administratively","administrative","administrators","administrations","administration","administrate"},
"administration":{"administrator","administratively","administrative","administrators","administrations","administrates","administrate"},
"administrations":{"administrator","administratively","administrative","administrators","administration","administrates","administrate"},
"administrative":{"administrator","administratively","administrators","administrations","administration","administrates","administrate"},
"administratively":{"administrator","administrative","administrators","administrations","administration","administrates","administrate"},
"administrator":{"administratively","administrative","administrators","administrations","administration","administrates","administrate"},
"administrators":{"administrator","administratively","administrative","administrations","administration","administrates","administrate"},
"adult":{"adults","adulthood"},
"adulthood":{"adults","adult"},
"adults":{"adulthood","adult"},
"advocate":{"advocates","advocated","advocacy","advocating"},
"advocacy":{"advocates","advocated","advocate","advocating"},
"advocated":{"advocates","advocated","advocacy","advocate","advocating"},
"advocates":{"advocates","advocated","advocacy","advocate","advocating"},
"advocating":{"advocates","advocated","advocacy","advocate","advocating"},
"affect":{"affective","affects","unaffected","affecting","affected","affect","affectively","effect"},
"affected":{"affective","affects","unaffected","affecting","affected","affect","affectively"},
"affecting":{"affective","affects","unaffected","affecting","affected","affect","affectively"},
"affective":{"affective","affects","unaffected","affecting","affected","affect","affectively"},
"affects":{"affective","affects","unaffected","affecting","affected","affect","affectively"},
"unaffected":{"unaffected"},
"aggregate":{"aggregate","aggregating","aggregates","aggregated","aggregation"},
"aggregated":{"aggregate","aggregating","aggregates","aggregated","aggregation"},
"aggregates":{"aggregate","aggregating","aggregates","aggregated","aggregation"},
"aggregating":{"aggregate","aggregating","aggregates","aggregated","aggregation"},
"aggregation":{"aggregate","aggregating","aggregates","aggregated","aggregation"},
"aid":{"aid","aided","aiding","aids"},
"aided":{"aid","aided","aiding","aids"},
"aiding":{"aid","aided","aiding","aids"},
"aids":{"aid","aided","aiding","aids"},
"unaided":{"unaided"},
"allocate":{"allocation","allocate","allocated","allocates","allocations","allocating"},
"allocated":{"allocation","allocate","allocated","allocates","allocations","allocating"},
"allocates":{"allocation","allocate","allocated","allocates","allocations","allocating"},
"allocating":{"allocation","allocate","allocated","allocates","allocations","allocating"},
"allocation":{"allocation","allocate","allocated","allocates","allocations","allocating"},
"allocations":{"allocation","allocate","allocated","allocates","allocations","allocating"},
"alter":{"alterable","alterations","alteration","alter","altered","altering","alternate","alternating","alters"},
"alterable":{"alterable","alterations","alteration","alter","altered","altering","alternate","alternating","alters"},
"alteration":{"alterable","alterations","alteration","alter","altered","altering","alternate","alternating","alters"},
"alterations":{"alterable","alterations","alteration","alter","altered","altering","alternate","alternating","alters"},
"altered":{"alterable","alterations","alteration","alter","altered","altering","alternate","alternating","alters"},
"altering":{"alterable","alterations","alteration","alter","altered","altering","alternate","alternating","alters"},
"alternate":{"alterable","alterations","alteration","alter","altered","altering","alternate","alternating","alters"},
"alternating":{"alterable","alterations","alteration","alter","altered","altering","alternate","alternating","alters"},
"alters":{"alterable","alterations","alteration","alter","altered","altering","alternate","alternating","alters"},
"unalterable":{"alterable","alterations","alteration","alter","altered","altering","alternate","alternating","alters","unalterable","unaltered"},
"unaltered":{"alterable","alterations","alteration","alter","altered","altering","alternate","alternating","alters","unalterable","unaltered"},
"alternative":{"alternative","alternatively","alternatives"},
"alternatively":{"alternative","alternatively","alternatives"},
"alternatives":{"alternative","alternatively","alternatives"},
"ambiguous":{"ambiguous","ambiguities","ambiguity"},
"ambiguities":{"ambiguous","ambiguities","ambiguity"},
"ambiguity":{"ambiguous","ambiguities","ambiguity"},
"unambiguous":{"unambiguous","ambiguous","ambiguities","ambiguity","unambiguously"},
"unambiguously":{"unambiguous","ambiguous","ambiguities","ambiguity","unambiguously"},
"amend":{"amend","amends","amendments","amending","amended","amendment"},
"amended":{"amend","amends","amendments","amending","amended","amendment"},
"amending":{"amend","amends","amendments","amending","amended","amendment"},
"amendment":{"amend","amends","amendments","amending","amended","amendment"},
"amendments":{"amend","amends","amendments","amending","amended","amendment"},
"amends":{"amend","amends","amendments","amending","amended","amendment"},
"analogy":{"analogous","analogies","analogy"},
"analogies":{"analogous","analogies","analogy"},
"analogous":{"analogous","analogies","analogy"},
"analyse":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analysed":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analyser":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analysers":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analyses":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analysing":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analysis":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analyst":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analysts":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analytic":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analytical":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analytically":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analyze":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analyzed":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analyzes":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"analyzing":{"analysts","analyst","analysis","analysing","analyses","analysers","analyser","analysed","analytic","analytical","analytically","analyse","analyzing","analyzes","analyzed","analyze"},
"annual":{"annually","annual"},
"annually":{"annually","annual"},
"anticipate":{"anticipate","anticipated","anticipates","anticipation","anticipating"},
"anticipated":{"anticipate","anticipated","anticipates","anticipation","anticipating"},
"anticipates":{"anticipate","anticipated","anticipates","anticipation","anticipating"},
"anticipating":{"anticipate","anticipated","anticipates","anticipation","anticipating"},
"anticipation":{"anticipate","anticipated","anticipates","anticipation","anticipating"},
"unanticipated":{"anticipate","anticipated","anticipates","anticipation","unanticipated","anticipating"},
"apparent":{"apparently","apparent"},
"apparently":{"apparently","apparent"},
"append":{"appendixes","append","appendix","appended","appending","appends","appendices"},
"appendix":{"appendixes","append","appendix","appended","appending","appends","appendices"},
"appended":{"appendixes","append","appendix","appended","appending","appends","appendices"},
"appends":{"appendixes","append","appendix","appended","appending","appends","appendices"},
"appending":{"appendixes","append","appendix","appended","appending","appends","appendices"},
"appendices":{"appendixes","append","appendix","appended","appending","appends","appendices"},
"appendixes":{"appendixes","append","appendix","appended","appending","appends","appendices"},
"appreciate":{"appreciable","appreciably","appreciated","appreciates","appreciation","appreciating","appreciate"},
"appreciable":{"appreciable","appreciably","appreciated","appreciates","appreciation","appreciating","appreciate"},
"appreciably":{"appreciable","appreciably","appreciated","appreciates","appreciation","appreciating","appreciate"},
"appreciated":{"appreciable","appreciably","appreciated","appreciates","appreciation","appreciating","appreciate"},
"appreciates":{"appreciable","appreciably","appreciated","appreciates","appreciation","appreciating","appreciate"},
"appreciating":{"appreciable","appreciably","appreciated","appreciates","appreciation","appreciating","appreciate"},
"appreciation":{"appreciable","appreciably","appreciated","appreciates","appreciation","appreciating","appreciate"},
"unappreciated":{"appreciable","appreciably","appreciated","appreciates","appreciation","unappreciated","appreciating","appreciate"},
"approach":{"approaches","approached","approach","approachable","approaching"},
"approachable":{"approaches","approached","approach","approachable","approaching"},
"approached":{"approaches","approached","approach","approachable","approaching"},
"approaches":{"approaches","approached","approach","approachable","approaching"},
"approaching":{"approaches","approached","approach","approachable","approaching"},
"unapproachable":{"approaches","approached","approach","approachable","approaching","unapproachable"},
"appropriate":{"appropriateness","appropriately","appropriacy","appropriate"},
"appropriately":{"appropriateness","appropriately","appropriacy","appropriate"},
"appropriateness":{"appropriateness","appropriately","appropriacy","appropriate"},
"inappropriate":{"inappropriacy","appropriateness","appropriately","appropriacy","inappropriate","inappropriately","appropriate"},
"inappropriately":{"inappropriacy","appropriateness","appropriately","appropriacy","inappropriate","inappropriately","appropriate"},
"approximate":{"approximately","approximated","approximations","approximation","approximating","approximates","approximate"},
"approximated":{"approximately","approximated","approximations","approximation","approximating","approximates","approximate"},
"approximately":{"approximately","approximated","approximations","approximation","approximating","approximates","approximate"},
"approximates":{"approximately","approximated","approximations","approximation","approximating","approximates","approximate"},
"approximating":{"approximately","approximated","approximations","approximation","approximating","approximates","approximate"},
"approximation":{"approximately","approximated","approximations","approximation","approximating","approximates","approximate"},
"approximations":{"approximately","approximated","approximations","approximation","approximating","approximates","approximate"},
"arbitrary":{"arbitrariness","arbitrary","arbitrarily"},
"arbitrariness":{"arbitrariness","arbitrary","arbitrarily"},
"arbitrarily":{"arbitrariness","arbitrary","arbitrarily"},
"area":{"area","areas"},
"areas":{"area","areas"},
"aspect":{"aspects","aspect"},
"aspects":{"aspects","aspect"},
"assemble":{"assembles","assembled","assemble","assemblies","assembling","assembly"},
"assembled":{"assembles","assembled","assemble","assemblies","assembling","assembly"},
"assembles":{"assembles","assembled","assemble","assemblies","assembling","assembly"},
"assemblies":{"assembles","assembled","assemble","assemblies","assembling","assembly"},
"assembling":{"assembles","assembled","assemble","assemblies","assembling","assembly"},
"assembly":{"assembles","assembled","assemble","assemblies","assembling","assembly"},
"assess":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess"},
"assessable":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess"},
"assessed":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess"},
"assesses":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess"},
"assessing":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess"},
"assessment":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess"},
"assessments":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess"},
"reassess":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess"},
"reassessed":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess"},
"reassessing":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess"},
"reassessment":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess"},
"assign":{"assign","assigns","reassigned","assigning","assignment","assignments","reassign","reassigns","assigned","reassigning"},
"assigned":{"assign","assigns","reassigned","assigning","assignment","assignments","reassign","reassigns","assigned","reassigning"},
"assigning":{"assign","assigns","reassigned","assigning","assignment","assignments","reassign","reassigns","assigned","reassigning"},
"assignment":{"assign","assigns","reassigned","assigning","assignment","assignments","reassign","reassigns","assigned","reassigning"},
"assignments":{"assign","assigns","reassigned","assigning","assignment","assignments","reassign","reassigns","assigned","reassigning"},
"assigns":{"assign","assigns","reassigned","assigning","assignment","assignments","reassign","reassigns","assigned","reassigning"},
"reassign":{"assign","assigns","reassigned","assigning","assignment","assignments","reassign","reassigns","assigned","reassigning"},
"reassigned":{"assign","assigns","reassigned","assigning","assignment","assignments","reassign","reassigns","assigned","reassigning"},
"reassigning":{"assign","assigns","reassigned","assigning","assignment","assignments","reassign","reassigns","assigned","reassigning"},
"reassigns":{"assign","assigns","reassigned","assigning","assignment","assignments","reassign","reassigns","assigned","reassigning"},
"unassigned":{"assign","assigns","reassigned","assigning","assignment","unassigned","assignments","reassign","reassigns","assigned","reassigning"},
"assist":{"assist","assists","assisting","assistants","assistant","assistance","assisted"},
"assistance":{"assist","assists","assisting","assistants","assistant","assistance","assisted"},
"assistant":{"assist","assists","assisting","assistants","assistant","assistance","assisted"},
"assistants":{"assist","assists","assisting","assistants","assistant","assistance","assisted"},
"assisted":{"assist","assists","assisting","assistants","assistant","assistance","assisted"},
"assisting":{"assist","assists","assisting","assistants","assistant","assistance","assisted"},
"assists":{"assist","assists","assisting","assistants","assistant","assistance","assisted"},
"unassisted":{"assist","unassisted","assists","assisting","assistants","assistant","assistance","assisted"},
"assume":{"assumed","assumptions","assume","assuming","assumes","assumption"},
"assumed":{"assumed","assumptions","assume","assuming","assumes","assumption"},
"assumes":{"assumed","assumptions","assume","assuming","assumes","assumption"},
"assuming":{"assumed","assumptions","assume","assuming","assumes","assumption"},
"assumption":{"assumed","assumptions","assume","assuming","assumes","assumption"},
"assumptions":{"assumed","assumptions","assume","assuming","assumes","assumption"},
"assure":{"assuring","assurance","assure","assuredly","assurances","assured","assures"},
"assurance":{"assuring","assurance","assure","assuredly","assurances","assured","assures"},
"assurances":{"assuring","assurance","assure","assuredly","assurances","assured","assures"},
"assured":{"assuring","assurance","assure","assuredly","assurances","assured","assures"},
"assuredly":{"assuring","assurance","assure","assuredly","assurances","assured","assures"},
"assures":{"assuring","assurance","assure","assuredly","assurances","assured","assures"},
"assuring":{"assuring","assurance","assure","assuredly","assurances","assured","assures"},
"attach":{"attached","attachments","attachment","attaching","attach","attaches"},
"attached":{"attached","attachments","attachment","attaching","attach","attaches"},
"attaches":{"attached","attachments","attachment","attaching","attach","attaches"},
"attaching":{"attached","attachments","attachment","attaching","attach","attaches"},
"attachment":{"attached","attachments","attachment","attaching","attach","attaches"},
"attachments":{"attached","attachments","attachment","attaching","attach","attaches"},
"unattached":{"attached","unattached","attachments","attachment","attaching","attach","attaches"},
"attain":{"attain","attainable","attained","attainment","attaining","attains","attainments"},
"attainable":{"attain","attainable","attained","attainment","attaining","attains","attainments"},
"attained":{"attain","attainable","attained","attainment","attaining","attains","attainments"},
"attaining":{"attain","attainable","attained","attainment","attaining","attains","attainments"},
"attainment":{"attain","attainable","attained","attainment","attaining","attains","attainments"},
"attainments":{"attain","attainable","attained","attainment","attaining","attains","attainments"},
"attains":{"attain","attainable","attained","attainment","attaining","attains","attainments"},
"unattainable":{"attain","attainable","attained","attainment","attaining","unattainable","attains","attainments"},
"attitude":{"attitude","attitudes"},
"attitudes":{"attitude","attitudes"},
"attribute":{"attribution","attribute","attributed","attributes","attributing","attributable"},
"attributable":{"attribution","attribute","attributed","attributes","attributing","attributable"},
"attributed":{"attribution","attribute","attributed","attributes","attributing","attributable"},
"attributes":{"attribution","attribute","attributed","attributes","attributing","attributable"},
"attributing":{"attribution","attribute","attributed","attributes","attributing","attributable"},
"attribution":{"attribution","attribute","attributed","attributes","attributing","attributable"},
"author":{"authoring","authors","authorship","author","authored"},
"authored":{"authoring","authors","authorship","author","authored"},
"authoring":{"authoring","authors","authorship","author","authored"},
"authors":{"authoring","authors","authorship","author","authored"},
"authorship":{"authoring","authors","authorship","author","authored"},
"authority":{"authoritative","authorities","authority"},
"authoritative":{"authoritative","authorities","authority"},
"authorities":{"authoritative","authorities","authority"},
"automate":{"automation","automate","automated","automates","automating","automatically","automatic"},
"automatic":{"automation","automate","automated","automates","automating","automatically","automatic"},
"automated":{"automation","automate","automated","automates","automating","automatically","automatic"},
"automates":{"automation","automate","automated","automates","automating","automatically","automatic"},
"automating":{"automation","automate","automated","automates","automating","automatically","automatic"},
"automatically":{"automation","automate","automated","automates","automating","automatically","automatic"},
"automation":{"automation","automate","automated","automates","automating","automatically","automatic"},
"available":{"available","availability"},
"availability":{"available","availability"},
"unavailable":{"available","availability","unavailable"},
"aware":{"awareness","aware"},
"awareness":{"awareness","aware"},
"unaware":{"unaware","awareness","aware"},
"benefit":{"benefits","benefiting","benefited","beneficiaries","beneficiary","beneficial","benefit"},
"beneficial":{"benefits","benefiting","benefited","beneficiaries","beneficiary","beneficial","benefit"},
"beneficiary":{"benefits","benefiting","benefited","beneficiaries","beneficiary","beneficial","benefit"},
"beneficiaries":{"benefits","benefiting","benefited","beneficiaries","beneficiary","beneficial","benefit"},
"benefited":{"benefits","benefiting","benefited","beneficiaries","beneficiary","beneficial","benefit"},
"benefiting":{"benefits","benefiting","benefited","beneficiaries","beneficiary","beneficial","benefit"},
"benefits":{"benefits","benefiting","benefited","beneficiaries","beneficiary","beneficial","benefit"},
"bias":{"biasing","biases","bias","biased"},
"biased":{"biasing","biases","bias","biased"},
"biases":{"biasing","biases","bias","biased"},
"biasing":{"biasing","biases","bias","biased"},
"unbiased":{"unbiased","biasing","biases","bias","biased"},
"bond":{"bonding","bonded","bond","bonds"},
"bonded":{"bonding","bonded","bond","bonds"},
"bonding":{"bonding","bonded","bond","bonds"},
"bonds":{"bonding","bonded","bond","bonds"},
"brief":{"briefing","brief","briefly","brevity","briefed","briefs"},
"brevity":{"briefing","brief","briefly","brevity","briefed","briefs"},
"briefed":{"briefing","brief","briefly","brevity","briefed","briefs"},
"briefing":{"briefing","brief","briefly","brevity","briefed","briefs"},
"briefly":{"briefing","brief","briefly","brevity","briefed","briefs"},
"briefs":{"briefing","brief","briefly","brevity","briefed","briefs"},
"bulk":{"bulk","bulky"},
"bulky":{"bulk","bulky"},
"capable":{"capability","capabilities","capable"},
"capabilities":{"capability","capabilities","capable"},
"capability":{"capability","capabilities","capable"},
"incapable":{"incapable","capability","capabilities","capable"},
"capacity":{"capacity","capacities"},
"capacities":{"capacity","capacities"},
"incapacitate":{"capacity","capacities","incapacitate","incapacitated"},
"incapacitated":{"capacity","capacities","incapacitate","incapacitated"},
"category":{"categories","categorised","categorise","categorisation","categorizing","category","categorized","categorises","categorizes","categorising","categorization"},
"categories":{"categories","categorised","categorise","categorisation","categorizing","category","categorized","categorises","categorizes","categorising","categorization"},
"categorisation":{"categories","categorised","categorise","categorisation","categorizing","category","categorized","categorises","categorizes","categorising","categorization"},
"categorise":{"categories","categorised","categorise","categorisation","categorizing","category","categorized","categorises","categorizes","categorising","categorization"},
"categorised":{"categories","categorised","categorise","categorisation","categorizing","category","categorized","categorises","categorizes","categorising","categorization"},
"categorises":{"categories","categorised","categorise","categorisation","categorizing","category","categorized","categorises","categorizes","categorising","categorization"},
"categorising":{"categories","categorised","categorise","categorisation","categorizing","category","categorized","categorises","categorizes","categorising","categorization"},
"categorization":{"categories","categorised","categorise","categorisation","categorizing","category","categorized","categorises","categorizes","categorising","categorization"},
"categorized":{"categories","categorised","categorise","categorisation","categorizing","category","categorized","categorises","categorizes","categorising","categorization"},
"categorizes":{"categories","categorised","categorise","categorisation","categorizing","category","categorized","categorises","categorizes","categorising","categorization"},
"categorizing":{"categories","categorised","categorise","categorisation","categorizing","category","categorized","categorises","categorizes","categorising","categorization"},
"cease":{"ceaseless","ceased","cease","ceasing","ceases"},
"ceased":{"ceaseless","ceased","cease","ceasing","ceases"},
"ceaseless":{"ceaseless","ceased","cease","ceasing","ceases"},
"ceases":{"ceased","cease","ceasing","ceases"},
"ceasing":{"ceased","cease","ceasing","ceases"},
"challenge":{"challenging","challenged","challenger","challenge","challenges","challengers"},
"challenged":{"challenging","challenged","challenger","challenge","challenges","challengers"},
"challenger":{"challenging","challenged","challenger","challenge","challenges","challengers"},
"challengers":{"challenging","challenged","challenger","challenge","challenges","challengers"},
"challenges":{"challenging","challenged","challenger","challenge","challenges","challengers"},
"challenging":{"challenging","challenged","challenger","challenge","challenges","challengers"},
"channel":{"channelled","channel","channels","channelling"},
"channelled":{"channelled","channel","channels","channelling"},
"channelling":{"channelled","channel","channels","channelling"},
"channels":{"channelled","channel","channels","channelling"},
"chapter":{"chapters","chapter"},
"chapters":{"chapters","chapter"},
"chart":{"charted","charting","chart","charts"},
"charted":{"charted","charting","chart","charts"},
"charting":{"charted","charting","chart","charts"},
"charts":{"charted","charting","chart","charts",""},
"uncharted":{"charted","charting","chart","charts","uncharted"},
"chemical":{"chemicals","chemically","chemical"},
"chemically":{"chemicals","chemically","chemical"},
"chemicals":{"chemicals","chemically","chemical"},
"circumstance":{"circumstances","circumstance"},
"circumstances":{"circumstances","circumstance"},
"cite":{"cites","cite","citation","cited","citations","citing"},
"citation":{"cites","cite","citation","cited","citations","citing"},
"citations":{"cites","cite","citation","cited","citations","citing"},
"cited":{"cites","cite","citation","cited","citations","citing"},
"citing":{"cites","cite","citation","cited","citations","citing"},
"cites":{"cites","cite","citation","cited","citations","citing"},
"clarify":{"clarity","clarifying","clarifies","clarified","clarification","clarify"},
"clarification":{"clarity","clarifying","clarifies","clarified","clarification","clarify"},
"clarified":{"clarity","clarifying","clarifies","clarified","clarification","clarify"},
"clarifies":{"clarity","clarifying","clarifies","clarified","clarification","clarify"},
"clarifying":{"clarity","clarifying","clarifies","clarified","clarification","clarify"},
"clarity":{"clarity","clarifying","clarifies","clarified","clarification","clarify"},
"classic":{"classical","classic","classics"},
"classical":{"classical","classic","classics"},
"classics":{"classical","classic","classics"},
"clause":{"clauses","clause"},
"clauses":{"clauses","clause"},
"code":{"coding","coded","code","codes"},
"coded":{"coding","coded","code","codes"},
"codes":{"coding","coded","code","codes"},
"coding":{"coding","coded","code","codes"},
"coherent":{"coherently","coherence","coherent"},
"coherence":{"coherently","coherence","coherent"},
"coherently":{"coherently","coherence","coherent"},
"incoherent":{"coherently","incoherent","coherence","coherent","incoherently"},
"incoherently":{"coherently","incoherent","coherence","coherent","incoherently"},
"coincide":{"coincident","coincidences","coincidence","coincidental","coincide","coincided","coincides","coinciding"},
"coincided":{"coincident","coincidences","coincidence","coincidental","coincide","coincided","coincides","coinciding"},
"coincides":{"coincident","coincidences","coincidence","coincidental","coincide","coincided","coincides","coinciding"},
"coinciding":{"coincident","coincidences","coincidence","coincidental","coincide","coincided","coincides","coinciding"},
"coincidence":{"coincident","coincidences","coincidence","coincidental","coincide","coincided","coincides","coinciding"},
"coincidences":{"coincident","coincidences","coincidence","coincidental","coincide","coincided","coincides","coinciding"},
"coincident":{"coincident","coincidences","coincidence","coincidental","coincide","coincided","coincides","coinciding"},
"coincidental":{"coincident","coincidences","coincidence","coincidental","coincide","coincided","coincides","coinciding"},
"collapse":{"collapse","collapsed","collapses","collapsible","collapsing"},
"collapsed":{"collapse","collapsed","collapses","collapsible","collapsing"},
"collapses":{"collapse","collapsed","collapses","collapsible","collapsing"},
"collapsible":{"collapse","collapsed","collapses","collapsible","collapsing"},
"collapsing":{"collapse","collapsed","collapses","collapsible","collapsing"},
"colleague":{"colleague","colleagues"},
"colleagues":{"colleague","colleagues"},
"commence":{"recommences","recommencing","commencing","recommenced","commencement","commences","commence","commenced"},
"commenced":{"recommences","recommencing","commencing","recommenced","commencement","commences","commence","commenced"},
"commences":{"recommences","recommencing","commencing","recommenced","commencement","commences","commence","commenced"},
"commencement":{"recommences","recommencing","commencing","recommenced","commencement","commences","commence","commenced"},
"commencing":{"recommences","recommencing","commencing","recommenced","commencement","commences","commence","commenced"},
"recommences":{"recommences","recommencing","commencing","recommenced","commencement","commences","commence","commenced"},
"recommenced":{"recommences","recommencing","commencing","recommenced","commencement","commences","commence","commenced"},
"recommencing":{"recommences","recommencing","commencing","recommenced","commencement","commences","commence","commenced"},
"comment":{"commenting","commentary","commentator","commentators","commented","comment","comments","commentaries"},
"commentaries":{"commenting","commentary","commentator","commentators","commented","comment","comments","commentaries"},
"commentary":{"commenting","commentary","commentator","commentators","commented","comment","comments","commentaries"},
"commentator":{"commenting","commentary","commentator","commentators","commented","comment","comments","commentaries"},
"commentators":{"commenting","commentary","commentator","commentators","commented","comment","comments","commentaries"},
"commented":{"commenting","commentary","commentator","commentators","commented","comment","comments","commentaries"},
"commenting":{"commenting","commentary","commentator","commentators","commented","comment","comments","commentaries"},
"comments":{"commenting","commentary","commentator","commentators","commented","comment","comments","commentaries"},
"commission":{"commissioner","commission","commissioned","commissions","commissioning","commissioners"},
"commissioned":{"commissioner","commission","commissioned","commissions","commissioning","commissioners"},
"commissioner":{"commissioner","commission","commissioned","commissions","commissioning","commissioners"},
"commissioners":{"commissioner","commission","commissioned","commissions","commissioning","commissioners"},
"commissioning":{"commissioner","commission","commissioned","commissions","commissioning","commissioners"},
"commissions":{"commissioner","commission","commissioned","commissions","commissioning","commissioners"},
"commit":{"commits","committing","committed","commit"},
"commitment":{"commitments","commitment"},
"commitments":{"commitments","commitment"},
"commits":{"commits","committing","committed","commit"},
"committed":{"commits","committing","committed","commit"},
"committing":{"commits","committing","committed","commit"},
"commodity":{"commodities","commodity"},
"commodities":{"commodities","commodity"},
"communicate":{"communicates","communicatively","communicative","communications","communication","communicating","communicated","communicable","communicate"},
"communicable":{"communicates","communicatively","communicative","communications","communication","communicating","communicated","communicable","communicate"},
"communicated":{"communicates","communicatively","communicative","communications","communication","communicating","communicated","communicable","communicate"},
"communicates":{"communicates","communicatively","communicative","communications","communication","communicating","communicated","communicable","communicate"},
"communicating":{"communicates","communicatively","communicative","communications","communication","communicating","communicated","communicable","communicate"},
"communication":{"communicates","communicatively","communicative","communications","communication","communicating","communicated","communicable","communicate"},
"communications":{"communicates","communicatively","communicative","communications","communication","communicating","communicated","communicable","communicate"},
"communicative":{"communicates","communicatively","communicative","communications","communication","communicating","communicated","communicable","communicate"},
"uncommunicative":{"communicates","communicatively","communicative","communications","communication","uncommunicative","communicating","communicated","communicable","communicate"},
"community":{"communities","community"},
"communities":{"communities","community"},
"compatible":{"compatibility","compatible"},
"compatibility":{"compatibility","compatible"},
"incompatibility":{"compatibility","incompatibility","incompatible","compatible"},
"incompatible":{"compatibility","incompatibility","incompatible","compatible"},
"compensate":{"compensatory","compensate","compensation","compensating","compensates","compensated","compensations"},
"compensated":{"compensatory","compensate","compensation","compensating","compensates","compensated","compensations"},
"compensates":{"compensatory","compensate","compensation","compensating","compensates","compensated","compensations"},
"compensating":{"compensatory","compensate","compensation","compensating","compensates","compensated","compensations"},
"compensation":{"compensatory","compensate","compensation","compensating","compensates","compensated","compensations"},
"compensations":{"compensatory","compensate","compensation","compensating","compensates","compensated","compensations"},
"compensatory":{"compensatory","compensate","compensation","compensating","compensates","compensated","compensations"},
"compile":{"compilations","compilation","compiled","compiles","compiling","compile"},
"compilation":{"compilations","compilation","compiled","compiles","compiling","compile"},
"compilations":{"compilations","compilation","compiled","compiles","compiling","compile"},
"compiled":{"compilations","compilation","compiled","compiles","compiling","compile"},
"compiles":{"compilations","compilation","compiled","compiles","compiling","compile"},
"compiling":{"compilations","compilation","compiled","compiles","compiling","compile"},
"complement":{"complements","complemented","complementary","complement","complementing"},
"complementary":{"complements","complemented","complementary","complement","complementing"},
"complemented":{"complements","complemented","complementary","complement","complementing"},
"complementing":{"complements","complemented","complementary","complement","complementing"},
"complements":{"complements","complemented","complementary","complement","complementing"},
"complex":{"complexities","complex","complexity"},
"complexities":{"complexities","complex","complexity"},
"complexity":{"complexities","complex","complexity"},
"component":{"componentry","components","component"},
"components":{"componentry","components","component"},
"compound":{"compounds","compounded","compound","compounding"},
"compounded":{"compounds","compounded","compound","compounding"},
"compounding":{"compounds","compounded","compound","compounding"},
"compounds":{"compounds","compounded","compound","compounding"},
"comprehensive":{"comprehensive","comprehensively"},
"comprehensively":{"comprehensive","comprehensively"},
"comprise":{"comprising","comprises","comprise","comprised"},
"comprised":{"comprising","comprises","comprise","comprised"},
"comprises":{"comprising","comprises","comprise","comprised"},
"comprising":{"comprising","comprises","comprise","comprised"},
"compute":{"computer","computable","computers","computing","computed","computerised","computations","computational","computation","compute"},
"computation":{"computer","computable","computers","computing","computed","computerised","computations","computational","computation","compute"},
"computational":{"computer","computable","computers","computing","computed","computerised","computations","computational","computation","compute"},
"computations":{"computer","computable","computers","computing","computed","computerised","computations","computational","computation","compute"},
"computable":{"computer","computable","computers","computing","computed","computerised","computations","computational","computation","compute"},
"computer":{"computer","computable","computers","computing","computed","computerised","computations","computational","computation","compute"},
"computed":{"computer","computable","computers","computing","computed","computerised","computations","computational","computation","compute"},
"computerised":{"computer","computable","computers","computing","computed","computerised","computations","computational","computation","compute"},
"computers":{"computer","computable","computers","computing","computed","computerised","computations","computational","computation","compute"},
"computing":{"computer","computable","computers","computing","computed","computerised","computations","computational","computation","compute"},
"conceive":{"conceiving","conceives","conceivably","conceivable","conceive","conceived"},
"conceivable":{"conceiving","conceives","conceivably","conceivable","conceive","conceived"},
"conceivably":{"conceiving","conceives","conceivably","conceivable","conceive","conceived"},
"conceived":{"conceiving","conceives","conceivably","conceivable","conceive","conceived"},
"conceives":{"conceiving","conceives","conceivably","conceivable","conceive","conceived"},
"conceiving":{"conceiving","conceives","conceivably","conceivable","conceive","conceived"},
"inconceivable":{"inconceivably","inconceivable","conceiving","conceives","conceivably","conceivable","conceive","conceived"},
"inconceivably":{"inconceivably","inconceivable","conceiving","conceives","conceivably","conceivable","conceive","conceived"},
"concentrate":{"concentration","concentrating","concentrates","concentrated","concentrate"},
"concentrated":{"concentration","concentrating","concentrates","concentrated","concentrate"},
"concentrates":{"concentration","concentrating","concentrates","concentrated","concentrate"},
"concentrating":{"concentration","concentrating","concentrates","concentrated","concentrate"},
"concentration":{"concentration","concentrating","concentrates","concentrated","concentrate"},
"concept":{"conceptually","conceptualising","conceptualises","conceptualised","conceptualise","conceptualisation","conceptual","concepts","conception","concept"},
"conception":{"conceptually","conceptualising","conceptualises","conceptualised","conceptualise","conceptualisation","conceptual","concepts","conception","concept"},
"concepts":{"conceptually","conceptualising","conceptualises","conceptualised","conceptualise","conceptualisation","conceptual","concepts","conception","concept"},
"conceptual":{"conceptually","conceptualising","conceptualises","conceptualised","conceptualise","conceptualisation","conceptual","concepts","conception","concept"},
"conceptualisation":{"conceptually","conceptualising","conceptualises","conceptualised","conceptualise","conceptualisation","conceptual","concepts","conception","concept"},
"conceptualise":{"conceptually","conceptualising","conceptualises","conceptualised","conceptualise","conceptualisation","conceptual","concepts","conception","concept"},
"conceptualised":{"conceptually","conceptualising","conceptualises","conceptualised","conceptualise","conceptualisation","conceptual","concepts","conception","concept"},
"conceptualises":{"conceptually","conceptualising","conceptualises","conceptualised","conceptualise","conceptualisation","conceptual","concepts","conception","concept"},
"conceptualising":{"conceptually","conceptualising","conceptualises","conceptualised","conceptualise","conceptualisation","conceptual","concepts","conception","concept"},
"conceptually":{"conceptually","conceptualising","conceptualises","conceptualised","conceptualise","conceptualisation","conceptual","concepts","conception","concept"},
"conclude":{"concludes","conclusively","conclusions","conclusion","concluding","concluded","conclude","conclusive"},
"concluded":{"concludes","conclusively","conclusions","conclusion","concluding","concluded","conclude","conclusive"},
"concludes":{"concludes","conclusively","conclusions","conclusion","concluding","concluded","conclude","conclusive"},
"concluding":{"concludes","conclusively","conclusions","conclusion","concluding","concluded","conclude","conclusive"},
"conclusion":{"concludes","conclusively","conclusions","conclusion","concluding","concluded","conclude","conclusive"},
"conclusions":{"concludes","conclusively","conclusions","conclusion","concluding","concluded","conclude","conclusive"},
"conclusive":{"concludes","conclusively","conclusions","conclusion","concluding","concluded","conclude","conclusive"},
"conclusively":{"concludes","conclusively","conclusions","conclusion","concluding","concluded","conclude","conclusive"},
"inconclusive":{"inconclusively","inconclusive","concludes","conclusively","conclusions","conclusion","concluding","concluded","conclude","conclusive"},
"inconclusively":{"inconclusively","inconclusive","concludes","conclusively","conclusions","conclusion","concluding","concluded","conclude","conclusive"},
"concurrent":{"concurrent","concurrently"},
"concurrently":{"concurrent","concurrently"},
"conduct":{"conduct","conducts","conducting","conducted"},
"conducted":{"conduct","conducts","conducting","conducted"},
"conducting":{"conduct","conducts","conducting","conducted"},
"conducts":{"conduct","conducts","conducting","conducted"},
"confer":{"confer","confers","conferring","conferred"},
"conference":{"conferences","conference"},
"conferences":{"conferences","conference"},
"conferred":{"confer","confers","conferring","conferred"},
"conferring":{"confer","confers","conferring","conferred"},
"confers":{"confer","confers","conferring","conferred"},
"confine":{"confining","confined","confines","confine"},
"confined":{"confining","confined","confines","confine"},
"confines":{"confining","confined","confines","confine"},
"confining":{"confining","confined","confines","confine"},
"unconfined":{"confining","confined","confines","unconfined","confine"},
"confirm":{"confirmed","confirmation","confirming","confirms","confirm"},
"confirmation":{"confirmed","confirmation","confirming","confirms","confirm"},
"confirmed":{"confirmed","confirmation","confirming","confirms","confirm"},
"confirming":{"confirmed","confirmation","confirming","confirms","confirm"},
"confirms":{"confirmed","confirmation","confirming","confirms","confirm"},
"conflict":{"conflicted","conflict","conflicting","conflicts"},
"conflicted":{"conflicted","conflict","conflicting","conflicts"},
"conflicting":{"conflicted","conflict","conflicting","conflicts"},
"conflicts":{"conflicted","conflict","conflicting","conflicts"},
"conform":{"conform","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"conformable":{"conform","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"conformance":{"conform","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"conformation":{"conform","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"conformed":{"conform","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"conforming":{"conform","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"conformist":{"conform","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"conformists":{"conform","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"conformity":{"conform","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"conforms":{"conform","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"nonconformist":{"non-conformity","conform","non-conformists","non-conformist","nonconformity","nonconformists","nonconformist","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"nonconformists":{"non-conformity","conform","non-conformists","non-conformist","nonconformity","nonconformists","nonconformist","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"nonconformity":{"non-conformity","conform","non-conformists","non-conformist","nonconformity","nonconformists","nonconformist","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"non-conformist":{"non-conformity","conform","non-conformists","non-conformist","nonconformity","nonconformists","nonconformist","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"non-conformists":{"non-conformity","conform","non-conformists","non-conformist","nonconformity","nonconformists","nonconformist","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"non-conformity":{"non-conformity","conform","non-conformists","non-conformist","nonconformity","nonconformists","nonconformist","conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"consent":{"consented","consenting","consents","consensus","consent"},
"consensus":{"consented","consenting","consents","consensus","consent"},
"consented":{"consented","consenting","consents","consensus","consent"},
"consenting":{"consented","consenting","consents","consensus","consent"},
"consents":{"consented","consenting","consents","consensus","consent"},
"consequent":{"consequent","consequences","consequently","consequence"},
"consequence":{"consequent","consequences","consequently","consequence"},
"consequences":{"consequent","consequences","consequently","consequence"},
"consequently":{"consequent","consequences","consequently","consequence"},
"considerable":{"considerable","considerably"},
"considerably":{"considerable","considerably"},
"consist":{"consists","consistency","consistent","consisting","consisted","consist","consistently"},
"consisted":{"consists","consistency","consistent","consisting","consisted","consist","consistently"},
"consistency":{"consists","consistency","consistent","consisting","consisted","consist","consistently"},
"consistent":{"consists","consistency","consistent","consisting","consisted","consist","consistently"},
"consistently":{"consists","consistency","consistent","consisting","consisted","consist","consistently"},
"consisting":{"consists","consistency","consistent","consisting","consisted","consist","consistently"},
"consists":{"consists","consistency","consistent","consisting","consisted","consist","consistently"},
"inconsistencies":{"consists","consistency","consistent","consisting","inconsistency","consisted","consist","inconsistencies","inconsistent","consistently"},
"inconsistency":{"consists","consistency","consistent","consisting","inconsistency","consisted","consist","inconsistencies","inconsistent","consistently"},
"inconsistent":{"consists","consistency","consistent","consisting","inconsistency","consisted","consist","inconsistencies","inconsistent","consistently"},
"constant":{"constantly","inconstantly","constancy","constant","constants"},
"constancy":{"constantly","inconstantly","constancy","constant","constants"},
"constantly":{"constantly","inconstantly","constancy","constant","constants"},
"constants":{"constantly","inconstantly","constancy","constant","constants"},
"inconstancy":{"inconstancy","constantly","inconstantly","constancy","constant","constants"},
"inconstantly":{"inconstancy","constantly","inconstantly","constancy","constant","constants"},
"constitute":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constituencies":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constituency":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constituent":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constituents":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constituted":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constitutes":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constituting":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constitution":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constitutions":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constitutional":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constitutionally":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"constitutive":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","constitutionally","constitutive","constituent","constitutional"},
"unconstitutional":{"constitute","constituencies","constituency","constitutes","constituents","constitution","constituted","constituting","constitutions","unconstitutional","constitutionally","constitutive","constituent","constitutional"},
"constrain":{"constraints","constraint","constrains","constraining","constrained","constrain"},
"constrained":{"constraints","constraint","constrains","constraining","constrained","constrain"},
"constraining":{"constraints","constraint","constrains","constraining","constrained","constrain"},
"constrains":{"constraints","constraint","constrains","constraining","constrained","constrain"},
"constraint":{"constraints","constraint","constrains","constraining","constrained","constrain"},
"constraints":{"constraints","constraint","constrains","constraining","constrained","constrain"},
"unconstrained":{"constraints","constraint","constrains","constraining","constrained","constrain","unconstrained"},
"construct":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"constructed":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"constructing":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"construction":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"constructions":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"constructive":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"constructs":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"reconstruct":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"reconstructed":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"reconstructing":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"reconstruction":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"reconstructs":{"reconstructs","constructive","constructions","reconstruct","construction","constructing","constructed","construct","constructs","reconstructing","reconstruction","reconstructed"},
"consult":{"consultant","consultancy","consult","consultation","consulted","consultants","consultations","consulting","consultative","consults"},
"consultancy":{"consultant","consultancy","consult","consultation","consulted","consultants","consultations","consulting","consultative","consults"},
"consultant":{"consultant","consultancy","consult","consultation","consulted","consultants","consultations","consulting","consultative","consults"},
"consultants":{"consultant","consultancy","consult","consultation","consulted","consultants","consultations","consulting","consultative","consults"},
"consultation":{"consultant","consultancy","consult","consultation","consulted","consultants","consultations","consulting","consultative","consults"},
"consultations":{"consultant","consultancy","consult","consultation","consulted","consultants","consultations","consulting","consultative","consults"},
"consultative":{"consultant","consultancy","consult","consultation","consulted","consultants","consultations","consulting","consultative","consults"},
"consulted":{"consultant","consultancy","consult","consultation","consulted","consultants","consultations","consulting","consultative","consults"},
"consults":{"consultant","consultancy","consult","consultation","consulted","consultants","consultations","consulting","consultative","consults"},
"consulting":{"consultant","consultancy","consult","consultation","consulted","consultants","consultations","consulting","consultative","consults"},
"consume":{"consuming","consumes","consumption","consume","consumed","consumers","consumer"},
"consumed":{"consuming","consumes","consumption","consume","consumed","consumers","consumer"},
"consumer":{"consuming","consumes","consumption","consume","consumed","consumers","consumer"},
"consumers":{"consuming","consumes","consumption","consume","consumed","consumers","consumer"},
"consumes":{"consuming","consumes","consumption","consume","consumed","consumers","consumer"},
"consuming":{"consuming","consumes","consumption","consume","consumed","consumers","consumer"},
"consumption":{"consuming","consumes","consumption","consume","consumed","consumers","consumer"},
"contact":{"contactable","contacted","contacting","contacts","contact"},
"contactable":{"contactable","contacted","contacting","contacts","contact"},
"contacted":{"contactable","contacted","contacting","contacts","contact"},
"contacting":{"contactable","contacted","contacting","contacts","contact"},
"contacts":{"contactable","contacted","contacting","contacts","contact"},
"contemporary":{"contemporary","contemporaries"},
"contemporaries":{"contemporary","contemporaries"},
"context":{"contextual","contexts","context"},
"contexts":{"contextual","contexts","context"},
"contextual":{"contextualise","contextualized","contextualizing","contextualize","contextualising","contextualised","contextual","contexts","context"},
"contextualise":{"contextualise","contextualized","contextualizing","contextualize","contextualising","contextualised","contextual","contexts","context"},
"contextualised":{"contextualise","contextualized","contextualizing","contextualize","contextualising","contextualised","contextual","contexts","context"},
"contextualising":{"contextualise","contextualized","contextualizing","contextualize","contextualising","contextualised","contextual","contexts","context"},
"contextualize":{"contextualise","contextualized","contextualizing","contextualize","uncontextualised","contextualising","contextualised","contextual","contexts","context"},
"contextualized":{"contextualise","contextualized","contextualizing","contextualize","uncontextualised","contextualising","contextualised","contextual","contexts","context"},
"contextualizing":{"contextualise","contextualized","contextualizing","contextualize","uncontextualised","contextualising","contextualised","contextual","contexts","context"},
"contract":{"contracted","contract","contracting","contracts"},
"contracted":{"contracted","contract","contracting","contracts"},
"contracting":{"contracted","contract","contracting","contracts"},
"contractor":{"contractor","contract","contractors"},
"contractors":{"contractor","contractors"},
"contracts":{"contracted","contract","contracting","contracts"},
"contradict":{"contradicted","contradict","contradicts","contradictory","contradictions","contradiction","contradicting"},
"contradicted":{"contradicted","contradict","contradicts","contradictory","contradictions","contradiction","contradicting"},
"contradicting":{"contradicted","contradict","contradicts","contradictory","contradictions","contradiction","contradicting"},
"contradiction":{"contradicted","contradict","contradicts","contradictory","contradictions","contradiction","contradicting"},
"contradictions":{"contradicted","contradict","contradicts","contradictory","contradictions","contradiction","contradicting"},
"contradictory":{"contradicted","contradict","contradicts","contradictory","contradictions","contradiction","contradicting"},
"contradicts":{"contradicted","contradict","contradicts","contradictory","contradictions","contradiction","contradicting"},
"contrary":{"contrarily","contrary"},
"contrarily":{"contrarily","contrary"},
"contrast":{"contrastive","contrasted","contrast","contrasting","contrasts"},
"contrasted":{"contrastive","contrasted","contrast","contrasting","contrasts"},
"contrasting":{"contrastive","contrasted","contrast","contrasting","contrasts"},
"contrastive":{"contrastive","contrasted","contrast","contrasting","contrasts"},
"contrasts":{"contrastive","contrasted","contrast","contrasting","contrasts"},
"contribute":{"contribute","contributed","contributors","contributes","contributing","contribution","contributions","contributor"},
"contributed":{"contribute","contributed","contributors","contributes","contributing","contribution","contributions","contributor"},
"contributes":{"contribute","contributed","contributors","contributes","contributing","contribution","contributions","contributor"},
"contributing":{"contribute","contributed","contributors","contributes","contributing","contribution","contributions","contributor"},
"contribution":{"contribute","contributed","contributors","contributes","contributing","contribution","contributions","contributor"},
"contributions":{"contribute","contributed","contributors","contributes","contributing","contribution","contributions","contributor"},
"contributor":{"contribute","contributed","contributors","contributes","contributing","contribution","contributions","contributor"},
"contributors":{"contribute","contributed","contributors","contributes","contributing","contribution","contributions","contributor"},
"controversy":{"controversial","controversy","controversies","controversially"},
"controversies":{"controversial","controversy","controversies","controversially"},
"controversial":{"controversial","controversy","controversies","controversially"},
"controversially":{"controversial","controversy","controversies","controversially"},
"uncontroversial":{"controversial","controversy","uncontroversial","controversies","controversially"},
"convene":{"convene","convenes","convened","convening"},
"convention":{"conventional","convention","conventionally","conventions"},
"convenes":{"convene","convenes","convened","convening"},
"convened":{"convene","convenes","convened","convening"},
"convening":{"convene","convenes","convened","convening"},
"conventional":{"conventional","convention","conventionally","conventions"},
"conventionally":{"conventional","convention","conventionally","conventions"},
"conventions":{"conventional","convention","conventionally","conventions"},
"unconventional":{"conventional","convention","conventionally","conventions","unconventional"},
"converse":{"converse","conversely"},
"conversely":{"converse","conversely"},
"convert":{"converts","converting","convertible","converted","conversion","convert","conversions"},
"conversion":{"converts","converting","convertible","converted","conversion","convert","conversions"},
"conversions":{"converts","converting","convertible","converted","conversion","convert","conversions"},
"converted":{"converts","converting","convertible","converted","conversion","convert","conversions"},
"convertible":{"converts","converting","convertible","converted","conversion","convert","conversions"},
"converting":{"converts","converting","convertible","converted","conversion","convert","conversions"},
"converts":{"converts","converting","convertible","converted","conversion","convert","conversions"},
"convince":{"convinces","convince","convinced","convincing","convincingly"},
"convinced":{"convinces","convince","convinced","convincing","convincingly"},
"convinces":{"convinces","convince","convinced","convincing","convincingly"},
"convincing":{"convinces","convince","convinced","convincing","convincingly"},
"convincingly":{"convinces","convince","convinced","convincing","convincingly"},
"unconvinced":{"convinces","unconvinced","convince","convinced","convincing","convincingly"},
"cooperate":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"cooperated":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"cooperates":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"cooperating":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"cooperation":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"cooperative":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"cooperatively":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"co-operate":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"co-operated":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"co-operates":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"co-operation":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"co-operative":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"co-operatively":{"cooperate","co-operative","co-operation","co-operates","co-operate","cooperatively","cooperative","cooperation","cooperating","cooperates","cooperated","co-operated","co-operatively"},
"coordinate":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"coordinated":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"coordinates":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"coordinating":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"coordination":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"coordinator":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"coordinators":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"co-ordinate":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"co-ordinated":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"co-ordinates":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"co-ordinating":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"co-ordination":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"co-ordinator":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"co-ordinators":{"co-ordinate","co-ordinated","coordinated","coordinators","coordinating","coordination","coordinator","coordinate","co-ordinates","co-ordinating","co-ordination","co-ordinator","co-ordinators","coordinates"},
"core":{"cores","core","cored","coring"},
"cores":{"cores","core","cored","coring"},
"coring":{"cores","core","cored","coring"},
"cored":{"cores","core","cored","coring"},
"corporate":{"corporates","corporations","corporation","corporate"},
"corporates":{"corporates","corporations","corporation","corporate"},
"corporation":{"corporates","corporations","corporation","corporate"},
"corporations":{"corporates","corporations","corporation","corporate"},
"correspond":{"correspondingly","correspondence","corresponded","corresponds","corresponding","correspond"},
"corresponded":{"correspondingly","correspondence","corresponded","corresponds","corresponding","correspond"},
"correspondence":{"correspondingly","correspondence","corresponded","corresponds","corresponding","correspond"},
"corresponding":{"correspondingly","correspondence","corresponded","corresponds","corresponding","correspond"},
"correspondingly":{"correspondingly","correspondence","corresponded","corresponds","corresponding","correspond"},
"corresponds":{"correspondingly","correspondence","corresponded","corresponds","corresponding","correspond"},
"couple":{"coupling","couples","coupled","couple"},
"coupled":{"coupling","couples","coupled","couple"},
"coupling":{"coupling","couples","coupled","couple"},
"couples":{"coupling","couples","coupled","couple"},
"create":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"created":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"creates":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"creating":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"creation":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"creations":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"creative":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"creatively":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"creativity":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"creator":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"creators":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"recreate":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"recreated":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"recreates":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"recreating":{"recreate","recreated","recreates","recreating","creators","creativity","creatively","creative","created","creator","creates","create","creation","creations","creating"},
"credit":{"credits","crediting","credited","credit"},
"credited":{"credits","crediting","credited","credit"},
"crediting":{"credits","crediting","credited","credit"},
"creditor":{"creditors","creditor"},
"creditors":{"creditors","creditor"},
"credits":{"credits","crediting","credited","credit"},
"criteria":{"criterion","criteria"},
"criterion":{"criterion","criteria"},
"crucial":{"crucially","crucial"},
"crucially":{"crucially","crucial"},
"culture":{"cultural","culturally","cultured","cultures","culture"},
"cultural":{"cultural","culturally","cultured","cultures","culture"},
"culturally":{"cultural","culturally","cultured","cultures","culture"},
"cultured":{"cultural","culturally","cultured","cultures","culture"},
"cultures":{"cultural","culturally","cultured","cultures","culture"},
"uncultured":{"uncultured","cultural","culturally","cultured","cultures","culture"},
"currency":{"currency","currencies"},
"currencies":{"currency","currencies"},
"cycle":{"cycle","cycled","cycles","cyclic","cyclical","cycling"},
"cycled":{"cycle","cycled","cycles","cyclic","cyclical","cycling"},
"cycles":{"cycle","cycled","cycles","cyclic","cyclical","cycling"},
"cyclic":{"cycle","cycled","cycles","cyclic","cyclical","cycling"},
"cyclical":{"cycle","cycled","cycles","cyclic","cyclical","cycling"},
"cycling":{"cycle","cycled","cycles","cyclic","cyclical","cycling"},
"debate":{"debates","debating","debatable","debated","debate"},
"debatable":{"debates","debating","debatable","debated","debate"},
"debated":{"debates","debating","debatable","debated","debate"},
"debates":{"debates","debating","debatable","debated","debate"},
"debating":{"debates","debating","debatable","debated","debate"},
"decade":{"decades","decade"},
"decades":{"decades","decade"},
"decline":{"decline","declined","declines","declining"},
"declined":{"decline","declined","declines","declining"},
"declines":{"decline","declined","declines","declining"},
"declining":{"decline","declined","declines","declining"},
"deduce":{"deduces","deducing","deduced","deduction","deductions","deduce"},
"deduced":{"deduces","deducing","deduced","deduction","deductions","deduce"},
"deduces":{"deduces","deducing","deduced","deduction","deductions","deduce"},
"deducing":{"deduces","deducing","deduced","deduction","deductions","deduce"},
"deduction":{"deduces","deducing","deduced","deduction","deductions","deduce"},
"deductions":{"deduces","deducing","deduced","deduction","deductions","deduce"},
"define":{"definition","defined","defines","definitions","defining","redefine","redefined","redefines","redefining","definable","define"},
"definable":{"definition","defined","defines","definitions","defining","redefine","redefined","redefines","redefining","definable","define"},
"defined":{"definition","defined","defines","definitions","defining","redefine","redefined","redefines","redefining","definable","define"},
"defines":{"definition","defined","defines","definitions","defining","redefine","redefined","redefines","redefining","definable","define"},
"defining":{"definition","defined","defines","definitions","defining","redefine","redefined","redefines","redefining","definable","define"},
"definition":{"definition","defined","defines","definitions","defining","redefine","redefined","redefines","redefining","definable","define"},
"definitions":{"definition","defined","defines","definitions","defining","redefine","redefined","redefines","redefining","definable","define"},
"redefine":{"definition","defined","defines","definitions","defining","redefine","redefined","redefines","redefining","definable","define"},
"redefined":{"definition","defined","defines","definitions","defining","redefine","redefined","redefines","redefining","definable","define"},
"redefines":{"definition","defined","defines","definitions","defining","redefine","redefined","redefines","redefining","definable","define"},
"redefining":{"definition","defined","defines","definitions","defining","redefine","redefined","redefines","redefining","definable","define"},
"definite":{"definitive","definitely","definite"},
"definitely":{"definitive","definitely","definite"},
"definitive":{"definitive","definitely","definite"},
"indefinite":{"indefinite","definitive","definitely","definite","indefinitely"},
"indefinitely":{"indefinite","definitive","definitely","definite","indefinitely"},
"demonstrate":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"demonstrable":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"demonstrably":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"demonstrated":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"demonstrates":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"demonstrating":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"demonstration":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"demonstrations":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"demonstrative":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"demonstratively":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"demonstrator":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"demonstrators":{"demonstrate","demonstrators","demonstrator","demonstratively","demonstrative","demonstrations","demonstration","demonstrating","demonstrates","demonstrated","demonstrably","demonstrable"},
"denote":{"denoted","denotation","denoting","denote","denotations","denotes"},
"denotation":{"denoted","denotation","denoting","denote","denotations","denotes"},
"denotations":{"denoted","denotation","denoting","denote","denotations","denotes"},
"denoted":{"denoted","denotation","denoting","denote","denotations","denotes"},
"denotes":{"denoted","denotation","denoting","denote","denotations","denotes"},
"denoting":{"denoted","denotation","denoting","denote","denotations","denotes"},
"deny":{"denials","denies","denial","deny","denying","denied","deniable"},
"deniable":{"denials","denies","denial","deny","denying","denied","deniable"},
"denial":{"denials","denies","denial","deny","denying","denied","deniable"},
"denials":{"denials","denies","denial","deny","denying","denied","deniable"},
"denied":{"denials","denies","denial","deny","denying","denied","deniable"},
"denies":{"denials","denies","denial","deny","denying","denied","deniable"},
"denying":{"denials","denies","denial","deny","denying","denied","deniable"},
"undeniable":{"undeniably"},
"depress":{"depressing","depression","depressed","depress","depresses"},
"depressed":{"depressing","depression","depressed","depress","depresses"},
"depresses":{"depressing","depression","depressed","depress","depresses"},
"depressing":{"depressing","depression","depressed","depress","depresses"},
"depression":{"depressing","depression","depressed","depress","depresses"},
"derive":{"derive","derivation","derivations","derives","derivative","derivatives","derived","deriving"},
"derivation":{"derive","derivation","derivations","derives","derivative","derivatives","derived","deriving"},
"derivations":{"derive","derivation","derivations","derives","derivative","derivatives","derived","deriving"},
"derivative":{"derive","derivation","derivations","derives","derivative","derivatives","derived","deriving"},
"derivatives":{"derive","derivation","derivations","derives","derivative","derivatives","derived","deriving"},
"derived":{"derive","derivation","derivations","derives","derivative","derivatives","derived","deriving"},
"derives":{"derive","derivation","derivations","derives","derivative","derivatives","derived","deriving"},
"deriving":{"derive","derivation","derivations","derives","derivative","derivatives","derived","deriving"},
"design":{"designs","designers","designed","design","designer","designing"},
"designed":{"designs","designers","designed","design","designer","designing"},
"designer":{"designs","designers","designed","design","designer","designing"},
"designers":{"designs","designers","designed","design","designer","designing"},
"designing":{"designs","designers","designed","design","designer","designing"},
"designs":{"designs","designers","designed","design","designer","designing"},
"detect":{"detects","detective","detect","detection","detecting","detected","detectable","detector","detectors","detectives"},
"detectable":{"detects","detective","detect","detection","detecting","detected","detectable","detector","detectors","detectives"},
"detected":{"detects","detective","detect","detection","detecting","detected","detectable","detector","detectors","detectives"},
"detecting":{"detects","detective","detect","detection","detecting","detected","detectable","detector","detectors","detectives"},
"detection":{"detects","detective","detect","detection","detecting","detected","detectable","detector","detectors","detectives"},
"detective":{"detects","detective","detect","detection","detecting","detected","detectable","detector","detectors","detectives"},
"detectives":{"detects","detective","detect","detection","detecting","detected","detectable","detector","detectors","detectives"},
"detector":{"detects","detective","detect","detection","detecting","detected","detectable","detector","detectors","detectives"},
"detectors":{"detects","detective","detect","detection","detecting","detected","detectable","detector","detectors","detectives"},
"detects":{"detects","detective","detect","detection","detecting","detected","detectable","detector","detectors","detectives"},
"deviate":{"deviation","deviate","deviated","deviates","deviating","deviations"},
"deviated":{"deviation","deviate","deviated","deviates","deviating","deviations"},
"deviates":{"deviation","deviate","deviated","deviates","deviating","deviations"},
"deviating":{"deviation","deviate","deviated","deviates","deviating","deviations"},
"deviation":{"deviation","deviate","deviated","deviates","deviating","deviations"},
"deviations":{"deviation","deviate","deviated","deviates","deviating","deviations"},
"device":{"device","devices"},
"devices":{"device","devices"},
"devote":{"devotedly","devotes","devotion","devoting","devoted","devote","devotions"},
"devoted":{"devotedly","devotes","devotion","devoting","devoted","devote","devotions"},
"devotedly":{"devotedly","devotes","devotion","devoting","devoted","devote","devotions"},
"devotes":{"devotedly","devotes","devotion","devoting","devoted","devote","devotions"},
"devoting":{"devotedly","devotes","devotion","devoting","devoted","devote","devotions"},
"devotion":{"devotedly","devotes","devotion","devoting","devoted","devote","devotions"},
"devotions":{"devotedly","devotes","devotion","devoting","devoted","devote","devotions"},
"differentiate":{"differentiating","differentiate","differentiation","differentiates","differentiated"},
"differentiated":{"differentiating","differentiate","differentiation","differentiates","differentiated"},
"differentiates":{"differentiating","differentiate","differentiation","differentiates","differentiated"},
"differentiating":{"differentiating","differentiate","differentiation","differentiates","differentiated"},
"differentiation":{"differentiating","differentiate","differentiation","differentiates","differentiated"},
"dimension":{"dimensions","dimensional","dimension","multidimensional"},
"dimensional":{"dimensions","dimensional","dimension","multidimensional"},
"dimensions":{"dimensions","dimensional","dimension","multidimensional"},
"multidimensional":{"dimensions","dimensional","dimension","multidimensional"},
"diminish":{"undiminished","diminution","diminishing","diminish","diminishes","diminished"},
"diminished":{"undiminished","diminution","diminishing","diminish","diminishes","diminished"},
"diminishes":{"undiminished","diminution","diminishing","diminish","diminishes","diminished"},
"diminishing":{"undiminished","diminution","diminishing","diminish","diminishes","diminished"},
"diminution":{"undiminished","diminution","diminishing","diminish","diminishes","diminished"},
"undiminished":{"undiminished","diminution","diminishing","diminish","diminishes","diminished"},
"discrete":{"discrete","discretely","discretion","discretionary"},
"discretely":{"discrete","discretely","discretion","discretionary"},
"discretion":{"discrete","discretely","discretion","discretionary"},
"discretionary":{"discrete","discretely","discretion","discretionary"},
"indiscretion":{"discrete","discretely","discretion","discretionary","indiscrete","indiscretion"},
"discriminate":{"discriminate","discriminated","discriminates","discriminating","discrimination"},
"discriminated":{"discriminate","discriminated","discriminates","discriminating","discrimination"},
"discriminates":{"discriminate","discriminated","discriminates","discriminating","discrimination"},
"discriminating":{"discriminate","discriminated","discriminates","discriminating","discrimination"},
"discrimination":{"discriminate","discriminated","discriminates","discriminating","discrimination"},
"displace":{"displacing","displaces","displacement","displaced","displace"},
"displaced":{"displacing","displaces","displacement","displaced","displace"},
"displacement":{"displacing","displaces","displacement","displaced","displace"},
"displaces":{"displacing","displaces","displacement","displaced","displace"},
"displacing":{"displacing","displaces","displacement","displaced","displace"},
"display":{"displays","displayed","displaying","display"},
"displayed":{"displays","displayed","displaying","display"},
"displaying":{"displays","displayed","displaying","display"},
"displays":{"displays","displayed","displaying","display"},
"dispose":{"disposing","disposes","disposed","disposal","disposable","dispose"},
"disposable":{"disposing","disposes","disposed","disposal","disposable","dispose"},
"disposal":{"disposing","disposes","disposed","disposal","disposable","dispose"},
"disposed":{"disposing","disposes","disposed","disposal","disposable","dispose"},
"disposes":{"disposing","disposes","disposed","disposal","disposable","dispose"},
"disposing":{"disposing","disposes","disposed","disposal","disposable","dispose"},
"distinct":{"distinctive","distinctively","distinct","distinction","distinctions","distinctly"},
"distinction":{"distinctive","distinctively","distinct","distinction","distinctions","distinctly"},
"distinctions":{"distinctive","distinctively","distinct","distinction","distinctions","distinctly"},
"distinctive":{"distinctive","distinctively","distinct","distinction","distinctions","distinctly"},
"distinctively":{"distinctive","distinctively","distinct","distinction","distinctions","distinctly"},
"distinctly":{"distinctive","distinctively","distinct","distinction","distinctions","distinctly"},
"indistinct":{"distinctive","distinctively","distinct","distinction","distinctions","indistinctly","indistinct","distinctly"},
"indistinctly":{"distinctive","distinctively","distinct","distinction","distinctions","indistinctly","indistinct","distinctly"},
"distort":{"distorted","distorts","distortion","distorting","distort","distortions"},
"distorted":{"distorted","distorts","distortion","distorting","distort","distortions"},
"distorting":{"distorted","distorts","distortion","distorting","distort","distortions"},
"distortion":{"distorted","distorts","distortion","distorting","distort","distortions"},
"distortions":{"distorted","distorts","distortion","distorting","distort","distortions"},
"distorts":{"distorted","distorts","distortion","distorting","distort","distortions"},
"distribute":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"distributed":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"distributing":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"distribution":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"distributional":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"distributions":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"distributive":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"distributor":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"distributors":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"redistribute":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"redistributed":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"redistributes":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"redistributing":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"redistribution":{"distributors","redistribute","redistributes","distribution","redistributing","redistribution","distributor","distributive","distributions","distributional","redistributed","distributed","distribute","distributing"},
"diverse":{"diversity","diversifying","diversify","diversifies","diversified","diversification","diversely","diverse"},
"diversely":{"diversity","diversifying","diversify","diversifies","diversified","diversification","diversely","diverse"},
"diversification":{"diversity","diversifying","diversify","diversifies","diversified","diversification","diversely","diverse"},
"diversified":{"diversity","diversifying","diversify","diversifies","diversified","diversification","diversely","diverse"},
"diversifies":{"diversity","diversifying","diversify","diversifies","diversified","diversification","diversely","diverse"},
"diversify":{"diversity","diversifying","diversify","diversifies","diversified","diversification","diversely","diverse"},
"diversifying":{"diversity","diversifying","diversify","diversifies","diversified","diversification","diversely","diverse"},
"diversity":{"diversity","diversifying","diversify","diversifies","diversified","diversification","diversely","diverse"},
"document":{"documentation","documenting","document","documented","documents"},
"documentation":{"documentation","documenting","document","documented","documents"},
"documented":{"documentation","documenting","document","documented","documents"},
"documenting":{"documentation","documenting","document","documented","documents"},
"documents":{"documentation","documenting","document","documented","documents"},
"domain":{"domains","domain"},
"domains":{"domains","domain"},
"domestic":{"domesticating","domesticated","domesticate","domestically","domestics","domestic"},
"domestically":{"domesticating","domesticated","domesticate","domestically","domestics","domestic"},
"domesticate":{"domesticating","domesticated","domesticate","domestically","domestics","domestic"},
"domesticated":{"domesticating","domesticated","domesticate","domestically","domestics","domestic"},
"domesticating":{"domesticating","domesticated","domesticate","domestically","domestics","domestic"},
"domestics":{"domesticating","domesticated","domesticate","domestically","domestics","domestic"},
"dominate":{"dominate","domination","dominating","dominated","dominant","dominance","dominates"},
"dominance":{"dominate","domination","dominating","dominated","dominant","dominance","dominates"},
"dominant":{"dominate","domination","dominating","dominated","dominant","dominance","dominates"},
"dominated":{"dominate","domination","dominating","dominated","dominant","dominance","dominates"},
"dominates":{"dominate","domination","dominating","dominated","dominant","dominance","dominates"},
"dominating":{"dominate","domination","dominating","dominated","dominant","dominance","dominates"},
"domination":{"dominate","domination","dominating","dominated","dominant","dominance","dominates"},
"draft":{"redrafted","draft","redrafts","redrafting","redraft","drafts","drafting","drafted"},
"drafted":{"redrafted","draft","redrafts","redrafting","redraft","drafts","drafting","drafted"},
"drafting":{"redrafted","draft","redrafts","redrafting","redraft","drafts","drafting","drafted"},
"drafts":{"redrafted","draft","redrafts","redrafting","redraft","drafts","drafting","drafted"},
"redraft":{"redrafted","draft","redrafts","redrafting","redraft","drafts","drafting","drafted"},
"redrafted":{"redrafted","draft","redrafts","redrafting","redraft","drafts","drafting","drafted"},
"redrafting":{"redrafted","draft","redrafts","redrafting","redraft","drafts","drafting","drafted"},
"redrafts":{"redrafted","draft","redrafts","redrafting","redraft","drafts","drafting","drafted"},
"drama":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramas":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatic":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatically":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatise":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatised":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatising":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatises":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatisation":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatisations":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatist":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatists":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatization":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatizations":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatize":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatized":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatizes":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dramatizing":{"dramatist","dramatization","dramatizations","dramatize","dramatized","dramatising","dramatisation","dramatists","dramatizes","dramatizing","dramatisations","dramatises","drama","dramas","dramatic","dramatically","dramatise","dramatised"},
"dynamic":{"dynamically","dynamic","dynamics"},
"dynamically":{"dynamically","dynamic","dynamics"},
"dynamics":{"dynamically","dynamic","dynamics"},
"economy":{"economics","economically","economist","economic","economy","economical","economies","economists"},
"economic":{"economics","economically","economist","economic","economy","economical","economies","economists"},
"economical":{"economics","economically","economist","economic","economy","economical","economies","economists"},
"economically":{"economics","economically","economist","economic","economy","economical","economies","economists"},
"economics":{"economics","economically","economist","economic","economy","economical","economies","economists"},
"economies":{"economics","economically","economist","economic","economy","economical","economies","economists"},
"economist":{"economics","economically","economist","economic","economy","economical","economies","economists"},
"economists":{"economics","economically","economist","economic","economy","economical","economies","economists"},
"uneconomical":{"economics","economically","economist","economic","uneconomical","economy","economical","economies","economists"},
"edit":{"editor","edit","edited","editing","editions","edition","editorial","editorials","editors","edits"},
"edited":{"editor","edit","edited","editing","editions","edition","editorial","editorials","editors","edits"},
"editing":{"editor","edit","edited","editing","editions","edition","editorial","editorials","editors","edits"},
"edition":{"editor","edit","edited","editing","editions","edition","editorial","editorials","editors","edits"},
"editions":{"editor","edit","edited","editing","editions","edition","editorial","editorials","editors","edits"},
"editor":{"editor","edit","edited","editing","editions","edition","editorial","editorials","editors","edits"},
"editorial":{"editor","edit","edited","editing","editions","edition","editorial","editorials","editors","edits"},
"editorials":{"editor","edit","edited","editing","editions","edition","editorial","editorials","editors","edits"},
"editors":{"editor","edit","edited","editing","editions","edition","editorial","editorials","editors","edits"},
"edits":{"editor","edit","edited","editing","editions","edition","editorial","editorials","editors","edits"},
"element":{"elements","element"},
"elements":{"elements","element"},
"eliminate":{"elimination","eliminated","eliminating","eliminates","eliminate"},
"eliminated":{"elimination","eliminated","eliminating","eliminates","eliminate"},
"eliminates":{"elimination","eliminated","eliminating","eliminates","eliminate"},
"eliminating":{"elimination","eliminated","eliminating","eliminates","eliminate"},
"elimination":{"elimination","eliminated","eliminating","eliminates","eliminate"},
"emerge":{"emerges","emergence","emerging","emerged","emergent","emerge"},
"emerged":{"emerges","emergence","emerging","emerged","emergent","emerge"},
"emergence":{"emerges","emergence","emerging","emergent","emerged","emerge"},
"emergent":{"emerges","emergence","emerging","emergent","emerged","emerge"},
"emerges":{"emerges","emergence","emerging","emergent","emerged","emerge"},
"emerging":{"emerges","emergence","emerging","emergent","emerged","emerge"},
"emphasis":{"emphasizing","emphatic","emphatically","emphasizes","emphasized","emphasising","emphasised","emphasise","emphasis","emphasize"},
"emphasise":{"emphasizing","emphatic","emphatically","emphasizes","emphasized","emphasising","emphasised","emphasise","emphasis","emphasize"},
"emphasised":{"emphasizing","emphatic","emphatically","emphasizes","emphasized","emphasising","emphasised","emphasise","emphasis","emphasize"},
"emphasising":{"emphasizing","emphatic","emphatically","emphasizes","emphasized","emphasising","emphasised","emphasise","emphasis","emphasize"},
"emphasize":{"emphasizing","emphatic","emphatically","emphasizes","emphasized","emphasising","emphasised","emphasise","emphasis","emphasize"},
"emphasized":{"emphasizing","emphatic","emphatically","emphasizes","emphasized","emphasising","emphasised","emphasise","emphasis","emphasize"},
"emphasizes":{"emphasizing","emphatic","emphatically","emphasizes","emphasized","emphasising","emphasised","emphasise","emphasis","emphasize"},
"emphasizing":{"emphasizing","emphatic","emphatically","emphasizes","emphasized","emphasising","emphasised","emphasise","emphasis","emphasize"},
"emphatic":{"emphasizing","emphatic","emphatically","emphasizes","emphasized","emphasising","emphasised","emphasise","emphasis","emphasize"},
"emphatically":{"emphasizing","emphatic","emphatically","emphasizes","emphasized","emphasising","emphasised","emphasise","emphasis","emphasize"},
"empirical":{"empirical","empirically","empiricism"},
"empirically":{"empirical","empirically","empiricism"},
"empiricism":{"empirical","empirically","empiricism"},
"enable":{"enabling","enable","enabled","enables"},
"enabled":{"enabling","enable","enabled","enables"},
"enables":{"enabling","enable","enabled","enables"},
"enabling":{"enabling","enable","enabled","enables"},
"encounter":{"encountered","encounter","encountering","encounters"},
"encountered":{"encountered","encounter","encountering","encounters"},
"encountering":{"encountered","encounter","encountering","encounters"},
"encounters":{"encountered","encounter","encountering","encounters"},
"energy":{"energy","energetic","energies","energetically"},
"energetic":{"energy","energetic","energies","energetically"},
"energetically":{"energy","energetic","energies","energetically"},
"energies":{"energy","energetic","energies","energetically"},
"enforce":{"enforced","enforcement","enforces","enforcing","enforce"},
"enforced":{"enforced","enforcement","enforces","enforcing","enforce"},
"enforcement":{"enforced","enforcement","enforces","enforcing","enforce"},
"enforces":{"enforced","enforcement","enforces","enforcing","enforce"},
"enforcing":{"enforced","enforcement","enforces","enforcing","enforce"},
"enhance":{"enhancing","enhances","enhance","enhanced","enhancement"},
"enhanced":{"enhancing","enhances","enhance","enhanced","enhancement"},
"enhancement":{"enhancing","enhances","enhance","enhanced","enhancement"},
"enhances":{"enhancing","enhances","enhance","enhanced","enhancement"},
"enhancing":{"enhancing","enhances","enhance","enhanced","enhancement"},
"enormous":{"enormously","enormity","enormous"},
"enormity":{"enormously","enormity","enormous"},
"enormously":{"enormously","enormity","enormous"},
"ensure":{"ensure","ensured","ensures","ensuring"},
"ensured":{"ensure","ensured","ensures","ensuring"},
"ensures":{"ensure","ensured","ensures","ensuring"},
"ensuring":{"ensure","ensured","ensures","ensuring"},
"entity":{"entity","entities"},
"entities":{"entity","entities"},
"environment":{"environmentally","environmentalist","environmental","environment","environments","environmentalists"},
"environmental":{"environmentally","environmentalist","environmental","environment","environments","environmentalists"},
"environmentalist":{"environmentally","environmentalist","environmental","environment","environments","environmentalists"},
"environmentalists":{"environmentally","environmentalist","environmental","environment","environments","environmentalists"},
"environmentally":{"environmentally","environmentalist","environmental","environment","environments","environmentalists"},
"environments":{"environmentally","environmentalist","environmental","environment","environments","environmentalists"},
"equate":{"equating","equates","equated","equation","equate","equations"},
"equated":{"equating","equates","equated","equation","equate","equations"},
"equates":{"equating","equates","equated","equation","equate","equations"},
"equating":{"equating","equates","equated","equation","equate","equations"},
"equation":{"equating","equates","equated","equation","equate","equations"},
"equations":{"equating","equates","equated","equation","equate","equations"},
"equip":{"equip","equipping","equipped","equipment","equips"},
"equipment":{"equip","equipping","equipped","equipment","equips"},
"equipped":{"equip","equipping","equipped","equipment","equips"},
"equipping":{"equip","equipping","equipped","equipment","equips"},
"equips":{"equip","equipping","equipped","equipment","equips"},
"equivalent":{"equivalence","equivalent"},
"equivalence":{"equivalence","equivalent"},
"erode":{"erode","eroding","erosion","erodes","eroded"},
"eroded":{"erode","eroding","erosion","erodes","eroded"},
"erodes":{"erode","eroding","erosion","erodes","eroded"},
"eroding":{"erode","eroding","erosion","erodes","eroded"},
"erosion":{"erode","eroding","erosion","erodes","eroded"},
"error":{"erroneous","erroneously","errors","error"},
"erroneous":{"erroneous","erroneously","errors","error"},
"erroneously":{"erroneous","erroneously","errors","error"},
"errors":{"erroneous","erroneously","errors","error"},
"establish":{"establishment","establishing","establishes","established","establish","establishments"},
"disestablish":{"establishment","establishing","establishes","established","disestablishment","disestablishing","disestablishes","disestablished","disestablish","establish","establishments"},
"disestablished":{"establishment","establishing","establishes","established","disestablishment","disestablishing","disestablishes","disestablished","disestablish","establish","establishments"},
"disestablishes":{"establishment","establishing","establishes","established","disestablishment","disestablishing","disestablishes","disestablished","disestablish","establish","establishments"},
"disestablishing":{"establishment","establishing","establishes","established","disestablishment","disestablishing","disestablishes","disestablished","disestablish","establish","establishments"},
"disestablishment":{"establishment","establishing","establishes","established","disestablishment","disestablishing","disestablishes","disestablished","disestablish","establish","establishments"},
"established":{"establishment","establishing","establishes","established","establish","establishments"},
"establishes":{"establishment","establishing","establishes","established","establish","establishments"},
"establishing":{"establishment","establishing","establishes","established","establish","establishments"},
"establishment":{"establishment","establishing","establishes","established","establish","establishments"},
"establishments":{"establishment","establishing","establishes","established","establish","establishments"},
"estate":{"estates","estate"},
"estates":{"estates","estate"},
"estimate":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"estimated":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"estimates":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"estimating":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"estimation":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"estimations":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"over-estimate":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"overestimate":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"overestimated":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"overestimates":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"overestimating":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"underestimate":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"underestimated":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"underestimates":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"underestimating":{"estimated","overestimates","overestimating","underestimate","underestimates","underestimating","underestimated","overestimated","overestimate","over-estimate","estimations","estimation","estimating","estimates","estimate"},
"ethic":{"ethics","ethically","ethic","ethical"},
"ethical":{"ethics","ethically","ethic","ethical"},
"ethically":{"ethics","ethically","ethic","ethical"},
"ethics":{"ethics","ethically","ethic","ethical"},
"unethical":{"unethical","ethics","ethically","ethic","ethical"},
"ethnic":{"ethnic","ethnicity"},
"ethnicity":{"ethnic","ethnicity"},
"evaluate":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"evaluated":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"evaluates":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"evaluating":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"evaluation":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"evaluations":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"evaluative":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"re-evaluate":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"re-evaluated":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"re-evaluates":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"re-evaluating":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"re-evaluation":{"re-evaluating","re-evaluation","re-evaluates","re-evaluated","re-evaluate","evaluative","evaluate","evaluations","evaluation","evaluating","evaluates","evaluated"},
"eventual":{"eventually","eventuality","eventual"},
"eventuality":{"eventually","eventuality","eventual"},
"eventually":{"eventually","eventuality","eventual"},
"evident":{"evident","evidenced","evidence","evidential","evidently"},
"evidenced":{"evident","evidenced","evidence","evidential","evidently"},
"evidence":{"evident","evidenced","evidence","evidential","evidently"},
"evidential":{"evident","evidenced","evidence","evidential","evidently"},
"evidently":{"evident","evidenced","evidence","evidential","evidently"},
"evolve":{"evolutionary","evolve","evolutionists","evolution","evolved","evolving","evolves","evolutionist"},
"evolution":{"evolutionary","evolve","evolutionists","evolution","evolved","evolving","evolves","evolutionist"},
"evolved":{"evolutionary","evolve","evolutionists","evolution","evolved","evolving","evolves","evolutionist"},
"evolving":{"evolutionary","evolve","evolutionists","evolution","evolved","evolving","evolves","evolutionist"},
"evolves":{"evolutionary","evolve","evolutionists","evolution","evolved","evolving","evolves","evolutionist"},
"evolutionary":{"evolutionary","evolve","evolutionists","evolution","evolved","evolving","evolves","evolutionist"},
"evolutionist":{"evolutionary","evolve","evolutionists","evolution","evolved","evolving","evolves","evolutionist"},
"evolutionists":{"evolutionary","evolve","evolutionists","evolution","evolved","evolving","evolves","evolutionist"},
"exceed":{"exceed","exceeds","exceeding","exceeded"},
"exceeded":{"exceed","exceeds","exceeding","exceeded"},
"exceeding":{"exceed","exceeds","exceeding","exceeded"},
"exceeds":{"exceed","exceeds","exceeding","exceeded"},
"exclude":{"exclusions","exclusionist","exclusion","excluding","excludes","excluded","exclusive","exclusively","exclusionary","exclude"},
"excluded":{"exclusions","exclusionist","exclusion","excluding","excludes","excluded","exclusive","exclusively","exclusionary","exclude"},
"excludes":{"exclusions","exclusionist","exclusion","excluding","excludes","excluded","exclusive","exclusively","exclusionary","exclude"},
"excluding":{"exclusions","exclusionist","exclusion","excluding","excludes","excluded","exclusive","exclusively","exclusionary","exclude"},
"exclusion":{"exclusions","exclusionist","exclusion","excluding","excludes","excluded","exclusive","exclusively","exclusionary","exclude"},
"exclusionary":{"exclusions","exclusionist","exclusion","excluding","excludes","excluded","exclusive","exclusively","exclusionary","exclude"},
"exclusions":{"exclusions","exclusionist","exclusion","excluding","excludes","excluded","exclusive","exclusively","exclusionary","exclude"},
"exclusive":{"exclusions","exclusionist","exclusion","excluding","excludes","excluded","exclusive","exclusively","exclusionary","exclude"},
"exclusively":{"exclusions","exclusionist","exclusion","excluding","excludes","excluded","exclusive","exclusively","exclusionary","exclude"},
"exhibit":{"exhibition","exhibit","exhibited","exhibitions","exhibits","exhibiting"},
"exhibited":{"exhibition","exhibit","exhibited","exhibitions","exhibits","exhibiting"},
"exhibiting":{"exhibition","exhibit","exhibited","exhibitions","exhibits","exhibiting"},
"exhibition":{"exhibition","exhibit","exhibited","exhibitions","exhibits","exhibiting"},
"exhibitions":{"exhibition","exhibit","exhibited","exhibitions","exhibits","exhibiting"},
"exhibits":{"exhibition","exhibit","exhibited","exhibitions","exhibits","exhibiting"},
"expand":{"expansion","expansive","expansionism","expanding","expand","expanded","expands"},
"expanded":{"expansion","expansive","expansionism","expanding","expand","expanded","expands"},
"expanding":{"expansion","expansive","expansionism","expanding","expand","expanded","expands"},
"expands":{"expansion","expansive","expansionism","expanding","expand","expanded","expands"},
"expansion":{"expansion","expansive","expansionism","expanding","expand","expanded","expands"},
"expansionism":{"expansion","expansive","expansionism","expanding","expand","expanded","expands"},
"expansive":{"expansion","expansive","expansionism","expanding","expand","expanded","expands"},
"expert":{"experts","expertly","expertise","expert"},
"expertise":{"experts","expertly","expertise","expert"},
"expertly":{"experts","expertly","expertise","expert"},
"experts":{"experts","expertly","expertise","expert"},
"explicit":{"explicitly","explicit"},
"explicitly":{"explicitly","explicit"},
"exploit":{"exploitation","exploit","exploited","exploiting","exploits"},
"exploitation":{"exploitation","exploit","exploited","exploiting","exploits"},
"exploited":{"exploitation","exploit","exploited","exploiting","exploits"},
"exploiting":{"exploitation","exploit","exploited","exploiting","exploits"},
"exploits":{"exploitation","exploit","exploited","exploiting","exploits"},
"export":{"exporters","exports","exporter","exported","export","exporting"},
"exported":{"exporters","exports","exporter","exported","export","exporting"},
"exporter":{"exporters","exports","exporter","exported","export","exporting"},
"exporters":{"exporters","exports","exporter","exported","export","exporting"},
"exporting":{"exporters","exports","exporter","exported","export","exporting"},
"exports":{"exporters","exports","exporter","exported","export","exporting"},
"expose":{"expose","exposures","exposure","exposing","exposes","exposed"},
"exposed":{"expose","exposures","exposure","exposing","exposes","exposed"},
"exposes":{"expose","exposures","exposure","exposing","exposes","exposed"},
"exposing":{"expose","exposures","exposure","exposing","exposes","exposed"},
"exposure":{"expose","exposures","exposure","exposing","exposes","exposed"},
"exposures":{"expose","exposures","exposure","exposing","exposes","exposed"},
"external":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"externalisation":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"externalise":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"externalised":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"externalises":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"externalising":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"externalization":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"externalize":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"externalized":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"externalizes":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"externalizing":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"externally":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"extract":{"extracts","extracted","extract","extracting","extraction"},
"extracted":{"extracts","extracted","extract","extracting","extraction"},
"extracting":{"extracts","extracted","extract","extracting","extraction"},
"extraction":{"extracts","extracted","extract","extracting","extraction"},
"extracts":{"extracts","extracted","extract","extracting","extraction"},
"facilitate":{"facilitation","facilities","facilitates","facilitate","facilitated","facilitating","facility","facilitators","facilitator"},
"facilitated":{"facilitation","facilities","facilitates","facilitate","facilitated","facilitating","facility","facilitators","facilitator"},
"facilitates":{"facilitation","facilities","facilitates","facilitate","facilitated","facilitating","facility","facilitators","facilitator"},
"facilities":{"facilitation","facilities","facilitates","facilitate","facilitated","facilitating","facility","facilitators","facilitator"},
"facilitating":{"facilitation","facilities","facilitates","facilitate","facilitated","facilitating","facility","facilitators","facilitator"},
"facilitation":{"facilitation","facilities","facilitates","facilitate","facilitated","facilitating","facility","facilitators","facilitator"},
"facilitator":{"facilitation","facilities","facilitates","facilitate","facilitated","facilitating","facility","facilitators","facilitator"},
"facilitators":{"facilitation","facilities","facilitates","facilitate","facilitated","facilitating","facility","facilitators","facilitator"},
"facility":{"facilitation","facilities","facilitates","facilitate","facilitated","facilitating","facility","facilitators","facilitator"},
"factor":{"factoring","factored","factor","factors"},
"factored":{"factoring","factored","factor","factors"},
"factoring":{"factoring","factored","factor","factors"},
"factors":{"factoring","factored","factor","factors"},
"feature":{"featuring","features","featured","feature"},
"featured":{"featuring","features","featured","feature"},
"features":{"featuring","features","featured","feature"},
"featuring":{"featuring","features","featured","feature"},
"federal":{"federations","federation","federal"},
"federation":{"federations","federation","federal"},
"federations":{"federations","federation","federal"},
"fee":{"fees","fee"},
"fees":{"fees","fee"},
"file":{"filed","files","filing","file"},
"filed":{"filed","files","filing","file"},
"files":{"filed","files","filing","file"},
"filing":{"filed","files","filing","file"},
"final":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finalise":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finalised":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finalises":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finalising":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finalize":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finalized":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finalizes":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finalizing":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finality":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finally":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finals":{"final","finalise","finalised","finalises","finalising","finalize","finalized","finalizes","finalizing","finality","finally","finals"},
"finance":{"financing","financiers","financier","financially","financial","finances","financed","finance"},
"financed":{"financing","financiers","financier","financially","financial","finances","financed","finance"},
"finances":{"financing","financiers","financier","financially","financial","finances","financed","finance"},
"financial":{"financing","financiers","financier","financially","financial","finances","financed","finance"},
"financially":{"financing","financiers","financier","financially","financial","finances","financed","finance"},
"financier":{"financing","financiers","financier","financially","financial","finances","financed","finance"},
"financiers":{"financing","financiers","financier","financially","financial","finances","financed","finance"},
"financing":{"financing","financiers","financier","financially","financial","finances","financed","finance"},
"finite":{"infinite","finite"},
"infinite":{"infinitely","infinite","finite"},
"infinitely":{"infinitely","infinite","finite"},
"flexible":{"inflexibility","flexibility","flexible"},
"flexibility":{"inflexibility","flexibility","flexible"},
"inflexible":{"inflexible","inflexibility","flexibility","flexible"},
"inflexibility":{"inflexible","inflexibility","flexibility","flexible"},
"fluctuate":{"fluctuated","fluctuating","fluctuates","fluctuate","fluctuations","fluctuation"},
"fluctuated":{"fluctuated","fluctuating","fluctuates","fluctuate","fluctuations","fluctuation"},
"fluctuates":{"fluctuated","fluctuating","fluctuates","fluctuate","fluctuations","fluctuation"},
"fluctuating":{"fluctuated","fluctuating","fluctuates","fluctuate","fluctuations","fluctuation"},
"fluctuation":{"fluctuated","fluctuating","fluctuates","fluctuate","fluctuations","fluctuation"},
"fluctuations":{"fluctuated","fluctuating","fluctuates","fluctuate","fluctuations","fluctuation"},
"focus":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"focused":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"focuses":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"focusing":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"refocus":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"refocused":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"refocuses":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"refocusing":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"format":{"formatted","formatting","format","formats"},
"formatted":{"formatted","formatting","format","formats"},
"formatting":{"formatted","formatting","format","formats"},
"formats":{"formatted","formatting","format","formats"},
"formula":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"formulae":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"formulas":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"formulate":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"formulated":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"formulating":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"formulation":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"formulations":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"reformulate":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"reformulated":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"reformulating":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"reformulation":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"reformulations":{"formulas","reformulation","formulating","formulation","formulations","reformulate","reformulated","reformulating","reformulations","formula","formulae","formulate","formulated"},
"foundation":{"foundations","foundation"},
"foundations":{"foundations","foundation"},
"founded":{"founded","founder","founders","founding"},
"founder":{"founded","founder","founders","founding"},
"founders":{"founded","founder","founders","founding"},
"founding":{"founded","founder","founders","founding"},
"unfounded":{"founded","founder","founders","founding","unfounded"},
"framework":{"frameworks","framework"},
"frameworks":{"frameworks","framework"},
"function":{"functioned","functioning","functions","functionally","functional","function"},
"functional":{"functioned","functioning","functions","functionally","functional","function"},
"functionally":{"functioned","functioning","functions","functionally","functional","function"},
"functioned":{"functioned","functioning","functions","functionally","functional","function"},
"functioning":{"functioned","functioning","functions","functionally","functional","function"},
"functions":{"functioned","functioning","functions","functionally","functional","function"},
"fund":{"funds","funding","funders","funder","funded","fund"},
"funded":{"funds","funding","funders","funder","funded","fund"},
"funding":{"funds","funding","funders","funder","funded","fund"},
"funds":{"funds","funding","funders","funder","funded","fund"},
"fundamental":{"fundamental","fundamentally"},
"fundamentally":{"fundamental","fundamentally"},
"gender":{"genders","gender"},
"genders":{"genders","gender"},
"generate":{"generating","generates","generated","generate"},
"generated":{"generating","generates","generated","generate"},
"generates":{"generating","generates","generated","generate"},
"generating":{"generating","generates","generated","generate"},
"generation":{"generation","generations"},
"generations":{"generation","generations"},
"globe":{"global","globalisation","globally","globalization","globe"},
"global":{"global","globalisation","globally","globalization","globe"},
"globally":{"global","globalisation","globally","globalization","globe"},
"globalisation":{"global","globalisation","globally","globalization","globe"},
"globalization":{"global","globalisation","globally","globalization","globe"},
"goal":{"goal","goals"},
"goals":{"goal","goals"},
"grade":{"grading","grade","grades","graded"},
"graded":{"grading","grade","grades","graded"},
"grades":{"grading","grade","grades","graded"},
"grading":{"grading","grade","grades","graded"},
"grant":{"grants","grant","granted","granting"},
"granted":{"grants","grant","granted","granting"},
"granting":{"grants","grant","granted","granting"},
"grants":{"grants","grant","granted","granting"},
"guarantee":{"guarantee","guaranteeing","guarantees","guaranteed"},
"guaranteed":{"guarantee","guaranteeing","guarantees","guaranteed"},
"guaranteeing":{"guarantee","guaranteeing","guarantees","guaranteed"},
"guarantees":{"guarantee","guaranteeing","guarantees","guaranteed"},
"guideline":{"guideline","guidelines"},
"guidelines":{"guideline","guidelines"},
"hierarchy":{"hierarchies","hierarchical","hierarchy"},
"hierarchical":{"hierarchies","hierarchical","hierarchy"},
"hierarchies":{"hierarchies","hierarchical","hierarchy"},
"highlight":{"highlights","highlight","highlighted","highlighting"},
"highlighted":{"highlights","highlight","highlighted","highlighting"},
"highlighting":{"highlights","highlight","highlighted","highlighting"},
"highlights":{"highlights","highlight","highlighted","highlighting"},
"hypothesis":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"hypotheses":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"hypothesise":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"hypothesised":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"hypothesises":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"hypothesising":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"hypothesize":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"hypothesized":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"hypothesizes":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"hypothesizing":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"hypothetical":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"hypothetically":{"hypothesising","hypothetically","hypothetical","hypothesizing","hypothesizes","hypothesized","hypothesize","hypothesises","hypothesised","hypothesis","hypotheses","hypothesise"},
"identical":{"identical","identically"},
"identically":{"identical","identically"},
"identify":{"identifying","identifies","identify","identifiable","identified","identification"},
"identifiable":{"identifying","identifies","identify","identifiable","identified","identification"},
"identification":{"identifying","identities","identifies","identity","identify","identifiable","identified","identification"},
"identified":{"identifying","identifies","identify","identifiable","identified","identification"},
"identifies":{"identifying","identifies","identify","identifiable","identified","identification"},
"identifying":{"identifying","identifies","identify","identifiable","identified","identification"},
"identities":{"identifying","identities","identifies","identity","identify","identifiable","identified","identification"},
"identity":{"identifying","identities","identifies","identity","identify","identifiable","identified","identification"},
"unidentifiable":{"identifying","identities","identifies","identity","unidentifiable","identify","identifiable","identified","identification"},
"ideology":{"ideologies","ideologically","ideology","ideological"},
"ideological":{"ideologies","ideologically","ideology","ideological"},
"ideologically":{"ideologies","ideologically","ideology","ideological"},
"ideologies":{"ideologies","ideologically","ideology","ideological"},
"ignorant":{"ignoring","ignorant","ignorance","ignores","ignore","ignored"},
"ignorance":{"ignoring","ignorant","ignorance","ignores","ignore","ignored"},
"ignore":{"ignoring","ignorant","ignorance","ignores","ignore","ignored"},
"ignored":{"ignoring","ignorant","ignorance","ignores","ignore","ignored"},
"ignores":{"ignoring","ignorant","ignorance","ignores","ignore","ignored"},
"ignoring":{"ignoring","ignorant","ignorance","ignores","ignore","ignored"},
"illustrate":{"illustrate","illustrated","illustrating","illustration","illustrations","illustrative","illustrates"},
"illustrated":{"illustrate","illustrated","illustrating","illustration","illustrations","illustrative","illustrates"},
"illustrates":{"illustrate","illustrated","illustrating","illustration","illustrations","illustrative","illustrates"},
"illustrating":{"illustrate","illustrated","illustrating","illustration","illustrations","illustrative","illustrates"},
"illustration":{"illustrate","illustrated","illustrating","illustration","illustrations","illustrative","illustrates"},
"illustrations":{"illustrate","illustrated","illustrating","illustration","illustrations","illustrative","illustrates"},
"illustrative":{"illustrate","illustrated","illustrating","illustration","illustrations","illustrative","illustrates"},
"image":{"image","imagery","images","imagine"},
"imagery":{"image","imagery","images"},
"images":{"image","imagery","images"},
"immigrate":{"immigrant","immigrants","immigrated","immigration","immigrating","immigrates","immigrate"},
"immigrant":{"immigrant","immigrants","immigrated","immigration","immigrating","immigrates","immigrate"},
"immigrants":{"immigrant","immigrants","immigrated","immigration","immigrating","immigrates","immigrate"},
"immigrated":{"immigrant","immigrants","immigrated","immigration","immigrating","immigrates","immigrate"},
"immigrates":{"immigrant","immigrants","immigrated","immigration","immigrating","immigrates","immigrate"},
"immigrating":{"immigrant","immigrants","immigrated","immigration","immigrating","immigrates","immigrate"},
"immigration":{"immigrant","immigrants","immigrated","immigration","immigrating","immigrates","immigrate"},
"impact":{"impact","impacting","impacts","impacted"},
"impacted":{"impact","impacting","impacts","impacted"},
"impacting":{"impact","impacting","impacts","impacted"},
"impacts":{"impact","impacting","impacts","impacted"},
"implement":{"implemented","implementing","implementation","implements","implement"},
"implementation":{"implemented","implementing","implementation","implements","implement"},
"implemented":{"implemented","implementing","implementation","implements","implement"},
"implementing":{"implemented","implementing","implementation","implements","implement"},
"implements":{"implemented","implementing","implementation","implements","implement"},
"implicate":{"implicated","implicates","implicating","implication","implications","implicate"},
"implicated":{"implicated","implicates","implicating","implication","implications","implicate"},
"implicates":{"implicated","implicates","implicating","implication","implications","implicate"},
"implicating":{"implicated","implicates","implicating","implication","implications","implicate"},
"implication":{"implicated","implicates","implicating","implication","implications","implicate"},
"implications":{"implicated","implicates","implicating","implication","implications","implicate"},
"implicit":{"implicit","implicitly"},
"implicitly":{"implicit","implicitly"},
"imply":{"implying","imply","implied","implies"},
"implied":{"implying","imply","implied","implies"},
"implies":{"implying","imply","implied","implies"},
"implying":{"implying","imply","implied","implies"},
"impose":{"imposing","imposes","imposed","impose","imposition"},
"imposed":{"imposing","imposes","imposed","impose","imposition"},
"imposes":{"imposing","imposes","imposed","impose","imposition"},
"imposing":{"imposing","imposes","imposed","impose","imposition"},
"imposition":{"imposing","imposes","imposed","impose","imposition"},
"incentive":{"incentive","incentives"},
"incentives":{"incentive","incentives"},
"incidence":{"incidentally","incidents","incidence","incident"},
"incident":{"incidentally","incidents","incidence","incident"},
"incidentally":{"incidentally","incidents","incidence","incident"},
"incidents":{"incidentally","incidents","incidence","incident"},
"incline":{"inclining","inclines","inclined","inclinations","inclination","incline"},
"inclination":{"inclining","inclines","inclined","inclinations","inclination","incline"},
"inclinations":{"inclining","inclines","inclined","inclinations","inclination","incline"},
"inclined":{"inclining","inclines","inclined","inclinations","inclination","incline"},
"inclines":{"inclining","inclines","inclined","inclinations","inclination","incline"},
"inclining":{"inclining","inclines","inclined","inclinations","inclination","incline"},
"income":{"incomes","income"},
"incomes":{"incomes","income"},
"incorporate":{"incorporates","incorporated","incorporation","incorporating","incorporate"},
"incorporated":{"incorporates","incorporated","incorporation","incorporating","incorporate"},
"incorporates":{"incorporates","incorporated","incorporation","incorporating","incorporate"},
"incorporating":{"incorporates","incorporated","incorporation","incorporating","incorporate"},
"incorporation":{"incorporates","incorporated","incorporation","incorporating","incorporate"},
"index":{"indexes","indexing","index","indexed"},
"indexed":{"indexes","indexing","index","indexed"},
"indexes":{"indexes","indexing","index","indexed"},
"indexing":{"indexes","indexing","index","indexed"},
"indicate":{"indication","indicating","indicated","indicators","indicate","indications","indicative","indicator","indicates"},
"indicated":{"indication","indicating","indicated","indicators","indicate","indications","indicative","indicator","indicates"},
"indicates":{"indication","indicating","indicated","indicators","indicate","indications","indicative","indicator","indicates"},
"indicating":{"indication","indicating","indicated","indicators","indicate","indications","indicative","indicator","indicates"},
"indication":{"indication","indicating","indicated","indicators","indicate","indications","indicative","indicator","indicates"},
"indications":{"indication","indicating","indicated","indicators","indicate","indications","indicative","indicator","indicates"},
"indicative":{"indication","indicating","indicated","indicators","indicate","indications","indicative","indicator","indicates"},
"indicator":{"indication","indicating","indicated","indicators","indicate","indications","indicative","indicator","indicates"},
"indicators":{"indication","indicating","indicated","indicators","indicate","indications","indicative","indicator","indicates"},
"individual":{"individuality","individualised","individualism","individual","individually","individuals","individualist","individualists","individualistic"},
"individualised":{"individuality","individualised","individualism","individual","individually","individuals","individualist","individualists","individualistic"},
"individuality":{"individuality","individualised","individualism","individual","individually","individuals","individualist","individualists","individualistic"},
"individualism":{"individuality","individualised","individualism","individual","individually","individuals","individualist","individualists","individualistic"},
"individualist":{"individuality","individualised","individualism","individual","individually","individuals","individualist","individualists","individualistic"},
"individualists":{"individuality","individualised","individualism","individual","individually","individuals","individualist","individualists","individualistic"},
"individualistic":{"individuality","individualised","individualism","individual","individually","individuals","individualist","individualists","individualistic"},
"individually":{"individuality","individualised","individualism","individual","individually","individuals","individualist","individualists","individualistic"},
"individuals":{"individuality","individualised","individualism","individual","individually","individuals","individualist","individualists","individualistic"},
"induce":{"inducing","induces","induced","induce"},
"induced":{"inducing","induces","induced","induce"},
"induces":{"inducing","induces","induced","induce"},
"inducing":{"inducing","induces","induced","induce"},
"induction":{"induction","inducing","induces","induced","induce"},
"inevitable":{"inevitability","inevitably","inevitable"},
"inevitability":{"inevitability","inevitably","inevitable"},
"inevitably":{"inevitability","inevitably","inevitable"},
"infer":{"inferring","infers","inferred","inferences","inference","infer"},
"inference":{"inferring","infers","inferred","inferences","inference","infer"},
"inferences":{"inferring","infers","inferred","inferences","inference","infer"},
"inferred":{"inferring","infers","inferred","inferences","inference","infer"},
"inferring":{"inferring","infers","inferred","inferences","inference","infer"},
"infers":{"inferring","infers","inferred","inferences","inference","infer"},
"infrastructure":{"infrastructures","infrastructure"},
"infrastructures":{"infrastructures","infrastructure"},
"inherent":{"inherent","inherently"},
"inherently":{"inherent","inherently"},
"inhibit":{"inhibits","inhibitions","inhibition","inhibiting","inhibited","inhibit"},
"inhibited":{"inhibits","inhibitions","inhibition","inhibiting","inhibited","inhibit"},
"inhibiting":{"inhibits","inhibitions","inhibition","inhibiting","inhibited","inhibit"},
"inhibition":{"inhibits","inhibitions","inhibition","inhibiting","inhibited","inhibit"},
"inhibitions":{"inhibits","inhibitions","inhibition","inhibiting","inhibited","inhibit"},
"inhibits":{"inhibits","inhibitions","inhibition","inhibiting","inhibited","inhibit"},
"initial":{"initial","initially"},
"initially":{"initial","initially"},
"initiate":{"initiate","initiators","initiatives","initiative","initiations","initiation","initiating","initiates","initiated","initiator"},
"initiated":{"initiate","initiators","initiatives","initiative","initiations","initiation","initiating","initiates","initiated","initiator"},
"initiates":{"initiate","initiators","initiatives","initiative","initiations","initiation","initiating","initiates","initiated","initiator"},
"initiating":{"initiate","initiators","initiatives","initiative","initiations","initiation","initiating","initiates","initiated","initiator"},
"initiation":{"initiate","initiators","initiatives","initiative","initiations","initiation","initiating","initiates","initiated","initiator"},
"initiations":{"initiate","initiators","initiatives","initiative","initiations","initiation","initiating","initiates","initiated","initiator"},
"initiative":{"initiate","initiators","initiatives","initiative","initiations","initiation","initiating","initiates","initiated","initiator"},
"initiatives":{"initiate","initiators","initiatives","initiative","initiations","initiation","initiating","initiates","initiated","initiator"},
"initiator":{"initiate","initiators","initiatives","initiative","initiations","initiation","initiating","initiates","initiated","initiator"},
"initiators":{"initiate","initiators","initiatives","initiative","initiations","initiation","initiating","initiates","initiated","initiator"},
"injure":{"injures","injured","injure","injuries","injury","injuring"},
"injured":{"injures","injured","injure","injuries","injury","injuring"},
"injures":{"injures","injured","injure","injuries","injury","injuring"},
"injuries":{"injures","injured","injure","injuries","injury","injuring"},
"injuring":{"injures","injured","injure","injuries","injury","injuring"},
"injury":{"injures","injured","injure","injuries","injury","injuring"},
"uninjured":{"injures","injured","injure","injuries","uninjured","injury","injuring"},
"innovate":{"innovation","innovators","innovative","innovations","innovating","innovator","innovates","innovated","innovate"},
"innovation":{"innovation","innovators","innovative","innovations","innovating","innovator","innovates","innovated","innovate"},
"innovated":{"innovation","innovators","innovative","innovations","innovating","innovator","innovates","innovated","innovate"},
"innovates":{"innovation","innovators","innovative","innovations","innovating","innovator","innovates","innovated","innovate"},
"innovating":{"innovation","innovators","innovative","innovations","innovating","innovator","innovates","innovated","innovate"},
"innovations":{"innovation","innovators","innovative","innovations","innovating","innovator","innovates","innovated","innovate"},
"innovative":{"innovation","innovators","innovative","innovations","innovating","innovator","innovates","innovated","innovate"},
"innovator":{"innovation","innovators","innovative","innovations","innovating","innovator","innovates","innovated","innovate"},
"innovators":{"innovation","innovators","innovative","innovations","innovating","innovator","innovates","innovated","innovate"},
"input":{"input","inputs"},
"inputs":{"input","inputs"},
"insert":{"insertion","inserting","inserted","insert","inserts"},
"inserted":{"insertion","inserting","inserted","insert","inserts"},
"inserting":{"insertion","inserting","inserted","insert","inserts"},
"insertion":{"insertion","inserting","inserted","insert","inserts"},
"inserts":{"insertion","inserting","inserted","insert","inserts"},
"insight":{"insight","insights","insightful"},
"insightful":{"insight","insights","insightful"},
"insights":{"insight","insights","insightful"},
"inspect":{"inspectors","inspector","inspections","inspection","inspecting","inspected","inspect","inspects"},
"inspected":{"inspectors","inspector","inspections","inspection","inspecting","inspected","inspect","inspects"},
"inspecting":{"inspectors","inspector","inspections","inspection","inspecting","inspected","inspect","inspects"},
"inspection":{"inspectors","inspector","inspections","inspection","inspecting","inspected","inspect","inspects"},
"inspections":{"inspectors","inspector","inspections","inspection","inspecting","inspected","inspect","inspects"},
"inspector":{"inspectors","inspector","inspections","inspection","inspecting","inspected","inspect","inspects"},
"inspectors":{"inspectors","inspector","inspections","inspection","inspecting","inspected","inspect","inspects"},
"inspects":{"inspectors","inspector","inspections","inspection","inspecting","inspected","inspect","inspects"},
"instance":{"instance","instances"},
"instances":{"instance","instances"},
"institute":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"instituted":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institutes":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"instituting":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institution":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institutional":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institutionalise":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institutionalised":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institutionalises":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institutionalising":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institutionalized":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institutionalizes":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institutionalizing":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institutionally":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"institutions":{"institutionalizing","institutionalizes","institutionalized","institutionalising","institutionalised","institutionalise","institutional","institution","instituting","institutes","instituted","institute","institutionally","institutions","institutionalises"},
"instruct":{"instructs","instructors","instructor","instructive","instructions","instructing","instructed","instruction","instruct"},
"instruction":{"instructs","instructors","instructor","instructive","instructions","instructing","instructed","instruction","instruct"},
"instructed":{"instructs","instructors","instructor","instructive","instructions","instructing","instructed","instruction","instruct"},
"instructing":{"instructs","instructors","instructor","instructive","instructions","instructing","instructed","instruction","instruct"},
"instructions":{"instructs","instructors","instructor","instructive","instructions","instructing","instructed","instruction","instruct"},
"instructive":{"instructs","instructors","instructor","instructive","instructions","instructing","instructed","instruction","instruct"},
"instructor":{"instructs","instructors","instructor","instructive","instructions","instructing","instructed","instruction","instruct"},
"instructors":{"instructs","instructors","instructor","instructive","instructions","instructing","instructed","instruction","instruct"},
"instructs":{"instructs","instructors","instructor","instructive","instructions","instructing","instructed","instruction","instruct"},
"integrate":{"integrate","integrated","integrates","integration","integrating"},
"integrated":{"integrate","integrated","integrates","integration","integrating"},
"integrates":{"integrate","integrated","integrates","integration","integrating"},
"integrating":{"integrate","integrated","integrates","integration","integrating"},
"integration":{"integrate","integrated","integrates","integration","integrating"},
"intelligence":{"intelligently","intelligent","intelligence"},
"intelligent":{"intelligently","intelligent","intelligence"},
"intelligently":{"intelligently","intelligent","intelligence"},
"unintelligent":{"unintelligent","intelligently","intelligent","intelligence"},
"intense":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"intensely":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"intensification":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"intensified":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"intensifies":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"intensify":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"intensifying":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"intensity":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"intensive":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"intensively":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"interact":{"interact","interactions","interacts","interactively","interactive","interaction","interacting","interacted"},
"interacted":{"interact","interactions","interacts","interactively","interactive","interaction","interacting","interacted"},
"interacting":{"interact","interactions","interacts","interactively","interactive","interaction","interacting","interacted"},
"interaction":{"interact","interactions","interacts","interactively","interactive","interaction","interacting","interacted"},
"interactions":{"interact","interactions","interacts","interactively","interactive","interaction","interacting","interacted"},
"interactive":{"interact","interactions","interacts","interactively","interactive","interaction","interacting","interacted"},
"interactively":{"interact","interactions","interacts","interactively","interactive","interaction","interacting","interacted"},
"interacts":{"interact","interactions","interacts","interactively","interactive","interaction","interacting","interacted"},
"internal":{"internally","internalized","internalizing","internalize","internalising","internalizes","internalises","internalised","internalise","internal"},
"internalise":{"internally","internalized","internalizing","internalize","internalising","internalizes","internalises","internalised","internalise","internal"},
"internalised":{"internally","internalized","internalizing","internalize","internalising","internalizes","internalises","internalised","internalise","internal"},
"internalises":{"internally","internalized","internalizing","internalize","internalising","internalizes","internalises","internalised","internalise","internal"},
"internalising":{"internally","internalized","internalizing","internalize","internalising","internalizes","internalises","internalised","internalise","internal"},
"internalize":{"internally","internalized","internalizing","internalize","internalising","internalizes","internalises","internalised","internalise","internal"},
"internalized":{"internally","internalized","internalizing","internalize","internalising","internalizes","internalises","internalised","internalise","internal"},
"internalizes":{"internally","internalized","internalizing","internalize","internalising","internalizes","internalises","internalised","internalise","internal"},
"internalizing":{"internally","internalized","internalizing","internalize","internalising","internalizes","internalises","internalised","internalise","internal"},
"internally":{"internally","internalized","internalizing","internalize","internalising","internalizes","internalises","internalised","internalise","internal"},
"interpret":{"interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","reinterpreting","reinterprets","reinterpretations","reinterpreted","reinterpret","interpretative"},
"interpretation":{"interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","reinterpreting","reinterprets","reinterpretations","reinterpreted","reinterpret","interpretative"},
"interpretations":{"interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","reinterpreting","reinterprets","reinterpretations","reinterpreted","reinterpret","interpretative"},
"interpretative":{"interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","reinterpreting","reinterprets","reinterpretations","reinterpreted","reinterpret","interpretative"},
"interpreted":{"interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","reinterpreting","reinterprets","reinterpretations","reinterpreted","reinterpret","interpretative"},
"interpreting":{"interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","reinterpreting","reinterprets","reinterpretations","reinterpreted","reinterpret","interpretative"},
"interpretive":{"interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","reinterpreting","reinterprets","reinterpretations","reinterpreted","reinterpret","interpretative"},
"interprets":{"interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","reinterpreting","reinterprets","reinterpretations","reinterpreted","reinterpret","interpretative"},
"misinterpret":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"misinterpretation":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"misinterpretations":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"misinterpreted":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"misinterpreting":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"misinterprets":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"reinterpret":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"reinterpreted":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"reinterprets":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"reinterpreting":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"reinterpretation":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"reinterpretations":{"misinterpreted","misinterpretations","misinterpretation","misinterpret","interprets","interpretive","interpreting","interpreted","interpretations","interpretation","interpret","reinterpretation","misinterpreting","reinterpreting","misinterprets","reinterprets","reinterpretations","reinter"},
"interval":{"intervals","interval"},
"intervals":{"intervals","interval"},
"intervene":{"intervened","intervention","intervene","interventions","intervenes","intervening"},
"intervened":{"intervened","intervention","intervene","interventions","intervenes","intervening"},
"intervenes":{"intervened","intervention","intervene","interventions","intervenes","intervening"},
"intervening":{"intervened","intervention","intervene","interventions","intervenes","intervening"},
"intervention":{"intervened","intervention","intervene","interventions","intervenes","intervening"},
"interventions":{"intervened","intervention","intervene","interventions","intervenes","intervening"},
"intrinsic":{"intrinsically","intrinsic"},
"intrinsically":{"intrinsically","intrinsic"},
"invest":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"invested":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"investing":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"investment":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"investments":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"investor":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"investors":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"invests":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"reinvest":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"reinvested":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"reinvesting":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"reinvestment":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"reinvests":{"investments","investor","investors","investment","invests","reinvest","reinvested","invest","reinvesting","reinvestment","investing","invested","reinvests"},
"investigate":{"investigations","investigators","investigator","investigative","investigation","investigating","investigates","investigated","investigate"},
"investigated":{"investigations","investigators","investigator","investigative","investigation","investigating","investigates","investigated","investigate"},
"investigates":{"investigations","investigators","investigator","investigative","investigation","investigating","investigates","investigated","investigate"},
"investigating":{"investigations","investigators","investigator","investigative","investigation","investigating","investigates","investigated","investigate"},
"investigation":{"investigations","investigators","investigator","investigative","investigation","investigating","investigates","investigated","investigate"},
"investigations":{"investigations","investigators","investigator","investigative","investigation","investigating","investigates","investigated","investigate"},
"investigative":{"investigations","investigators","investigator","investigative","investigation","investigating","investigates","investigated","investigate"},
"investigator":{"investigations","investigators","investigator","investigative","investigation","investigating","investigates","investigated","investigate"},
"investigators":{"investigations","investigators","investigator","investigative","investigation","investigating","investigates","investigated","investigate"},
"invoke":{"invokes","invoking","invoked","invoke"},
"invoked":{"invokes","invoking","invoked","invoke"},
"invokes":{"invokes","invoking","invoked","invoke"},
"invoking":{"invokes","invoking","invoked","invoke"},
"involve":{"involves","involved","involve","uninvolved","involvement","involving"},
"involved":{"involves","involved","involve","uninvolved","involvement","involving"},
"involvement":{"involves","involved","involve","uninvolved","involvement","involving"},
"involves":{"involves","involved","involve","uninvolved","involvement","involving"},
"involving":{"involves","involved","involve","uninvolved","involvement","involving"},
"uninvolved":{"involves","involved","involve","uninvolved","involvement","involving"},
"isolate":{"isolating","isolates","isolate","isolated","isolation","isolationism"},
"isolated":{"isolating","isolates","isolate","isolated","isolation","isolationism"},
"isolates":{"isolating","isolates","isolate","isolated","isolation","isolationism"},
"isolating":{"isolating","isolates","isolate","isolated","isolation","isolationism"},
"isolation":{"isolating","isolates","isolate","isolated","isolation","isolationism"},
"isolationism":{"isolating","isolates","isolate","isolated","isolation","isolationism"},
"issue":{"issuing","issues","issued","issue"},
"issued":{"issuing","issues","issued","issue"},
"issues":{"issuing","issues","issued","issue"},
"issuing":{"issuing","issues","issued","issue"},
"item":{"itemised","items","itemising","itemise","item","itemises","itemisation"},
"itemisation":{"itemised","items","itemising","itemise","item","itemises","itemisation"},
"itemise":{"itemised","items","itemising","itemise","item","itemises","itemisation"},
"itemised":{"itemised","items","itemising","itemise","item","itemises","itemisation"},
"itemises":{"itemised","items","itemising","itemise","item","itemises","itemisation"},
"itemising":{"itemised","items","itemising","itemise","item","itemises","itemisation"},
"items":{"itemised","items","itemising","itemise","item","itemises","itemisation"},
"job":{"jobs","job"},
"jobs":{"jobs","job"},
"journal":{"journals","journal"},
"journals":{"journals","journal"},
"justify":{"justify","justifiable","justifiably","justification","justifications","justified","justifies","justifying"},
"justifiable":{"justify","justifiable","justifiably","justification","justifications","justified","justifies","justifying"},
"justifiably":{"justify","justifiable","justifiably","justification","justifications","justified","justifies","justifying"},
"justification":{"justify","justifiable","justifiably","justification","justifications","justified","justifies","justifying"},
"justifications":{"justify","justifiable","justifiably","justification","justifications","justified","justifies","justifying"},
"justified":{"justify","justifiable","justifiably","justification","justifications","justified","justifies","justifying"},
"justifies":{"justify","justifiable","justifiably","justification","justifications","justified","justifies","justifying"},
"justifying":{"justify","justifiable","justifiably","justification","justifications","justified","justifies","justifying"},
"unjustified":{"justify","unjustified","justifiable","justifiably","justification","justifications","justified","justifies","justifying"},
"label":{"labelling","labeling","labels","labelled","label","labeled"},
"labeled":{"labelling","labeling","labels","labelled","label","labeled"},
"labeling":{"labelling","labeling","labels","labelled","label","labeled"},
"labelled":{"labelling","labeling","labels","labelled","label","labeled"},
"labelling":{"labelling","labeling","labels","labelled","label","labeled"},
"labels":{"labelling","labeling","labels","labelled","label","labeled"},
"labour":{"labouring","labor","labored","labors","laboured","labours","labour"},
"labor":{"labouring","labor","labored","labors","laboured","labours","labour"},
"labored":{"labouring","labor","labored","labors","laboured","labours","labour"},
"labors":{"labouring","labor","labored","labors","laboured","labours","labour"},
"laboured":{"labouring","labor","labored","labors","laboured","labours","labour"},
"labouring":{"labouring","labor","labored","labors","laboured","labours","labour"},
"labours":{"labouring","labor","labored","labors","laboured","labours","labour"},
"layer":{"layers","layering","layered","layer"},
"layered":{"layers","layering","layered","layer"},
"layering":{"layers","layering","layered","layer"},
"layers":{"layers","layering","layered","layer"},
"lecture":{"lecturer","lecturing","lecture","lecturers","lectures","lectured"},
"lectured":{"lecturer","lecturing","lecture","lecturers","lectures","lectured"},
"lecturer":{"lecturer","lecturing","lecture","lecturers","lectures","lectured"},
"lecturers":{"lecturer","lecturing","lecture","lecturers","lectures","lectured"},
"lectures":{"lecturer","lecturing","lecture","lecturers","lectures","lectured"},
"lecturing":{"lecturer","lecturing","lecture","lecturers","lectures","lectured"},
"legal":{"legality","legal","legally"},
"illegal":{"legality","legal","legally","illegally","illegality","illegal"},
"illegality":{"legality","legal","legally","illegally","illegality","illegal"},
"illegally":{"legality","legal","legally","illegally","illegality","illegal"},
"legality":{"legality","legal","legally"},
"legally":{"legality","legal","legally"},
"legislate":{"legislator","legislative","legislation","legislating","legislators","legislates","legislated","legislate","legislature"},
"legislated":{"legislator","legislative","legislation","legislating","legislators","legislates","legislated","legislate","legislature"},
"legislates":{"legislator","legislative","legislation","legislating","legislators","legislates","legislated","legislate","legislature"},
"legislating":{"legislator","legislative","legislation","legislating","legislators","legislates","legislated","legislate","legislature"},
"legislation":{"legislator","legislative","legislation","legislating","legislators","legislates","legislated","legislate","legislature"},
"legislative":{"legislator","legislative","legislation","legislating","legislators","legislates","legislated","legislate","legislature"},
"legislator":{"legislator","legislative","legislation","legislating","legislators","legislates","legislated","legislate","legislature"},
"legislators":{"legislator","legislative","legislation","legislating","legislators","legislates","legislated","legislate","legislature"},
"legislature":{"legislator","legislative","legislation","legislating","legislators","legislates","legislated","legislate","legislature"},
"levy":{"levies","levy"},
"levies":{"levies","levy"},
"liberal":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberalise":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberalism":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberalisation":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberalised":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberalises":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberalising":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberalization":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberalize":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberalized":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberalizes":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberalizing":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberate":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberated":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberates":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberation":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberating":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberator":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberators":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberally":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"liberals":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"licence":{"licence","licences","license","licensing","licensed","licenses","unlicensed"},
"licences":{"licence","licences","license","licensing","licensed","licenses"},
"license":{"licence","licences","license","licensing","licensed","licenses"},
"licensed":{"licence","licences","license","licensing","licensed","licenses"},
"licensing":{"licence","licences","license","licensing","licensed","licenses"},
"licenses":{"licence","licences","license","licensing","licensed","licenses"},
"unlicensed":{"licence","licences","license","licensing","licensed","licenses","unlicensed"},
"link":{"link","linkage","linkages","linked","linking","links"},
"linkage":{"link","linkage","linkages","linked","linking","links"},
"linkages":{"link","linkage","linkages","linked","linking","links"},
"linked":{"link","linkage","linkages","linked","linking","links"},
"linking":{"link","linkage","linkages","linked","linking","links"},
"links":{"link","linkage","linkages","linked","linking","links"},
"locate":{"relocate","located","relocated","relocation","locating","locate","location","locations","relocates","relocating"},
"located":{"relocate","located","relocated","relocation","locating","locate","location","locations","relocates","relocating"},
"locating":{"relocate","located","relocated","relocation","locating","locate","location","locations","relocates","relocating"},
"location":{"relocate","located","relocated","relocation","locating","locate","location","locations","relocates","relocating"},
"locations":{"relocate","located","relocated","relocation","locating","locate","location","locations","relocates","relocating"},
"relocate":{"relocate","located","relocated","relocation","locating","locate","location","locations","relocates","relocating"},
"relocated":{"relocate","located","relocated","relocation","locating","locate","location","locations","relocates","relocating"},
"relocates":{"relocate","located","relocated","relocation","locating","locate","location","locations","relocates","relocating"},
"relocating":{"relocate","located","relocated","relocation","locating","locate","location","locations","relocates","relocating"},
"relocation":{"relocate","located","relocated","relocation","locating","locate","location","locations","relocates","relocating"},
"logic":{"logic","illogical","logician","logically","logicians","logical","illogically"},
"illogical":{"logic","illogical","logician","logically","logicians","logical","illogically"},
"illogically":{"logic","illogical","logician","logically","logicians","logical"},
"logical":{"logic","logician","logically","logicians","logical"},
"logically":{"logic","logician","logically","logicians","logical"},
"logician":{"logic","logician","logically","logicians","logical"},
"logicians":{"logic","logician","logically","logicians","logical"},
"maintain":{"maintained","maintaining","maintains","maintenance","maintain"},
"maintained":{"maintained","maintaining","maintains","maintenance","maintain"},
"maintaining":{"maintained","maintaining","maintains","maintenance","maintain"},
"maintains":{"maintained","maintaining","maintains","maintenance","maintain"},
"maintenance":{"maintained","maintaining","maintains","maintenance","maintain"},
"major":{"major","majorities","majority"},
"majorities":{"major","majorities","majority"},
"majority":{"major","majorities","majority"},
"manipulate":{"manipulations","manipulate","manipulated","manipulates","manipulating","manipulation","manipulative"},
"manipulated":{"manipulations","manipulate","manipulated","manipulates","manipulating","manipulation","manipulative"},
"manipulates":{"manipulations","manipulate","manipulated","manipulates","manipulating","manipulation","manipulative"},
"manipulating":{"manipulations","manipulate","manipulated","manipulates","manipulating","manipulation","manipulative"},
"manipulation":{"manipulations","manipulate","manipulated","manipulates","manipulating","manipulation","manipulative"},
"manipulations":{"manipulations","manipulate","manipulated","manipulates","manipulating","manipulation","manipulative"},
"manipulative":{"manipulations","manipulate","manipulated","manipulates","manipulating","manipulation","manipulative"},
"manual":{"manuals","manual","manually"},
"manually":{"manuals","manual","manually"},
"manuals":{"manuals","manual","manually"},
"margin":{"marginal","margins","marginally","margin"},
"marginal":{"marginal","margins","marginally","margin"},
"marginally":{"marginal","margins","marginally","margin"},
"margins":{"marginal","margins","marginally","margin"},
"mature":{"maturational","maturity","maturing","matures","matured","maturation","immaturity","immature","mature"},
"immature":{"maturational","maturity","maturing","matures","matured","maturation","immaturity","immature","mature"},
"immaturity":{"maturational","maturity","maturing","matures","matured","maturation","immaturity","immature","mature"},
"maturation":{"maturational","maturity","maturing","matures","matured","maturation","mature"},
"matured":{"maturational","maturity","maturing","matures","matured","maturation","mature"},
"matures":{"maturational","maturity","maturing","matures","matured","maturation","mature"},
"maturing":{"maturational","maturity","maturing","matures","matured","maturation","mature"},
"maturity":{"maturational","maturity","maturing","matures","matured","maturation","mature"},
"maximise":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"max":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"maximised":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"maximises":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"maximising":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"maximisation":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"maximize":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"maximized":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"maximizes":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"maximizing":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"maximization":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"maximum":{"max","maximizing","maximised","maximises","maximum","maximizes","maximized","maximize","maximising","maximisation","maximise","maximization"},
"mechanism":{"mechanisms","mechanism"},
"mechanisms":{"mechanisms","mechanism"},
"mediate":{"mediated","mediation","mediate","mediating","mediates"},
"mediated":{"mediated","mediation","mediate","mediating","mediates"},
"mediates":{"mediated","mediation","mediate","mediating","mediates"},
"mediating":{"mediated","mediation","mediate","mediating","mediates"},
"mediation":{"mediated","mediation","mediate","mediating","mediates"},
"medical":{"medical","medically"},
"medically":{"medical","medically"},
"mental":{"mental","mentally","mentality"},
"mentality":{"mental","mentally","mentality"},
"mentally":{"mental","mentally","mentality"},
"method":{"methodical","methodology","methodologies","methods","method","methodological"},
"methodical":{"methodical","methodology","methodologies","methods","method","methodological"},
"methodological":{"methodical","methodology","methodologies","methods","method","methodological"},
"methodologies":{"methodical","methodology","methodologies","methods","method","methodological"},
"methodology":{"methodical","methodology","methodologies","methods","method","methodological"},
"methods":{"methodical","methodology","methodologies","methods","method","methodological"},
"migrate":{"migrating","migrate","migration","migratory","migrations","migrates","migrated","migrants","migrant"},
"migrant":{"migrating","migrate","migration","migratory","migrations","migrates","migrated","migrants","migrant"},
"migrants":{"migrating","migrate","migration","migratory","migrations","migrates","migrated","migrants","migrant"},
"migrated":{"migrating","migrate","migration","migratory","migrations","migrates","migrated","migrants","migrant"},
"migrates":{"migrating","migrate","migration","migratory","migrations","migrates","migrated","migrants","migrant"},
"migrating":{"migrating","migrate","migration","migratory","migrations","migrates","migrated","migrants","migrant"},
"migration":{"migrating","migrate","migration","migratory","migrations","migrates","migrated","migrants","migrant"},
"migrations":{"migrating","migrate","migration","migratory","migrations","migrates","migrated","migrants","migrant"},
"migratory":{"migrating","migrate","migration","migratory","migrations","migrates","migrated","migrants","migrant"},
"minimal":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalises":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalist":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalists":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalistic":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimally":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimise":{"minimized","minimise","minimised","minimises","minimising","minimize","minimizes","minimizing"},
"minimised":{"minimized","minimise","minimised","minimises","minimising","minimize","minimizes","minimizing"},
"minimises":{"minimized","minimise","minimised","minimises","minimising","minimize","minimizes","minimizing"},
"minimising":{"minimized","minimise","minimised","minimises","minimising","minimize","minimizes","minimizing"},
"minimize":{"minimized","minimise","minimised","minimises","minimising","minimize","minimizes","minimizing"},
"minimized":{"minimized","minimise","minimised","minimises","minimising","minimize","minimizes","minimizing"},
"minimizes":{"minimized","minimise","minimised","minimises","minimising","minimize","minimizes","minimizing"},
"minimizing":{"minimized","minimise","minimised","minimises","minimising","minimize","minimizes","minimizing"},
"ministry":{"ministerial","ministries","ministry"},
"ministerial":{"ministerial","ministries","ministry"},
"ministries":{"ministerial","ministries","ministry"},
"minor":{"minor","minorities","minority","minors"},
"minorities":{"minor","minorities","minority","minors"},
"minority":{"minor","minorities","minority","minors"},
"minors":{"minor","minorities","minority","minors"},
"mode":{"modes","mode"},
"modes":{"modes","mode"},
"modify":{"modify","modification","modifications","modifying","modified","modifies"},
"modification":{"modify","modification","modifications","modifying","modified","modifies"},
"modifications":{"modify","modification","modifications","modifying","modified","modifies"},
"modified":{"modify","modification","modifications","modifying","modified","modifies"},
"modifies":{"modify","modification","modifications","modifying","modified","modifies"},
"modifying":{"modify","modification","modifications","modifying","modified","modifies"},
"unmodified":{"modify","modification","modifications","unmodified","modifying","modified","modifies"},
"monitor":{"monitor","monitors","monitoring","monitored"},
"monitored":{"monitor","monitors","monitoring","monitored"},
"monitoring":{"monitor","monitors","monitoring","monitored"},
"monitors":{"monitor","monitors","monitoring","monitored"},
"unmonitored":{"unmonitored","monitor","monitors","monitoring","monitored"},
"motive":{"motivates","motivated","motivate","motive","motivating","motivation","motivations","motives"},
"motivate":{"motivates","motivated","motivate","motive","motivating","motivation","motivations","motives"},
"motivated":{"motivates","motivated","motivate","motive","motivating","motivation","motivations","motives"},
"motivates":{"motivates","motivated","motivate","motive","motivating","motivation","motivations","motives"},
"motivating":{"motivates","motivated","motivate","motive","motivating","motivation","motivations","motives"},
"motivation":{"motivates","motivated","motivate","motive","motivating","motivation","motivations","motives"},
"motivations":{"motivates","motivated","motivate","motive","motivating","motivation","motivations","motives"},
"motives":{"motivates","motivated","motivate","motive","motivating","motivation","motivations","motives"},
"unmotivated":{"motivates","motivated","motivate","motive","motivating","motivation","motivations","unmotivated","motives"},
"mutual":{"mutually","mutual"},
"mutually":{"mutually","mutual"},
"negate":{"negate","negatives","negated","negates","negating","negatively","negative"},
"negative":{"negate","negatives","negated","negates","negating","negatively","negative"},
"negated":{"negate","negatives","negated","negates","negating","negatively","negative"},
"negates":{"negate","negatives","negated","negates","negating","negatively","negative"},
"negating":{"negate","negatives","negated","negates","negating","negatively","negative"},
"negatively":{"negate","negatives","negated","negates","negating","negatively","negative"},
"negatives":{"negate","negatives","negated","negates","negating","negatively","negative"},
"network":{"networks","networking","network","networked"},
"networked":{"networks","networking","network","networked"},
"networking":{"networks","networking","network","networked"},
"networks":{"networks","networking","network","networked"},
"neutral":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"neutralisation":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"neutralise":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"neutralised":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"neutralises":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"neutralising":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"neutrality":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"neutralization":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"neutralize":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"neutralized":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"neutralizes":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"neutralizing":{"neutrality","neutralization","neutralize","neutralized","neutralise","neutralising","neutralises","neutralised","neutralizing","neutralisation","neutral","neutralizes"},
"norm":{"norm","norms"},
"norms":{"norm","norms"},
"normal":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"abnormal":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","abnormal","abnormally","normalizes"},
"abnormally":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","abnormal","abnormally","normalizes"},
"normalisation":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"normalise":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"normalised":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"normalises":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"normalising":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"normalization":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"normalize":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"normalized":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"normalizes":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"normalizing":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"normality":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"normally":{"normally","normality","normalizing","normalized","normal","normalisation","normalises","normalised","normalize","normalization","normalising","normalise","normalizes"},
"notion":{"notion","notions"},
"notions":{"notion","notions"},
"objective":{"objectively","objectivity","objective"},
"objectively":{"objectively","objectivity","objective"},
"objectivity":{"objectively","objectivity","objective"},
"obtain":{"unobtainable","obtains","obtaining","obtained","obtainable","obtain"},
"obtainable":{"unobtainable","obtains","obtaining","obtained","obtainable","obtain"},
"obtained":{"unobtainable","obtains","obtaining","obtained","obtainable","obtain"},
"obtaining":{"unobtainable","obtains","obtaining","obtained","obtainable","obtain"},
"obtains":{"unobtainable","obtains","obtaining","obtained","obtainable","obtain"},
"unobtainable":{"unobtainable","obtains","obtaining","obtained","obtainable","obtain"},
"obvious":{"obviously","obvious"},
"obviously":{"obviously","obvious"},
"occupy":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occupancy":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occupant":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occupants":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occupation":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occupational":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occupations":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occupied":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occupier":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occupiers":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occupies":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occupying":{"occupants","occupation","occupational","occupant","occupiers","occupy","occupancy","occupations","occupies","occupying","occupier","occupied"},
"occur":{"occurrences","occurrence","occurred","occur","occurring","occurs","reoccur","reoccurs","reoccurring","reoccurred"},
"occurred":{"occurrences","occurrence","occurred","occur","occurring","occurs","reoccur","reoccurs","reoccurring","reoccurred"},
"occurrence":{"occurrences","occurrence","occurred","occur","occurring","occurs","reoccur","reoccurs","reoccurring","reoccurred"},
"occurrences":{"occurrences","occurrence","occurred","occur","occurring","occurs","reoccur","reoccurs","reoccurring","reoccurred"},
"occurring":{"occurrences","occurrence","occurred","occur","occurring","occurs","reoccur","reoccurs","reoccurring","reoccurred"},
"occurs":{"occurrences","occurrence","occurred","occur","occurring","occurs","reoccur","reoccurs","reoccurring","reoccurred"},
"reoccur":{"occurrences","occurrence","occurred","occur","occurring","occurs","reoccur","reoccurs","reoccurring","reoccurred"},
"reoccurred":{"occurrences","occurrence","occurred","occur","occurring","occurs","reoccur","reoccurs","reoccurring","reoccurred"},
"reoccurring":{"occurrences","occurrence","occurred","occur","occurring","occurs","reoccur","reoccurs","reoccurring","reoccurred"},
"reoccurs":{"occurrences","occurrence","occurred","occur","occurring","occurs","reoccur","reoccurs","reoccurring","reoccurred"},
"odd":{"odd","odds"},
"odds":{"odd","odds"},
"offset":{"offsetting","offsets","offset"},
"offsets":{"offsetting","offsets","offset"},
"offsetting":{"offsetting","offsets","offset"},
"option":{"option","optional","options"},
"optional":{"option","optional","options"},
"options":{"option","optional","options"},
"orient":{"orient","orientate","orientated","orientates","orientation","orientating","oriented","reorient","reorientation","orients","orienting"},
"orientate":{"orient","orientate","orientated","orientates","orientation","orientating","oriented","reorient","reorientation","orients","orienting"},
"orientated":{"orient","orientate","orientated","orientates","orientation","orientating","oriented","reorient","reorientation","orients","orienting"},
"orientates":{"orient","orientate","orientated","orientates","orientation","orientating","oriented","reorient","reorientation","orients","orienting"},
"orientation":{"orient","orientate","orientated","orientates","orientation","orientating","oriented","reorient","reorientation","orients","orienting"},
"orientating":{"orient","orientate","orientated","orientates","orientation","orientating","oriented","reorient","reorientation","orients","orienting"},
"oriented":{"orient","orientate","orientated","orientates","orientation","orientating","oriented","reorient","reorientation","orients","orienting"},
"orienting":{"orient","orientate","orientated","orientates","orientation","orientating","oriented","reorient","reorientation","orients","orienting"},
"orients":{"orient","orientate","orientated","orientates","orientation","orientating","oriented","reorient","reorientation","orients","orienting"},
"reorient":{"orient","orientate","orientated","orientates","orientation","orientating","oriented","reorient","reorientation","orients","orienting"},
"reorientation":{"orient","orientate","orientated","orientates","orientation","orientating","oriented","reorient","reorientation","orients","orienting"},
"outcome":{"outcome","outcomes"},
"outcomes":{"outcome","outcomes"},
"output":{"outputs","output"},
"outputs":{"outputs","output"},
"overlap":{"overlap","overlapped","overlapping","overlaps"},
"overlapped":{"overlap","overlapped","overlapping","overlaps"},
"overlapping":{"overlap","overlapped","overlapping","overlaps"},
"overlaps":{"overlap","overlapped","overlapping","overlaps"},
"panel":{"panels","panelling","panel","panelled"},
"panelled":{"panels","panelling","panel","panelled"},
"panelling":{"panels","panelling","panel","panelled"},
"panels":{"panels","panelling","panel","panelled"},
"paradigm":{"paradigms","paradigm"},
"paradigms":{"paradigms","paradigm"},
"paragraph":{"paragraph","paragraphing","paragraphs"},
"paragraphing":{"paragraph","paragraphing","paragraphs"},
"paragraphs":{"paragraph","paragraphing","paragraphs"},
"parallel":{"paralleled","parallels","parallelling","unparalleled","parallel","parallelled"},
"paralleled":{"paralleled","parallels","parallelling","unparalleled","parallel","parallelled"},
"parallelled":{"paralleled","parallels","parallelling","unparalleled","parallel","parallelled"},
"parallelling":{"paralleled","parallels","parallelling","unparalleled","parallel","parallelled"},
"parallels":{"paralleled","parallels","parallelling","unparalleled","parallel","parallelled"},
"unparalleled":{"paralleled","parallels","parallelling","unparalleled","parallel","parallelled"},
"parameter":{"parameters","parameter"},
"parameters":{"parameters","parameter"},
"participate":{"participatory","participants","participated","participates","participating","participation","participate","participant"},
"participant":{"participatory","participants","participated","participates","participating","participation","participate","participant"},
"participants":{"participatory","participants","participated","participates","participating","participation","participate","participant"},
"participated":{"participatory","participants","participated","participates","participating","participation","participate","participant"},
"participates":{"participatory","participants","participated","participates","participating","participation","participate","participant"},
"participating":{"participatory","participants","participated","participates","participating","participation","participate","participant"},
"participation":{"participatory","participants","participated","participates","participating","participation","participate","participant"},
"participatory":{"participatory","participants","participated","participates","participating","participation","participate","participant"},
"partner":{"partnerships","partners","partnership","partner"},
"partners":{"partnerships","partners","partnership","partner"},
"partnership":{"partnerships","partners","partnership","partner"},
"partnerships":{"partnerships","partners","partnership","partner"},
"passive":{"passivity","passively","passive"},
"passively":{"passivity","passively","passive"},
"passivity":{"passivity","passively","passive"},
"perceive":{"perceiving","perceives","perception","perceived","perceive","perceptions"},
"perceived":{"perceiving","perceives","perception","perceived","perceive","perceptions"},
"perceives":{"perceiving","perceives","perception","perceived","perceive","perceptions"},
"perceiving":{"perceiving","perceives","perception","perceived","perceive","perceptions"},
"perception":{"perceiving","perceives","perception","perceived","perceive","perceptions"},
"perceptions":{"perceiving","perceives","perception","perceived","perceive","perceptions"},
"percent":{"percent","percentage","percentages"},
"percentage":{"percent","percentage","percentages"},
"percentages":{"percent","percentage","percentages"},
"period":{"periods","periodicals","periodically","period","periodical","periodic"},
"periodic":{"periods","periodicals","periodically","period","periodical","periodic"},
"periodical":{"periods","periodicals","periodically","period","periodical","periodic"},
"periodically":{"periods","periodicals","periodically","period","periodical","periodic"},
"periodicals":{"periods","periodicals","periodically","period","periodical","periodic"},
"periods":{"periods","periodicals","periodically","period","periodical","periodic"},
"persist":{"persistently","persistent","persistence","persisting","persisted","persist","persists"},
"persisted":{"persistently","persistent","persistence","persisting","persisted","persist","persists"},
"persistence":{"persistently","persistent","persistence","persisting","persisted","persist","persists"},
"persistent":{"persistently","persistent","persistence","persisting","persisted","persist","persists"},
"persistently":{"persistently","persistent","persistence","persisting","persisted","persist","persists"},
"persisting":{"persistently","persistent","persistence","persisting","persisted","persist","persists"},
"persists":{"persistently","persistent","persistence","persisting","persisted","persist","persists"},
"perspective":{"perspective","perspectives"},
"perspectives":{"perspective","perspectives"},
"phase":{"phase","phasing","phases","phased"},
"phased":{"phase","phasing","phases","phased"},
"phases":{"phase","phasing","phases","phased"},
"phasing":{"phase","phasing","phases","phased"},
"phenomenon":{"phenomenon","phenomena","phenomenal"},
"phenomena":{"phenomenon","phenomena","phenomenal"},
"phenomenal":{"phenomenon","phenomena","phenomenal"},
"philosophy":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosopher":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophers":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophical":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophically":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophies":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophise":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophised":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophises":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophising":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophize":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophized":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophizes":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"philosophizing":{"philosophising","philosophize","philosophized","philosopher","philosophizes","philosophised","philosophizing","philosophises","philosophise","philosophies","philosophical","philosophers","philosophy","philosophically"},
"physical":{"physically","physical"},
"physically":{"physically","physical"},
"plus":{"plus","pluses"},
"pluses":{"plus","pluses"},
"policy":{"policies","policy"},
"policies":{"policies","policy"},
"portion":{"portions","portion"},
"portions":{"portions","portion"},
"pose":{"poses","posing","posed","pose"},
"posed":{"poses","posing","posed","pose"},
"poses":{"poses","posing","posed","pose"},
"posing":{"poses","posing","posed","pose"},
"positive":{"positively","positive"},
"positively":{"positively","positive"},
"potential":{"potentially","potential"},
"potentially":{"potentially","potential"},
"practitioner":{"practitioner","practitioners"},
"practitioners":{"practitioner","practitioners"},
"precede":{"precede","preceding","precedes","precedent","preceded","precedence"},
"preceded":{"precede","preceding","precedes","precedent","preceded","precedence"},
"precedence":{"precede","preceding","precedes","precedent","preceded","precedence"},
"precedent":{"precede","preceding","precedes","precedent","preceded","precedence"},
"precedes":{"precede","preceding","precedes","precedent","preceded","precedence"},
"preceding":{"precede","preceding","precedes","precedent","preceded","precedence"},
"unprecedented":{"unprecedented","precede","preceding","precedes","precedent","preceded","precedence"},
"precise":{"precise","imprecise","precisely","precision"},
"imprecise":{"precise","imprecise","precisely","precision"},
"precisely":{"precise","precisely","precision"},
"precision":{"precise","precisely","precision"},
"predict":{"predictable","predict","predictability","predictions","predictably","predicted","predicts","predicting","prediction"},
"predictability":{"predictable","predict","predictability","predictions","predictably","predicted","predicts","predicting","prediction"},
"predictable":{"predictable","predict","predictability","predictions","predictably","predicted","predicts","predicting","prediction"},
"predictably":{"predictable","predict","predictability","predictions","predictably","predicted","predicts","predicting","prediction"},
"predicted":{"predictable","predict","predictability","predictions","predictably","predicted","predicts","predicting","prediction"},
"predicting":{"predictable","predict","predictability","predictions","predictably","predicted","predicts","predicting","prediction"},
"prediction":{"predictable","predict","predictability","predictions","predictably","predicted","predicts","predicting","prediction"},
"predictions":{"predictable","predict","predictability","predictions","predictably","predicted","predicts","predicting","prediction"},
"predicts":{"predictable","predict","predictability","predictions","predictably","predicted","predicts","predicting","prediction"},
"unpredictability":{"predictable","predict","predictability","predictions","predictably","predicted","predicts","unpredictability","unpredictable","predicting","prediction"},
"unpredictable":{"predictable","predict","predictability","predictions","predictably","predicted","predicts","unpredictability","unpredictable","predicting","prediction"},
"predominant":{"predominance","predominantly","predominate","predominant","predominates","predominating","predominated"},
"predominance":{"predominance","predominantly","predominate","predominant","predominates","predominating","predominated"},
"predominantly":{"predominance","predominantly","predominate","predominant","predominates","predominating","predominated"},
"predominate":{"predominance","predominantly","predominate","predominant","predominates","predominating","predominated"},
"predominated":{"predominance","predominantly","predominate","predominant","predominates","predominating","predominated"},
"predominates":{"predominance","predominantly","predominate","predominant","predominates","predominating","predominated"},
"predominating":{"predominance","predominantly","predominate","predominant","predominates","predominating","predominated"},
"preliminary":{"preliminaries","preliminary"},
"preliminaries":{"preliminaries","preliminary"},
"presume":{"presume","presumably","presumptions","presumed","presuming","presumption","presumes"},
"presumably":{"presume","presumably","presumptions","presumed","presuming","presumption","presumes"},
"presumed":{"presume","presumably","presumptions","presumed","presuming","presumption","presumes"},
"presumes":{"presume","presumably","presumptions","presumed","presuming","presumption","presumes"},
"presuming":{"presume","presumably","presumptions","presumed","presuming","presumption","presumes"},
"presumption":{"presume","presumably","presumptions","presumed","presuming","presumption","presumes"},
"presumptions":{"presume","presumably","presumptions","presumed","presuming","presumption","presumes"},
"previous":{"previous","previously"},
"previously":{"previous","previously"},
"primary":{"primarily","primary"},
"primarily":{"primarily","primary"},
"prime":{"prime","primacy"},
"primacy":{"prime","primacy"},
"principal":{"principal","principally"},
"principally":{"principal","principally"},
"principle":{"principled","principles","principle"},
"principled":{"principled","principles","principle"},
"principles":{"principled","principles","principle"},
"unprincipled":{"principled","principles","unprincipled","principle"},
"priority":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"priorities":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"prioritisation":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"prioritise":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"prioritised":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"prioritises":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"prioritising":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"prioritization":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"prioritize":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"prioritized":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"prioritizes":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"prioritizing":{"prioritised","priorities","prioritizing","prioritized","prioritize","prioritization","prioritising","prioritises","prioritisation","prioritise","priority","prioritizes"},
"proceed":{"procedure","proceeds","proceeding","proceed","proceedings","procedural","proceeded","procedures"},
"procedural":{"procedure","proceeds","proceeding","proceed","proceedings","procedural","proceeded","procedures"},
"procedure":{"procedure","proceeds","proceeding","proceed","proceedings","procedural","proceeded","procedures"},
"procedures":{"procedure","proceeds","proceeding","proceed","proceedings","procedural","proceeded","procedures"},
"proceeded":{"procedure","proceeds","proceeding","proceed","proceedings","procedural","proceeded","procedures"},
"proceeding":{"procedure","proceeds","proceeding","proceed","proceedings","procedural","proceeded","procedures"},
"proceedings":{"procedure","proceeds","proceeding","proceed","proceedings","procedural","proceeded","procedures"},
"proceeds":{"procedure","proceeds","proceeding","proceed","proceedings","procedural","proceeded","procedures"},
"process":{"processed","process","processes","processing"},
"processed":{"processed","process","processes","processing"},
"processes":{"processed","process","processes","processing"},
"processing":{"processed","process","processes","processing"},
"professional":{"professionally","professionals","professional","professionalism"},
"professionally":{"professionally","professionals","professional","professionalism"},
"professionals":{"professionally","professionals","professional","professionalism"},
"professionalism":{"professionally","professionals","professional","professionalism"},
"prohibit":{"prohibits","prohibitive","prohibitions","prohibition","prohibit","prohibited","prohibiting"},
"prohibited":{"prohibits","prohibitive","prohibitions","prohibition","prohibit","prohibited","prohibiting"},
"prohibiting":{"prohibits","prohibitive","prohibitions","prohibition","prohibit","prohibited","prohibiting"},
"prohibition":{"prohibits","prohibitive","prohibitions","prohibition","prohibit","prohibited","prohibiting"},
"prohibitions":{"prohibits","prohibitive","prohibitions","prohibition","prohibit","prohibited","prohibiting"},
"prohibitive":{"prohibits","prohibitive","prohibitions","prohibition","prohibit","prohibited","prohibiting"},
"prohibits":{"prohibits","prohibitive","prohibitions","prohibition","prohibit","prohibited","prohibiting"},
"project":{"projected","projecting","project","projects","projection","projections"},
"projected":{"projected","projecting","project","projects","projection","projections"},
"projecting":{"projected","projecting","project","projects","projection","projections"},
"projection":{"projected","projecting","project","projects","projection","projections"},
"projections":{"projected","projecting","project","projects","projection","projections"},
"projects":{"projected","projecting","project","projects","projection","projections"},
"promote":{"promotes","promoters","promoter","promotion","promoting","promote","promoted","promotions"},
"promoted":{"promotes","promoters","promoter","promotion","promoting","promote","promoted","promotions"},
"promoter":{"promotes","promoters","promoter","promotion","promoting","promote","promoted","promotions"},
"promoters":{"promotes","promoters","promoter","promotion","promoting","promote","promoted","promotions"},
"promotes":{"promotes","promoters","promoter","promotion","promoting","promote","promoted","promotions"},
"promoting":{"promotes","promoters","promoter","promotion","promoting","promote","promoted","promotions"},
"promotion":{"promotes","promoters","promoter","promotion","promoting","promote","promoted","promotions"},
"promotions":{"promotes","promoters","promoter","promotion","promoting","promote","promoted","promotions"},
"proportion":{"proportionate","proportion","proportions","proportionally","proportional","proportionately"},
"disproportion":{"proportionate","proportion","proportions","proportionally","proportional","disproportionately","disproportion","proportionately","disproportionate"},
"disproportionate":{"proportionate","proportion","proportions","proportionally","proportional","disproportionately","disproportion","proportionately"},
"disproportionately":{"proportionate","proportion","proportions","proportionally","proportional","disproportionately","disproportion","proportionately","disproportionate"},
"proportional":{"proportionate","proportion","proportions","proportionally","proportional","proportionately"},
"proportionally":{"proportionate","proportion","proportions","proportionally","proportional","proportionately"},
"proportionate":{"proportionate","proportion","proportions","proportionally","proportional","proportionately"},
"proportionately":{"proportionate","proportion","proportions","proportionally","proportional","proportionately"},
"proportions":{"proportionate","proportion","proportions","proportionally","proportional","proportionately"},
"prospect":{"prospects","prospective","prospect"},
"prospective":{"prospects","prospective","prospect"},
"prospects":{"prospects","prospective","prospect"},
"protocol":{"protocol","protocols"},
"protocols":{"protocol","protocols"},
"psychology":{"psychology","psychological","psychologically","psychologists","psychologist"},
"psychological":{"psychology","psychological","psychologically","psychologists","psychologist"},
"psychologically":{"psychology","psychological","psychologically","psychologists","psychologist"},
"psychologist":{"psychology","psychological","psychologically","psychologists","psychologist"},
"psychologists":{"psychology","psychological","psychologically","psychologists","psychologist"},
"publication":{"publication","publications"},
"publications":{"publication","publications"},
"publish":{"publishes","publisher","published","publishing","publishers","publish"},
"published":{"publishes","publisher","published","publishing","publishers","publish"},
"publisher":{"publishes","publisher","published","publishing","publishers","publish"},
"publishers":{"publishes","publisher","published","publishing","publishers","publish"},
"publishes":{"publishes","publisher","published","publishing","publishers","publish"},
"publishing":{"publishes","publisher","published","publishing","publishers","publish"},
"unpublished":{"publishes","publisher","published","publishing","unpublished","publishers","publish"},
"purchase":{"purchasers","purchase","purchased","purchaser","purchases","purchasing"},
"purchased":{"purchasers","purchase","purchased","purchaser","purchases","purchasing"},
"purchaser":{"purchasers","purchase","purchased","purchaser","purchases","purchasing"},
"purchasers":{"purchasers","purchase","purchased","purchaser","purchases","purchasing"},
"purchases":{"purchasers","purchase","purchased","purchaser","purchases","purchasing"},
"purchasing":{"purchasers","purchase","purchased","purchaser","purchases","purchasing"},
"pursue":{"pursuing","pursue","pursuits","pursuit","pursues","pursued"},
"pursued":{"pursuing","pursue","pursuits","pursuit","pursues","pursued"},
"pursues":{"pursuing","pursue","pursuits","pursuit","pursues","pursued"},
"pursuing":{"pursuing","pursue","pursuits","pursuit","pursues","pursued"},
"pursuit":{"pursuing","pursue","pursuits","pursuit","pursues","pursued"},
"pursuits":{"pursuing","pursue","pursuits","pursuit","pursues","pursued"},
"qualitative":{"qualitative","qualitatively"},
"qualitatively":{"qualitative","qualitatively"},
"quote":{"quotation","quoting","quotations","quoted","quotes","quote"},
"quotation":{"quotation","quoting","quotations","quoted","quotes","quote"},
"quotations":{"quotation","quoting","quotations","quoted","quotes","quote"},
"quoted":{"quotation","quoting","quotations","quoted","quotes","quote"},
"quotes":{"quotation","quoting","quotations","quoted","quotes","quote"},
"quoting":{"quotation","quoting","quotations","quoted","quotes","quote"},
"radical":{"radical","radically","radicals"},
"radically":{"radical","radically","radicals"},
"radicals":{"radical","radically","radicals"},
"random":{"randomness","random","randomly"},
"randomly":{"randomness","random","randomly"},
"randomness":{"randomness","random","randomly"},
"range":{"ranging","range","ranged","ranges"},
"ranged":{"ranging","range","ranged","ranges"},
"ranges":{"ranging","range","ranged","ranges"},
"ranging":{"ranging","range","ranged","ranges"},
"ratio":{"ratios","ratio"},
"ratios":{"ratios","ratio"},
"rational":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"irrational":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","irrational","rationalization"},
"rationalisation":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationalisations":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationalise":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationalised":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationalises":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationalising":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationalism":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationality":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationalization":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationalizations":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationalize":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationalized":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationalizes":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"rationally":{"rationalise","rationalize","rationalizations","rationality","rationalism","rationalising","rationalises","rationalised","rationalized","rationalizes","rationally","rationalisations","rationalisation","rational","rationalization"},
"react":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reacted":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reacts":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reacting":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reaction":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reactionaries":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reactionary":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reactions":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reactive":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reactivate":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reactivation":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reactor":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"reactors":{"reactionaries","react","reacted","reactor","reactivation","reactors","reacting","reactivate","reaction","reactions","reactionary","reactive","reacts"},
"recover":{"recovering","recover","recoverable","recovered","recovers","recovery"},
"recoverable":{"recovering","recover","recoverable","recovered","recovers","recovery"},
"recovered":{"recovering","recover","recoverable","recovered","recovers","recovery"},
"recovering":{"recovering","recover","recoverable","recovered","recovers","recovery"},
"recovers":{"recovering","recover","recoverable","recovered","recovers","recovery"},
"recovery":{"recovering","recover","recoverable","recovered","recovers","recovery"},
"refine":{"refining","refines","refinements","refinement","refine","refined"},
"refined":{"refining","refines","refinements","refinement","refine","refined"},
"refinement":{"refining","refines","refinements","refinement","refine","refined"},
"refinements":{"refining","refines","refinements","refinement","refine","refined"},
"refines":{"refining","refines","refinements","refinement","refine","refined"},
"refining":{"refining","refines","refinements","refinement","refine","refined"},
"regime":{"regimes","regime"},
"regimes":{"regimes","regime"},
"region":{"region","regional","regionally","regions"},
"regional":{"region","regional","regionally","regions"},
"regionally":{"region","regional","regionally","regions"},
"regions":{"region","regional","regionally","regions"},
"register":{"registration","registers","registering","registered","register"},
"registered":{"registration","registers","registering","registered","register"},
"registering":{"registration","registers","registering","registered","register"},
"registers":{"registration","registers","registering","registered","register"},
"registration":{"registration","registers","registering","registered","register"},
"regulate":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"deregulated":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"deregulates":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"deregulating":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"deregulation":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"regulated":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"regulates":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"regulating":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"regulation":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"regulations":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"regulator":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"regulators":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"regulatory":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"unregulated":{"regulatory","deregulating","regulate","deregulated","deregulates","deregulation","regulates","regulating","regulator","regulation","regulated","regulations","unregulated","regulators"},
"reinforce":{"reinforces","reinforce","reinforced","reinforcements","reinforcing","reinforcement"},
"reinforced":{"reinforces","reinforce","reinforced","reinforcements","reinforcing","reinforcement"},
"reinforcement":{"reinforces","reinforce","reinforced","reinforcements","reinforcing","reinforcement"},
"reinforcements":{"reinforces","reinforce","reinforced","reinforcements","reinforcing","reinforcement"},
"reinforces":{"reinforces","reinforce","reinforced","reinforcements","reinforcing","reinforcement"},
"reinforcing":{"reinforces","reinforce","reinforced","reinforcements","reinforcing","reinforcement"},
"reject":{"rejecting","rejects","rejections","rejection","reject","rejected"},
"rejected":{"rejecting","rejects","rejections","rejection","reject","rejected"},
"rejecting":{"rejecting","rejects","rejections","rejection","reject","rejected"},
"rejection":{"rejecting","rejects","rejections","rejection","reject","rejected"},
"rejects":{"rejecting","rejects","rejections","rejection","reject","rejected"},
"rejections":{"rejecting","rejects","rejections","rejection","reject","rejected"},
"relax":{"relaxation","relaxed","relaxes","relaxing","relax"},
"relaxation":{"relaxation","relaxed","relaxes","relaxing","relax"},
"relaxed":{"relaxation","relaxed","relaxes","relaxing","relax"},
"relaxes":{"relaxation","relaxed","relaxes","relaxing","relax"},
"relaxing":{"relaxation","relaxed","relaxes","relaxing","relax"},
"release":{"releasing","released","release","releases"},
"released":{"releasing","released","release","releases"},
"releases":{"releasing","released","release","releases"},
"releasing":{"releasing","released","release","releases"},
"relevant":{"relevance","relevant","irrelevance"},
"irrelevance":{"relevance","relevant","irrelevance","irrelevant"},
"irrelevant":{"relevance","relevant","irrelevance","irrelevant"},
"relevance":{"relevance","relevant","irrelevance"},
"reluctance":{"reluctantly","reluctant","reluctance"},
"reluctant":{"reluctantly","reluctant","reluctance"},
"reluctantly":{"reluctantly","reluctant","reluctance"},
"rely":{"reliability","reliable","rely","reliance","relying","relies","reliably","reliant","relied"},
"reliability":{"reliability","reliable","rely","reliance","relying","relies","reliably","reliant","relied"},
"reliable":{"reliability","reliable","rely","reliance","relying","relies","reliably","reliant","relied"},
"reliably":{"reliability","reliable","rely","reliance","relying","relies","reliably","reliant","relied"},
"reliance":{"reliability","reliable","rely","reliance","relying","relies","reliably","reliant","relied"},
"reliant":{"reliability","reliable","rely","reliance","relying","relies","reliably","reliant","relied"},
"relied":{"reliability","reliable","rely","reliance","relying","relies","reliably","reliant","relied"},
"relies":{"reliability","reliable","rely","reliance","relying","relies","reliably","reliant","relied"},
"relying":{"reliability","reliable","rely","reliance","relying","relies","reliably","reliant","relied"},
"unreliable":{"reliability","reliable","rely","reliance","relying","relies","unreliable","reliably","reliant","relied"},
"remove":{"removed","removing","removes","removals","removal","removable","remove"},
"removable":{"removed","removing","removes","removals","removal","removable","remove"},
"removal":{"removed","removing","removes","removals","removal","removable","remove"},
"removals":{"removed","removing","removes","removals","removal","removable","remove"},
"removed":{"removed","removing","removes","removals","removal","removable","remove"},
"removes":{"removed","removing","removes","removals","removal","removable","remove"},
"removing":{"removed","removing","removes","removals","removal","removable","remove"},
"require":{"requiring","requirement","required","require","requires","requirements"},
"required":{"requiring","requirement","required","require","requires","requirements"},
"requirement":{"requiring","requirement","required","require","requires","requirements"},
"requirements":{"requiring","requirement","required","require","requires","requirements"},
"requires":{"requiring","requirement","required","require","requires","requirements"},
"requiring":{"requiring","requirement","required","require","requires","requirements"},
"research":{"researching","researchers","researcher","researched","research","researches"},
"researched":{"researching","researchers","researcher","researched","research","researches"},
"researcher":{"researching","researchers","researcher","researched","research","researches"},
"researchers":{"researching","researchers","researcher","researched","research","researches"},
"researches":{"researching","researchers","researcher","researched","research","researches"},
"researching":{"researching","researchers","researcher","researched","research","researches"},
"reside":{"reside","residing","residence","resided","resident","residential","residents","resides"},
"resided":{"reside","residing","residence","resided","resident","residential","residents","resides"},
"residence":{"reside","residing","residence","resided","resident","residential","residents","resides"},
"resident":{"reside","residing","residence","resided","resident","residential","residents","resides"},
"residential":{"reside","residing","residence","resided","resident","residential","residents","resides"},
"residents":{"reside","residing","residence","resided","resident","residential","residents","resides"},
"resides":{"reside","residing","residence","resided","resident","residential","residents","resides"},
"residing":{"reside","residing","residence","resided","resident","residential","residents","resides"},
"resolve":{"resolve","resolved","resolves","resolving","resolution"},
"resolution":{"resolve","resolved","resolves","resolving","resolution"},
"resolved":{"resolve","resolved","resolves","resolving","resolution"},
"resolves":{"resolve","resolved","resolves","resolving","resolution"},
"resolving":{"resolve","resolved","resolves","resolving","resolution"},
"unresolved":{"resolve","resolved","resolves","resolving","unresolved","resolution"},
"resource":{"resource","resourced","resourceful","resources","resourcing","under-resourced"},
"resourced":{"resource","resourced","resourceful","resources","resourcing","under-resourced"},
"resourceful":{"resource","resourced","resourceful","resources","resourcing","under-resourced"},
"resources":{"resource","resourced","resourceful","resources","resourcing","under-resourced"},
"resourcing":{"resource","resourced","resourceful","resources","resourcing","under-resourced"},
"under-resourced":{"unresourceful","resource","resourced","resourceful","resources","resourcing","under-resourced"},
"respond":{"respondent","responded","respondents","respond","unresponsive","responsiveness","responsive","responses","response","responds","responding"},
"responded":{"respondent","responded","respondents","respond","unresponsive","responsiveness","responsive","responses","response","responds","responding"},
"respondent":{"respondent","responded","respondents","respond","unresponsive","responsiveness","responsive","responses","response","responds","responding"},
"respondents":{"respondent","responded","respondents","respond","unresponsive","responsiveness","responsive","responses","response","responds","responding"},
"responding":{"respondent","responded","respondents","respond","unresponsive","responsiveness","responsive","responses","response","responds","responding"},
"responds":{"respondent","responded","respondents","respond","unresponsive","responsiveness","responsive","responses","response","responds","responding"},
"response":{"respondent","responded","respondents","respond","unresponsive","responsiveness","responsive","responses","response","responds","responding"},
"responses":{"respondent","responded","respondents","respond","unresponsive","responsiveness","responsive","responses","response","responds","responding"},
"responsive":{"respondent","responded","respondents","respond","unresponsive","responsiveness","responsive","responses","response","responds","responding"},
"responsiveness":{"respondent","responded","respondents","respond","unresponsive","responsiveness","responsive","responses","response","responds","responding"},
"unresponsive":{"respondent","responded","respondents","respond","unresponsive","responsiveness","responsive","responses","response","responds","responding"},
"restore":{"restored","restoration","restores","restoring","restore"},
"restoration":{"restored","restoration","restores","restoring","restore"},
"restored":{"restored","restoration","restores","restoring","restore"},
"restores":{"restored","restoration","restores","restoring","restore"},
"restoring":{"restored","restoration","restores","restoring","restore"},
"restrain":{"restraining","restraint","restrain","restraints","restrained","restrains"},
"restrained":{"restraining","restraint","restrain","restraints","restrained","restrains"},
"restraining":{"restraining","restraint","restrain","restraints","restrained","restrains"},
"restrains":{"restraining","restraint","restrain","restraints","restrained","restrains"},
"restraint":{"restraining","restraint","restrain","restraints","restrained","restrains"},
"restraints":{"restraining","restraint","restrain","restraints","restrained","restrains"},
"unrestrained":{"restraining","restraint","restrain","restraints","restrained","unrestrained","restrains"},
"restrict":{"restricted","restrict","restricting","restriction","restricts","restrictions","restrictive","restrictively"},
"restricted":{"restricted","restrict","restricting","restriction","restricts","restrictions","restrictive","restrictively"},
"restricting":{"restricted","restrict","restricting","restriction","restricts","restrictions","restrictive","restrictively"},
"restriction":{"restricted","restrict","restricting","restriction","restricts","restrictions","restrictive","restrictively"},
"restrictions":{"restricted","restrict","restricting","restriction","restricts","restrictions","restrictive","restrictively"},
"restrictive":{"restricted","restrict","restricting","restriction","restricts","restrictions","restrictive","restrictively"},
"restrictively":{"restricted","restrict","restricting","restriction","restricts","restrictions","restrictive","restrictively"},
"restricts":{"restricted","restrict","restricting","restriction","restricts","restrictions","restrictive","restrictively"},
"unrestricted":{"restricted","restrict","restricting","restriction","restricts","restrictions","restrictive","unrestrictive","unrestricted","restrictively"},
"retain":{"retaining","retainer","retain","retained","retainers","retains","retention","retentive"},
"retained":{"retaining","retainer","retain","retained","retainers","retains","retention","retentive"},
"retaining":{"retaining","retainer","retain","retained","retainers","retains","retention","retentive"},
"retainer":{"retaining","retainer","retain","retained","retainers","retains","retention","retentive"},
"retainers":{"retaining","retainer","retain","retained","retainers","retains","retention","retentive"},
"retains":{"retaining","retainer","retain","retained","retainers","retains","retention","retentive"},
"retention":{"retaining","retainer","retain","retained","retainers","retains","retention","retentive"},
"retentive":{"retaining","retainer","retain","retained","retainers","retains","retention","retentive"},
"reveal":{"reveal","revealing","reveals","revelation","revelations","revealed"},
"revealed":{"reveal","revealing","reveals","revelation","revelations","revealed"},
"revealing":{"reveal","revealing","reveals","revelation","revelations","revealed"},
"reveals":{"reveal","revealing","reveals","revelation","revelations","revealed"},
"revelation":{"reveal","revealing","reveals","revelation","revelations","revealed"},
"revelations":{"reveal","revealing","reveals","revelation","revelations","revealed"},
"revenue":{"revenue","revenues"},
"revenues":{"revenue","revenues"},
"reverse":{"reversed","reversals","reversing","reversible","reverses","reversal","reverse"},
"reversal":{"reversed","reversals","reversing","reversible","reverses","reversal","reverse"},
"reversed":{"reversed","reversals","reversing","reversible","reverses","reversal","reverse"},
"reverses":{"reversed","reversals","reversing","reversible","reverses","reversal","reverse"},
"reversible":{"reversed","reversals","reversing","reversible","reverses","reversal","reverse"},
"reversing":{"reversed","reversals","reversing","reversible","reverses","reversal","reverse"},
"reversals":{"reversed","reversals","reversing","reversible","reverses","reversal","reverse"},
"irreversible":{"reversed","irreversible","reversals","reversing","reversible","reverses","reversal","reverse"},
"revise":{"revising","revision","revises","revised","revise","revisions"},
"revised":{"revising","revision","revises","revised","revise","revisions"},
"revises":{"revising","revision","revises","revised","revise","revisions"},
"revising":{"revising","revision","revises","revised","revise","revisions"},
"revision":{"revising","revision","revises","revised","revise","revisions"},
"revisions":{"revising","revision","revises","revised","revise","revisions"},
"revolution":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionary":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionaries":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionise":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionised":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionises":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionising":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionist":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionists":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionize":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionized":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionizes":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutionizing":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"revolutions":{"revolutions","revolutionizes","revolutionist","revolution","revolutionized","revolutionize","revolutionists","revolutionise","revolutionising","revolutionises","revolutionised","revolutionizing","revolutionaries","revolutionary"},
"rigid":{"rigid","rigidities","rigidity","rigidly"},
"rigidities":{"rigid","rigidities","rigidity","rigidly"},
"rigidity":{"rigid","rigidities","rigidity","rigidly"},
"rigidly":{"rigid","rigidities","rigidity","rigidly"},
"role":{"role","roles"},
"roles":{"role","roles"},
"route":{"route","routing","routes","routed"},
"routed":{"route","routing","routes","routed"},
"routes":{"route","routing","routes","routed"},
"routing":{"route","routing","routes","routed"},
"scenario":{"scenarios","scenario"},
"scenarios":{"scenarios","scenario"},
"schedule":{"rescheduling","scheduling","schedules","scheduled","reschedules","rescheduled","reschedule","schedule"},
"reschedule":{"rescheduling","scheduling","schedules","scheduled","reschedules","rescheduled","reschedule","schedule"},
"rescheduled":{"rescheduling","scheduling","schedules","scheduled","reschedules","rescheduled","reschedule","schedule"},
"reschedules":{"rescheduling","scheduling","schedules","scheduled","reschedules","rescheduled","reschedule","schedule"},
"rescheduling":{"rescheduling","scheduling","schedules","scheduled","reschedules","rescheduled","reschedule","schedule"},
"scheduled":{"rescheduling","scheduling","schedules","scheduled","reschedules","rescheduled","reschedule","schedule"},
"schedules":{"rescheduling","scheduling","schedules","scheduled","reschedules","rescheduled","reschedule","schedule"},
"scheduling":{"rescheduling","scheduling","schedules","scheduled","reschedules","rescheduled","reschedule","schedule"},
"unscheduled":{"rescheduling","scheduling","schedules","scheduled","reschedules","rescheduled","reschedule","schedule","unscheduled"},
"scheme":{"schemes","scheming","schemed","schematically","schematic","scheme"},
"schematic":{"schemes","scheming","schemed","schematically","schematic","scheme"},
"schematically":{"schemes","scheming","schemed","schematically","schematic","scheme"},
"schemed":{"schemes","scheming","schemed","schematically","schematic","scheme"},
"schemes":{"schemes","scheming","schemed","schematically","schematic","scheme"},
"scheming":{"schemes","scheming","schemed","schematically","schematic","scheme"},
"section":{"sections","section","sectioned","sectioning"},
"sectioned":{"sections","section","sectioned","sectioning"},
"sectioning":{"sections","section","sectioned","sectioning"},
"sections":{"sections","section","sectioned","sectioning"},
"sector":{"sector","sectors"},
"sectors":{"sector","sectors"},
"secure":{"securities","security","secure","securing","secures","securely","secured"},
"insecure":{"securities","security","secure","securing","secures","securely","secured","insecurity","insecurities","insecure"},
"insecurities":{"securities","security","secure","securing","secures","securely","secured","insecurity","insecurities","insecure"},
"insecurity":{"securities","security","secure","securing","secures","securely","secured","insecurity","insecurities","insecure"},
"secured":{"securities","security","secure","securing","secures","securely","secured"},
"securely":{"securities","security","secure","securing","secures","securely","secured"},
"secures":{"securities","security","secure","securing","secures","securely","secured"},
"securing":{"securities","security","secure","securing","secures","securely","secured"},
"securities":{"securities","security","secure","securing","secures","securely","secured"},
"security":{"securities","security","secure","securing","secures","securely","secured"},
"seek":{"seek","sought","seeks","seeking"},
"seeking":{"seek","sought","seeks","seeking"},
"seeks":{"seek","sought","seeks","seeking"},
"sought":{"seek","sought","seeks","seeking"},
"select":{"selectively","selectors","selections","selector","selects","selection","selected","select","selective","selecting"},
"selected":{"selectively","selectors","selections","selector","selects","selection","selected","select","selective","selecting"},
"selecting":{"selectively","selectors","selections","selector","selects","selection","selected","select","selective","selecting"},
"selection":{"selectively","selectors","selections","selector","selects","selection","selected","select","selective","selecting"},
"selections":{"selectively","selectors","selections","selector","selects","selection","selected","select","selective","selecting"},
"selective":{"selectively","selectors","selections","selector","selects","selection","selected","select","selective","selecting"},
"selectively":{"selectively","selectors","selections","selector","selects","selection","selected","select","selective","selecting"},
"selector":{"selectively","selectors","selections","selector","selects","selection","selected","select","selective","selecting"},
"selectors":{"selectively","selectors","selections","selector","selects","selection","selected","select","selective","selecting"},
"selects":{"selectively","selectors","selections","selector","selects","selection","selected","select","selective","selecting"},
"sequence":{"sequentially","sequential","sequencing","sequences","sequenced","sequence"},
"sequenced":{"sequentially","sequential","sequencing","sequences","sequenced","sequence"},
"sequences":{"sequentially","sequential","sequencing","sequences","sequenced","sequence"},
"sequencing":{"sequentially","sequential","sequencing","sequences","sequenced","sequence"},
"sequential":{"sequentially","sequential","sequencing","sequences","sequenced","sequence"},
"sequentially":{"sequentially","sequential","sequencing","sequences","sequenced","sequence"},
"sex":{"sexually","sexuality","sexual","sexism","sexes","sex"},
"sexes":{"sexually","sexuality","sexual","sexism","sexes","sex"},
"sexism":{"sexually","sexuality","sexual","sexism","sexes","sex"},
"sexual":{"sexually","sexuality","sexual","sexism","sexes","sex"},
"sexuality":{"sexually","sexuality","sexual","sexism","sexes","sex"},
"sexually":{"sexually","sexuality","sexual","sexism","sexes","sex"},
"shift":{"shift","shifts","shifting","shifted"},
"shifted":{"shift","shifts","shifting","shifted"},
"shifting":{"shift","shifts","shifting","shifted"},
"shifts":{"shift","shifts","shifting","shifted"},
"significant":{"signifying","signify","signifies","significant","significance","significantly"},
"insignificant":{"signifying","signify","signifies","insignificant","significant","significance","significantly","insignificantly"},
"insignificantly":{"signifying","signify","signifies","insignificant","significant","significance","significantly","insignificantly"},
"significance":{"signifying","signify","signifies","significant","significance","significantly"},
"significantly":{"signifying","signify","signifies","significant","significance","significantly"},
"signified":{"signifying","signify","signifies","signified"},
"signifies":{"signifying","signify","signifies","signified"},
"signify":{"signifying","signify","signifies","signified"},
"signifying":{"signifying","signify","signifies","signified"},
"similar":{"similarly","similarity","similar","similarities"},
"dissimilar":{"similarly","similarity","similar","dissimilar","similarities"},
"similarities":{"similarly","similarity","similar","similarities"},
"similarity":{"similarly","similarity","similar","similarities"},
"similarly":{"similarly","similarity","similar","similarities"},
"simulate":{"simulate","simulated","simulating","simulation","simulates"},
"simulated":{"simulate","simulated","simulating","simulation","simulates"},
"simulates":{"simulate","simulated","simulating","simulation","simulates"},
"simulating":{"simulate","simulated","simulating","simulation","simulates"},
"simulation":{"simulate","simulated","simulating","simulation","simulates"},
"site":{"site","sites"},
"sites":{"site","sites"},
"sole":{"solely","sole"},
"solely":{"solely","sole"},
"source":{"source","sourcing","sources","sourced"},
"sourced":{"source","sourcing","sources","sourced"},
"sources":{"source","sourcing","sources","sourced"},
"sourcing":{"source","sourcing","sources","sourced"},
"specific":{"specific","specifically","specification","specifications","specificity","specifics"},
"specifically":{"specific","specifically","specification","specifications","specificity","specifics"},
"specification":{"specific","specifically","specification","specifications","specificity","specifics"},
"specifications":{"specific","specifically","specification","specifications","specificity","specifics"},
"specificity":{"specific","specifically","specification","specifications","specificity","specifics"},
"specifics":{"specific","specifically","specification","specifications","specificity","specifics"},
"specify":{"unspecified","specify","specifying","specified","specifies","specifiable"},
"specifiable":{"unspecified","specify","specifying","specified","specifies","specifiable"},
"specified":{"unspecified","specify","specifying","specified","specifies","specifiable"},
"specifies":{"unspecified","specify","specifying","specified","specifies","specifiable"},
"specifying":{"unspecified","specify","specifying","specified","specifies","specifiable"},
"unspecified":{"unspecified","specify","specifying","specified","specifies","specifiable"},
"sphere":{"spherical","sphere","spheres","spherically"},
"spheres":{"spherical","sphere","spheres","spherically"},
"spherical":{"spherical","sphere","spheres","spherically"},
"spherically":{"spherical","sphere","spheres","spherically"},
"stable":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"instability":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","instability","stable","unstable"},
"stabilisation":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"stabilise":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"stabilised":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"stabilises":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"stabilising":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"stabilization":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"stabilize":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"stabilized":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"stabilizes":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"stabilizing":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"stability":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","stable"},
"unstable":{"stabilises","stabilised","stabilization","stabilising","stability","stabilize","stabilized","stabilizes","stabilizing","stabilise","stabilisation","instability","stable","unstable"},
"statistic":{"statistician","statistical","statistically","statistics","statistic","statisticians"},
"statistician":{"statistician","statistical","statistically","statistics","statistic","statisticians"},
"statisticians":{"statistician","statistical","statistically","statistics","statistic","statisticians"},
"statistical":{"statistician","statistical","statistically","statistics","statistic","statisticians"},
"statistically":{"statistician","statistical","statistically","statistics","statistic","statisticians"},
"statistics":{"statistician","statistical","statistically","statistics","statistic","statisticians"},
"strategy":{"strategic","strategist","strategy","strategies","strategically","strategists"},
"strategic":{"strategic","strategist","strategy","strategies","strategically","strategists"},
"strategies":{"strategic","strategist","strategy","strategies","strategically","strategists"},
"strategically":{"strategic","strategist","strategy","strategies","strategically","strategists"},
"strategist":{"strategic","strategist","strategy","strategies","strategically","strategists"},
"strategists":{"strategic","strategist","strategy","strategies","strategically","strategists"},
"stress":{"stressing","stressed","stressful","stresses","stress"},
"stressed":{"stressing","stressed","stressful","stresses","stress"},
"stresses":{"stressing","stressed","stressful","stresses","stress"},
"stressful":{"stressing","stressed","stressful","stresses","stress"},
"stressing":{"stressing","stressed","stressful","stresses","stress"},
"unstressed":{"stressing","unstressed","stressed","stressful","stresses","stress"},
"structure":{"structured","restructuring","structures","structuring","structurally","structural","structure","restructure","restructured","restructures"},
"restructure":{"structured","restructuring","structures","structuring","structurally","structural","structure","restructure","restructured","restructures"},
"restructured":{"structured","restructuring","structures","structuring","structurally","structural","structure","restructure","restructured","restructures"},
"restructures":{"structured","restructuring","structures","structuring","structurally","structural","structure","restructure","restructured","restructures"},
"restructuring":{"structured","restructuring","structures","structuring","structurally","structural","structure","restructure","restructured","restructures"},
"structural":{"structured","restructuring","structures","structuring","structurally","structural","structure","restructure","restructured","restructures"},
"structurally":{"structured","restructuring","structures","structuring","structurally","structural","structure","restructure","restructured","restructures"},
"structured":{"structured","restructuring","structures","structuring","structurally","structural","structure","restructure","restructured","restructures"},
"structures":{"structured","restructuring","structures","structuring","structurally","structural","structure","restructure","restructured","restructures"},
"structuring":{"structured","restructuring","structures","structuring","structurally","structural","structure","restructure","restructured","restructures"},
"unstructured":{"structured","restructuring","structures","structuring","structurally","structural","structure","restructure","restructured","restructures","unstructured"},
"style":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"styled":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"styles":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"styling":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"stylish":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"stylise":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"stylised":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"stylises":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"stylising":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"stylize":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"stylized":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"stylizes":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"stylizing":{"style","styled","styles","styling","stylish","stylise","stylised","stylises","stylising","stylizes","stylizing","stylize","stylized"},
"submit":{"submit","submitting","submitted","submits","submissions","submission"},
"submission":{"submit","submitting","submitted","submits","submissions","submission"},
"submissions":{"submit","submitting","submitted","submits","submissions","submission"},
"submits":{"submit","submitting","submitted","submits","submissions","submission"},
"submitted":{"submit","submitting","submitted","submits","submissions","submission"},
"submitting":{"submit","submitting","submitted","submits","submissions","submission"},
"subordinate":{"subordination","subordinate","subordinates"},
"subordinates":{"subordination","subordinate","subordinates"},
"subordination":{"subordination","subordinate","subordinates"},
"subsequent":{"subsequently","subsequent"},
"subsequently":{"subsequently","subsequent"},
"subsidy":{"subsidising","subsidize","subsidizes","subsidy","subsidized","subsidiary","subsidizing","subsidises","subsidised","subsidise","subsidies"},
"subsidiary":{"subsidising","subsidize","subsidizes","subsidy","subsidized","subsidiary","subsidizing","subsidises","subsidised","subsidise","subsidies"},
"subsidies":{"subsidising","subsidize","subsidizes","subsidy","subsidized","subsidiary","subsidizing","subsidises","subsidised","subsidise","subsidies"},
"subsidise":{"subsidising","subsidize","subsidizes","subsidy","subsidized","subsidiary","subsidizing","subsidises","subsidised","subsidise","subsidies"},
"subsidised":{"subsidising","subsidize","subsidizes","subsidy","subsidized","subsidiary","subsidizing","subsidises","subsidised","subsidise","subsidies"},
"subsidises":{"subsidising","subsidize","subsidizes","subsidy","subsidized","subsidiary","subsidizing","subsidises","subsidised","subsidise","subsidies"},
"subsidising":{"subsidising","subsidize","subsidizes","subsidy","subsidized","subsidiary","subsidizing","subsidises","subsidised","subsidise","subsidies"},
"subsidize":{"subsidising","subsidize","subsidizes","subsidy","subsidized","subsidiary","subsidizing","subsidises","subsidised","subsidise","subsidies"},
"subsidized":{"subsidising","subsidize","subsidizes","subsidy","subsidized","subsidiary","subsidizing","subsidises","subsidised","subsidise","subsidies"},
"subsidizes":{"subsidising","subsidize","subsidizes","subsidy","subsidized","subsidiary","subsidizing","subsidises","subsidised","subsidise","subsidies"},
"subsidizing":{"subsidising","subsidize","subsidizes","subsidy","subsidized","subsidiary","subsidizing","subsidises","subsidised","subsidise","subsidies"},
"substitute":{"substituting","substitute","substituted","substitutes","substitution"},
"substituted":{"substituting","substitute","substituted","substitutes","substitution"},
"substitutes":{"substituting","substitute","substituted","substitutes","substitution"},
"substituting":{"substituting","substitute","substituted","substitutes","substitution"},
"substitution":{"substituting","substitute","substituted","substitutes","substitution"},
"successor":{"successor","succession","successive","successors","successions","successively"},
"succession":{"successor","succession","successive","successors","successions","successively"},
"successions":{"successor","succession","successive","successors","successions","successively"},
"successive":{"successor","succession","successive","successors","successions","successively"},
"successively":{"successor","succession","successive","successors","successions","successively"},
"successors":{"successor","succession","successive","successors","successions","successively"},
"sufficient":{"sufficiently","sufficiency","sufficient"},
"sufficiency":{"sufficiently","sufficiency","sufficient"},
"insufficient":{"sufficiently","insufficient","sufficiency","sufficient","insufficiently"},
"insufficiently":{"sufficiently","insufficient","sufficiency","sufficient","insufficiently"},
"sufficiently":{"sufficiently","sufficiency","sufficient"},
"sum":{"sums","summing","summed","summation","sum"},
"summation":{"sums","summing","summed","summation","sum"},
"summed":{"sums","summing","summed","summation","sum"},
"summing":{"sums","summing","summed","summation","sum"},
"sums":{"sums","summing","summed","summation","sum"},
"summary":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summaries":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summarise":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summarised":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summarises":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summarising":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summarize":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summarized":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summarizes":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summarizing":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"supplement":{"supplementing","supplemented","supplementary","supplement","supplements"},
"supplementary":{"supplementing","supplemented","supplementary","supplement","supplements"},
"supplemented":{"supplementing","supplemented","supplementary","supplement","supplements"},
"supplementing":{"supplementing","supplemented","supplementary","supplement","supplements"},
"supplements":{"supplementing","supplemented","supplementary","supplement","supplements"},
"survey":{"survey","surveying","surveyed","surveys"},
"surveyed":{"survey","surveying","surveyed","surveys"},
"surveying":{"survey","surveying","surveyed","surveys"},
"surveys":{"survey","surveying","surveyed","surveys"},
"survive":{"surviving","survivor","survive","survival","survived","survives","survivors"},
"survival":{"surviving","survivor","survive","survival","survived","survives","survivors"},
"survived":{"surviving","survivor","survive","survival","survived","survives","survivors"},
"survives":{"surviving","survivor","survive","survival","survived","survives","survivors"},
"surviving":{"surviving","survivor","survive","survival","survived","survives","survivors"},
"survivor":{"surviving","survivor","survive","survival","survived","survives","survivors"},
"survivors":{"surviving","survivor","survive","survival","survived","survives","survivors"},
"suspend":{"suspends","suspension","suspend","suspended","suspending"},
"suspended":{"suspends","suspension","suspend","suspended","suspending"},
"suspending":{"suspends","suspension","suspend","suspended","suspending"},
"suspends":{"suspends","suspension","suspend","suspended","suspending"},
"suspension":{"suspends","suspension","suspend","suspended","suspending"},
"sustain":{"sustained","sustenance","sustains","sustaining","sustainability","sustain","sustainable"},
"sustainable":{"sustained","sustenance","sustains","sustaining","sustainability","sustain","sustainable"},
"sustainability":{"sustained","sustenance","sustains","sustaining","sustainability","sustain","sustainable"},
"sustained":{"sustained","sustenance","sustains","sustaining","sustainability","sustain","sustainable"},
"sustaining":{"sustained","sustenance","sustains","sustaining","sustainability","sustain","sustainable"},
"sustains":{"sustained","sustenance","sustains","sustaining","sustainability","sustain","sustainable"},
"sustenance":{"sustained","sustenance","sustains","sustaining","sustainability","sustain","sustainable"},
"unsustainable":{"sustained","sustenance","sustains","unsustainable","sustaining","sustainability","sustain","sustainable"},
"symbol":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbolic":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbolically":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbolise":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbolises":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbolised":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbolising":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbolism":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbolize":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbolized":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbolizes":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbolizing":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"symbols":{"symbolically","symbolic","symbols","symbol","symbolizing","symbolizes","symbolized","symbolised","symbolises","symbolising","symbolise","symbolism","symbolize"},
"tape":{"taping","taped","tape","tapes"},
"taped":{"taping","taped","tape","tapes"},
"tapes":{"taping","taped","tape","tapes"},
"taping":{"taping","taped","tape","tapes"},
"target":{"targeted","target","targets","targeting"},
"targeted":{"targeted","target","targets","targeting"},
"targeting":{"targeted","target","targets","targeting"},
"targets":{"targeted","target","targets","targeting"},
"task":{"tasks","task"},
"tasks":{"tasks","task"},
"team":{"teams","teaming","teamed","team"},
"teamed":{"teams","teaming","teamed","team"},
"teaming":{"teams","teaming","teamed","team"},
"teams":{"teams","teaming","teamed","team"},
"technical":{"technically","technical"},
"technically":{"technically","technical"},
"technique":{"techniques","technique"},
"techniques":{"techniques","technique"},
"technology":{"technology","technological","technologically"},
"technological":{"technology","technological","technologically"},
"technologically":{"technology","technological","technologically"},
"temporary":{"temporarily","temporary"},
"temporarily":{"temporarily","temporary"},
"tense":{"tensions","tenser","tension","tense","tensely","tensest"},
"tension":{"tensions","tenser","tension","tense","tensely","tensest"},
"tensely":{"tensions","tenser","tension","tense","tensely","tensest"},
"tenser":{"tensions","tenser","tension","tense","tensely","tensest"},
"tensest":{"tensions","tenser","tension","tense","tensely","tensest"},
"tensions":{"tensions","tenser","tension","tense","tensely","tensest"},
"terminate":{"terminating","terminates","terminated","terminals","terminal","termination","terminations","terminate"},
"terminal":{"terminating","terminates","terminated","terminals","terminal","termination","terminations","terminate"},
"terminals":{"terminating","terminates","terminated","terminals","terminal","termination","terminations","terminate"},
"terminated":{"terminating","terminates","terminated","terminals","terminal","termination","terminations","terminate"},
"terminates":{"terminating","terminates","terminated","terminals","terminal","termination","terminations","terminate"},
"terminating":{"terminating","terminates","terminated","terminals","terminal","termination","terminations","terminate"},
"termination":{"terminating","terminates","terminated","terminals","terminal","termination","terminations","terminate"},
"terminations":{"terminating","terminates","terminated","terminals","terminal","termination","terminations","terminate"},
"text":{"textual","texts","text"},
"texts":{"textual","texts","text"},
"textual":{"textual","texts","text"},
"theme":{"thematic","themes","theme","thematically"},
"themes":{"thematic","themes","theme","thematically"},
"thematic":{"thematic","themes","theme","thematically"},
"thematically":{"thematic","themes","theme","thematically"},
"theory":{"theorist","theories","theorists","theoretical","theory","theoretically"},
"theoretical":{"theorist","theories","theorists","theoretical","theory","theoretically"},
"theoretically":{"theorist","theories","theorists","theoretical","theory","theoretically"},
"theories":{"theorist","theories","theorists","theoretical","theory","theoretically"},
"theorist":{"theorist","theories","theorists","theoretical","theory","theoretically"},
"theorists":{"theorist","theories","theorists","theoretical","theory","theoretically"},
"thesis":{"thesis","theses"},
"theses":{"thesis","theses"},
"topic":{"topical","topic","topics"},
"topical":{"topical","topic","topics"},
"topics":{"topical","topic","topics"},
"trace":{"traced","tracing","trace","traces","traceable"},
"traceable":{"traced","tracing","trace","traces","traceable"},
"traced":{"traced","tracing","trace","traces","traceable"},
"traces":{"traced","tracing","trace","traces","traceable"},
"tracing":{"traced","tracing","trace","traces","traceable"},
"tradition":{"traditional","tradition","traditions","traditionally","traditionalist"},
"non-traditional":{"traditional","non-traditional","tradition","traditions","traditionally","traditionalist"},
"traditional":{"traditional","tradition","traditions","traditionally","traditionalist"},
"traditionalist":{"traditional","tradition","traditions","traditionally","traditionalist"},
"traditionally":{"traditional","tradition","traditions","traditionally","traditionalist"},
"traditions":{"traditional","tradition","traditions","traditionally","traditionalist"},
"transfer":{"transfers","transferring","transferred","transference","transferable","transfer"},
"transferable":{"transfers","transferring","transferred","transference","transferable","transfer"},
"transference":{"transfers","transferring","transferred","transference","transferable","transfer"},
"transferred":{"transfers","transferring","transferred","transference","transferable","transfer"},
"transferring":{"transfers","transferring","transferred","transference","transferable","transfer"},
"transfers":{"transfers","transferring","transferred","transference","transferable","transfer"},
"transform":{"transformation","transforms","transforming","transformed","transformations","transform"},
"transformation":{"transformation","transforms","transforming","transformed","transformations","transform"},
"transformations":{"transformation","transforms","transforming","transformed","transformations","transform"},
"transformed":{"transformation","transforms","transforming","transformed","transformations","transform"},
"transforming":{"transformation","transforms","transforming","transformed","transformations","transform"},
"transforms":{"transformation","transforms","transforming","transformed","transformations","transform"},
"transit":{"transiting","transitional","transit","transitory","transits","transitions","transited","transition"},
"transited":{"transiting","transitional","transit","transitory","transits","transitions","transited","transition"},
"transiting":{"transiting","transitional","transit","transitory","transits","transitions","transited","transition"},
"transition":{"transiting","transitional","transit","transitory","transits","transitions","transited","transition"},
"transitional":{"transiting","transitional","transit","transitory","transits","transitions","transited","transition"},
"transitions":{"transiting","transitional","transit","transitory","transits","transitions","transited","transition"},
"transitory":{"transiting","transitional","transit","transitory","transits","transitions","transited","transition"},
"transits":{"transiting","transitional","transit","transitory","transits","transitions","transited","transition"},
"transmit":{"transmitting","transmits","transmitted","transmit","transmissions","transmission"},
"transmission":{"transmitting","transmits","transmitted","transmit","transmissions","transmission"},
"transmissions":{"transmitting","transmits","transmitted","transmit","transmissions","transmission"},
"transmitted":{"transmitting","transmits","transmitted","transmit","transmissions","transmission"},
"transmitting":{"transmitting","transmits","transmitted","transmit","transmissions","transmission"},
"transmits":{"transmitting","transmits","transmitted","transmit","transmissions","transmission"},
"transport":{"transporting","transports","transporter","transported","transportation","transporters","transport"},
"transportation":{"transporting","transports","transporter","transported","transportation","transporters","transport"},
"transported":{"transporting","transports","transporter","transported","transportation","transporters","transport"},
"transporter":{"transporting","transports","transporter","transported","transportation","transporters","transport"},
"transporters":{"transporting","transports","transporter","transported","transportation","transporters","transport"},
"transporting":{"transporting","transports","transporter","transported","transportation","transporters","transport"},
"transports":{"transporting","transports","transporter","transported","transportation","transporters","transport"},
"trend":{"trends","trend"},
"trends":{"trends","trend"},
"trigger":{"triggered","triggering","trigger","triggers"},
"triggered":{"triggered","triggering","trigger","triggers"},
"triggering":{"triggered","triggering","trigger","triggers"},
"triggers":{"triggered","triggering","trigger","triggers"},
"ultimate":{"ultimately","ultimate"},
"ultimately":{"ultimately","ultimate"},
"undergo":{"underwent","undergoing","undergoes","undergo","undergone"},
"undergoes":{"underwent","undergoing","undergoes","undergo","undergone"},
"undergoing":{"underwent","undergoing","undergoes","undergo","undergone"},
"undergone":{"underwent","undergoing","undergoes","undergo","undergone"},
"underwent":{"underwent","undergoing","undergoes","undergo","undergone"},
"underlie":{"underlying","underlie","underlay","underlies"},
"underlay":{"underlying","underlie","underlay","underlies"},
"underlies":{"underlying","underlie","underlay","underlies"},
"underlying":{"underlying","underlie","underlay","underlies"},
"undertake":{"undertook","undertaking","undertakes","undertake","undertaken"},
"undertaken":{"undertook","undertaking","undertakes","undertake","undertaken"},
"undertakes":{"undertook","undertaking","undertakes","undertake","undertaken"},
"undertaking":{"undertook","undertaking","undertakes","undertake","undertaken"},
"undertook":{"undertook","undertaking","undertakes","undertake","undertaken"},
"uniform":{"uniform","uniformity","uniformly"},
"uniformity":{"uniform","uniformity","uniformly"},
"uniformly":{"uniform","uniformity","uniformly"},
"unify":{"unify","unification","unified","unifies","unifying"},
"unification":{"unify","unification","unified","unifies","unifying"},
"unified":{"unify","unification","unified","unifies","unifying"},
"unifies":{"unify","unification","unified","unifies","unifying"},
"unifying":{"unify","unification","unified","unifies","unifying"},
"unique":{"uniquely","uniqueness","unique"},
"uniquely":{"uniquely","uniqueness","unique"},
"uniqueness":{"uniquely","uniqueness","unique"},
"utilise":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utilisation":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utilised":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utilises":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utilising":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utility":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utilities":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utilization":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utilize":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utilized":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utilizes":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utilizing":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"valid":{"validated","validity","validate","validly","valid","validation","validating"},
"invalidate":{"validated","validity","validate","invalidate","invalidity","validly","valid","validation","validating"},
"invalidity":{"validated","validity","validate","invalidate","invalidity","validly","valid","validation","validating"},
"validate":{"validated","validity","validate","validly","valid","validation","validating"},
"validated":{"validated","validity","validate","validly","valid","validation","validating"},
"validating":{"validated","validity","validate","validly","valid","validation","validating"},
"validation":{"validated","validity","validate","validly","valid","validation","validating"},
"validity":{"validated","validity","validate","validly","valid","validation","validating"},
"validly":{"validated","validity","validate","validly","valid","validation","validating"},
"vary":{"varies","vary","varying","varied","variations","variation","variance","variably","variability"},
"invariable":{"varies","vary","invariable","varying","varied","variations","variation","variance","variably","variables","variable","variability","invariably"},
"invariably":{"varies","vary","invariable","varying","varied","variations","variation","variance","variably","variables","variable","variability","invariably"},
"variability":{"varies","vary","varying","varied","variations","variation","variance","variably","variables","variable","variability"},
"variable":{"varies","vary","varying","varied","variations","variation","variance","variably","variables","variable","variability"},
"variables":{"varies","vary","varying","varied","variations","variation","variance","variably","variables","variable","variability"},
"variably":{"varies","vary","varying","varied","variations","variation","variance","variably","variables","variable","variability"},
"variance":{"varies","vary","varying","varied","variations","variation","variance","variably","variables","variable","variability"},
"variant":{"varies","vary","varying","varied","variations","variation","variants","variant","variance","variably","variables","variable","variability"},
"variants":{"varies","vary","varying","varied","variations","variation","variants","variant","variance","variably","variables","variable","variability"},
"variation":{"varies","vary","varying","varied","variations","variation","variance","variably","variables","variable","variability"},
"variations":{"varies","vary","varying","varied","variations","variation","variance","variably","variables","variable","variability"},
"varied":{"varies","vary","varying","varied","variations","variation","variance","variably","variables","variable","variability"},
"varies":{"varies","vary","varying","varied","variations","variation","variance","variably","variables","variable","variability"},
"varying":{"varies","vary","varying","varied","variations","variation","variance","variably","variables","variable","variability"},
"vehicle":{"vehicle","vehicles"},
"vehicles":{"vehicle","vehicles"},
"version":{"version","versions"},
"versions":{"version","versions"},
"violate":{"violate","violations","violation","violating","violates","violated"},
"violated":{"violate","violations","violation","violating","violates","violated"},
"violates":{"violate","violations","violation","violating","violates","violated"},
"violating":{"violate","violations","violation","violating","violates","violated"},
"violation":{"violate","violations","violation","violating","violates","violated"},
"violations":{"violate","violations","violation","violating","violates","violated"},
"virtual":{"virtual","virtually"},
"virtually":{"virtual","virtually"},
"visible":{"visibly","visibility","visible"},
"visibility":{"visibly","visibility","visible"},
"visibly":{"visibly","visibility","visible"},
"invisible":{"visibly","invisible","invisibility","visibility","visible"},
"invisibility":{"visibly","invisible","invisibility","visibility","visible"},
"vision":{"vision","visions"},
"visions":{"vision","visions"},
"visual":{"visually","visualise","visualised","visualising","visual","visualisation","visualize","visualized","visualizing","visualization"},
"visualise":{"visually","visualise","visualised","visualising","visual","visualisation","visualize","visualized","visualizing","visualization"},
"visualised":{"visually","visualise","visualised","visualising","visual","visualisation","visualize","visualized","visualizing","visualization"},
"visualising":{"visually","visualise","visualised","visualising","visual","visualisation","visualize","visualized","visualizing","visualization"},
"visualisation":{"visually","visualise","visualised","visualising","visual","visualisation","visualize","visualized","visualizing","visualization"},
"visualize":{"visually","visualise","visualised","visualising","visual","visualisation","visualize","visualized","visualizing","visualization"},
"visualized":{"visually","visualise","visualised","visualising","visual","visualisation","visualize","visualized","visualizing","visualization"},
"visualizing":{"visually","visualise","visualised","visualising","visual","visualisation","visualize","visualized","visualizing","visualization"},
"visualization":{"visually","visualise","visualised","visualising","visual","visualisation","visualize","visualized","visualizing","visualization"},
"visually":{"visually","visualise","visualised","visualising","visual","visualisation","visualize","visualized","visualizing","visualization"},
"volume":{"volume","vol","volumes"},
"volumes":{"volume","vol","volumes"},
"vol":{"volume","vol","volumes"},
"voluntary":{"volunteers","volunteer","voluntary","volunteered","volunteering","voluntarily"},
"voluntarily":{"volunteers","volunteer","voluntary","volunteered","volunteering","voluntarily"},
"volunteer":{"volunteers","volunteer","voluntary","volunteered","volunteering","voluntarily"},
"volunteering":{"volunteers","volunteer","voluntary","volunteered","volunteering","voluntarily"},
"volunteered":{"volunteers","volunteer","voluntary","volunteered","volunteering","voluntarily"},
"volunteers":{"volunteers","volunteer","voluntary","volunteered","volunteering","voluntarily"},
"aren":{"beings","are","isn","being","weren","were","is","been","aren","re","s","am","be","was","wasn"},
"isn":{"beings","are","isn","being","weren","were","is","been","aren","re","s","am","be","was","wasn"},
"wasn":{"beings","are","isn","being","weren","were","is","been","aren","re","s","am","be","was","wasn"},
"weren":{"beings","are","isn","being","weren","were","is","been","aren","re","s","am","be","was","wasn"},
"unbusinesslike":{"businesswoman","business","businesses","businessmen","unbusinesslike","businessman","businesswomen","businesslike"},
"centerist":{"centred","center","centerist","centrists","centrist","centres","centralization","central","centered","centers","centerists","centre"},
"centerists":{"centred","center","centerist","centrists","centrist","centres","centralization","central","centered","centers","centerists","centre"},
"couldn":{"could","couldn"},
"didn":{"do","did","didn","does","doesn","doing","don","done"},
"doesn":{"do","did","didn","does","doesn","doing","don","done"},
"hadn":{"ve","haven","has","hasn","hadn","had","have","having","haves"},
"hasn":{"ve","haven","has","hasn","hadn","had","have","having","haves"},
"ve":{"ve","haven","has","hasn","hadn","had","have","having","haves"},
"lifesize":{"lifesize"},
"mightn":{"might","mightn"},
"needn":{"needn","needs","needless","needing","needed","need"},
"noone":{"noone","no","nobody","nothing","nowhere"},
"oughtn":{"ought","oughtn"},
"proven":{"proving","prove","proved","proven","proves"},
"shouldn":{"should","shouldn"},
"wiseness":{"wisely","wise","wisest","wisdom","wiser","wiseness"},
"wouldn":{"wouldn","would"},
"advisors":{"advisory","advise","advised","advisors","adviser","advisers","advises","advice","advising"},
"aunty":{"aunt","aunty","aunts"},
"broadcasted":{"broadcasts","broadcasting","broadcasted","broadcast"},
"bussing":{"bussed","buses","bus","bussing"},
"cappings":{"capped","cappings","caps","cap","capping"},
"cruellest":{"cruel","cruelties","cruelty","crueller","cruellest","cruelness","cruelly"},
"crueller":{"cruel","cruelties","cruelty","crueller","cruellest","cruelness","cruelly"},
"kneeled":{"kneel","kneels","kneeled","kneeling"},
"orangish":{"orangish","orange","oranges"},
"ridded":{"ridding"},
"shoed":{"shoes","shoeing","shoe","shoed"},
"skilful":{"skilled","skilfully","skill","skills","skilful"},
"misspelt":{"spelled","spells","spelling","spelt","spell","misspelt"},
"sweated":{"sweat","sweats","sweating","sweated"},
"wheats":{"wheats","wheat"},
"affectively":{"affective","affects","affecting","affected","affect","affectively"},
"appropriacy":{"appropriateness","appropriately","appropriacy","appropriate"},
"inappropriacy":{"inappropriacy","appropriateness","appropriately","appropriacy","inappropriate","inappropriately","appropriate"},
"unassessed":{"reassessment","reassessing","reassessed","reassess","assessable","assessments","assessment","assessing","assesses","assessed","assess","unassessed"},
"communicatively":{"communicates","communicatively","communicative","communications","communication","communicating","communicated","communicable","communicate"},
"componentry":{"componentry","components","component"},
"conformability":{"conforms","conformity","conformists","conformist","conforming","conformed","conformation","conformance","conformability","conformable"},
"uncontextualised":{"contextualise","contextualized","contextualizing","contextualize","uncontextualised","contextualising","contextualised","contextual","contexts","context","uncontextualized"},
"uncontextualized":{"contextualise","contextualized","contextualizing","contextualize","uncontextualised","contextualising","contextualised","contextual","contexts","context","uncontextualized"},
"indiscrete":{"discrete","discretely","discretion","discretionary","indiscrete","indiscretion"},
"exclusionist":{"exclusions","exclusionist","exclusion","excluding","excludes","excluded","exclusive","exclusively","exclusionary","exclude"},
"externality":{"external","externalisation","externalises","externalise","externally","externalizing","externalized","externality","externalize","externalization","externalising","externalised","externalizes"},
"focussed":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"focussing":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"refocussed":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"refocusses":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"refocussing":{"focus","refocused","focused","refocuses","focusing","refocus","refocusing","focussing","refocusses","focussed","refocussing","focuses","refocussed"},
"funder":{"funds","funding","funders","funder","funded","fund"},
"funders":{"funds","funding","funders","funder","funded","fund"},
"intenseness":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"intension":{"intense","intensive","intensity","intension","intensifying","intensify","intensifies","intensified","intensification","intenseness","intensely","intensively"},
"liberations":{"liberator","liberals","liberalising","liberalizes","liberating","liberalizing","liberate","liberated","liberation","liberalized","liberally","liberalize","liberal","liberalise","liberalism","liberalisation","liberalised","liberalises","liberalization","liberators","liberations","liberates"},
"maturational":{"maturational","maturity","maturing","matures","matured","maturation","mature"},
"minimalisation":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalise":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalised":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalising":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalization":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalize":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalized":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalizes":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"minimalizing":{"minimalize","minimalization","minimalistic","minimalists","minimalising","minimalist","minimalizes","minimalizing","minimally","minimalisation","minimal","minimalise","minimalized","minimalises","minimalised"},
"deregister":{"registration","registers","registering","registered","deregistration","deregisters","deregistering","deregistered","deregister","register"},
"deregistered":{"registration","registers","registering","registered","deregistration","deregisters","deregistering","deregistered","deregister","register"},
"deregistering":{"registration","registers","registering","registered","deregistration","deregisters","deregistering","deregistered","deregister","register"},
"deregisters":{"registration","registers","registering","registered","deregistration","deregisters","deregistering","deregistered","deregister","register"},
"deregistration":{"registration","registers","registering","registered","deregistration","deregisters","deregistering","deregistered","deregister","register"},
"unresourceful":{"unresourceful","resource","resourced","resourceful","resources","resourcing","under-resourced"},
"unrestrictive":{"restricted","restrict","restricting","restriction","restricts","restrictions","restrictive","unrestrictive","unrestricted","restrictively"},
"summarisation":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summarisations":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summarization":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"summarizations":{"summary","summarize","summaries","summarised","summarizing","summarizes","summarized","summarizations","summarization","summarisations","summarisation","summarising","summarises","summarise"},
"utiliser":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"utilisers":{"utilisation","utilise","utilizing","utilizes","utilized","utilisers","utilises","utilised","utilising","utility","utilization","utilize","utiliser","utilities"},
"flawless":{"flawlessly"},
"flawlessly":{"flawless"},
"rebel":{"rebellion"},
"rebellion":{"rebel"},
"personality":{"personal","personally","personalities","persons","person"},
"adamancy":{"adamant"},
"adamant":{"adamancy"},
"rebuild":{"rebuilding"},
"rebuilding":{"rebuild"},
"rarity":{"rare"},
"chaos":{"chaotic"},
"chaotic":{"chaos"},
"blank":{"blankness"},
"blankness":{"blank"},
"cloudiness":{"cloudy","cloud","clouds"},
"aloud":{"loud"},
"naught":{"naughty","naughtiness"},
"naughty":{"naught","naughtiness"},
"naughtiness":{"naught","naughty"},
"scholar":{"scholarly"},
"scholarly":{"scholar"},
"richen":{"rich"},
"absolute":{"absolutely"},
"absolutely":{"absolute"},
"humor":{"humors","humorous"},
"humors":{"humor","humorous"},
"humorous":{"humor","humors"},
"laze":{"laziness","lazy","lazily"},
"hardly":{"hard"},
"strive":{"striving"},
"for":{"in","of","on","to","with","at","by","from","about"},
"to":{"in","for","of","on","with","at","by","from","about","too"},
"of":{"in","for","off","on","to","with","at","by","from","about"},
"with":{"in","for","of","on","to","at","by","from","about"},
"at":{"in","for","of","on","to","with","by","from","about"},
"by":{"in","for","of","on","to","with","at","from","about"},
"from":{"in","for","of","on","to","with","at","by","about"},
"about":{"in","for","of","on","to","with","at","by","from"},
"into":{"in"},
"undeniably":{"undeniable"},
"before":{"ago"},
"ago":{"before"},
"twin":{"twins"},
"twins":{"twin"},
"beautify":{"beautiful"},
"asia":{"asian"},
"asian":{"asia"},
"thw":{"the"},
"bust":{"best"},
"fiend":{"friend"},
"very":{"every"},
"plated":{"played"},
"prat":{"part"},
"unclocked":{"unlocked"},
"mu":{"my"},
"though":{"through"}
}
