ecdic={"'neath":"p:在_底下,底下",
"'til":"p:直到",
"'till":"p:直到",
"AHA":"i:嘿嘿",
"Abigail":"n:使女",
"Aborigines":"n:土产,土人,土著",
"Abra":"n:岩洞",
"Ah":"i:唉,呀,哎,呵,阿,哦;f:呀,哟",
"Ahoy":"i:喂",
"Alameda":"n:林荫道",
"Andre":"n:安德烈",
"Anhui":"n:安徽",
"Ann":"n:安",
"Anshan":"n:鞍山",
"Anton":"n:安东",
"Anyang":"n:安阳",
"Archibald":"n:高射炮",
"Ariel":"n:羚羊",
"Arret":"n:扣押,命令,裁判",
"Artus":"n:关节",
"Aurelia":"n:蛹",
"Aw":"i:呀,厌恶,讨厌",
"Azov":"n:亚速海",
"BIOS":"n:生命,生物",
"BIS":"d:又,重复,重叠",
"Baffler":"n:挡板",
"Bah":"n:六六六;i:呸;v:嘲笑",
"Bao":"n:鲍,包",
"Baoding":"n:保定",
"Baqi":"n:八旗",
"Barents":"n:巴伦支海",
"Barton":"n:巴顿,鸡舍",
"Bei":"n:贝",
"Beiping":"n:北平",
"Benxi":"n:本溪",
"Berger":"n:伯杰",
"Bibby":"n:警察",
"Bice":"n:蓝色,绿色",
"Bilbo":"n:剑",
"Blimey":"i:啊呀",
"Bo":"n:流浪汉,小伙子,浪子,老兄",
"Boeing":"n:波音",
"Bowlegs":"n:罗圈腿",
"Bree":"n:肉汤,汤",
"Britannia":"n:大不列颠",
"Britannica":"n:不列颠",
"Brodie":"n:失败,自杀,失策",
"Bub":"n:小伙子,小兄弟",
"Buran":"n:雪暴",
"CIT":"n:老百姓,城里人,便服",
"COALMINE":"n:煤矿",
"COMM":"n:通信",
"Caballero":"n:骑士,绅士",
"Cai":"n:蔡",
"Cao":"n:曹,章",
"Capetown":"n:开普敦",
"Caplet":"n:锭",
"Carey":"n:凯里",
"Carl":"n:家伙",
"Carlin":"n:巫婆,老太婆",
"Carline":"n:巫婆,老太婆",
"Carmen":"n:卡门",
"Caro":"n:果肉",
"Cate":"n:美食,美味,珍馐",
"Cato":"n:政治家",
"Celeste":"n:天蓝色",
"Celestine":"n:天青石",
"Changchun":"n:长春",
"Changsha":"n:长沙",
"Changzhou":"n:常州",
"Chanticleer":"n:雄鸡",
"Chao":"n:曹",
"Chappy":"n:小伙子,花花公子,家伙",
"Che":"n:车",
"Cheng":"n:程",
"Chengde":"n:承德",
"Chengdu":"n:成都",
"Chinatown":"n:唐人街",
"Chu":"n:楚",
"Cion":"n:接穗,悬雍垂",
"Clippers":"n:剪子,推子,剪,钳子;v:剪",
"Cohen":"n:科恩",
"Comintern":"n:共产国际",
"Comparator":"n:比色计",
"Compo":"n:组成,混合,灰沙,组合;v:组成",
"Coulee":"n:低地,深谷",
"Crimean":"n:克里米亚",
"Crista":"n:脊",
"Crumby":"a:肮脏,低廉,劣等",
"Cui":"n:崔",
"Cully":"n:家伙,傻瓜",
"Curr":"v:低语",
"DOODAH":"n:惊慌",
"Dai":"n:戴",
"Dan":"n:丹,浮标",
"Dandong":"n:丹东",
"Dangler":"n:耳环",
"Darby":"n:钞票",
"Dee":"n:吊环",
"Dene":"n:沙丘,幽谷",
"Deng":"n:邓",
"Deva":"n:神",
"Diao":"n:刁",
"Dingus":"n:东西,玩意儿",
"Dion":"n:聚酯",
"Dost":"v:做",
"Doughty":"a:强悍",
"Doyle":"n:医生",
"Duan":"n:段",
"Dukes":"n:拳头",
"Dunhuang":"n:敦煌",
"Eddie":"n:埃迪",
"Elohim":"n:上帝,神",
"Erector":"n:建设者",
"Erwin":"n:欧文",
"Eva":"n:夏娃",
"Everglade":"n:沼泽地,湿地",
"FEI":"n:费",
"Fenghua":"n:奉化",
"Fetters":"n:锁链,枷锁,脚镣,镣",
"Fie":"i:呸",
"Flam":"n:谎话,诡计,欺诈;v:欺骗",
"Flor":"n:酒花",
"Foss":"n:城壕",
"Foxfire":"n:狐火",
"Fu":"n:甫",
"Fudan":"n:复旦",
"Fujian":"n:福建",
"Fujitsu":"n:富士通",
"Fuling":"n:涪陵",
"Fushun":"n:抚顺",
"Fuyang":"n:阜阳",
"Fuzhou":"n:福州",
"GAI":"n:盖",
"GAN":"n:甘",
"GIRT":"v:缠,束",
"Gaby":"n:傻瓜",
"Gangtok":"n:甘托克",
"Garth":"n:花园,庭院",
"Gasser":"n:加塞",
"Georgina":"n:德国",
"Goodnight":"n:再见",
"Gordon":"n:戈登",
"Grue":"v:战栗;n:雪",
"Guangxi":"n:光绪,广西",
"Guilin":"n:桂林",
"Guiyang":"n:桂阳",
"Guizhou":"n:贵州",
"Guo":"n:郭",
"Gussie":"v:装饰",
"Hague":"n:海牙",
"Haikou":"n:海口",
"Hainan":"n:海南",
"Hankou":"n:汉口",
"Hans":"n:汉斯",
"Harbin":"n:哈尔滨",
"Headwaters":"n:河源,水源",
"Hefei":"n:合肥",
"Heihe":"n:黑河",
"Heilongjiang":"n:龙江",
"Henley":"n:亨利",
"Hodge":"n:庄稼人",
"Hoke":"v:搪塞",
"Holt":"n:林地",
"Hong":"n:洪",
"Hou":"n:侯",
"Hu":"n:胡",
"Huan":"n:宦,桓",
"Hugh":"n:休",
"Huma":"n:呼玛",
"Humph":"i:哼",
"Huo":"n:霍",
"Hurray":"v:欢呼,叫好",
"Hurst":"n:沙洲,树林",
"IND":"n:印度",
"IPA":"n:国际音标",
"Illuminati":"n:天才",
"Inness":"n:学会,绝缘",
"Irwin":"n:欧文",
"Izvestia":"n:审判员",
"JIADING":"n:嘉定",
"JUL":"n:七月,7月",
"Jake":"a:家伙",
"Jane":"n:简",
"Jardiniere":"n:花瓶,花盆",
"Jesse":"n:杰西",
"Jessie":"n:杰西",
"Jia":"n:贾",
"Jian":"n:简,集安",
"Jiang":"n:蒋",
"Jiangling":"n:江陵",
"Jiangsu":"n:江苏",
"Jiangxi":"n:赣",
"Jie":"n:解",
"Jiff":"n:一会儿",
"Jilin":"n:吉林",
"Jin":"n:靳,市斤,金",
"Jinan":"n:济南",
"Jingdezhen":"n:景德镇",
"Jinling":"n:金陵",
"Jiujiang":"n:九江",
"Jocko":"n:黑猩猩",
"Joe":"n:乔",
"Julu":"n:巨鹿",
"Jun":"n:六月,6月",
"Kaddish":"n:祈祷",
"Kaifeng":"n:开封",
"Kang":"n:炕,炕床",
"Kaohsiung":"n:高雄",
"Kay":"n:凯,珊瑚礁",
"Keck":"v:恶心,作呕",
"Kodak":"n:柯达",
"Kong":"n:孔",
"Kou":"n:寇",
"Kowloon":"n:九龙",
"Kunming":"n:昆明",
"Kyle":"n:海峡",
"LBS":"n:磅",
"Lai":"n:赖",
"Lang":"n:郎",
"Laura":"n:劳拉",
"Laval":"n:亚麻布",
"Leng":"n:冷",
"Levin":"n:电光,闪电",
"Lewes":"n:刘易斯",
"Lian":"n:廉",
"Liane":"n:蔓生植物,藤本植物",
"Liang":"n:两",
"Liaoning":"n:辽宁",
"Liaoyang":"n:辽阳",
"Linan":"n:临安",
"Linn":"n:瀑布,绝壁",
"Liu":"n:刘",
"Lou":"n:娄",
"Lune":"n:弓形,半月形,月亮",
"Luzhou":"n:庐州",
"MAI":"n:麦",
"Mage":"n:学者",
"Marie":"n:玛丽",
"Martha":"n:玛莎",
"Mavericks":"n:迷路",
"Mel":"n:蜂蜜",
"Melton":"n:麦尔登呢",
"Mencius":"n:孟子",
"Meng":"n:孟",
"Microsoft":"n:微软",
"Milli":"n:毫",
"Mitsubishi":"n:三菱",
"Mizar":"n:开阳",
"Momenta":"n:冲力,动量",
"Moroni":"n:莫罗尼",
"Mort":"n:死",
"NCO":"n:军士",
"Nie":"n:聂",
"Ningbo":"n:宁波",
"Niu":"n:钮,牛",
"Noddy":"n:傻瓜,呆子",
"Nope":"d:不",
"Norton":"n:诺顿",
"Nye":"n:奈",
"OU":"n:欧",
"Oho":"i:哎呀,啊,哎哟,哟嗬",
"Ouch":"f:哟;i:哎;n:扣子",
"Palisades":"n:栅栏",
"Palmerston":"n:外交家",
"Pappy":"a:烂",
"Patroon":"n:船长",
"Pena":"n:岩石",
"Peng":"n:彭",
"Penna":"n:羽毛",
"Pentium":"n:奔腾",
"Phew":"i:呸",
"Pinewood":"n:松林",
"Pinyin":"n:拼音",
"Plebs":"n:百姓,庶民,平民",
"Pointblank":"a:直截了当",
"Pooh":"i:呸",
"Poppa":"n:爸爸",
"Porky":"a:猪肉",
"Protestants":"n:新教",
"Pshaw":"i:哼",
"QM":"n:舵手",
"Qian":"n:钱",
"Qiao":"n:乔",
"Qingdao":"n:青岛",
"Qinghua":"n:清华",
"Qiu":"n:邱",
"Qu":"n:曲",
"Quan":"n:全",
"Quanta":"n:份额,定量,量",
"RESEND":"v:退还,送还",
"Rae":"n:雷",
"Rafael":"n:拉斐尔",
"Raff":"n:大量,废料,许多,垃圾,大批",
"Rao":"n:饶,尧",
"Redd":"v:整顿,收拾",
"Remarque":"n:标记",
"Ren":"n:任",
"Reuters":"n:路透社",
"Richard":"n:理查",
"Roche":"n:岩石",
"Roger":"i:乐果",
"Rong":"n:荣",
"Rowe":"n:罗",
"Ruan":"n:阮",
"Rumours":"n:风风雨雨",
"Rx":"n:药方,处方",
"SHU":"n:舒",
"Sal":"n:出售,娑罗双树,盐,柳安",
"Sammy":"n:傻子,蠢货",
"Sanders":"n:檀香,檀木",
"Santana":"n:桑塔纳",
"Sayer":"n:发言人,诗人",
"Scriptures":"n:经典",
"Sha":"n:莎",
"Shahe":"n:沙河",
"Shandong":"n:山东",
"Shantou":"n:汕头",
"Shanxi":"n:山西",
"Shao":"n:芍,绍,邵",
"Shaoxing":"n:绍兴,绍",
"Sheba":"n:美女",
"Shen":"n:沈",
"Sheng":"n:盛",
"Shenzhen":"n:深圳",
"Sheol":"n:阴间,地狱",
"Shetlands":"n:设得兰群岛",
"Shi":"n:师",
"Shijiazhuang":"n:石家庄",
"Shoppe":"n:专柜",
"Shorty":"n:矮子",
"Sile":"v:产卵",
"Skeeter":"n:蚊子",
"Skoal":"i:干杯",
"Smalls":"n:粉末",
"Smokey":"n:警察",
"Sony":"n:索尼",
"Sui":"n:隋",
"Suzhou":"n:苏州,苏",
"Tache":"n:斑点,扣子,钩,黑斑,钩子,环,扣",
"Taian":"n:泰安",
"Tainan":"n:台南",
"Taoists":"n:道家",
"Tarter":"a:牙垢",
"Tass":"n:塔斯社",
"Termini":"n:终点",
"Terra":"n:地球,土,地",
"Tian":"n:田",
"Tiananmen":"n:天安门",
"Tong":"n:钳子,童",
"Tony":"a:高级",
"Tooter":"n:宣传员",
"Tootsie":"n:脚,女人",
"Trow":"v:想",
"Tu":"n:屠",
"Tuan":"n:老板",
"Ural":"n:乌拉尔",
"Ursa":"n:大熊座",
"Urumqi":"n:乌鲁木齐",
"VIPs":"n:达官贵人",
"Vail":"v:脱帽,脱,低下,低头;n:贿赂,赏钱",
"Val":"n:克当量",
"Vance":"n:万斯",
"Vic":"n:犯人",
"Vita":"n:生命,生存,传记;v:生存",
"Voyageur":"n:船夫",
"WC":"n:公厕",
"WIS":"n:知道",
"Wang":"n:王",
"Ween":"v:以为,想,想像,预期,设想,相信",
"Wenzhou":"n:温州",
"Willa":"n:威拉",
"William":"n:威廉",
"Willie":"n:害怕,发抖",
"Wuhu":"n:芜湖",
"Wuxi":"n:无锡",
"Xanadu":"n:华夏,世外桃源",
"Xanthippe":"n:悍妇",
"Xia":"n:夏",
"Xiamen":"n:厦门",
"Xiang":"n:项",
"Xiangyang":"n:襄阳",
"Xiao":"n:萧,肖",
"Xichang":"n:西昌",
"Xie":"n:谢",
"Xin":"n:忻,辛",
"Xing":"n:邢",
"Xining":"n:西宁",
"Xiong":"n:熊",
"Xu":"n:徐",
"Xuan":"n:轩,宣",
"Xue":"n:薛",
"Xuzhou":"n:徐州,许州",
"Yan":"n:阎,严,彦",
"Yangzhou":"n:扬,扬州",
"Yanjing":"n:燕京",
"Yantai":"n:烟台",
"Yao":"n:姚",
"Yeltsin":"n:叶利钦",
"Yippee":"i:开心",
"Yixing":"n:宜兴",
"Yu":"n:禹,俞",
"Yulin":"n:榆林,玉林",
"Yun":"n:云",
"Yup":"d:是的",
"Yuxi":"n:玉溪",
"Zeng":"n:曾",
"Zhai":"n:翟",
"Zhan":"n:詹",
"Zhang":"n:张,丈",
"Zhanjiang":"n:湛江",
"Zhao":"n:赵,肇",
"Zhejiang":"n:浙江",
"Zhen":"n:甄",
"Zheng":"n:郑",
"Zhengzhou":"n:郑州",
"Zhong":"n:钟",
"Zhu":"n:朱",
"Zhuhai":"n:珠海",
"Zong":"n:宗",
"Zou":"n:邹",
"Zunyi":"n:遵义",
"a":"a:一;d:一道",
"a bit":"a:差,点滴,了,稍稍,些小,一点,一丁点儿,稍许,点,一点儿,一星儿,丝毫,些微",
"a few":"a:些,两,某些,一点,零星,数,少量,些个,一星半点,些许",
"a fortiori":"n:更加,何况",
"a good deal":"n:大量,诸多,好多",
"a great deal":"n:夥",
"a little":"a:一些,一点儿,点,些,有点,稍稍,稍,少许,略微,些小,聊,稍为,有限,些个,些微,零星,一星半点,一星儿",
"a priori":"a:先天",
"a trifle":"n:稍,略微",
"a-bomb":"n:原子弹",
"aaron":"n:亚伦",
"aba":"n:毛织物,长袍",
"abacus":"n:算盘,顶板",
"abaft":"p:后,之后,在_之后,在_后",
"abalone":"n:鲍鱼,鲍,鳆",
"abandon":"v:下马;n:狂热",
"abandoned":"a:无赖,野",
"abandonment":"n:放弃,断念,放肆,投保",
"abase":"v:贬,降低",
"abasement":"n:屈辱,失意,败落",
"abash":"v:羞怯;a:羞怯",
"abashed":"a:惭愧,羞愧",
"abate":"v:减弱,减小,缓和,压低,杀,取消,减,煞,除掉,免税,作废,削弱,制止",
"abatement":"n:减少,减轻,废料,折扣,减除,失效,中断,减退",
"abbe":"n:神父",
"abbey":"n:修道院,修道士",
"abbot":"n:方丈,住持",
"abbreviate":"v:缩写,节略,删节;a:简略",
"abbreviation":"n:简称,省略,缩略语;v:省略",
"abc":"n:初步,入门,字母表;v:入门",
"abdicate":"v:放弃,让,退,让位,逊,弃,辞,废",
"abdication":"n:放弃,辞职,让位,弃权",
"abdomen":"n:腹腔,肚子",
"abdominal muscle":"n:腹肌",
"abduct":"v:绑架,拐走,拐,拐带,胁持",
"abduction":"n:劫持",
"abductor":"n:拐子,诱拐者",
"abeam":"d:横向",
"aberrant":"a:怪人",
"aberration":"n:错乱,偏差,反常,失常,过失,变型,越轨",
"abet":"v:教唆,帮助,撮弄,鼓动,唆,主使",
"abettor":"n:教唆者",
"abeyance":"n:停止;v:搁置",
"abhor":"v:疾,嫌弃",
"abhorrence":"n:厌恶,憎恶,痛恨,嫌恶",
"abidance":"n:继续,遵守",
"abide":"v:等待,忍受,继续,保持,守,坚持,容忍,居住,依从",
"abide by":"v:循,守",
"abilities":"n:锋芒",
"ability":"n:能,才力,力,力量,技能,技法,两下子,材,干才,功夫,伎",
"abject":"a:猥劣,卑怯;n:小人",
"abjection":"v:脱落,放射,脱出;n:卑劣",
"ablation":"n:磨削,脱落,消融",
"ablaze":"d:燃烧,闪耀,着火,激昂;a:熊熊,炽盛",
"able":"a:会,能干,干,成,贤;v:能",
"abloom":"a:盛开,开花",
"ablution":"n:清洗,洗净",
"abnegate":"v:克制",
"abnegation":"n:克制",
"abnormal":"a:异常,反常,变态,乖谬,潦倒,不对;n:畸形",
"abnormality":"n:反常,变态,不规则;a:反常",
"abnormally":"d:超常",
"aboard":"p:上,上面,在_上面,在_上",
"abode":"n:住处,住所,寓所,宅邸",
"abolish":"v:消灭,废,废弃,结束,破除",
"abolition":"n:废除,废弃,废止",
"abominable":"a:可恶,可恨,恶劣,秽",
"abominable snowman":"n:雪人",
"abominate":"v:憎恨,嫌恶,厌恶,痛恨,憎恶",
"abomination":"n:憎恶,憎恨,可恶",
"aboriginal":"n:土著居民",
"aboriginals":"n:土著",
"aborigine":"n:土著居民",
"abort":"v:打胎,抑止,堕胎,失败,截止,退化",
"abortion":"n:堕胎,人工流产,失败,小月,打胎,畸形;v:小产,流产",
"abortive":"a:未遂",
"abound":"v:盛产,充满,富于,富有",
"abound in":"v:富于,盛产",
"about":"d:约,左右,差不多,可;p:前后,手头;a:流行,左右,周遭;n:光景,内外",
"above":"p:超过,上面,以上,上,之上;n:上,上头;d:上级,上流,上述,上文,以上;a:前述;f:开外",
"above all":"p:最",
"above and beyond":"p:不止,超过",
"above-mentioned":"a:上述",
"aboveboard":"d:公开,光明磊落;n:正大;a:明",
"abracadabra":"n:咒语,胡言乱语,诅咒",
"abrade":"v:擦伤,磨损,磨耗,磨蚀,研磨,磨擦",
"abraham's bosom":"n:天堂",
"abrasion":"n:磨蚀;v:擦伤",
"abrasive":"n:金刚砂",
"abrasiveness":"n:磨耗",
"abreast":"d:并排,并列",
"abridge":"v:节本,摘要,削,节略,夺,缩写,省略;n:节",
"abridgement":"n:节本,削减,摘要,概略,缩减",
"abroad":"d:海外,到处,流行;a:外;n:国外",
"abrogate":"v:废,废止,结束",
"abrogation":"n:废除;v:终止",
"abrupt":"a:突然,突兀,陡峭,陡,冒失;v:突兀",
"abruptly":"d:突然,猛,忽地,没头没脑,乍,勃然,骤",
"abscess":"n:脓肿",
"abscissa":"n:横轴",
"abscission":"n:脱落;v:脱落",
"abscond":"v:隐匿,卷逃,逃匿,潜伏,失踪,私逃,逃逸",
"absconding":"v:潜伏",
"absence":"n:缺席,无,缺乏,缺少,缺,缺勤,心不在焉",
"absent":"v:缺席;a:无",
"absenteeism":"n:旷工,缺勤,旷课",
"absently":"d:茫然",
"absentminded":"d:恍忽;a:昏头昏脑",
"absolute":"a:绝对",
"absolute majority":"n:绝大多数",
"absolute value":"n:绝对值",
"absolute zero":"n:绝对零度",
"absolutely":"d:绝对,绝,断然,百分之百;a:完全,百分之百;i:当然;v:断",
"absoluteness":"n:绝对,专制,完全",
"absolution":"n:宽恕,解除,免除",
"absolve":"v:免除,宽恕,超生,解脱,出脱,解除",
"absorb":"v:并吞,承担,理解,忍受,吞没,占用,裹,合并,吸吮,吃,吮吸,同化,吞,吞食",
"absorbed":"a:专心致志,专心一志",
"absorbent":"n:淋巴管",
"absorbent cotton":"n:药棉",
"absorber":"n:减震器",
"absorption":"n:热中,合并,专心,专心一意,全神贯注,饮食",
"absorption spectrum":"n:吸收光谱",
"abstain":"v:弃权,避免,忌食,戒除,断,放弃,避开,戒",
"abstemiously":"d:适度",
"abstemiousness":"n:节制",
"abstention":"n:回避,克制",
"abstinence":"n:禁欲,节欲;v:节制",
"abstinency":"n:节制",
"abstract":"v:提炼;n:撮要;a:抽象,理论",
"abstracted":"a:茫然",
"abstractedly":"d:茫然",
"abstractedness":"n:出神,发呆",
"abstraction":"n:抽象,出神,发呆,提取",
"abstractness":"n:抽象性",
"abstruse":"a:深奥,深邃,玄,微,奥,寥",
"absurd":"a:荒唐,荒谬,可笑,荒诞,无稽,怪诞;v:岂有此理",
"absurdities":"n:奇谈怪论",
"absurdity":"n:谬论,荒谬,奇谈怪论,无稽",
"absurdness":"n:讹谬",
"abundance":"n:大量,充足,充裕,富裕,盈余;a:充足",
"abundant":"a:丰富,充分,充裕,充沛,充足,裕,博,赡,富饶,沛,盎然,丰,阜,富足,殷,富;v:横溢,饶,腆,盛",
"abundantly":"d:多",
"abuse":"v:虐待,欺骗;n:陋习",
"abuses":"n:流弊",
"abusively":"d:妄,滥",
"abusiveness":"n:虐待,滥用",
"abut":"v:毗连,接近,对接,毗邻,贴近",
"abutment":"n:接合,支座,接界,桥基,支柱,邻接",
"abuzz":"a:热闹,活跃",
"abysmal":"a:深不可测;v:深不可测",
"abyss":"n:深渊,地狱;a:深渊",
"abyssinia":"n:阿比西尼亚",
"abyssinian":"a:阿比西尼亚",
"ac":"n:交流电",
"acacia":"n:刺槐",
"academe":"n:学术界,研究院",
"academia":"n:学术界",
"academic":"n:学人,大学生;a:学术",
"academic year":"n:学年",
"academical":"a:学院",
"academician":"n:院士",
"academy":"n:学院,学会,研究院",
"accede":"v:加入,同意,继承,答应,参加,允诺,依从",
"accelerate":"v:加速,加快,促进,催促",
"accelerating":"v:加速",
"acceleration":"n:早熟,变速;v:加速",
"accelerator":"n:加速器,油门",
"accelerometer":"n:速度计",
"accent":"n:腔调,音调;v:强调,重读",
"accentuate":"v:强调,重读",
"accentuation":"n:加重,强调,抑扬",
"accept":"v:承认,承担,相信,当,听,采纳,信,答应,受理,领受,留,纳,收纳,容纳,接办,理解,顺应,收容",
"acceptability":"n:合意,适意,接受",
"acceptance":"n:承兑,承诺;v:接受",
"acceptation":"n:意义,承认",
"accepted":"a:公认",
"acceptor":"n:接收器",
"access":"n:存取,访问,门,入口,通路;v:接近",
"accessibility":"n:可亲",
"accession":"n:继承,同意,增加,接近,参加",
"accessories":"n:附属品",
"accessory":"n:从犯;a:从",
"accessory nerve":"n:副神经",
"accidence":"n:初步,岔曲儿",
"accident":"n:意外,偶然,不幸,灾难,差池,长短,高低,岔,闪失,灾害;a:不测,意外;v:突变;c:故",
"accidental":"v:无意,飞;a:附属",
"accidental injury":"n:误伤",
"accidentally":"d:偶然,意外,附带;a:偶然",
"acclaim":"v:喝彩,夸赞,有口皆碑,称誉,叹,称赞;n:喝采",
"acclamation":"n:称赞,叫好,欢呼",
"acclimate":"v:适应",
"acclimation":"n:驯化;v:驯化",
"acclimatization":"n:驯化",
"acclivity":"n:斜坡",
"accolade":"n:表扬,迎接,嘉奖,接吻",
"accommodate":"v:贷,住,迁就,通融,收容,招待,装载,调解,排解,顺应,迎合,供给,便利,留宿",
"accommodating":"a:圆通",
"accommodation":"n:和解,设备,接待,调解,适应,调节,迁就,便利,通融,随波逐流,供给,船位,将就,顺应,排解,贷款,调停;v:调节",
"accommodation ladder":"n:舷梯",
"accompaniment":"n:随着,附属物",
"accompanist":"n:琴师",
"accompany":"v:送,随行,附有,作伴,做伴,伴唱,伴同,衬",
"accomplice":"n:共犯",
"accomplish":"v:达到,就,成,作为,实行,贯彻,做成,办到",
"accomplished fact":"n:既成事实",
"accomplishment":"n:才能,技能,修养,教养,实行,履行;v:执行",
"accord":"n:一致;v:符合,给予,调解;a:和谐",
"accordance":"n:据,协调,给予,风琴,依照",
"accordant":"a:谐和",
"according":"v:照,按,据,依",
"according to":"p:按照,比照,以,根据,据,照着,遵照,依据,照,本着,如,按,基于,依照,本,依",
"accordingly":"d:于是,因此,随着,所以,据此",
"accordion":"n:手风琴",
"accost":"v:搭讪,搭话,招呼,勾引",
"account":"n:账目,账户,叙述,考虑;v:叙述",
"account book":"n:簿籍,帐",
"account for":"n:交代,得分,打死,打落,解释,说明,占,证明",
"accountability":"n:责任制",
"accountancy":"n:会计",
"accountant":"n:帐房,账房,出纳",
"accounting":"n:记账,账",
"accoutrement":"n:装备,衣服",
"accra":"n:阿克拉",
"accredit":"v:委任,派驻,听信,认可,授权,委派,相信",
"accretion":"n:增大,增生,生长,粘连;v:增生,生长",
"accrual":"n:增加,增殖;v:获利,增殖",
"accrue":"v:发生,增长",
"acculturate":"v:社会化",
"accumulate":"v:积蓄,存储,存,攒,汪,委,累,蕴,贮,滚存,储蓄,敛,储存",
"accumulation":"n:堆积,积聚,滚存,累加,蓄电池;v:蓄积,堆积,聚集,积聚",
"accumulator":"n:存储器,缓冲器",
"accuracy":"n:精度,正确,音准,准头",
"accurate":"a:精确,准确,准,精密,灵验,凿,不爽",
"accurately":"d:如实",
"accusation":"n:罪状,责备,辞讼,告发,谴责,非难",
"accuse":"v:指责,指控,控,谴责,攻击,非难,攻,诉,告,弹劾,检举,起诉",
"accuser":"n:原告",
"ace":"n:能手,么,尖子,好手,毫厘,专家",
"acerbate":"v:激怒",
"acerbic":"a:涩,酸性;n:酸性",
"acerbity":"n:苦涩,酸味",
"acetaminophen":"n:扑热息痛",
"acetic":"a:醋",
"acetic acid":"n:乙酸",
"acetone":"n:丙酮",
"acetylene":"n:乙炔,电石气",
"acetylsalicylic acid":"n:阿司匹林",
"ache":"v:疼痛,疼,渴望;a:疼痛,痛;n:痛",
"achene":"n:瘦果",
"achieve":"v:成就,获,获取,致,奏,造,收到",
"achievement":"n:达到,功绩,业绩,成,完成,武功,绩,名堂,造诣,战绩,勋,成果,功",
"achievements":"n:效益,造就,成就",
"aching":"a:痛,酸痛,酸溜溜",
"achromatic colour":"n:无色",
"acid":"a:酸,酸性;n:迷幻药",
"acid rain":"n:酸雨",
"acid rock":"n:酸性岩",
"acid value":"n:酸值",
"acidification":"n:发酸;v:酸化",
"acidify":"v:酸化",
"acidifying":"v:酸化",
"acidity":"n:酸度,酸性,酸味",
"acidosis":"n:酸中毒",
"ack-ack":"n:高射炮",
"acknowledge":"v:感谢,供认,确认,认,拜,公证",
"acknowledgement":"n:谢意,感谢,收条,供认",
"acme":"n:极盛,尖端,成熟期,极点,极度",
"acne":"n:痤疮,粉刺",
"acne rosacea":"n:酒糟鼻,酒渣鼻",
"acolyte":"n:沙弥,助手,侍者,卫星",
"aconite":"n:乌头",
"acorn":"n:橡实",
"acoustic":"n:音质",
"acoustics":"n:音响效果,声学,音响",
"acquaint":"v:认识,了解",
"acquaintance":"n:交,了解,心得,雅,知识;v:了解;c:故",
"acquaintanceship":"n:认识,相识",
"acquainted":"v:相识",
"acquiesce":"v:默认,默许",
"acquiescence":"n:默许,默认",
"acquire":"v:养成,得,获取,添置,招致,养,捕获",
"acquired":"a:后天",
"acquirement":"n:取得,技艺,获得",
"acquiring":"v:瞄准",
"acquisition":"v:搜索,探测,获得;n:探测",
"acquit":"v:履行,开释,付清,还清,出脱",
"acquittal":"n:履行,清偿,开释",
"acquittance":"n:付清,还清,解除",
"acre":"n:土地,大量,耕地,田地",
"acreage":"n:面积",
"acrid":"a:辛辣,刻毒",
"acridity":"n:腐蚀性,刻毒,苦,狠毒;a:辛辣",
"acrimonious":"a:尖刻,尖酸,酸溜溜",
"acrimony":"n:毒辣,苦味,激烈",
"acrobatics":"n:百戏",
"across":"d:交叉,越过,过,阔,穿过,对过,宽,斜对面;p:过,穿过,横,越过,经过;f:过",
"acrylic":"n:晴纶",
"act":"v:做,行事,为,扮演,表演,作,充当,演戏;n:决议",
"act as":"v:做,扮,作,充当,扮演,充,为",
"act of god":"n:不可抗力",
"act on":"v:遵奉,践,遵行,作用",
"act out":"v:演出",
"act up":"v:失灵,耍脾气",
"act upon":"v:照办",
"acting":"n:演出,演戏;a:代理,演出;v:代",
"actinium":"n:锕",
"action":"n:措施,举动,活动,诉讼,作为,情节,战事,效应,姿势,机能,态度,手段,表演,赌博,业;v:动,战斗",
"activate":"v:搞活,创设,起动,开动,触发,激化,建成,成立",
"activated":"a:活性",
"activated carbon":"n:活性碳",
"activating":"v:激发",
"activation":"a:激动;n:活化",
"activator":"n:催化剂",
"active":"a:活跃,积极,活性,活,现行,活泼;v:激活;n:积极分子",
"activeness":"n:活跃",
"activism":"n:能动性",
"activist":"n:积极分子,活动家",
"activity":"n:活性,活跃,功能,活动性,活力,机构,动静,机能,主动性,功率,举动",
"actor":"n:演员,艺人,原告",
"actress":"n:坤角儿",
"actual":"a:现实,活生生",
"actualise":"v:实现",
"actuality":"n:现实,现存,现实性,现状",
"actualization":"n:实现",
"actualize":"v:实现,实行",
"actually":"d:其实,竟然,竟,真,究竟,现在,硬是,竟会,果,如今",
"actuary":"n:记录员",
"actuate":"v:驱动,激励,开动,推动,鼓动,启动",
"actuating":"v:启动",
"actuation":"n:动作,驱使,激励,开动,刺激",
"actuator":"n:调节器",
"acuity":"n:剧烈,尖锐,敏锐",
"acumen":"n:慧眼",
"acupuncture":"n:针,针灸,针刺;v:针刺",
"acute":"a:急性,敏锐,尖锐,灵敏,激烈,剧,尖",
"acuteness":"n:敏锐,锐利,剧烈",
"ad":"n:到,根据,达",
"ad hoc":"a:为此,特设;n:特设",
"ad infinitum":"a:无限",
"ad lib":"n:随意",
"adage":"n:古话,格言,老话,俗话,谚",
"adam":"n:亚当",
"adam's apple":"n:柚,结喉",
"adamant":"v:宁折不弯,牢不可破;n:金刚石;a:坚强不屈",
"adapt":"v:适应,修改,改",
"adaptability":"n:适应性",
"adaptation":"n:改编,改写本,顺应,同化",
"adapter":"n:适配器,连接器,拾音器",
"adaption":"n:适应",
"adaptor":"n:插座",
"add":"v:增加,加入,对,补充,加上,相加,合计,加添,追加,附,加料,累积,续,补发,添设,追补,搭,拢,统计,获得",
"add to":"v:相加,追补,追加,增加,傅",
"add together":"v:相加",
"add up":"v:拢,统计",
"add-in":"n:附件",
"added":"a:额外",
"addend":"n:被加数",
"addendum":"n:附表",
"adder":"n:加法器",
"addict":"v:耽于",
"addiction":"n:上瘾,热中,毒瘾",
"adding":"v:计算",
"addis ababa":"n:亚的斯亚贝巴",
"addition":"n:加,相加,添加,追加,头衔,称号;v:添加",
"additional":"v:补充,附加;a:额外",
"additionally":"d:又,加之",
"additive":"v:附加;n:添加物",
"address":"v:讲话;n:献殷勤,致辞",
"addressee":"n:收件人",
"addressing":"v:访问",
"adduce":"v:提出,举出,引证,提供,引用",
"ade":"n:果汁",
"aden":"n:亚丁",
"adept":"n:熟手,内行,名手;a:拿手",
"adequacy":"n:恰当,合适,适当",
"adequate":"a:充足,够,恰当",
"adhere":"v:坚持,粘住,粘,粘连,粘着,粘附,遵循,附着,依附,粘合,追随,附",
"adherence":"n:坚持,粘附,固执,粘着;v:附着",
"adherent":"n:追随者,党羽,门徒,门下",
"adherents":"n:徒子徒孙,党羽",
"adhering":"v:附着",
"adhesion":"n:粘着,粘附,粘连,同意,追随,附着,加入,胶着,信奉;v:粘着,附着,粘合",
"adhesive":"a:粘;n:粘合剂",
"adhesive plaster":"n:膏药,橡皮膏,膏子",
"adhesive tape":"n:胶带",
"adhesiveness":"n:粘性",
"adieu":"n:辞别,再见;i:再会,一路平安",
"adios":"i:再见",
"adjacency":"n:邻接,接近,毗邻",
"adjacent":"a:邻;v:相邻",
"adjective":"n:形容词",
"adjoin":"v:接壤,毗邻,依附,附上,邻,毗,相邻,粘连,加上",
"adjoining":"a:隔壁,相邻,邻",
"adjourn":"v:休庭,散会,闭会,停止,休",
"adjournment":"n:延期,散会,闭会",
"adjudge":"v:判定,裁定,认为,断定",
"adjudicate":"v:评判,裁定,裁断",
"adjudication":"v:裁决,裁定;n:判决",
"adjunct":"n:附加语,助手,附属物,修饰语,副手",
"adjuration":"n:恳请",
"adjure":"v:恳求,恳请",
"adjust":"v:适应,整,对,整理,评定,排解,调解,调,核算,校准,整肃,符合,整顿,矫正,顺应,调停",
"adjustable":"a:伸缩;v:伸缩",
"adjuster":"n:调节器",
"adjusting":"v:调整,校准",
"adjustment":"v:调解,调节,调整,校正;n:清算,校正",
"adjutant":"n:副官",
"administer":"v:实施,有助于,职,艾,支配,辅助,辖,处理,代办,供给,下药,知,统制,厘,听,治,承办,管,施行",
"administrate":"v:管理,支配",
"administration":"n:管理,经营,市政,政,掌管,施政,施行,局;v:管理",
"administrator":"n:管理员,理事",
"admirable":"a:可贵",
"admiral":"n:将军,上将",
"admiralty":"n:制海权",
"admiralty mile":"n:海里",
"admiration":"n:羡慕,赞叹,佩服,美谈",
"admire":"v:称赞,赞赏,崇拜,敬仰,夸奖,佩,叹赏,慕,赏,仰,褒奖,嘉,惊异,倾心,想望,景,思慕;a:艳",
"admirer":"n:情人",
"admissibility":"n:准许",
"admission":"n:承认,入场费,接纳,坦白,招认,首肯",
"admit":"v:承认,进入,录取,容许,认,接待,通向,吸收,收容,发展,接收;n:认罪",
"admittance":"n:导纳,通道",
"admittedly":"d:固然,固;c:固然",
"admix":"v:掺和",
"admixture":"n:混合物,合剂,搀合",
"admonish":"v:劝告,规劝,训诫,诫,警告,忠告,规谏,规,戒,告戒",
"admonition":"n:训诫,忠告,警告",
"ado":"n:纷扰,骚扰,费力",
"adobe":"n:砖坯,土坯,坯",
"adolescence":"n:青春期,青春",
"adolescent":"n:青少年,少年,少女",
"adolf hitler":"n:希特勒",
"adonis":"n:美男子",
"adopt":"v:通过,认,沿用,领,接纳,取,借用,过继,选定,采,抱养,承袭,立",
"adopted":"v:寄",
"adoption":"n:采纳,过继,接受,指定,继嗣,借用",
"adoptive":"a:养,义;v:养",
"adorably":"d:崇拜",
"adoration":"n:敬慕,爱慕,礼拜,敬爱,崇敬",
"adore":"v:崇敬,慕",
"adorn":"v:点缀,饰,打扮,佩戴,装,妆饰,装点",
"adornment":"n:装饰,妆饰",
"adrenal":"n:肾上腺",
"adrenal gland":"n:肾上腺",
"adrenalin":"n:肾上腺素",
"adrenaline":"n:肾上腺素,肾上腺",
"adriatic":"n:亚得里亚海",
"adriatic sea":"n:亚得里亚海",
"adrift":"d:飘零,漂浮;v:飘零",
"adsorb":"v:吸附",
"adsorbent":"n:吸附剂",
"adsorption":"n:吸附;v:吸附",
"adulate":"v:奉承",
"adult":"n:人,大;v:成年",
"adulterate":"v:掺,兑,以假乱真,掺杂",
"adulteration":"n:搀杂,掺假,伪造,掺杂,冒牌货",
"adulterer":"n:奸夫,姘夫",
"adulteress":"n:奸妇",
"adulterous":"a:私通",
"adultery":"n:私通,奸情;v:通奸",
"adulthood":"n:成年,成年期",
"adumbrate":"v:遮蔽,勾画,轻描淡写,暗示,预示",
"adumbration":"n:勾画,轮廓,草图,阴影,轻描淡写,预示",
"advance":"v:进步;n:晋升,向上,预付,增进,腾贵;d:事先,预先;c:进步;a:将",
"advanced":"a:高深,发达",
"advancement":"n:促进,进步,发达,预付,进展,升级",
"advancing":"v:超前",
"advantage":"n:有利,利,长处,上风,优胜;v:有助于,有利于",
"advantageous":"a:有利;v:占便宜",
"advent":"n:到来,来临;v:到来",
"adventitious root":"n:不定根",
"adventure":"n:奇遇,投机;v:冒险,碰运气",
"adventurer":"n:冒险家",
"adventurism":"n:冒险主义",
"adverb":"n:副词",
"adverbial":"a:副词",
"adversary":"n:对头",
"adverse":"a:相反",
"adversely":"d:不利,逆,不幸",
"adversity":"n:逆境,不幸,患难,厄运,难,灾,苦难,厄",
"advert":"v:注意,留意,提到",
"advertise":"v:通告,通知,征聘,鼓吹,标榜",
"advertisement":"n:告示,公告",
"advertising":"n:广告业",
"advice":"n:意见,指教,通知,报告",
"advices":"n:报道",
"advisability":"n:得当,适当,明智",
"advisable":"a:可取",
"advise":"v:忠告,商量,劝说,嘱,告诫,劝导,开导,规劝,训诫,规,开解,通告",
"advisement":"n:考虑,忠告,劝告,意见",
"adviser":"n:参谋,导师,参事",
"advisory":"a:顾问团;n:报告",
"advocacy":"n:鼓吹,主张,辩护",
"advocate":"v:拥护;n:主",
"adz":"n:锛子",
"aegean":"n:爱琴海,爱琴",
"aegean sea":"n:爱琴海",
"aegis":"n:赞助,主办,庇护,掩护",
"aeolus":"n:风神",
"aerate":"v:充气,吹风,通气",
"aeration":"n:通气,充气,吹风,换气;v:换气",
"aerial":"a:空中,空气",
"aerial ladder":"n:云梯,天梯",
"aerialist":"n:马戏团",
"aerie":"n:巢,孩子",
"aerobics":"n:健美操",
"aerodrome":"n:机场,飞机场",
"aerodynamic force":"n:气动力",
"aerofoil":"n:机翼,翼型",
"aerogram":"n:无线电报",
"aerogramme":"n:无线电报",
"aeronautics":"n:航空学",
"aeroplane":"n:机",
"aerospace":"n:航天,航空",
"aesthetic":"a:美学",
"aestheticism":"n:美感",
"aesthetics":"n:美学",
"aether":"n:太空,苍天",
"aetiology":"n:病因",
"af":"n:视频",
"afar":"d:远,遥远",
"affability":"n:和蔼,温柔",
"affable":"a:和蔼可亲,和蔼",
"affair":"n:事,事件,事态,事儿,东西,艳遇,务,物品",
"affairs":"n:事务,是;v:是",
"affect":"v:作用,关系,好,作,牵动,冒充,作态;n:感情,情感",
"affectation":"n:矫揉造作,装模作样,假装,做作",
"affected":"v:做作,酸文假醋;a:矫揉造作",
"affection":"n:爱,爱情,爱慕,情感,喜爱,慈爱,好感,作用,情思,性情,爱心;v:爱慕",
"affectionate":"a:爱,多情,亲热,恩爱,绸缪,蜜里调油,温存;v:钟情",
"affectionately":"d:亲爱的,脉脉",
"afferent":"a:向心",
"afferent nerve":"n:传入神经",
"affiance":"n:信托,婚约,信用,誓约;v:订婚",
"affidavit":"n:结",
"affiliate":"v:加入,参加,联合;n:分会,会员",
"affiliated":"v:附属",
"affiliation":"n:入会,加入,溯源",
"affinity":"n:近似,吸引力,类似",
"affirm":"v:肯定,断言,确认,证明,维持,证实,认定,批准",
"affirmation":"n:肯定,断言,证实,批准,确认",
"affirmative":"n:肯定;a:肯定",
"affirmatively":"d:断然",
"affix":"v:盖,附上,粘贴;n:附件",
"afflatus":"v:吸气;n:灵感",
"afflict":"v:苦恼",
"affliction":"n:不幸,折磨,忧伤,困苦,哀伤;v:折磨",
"affluence":"n:丰富,富足,汇集,流入,富饶",
"affluent":"a:富足",
"afford":"v:提供,生产,供给,给与,产",
"afforest":"v:绿化,造林,植树",
"afforestation":"n:造林,绿化",
"affray":"n:斗殴,打架,纷争;v:吓唬",
"affront":"v:冲犯,侮辱",
"afghanistan":"n:阿富汗",
"aficionado":"n:迷",
"afield":"d:远离,迷路,离乡背井",
"afire":"d:燃烧",
"aflame":"d:发亮",
"afloat":"d:流通,传播,流行,散播",
"aflutter":"d:鼓动,飘扬,激动;a:飘扬",
"afoot":"d:徒步,步行",
"aforementioned":"a:上述,该,前述",
"aforesaid":"a:该,上述;n:上面",
"aforethought":"a:预谋",
"afraid":"a:恐怕,害怕,担心,畏惧,畏葸,怔,担忧,寒,寒心,凛",
"afresh":"d:另外",
"africa":"n:非洲,非",
"african elephant":"n:象",
"after":"p:经过,经,后,以后,追求,像,接,因为,寻找,低于,相继,模仿;d:随后,后来;n:后;c:之后;a:后",
"after a fashion":"p:勉强,稍许",
"after all":"p:究,总,归根到底,究竟,终久,终,总归,端的",
"after-hours":"a:业余",
"afterbirth":"n:胞衣,衣,胞,胎衣,衣胞",
"aftereffect":"n:后效,后劲,副作用",
"afterglow":"n:晚霞,余辉",
"afterimage":"n:遗像,余味,余音",
"afterlife":"n:晚年,后半辈子,后世,来世",
"aftermath":"n:结果,余波,后果",
"afternoon":"n:午后,过晌",
"aftershock":"n:余震",
"aftertaste":"n:余味,回味,余韵",
"afterward":"d:后来,以后",
"afterwards":"d:然后,已,继而;n:后,以后,之后;p:继",
"again":"d:又,再次,重,再度,但,而且,另外,此外,复,加之",
"against":"p:对,反对,靠,违反,以防,违背,倚,逆,碰,犯,防,对照,相反,触,敌对,御,靠近;v:抢",
"against the wind":"p:打头风,迎风,逆风",
"agape":"d:目瞪口呆",
"agar":"n:琼脂,石花胶,洋菜,石花菜,洋粉",
"agar-agar":"n:石花胶,琼脂",
"agate":"n:玛瑙,石子",
"agave":"n:龙舌草",
"age":"n:年,时期,老年,年事,晚年;v:上年纪,苍老",
"age limit":"n:年限",
"age-old":"a:悠久",
"aged":"a:年迈,年老,苍老,老迈",
"ageing":"v:老化;n:老化",
"ageless":"a:长生不老",
"agency":"n:机构,代办处,作用,力量,媒介,机关,行为,局,代办,厅,经办,动力,办事处",
"agenda":"n:议程,议事日程",
"agent":"n:间谍,特务,代理,密探,介质,原因,内奸,中间商,药剂,坐探,施事,行商,总管",
"ageratum":"n:藿香",
"agglomerate":"v:结块,烧结",
"agglomeration":"n:凝聚,结块",
"agglutinate":"v:凝集,凝聚,接合,烧结,胶合",
"agglutination":"n:愈合,粘结,胶合;v:粘着",
"aggrandize":"v:扩大,加大,夸大,提高,扩张,夸张",
"aggrandizement":"n:增大",
"aggravate":"v:惹恼,加剧",
"aggravation":"n:加重,激怒,惹恼,恶化;v:加重",
"aggregate":"n:骨料,集合,聚集,总量,总汇,合计;v:总计;a:总",
"aggregation":"n:聚集,聚合;v:聚合,聚集",
"aggression":"n:侵犯,攻击",
"aggressive":"a:侵略,咄咄逼人,嚣张",
"aggressor":"n:侵略者,侵略国",
"aggrieve":"v:侵害",
"aggrieved":"a:悲伤",
"agile":"a:灵活,灵敏,利落,利索,麻利,矫捷,活便,灵便",
"agility":"n:敏捷,机敏",
"aging":"n:时效",
"agitate":"v:激动,摇动,搅拌,煽惑,腾,思考,搅乱;a:激动",
"agitated":"n:回肠;a:惶;v:心神不定",
"agitatedly":"d:动摇",
"agitation":"n:激动,骚动,煽动,搅动,兴奋,焦虑,议论,搅拌,心神不定;v:抖动,搅拌;a:激动",
"agitator":"n:鼓吹者",
"aglow":"a:发亮;d:兴奋",
"agnosticism":"n:不可知论",
"ago":"d:前,以前;a:前,之前;n:之前",
"agog":"d:渴望",
"agonize":"v:苦闷,挣扎",
"agonized":"a:苦涩",
"agonizing":"a:惨痛,揪心",
"agony":"n:挣扎,罪,烦闷;a:痛苦",
"agree":"v:同意,一致,对,承认,答应,赞成,接受,赞同,相符,适合,约定,不符,合适,符合,说定,不合,附,契,投合,议定,入,承应,订,契合,订约,肯,投,应许",
"agreeable":"a:适意,投机,中意,投缘,适口,投契,润泽",
"agreeableness":"n:愉快,一致,适合,适意",
"agreeably":"d:欣然,依照,应,一致,一样,依",
"agreed":"a:一致;v:议定",
"agreement":"n:同意,合同,合约,默契,投合,呼应,约;v:同意",
"agricultural laborer":"n:农业工人",
"agriculture":"n:农艺,本业",
"agronomics":"n:农学",
"agronomist":"n:农学家,农艺师",
"agronomy":"n:农艺,农学,农艺学",
"aground":"v:触礁,搁浅;d:触礁",
"ague":"n:打冷颤,发冷",
"ahead":"d:提前,领先,赢得,在先;n:头里;a:先头",
"ahriman":"n:鬼",
"ahura mazda":"n:创世主",
"ai":"n:艾",
"aid":"v:协助,接济,支援,相助,援,相帮,援外;n:助手;a:周全",
"aid station":"n:急救站",
"aide":"n:助手,助理,幕宾",
"aide-de-camp":"n:副官,幕僚",
"aids":"n:艾滋病,爱滋病",
"ail":"v:生病",
"aileron":"n:副翼",
"ailment":"n:疾病,病痛",
"aim":"v:取,照准,指望;n:靶子,志向",
"aiming":"n:照准;v:对准",
"aimlessly":"a:等闲;d:瞎",
"air":"n:空中,飞机,气,神气,天空,空,风度,微风,态度,传播;v:晾晒,宣扬,发挥",
"air attack":"n:空袭",
"air bladder":"n:气泡",
"air castle":"n:妄想,空中楼阁",
"air cell":"n:气囊",
"air compressor":"n:风泵",
"air conditioner":"n:空调器",
"air conditioning":"n:冷气;v:冷气",
"air defense":"n:防空",
"air force":"n:空军",
"air gun":"n:鸟枪",
"air hammer":"n:风锤",
"air hole":"n:气孔,气门",
"air hostess":"n:空中小姐",
"air lock":"n:气闸",
"air marshal":"n:中将",
"air mattress":"n:气垫",
"air out":"n:出气;v:出气",
"air power":"n:制空权",
"air pressure":"n:风压",
"air pump":"n:抽气机,风泵",
"air raid":"n:空袭",
"air rifle":"n:气枪",
"air space":"n:空域,领空",
"air transport":"n:空运",
"air-condition":"v:空调",
"air-drop":"n:空投;v:空投",
"air-dry":"v:风干",
"airborne":"a:空降,机载",
"airbrush":"n:喷枪",
"airbus":"n:空中客车",
"aircraft":"n:机,飞艇,航空器",
"aircrew":"n:机组",
"airdrome":"n:机场,飞机场",
"airdrop":"v:空投,伞降;n:空投",
"airfield":"n:飞机场",
"airflow":"n:气流",
"airfoil":"n:机翼",
"airframe":"n:机体,机架,构架,机身",
"airfreight":"v:空运",
"airgun":"n:气枪",
"airiness":"n:快活,空虚,轻快",
"airing":"n:表态,广播,晒;v:晾干",
"airlift":"v:空运",
"airline":"n:直路,近路,航线",
"airliner":"n:客机,班机",
"airman":"n:飞行员,航空兵",
"airmen":"n:飞行员",
"airplane":"n:飞机,机,铁鸟",
"airplane pilot":"n:飞行员",
"airplane ticket":"n:飞机票",
"airport":"n:空港,航空港",
"airs":"n:气,架子",
"airship":"n:飞艇,飞船,气艇",
"airsick":"a:晕机",
"airsickness":"n:晕机",
"airspace":"n:领空",
"airstream":"n:气流",
"airtight":"a:闷",
"airway":"n:航线",
"aisle":"n:过道,走道",
"akimbo":"a:叉腰",
"akin":"a:类似,同族,近似",
"ala":"n:翅,翼",
"alack":"i:乌呼,呜呼;n:呜呼哀哉",
"alacrity":"n:乐意,踊跃",
"alamo":"n:杨树",
"alarm":"n:警报器,警铃,惊慌,恐慌,报警器;v:惊,吓,警告,警戒,震惊",
"alarmed":"a:惊慌,惊惶,惶惶",
"alarming":"a:惊人",
"alas":"i:哎呀,呜呼哀哉,乌呼,呜呼",
"alaska":"n:阿拉斯加",
"alb":"n:僧袍",
"albania":"n:阿尔巴尼亚",
"albanian":"a:阿尔巴尼亚",
"albatross":"n:信天翁,障碍物",
"albedo":"n:反射率",
"albeit":"c:尽管,纵令",
"albinism":"n:白化病",
"albino":"n:天老儿",
"album":"n:相册,影集,文集",
"albumen":"n:蛋清,卵白",
"albumin":"n:生化",
"alchemist":"n:方士",
"alchemy":"n:炼丹术,魔力",
"alcohol":"n:酒精,醇,乙醇",
"alcoholic":"a:酒精",
"alcoholic drink":"n:酒",
"alcoholism":"n:酗酒",
"alcove":"n:壁橱,凉亭",
"aldehyde":"n:醛,乙醛",
"alder":"n:桤",
"alehouse":"n:酒馆",
"alembic":"n:蒸馏器,蒸馏罐",
"alert":"a:机警,警惕;n:警戒;v:警悟,眼明手快",
"alertness":"n:戒心;v:警觉",
"alexander":"n:亚历山大",
"alexandria":"n:亚历山大",
"alfalfa":"n:苜蓿,紫花苜蓿",
"alga":"n:藻类",
"algae":"n:海藻",
"algebra":"n:代数,代数学",
"algeria":"n:阿尔及利亚",
"algiers":"n:阿尔及尔",
"algorithm":"n:算法",
"alias":"v:混淆,折叠;n:假名;d:别名",
"alibi":"n:托辞,辩解",
"alien":"n:外国人,外人,外来人,外族;v:离间;a:不合",
"alienate":"v:疏远,离间,挑拨,调",
"alienation":"n:转让;v:异化",
"alight":"v:下车;a:照亮",
"align":"v:排列,匹配,对齐,校准,参加,联合",
"aligning":"v:对准,矫正",
"alignment":"n:调整,结盟,阵线;v:对准,调整",
"alike":"a:相似,一样;d:相似,相等,一律",
"aliment":"n:抚养,养料;v:抚养",
"alimentary":"a:食物",
"alimentary canal":"n:消化道,消化管",
"alimentary tract":"n:消化道",
"alimony":"n:抚养费",
"aline":"v:校准,对齐",
"alive":"a:活,活活,活泼,有声有色,盎然",
"alizarin red":"n:茜",
"alkali":"n:硷",
"alkaline":"a:碱;n:碱性",
"alkaline-earth metal":"n:碱土金属",
"alkalinity":"n:碱度,碱性",
"alkalize":"v:碱化",
"alkaloid":"n:生物碱",
"all":"d:完全;n:万物,周;a:总,凡是,整;r:一切,所有;v:是,举",
"all along":"p:向,一贯,从来,迄,一向,沿着,素来,顺着",
"all at once":"n:忽然,立时,突然,骤然,陡然,一下",
"all day long":"d:一天到晚,成天,整日,镇日,成日",
"all fours":"n:四肢",
"all in":"p:总计",
"all in all":"d:总而言之,归根结蒂,总之,综上所述",
"all over":"p:到处,全身,四处,遍,遍及,完全,周,完了,浑,历,完结",
"all right":"a:好,中,着,成,行",
"all the same":"n:照样,反正,还是",
"all the time":"n:成天",
"all the way":"n:远远,一直",
"all through":"p:一直,始终,遍及,贯穿,历",
"all together":"d:统括,一起",
"all told":"n:合共,拢共,合计,总共,一总,拢总",
"all up with":"p:终了,结束",
"all-around":"a:通盘",
"all-embracing":"a:包罗万象",
"all-inclusive":"a:包罗万象",
"all-round":"a:全能",
"all-rounder":"n:多面手,全才",
"all-weather":"a:全天候",
"allah":"n:真主,安拉,主",
"allay":"v:减轻,消,解,压,止",
"allegation":"n:声称,辩解,主张,陈述",
"allege":"v:声称,申述,陈述,申说",
"allegedly":"d:据称,据说",
"allegiance":"n:效忠,归顺,忠心",
"allegorical":"a:讽喻",
"allegory":"n:象征,讽喻",
"allegretto":"n:快板",
"allegro":"n:快板儿",
"allergen":"n:过敏原,变应原",
"allergic":"a:过敏",
"allergic reaction":"n:变态反应",
"allergy":"n:反感,憎恶",
"alleviate":"v:减除",
"alleviation":"n:缓和",
"alley":"n:小街,里巷,巷道",
"alley cat":"n:野猫",
"alleyway":"n:胡同,小巷,弄堂,通道",
"alliance":"n:结盟,近似,共同点,同盟条约;v:联合",
"allies":"n:同盟国,盟军,协约国",
"alligator":"n:鳄鱼,鳄",
"alliteration":"n:双声",
"allocate":"v:分配,拨,指定,部署,调拨,拨付,分派,配备,划拨,调,支配,配置",
"allocation":"n:配置,部署;v:分配",
"allot":"v:调拨,分,划拨,调,发给",
"allotment":"n:股份,配置,天命,分派,份额,命运",
"allover":"a:印花布",
"allow":"v:让,给,容许,体谅,由,准,容,任凭,许,供给,听,允,兴,原谅,沉溺,批准,应允,应许",
"allowable":"a:允许",
"allowance":"n:补贴,补助,补助金,间隙,贴,斟酌,空隙,默许,承认,定量;v:补助,许可",
"alloy":"n:合金,成色;v:搀,减损",
"allude":"v:暗示,提到",
"allure":"v:诱惑,吸引;n:诱惑力",
"allurement":"n:引诱,诱惑力,诱惑",
"alluring":"v:引人入胜",
"allusion":"n:典故,暗示,提及,典",
"alluvial fan":"n:冲积扇",
"alluvial flat":"n:河漫滩",
"alluvial plain":"n:冲积平原",
"ally":"n:盟国;v:结合",
"alma mater":"n:校歌",
"almanac":"n:历,皇历",
"almighty":"v:无所不能;d:非常;a:全能",
"almond":"n:扁桃腺",
"almond tree":"n:扁桃",
"almost":"d:差不多,近乎,差点儿,差点,大部分,快要,几,将近;v:垂;a:差不多",
"alms":"n:施舍,救济品,救济费",
"almshouse":"n:救济院",
"aloft":"p:高处,在_高处",
"alone":"d:单独;a:唯独,孤单;v:唯有,单枪匹马,惟有",
"along":"d:一道,向前,过去,一并,沿,一块儿;p:沿着,沿,顺着,缘;a:齐;c:边",
"along with":"p:随同_一起,随,随着,偕同,连同_一起,同_一起,一起",
"alongside":"p:靠着,傍着;d:一道",
"aloof":"a:超然,清高,孤高,落落寡合;d:隔开,避开;v:远离",
"aloofness":"n:冷淡,超然",
"alopecia areata":"n:鬼剃头",
"aloud":"d:大声,响亮",
"alp":"n:高峰",
"alpha":"n:主星,最初",
"alpha decay":"n:衰变",
"alpha particle":"n:甲种粒子",
"alpha ray":"n:甲种射线",
"alphabet":"n:初步",
"alphabetic writing":"n:拼音文字",
"alpine":"a:高山",
"alps":"n:阿尔卑斯",
"already":"d:已,就,早已,都,既,业",
"alright":"d:也罢,也好",
"alsace":"n:阿尔萨斯",
"also":"d:而且,同样;a:一;c:并且",
"altair":"n:牵牛,牛郎星,牵牛星",
"altar":"n:坛,祭台",
"alter":"v:修改,改动,动,改换,更改,更换,变革,窜,校改,改建,移,移易",
"alter ego":"n:知己",
"alteration":"v:变更,更改,变动;n:蚀变,变更",
"altercate":"v:吵嘴,口角,争辩,争论",
"altercation":"n:争吵,口角,吵嘴",
"alternate":"v:交错,替补;n:代理人;a:副",
"alternately":"d:交替,交互,花花搭搭;a:更番;v:更番",
"alternating":"v:交流",
"alternating current":"n:交流电",
"alternation":"n:更迭,变换,交替;v:更迭,变换",
"alternative":"n:交替;v:选择",
"alternator":"n:发电机,振荡器",
"although":"c:尽管,虽,虽说,纵然,虽则",
"altimeter":"n:高度计",
"altitude":"n:高,海拔,高等,高程;a:高",
"alto":"n:中提琴,女低音,中音",
"altogether":"d:全部,全然,总之,一起,共,全,拢共,干脆,压根儿,一股脑儿,凡,拢总,总而言之;v:共计",
"alum":"n:明矾,校友",
"alumina":"n:铝土",
"aluminium hydroxide":"n:氢氧化铝",
"aluminum":"n:铝,钢精",
"aluminum foil":"n:铝箔",
"alumna":"n:矾土",
"alums":"n:明矾",
"always":"d:总,老,经常,始终,随时,向,历来,时刻,时时,每每;a:百;n:平生",
"amalgam":"n:混合物",
"amalgamate":"v:混合",
"amalgamation":"n:混",
"amanuensis":"n:秘书",
"amass":"v:积聚,集中,积,聚集,集合,收集",
"amateur":"n:爱好者;a:业余",
"amaze":"v:震惊",
"amazed":"a:惊讶;v:惊异",
"amazement":"n:诧异",
"amazing":"a:惊人,了不起",
"amazingly":"d:非常",
"amazon":"n:蜂鸟",
"ambassador":"n:代表,使节,专使",
"ambassadorship":"n:大使",
"amber":"n:琥珀",
"ambergris":"n:龙涎香",
"ambiance":"n:环境,气氛",
"ambient":"a:环境",
"ambiguity":"n:含糊,二重性,含胡",
"ambiguous":"a:含糊,含混不清,含含糊糊,模棱,笼统,依违两可;n:灰色;v:含糊其词",
"ambit":"n:界限,周围,范围",
"ambition":"n:雄心,奢望,志,精力,心气,心胸",
"ambitious":"a:远大",
"ambivalent":"n:阴阳人;a:阴阳人",
"amble":"n:漫步;v:缓步",
"ambulance":"n:救护车",
"ambulate":"v:走动,步行",
"ambulation":"n:移动",
"ambulatory":"n:走廊,回廊",
"ambuscade":"n:伏兵,伏击战,伏击;v:打埋伏",
"ambush":"v:埋设,打埋伏;n:埋伏",
"ameliorate":"v:改进",
"amelioration":"n:改善",
"amen":"v:核准,完成;n:认可;i:阿门",
"amend":"v:修改,改善,更正,改良,改动,改过,订正,改变,改进",
"amendment":"n:修正,修改,改正,改进;v:修正,校正",
"amends":"n:补偿,赔偿,恢复,道歉,复原",
"amenity":"n:舒适,温厚,规例,举止,快感,乐事,优雅,礼仪,适意",
"amerce":"v:惩罚,罚款",
"amercement":"n:罚金",
"america":"n:美国,美洲,美",
"american football":"n:橄榄球",
"american ginseng":"n:西洋参",
"american indian":"n:印第安人",
"americium":"n:镅",
"amethyst":"n:紫水晶,紫色,紫石英",
"amiability":"n:和蔼,亲切,和气,温和",
"amiable":"a:和蔼可亲,和蔼,随和,可亲,蔼,慈祥,和顺,平易,易,和气,和悦,慈和",
"amicability":"n:和睦,温和,亲善,友善,友好",
"amicable":"a:友好,友善",
"amid":"p:中,在_中,之中,在_之中",
"amidships":"d:当中",
"amidst":"p:在_之中,在_中,中,之中",
"amigo":"n:朋友",
"amine":"n:胺",
"amino":"a:氨基",
"amiss":"d:错;a:不是味儿",
"amity":"n:和睦,友好,和好;a:和睦",
"amman":"n:安曼",
"ammeter":"n:电流表,安培计",
"ammo":"n:军火,弹药",
"ammonia":"n:氨水",
"ammonium":"n:铵",
"ammonium chloride":"n:氯化铵",
"ammonium hydroxide":"n:氢氧化铵",
"ammonium nitrate":"n:硝酸铵",
"ammunition":"n:子弹,火",
"amnesia":"n:健忘",
"amnesiac":"a:善忘",
"amnesty":"v:赦免,大赦;n:特赦",
"amnion":"n:羊膜",
"amoeba":"n:变形虫,阿米巴",
"amoebic dysentery":"n:阿米巴痢疾",
"amok":"n:杀人狂;a:杀人狂",
"among":"p:中,中间,之中,间,在_中间;n:之间,其间;r:其中",
"amongst":"p:在_之中,之中,中间,在_中间",
"amontillado":"n:白葡萄酒,雪利酒",
"amorous":"a:脉脉含情,艳,爱情,风流",
"amorously":"d:脉,脉脉",
"amorousness":"n:好色",
"amortize":"v:缓冲",
"amount":"n:多少;v:总计,共计,成为",
"amour":"n:恋爱",
"ampere":"n:安",
"amphibian":"n:两栖动物",
"amphibious":"a:两栖",
"amphibious operation":"n:登陆战",
"ample":"a:充足,足,丰富,充分,充裕,褒,宽裕,优,庞大,余裕;v:充,绰,足够;n:余裕",
"amplification":"n:放大,扩充;v:放大",
"amplifier":"n:扩音器,放大镜",
"amplify":"v:夸大,增强,发挥,展开,衍,扩张",
"amplitude":"n:振幅,幅度,调幅,广度,广阔,丰富",
"amplitude modulation":"n:调幅",
"amputate":"v:切除,切断,截",
"amputation":"n:截肢",
"amsterdam":"n:阿姆斯特丹",
"amulet":"n:符咒,护符",
"amuse":"v:逗乐,逗笑,娱乐,逗,逗趣,逗闷子,逗笑儿,娱",
"amusement":"n:乐趣,娱",
"amusement park":"n:乐园,游乐园",
"amusing":"a:逗人;v:逗笑儿",
"amylase":"n:淀粉酶",
"an":"a:一",
"ana":"n:语录,回忆录;d:各",
"anaemia":"n:贫血,血亏",
"anaesthesia":"n:麻木,麻;a:麻木;v:麻醉",
"anaesthetic":"n:麻药,麻醉品",
"analects":"n:语录",
"analgesia":"n:镇痛",
"analgesic":"n:止痛药",
"analog":"a:模拟;v:模拟",
"analogize":"v:譬喻,类推,推论",
"analogous":"a:类似,同类",
"analogue":"a:相似",
"analogy":"n:相似,比喻,比方,类比,模拟,类推,比拟;v:模拟,类推",
"analyse":"v:分解,剖,解析,剖析,剖解",
"analyses":"v:分析;n:分析",
"analysis":"v:分析,检验,解析,化验;n:演绎法,梗概,要略",
"analyst":"n:化验员",
"analytic geometry":"n:解析几何",
"analytical":"a:分析",
"analytical geometry":"n:解析几何",
"analyze":"v:分析,分解,破解,剖解,剖析",
"analyzer":"n:分析器",
"analyzing":"v:解析",
"anamorphic":"a:渐变",
"anarchic":"a:无政府",
"anarchism":"n:无政府主义,无政府",
"anarchy":"n:无政府,混乱",
"anathema":"n:诅咒,咒",
"anatomise":"v:解剖",
"anatomize":"v:分析,解析",
"anatomy":"n:分解,组织,分析;v:解剖",
"ancestor":"n:祖先,祖宗,祖上,先,老祖宗,祖辈,祖,先祖,宗,祖本;d:先",
"ancestors":"n:先世,上辈,上代,先辈,祖辈,上辈子,前人,祖先",
"ancestral":"a:祖先",
"ancestry":"n:世系,世家,血统,祖辈,系谱,祖宗,谱系,家世",
"anchor":"n:支架,铁锚,衔铁,湾,桩;v:固定,锚泊,停",
"anchorage":"n:停泊,抛锚,锚泊",
"anchoring":"v:锚泊",
"anchovy":"n:海蜒",
"ancient":"a:古代,古老,古;n:古代,神;c:故",
"anciently":"d:从前,古时候",
"ancientness":"n:古代,旧",
"ancillary":"n:零件,配件,助手,随从;a:副",
"and":"c:和,而,以,并,及,却,同,然后,因此,接着,兼,载",
"and so":"c:故,所以",
"and so forth":"d:等等,等,诸如此类,不一而足,什么的",
"and so on":"d:的,等等,等,什么的,云云,以此类推,不一而足",
"and then":"n:然后,聿,进而",
"andersen":"n:安徒生",
"andorra":"n:安道尔",
"androgyny":"n:雌雄同体",
"android":"n:机器人",
"anecdote":"n:趣闻,奇闻,秘史",
"anecdotes":"n:掌故",
"anemia":"n:贫血,血亏",
"anemometer":"n:风速计,风速表",
"anemone":"n:海葵",
"anent":"p:关于,论及",
"anesthesia":"n:麻醉",
"anesthetic":"n:麻醉剂,麻药",
"anesthetist":"n:麻醉师",
"anesthetization":"n:麻醉",
"anesthetize":"v:麻醉",
"anew":"d:从头,再,从新,另",
"angel":"n:天使,安琪儿,守护神,神仙",
"angel shark":"n:扁鲨",
"angelfish":"n:扁鲨",
"angelica":"n:白芷,当归",
"anger":"n:愤怒,怒火,火,火气,忿怒;v:发炎,恼火,触怒;a:愤怒",
"angina":"v:绞痛;n:心绞痛",
"angina pectoris":"n:狭心症",
"angiosperm":"n:被子植物",
"angle":"n:观点,方面,钓钩,见地,角落,棱,歪曲,诡计,偏见;v:图谋,贪图",
"angle iron":"n:角钢,三角铁",
"angle of reflection":"n:反射角",
"angling":"n:钓鱼",
"angola":"n:安哥拉",
"angrily":"d:怒冲冲,忿怒,怒",
"angry":"a:生气,气愤,恼怒,愤,忿,怒,气呼呼,怒冲冲,气冲冲,恼",
"angst":"n:苦恼,担心",
"angstrom":"n:埃",
"anguish":"n:苦恼,苦闷;v:苦恼;a:痛",
"anguished":"a:苦涩",
"angular acceleration":"n:角加速度",
"angularity":"n:生硬,棱角",
"aniline":"n:阿尼林",
"aniline dye":"n:染料",
"animadvert":"v:责备,非难,谴责,苛责",
"animal":"n:动物,牲口,牲畜,兽",
"animal fiber":"n:动物纤维",
"animal husbandry":"n:牧畜",
"animal kingdom":"n:动物界",
"animal nature":"n:兽性",
"animal oil":"n:动物油",
"animal starch":"n:糖元",
"animalcule":"n:微生物",
"animals":"n:兽类",
"animate":"v:活跃,激励,激发,绘制",
"animated":"a:热闹",
"animated cartoon":"n:动画",
"animatedly":"d:兴致勃勃",
"animation":"n:动画,生动,活跃,动画片,生机,活泼",
"animosity":"n:敌意,怨恨,敌视",
"animus":"n:仇视,意图,恶意,宗旨",
"anion":"n:负离子",
"anise":"n:大料",
"anisotropy":"a:各向异性",
"ankara":"n:安卡拉",
"ankle":"v:走路,走;n:腿腕子",
"anklebone":"n:踝骨",
"anklet":"n:腿带,短袜",
"annal":"n:纪要",
"annals":"n:年报,志,春秋,汗青,年表,年刊",
"annam":"n:安南",
"anneal":"v:退火,烧",
"annealing":"v:退火",
"annelid":"n:环节动物",
"annex":"v:兼并,获得,合并,追加,攻占,附带,侵吞,并,偷,盖;n:附录,兼,附属品",
"annexation":"n:归并,吞并,并吞,附加",
"annie oakley":"n:优待券",
"annihilate":"v:灭绝,吃,废止,歼击,聚歼,剿,废除",
"annihilation":"n:消灭,歼灭",
"annihilator":"n:减震器",
"anniversary":"n:周年,期",
"annotate":"v:注解,注释,注",
"annotation":"n:批注,笺,注文,附注,注解",
"annotations":"n:附注",
"announce":"v:宣告,报,通知,预告,发布,告,报知,声明,显示,宣,声称;n:布",
"announcement":"n:声明,公告,布告,宣告,榜,预告,声;v:告",
"announcer":"n:广播员,解说员",
"annoy":"v:搅,烦恼,讨嫌,惹恼,磨;a:来劲",
"annoyance":"n:厌烦,麻烦,打搅;v:烦扰",
"annoyed":"a:急,恼",
"annoying":"a:可气,难人,讨嫌,烦心",
"annual":"n:年,年鉴,年报,全年;a:年,年度,全年",
"annually":"d:一年一度,年年",
"annuals":"n:年刊",
"annuity":"n:年金,养老金",
"annul":"v:销,毁弃,废止,撤销",
"annular":"a:环形",
"annulment":"n:废止;v:终止",
"annulus":"n:环,环带,环节",
"annunciation":"n:公布",
"anode":"n:阳极,正极",
"anodize":"v:电镀",
"anodyne":"n:止痛药;a:镇痛",
"anoint":"v:基督",
"anomalous":"a:异常,变态",
"anomaly":"n:反常;a:反常",
"anon":"d:立即,不久,即刻",
"anonymity":"n:匿名,无名",
"anonymous":"a:匿名;v:匿名",
"anopheles":"n:疟蚊",
"anorak":"n:皮猴,棉猴儿",
"anorexia":"n:厌食,食欲不振;v:食欲不振",
"anorexic":"a:厌食",
"another":"r:另;a:别的;d:另外",
"answer":"v:接茬儿,对答,答对,答题,抵偿,回话,酬对;n:答辩",
"answer for":"n:担保",
"answering":"v:回答",
"ant":"n:蚂蚁,蚍蜉,蚁",
"ant cow":"n:蚜虫",
"antagonise":"v:对抗",
"antagonism":"a:相反;v:对抗;n:敌对",
"antagonist":"n:对手,敌手",
"antagonistic":"a:敌对",
"antagonize":"v:反对,反抗,中和,抵销",
"antarctic":"n:南极",
"antarctic circle":"n:南极圈",
"antarctica":"n:南极洲",
"ante":"n:赌注;v:出",
"anteater":"n:食蚁兽",
"antecedence":"n:先行",
"antecedent":"n:经历,在先,前项,先例,祖先,履历",
"antecedents":"n:来路,来历",
"antechamber":"n:接待室,前厅",
"antediluvian":"n:老朽",
"antelope":"n:羚",
"antenatal":"n:产前",
"antenna":"n:天线,触角",
"antennae":"n:天线",
"anterior":"a:先前",
"anteroom":"n:休息室,接待室,前厅,候诊室",
"anthem":"n:赞歌,校歌,国歌",
"anther":"n:花药,花粉囊",
"anthology":"n:诗集,文选;v:选",
"anthracite":"n:红煤",
"anthracite coal":"n:无烟煤",
"anthrax":"n:炭疽",
"anthropoid":"n:类人猿,人猿",
"anthropoid ape":"n:人猿",
"anthropology":"n:人类学",
"anti":"a:反,反对;n:反对派;p:反对",
"antiaircraft":"n:高射炮;a:防空",
"antiaircraft gun":"n:高炮",
"antibiotic":"a:抗菌素,抗菌",
"antibiotics":"n:抗菌素,抗生素",
"antibody":"n:抗体",
"anticancer":"a:抗癌",
"anticipate":"v:预见,预言,料,预想,料及,指望,意料,预付,预支,促进,意,逆",
"anticipation":"n:预料,期待,预期,预测,抢先,预感,预支,预处理,预言;d:预先",
"anticlimax":"n:虎头蛇尾",
"anticyclone":"n:反气旋",
"antidote":"n:解毒剂",
"antifreeze":"n:防冻液",
"antigen":"n:抗原",
"antiknock":"n:减震",
"antimatter":"n:反物质",
"antimony":"n:锑",
"antiparticle":"n:反粒子",
"antipathy":"n:反感,憎恶,厌恶",
"antiquated":"a:过时",
"antique":"n:古物;a:古色古香",
"antiquities":"n:古风,古物",
"antiquity":"n:古老,古迹,古物,古旧,古",
"antisepsis":"n:灭菌,防腐,消毒",
"antiseptic":"n:消毒剂;v:防腐",
"antistatic":"a:抗静电",
"antisubmarine":"a:反潜",
"antithesis":"n:对仗",
"antitoxin":"n:抗毒素,防毒",
"antler":"n:鹿角",
"antonym":"n:反义词",
"antwerp":"n:安特卫普",
"anus":"n:肛门,肛瘘",
"anvil":"n:砧子,基石",
"anxiety":"n:担心,心病,挂虑,渴望,悬念,愁苦,忧,苦闷,忧心,虞;a:焦虑,焦急;v:患",
"anxious":"a:急于,忧虑,焦急,急,切;v:心焦,忧虑",
"anxiously":"d:眼巴巴",
"any":"d:一些,丝毫,略微,稍微,少许,随便;a:任何,一点,一些,凡是;r:哪;v:是",
"anybody":"n:张三李四",
"anyhow":"d:反正,总之,总,左右,横竖,随便",
"anymore":"d:不再",
"anyone":"r:谁,你,任何人",
"anything":"r:什么,什麽;n:一针一线",
"anything but":"p:绝不",
"anytime":"d:一定,总是;n:旦夕",
"anyway":"d:不管怎样,随便,左右,左不过,死活,总",
"anyways":"d:不管怎样",
"anywhere":"d:随地,随处;r:哪儿",
"aorta":"n:主动脉,大动脉",
"apache":"n:流氓",
"apart":"d:拆开,离,撇开,散开,分别,各别,除去;v:相距",
"apart from":"p:除外,以外,远离,除_以外",
"apartheid":"n:隔离",
"apartment":"n:公寓,房间,住房,套间",
"apathetic":"a:淡漠,麻木,漠不关心,暮气沉沉",
"apathetically":"d:漠然",
"apathy":"n:冷漠,冷淡,漠不关心,淡漠,暮气",
"apatite":"n:磷灰石",
"ape":"n:猿猴;v:仿效",
"ape-man":"n:猿人",
"aperture":"n:洞,孔隙,窗口,隙,眼,口径",
"apex":"n:顶峰,舌尖,心尖,绝顶,峰值",
"aphasia":"n:失语症",
"aphid":"n:蚜虫,蚜,腻虫",
"aphorism":"n:谚语,警语",
"aphrodisiac":"n:春药",
"apiary":"n:蜂房,养蜂场",
"apical":"a:舌尖音",
"apiece":"d:各人",
"aplenty":"d:丰富,极;n:大量,丰富;a:丰富",
"aplomb":"n:自信,冷静,自恃,垂直",
"apnea":"v:窒息;n:窒息",
"apocalypse":"n:启示",
"apogee":"n:极点",
"apollo":"n:美男子",
"apologetic":"a:辩护,不过意",
"apologetically":"d:辩解,道歉",
"apologia":"n:道歉",
"apologist":"n:辩护士,卫道士",
"apologize":"v:道歉,认错,请罪,负荆请罪,辩解,赔礼,赔话",
"apology":"n:歉意,辩解,赔不是",
"apoplexy":"v:中风;n:卒中",
"apostasy":"n:变节",
"apostatize":"v:变节,脱党",
"apostle":"n:鼓吹者",
"apothecary":"n:药剂师,药铺,药房",
"apothegm":"n:格言",
"apotheosis":"n:崇拜,神化",
"appall":"v:吓坏",
"appalling":"a:骇人听闻",
"apparatus":"n:器具,器材,仪表,机关,注释,仪,组织",
"apparel":"n:衣服,装饰,穿着;v:装饰",
"apparent":"a:明显,显而易见;v:显见;d:显然",
"apparently":"d:显然,看起来",
"apparition":"n:出现,鬼怪,幻象,幻影,妖怪",
"appeal":"n:上诉,恳求;v:控诉,要求",
"appear":"v:出现,看来,好像,出,露出,仿佛,发表,起,显出,似,浮现,亮,现,透;n:形",
"appearance":"n:外表,外观,仪表,露面,表面,现象,模样,象,仪容,出庭,面貌,相,神态,门面,容,幽灵,姿,状;v:形容",
"appease":"v:满足,缓和,劝慰,抚慰,解,充",
"appeasement":"n:绥靖,抚慰,满足,迁就,姑息,缓和",
"appellation":"n:称谓,称呼,名",
"append":"v:附上,加上,增补,加,添加",
"appendage":"n:附庸,尾巴",
"appendages":"n:附件",
"appended":"v:附加",
"appendices":"n:附录",
"appendicitis":"n:阑尾炎",
"appendix":"n:附庸,附言",
"appertain":"v:属于",
"appetite":"n:食欲,胃口,欲望,嗜好,爱好,饭量,食量",
"appetizing":"a:香喷喷,香;v:对胃口",
"applaud":"v:喝彩,欢呼,赞美,夸奖,拍掌",
"applause":"n:鼓掌,喝采,称赞,夸奖;v:叫好",
"apple":"n:苹果",
"apple sauce":"n:胡说,苹果酱",
"apple tree":"n:苹果树",
"applesauce":"n:苹果酱",
"appliance":"n:设备,工具,仪器,适用;v:应用",
"applicability":"n:适用性,适当",
"applicable":"a:适用",
"applicant":"n:申请人,申请者,投保人",
"application":"n:申请书,运用,适用,用功,勤勉,请求,报名,用场;v:接近,应用",
"application form":"n:志愿书",
"applied":"v:外加",
"applique":"n:贴花",
"apply":"v:适用,用,涂,上,施,着,请求,提出,致力,下,努力,外敷,抹,施行,呈请,措,寻求,傅,报名,声请,适合",
"appoint":"v:任命,任,派,规定,指派,命令,内定,引用,立,叙用,供给,差使;n:命",
"appointment":"n:任命,预约,任职,约定,职位,约,任用,委派,命令,天意;v:指定",
"apportion":"v:分摊,配",
"apportionment":"n:分摊,分配",
"appose":"v:并列",
"appositeness":"n:适合;v:适合",
"apposition":"v:外加,接合;n:并列",
"appositive":"n:同位语",
"appraisal":"n:评价,估计,评论;v:检验",
"appraise":"v:估;n:叙",
"appraiser":"n:幕宾",
"appreciate":"v:感谢,赞赏,增值,感激,懂得,体会,体味,鉴别,升值,玩,赏,感,赏鉴,鉴貌辨色,腾贵",
"appreciation":"n:感谢,了解,感激,知道,鉴赏,鉴别,上涨,腾贵",
"apprehend":"v:害怕,缉获,缉拿,疑惧,拘押,捉拿",
"apprehension":"n:恐惧,忧虑,顾虑,担忧,见解,领悟,理解",
"apprehensions":"n:疑惧;v:疑惧",
"apprehensive":"a:惶惑",
"apprentice":"n:艺徒,徒,见习生,初学者,生手,高徒",
"apprise":"v:通知,通报,告知",
"approach":"n:途径;v:看待,探讨",
"approach trench":"n:交通壕",
"approaching":"n:未来;a:近;v:垂",
"approbation":"n:赞许,称赞,批准,嘉奖",
"appropriate":"a:适当,合适;v:偷走",
"appropriately":"d:恰",
"appropriateness":"n:高低,适当,占有",
"appropriation":"n:经费,盗用,挪用,据为己有;v:拨款",
"approval":"n:同意,认可;v:核准",
"approve":"v:赞成,通过,同意,赞同,证实,认可,准,肯定,审批,证明",
"approximate":"v:接近;a:概;d:大概",
"approximately":"d:约,大体,约莫,近乎,许,约略,大略,概;a:近",
"approximation":"n:概算,逼近;v:近似,接近",
"appurtenance":"n:附属物,设备,装置",
"appurtenant":"a:附属物",
"apr":"n:4月,四月",
"apres":"p:以后,在_以后,在_之后,之后",
"apricot":"n:杏树,杏,杏子",
"apricot tree":"n:杏树",
"april":"n:四月,4月",
"april fool":"n:愚人节",
"apron":"n:停机坪,挡板,窗台",
"apropos":"a:中肯;p:关于",
"apt":"a:容易,贴切,恰如其分,得当",
"aptitude":"n:天资,聪颖,颖悟,资质,材",
"aptly":"d:巧",
"aptness":"n:才能,性情",
"aqua":"n:溶液",
"aqua fortis":"n:硝酸",
"aqua vitae":"n:烧酒",
"aquanaut":"n:潜水员",
"aquaplane":"v:滑水;n:水上飞机",
"aquarium":"n:水族馆",
"aquatic":"a:水上,水生;n:水上",
"aquatic bird":"n:水鸟,水禽",
"aquatic plant":"n:水草",
"aquavit":"n:烧酒,白兰地",
"aqueduct":"n:渠道,导管,水管",
"aquila":"n:天鹰座",
"arab":"n:阿拉伯人,阿拉伯",
"arabian":"n:阿拉伯人,阿拉伯",
"arabian jasmine":"n:茉莉",
"arabian nights":"n:天方夜谭",
"arabic":"n:阿拉伯语,阿拉伯",
"arabic language":"n:阿拉伯文",
"arable":"n:耕地",
"arachnid":"n:蜘蛛",
"aral sea":"n:咸海",
"arbiter":"n:调停人",
"arbitrage":"n:股票,裁判,套汇;v:套汇,套购",
"arbitrament":"n:裁决",
"arbitrarily":"d:横加",
"arbitrariness":"n:武断,独断,专横,任性,霸道",
"arbitrary":"a:专横,蛮横,生硬,随便,乱,专断;v:随心所欲,独断",
"arbitrate":"v:调解,调处,排解",
"arbitration":"n:仲裁;v:鉴定,仲裁",
"arbor":"n:凉亭,轴,树木,亭,乔木,木本植物",
"arboretum":"n:植物园",
"arborvitae":"n:侧柏",
"arbour":"n:花园,亭",
"arc":"n:电弧,弧线",
"arch":"n:弓,拱形,拱顶,牌坊,猫,脚心;a:总的",
"archaeology":"n:古物,考古",
"archaeopteryx":"n:始祖鸟",
"archaic":"a:古,古物;n:古代",
"archaism":"n:古风,之乎者也,古字",
"archbishop":"n:大主教",
"archduchess":"n:公主",
"arched":"v:罗锅,弓形,拱形,穹形;n:弓形,拱门,罗锅;a:拱形",
"archenemy":"n:大敌,撒旦",
"archeology":"n:考古学,古物",
"archer":"n:射手,鞋匠",
"archery":"n:射箭",
"archetype":"n:原型,典型",
"archfiend":"n:撒旦,魔王",
"arching":"v:弓状",
"archipelago":"n:群岛,列岛",
"architect":"n:建筑师,设计师",
"architectonics":"n:建筑学",
"architecture":"n:建筑,建筑学,建筑物,结构,构造,架构",
"architrave":"n:线脚",
"archive":"n:档案,卷宗;v:存档",
"archives":"n:案卷,档案馆,档案",
"archness":"n:狡猾",
"archway":"n:拱道,拱门",
"arctic":"n:北极,北极圈;a:严寒",
"arctic circle":"n:北极圈",
"arctic fox":"n:白狐,北极狐",
"arctic ocean":"n:北冰洋",
"ardency":"n:热情,热烈,热心",
"ardent":"a:热情,热心,热烈,殷切,热切,殷,热",
"ardently":"d:殷殷",
"ardor":"n:热情,热心,热忱",
"arduous":"a:艰巨,艰苦,吃重,艰难;v:是",
"arduousness":"n:艰苦,奋斗,艰难",
"are":"n:公亩",
"area":"n:地区,区域,面积,区,领域,地方,范围,带,场地,地面,空地,区间,境,一带,境界,境域,壤,地积,舆",
"areca catechu":"n:槟榔",
"arena":"n:场所,舞台,竞技场;v:擂",
"argent":"n:货币",
"argentina":"n:阿根廷",
"argentine":"a:阿根廷;n:银",
"argle-bargle":"n:争论,讨价还价",
"argon":"n:氩",
"argot":"n:隐语,暗语,黑话,行话",
"arguably":"d:可能",
"argue":"v:争论,认为,争辩,辩论,主张,说服,表明,辩,讨论,争,驳,证明,论,议论,计较,论战,争长论短,打嘴仗,论辩,强辩,巧辩,讼,顶撞,立论,说嘴,声辩,较量,说理,汹,劝说,论争,争竞,争议,问难",
"argument":"n:论点,争论,论据,辩论,论证,理由,道理,立论,说法,自变量,诡辩,论调,情节,摘要;v:争论,论证",
"argumentation":"n:立论,推论,义理,辩论,论说,议论文,争论,论说文,论证;v:论证",
"argumentative":"a:振振有词",
"argumentatively":"d:振振有词",
"argy-bargy":"n:抬杠,讨价还价,议论",
"aria":"n:咏叹调,唱段,唱腔",
"arid":"a:干旱,干燥,旱;n:干旱",
"aridity":"n:干燥,荒芜,乏味,枯燥,贫瘠;a:荒芜",
"aright":"d:不错;v:纠正",
"arise":"v:产生,出现,发生,起来,起,起身,升起,出,起床,上升,兴起",
"aristocracy":"n:贵族",
"aristocrat":"n:贵族",
"arithmetic":"n:算术,运算,算法,计算,算学",
"arithmetic progression":"n:等差级数,等差数列",
"ark":"n:方舟,柜",
"arm":"n:手臂,胳膊,臂,武器,胳臂;v:发给,供给",
"armada":"n:舰队,船队,大队,机群",
"armadillo":"n:犰狳",
"armament":"n:军备,装备,武装力量,武装,军械,兵器,火炮,军队",
"armature":"n:电枢,衔铁,钢筋,甲胄,针刺,转子,骨架",
"armband":"n:臂章,袖章,袖标",
"armchair":"n:扶手椅,交椅",
"armed forces":"n:军队,武装,部队,军",
"armenia":"n:亚美尼亚",
"armful":"n:抱",
"armillary sphere":"n:浑仪",
"arming":"v:徽章",
"armistice":"n:停战,休战;v:停战,休战",
"armlet":"n:臂章",
"armor":"n:盔甲,甲胄,甲,装甲,铁甲",
"armored":"a:装甲",
"armored car":"n:装甲车",
"armorer":"n:盔甲",
"armory":"n:军械,兵工厂,军械库,武库",
"armour":"n:甲,装甲;a:坚",
"armoured":"a:装甲",
"armourer":"n:盔甲",
"armoury":"n:装甲,兵工厂,军械库,军械,盔甲",
"armpit":"n:腋窝,胳肢窝,夹肢窝,腋,胳",
"armrest":"n:扶手,靠手",
"arms":"n:枪炮,铁,兵,兵器,兵戎,干戈,武器,武装,刀兵,兵戈,军备,枪杆子",
"army":"n:军队,部队,陆军,军,大军,队伍,集团军,师,兵团,军旅,戎,伍,子弟兵,团体,野战军;a:伍",
"aroma":"n:香味,芳香,香气,风味,韵味,风格",
"aromatic":"n:芳香,芳香剂;a:芳香,香",
"aromatic hydrocarbon":"n:芳烃",
"around":"d:周围,到处;p:差不多,左右,在_周围,在_附近;n:周围,光景,内外,周遭;v:围,围绕;a:周遭",
"arousal":"n:觉醒,激励,唤起;v:觉醒",
"arouse":"v:引起,激起,唤起,激发,唤醒,发动,激,徼,鼓动,睡醒,启发,动,鼓励,提起,动员,调动",
"aroused":"a:激昂",
"arraign":"v:传讯,控告,提审,审问,弹劾,责难",
"arrange":"v:安排,排列,准备,整理,商定,约定,改编,布置,排,设法,编排,列,铺排,筹备,料理,分类,接洽,筹办,安置,部署,署,掇弄,庀,顺,约,支配,置,摆布,措置,调弄,配器,摒挡,布,顿,整顿,措,打叠,调停,骘,安顿,擘画;n:布",
"arrangement":"n:安排,排列,装置,布置,商定,分类,次序,调解,调整,格局,料理,改作,事物,整顿,和解,整理,改编,预备,约定,筹备;v:调整,布置",
"arrangements":"n:事宜",
"arrant":"a:彻头彻尾,臭名昭著;v:臭名昭著",
"arras":"n:挂毯",
"array":"n:阵列,排列,衣服,队列;v:打扮,布置,排列,装饰,召集",
"arrears":"n:尾数,积欠,欠款,欠债",
"arrest":"v:逮捕;n:抑制",
"arrest warrant":"n:逮捕令",
"arresting":"v:制动",
"arrival":"n:到达,到来,抵达,出现,登场",
"arrive":"v:到,到达,来,来到,抵达,到来,赶到,被,达到,得出,出,发生,达,降临,成功,抵,达成,临,来临,戾,莅,造,莅临,幸,詹",
"arrive at":"v:达成,到达,造,得出,抵,赶到",
"arrogance":"n:傲慢,自大,自高自大,骄气,气焰",
"arrogant":"a:傲慢,自高自大,自大,骄傲,倨,自满,颐指气使,傲,狂,嚣张,高慢,骄慢,自傲;v:颐指气使,自高自大",
"arrogate":"v:独揽,霸占",
"arrogation":"n:霸占",
"arrow":"n:箭,箭头,矢,令箭,标杆",
"arrowhead":"n:箭头,镞,匕,慈姑,镝,茨菰",
"arrowroot":"n:葛,竹芋",
"arrows":"n:箭",
"arroyo":"n:小溪",
"arse":"n:屁股",
"arsenal":"n:武库,军火库,军械库,兵工厂",
"arsenic":"n:砷,砒霜,信石,信",
"arson":"n:纵火,放火",
"arsonist":"n:纵火犯",
"art":"n:艺术,技巧,技术,美术,文科,技艺,装模作样,诡计,插图,奸计,技能,学问,术,策略,功夫,解数",
"art exhibition":"n:美展",
"art gallery":"n:画廊",
"art object":"n:美术品",
"art paper":"n:铜版纸",
"arteria coronaria":"n:冠状动脉",
"arterial":"n:动脉",
"arterial blood":"n:动脉血",
"arteries":"n:动脉",
"arteriosclerosis":"n:动脉硬化",
"artery":"n:动脉,干线,大动脉,中枢,要道,干路,干道",
"artful":"a:刁钻,刁滑,滑头滑脑,巧,刁",
"artfulness":"n:巧妙,狡猾",
"arthritis":"n:关节炎",
"arthropod":"n:节肢动物",
"artichoke":"n:宝塔菜,百合",
"article":"n:文章,物品,论文,条款,冠词,制品,商品,条,条文,件,文翰,笔札,项目,关节,家伙,节;v:列举,约定,控告",
"article of faith":"n:信条",
"articles":"n:用品,笔墨",
"articulate":"v:接合,咬,挂钩,形成,表现;a:伶牙俐齿",
"articulation":"n:发音,关节,表达,连接,咬合;v:接合,连接",
"artifice":"n:诡计,技巧,手段,手腕,花头,做作,巧计,机谋,技能,谋略,策略",
"artificer":"n:工匠,技工,设计者,发明家,发明者,巧匠,技师,能工巧匠",
"artificial":"a:人工,人为,假,矫揉造作,做作,人造,义,造作;v:做作",
"artificial intelligence":"n:人工智能",
"artificial satellite":"n:卫星",
"artificiality":"n:人造,人为,人工",
"artillery":"n:炮兵,大炮,火炮,炮车",
"artillery fire":"n:炮击",
"artillery shell":"n:炮弹",
"artilleryman":"n:炮手,炮兵",
"artillerymen":"n:炮兵",
"artisan":"n:工匠,技工,手艺人,艺人,匠人,匠,能工巧匠",
"artist":"n:艺术家,画家,美术家,艺人,能手",
"artiste":"n:能手,艺人",
"artistic":"a:艺术,美观",
"artistry":"n:技艺,艺术性,艺术",
"artless":"a:天真;v:胸无城府",
"artlessness":"n:拙劣,质朴",
"artwork":"n:美术品,图形;v:描绘",
"arytenoid cartilage":"n:勺状软骨",
"as":"p:作为,象,当;c:以便;d:一边;f:似的",
"as a consequence of":"p:由于",
"as a result of":"p:由于",
"as compared to":"p:比较,与_比较",
"as compared with":"p:比较,与_比较",
"as distinct from":"p:与_不同,不同",
"as distinguished by":"p:不同,与_不同",
"as distinguished from":"p:不同,与_不同",
"as far as":"p:关于,至于",
"as for":"p:至于,对于",
"as if":"c:似的,好象,似乎,仿佛,似,宛如,如,犹如,恍若,恍,若,宛,犹,宛然",
"as it is":"c:其实,实际上",
"as long as":"c:但凡",
"as much as":"c:就,多少,足,足足,等于",
"as opposed to":"p:相对,与_相对",
"as regards":"p:至于,关于,讲",
"as result of":"p:由于,因为",
"as soon as":"c:一,就,刚,即,一__就__",
"as though":"c:仿佛,好像",
"as to":"p:关于,讲,至于,对于",
"as usual":"p:如故,照旧,仍然",
"as well":"d:也,同样,还,外带",
"as well as":"p:也,以及,既,以,载",
"asbestos":"n:石棉",
"ascend":"v:上升,升,登,上坡,上去,升高,攀登,登高,高耸,腾",
"ascendancy":"n:优势,权势,主权",
"ascendant":"n:优势,福星高照,祖先",
"ascending colon":"n:升结肠",
"ascension":"n:上升,升起,升腾,升高;v:升起",
"ascent":"n:上坡路,攀登,上升,升起,登高,阶梯,上坡,升高,坡度;v:升起,生长",
"ascertain":"v:查明,弄清,确定,探明,探悉,稽考,查究,判明,落实,推求,捉摸",
"ascertainment":"n:确定,查明,断定,探知;v:断定",
"ascetic":"a:禁欲",
"asceticism":"n:禁欲主义,苦行",
"ascription":"n:归于,推诿",
"aseptic":"a:防腐剂",
"asexual":"a:无性",
"asexuality":"n:无性",
"asgard":"n:天堂,仙境",
"ash":"n:灰烬,灰,骨灰,废墟,灰尘,苍白,白蜡树,碳酸钠,灰色,余烬,烬",
"ash can":"n:深水炸弹",
"ash-bin":"n:垃圾桶",
"ashamed":"a:羞愧,惭愧,羞耻,不好意思,害臊,难为情,羞惭,愧,愧怍,觍,没脸,愧疚,怍;n:羞耻",
"ashcan":"n:垃圾箱",
"ashen":"a:灰白,铁青,土色",
"ashes":"n:遗骨,遗体,骨灰,余烬,灰烬,烬",
"ashore":"d:上岸,岸上,登陆,陆上;v:登陆,上岸",
"ashtray":"n:烟灰缸,烟缸",
"ashy":"n:灰色",
"asia":"n:亚洲,亚",
"asia minor":"n:小亚细亚",
"asian":"n:亚细亚",
"aside":"d:一边;n:旁白;p:一边",
"asininity":"n:愚蠢,愚钝,蠢事",
"ask":"v:问,要,要求,请,叫,请求,问道,找,邀请,将,求,征求,买,询问,需要,发问,约,索,教,申请,讨,祈求,约请,公布,质问,询,探问,索要,转托,问询,问讯,征,告,叩,动问",
"ask for":"v:要,讨,买,告,请求,申请,责,索要,征求,找,征",
"ask for it":"v:自找",
"ask for trouble":"v:惹火烧身,自讨苦吃",
"askance":"d:斜,横,斜视",
"askew":"a:歪;d:歪,斜;v:歪斜",
"asking":"v:请求,问",
"aslant":"d:斜;v:歪斜,侧;a:歪斜",
"asleep":"d:麻木,睡熟,长眠",
"asparagus":"n:芦笋,文竹,石刁柏,天门冬,龙须菜",
"aspect":"n:方面,外貌,面貌,面目,形势,样子,貌,特征,方位,面,方向,头,侧面,体,容貌,上面,光景,局势,姿,点,见地,局面,态,神色,首",
"aspen":"n:白杨,白杨树,杨树",
"asperity":"n:粗糙,刺耳,粗暴",
"aspersion":"n:中伤,诬蔑",
"asphalt":"n:沥青,柏油,土沥青",
"asphodel":"n:水仙",
"asphyxia":"v:昏厥,窒息;n:窒息",
"asphyxiate":"v:窒息",
"asphyxiation":"v:窒息;n:窒息",
"aspic":"n:肉冻",
"aspidistra":"n:蜘蛛抱蛋",
"aspirant":"n:考生,野心家",
"aspirate":"n:送气音,音;v:吸入,吸气",
"aspirated":"v:送气",
"aspirating":"v:除尘",
"aspiration":"n:愿望,渴望,抱负,热望,心愿,志气,吸入,志趣,志愿,心气,呼吸,送气音,吸取,心胸,意愿,志,志向;v:吸取,呼吸",
"aspirations":"n:渴望,心声",
"aspirator":"n:吸尘器",
"aspire":"v:渴望,追求,热望,升,有志于",
"aspirin":"n:阿司匹林",
"ass":"n:驴,驴子,傻瓜,傻子,蠢人,笨蛋,屁股,蠢驴",
"assail":"v:袭击,攻击,攻打,抨击,指责",
"assailant":"n:凶手",
"assassin":"n:刺客,凶手",
"assassinate":"v:暗杀,刺杀,破坏,行刺,中伤,刺,暗害",
"assassination":"n:暗杀,暗害",
"assault":"v:殴打,进攻,威胁,突击,攻打,攻,攻击,冲锋,非议,冲击;n:攻击",
"assay":"n:测定;v:化验,企图,试验",
"assemblage":"n:会众,汇,会合,集会;v:汇",
"assemble":"v:聚集,装配,集合,汇编,安装,聚,组装,会集,会,收集,汇集,会合,会聚,集聚,攒,凑合,萃,调集,荟萃,集,装,总,取齐,齐集",
"assembler":"n:汇编程序,汇编,装配工",
"assembling":"v:装配,组装",
"assembly":"n:装配,部件,议会,集会,装置,组合,会众,集合,议院,汇编",
"assembly hall":"n:礼堂,大礼堂,会馆,会场,会堂",
"assembly language":"n:汇编语言",
"assembly line":"n:装配线,流水线",
"assemblyman":"n:装配工,议员",
"assent":"v:同意,应允,赞成;n:赞成",
"assert":"v:断言,声称,维护,宣称,主张,坚持,声明,居",
"assertion":"n:断言,主张,坚持,声明,维护,断定,声称;v:断定,断言",
"assertive":"a:武断",
"assess":"v:评价,估价,评估,评定,征收,估量,叙,估,核计;n:叙",
"assessment":"n:估价,评定,评价,税额",
"assessor":"n:陪审,助理",
"asset":"n:资产,财产",
"assets":"n:公物,财产,资财,资产",
"asseverate":"v:宣称,断言",
"asseveration":"n:断言,誓言;v:断言",
"asshole":"n:肛门",
"assiduity":"n:兢兢业业,殷勤,勤勉,关心,刻苦",
"assiduous":"a:刻苦,勤勉;v:孜孜不倦",
"assiduously":"d:孜孜不倦,如饥似渴",
"assign":"v:分配,指定,派,布置,指派,定,拨,划,转让,交,差遣,分,调遣,划拨,调派,差使,差,选定",
"assignation":"n:约定,指定,转让,选定,约会,分配,幽会",
"assigning":"v:指定",
"assignment":"n:任务,作业,分配,指定,赋值,工作,转让,分派,任命,差事,测定,委派,指出;v:分配,赋值,分派,测定",
"assimilate":"v:吸收,同化,消化,吸取,摄取,摄",
"assimilation":"n:同化,吸收;v:同化",
"assist":"v:帮助,协助,参加,帮,出席,辅助,援助,扶助,辅,襄助,左,助,帮同,协办;n:援助,加速器,相,协助",
"assistance":"n:帮助,援助,协助,出席,辅",
"assistant":"n:助手,店员,助理,伙计,助理员,助教,帮手,辅导员,襄助,副,下手,副手,羽翼;a:下作",
"assisting":"v:助攻",
"assize":"n:条例,法令,条令",
"associate":"n:同人;v:联合,连带,过从",
"associates":"n:侪辈",
"association":"n:联想,联系,协会,会,交往,组合,学会,群落,社会,社团,交际,结合,联合,联盟,瓜葛,配对;v:交往,结合",
"association football":"n:足球",
"assort":"v:调和,配套,相交,相配,交际,配备,相称",
"assorted":"a:各色,杂七杂八;n:什锦",
"assortment":"n:品种,分类,搭配,种类;v:分类",
"assuage":"v:减轻,平息,缓和,满足,平,解,充",
"assume":"v:假定,假设,设想,承担,担任,作,采取,取,即,假装,担当,采用,呈,想像,接受,上任,臆断,执掌,摆",
"assumed name":"n:化名,假名,号",
"assuming":"a:非分",
"assumption":"n:假设,假定,设想,臆说,假装,想当然,小前提",
"assurance":"n:保证,自信,担保,把握,断言,定心丸,自大,确信,保险;v:担保",
"assure":"v:保证,担保,包,包管,管,管保",
"assured":"n:被保险人",
"assuredly":"d:固,的确,管教",
"assyria":"n:亚述",
"assyrian":"a:亚述",
"astatine":"n:砹",
"aster":"n:天体,紫菀,星体",
"asterisk":"n:星号",
"astern":"d:往后",
"asteroid":"n:小行星,海星",
"asthma":"n:哮喘,气喘,喘;v:喘",
"astigmatism":"n:散光,偏差",
"astir":"d:行动,起床,活动;a:哄动",
"astonish":"v:吃惊,惊讶,震惊;a:吃惊",
"astonished":"a:骇怪,怪讶,骇异;v:惊异",
"astonishing":"a:惊人,奇",
"astonishment":"n:惊讶,惊奇",
"astound":"v:震惊,大吃一惊",
"astounded":"v:惊讶,惊异;a:愕然,惊讶",
"astounding":"v:骇人听闻;a:骇人听闻",
"astraddle":"d:跨;p:跨着",
"astrakhan":"n:羔羊皮",
"astray":"d:迷路,堕落",
"astride":"d:跨;p:跨着",
"astringency":"n:严峻,严格",
"astringent":"a:涩,收敛;n:涩味",
"astrolabe":"v:试;n:试",
"astrologer":"n:阴阳生",
"astrology":"n:占星术,星相,星象",
"astronaut":"n:宇航员,太空人",
"astronomical":"n:天文;a:天文数字",
"astronomically":"d:天文学",
"astronomy":"n:天文学,天文",
"astute":"a:精明,聪慧,智",
"astuteness":"n:谋略",
"asunder":"d:分离,碎,隔离,断,开,散",
"asylum":"n:收容所,避难所;v:庇护",
"asymptote":"n:渐近线",
"asynchronous":"a:异步",
"at":"p:在,就,对,到,向,于,望,照,从事,诸,在_方面;r:诸;d:一般;n:举措",
"at a loss":"p:困惑,迷惘,亏本,茫然,茫无头绪",
"at a time":"p:同时",
"at all":"p:完全,毫,简直,根本",
"at any rate":"p:好歹,总而言之",
"at best":"d:大不了;p:顶多",
"at bottom":"p:说到底,骨子里,实际上",
"at fault":"p:困惑,不知所措",
"at first hand":"p:直接",
"at first sight":"p:初见",
"at hand":"p:手边,凑手,手头,手下,手底下",
"at heart":"p:心上,心中",
"at home":"p:对内,熟悉",
"at large":"a:详尽",
"at last":"p:高低,总算,最后,卒,结果,算是",
"at least":"d:至少,总",
"at leisure":"p:清风明月,有空,清闲",
"at length":"p:最后",
"at long last":"p:算,总算",
"at most":"p:大不了,顶多;d:大不了",
"at once":"p:登时,偻,赶快,连忙,一骨碌,跟着,迅即,当时,当下,即,立地,就,当儿",
"at one time":"p:一度",
"at peace":"p:相安无事",
"at present":"p:时下,当今,现在,兹,此时,当下,即,眼前,如今,这会儿,此刻,现下",
"at random":"d:信,夹七夹八,横七竖八",
"at rest":"p:休息,安然,静止,安息;d:静止",
"at sea":"d:海上,茫然,不知所措,茫",
"at stake":"p:危如累卵",
"at the most":"p:至多",
"at the same time":"d:一边",
"at the worst":"p:大不了",
"at times":"p:时时,有时候",
"at will":"p:随便,信,随意",
"atavism":"n:返祖现象",
"ataxia":"n:混乱",
"atelier":"n:工作室,工场,画室",
"atheism":"n:无神论",
"athens":"n:雅典",
"athirst":"a:渴望",
"athlete":"n:运动员",
"athlete's foot":"n:足癣,脚癣",
"athletic field":"n:运动场",
"athletics":"n:体育运动,竞技,运动,田径运动",
"athwart":"p:横过,相反,横穿,横跨,逆,事与愿违;d:不便,斜,相反",
"atlanta":"n:亚特兰大",
"atlantic":"n:大西洋",
"atlas":"n:地图集,图集,图籍,图谱,图册",
"atmosphere":"n:气氛,大气,空气,大气层,环境,大气压,风,氛围,排气,雾,风格,基调,雰,气象,风气,云层,氛",
"atmospheric electricity":"n:天电",
"atmospheric pressure":"n:气压",
"atmospherics":"n:天电",
"atom":"n:原子,微粒,微量",
"atom-bomb":"n:原子弹",
"atomic":"a:原子",
"atomic bomb":"n:原子弹",
"atomic energy":"n:核能",
"atomic pile":"n:核反应堆",
"atomic reactor":"n:核反应堆",
"atomic weapon":"n:原子武器",
"atomiser":"n:喷雾器",
"atomization":"n:雾化,喷雾",
"atomize":"v:雾化,喷雾",
"atomized":"v:雾化",
"atomizer":"n:喷雾器,雾化器",
"atomizing":"v:喷雾",
"atone":"v:赎罪,补偿,偿,偿还,抵,调解,赎回,将功赎罪,赎",
"atonement":"n:补偿,赎罪",
"atop":"p:顶上,在_顶上",
"atria":"n:心房",
"atrium":"n:心房,门廊,鼓室",
"atrocious":"a:穷凶极恶,狠毒;v:穷凶极恶",
"atrocities":"n:滔天大罪",
"atrocity":"n:暴行,残忍,残暴,暴虐,滔天大罪,凶恶",
"atrophy":"n:衰退,虚脱,退化,退缩,萎缩;v:虚脱,衰退,萎缩",
"atropine":"n:阿托品",
"attach":"v:相连,附着,附属,附上,附加,附,附带,扣留,加上,归于,相伴,指派,逮捕,缚,配属,拘留",
"attach to":"v:丽,归于,附",
"attached":"v:附属,附加",
"attachment":"n:设备,依恋,附件,爱慕,连结,附着,感情,连接,扣押,配件,逮捕,附着物,依附,附属物,备件;v:连接,附着,连结",
"attack":"v:攻击,进攻;n:主动",
"attain":"v:达到,获得,到达,达,造,遂",
"attainder":"n:耻辱",
"attainment":"n:达到,成就,造诣,获得,才能,素养,学识,建树,到达",
"attainments":"n:战绩,造诣,造就",
"attar":"n:香精",
"attempt":"n:企图,尝试;v:窥伺,诱惑",
"attend":"v:参加,出席,注意,照顾,照料,办,侍候,办理,料理,侍奉,看病,上班,服侍,陪,倾听,照拂,看管,随从,顾,留意,期待,上课,照看,赴,看护,随行,张罗,贯,凝神,伴随,伏侍,奉",
"attend to":"v:办,看管,办理,干,张罗,照拂,奉,料理,司,照看,照料,顾",
"attendance":"n:出席,照料,参加者,到场,看护,勤,出勤率",
"attendant":"n:服务员,随从,听差,从,随员,跟班,侍者,厅子,值班员",
"attendants":"n:左右,侍从,随从",
"attendee":"n:参加者",
"attention":"n:注意,注意力,关心,专心,殷勤,留心,姑息,礼貌,关照,注目;v:姑息",
"attentive":"a:专心,仔细,细心;n:周",
"attentively":"d:用心,凝神",
"attentiveness":"n:注意,专心",
"attenuate":"v:衰减,减弱",
"attenuation":"n:衰减,减弱,减小,减少;v:衰减,减小,稀释",
"attest":"v:证明,证实,表明",
"attestation":"n:宣誓,证明,证言,证实,证明书,证据;v:认证",
"attic":"n:阁楼,顶楼,楼阁",
"attica":"n:雅典",
"attire":"v:装扮,打扮;n:衣装",
"attitude":"n:态度,看法,姿态,姿势,风,身段",
"attitudinize":"v:装腔作势,装模作样,作势",
"attorney":"n:律师,代理人,代言人",
"attract":"v:吸引,引起,吸,招引,引诱,惹,引人注意,诱惑,诱人,招,抓,引",
"attracting":"a:逗人",
"attraction":"n:吸引力,吸引,引力,魅力,引;v:引诱",
"attractive":"a:诱人,招眼;v:引人入胜",
"attractive force":"n:吸引力,引力",
"attribute":"n:属性,特征;v:归于",
"attribution":"n:属性,归属",
"attributive":"n:修饰语,定语",
"attrition":"n:磨损,摩擦,消耗,磨灭",
"attune":"v:调",
"atwitter":"a:兴奋",
"aubergine":"n:茄,紫红色,茄子",
"auburn":"n:茶褐色,赭色,红褐色",
"auckland":"n:奥克兰",
"auction":"n:拍卖;v:拍卖",
"auction bridge":"n:拍卖",
"auction off":"v:拍卖",
"auctioneer":"v:拍卖;n:拍卖商",
"audacious":"a:大胆,胆大",
"audacity":"a:大胆,鲁莽,无礼,无耻;n:胆识,厚脸皮",
"audience":"n:观众,听众,读者,接见,倾听,听取",
"audio":"n:音响,伴音",
"audio amplifier":"n:扩音器",
"audit":"v:旁听,审计,查,查账,稽核,检查,清算;n:查账,决算",
"audition":"n:听;v:试唱",
"auditor":"n:审计员,旁听生",
"auditorium":"n:礼堂,大礼堂,观众席,讲堂,教室,大会堂",
"auditory":"n:礼堂,听众,讲堂;a:听觉",
"auditory nerve":"n:听神经",
"auditory ossicle":"n:听骨",
"auditory sense":"n:听觉",
"aug":"n:八月,8月",
"auger":"v:钻;n:钻",
"augite":"n:辉石",
"augment":"v:增加,扩大,加强,增大,加,扩编,增补,扩张,增长,扩充;n:增大,增加",
"augmentation":"n:增加,增大,扩大",
"augur":"v:预示,预言,预卜,预料,占卜",
"augury":"n:预兆,占卜,兆,谶,前兆,征兆",
"august":"n:八月,8月;a:可敬",
"augustinian":"n:信奉",
"augustness":"n:庄严,威严",
"aunt":"n:姑妈,姨妈,姑姑,姑母,姨母,伯母,阿姨,姑,婶婶,婶娘,婶母,大婶,舅母,姨,大妈,婶婆,婶子,姨儿,大姑儿,大姑娘,舅妈,大姨,妗,大姑,大婶儿,妗子,婶,叔母,大娘",
"auntie":"n:阿姨,姨妈,婶",
"aura":"n:气氛,先兆,气味,预感,氛围",
"aural":"a:伴音",
"aureole":"n:光环,日晕,晕,电晕,华盖",
"aureomycin":"n:金霉素",
"auricle":"n:心房,耳郭,外耳,耳廓,心耳",
"auricular appendage":"n:心耳",
"auricular point":"n:耳穴",
"aurora":"n:极光,曙光",
"auroral":"a:黎明",
"auscultate":"v:听诊",
"auscultation":"n:听诊;v:听诊",
"auspice":"n:占卜,前兆,主办,吉庆,预兆,赞助,吉祥,吉兆",
"auspices":"n:主办,赞助;v:主办,赞助",
"auspicious":"a:吉祥,吉利,瑞,繁荣昌盛,吉,嘉,祥,吉祥如意,吉庆",
"auspiciously":"d:幸而",
"auspiciousness":"n:吉祥,吉兆,禧",
"austen":"n:奥斯汀",
"austenitic manganese steel":"n:高锰钢",
"austere":"a:严峻,凛,懔",
"austerity":"n:紧缩,严格,朴素,严峻,严肃,冰霜,简朴",
"austin":"n:奥斯汀",
"australia":"n:澳洲",
"austria":"n:奥地利",
"austrian":"a:奥地利",
"authentic":"a:真实,真的,确,确凿,凿,真确",
"authentically":"d:确",
"authenticate":"v:证实,鉴定,认证",
"authentication":"n:确定,证明,鉴定,认证,确证;v:认证",
"authenticity":"n:真实性,可靠,确实,真伪,真实",
"author":"v:写,制作;n:笔者",
"authoress":"n:女作家",
"authorisation":"n:授权",
"authorise":"v:授权,批准",
"authoritarianism":"n:命令主义",
"authoritativeness":"n:权威",
"authorities":"n:官方,当局",
"authority":"n:当局,权威,权力,权,职权,权威性,根据,权限,大权,大家,威信,泰斗,说服力,柄,通,威权;r:大家",
"authorization":"n:授权,认可,委任,核准",
"authorize":"v:授权,批准,委托,认可,委任,允许,审定,授命",
"authorship":"n:来源",
"auto":"n:汽车",
"auto racing":"v:赛车",
"autobiography":"n:自传",
"autoclave":"n:高压锅",
"autocracy":"n:专制",
"autocrat":"n:独夫,独裁者",
"autocratic":"n:专制;a:专制",
"autograph":"n:亲笔,题名;v:签;a:署名",
"autograph album":"n:纪念册",
"automate":"v:自动化",
"automatic":"n:无意识;a:自动",
"automatic rifle":"n:自动步枪",
"automatically":"d:自然而然,无意识",
"automation":"n:自动化,自动;v:自动化",
"automatism":"n:自动,自动化",
"automatize":"v:自动化",
"automobile":"n:汽车,卧车",
"automobile race":"n:赛车",
"automotive vehicle":"n:机动车",
"autonomous":"a:自主",
"autonomously":"d:自主",
"autonomy":"n:自主权,自治,自治权,自主性,自律;v:自治,自律",
"autopsy":"n:检查;v:验尸",
"autotypy":"v:复制",
"autumn":"n:秋天,秋季,秋,晚年,成熟期,暮年,秋令",
"autumnal equinox":"n:秋分",
"auxiliary":"a:辅助,副,附属;n:援军,机帆船,能愿动词;v:附属,辅助",
"avail":"n:效用,收益,效力,利益;v:有利于,有助于",
"availability":"n:可用性,效力,利用率,有效",
"available":"a:现有",
"avails":"n:收益",
"avalanche":"n:雪崩;v:雪崩",
"avant-garde":"n:先锋,先驱",
"avarice":"n:贪婪,贪心;a:贪心",
"avaricious":"a:贪婪,饕;v:贪",
"avatar":"n:化身,体现",
"ave":"n:欢迎",
"avenge":"v:报仇,报复,复仇,雪恨",
"avenue":"n:途径,林荫道,马路,道路,大街,手段,大道,通道,通路,过道,走道",
"aver":"v:断言,证明,声称",
"average":"a:平均;n:海损;v:平均",
"averse":"a:讨厌",
"aversion":"n:厌恶,反感,嫌恶,排斥;v:转移",
"avert":"v:避免,避开,防止,免,免于,消弭,转移",
"avian":"a:鸟",
"aviation":"n:航空,飞机,飞行;a:航空",
"aviator":"n:飞行员",
"avidity":"n:饥渴,热望,强度,贪欲,贪婪",
"avocado":"n:鳄梨",
"avocation":"n:兼差,娱乐,副业,本职,消遣",
"avoid":"v:避免,避开,防止,回避,躲,避,躲避,逃避,免,规避,躲开,免除,辟,禁忌,逐出,避让,忌,废止,免于,免遭,撤销;n:禁忌",
"avoidance":"n:逃避,无效,空缺,回避,躲避,废止",
"avoirdupois":"n:肥胖,重量,体重",
"avouch":"v:保证,担保,声音,断言,主张",
"avow":"v:声明,承认,申明,声言,供认",
"avowal":"n:承认,供认,声明,宣布",
"await":"v:等待,等,有待,期待,待,等候,候,迎候,伺",
"awake":"v:醒来,醒,叫醒,觉醒,唤醒,激起,觉,启发,奋起,提醒;a:惺惺",
"awaken":"v:惊醒,唤醒,觉醒,叫醒,启,启迪,悟",
"awakening":"n:觉醒,醒,激励,启发",
"award":"n:奖;v:颁发,奖励",
"aware":"a:发觉,觉得,晓得",
"awareness":"n:觉悟,知道",
"away":"d:离开,走开,远,跑,继续,远离,立刻,完,到底,退场;v:跑",
"awe":"n:敬畏,畏惧;v:敬畏,震慑,畏惧;a:威严",
"awe-inspiring":"a:威风凛凛",
"awesomely":"d:赫然;a:赫然",
"awful":"d:极其;a:了不得",
"awfully":"d:非常,很,慌,不亦乐乎,不行,要命,坏",
"awfulness":"n:庄严,丑态,不快,威严",
"awhile":"d:暂时,片刻",
"awkward":"a:尴尬,笨手笨脚,笨,笨拙,别扭,别别扭扭,窘,拙笨,蠢笨,不得劲,粗笨,力巴,拙,讪,拘束,困窘,拙劣",
"awkwardness":"n:笨拙",
"awl":"n:锥子,锥",
"awn":"n:芒",
"awning":"n:船篷,篷,风帆,棚",
"awry":"d:歪,曲,斜,错误,扭",
"ax":"n:斧子;v:削减",
"axe":"n:斧头,斧子,斧,乐器,斤",
"axiom":"n:公理,原理,原则,格言,通则,至理名言,不刊之论",
"axis":"n:轴,轴线,轴心,光轴,枢纽",
"axle":"n:车轴,轴,轮轴,转轴,轴线",
"axletree":"n:车轴,轮轴",
"axolotl":"n:蝾螈",
"aye":"n:赞成票",
"azalea":"n:杜鹃花,杜鹃,映山红",
"azerbaijan":"n:阿塞拜疆",
"azimuth":"n:方位角,方位,航线,航向",
"azure":"a:蔚蓝;n:苍穹,天蓝色,苍天",
"b":"n:乙",
"baal":"n:神",
"baas":"v:老板",
"babble":"v:潺潺,泄漏,咿呀,絮絮叨叨,胡言乱语;n:胡话;a:絮絮叨叨",
"babbler":"n:画眉,鹛,碎嘴子",
"babe":"n:婴儿,婴孩,姑娘",
"babel":"n:混乱",
"baboon":"n:狒狒",
"babushka":"n:头巾",
"baby":"n:婴儿,婴孩,人,娃娃,宝贝,宝宝,姑娘,物,爱人,小人儿,婴,赤子,娃,娃子,微型",
"babyhood":"n:幼稚",
"babylon":"n:巴比伦",
"babylonian":"a:巴比伦;n:迦勒底人",
"babysitter":"n:姆",
"bacchanal":"n:酒徒,发酒疯",
"bacchic":"a:崇拜",
"baccy":"n:烟草",
"bach":"n:巴赫,单身汉",
"bachelor":"n:单身汉,光棍,独身汉,学士,独身,光棍儿",
"bachelor of science":"n:理学士",
"bachelorhood":"a:独身",
"bacillary dysentery":"n:菌痢",
"bacilli":"n:杆菌",
"bacillus":"n:细菌,杆菌",
"back":"v:支持;n:里面,体力,腰板,腰板儿,衬垫,脊,龙骨,节理,底座,腰杆子,山脊;d:回;a:阴,后边",
"back away":"v:退缩",
"back down":"v:放弃,退却",
"back of":"p:背后,后部",
"back out":"v:翻悔,食言",
"back room":"n:里屋,密室",
"back talk":"n:回嘴",
"back up":"v:拦蓄,撑腰,裱,裱糊,支持,作主,援助",
"backbite":"n:电木,胶木;a:谗;v:谗",
"backbiting":"n:诽谤",
"backboard":"n:底板",
"backbone":"n:骨气,脊梁骨,支柱,骨干,中坚,顶梁柱,脊骨,脊柱,种,书脊,主干,分水岭,基干,中枢,脊椎,主力,刚毅,构架,脊,主心骨,膂,基础",
"backchat":"n:回嘴,闲聊,反唇相讥",
"backdate":"v:回溯",
"backdrop":"n:背景,干扰,天幕;v:干扰",
"backer":"n:靠山,后台老板",
"backfire":"v:回火",
"background":"n:背景,出身,底,后台,幕后,地,经历,来历,背后,来头,底子,来路;v:配乐",
"backhand":"n:反手,反向",
"backhander":"n:回扣",
"backing":"n:支持,支援,腰杆子;v:依托,倚靠,加固,逆向;d:逆向",
"backlash":"n:后坐,后座,间隙,反冲,反击;v:后退",
"backlog":"v:积压;n:存货",
"backpedal":"v:后退,变卦",
"backrest":"n:靠背",
"backseat":"n:后座,后坐",
"backside":"n:屁股,背后,背部",
"backslide":"v:故态复萌,倒退,堕落,违背,退步;n:倒退",
"backstage":"d:幕后,后台;n:幕后,后台",
"backstairs":"a:秘密",
"backstop":"n:棘爪",
"backstroke":"v:回击;n:仰泳",
"backtrack":"v:退走,走回头路",
"backup":"n:支持,阻塞,备用;v:备用",
"backward":"d:倒,逆,逆向;a:落后,往后;n:往后",
"backwardness":"n:落后",
"backwards":"d:逆,倒",
"backwash":"n:浪涛,逆流,余波,反动,反响,回流,倒流;v:反响",
"backwater":"n:回水,逆流;v:回水",
"backyard":"n:后院",
"bacon":"n:咸肉,熏肉,得胜,奖品,腊肉,利益",
"bacteria":"n:细菌",
"bacteriology":"n:细菌学",
"bacteriophage":"n:噬菌体,抗菌素",
"bacterium":"n:细菌,菌",
"bad":"a:坏,差,不良,难,不善,干,恶,鬼,不妙,劣;n:不幸,倒霉;v:败",
"bad blood":"n:不和,仇恨",
"bad check":"n:空头支票",
"bad debt":"n:呆账,烂账,倒账",
"bad egg":"n:流氓",
"bad hat":"n:坏蛋",
"bad luck":"n:灾星,坎坷,恶运,晦气,冤",
"bad person":"n:蟊贼",
"badge":"n:徽章,标志,证章,象征,奖章,标记,徽,像章,胸章,章",
"badger":"v:纠缠,惹,欺负,撩;n:小贩,狗獾",
"badinage":"n:嘲弄,开玩笑",
"badlands":"n:不毛之地",
"badly":"d:厉害,严重,坏,非常,笨",
"badman":"n:亡命之徒",
"badminton":"n:羽毛球",
"badmouth":"v:贬低",
"badness":"n:坏,不良,恶劣,恶,严重",
"baffle":"v:难倒;n:隔膜,栅极",
"baffled":"v:莫名其妙",
"baffling":"v:阻遏",
"bag":"n:包,提包,袋子,袋,口袋,猎获;v:偷窃,吞没,击落,杀",
"bagatelle":"n:琐事,小曲儿",
"baggage":"n:行李,辎重,淫妇",
"baghdad":"n:巴格达",
"bagpipe":"n:风笛",
"bagpipes":"n:风笛",
"bahrain":"n:巴林",
"bai":"n:柏",
"bail":"n:保释;v:担保",
"bail out":"v:保释,跳伞",
"bailey":"n:贝利,城郭",
"bailiff":"n:法警,差役",
"bailiwick":"n:专长",
"bailout":"n:跳伞",
"bairn":"n:小孩",
"bait":"n:鱼饵,钓饵,诱饵;v:引诱,休息,欺负,作弄",
"bake":"v:烤,烘烤,烘,烘焙,烘干,焙,烧;n:焙,烤,烘",
"bakelite":"n:电木,胶木,酚醛塑料",
"baker":"n:烘炉",
"baking":"v:烘烤;n:烘烤",
"baking powder":"n:发粉,起子,发酵粉",
"baking soda":"n:小苏打",
"baksheesh":"n:小费,赏金,小帐,酒钱",
"balance":"n:平衡;v:对照,秤,对比,踌躇",
"balance of power":"n:势均力敌",
"balance sheet":"n:决算表",
"balance wheel":"n:摆轮",
"balanced":"a:均衡",
"balancing":"v:对消;a:均衡",
"balcony":"n:阳台,凉台,晾台,露台,楼台",
"bald":"a:秃顶,秃,光秃秃,兀;v:秃顶",
"bald eagle":"n:秃鹰",
"balderdash":"n:梦呓,胡言乱语,妄语",
"baldness":"n:秃顶,秃头,秃,露骨,脱发",
"baldric":"n:腰带",
"baldy":"n:秃子",
"bale":"n:包,痛苦,悲叹,灾害;v:抽水,打包",
"bale out":"v:抽水",
"baleen":"n:鲸须",
"balk":"n:挫折,失败,阻碍,田埂,障碍;v:避免,犹豫不决,打破,逃避,忽视",
"balkan":"n:巴尔干",
"ball":"n:球,舞会,皮球,棒球,滚珠,炮弹,面团,家伙,地球,玻璃球,圆球,钢珠,丸药,眼球,球儿,弹丸,丸子,星球,圆子,肉丸子,丸剂,毬,天体,丸;v:弹,狂欢",
"ball bearing":"n:滚珠轴承",
"ball cartridge":"n:实弹",
"ball game":"n:球,情况,形势",
"ball-shaped":"n:球状",
"ballad":"n:民谣,民歌,歌谣,谣,小调,叙事曲,快板儿,繇",
"balladry":"n:民谣",
"ballast":"n:镇流器,石碴,稳定",
"ballet":"n:芭蕾舞,芭蕾,舞剧",
"ballistic":"v:冲击;a:冲击",
"ballistic missile":"n:弹道导弹",
"balloon":"v:猛增,激增;n:气球",
"balloon flower":"n:桔梗",
"ballot":"n:投票;v:抽签",
"ballot box":"n:投票箱",
"ballpark":"n:球场",
"ballplayers":"n:球坛",
"ballpoint":"n:圆珠笔",
"ballroom":"n:舞厅,舞场,舞池,厅",
"ballroom dance":"n:交际舞",
"ballroom dancing":"n:交际舞",
"bally":"a:极,非常",
"ballyhoo":"n:宣传,大吹大擂,喧闹",
"balm":"n:香味,香油,止痛药,香脂,芳香,镇痛剂",
"balminess":"n:芳香",
"balmy":"a:煦",
"baloney":"n:屁话",
"balsa":"n:救生筏",
"balsam":"n:凤仙花,香脂,镇痛剂,金钱",
"baltic":"a:波罗的海",
"baltic sea":"n:波罗的海",
"baltimore":"n:巴尔的摩",
"baluster":"n:栏杆",
"balustrade":"n:栏杆,阑干,栏,扶手,槛",
"balzac":"n:巴尔扎克",
"bamako":"n:巴马科",
"bamboo":"n:竹子,竹竿,筠,毛竹,南竹,淡竹,篁,竹,竹材",
"bamboo curtain":"n:竹帘",
"bamboo palm":"n:棕竹",
"bamboo shoot":"n:竹笋,笋",
"bamboozle":"v:欺骗,骗,愚弄,哄,迷惑",
"ban":"n:禁令;v:诅咒,罢黜",
"banality":"n:平凡,平庸,陈腐,陈词滥调",
"banana":"n:香蕉,芭蕉",
"banana oil":"n:香蕉水,马屁精,伪善,花言巧语,圆滑",
"band":"n:乐队,带,频带;v:镶边,穿连裆裤",
"band together":"v:成群结队,穿连裆裤",
"bandage":"n:绷带;v:包扎",
"banded adder":"n:金环蛇",
"banded krait":"n:金环蛇",
"banding":"n:带状,条纹,传动带;v:传动带,捆扎",
"bandit":"n:土匪,匪徒,强盗,胡匪,恶棍,匪盗,盗贼,虎狼,寇,暴徒,匪",
"banditry":"n:匪患",
"bandits":"n:盗贼,草寇,盗匪",
"bandung":"n:万隆",
"bandwidth":"n:带宽",
"bandy":"v:交换,议论,传播,散播,谈论,互换",
"bandy about":"v:议论,散播",
"bandy legs":"v:罗圈腿",
"bane":"n:祸根,死,祸害,灾星,毁灭,孽种",
"bang":"n:刺激,服用,精力,冲击,猛冲,猛击,快感,刘海儿;v:轰,撞击,超过,毁坏,拍板,碰上,弄坏;d:轰然,哐啷,啪",
"bang up":"v:毁坏,弄坏",
"bangalore":"n:爆破筒",
"banger":"n:香肠,老爷车,爆竹",
"bangkok":"n:曼谷",
"bangladesh":"n:孟加拉国",
"bangle":"n:手镯,脚镯",
"bangui":"n:班吉",
"banian":"n:长袍,榕树",
"banish":"v:驱逐,消除,流放,排除,发配,充军,放逐,赶走,流,逐,驱遣",
"banishment":"n:流放,排除,充军,放逐,流刑,驱逐",
"banister":"n:栏杆,槛",
"banisters":"n:栏杆,扶手",
"banjul":"n:班珠尔",
"bank":"n:银行,河岸,堤岸,岸;v:倾斜,封火,依靠,封",
"bank gravel":"n:河卵石",
"bank loan":"n:融资",
"bank note":"n:银行券,票,票子,钞,纸币",
"bankbook":"n:存折",
"banker":"n:银行家,工作台,庄家,财东",
"banking":"n:金融,银行业,堤防,筑堤;v:筑堤",
"banknote":"n:钞票",
"banknotes":"n:纸币",
"bankroll":"n:资金",
"bankruptcy":"n:破产,倒闭,亏空,倒账",
"banner":"n:旗帜,横幅,旗,旗号,旗子,帜,军旗",
"banquet":"n:宴会,宴席,酒席;v:大吃大喝,宴请",
"banquette":"n:长凳",
"banshee":"n:妖精",
"bantam":"n:吉普车",
"banter":"v:打趣,戏谑,开玩笑,取笑,逗弄,逗,撩拨;n:开玩笑;a:谐谑",
"banyan":"n:菩提树,长袍,榕树",
"banzai":"n:万岁",
"baptise":"v:洗涤",
"baptism":"n:洗礼,命名,浸礼",
"baptize":"v:洗,洗涤,浸染",
"bar":"n:酒吧,酒吧间;v:不准,讨厌,制裁,阻挡;p:除",
"bar code":"n:条形码",
"bar fly":"p:酒鬼,酒徒",
"barb":"n:触须,毛刺,倒刺",
"barbados":"n:巴巴多斯",
"barbaric":"a:蒙昧,古拙",
"barbarism":"n:野蛮,暴虐,芜杂",
"barbarity":"n:暴虐,残忍,凶猛,粗野,兽性,芜杂",
"barbarous":"a:野蛮,残",
"barbecue":"v:烤,红烧;n:烤肉",
"barbel":"n:触须",
"barbell":"n:杠铃",
"barber":"n:理发师,理发匠,理发员",
"barbershop":"n:理发店",
"barbette":"n:炮座",
"barcelona":"n:巴塞罗那",
"bard":"n:诗人,作者",
"bare":"v:露出,敞开;a:光溜溜",
"barebacked":"d:赤膊;v:赤膊",
"barefoot":"a:赤足,赤脚;n:赤脚",
"barefooted":"d:跣;a:赤脚",
"bareheaded":"a:光头,免冠;v:免冠;n:光头",
"barely":"d:刚,仅,仅仅,公开,苟",
"bareness":"n:赤裸",
"barf":"v:呕吐",
"bargain":"v:讨价还价,谈判;n:事半功倍",
"bargainer":"n:卖主",
"bargaining":"v:交涉,讨价还价,契约,议价",
"bargains":"n:特价品",
"barge":"v:撞,打扰,打断,闯入;n:拖驳",
"barge in":"v:闯入,打断",
"barge pole":"n:篙",
"bargeman":"n:船员",
"baring":"v:开拓",
"baritone":"n:男中音",
"barium":"n:钡",
"bark":"v:叫;n:枪声;d:高声,汪汪",
"bark beetle":"n:蛀虫",
"barkeeper":"n:酒保",
"barker":"n:手枪",
"barking deer":"n:麂子",
"barley":"n:大麦,停战,麦子",
"barley candy":"n:麦芽糖",
"barmy":"a:发痴",
"barn":"n:谷仓,牲口棚,库房,仓,粮仓,厩,牛房,车库",
"barn grass":"n:稗子",
"barn owl":"n:鸱",
"barn swallow":"n:燕子",
"barnyard grass":"n:稗",
"barometer":"n:气压计,晴雨表,气压表,晴雨计",
"barometric pressure":"n:大气压,气压",
"baron":"n:男爵,贵族,男,富商",
"barony":"n:独立国,独立王国",
"barrack":"n:营房,营寨;v:嘲弄,喝倒彩",
"barracks":"n:兵营,工棚,营盘,老营,营,营房,军营",
"barracuda":"n:梭子鱼",
"barrage":"n:堰,遮断,拦河坝,倾泻,阻塞;v:阻塞,拦阻",
"barrel":"n:桶,枪管,许多,炮筒,圆筒,膛,卷筒",
"barren":"a:荒芜,荒,贫瘠,荒凉,空,寸草不生,瘠薄,硗薄,僻陋,瘦瘠,秃,光秃秃;v:空怀,寸草不生;n:不毛之地,荒地",
"barrette":"n:发夹",
"barricade":"n:街垒,路障,隔板;v:阻塞,遮住",
"barrier":"n:障碍,壁垒,障碍物,隔板,栅栏,关卡,埂,隔阂,关口,难关,栅,障,挡板,壁",
"barriers":"n:樊篱",
"barring":"p:除_之外,之外,除,除非;v:除外",
"barrio":"n:郊区,村镇,村庄",
"barrister":"n:律师",
"barroom":"n:酒吧间",
"barrow":"n:独轮车,丘陵,冢,担架,古墓,山,土丘,穴,鱼子,手推车",
"bars":"n:栅栏",
"bartender":"n:酒保",
"barter":"v:换;n:易货",
"barter away":"v:出卖",
"barycenter":"n:重心",
"baryon number":"n:质量数",
"basal metabolism":"n:基础代谢",
"basalt":"n:玄武岩",
"base":"n:基地,基础,基数,基,军事基地,底座,碱;a:猥鄙,贱,猥陋;v:托",
"base metal":"n:碱金属",
"baseball":"n:棒球,垒球",
"baseball game":"n:棒球",
"baseboard":"n:脚板,底板",
"baseless":"a:凭空",
"baseline":"n:基线,底线",
"basement":"n:地下室,底层,窨,地窨子",
"baseness":"n:卑鄙,恶劣,下贱",
"bases":"n:根据,基础",
"bash":"v:猛击,痛击;n:猛击,痛打",
"bashful":"a:腼腆,忸怩,羞答答,怕羞,羞,羞羞答答,羞人答答,羞涩",
"bashfully":"d:含羞",
"basic":"a:基本;n:根本,元",
"basic principle":"n:大法",
"basically":"d:基本上,基本,主要",
"basilica":"n:王宫,皇宫",
"basin":"n:盆地,盆,深度,容器,脸盆,面盆,流域,水系,水坑,盆子,船坞,骨盆",
"basis":"n:基础,根据,依据,基准,基,根基,根,本原",
"bask":"v:晒太阳,取暖,晒",
"basket":"n:篮子,篮,筐,笼子,菜篮,菜篮子,吊篮,笆篓,挑子,蒉,笼,篓,篓子,背篼,篼,箩",
"basket fern":"n:贯众",
"basketball":"n:篮球",
"basketful":"n:筐,工艺品",
"basketry":"n:笆",
"bass":"n:低音,男低音,鲈鱼",
"bass drum":"n:大鼓",
"bass horn":"n:大号",
"basset":"v:露头,露出;n:露头",
"bassinet":"n:摇篮",
"basso":"n:低音",
"basswood":"n:椴木,椴树",
"bast":"n:韧皮部",
"bastard":"n:杂种,坏蛋,混蛋,崽子,兔崽子,私生子,混账,劣货,代用品,坏东西;a:劣质",
"bastardize":"v:误用",
"bastardy":"n:私生子",
"baste":"v:痛打,痛骂,绷",
"baster":"n:混血儿",
"bastion":"n:堡垒",
"bat":"n:蝙蝠;v:投球,战斗,拍",
"batch":"n:批处理,批,批量,成批,间歇,茬,起,拨",
"batching":"v:配料,定量,计量;n:定量",
"bate":"v:抑制,减轻,压低,降低,削弱,减少,软化",
"bateau bridge":"n:浮桥",
"bath":"n:洗澡,浴缸,澡,澡盆,浴室;v:浸泡",
"bathe":"v:游泳,洗澡,洗;n:浴,游泳衣,洗澡",
"bathhouse":"n:澡堂",
"bathing":"n:游泳",
"bathing suit":"n:游泳衣",
"bathos":"n:陈腐",
"bathrobe":"n:浴衣,睡衣",
"bathroom":"n:浴室,厕,卫生间",
"bathroom tissue":"n:草纸",
"bathtub":"n:浴盆,澡盆,浴缸",
"bating":"n:软化;v:软化",
"batiste":"n:麻纱",
"batman":"n:勤务兵,马弁,马夫",
"baton":"n:指挥棒,警棍,接力棒,拍子",
"battalion":"n:营,部队,大队,大军,军队",
"batten":"n:木条,头部;v:压条",
"batter":"v:打,殴打,炮轰,打碎,猛击,磨损,炮击,攻击;n:倾斜度,斜坡,毁损,坡度",
"battering":"v:挤压,磨损;n:磨损",
"battering ram":"n:撞车",
"battery":"n:电池,电池组,炮台,殴打,一连串,组,炮位",
"batting":"n:击球,套子,打球,棉絮;v:套",
"batting average":"n:能力",
"battle":"n:战争,战役,斗争,胜利;v:斗争,战斗",
"battle cry":"n:呐喊,口号,标语",
"battle line":"n:前线",
"battle of wits":"n:斗智,唇枪舌剑",
"battle royal":"n:大战",
"battle sight":"n:表尺",
"battlefield":"n:战场,疆场,沙场,战地",
"battlefront":"n:战场,战线",
"battleground":"n:战场,沙场,战地",
"battlement":"n:雉堞,城垛,垛子",
"battlements":"n:垛,垛子",
"battleship":"n:战舰,战列舰",
"bauble":"n:玩具",
"baud rate":"n:波特率",
"baulk":"n:障碍,田埂,挫折",
"bauxite":"n:铝矾土,矾土,铝土矿,铁矾土",
"bavaria":"n:巴伐利亚",
"bavarian":"a:巴伐利亚",
"bawd":"n:妓女,鸨母",
"bawdy":"a:淫秽",
"bawl":"v:喊,骂,叫,叫卖,嚷嚷,咆哮;n:叫喊",
"bawl out":"v:骂",
"bay":"n:海湾,港湾,湾;v:咆哮",
"bay of bengal":"n:孟加拉湾",
"bay tree":"n:桂",
"bay window":"n:吊窗",
"bayonet":"n:刺刀,枪刺;v:刺杀",
"bazaar":"n:集市,市场,市集,小市,百货店,商场",
"bazooka":"n:火箭炮,火箭筒",
"bc":"n:公元前",
"be":"v:是,在,为,做,当,发生,作,产生,存在,则,成为,即,处于,举行,到达,系,属于,说是,来到,属,生存,伴随,乃是,乃,逗留,听任",
"be after":"v:寻找,追求",
"be born":"v:诞生,坠地,落生,落地,生于,生,诞",
"be full":"v:饫,饱",
"be on":"v:上映,开,自高自大",
"be quiet":"v:安静",
"be sick":"v:呕吐",
"be well":"v:舒服",
"beach":"n:海滩,沙滩,海滨;v:涂",
"beach wagon":"n:旅行车",
"beachhead":"n:滩头",
"beacon":"n:灯塔,明灯,觇标,信标,指南,标灯,导标,烽火,烽,烽烟,望楼,警标;v:鼓励,照亮",
"beacon fire":"n:燧,烽火",
"beacon light":"n:标灯,灯标",
"bead":"n:珠子,露珠,颗粒,水珠,数珠,垫圈,准星,泡沫,水泡,玻璃球,滴;v:瞄准,起泡",
"bead tree":"n:苦楝",
"beading":"n:起泡",
"beadle":"n:差役",
"beads":"n:念珠,数珠",
"beagle":"n:警察,密探,香肠",
"beak":"n:嘴,觜,先生,铁嘴",
"beaker":"n:烧杯,觚",
"beam":"n:梁,束,横梁,波束,杆;v:探测,眉开眼笑,发光,导航,播音,闪光",
"beam scale":"n:秤杆",
"beaming":"a:粲然;v:辐射",
"bean":"n:豌豆,豆,蚕豆,金币,头,子粒,小豆,硬币,子实,脑袋",
"bean curd":"n:豆腐,麻豆腐,腐",
"bean tree":"n:红豆",
"beanpole":"n:豆荚",
"beans":"n:豆,豆子,豆粒",
"beanstalk":"n:豆秸,豆萁",
"bear":"v:有,忍受,承受,生,受,负担,当,承担,结,容忍,带有,具有,显示,产生,忍耐,忍,记;n:卖方,肩;p:经;a:空头",
"bear away":"v:取得,夺得",
"bear cat":"n:硬汉,熊猫",
"bear down":"v:压服,努力",
"bear down on":"v:压服",
"bear down upon":"v:压服",
"bear in mind":"n:记,志,记住",
"bear off":"v:赢得",
"bear on":"v:系",
"bear out":"v:支持",
"bear up":"v:振作,支持,援助",
"bear upon":"v:依靠,根据",
"bear witness":"v:作证",
"bearable":"a:堪",
"beard":"n:胡子,胡须,须,络腮胡子,芒",
"bearer":"n:脚夫,担架,轿夫,来人,挑夫,载体,生产者,无记名,支座",
"bearers":"n:腰带",
"bearing":"n:轴承,方面,风度,关系,影响,举止,态度,方位,支座,仪态,气度,神态,仪表,风采,标记,航向,气宇,仪,忍耐,神宇,相,姿态,器宇,人品,忍受,结实,走向",
"bearings":"n:轴承",
"bearishness":"n:笨拙,粗鲁",
"beast":"n:野兽,动物,畜生,走兽,兽,慝,坏蛋,家畜,飞行器,衣冠禽兽",
"beast of burden":"n:力畜",
"beastliness":"n:残忍,贪食,污秽,凶恶,兽性,淫猥,粗暴",
"beastly":"d:非常",
"beasts":"n:兽类,牛马",
"beat":"v:打,打败,击败,揍,跳动,敲打,跳,鼓,敲,拍,赢,拍打,殴打,超过,胜过,败,战胜,压低,毒打,搅,吹,击退,打垮;n:鼓声,拍子",
"beat back":"v:反击,抗击",
"beat down":"v:压低,减价,压抑",
"beat out":"v:敲打,解决",
"beat up":"v:殴,殴打,毒打",
"beater":"n:锤,打浆机,搅拌器",
"beaters":"n:打手",
"beatify":"v:祝福",
"beating":"n:打,跳动,脉搏,鞭打,打浆,溃败,拍打;v:挫败,干扰,打斗",
"beau":"n:花花公子,情人,伴侣,爱人;a:美",
"beauteous":"a:隋",
"beautician":"n:美容师",
"beautification":"n:美化",
"beautiful":"a:美丽,漂亮,美,秀丽,美貌,美观,美妙,佳,婉丽,帅,绮丽,秀,奕;n:玉,锦绣",
"beautify":"v:美化,修饰,装饰,美",
"beauty":"n:美,美貌,美丽,美人,美景,美女,美感,妙处,佳丽,西施,丽人,娥眉,红粉,佳人",
"beauty parlor":"n:美容院",
"beauty salon":"n:美容院",
"beauty sleep":"n:小睡",
"beauty spot":"n:美景,痣,名胜",
"beauty treatment":"n:美容,化妆",
"beaver":"n:海狸,河狸,礼帽,胡须,海獭,孜孜不倦",
"becalm":"v:平静",
"because":"c:因为,因,由于,坐,盖,鉴于;p:鉴于;v:坐",
"because of":"p:由于,因,因为,以,由,基于",
"beck":"n:急流,点头,溪流",
"beckon":"v:招手,召唤,吸引,打手势,招呼,引诱,点头,招",
"become":"v:变,成为,成,变成,做,为,产生,适合,发生,作,下去,变为,发,适宜,遭遇,转为,适于",
"becoming":"n:适合,得体,生成,适应,转化;a:合适",
"bed":"n:床,层,花坛,铺,床铺;v:移苗",
"bed bug":"n:壁虱",
"bed check":"n:查铺",
"bed cover":"n:床单",
"bed down":"v:下陷",
"bed sheet":"n:单子,床单",
"bed-wetting":"n:尿床,遗尿症,夜尿症",
"bedaub":"v:涂抹,骂,涂",
"bedazzle":"v:困惑",
"bedazzlement":"n:眼花缭乱",
"bedbug":"n:壁虱,臭虫",
"bedchamber":"n:寝室,寝宫",
"bedclothes":"n:被褥,床单,铺盖",
"bedding":"n:层面,被褥,寝具,定植,卧具,基坑,衬垫,铺垫,褥垫,铺陈",
"bedeck":"v:装饰,修饰",
"bedevil":"v:纠缠,虐待,折磨,骗,迷惑",
"bedevilment":"n:苦恼,着魔,迷惑",
"bedfellow":"n:妻",
"bedizen":"v:装饰",
"bedlam":"n:疯人院,喧闹,精神病院",
"bedouin":"n:流浪者",
"bedpan":"n:便盆",
"bedrock":"n:基岩,基础,根底,最低点,磐石",
"bedroll":"n:铺盖卷",
"bedroom":"n:卧室,寝室,卧房",
"bedside":"n:床头",
"bedsore":"n:褥疮",
"bedspread":"n:床单,床罩",
"bedstead":"n:床架",
"bee":"n:蜜蜂,蜂,聚会",
"beech":"n:山毛榉,榉,柜",
"beef":"n:牛肉,牢骚;v:加强,告发",
"beef cattle":"n:菜牛",
"beef tallow":"n:牛油",
"beef up":"v:加强",
"beefeater":"n:饭桶,大力士",
"beefsteak":"n:牛排",
"beehive":"n:蜂巢,蜂房,蜂窝,星团,蜂窠,蜂箱",
"beeline":"n:捷径,直线;v:一直",
"beelzebub":"n:撒旦,恶魔",
"beep":"n:吉普车",
"beer":"n:啤酒,麦酒",
"beeswax":"n:黄蜡,白蜡",
"beet":"v:改进,减轻,改,修理,抵,悔,解,充;n:甜菜",
"beethoven":"n:贝多芬",
"beetle":"n:甲虫;v:赶紧,突出,伸出",
"beetling":"a:悬垂",
"beetroot":"n:甜菜",
"befall":"v:降临,发生,临到,临头,遭遇",
"befit":"v:合适,适宜,适合",
"befitting":"a:的当",
"befog":"v:迷惑",
"before":"d:以前;p:前面,临;n:先前,已往,以往,从前,之前,以前;c:之前",
"before long":"p:不久,快,曾几何时,不久以后;d:不久以后",
"beforehand":"d:预先,事先,提前;a:头里,早,提前,先行;n:事前,头里;v:提前,先行",
"befoul":"v:污蔑,中伤",
"befriend":"v:照顾,扶助,帮助,亲近,援助",
"befuddle":"v:蒙蔽,绕,淆乱,搅乱,迷惑",
"befuddled":"a:昏沉,昏乱;v:醉生梦死,昏沉",
"befuddlement":"a:迷惘",
"beg":"v:恳求,请,请求,乞求,求,乞讨,央求,回避,行乞,央告,恳请,讨,讨饭,丐,祈,乞食,讨乞,祷,求乞,要饭,谢绝,乞",
"beg off":"v:谢绝",
"beget":"v:生,引起,产生,招致",
"begetter":"n:父",
"beggar":"n:乞丐,叫花子,叫化子,穷人,乞儿,花子",
"beggar-ticks":"n:鬼针草",
"beggary":"n:贫民窟,赤贫",
"begin":"v:开始,起,始于,动手,开,着手,始,开头,开演,创始,开场,起步,创建,上手,徂,上来,兴",
"beginner":"n:初学者,鼻祖,生手",
"beginning":"n:开始,开端,起初,起源,起始,初,当初,发端,本原,肇端;v:端,伊始,创始",
"begone":"v:滚",
"begonia":"n:秋海棠",
"begrime":"v:沾污",
"begrudge":"v:吝惜,嫉妒,妒忌,拿捏",
"beguile":"v:欺骗,消磨,骗,欺诈,诱惑,解",
"beguilement":"n:欺骗",
"beguiler":"n:骗子",
"begum":"n:贵妇,公主",
"behalf":"n:维护,利益,方面",
"behave":"v:表现,行为,举止,行事,听话,开动,运转,举措,为人,做人;n:举措;a:听话",
"behavior":"n:行为,特性,举止,性能,状态,表现,行动,作用,举动,习性,品行,态度,活动,行事,行止,功效,脾气,所作所为,为人,行,操,动作,操行",
"behaviour":"n:举动,态度,行径,为人,性能,习性,状态,行,活动,动作,脾气,行止,作用,路道",
"behead":"v:斩首,开刀,杀头,斩,斩决",
"beheading":"v:斩首",
"behemoth":"n:庞然大物",
"behest":"n:遗志,指示,遗愿,命令",
"behind":"n:屁股;p:在_之后,操纵,在_后面,之后;d:落后,迟,过",
"behindhand":"a:过期,落后,迟延;d:迟,落后",
"behold":"v:看,看到,注视,观察,见,观",
"behoove":"v:应当",
"behove":"v:理应",
"beige":"n:米色",
"beijing":"n:北京,京",
"beijing dialect":"n:京腔",
"being":"n:生存,存在,性命,临时,实在,一时",
"beirut":"n:贝鲁特",
"belabor":"v:努力,骂,痛骂,痛打",
"belabour":"v:痛骂,痛打",
"belay":"v:停止",
"belch":"v:谈,发牢骚,打嗝儿,爆发,冒火,喷射;n:打嗝,饱嗝儿,喷射",
"belching":"v:嗳气",
"beleaguer":"v:围攻,包围,围困",
"belfry":"n:钟楼,头脑,塔楼",
"belgium":"n:比利时",
"belgrade":"n:贝尔格莱德",
"belie":"v:揭穿,伪装,违背",
"belief":"n:信仰,信念,信条,信心,教义,意见,信,信任",
"believe":"v:相信,认为,信,想,以为,信任,信奉,听信,确信,信赖,置信,奉,崇奉,凭信",
"believe in":"v:信仰,崇奉,信任,奉,信,恁,鲟鱼",
"believer":"n:信徒,徒,教徒,信士",
"belittle":"v:小看,贬低,轻视,佚,蔑,贬损,薄,贬抑,菲薄,小视;a:薄",
"bell":"n:钟声,门铃,钟,铃,贝尔,车铃;v:鸣,叫",
"bell captain":"n:领班",
"bell the cat":"v:挺身而出",
"bell tower":"n:钟楼",
"bellboy":"n:侍者",
"belle":"n:美女",
"belles-lettres":"n:纯文学",
"bellhop":"n:侍者",
"bellicose":"a:好斗,好战,黩武",
"bellicosity":"n:好战,好斗",
"belligerence":"n:交战",
"belligerent":"n:交战国",
"bellman":"n:更夫",
"bellow":"v:怒吼,咆哮,吼叫,吼,呼啸;n:吼声,咆哮",
"bellows":"n:波纹管,风箱,鼓风机",
"bellwether":"n:头羊",
"belly":"n:腹部,肚子,肚,肚皮,内部,贪心,子宫,胃,胃口,贝利,腹,食欲,肠胃",
"belly button":"n:肚脐眼,肚脐",
"belly laugh":"n:捧腹大笑",
"bellyache":"v:发牢骚,腹痛,哭诉;n:腹痛,牢骚",
"bellyful":"n:过多,过分,过量",
"bellying":"v:鼓鼓囊囊",
"belong":"v:属于,属,就,归属,附属",
"belong to":"v:属,归,归属,附属,就",
"belonging":"n:行李,附件,家属,财产",
"belongings":"n:财物,附件",
"beloved":"a:亲爱的,得人心,亲爱",
"below":"p:低于,下面;n:下方,下边,下头,下,下面,之下,以下;d:台下,底下,下头",
"belt":"n:腰带,带,皮带,地带,带子,裤带,保险带,抽打,传动带,刺激;v:环绕,痛打",
"belting":"n:抽打,传动带",
"beluga":"n:白鲸,白鲟",
"belying":"v:掩饰",
"bemoan":"v:悲叹,哀悼,哀叹,惋惜,痛惜",
"bemoaned":"a:惨然;v:惨然",
"ben":"n:本,内室,高地",
"bench":"n:长凳,工作台,凳子,长椅,台阶,架,椅,主教,条凳,议席,法院,阶段,座,苗床",
"bench mark":"n:规范,标准",
"bench warrant":"n:逮捕证",
"benchmark":"n:标准,基准",
"bend":"v:弯曲,弯,俯身,转向,系,折,服从,压弯;n:挠度,弓,容量,弯子,屈服,河曲,湾,接头,盘道,曲",
"bender":"n:狂饮",
"bending":"n:弯度,挠度;a:弯曲;v:挠度",
"bends":"n:盘道",
"beneath":"p:下面,底下,在_之下,在_下方,低于,在_下面;d:在下",
"benediction":"n:祝福,天恩",
"benefaction":"n:慈善,捐款,善事,功德,施舍,捐助",
"benefactor":"n:恩人,施主,恩公",
"benefice":"n:封地,采地",
"beneficence":"n:恩惠,泽,功德,捐款,救济品,慈善",
"beneficent":"a:行善",
"beneficial":"a:有益,有利,益",
"benefit":"n:好处,利益;v:创利,补,义赛,利于",
"benevolence":"n:仁慈,善心,慈悲,慈善,恩典,捐款,亲切,捐助,仁,仁爱,厚道",
"benevolent":"a:仁慈,慈善,慈悲,医术",
"bengal":"n:孟加拉",
"bengali":"a:孟加拉",
"benighted":"a:蒙昧,愚昧无知;v:愚昧无知",
"benign":"a:良性,仁慈",
"benign tumor":"n:良性肿瘤",
"benignant":"a:宽大为怀",
"benignity":"n:宽厚,温和,仁慈,亲切",
"benjamin":"n:宠儿",
"bent":"n:爱好;a:弯曲,弯",
"bent on":"n:热中",
"benumb":"v:冻僵,麻木,麻痹",
"benumbed":"a:麻木",
"benzene":"n:苯",
"benzene ring":"n:苯环",
"benzine":"n:挥发油,汽油",
"benzoic acid":"n:苯甲酸,安息香酸",
"bequeath":"v:遗赠,传,贻,遗,遗留",
"bequest":"n:遗产,遗赠,遗物",
"berate":"v:训斥,责骂,呵斥,谇",
"bereave":"v:丧失,失去",
"bereavement":"n:丧失,居丧",
"bereft":"a:失去",
"beret":"n:贝雷帽",
"berg":"n:冰山",
"beriberi":"n:脚气病,脚气",
"bering":"n:白令海",
"berkeley":"n:伯克利",
"berkelium":"n:锫",
"berkshire":"n:巴克夏猪",
"berlin":"n:柏林",
"berm":"n:小路,便道",
"bern":"n:伯尔尼",
"berry":"n:浆果,卵,树莓,子",
"berth":"n:床位;v:停靠,泊,容纳",
"beryl":"n:绿宝石",
"beryllium":"n:铍",
"beseech":"v:恳求,哀求,恳",
"beseem":"v:相称,合适",
"beset":"v:困扰,包围,困惑,嵌,扰,围困,围绕,攻,镶,袭",
"beside":"p:旁边,一边,在_旁,在_旁边,旁;n:旁,旁边",
"besides":"d:此外,而且,又,再说,更,还有,再者,并且,另外,同时;c:除此之外,再说,况且,并且,此外,再则,再者;p:除此而外,除去;n:之外,外;v:除外",
"besiege":"v:包围,围困,围攻,围,困,围击",
"besmear":"v:涂抹,中伤",
"besmirch":"v:丑化,染污",
"besom":"n:扫帚;v:扫",
"besot":"v:沉醉,糊涂",
"besotted":"v:痴迷",
"bespatter":"v:溅,诽谤",
"bespeak":"v:定,表明,证明,显示,预约,暗示,预定",
"bespoke":"v:要求,预约",
"best":"v:超过;d:最,最好;n:至上;a:最好",
"best friend":"n:至交",
"bestial":"a:兽",
"bestiality":"n:兽行,兽性,兽欲",
"bestir":"v:振作",
"bestir oneself":"v:振作,意气风发,孜孜不倦,发奋,振刷",
"bestow":"v:安置,授予,施与,用,锡,贮藏,给与,使用,赐,赉,予,赐予,赠,授,放置,丐,留宿,赏赐,施;n:锡",
"bestowal":"n:贮藏,赠品,赠与,给与;a:贮存",
"bestrew":"v:撒布,布满",
"bestride":"v:跨,骑,威慑,跨过,跨越,支配",
"bet":"v:打赌,赌;n:意见",
"beta vulgaris":"n:叶甜菜",
"betel nut":"n:槟榔",
"betel palm":"n:榔",
"bethink":"v:想起,想到,决心,铭记,考虑",
"bethlehem":"n:伯利恒",
"betide":"v:发生,预示,预兆",
"betimes":"d:及时,早,及早,即刻",
"betoken":"v:预示,表示,指示,主,表白",
"betray":"v:出卖,泄露,暴露,背叛,辜负,泄漏,流露,背弃,表现,露,叛变,密告,诱惑,陷害,卖,叛逃,叛离,负,叛卖,叛,玩弄",
"betrayal":"n:背叛,变节,玩弄;v:变节",
"betrayer":"n:叛徒,内奸,卖国贼",
"betroth":"v:聘",
"betrothal":"n:订婚,婚约,定亲",
"betrothed":"n:未婚夫",
"better":"v:改善;n:前辈;c:宁,宁可,宁愿;a:好过,强;d:以上",
"betterment":"n:改良,改善,增值,修缮,改正,改建",
"betting":"v:赌博,打赌",
"between":"p:之间,中间,比较,间,私下,其间,在_之间,在_中间;n:中间,其间,之间;d:中间,当中",
"betwixt":"p:模棱两可,在_之间,之间,中间,在_中间",
"bevel":"n:斜,斜角;v:倾斜,斜切,斜;a:斜",
"beverage":"n:饮料",
"bevy":"n:群",
"bewail":"v:悲叹,哀叹,哀悼,痛哭,哀,叹惜",
"bewailing":"v:哀",
"beware":"v:当心,注意,谨防",
"bewilder":"v:迷惑,淆惑,迷离扑朔,昏乱",
"bewildered":"a:糊涂,困惑,胡涂,糊里糊涂",
"bewildering":"a:怪,迷乱;v:迷离扑朔",
"bewilderment":"n:迷惑,慌张,狼狈,为难",
"bewitch":"v:迷惑,迷住,蛊惑,恼,迷,惑",
"bewitching":"a:迷人;v:引人入胜",
"bewitchment":"n:蛊惑,迷惑,妖术,魔力",
"beyond":"p:超出,超过,胜过;n:以远,外,以外,远处,之外,来世;d:以外,此外;v:除外",
"beyond control":"p:不可收拾",
"beyond doubt":"p:无疑,必定",
"beyond measure":"p:不可估量",
"bezel":"n:斜面",
"bhutan":"n:不丹",
"bi":"n:毕",
"bian":"n:卞",
"biao":"n:彪",
"bias":"n:偏见,偏压,偏,倾向,成见,斜线,偏执,偏流;v:倾斜,偏移;a:偏心",
"biased":"a:偏颇,偏心;v:倚",
"biasing":"v:偏压",
"bib":"n:围嘴,活塞;v:喝",
"bible":"n:圣经,经典,金科玉律",
"biblical":"a:圣经",
"bibliography":"n:书目,文献,目录学",
"bicarbonate":"n:小苏打",
"biceps":"n:筋力",
"bicker":"v:争吵,拌嘴,吵架,斗嘴,闹别扭,闪烁,口角,抬,抬杠,吵嘴,顶嘴;n:斗嘴,闪烁,摇晃,口角",
"bickering":"v:闹别扭",
"bicuspid":"n:前臼齿",
"bicycle":"n:自行车,脚踏车,单车,夹带",
"bicycle pump":"n:打气筒",
"bid":"v:叫,吩咐,投标,出价;n:提议,刑期",
"bid price":"n:开价,标价",
"biddable":"a:听话",
"bidder":"n:投标人,邀请",
"bidding":"n:吩咐,出价,邀请,公告,投标,命令",
"biddy":"n:鸡",
"bide":"v:经受,持续,等候,忍耐",
"bidet":"n:脚盆",
"biennial":"n:二年生植物",
"bier":"n:棺,灵榇,灵床,棺材,灵柩,灵",
"biff":"v:殴打,打",
"bifurcate":"v:分叉,分歧",
"bifurcation":"n:分歧,分枝,分叉;v:分叉",
"big":"a:大,有,巨大,庞大;n:大亨,马,巨子;d:夸大",
"big cheese":"n:大人物,大亨",
"big dipper":"n:北斗",
"big enchilada":"n:要人,要员",
"big money":"n:大钱",
"big shot":"n:头面人物,大亨",
"big stick":"n:大棒,云梯,威吓,实力,武力",
"big toe":"n:拇,将指,拇指",
"big tree":"n:大树",
"bigamy":"n:重婚,重婚罪;v:重婚",
"biggie":"n:要人,权贵,名人,大亨,伟人",
"bighead":"n:胖头鱼",
"bighearted":"a:坦荡",
"bight":"n:环形,海岸线,海湾,角落,曲线",
"bigness":"n:尺寸,重大,大,巨大,夸大,庞大,体积",
"bigot":"n:顽固派",
"bigoted":"a:顽固,左,偏执,古板,泥",
"bigotry":"n:偏执,固执,顽固,执拗",
"bigwig":"n:显贵,大亨,头面人物,权贵",
"bigwigs":"n:权贵",
"bijou":"n:宝石,珠宝",
"bike":"n:自行车,脚踏车,摩托车,窝",
"bikini":"n:比基尼",
"bilabial":"n:双唇音,唇音",
"bilateral":"n:双边;a:双边",
"bile":"n:胆汁,愤怒,乖戾,生气",
"bile acid":"n:胆酸",
"bile duct":"n:胆管",
"bilge":"n:船底,腹部;v:凸出",
"bilingualism":"n:双语",
"bilk":"v:骗,蒙骗,挫败,瞒,欺;n:骗子,赖账",
"bill":"n:比尔,账单,法案,议案,票,钞票,票据,招贴,纸币,支票,票子,单,单据,发票,汇票,传单,帽檐,发单,证券,海报,报单,单子,广告,岬角,诉状,戏单,账单子,招子,凭单,清单;v:填,接吻,宣布,填报",
"bill of fare":"n:菜单",
"bill of lading":"n:提单,提货单",
"billboard":"n:广告牌;v:宣传",
"billet":"n:职位,地位,钢坯",
"billfold":"n:皮夹子,钱夹",
"billhook":"n:砍刀",
"billiard ball":"n:台球",
"billiard room":"n:弹子房",
"billiard table":"n:台子",
"billiards":"n:台球,弹子",
"billing":"n:布告,演员表",
"billingsgate":"n:下流话",
"billion":"n:无数,兆",
"billionaire":"n:亿万富翁",
"billow":"n:巨浪,浪涛,波浪,浪;v:翻滚",
"billowing":"a:滚滚;v:潋滟",
"billows":"n:波澜,波涛,涛",
"billowy":"a:滔滔,波澜壮阔,滔天;n:汹涌",
"bills":"n:法案",
"billy":"n:棍棒,警棍,弟兄,瓦罐",
"bimbo":"n:妓女,流氓",
"bimetallic":"a:复本位制",
"bimetallism":"n:复本位制",
"bimonthly":"n:双月刊",
"bin":"n:垃圾箱,箱子,储藏室",
"binary":"n:二,复,双,二进位;a:双,复",
"binary star":"n:双星",
"binary system":"n:二进制",
"bind":"v:绑,约束,捆,束缚,装订,包扎,捆绑,粘合,扎,定,联结,订;n:带子,容量,藤,困境,蔓,葛",
"binder":"n:绳索,装订机,带子,割捆机,大量,绷带",
"binder board":"n:刨花板,纸板",
"binding":"n:装订,结合,绷带,连接,具结,捆绑,束缚;v:捆绑,结合,装订",
"binding energy":"n:结合能",
"bingo":"n:白兰地酒",
"binocular":"a:双目;n:双目",
"binomial":"n:二项式,双名",
"biochemistry":"n:生化",
"biographies":"n:列传",
"biography":"n:传记,传;v:传",
"biological clock":"n:生物钟",
"biological warfare":"n:细菌战,生物战",
"biological weapon":"n:生物武器",
"biology":"n:生物学,生态学",
"bionic":"a:仿生",
"bionics":"n:仿生学,仿生",
"biosphere":"n:生物圈,生物界",
"biotin":"n:维生素",
"birch":"n:白桦,桦树,桦木",
"bird":"n:鸟,鸟儿,飞机,飞行器,家伙,导弹,东西,伯德,姑娘,火箭,解雇,鸟雀,羽毛球,禽",
"bird dog":"v:歼击机",
"bird nest":"n:鸟巢",
"bird of passage":"n:候鸟",
"bird's nest":"n:鸟窝,鸟巢",
"birdbrain":"n:愚蠢",
"birdcage":"n:鸟笼",
"birdie":"n:小鸟",
"birds":"n:禽,走禽,鸟类,飞禽",
"birmingham":"n:伯明翰",
"birth":"n:出生,出身,诞生,血统,分娩,门第,起源,生产;v:出生",
"birth control":"n:节育,避孕",
"birthday":"n:生日,寿辰,诞辰,寿,生辰,千秋,诞",
"birthday cake":"n:寿桃",
"birthday present":"n:寿礼",
"birthday suit":"n:裸体",
"birthmark":"n:胎记,记,胎痣",
"birthplace":"n:出生地,发祥地,贯,故乡,籍",
"birthrate":"n:出生率",
"biscuit":"n:饼干,唱片",
"bise":"n:灾害",
"bisect":"v:平分,一分为二,剖面,对开,分叉,分开",
"bisection":"n:平分,折半",
"bisexual":"n:雌雄同体;a:两性",
"bishop":"n:主教,象",
"bison":"n:野牛",
"bisque":"n:黄褐色",
"bissau":"n:比绍",
"bissextile year":"n:闰年",
"bit":"n:位,一点儿,一些,位数,钻头,一会儿,数位,嚼子,片段,一转眼,凿子,刨刀,演奏;v:控制,抑制,约束",
"bit by bit":"a:一点一滴,渐渐",
"bitch":"n:狗;v:发牢骚,弄坏",
"bite":"n:咬,叮;v:受骗,辛辣,上当;a:辛辣,辣",
"biting":"a:尖刻,刺骨,刺痛,凄厉",
"biting midge":"n:蠓,小咬",
"bitter":"a:苦;n:苦味;d:非常",
"bitter end":"n:末端",
"bitterly":"d:剧烈,悲痛,苦,酷,痛;a:痛",
"bittern":"n:卤,卤水,盐卤",
"bitterness":"n:苦难,苦味,酷烈,悲哀,讽刺,苦水",
"bitumen":"n:沥青",
"bivalve":"n:牡蛎",
"bivouac":"v:露营,野营;n:野营,露营",
"biweekly":"n:半月刊,双周刊",
"bizarre":"a:离奇,奇异",
"bizarreness":"n:奇异,奇怪",
"blab":"v:泄漏,泄密,瞎说",
"blabbermouth":"n:碎嘴子",
"black":"n:黑,黑色,黑人;a:黑蒙蒙,黑茫茫;v:染污,抹杀",
"black bear":"n:狗熊,黑瞎子",
"black birch":"n:黑桦",
"black book":"n:黑名单",
"black box":"n:律师",
"black cat":"n:黑页岩",
"black death":"n:黑死病,鼠疫",
"black fox":"n:玄狐",
"black hand":"n:黑手党",
"black hole":"n:牢房,坍缩星,禁闭室",
"black knot":"n:死结",
"black lead":"n:笔铅,铅",
"black magic":"n:妖术,左道旁门",
"black nightshade":"n:龙葵",
"black out":"v:抹杀",
"black sea":"n:黑海",
"black sheep":"n:恶棍",
"black spot":"n:黑斑",
"black tea":"n:祁红",
"blackamoor":"n:黑人",
"blackball":"n:反对票;v:排斥",
"blackbird":"n:画眉",
"blackboard":"n:黑板",
"blackboard eraser":"n:板擦儿",
"blacken":"v:诽谤,中伤",
"blackened":"v:黑糊糊;a:黑糊糊",
"blackguard":"n:流氓,恶棍,无赖,浑蛋",
"blackleg":"n:骗子,工贼",
"blacklist":"n:黑名单",
"blackly":"d:暗,黑",
"blackmail":"v:敲诈,勒索,勒,诛求,讹赖,讹;n:敲诈",
"blackness":"n:黑暗,黑,黑色,墨黑,凶恶,阴郁,阴险",
"blackout":"n:断电,关灯,删除,停止,封锁;v:断电",
"blacksmith":"n:铁匠,铁工,锻工",
"bladder":"n:膀胱,胆,泡,脬,气球,球胆,囊,救生圈,水泡",
"blade":"n:叶片,刀刃,刀片,叶,刀,刀口,剑,刃,刃儿,刀锋,翼,冰袋,螺旋桨,锋刃,肩胛骨",
"blah":"n:胡扯",
"blame":"v:怪,责怪,责备;n:挑剔,责",
"blamed":"d:很",
"blameless":"v:无可非议;a:无可非议",
"blanch":"v:漂白",
"blandish":"v:讨好,奉承",
"blandishment":"n:奉承",
"blandishments":"n:花言巧语",
"blandness":"n:无精打采,和蔼",
"blank":"n:空白,空白处,空格,空虚;v:消失;a:空,空地",
"blank space":"n:空格,空白",
"blanket":"n:毯子,毛毯;v:掩盖,干扰,妨碍,遮掩",
"blanketing":"n:熄灭;v:抑止",
"blanking":"v:熄灭,间隔;n:间隔",
"blankly":"d:茫然,发呆",
"blankness":"n:空虚,茫然,单调,空白",
"blare":"v:叫,咆哮,怒号,吼;n:响声,吼叫,巨响",
"blarney":"n:奉承话,恭维话,甜言蜜语;v:拍马屁",
"blaspheme":"v:亵渎,中伤,侮慢,骂",
"blasphemy":"n:亵渎,咒骂",
"blast":"v:爆破;n:鼓风,牢骚,爆破,容量",
"blast off":"v:发射",
"blast wave":"n:冲击波",
"blasting":"v:过载,鼓风,放炮;n:过载",
"blat":"v:瞎说,叫",
"blatancy":"n:吵闹",
"blatant":"a:明目张胆",
"blatantly":"d:悍然",
"blather":"v:瞎扯,胡言乱语,乱说;n:胡说,废话",
"blaze":"n:幻景,火光,焰火,刻痕,爆发,昂扬,白斑,激发,闪光,光明;v:照耀,激动,宣扬,传播,宣布,发光,激昂",
"blazing":"a:炽烈,炽热,炎炎,炎热,烈日,眩目",
"blazing star":"n:慧心,彗星",
"blazon":"v:宣布,表彰,画,宣扬,夸示;n:表彰,宣扬",
"bleach":"v:脱色,漂;n:漂白",
"bleacher":"n:漂白剂",
"bleachers":"n:看台",
"bleaching":"n:漂白;v:脱色",
"bleaching powder":"n:漂白粉",
"bleak":"a:凄凉,萧瑟,萧条,惨淡,苍凉",
"blear":"v:蒙蔽",
"bleat":"v:叫,哀诉,哭诉;n:废话,哭诉,叫声",
"bleed":"v:出血,流血,放血,同情,悲痛,死,放,内出血,排放,渗出,添麻烦,渗水,受伤,放出,泄气,压榨,牟取",
"bleeder":"n:食客",
"bleeding":"v:放血,出血;n:放血,出血",
"blemish":"n:瑕疵,缺点,污点;v:玷污",
"blench":"v:回避,畏缩,退缩,无视",
"blend":"v:和,混合;n:混合色;a:杂",
"blend in":"v:交融,相称,混合",
"blender":"n:搅拌器,搅拌机,混合物",
"blending":"n:合成,折衷,混合,配料,混纺,融合;v:混纺,混合,融合;a:混纺",
"bless":"v:保佑,祝福,赐福,感谢,颂扬,祝,赞美,庇佑,净化,佑",
"blessed":"a:神圣;v:他妈的",
"blessedness":"n:幸福,祉,戬",
"blessing":"n:福,祝福,赐福,保佑,幸事,洪福,应允,纵容;v:赐福,祝福",
"blight":"v:损害,摧残,挫折,损伤,妨害;n:扼杀",
"blighter":"n:家伙,笨蛋,混蛋,流氓",
"blimp":"n:大块头",
"blind":"n:百叶窗;v:有眼无珠,欺瞒,遮掩,瞎眼;a:盲目,瞎",
"blind alley":"n:绝路,死路,绝境",
"blind date":"n:相亲",
"blind gut":"n:盲肠,肠梗阻",
"blind person":"n:盲人",
"blind side":"n:缝隙,弱点,死角",
"blind spot":"n:死区",
"blinder":"n:眼罩",
"blindfold":"v:蒙骗,迷惑;n:眼罩",
"blinding":"v:堵塞",
"blindly":"d:瞎,没头没脑,蛮干,一味",
"blindness":"n:失明,盲目,盲目性,愚昧,盲点,文盲",
"blinds":"n:百叶窗",
"blink":"v:眨,眨眼,闪烁,眨巴,无视;n:反光,瞬间,微光,一瞥,闪光",
"blinker":"n:护目镜,眼罩;v:蒙蔽",
"blinkers":"n:眼罩",
"blip":"n:记号,影像,标志,标记",
"bliss":"n:洪福,狂喜,满足,天福,天堂",
"blister":"v:痛斥,辱骂,烫伤,挖苦,责备;n:水疱,燎泡,气泡,水肿,砂眼",
"blither":"v:废话,空谈",
"blithering":"v:无以复加",
"blitz":"n:闪电战,闪击战",
"blizzard":"n:暴风雪,雪暴,暴风雨",
"bloat":"v:膨胀,熏制,胀,得意忘形;a:胀",
"blob":"v:污染,跳水;n:错误",
"bloc":"n:集团",
"block":"n:块;v:拦挡,障蔽,杜绝,阻挠",
"block diagram":"n:方框图,框图",
"block letter":"n:正体,楷体",
"block off":"n:挡住",
"block up":"n:封锁,堙,叉,滞,闭,堵,犁,隔断,阻塞,阏",
"blockade":"v:封锁;n:堵塞,阻碍",
"blockage":"n:堵塞,障碍,封锁,阻碍,阻断,阻滞,闭塞,阻塞;v:阻塞,堵塞,截止",
"blockhead":"n:蠢人,傻子,傻瓜,蠢货,草包,木头人,木头人儿,蠢材",
"blockhouse":"n:碉堡,堡垒,碉,掩体,木屋,炮楼,地堡",
"blocking":"v:堵塞,阻塞;a:闭塞",
"bloke":"n:家伙,首领,醉鬼,笨蛋,小子",
"blond":"a:白皙,淡黄",
"blood":"n:血,血液,鲜血,血统,流血,脾气,生命,牺牲,家族,血气,杀人,元气,家世,门第,活力,种族,兽欲,花花公子,杀戮,激怒",
"blood clam":"n:蚶子,毛蚶",
"blood corpuscle":"n:血球",
"blood feud":"n:仇杀",
"blood heat":"n:体温",
"blood line":"n:血统,世系",
"blood poisoning":"n:败血症",
"blood relation":"n:骨肉,血亲",
"blood test":"n:验血",
"bloodbath":"n:大屠杀,血洗",
"bloodhound":"n:猎狗,警犬,侦探",
"bloodily":"d:血淋淋",
"bloodiness":"n:残忍,残酷",
"bloodletting":"v:放血;n:放血",
"bloodline":"n:世系,血统",
"bloodlines":"n:血统",
"bloodshed":"n:流血,杀戮",
"bloodstain":"n:血迹,血痕,血污",
"bloodstone":"n:鸡血石",
"bloodsucker":"n:蛭,剥削者,吸血鬼,水蛭",
"bloodsucking":"v:嗜血;a:嗜血",
"bloodthirsty":"a:嗜血,嗜杀成性;v:嗜杀成性,嗜血",
"bloody":"a:血腥,血淋淋,血糊糊,血丝乎拉;v:血污,血洗;d:太",
"bloom":"n:花;v:兴旺,发亮",
"bloomer":"n:成年人,失败",
"blooming":"v:盛开",
"blooper":"n:差错",
"blossom":"v:开花,兴旺,长成,繁荣,茂盛,绽放,放;n:初期",
"blot":"v:遮住;n:耻辱",
"blot out":"v:抹杀,灭,遮住",
"blotch":"n:斑点,疙瘩,斑,白斑病,污点,白斑",
"blotter":"n:吸墨纸,流水账",
"blouse":"n:衬衫,上身",
"blow":"v:风,吹;n:殴打",
"blow a fuse":"v:七窍生烟",
"blow off":"v:排污,直言,放出,排放,发泄",
"blow out":"v:弹出",
"blow over":"v:吹散,平息",
"blow up":"v:充气,炸掉,爆发,勃然大怒,炸,炸裂",
"blower":"n:鼓风机,风扇,吹风机,风箱",
"blowhole":"n:气泡,砂眼",
"blowing":"v:漏气,着火,吹塑",
"blowlamp":"n:喷灯",
"blown":"v:漏气",
"blowout":"n:爆破,爆发,熄火,熔解,爆裂,井喷;v:爆裂",
"blowpipe":"n:吹管,气割",
"blowtorch":"n:喷灯",
"blowup":"n:勃然大怒,破裂,放大,爆炸,发作",
"blubber":"n:鲸油,水母,哭闹,哭泣;v:啼",
"bludgeon":"v:强迫,威胁;n:棍棒",
"blue":"n:蓝色;a:忧闷;v:烧蓝,浪费",
"blue blood":"n:贵族,名门",
"blue chip":"n:热门货",
"blue copperas":"n:蓝矾,硫酸铜",
"blue devils":"n:忧郁,沮丧",
"blue funk":"n:沮丧,为难",
"blue sky":"n:蓝天,碧空,青天",
"blue vitriol":"n:硫酸铜,胆矾,蓝矾",
"blue-black":"a:深蓝",
"blue-chip":"a:热门货",
"blue-green algae":"n:蓝藻",
"blue-pencil":"v:否决",
"bluebeard":"n:莸",
"blueberry":"n:越橘",
"bluebonnet":"n:矢车菊",
"bluebottle":"n:矢车菊",
"bluejacket":"n:水兵,水手",
"blueness":"n:蓝色",
"blueprint":"n:蓝图,晒图,原本;v:晒,构想",
"bluff":"v:虚张声势;n:骗子",
"bluffer":"n:骗子",
"bluffness":"n:陡壁",
"bluing":"n:发蓝",
"bluish green":"n:碧,翠绿",
"blunder":"n:疏忽,故障,失策,娄子,过失;v:蹒跚",
"blunt":"a:钝,率直,秃,直截了当;v:戳,直言不讳,挫伤,减弱,麻痹",
"bluntness":"n:钝",
"blur":"v:混淆,污损;n:污迹,污点",
"blurb":"v:吹捧",
"blurred":"a:迷离,迷糊,迷蒙;v:迷糊",
"blurt":"v:脱口而出",
"blurt out":"v:随口,脱口而出",
"blush":"v:脸红;n:观点,一瞥,红色,红潮,红脸",
"blusher":"n:红色,胭脂",
"bluster":"v:咆哮;n:气焰,恫吓",
"boa":"n:蟒蛇,蚺蛇,蚺",
"boa constrictor":"n:蟒蛇",
"boar":"n:野猪",
"board":"n:董事会,板,木板,委员会;v:寄养,坐",
"board game":"n:棋",
"board meeting":"n:理事会",
"board of directors":"n:董事会,董事长",
"board of trustees":"n:董事会,董事长",
"boarder":"n:寄宿生,乘客",
"boarding":"n:搭伙,木板,隔板;v:定形",
"boarding house":"n:公寓",
"boardroom":"n:会议室",
"boast":"v:夸耀,自夸,吹嘘,夸口,吹,吹牛,夸;n:夸,自负,吹牛",
"boastful":"a:夸诞;v:虚夸",
"boat":"n:船;v:乘船",
"boat train":"n:船队",
"boater":"n:船员,船民,船工",
"boating":"v:划船,乘船",
"boatman":"n:船夫,船户,船家,舟子,艄公,船工,船员,船老大,船民",
"bob":"n:短发;v:摆动,剪短,浮动,敲,卷土重来",
"bob up":"v:卷土重来",
"bobbin":"n:线轴儿,筒子,线轴",
"bobble":"v:失,失误",
"bobbles":"n:绒球",
"bobby":"n:警察",
"bobby pin":"n:发夹",
"bobsled":"n:雪橇",
"bobsleigh":"n:雪橇;v:雪橇",
"bobtail":"n:晚礼服",
"bock beer":"n:黑啤酒",
"bode":"v:预示,预兆,预报",
"bodega":"n:酒店,酒窖",
"bodhisattva":"n:佛教,菩萨",
"bodily":"d:整体,亲身,自己,全部,一切;a:身体",
"boding":"n:预兆,凶兆,前兆",
"bodkin":"n:刺针,锥子",
"body":"n:身体,物体,身子,天体,团体,部分,体,躯体,身躯,肉体,机构,身,正文,主体,躯干,本体,机关,尸首,躯壳,实质,身板,车身,外壳,体躯,形体,床身,队,稠度;v:体现,接地,实现;a:立体",
"body guard":"n:亲兵,警卫员,保镖,卫兵",
"body louse":"n:体虱,虱,虱子",
"body odor":"n:体臭,腋臭,体味,狐臭,狐臊,汗臭",
"body temperature":"n:体温",
"body type":"n:体型",
"bodyguard":"n:保镖,警卫,卫兵,卫士,马弁",
"bodywork":"n:车身,车体",
"boffin":"n:研究员",
"bog":"n:沼泽;v:停滞不前,停滞",
"bog down":"v:停滞不前,停滞",
"bogey":"n:怪物,飞碟,妖魔,鬼怪,妖怪",
"bogeyman":"n:魔鬼",
"boggle":"v:犹豫,搪塞,踌躇,退缩,畏缩不前;n:吃惊,搪塞,退缩,犹豫",
"bogota":"n:波哥大",
"bogus":"a:伪,伪造",
"bohemian":"n:吉卜赛人,流浪者",
"bohemianism":"n:放荡不羁",
"boil":"v:煮,沸腾,开,煮沸,汹涌;n:脓肿,煮沸,疖子",
"boil over":"v:沸腾",
"boiler":"n:锅炉,煲,釜,锅",
"boiling":"v:滚,鼎沸,煮沸,沸腾;n:滚,沸腾,煮沸;a:鼎沸,滚沸;d:非常",
"boisterous":"a:热热闹闹,闹哄哄,哄然,热闹",
"boisterously":"d:哄然",
"bold":"a:大胆,胆大,悍,苍劲,刚劲;n:黑体;v:敢",
"boldface":"n:黑体",
"boldly":"d:冒",
"boldness":"n:大胆,魄力,勇敢,狂放,冒失,显著,胆量,厚脸皮",
"bole":"n:树干,伯乐",
"bolivia":"n:玻利维亚",
"boll":"n:铃",
"bolster":"v:支撑,撑腰;n:枕,衬垫",
"bolster up":"v:撑腰",
"bolt":"v:退出;n:枪机;d:突然",
"bolt out":"v:脱口而出",
"bolt-hole":"n:狡兔三窟",
"bolting":"v:抽薹,筛分",
"bolus":"n:丸,丸子",
"bomb":"v:投弹;n:胡须,蛋",
"bombard":"v:轰击,炮轰,轰炸,开炮,攻击,轰,炮击,痛斥,痛骂,质问",
"bombardier":"n:炮手",
"bombardment":"n:轰炸,轰击,炮击;v:轰炸,照射,轰击",
"bombast":"n:豪言壮语",
"bombastic":"v:虚夸;a:虚夸",
"bombay":"n:孟买",
"bomber":"n:轰炸机,爆破手",
"bombing":"v:轰炸,投弹",
"bombshell":"n:炮弹,炸弹",
"bon voyage":"n:一帆风顺,一路平安",
"bonanza":"n:摇钱树,发财,富源",
"bonbon":"n:糖果,夹心糖",
"bond":"n:债券,键,证券;v:粘附,粘着,连结",
"bond servant":"n:奴隶",
"bondage":"n:束缚,劳役,监禁,奴役,屈从",
"bonding":"v:粘合,接合;a:结合",
"bondman":"n:奴隶",
"bonds":"n:牢笼",
"bondsman":"n:奴隶,保证人,保人",
"bone":"n:骨头,骨,骨骼,骨架,遗体,争端;v:偷",
"bone black":"n:骨炭",
"bone char":"n:骨灰",
"bonehead":"n:傻瓜,笨蛋,傻子,蠢货",
"bonfire":"n:篝火,营火",
"bonhomie":"n:和蔼,敦厚",
"boniness":"n:瘦骨嶙峋",
"bonk":"v:做爱;n:做爱",
"bonn":"n:波恩",
"bonnet":"n:女帽,罩子",
"bonnie":"a:好",
"bonny":"a:好",
"bonsai":"n:盆景",
"bonus":"n:奖金,红利,花红,红,赢利",
"bony":"a:瘦,干瘦,柴;n:柴",
"bony fish":"n:硬骨鱼",
"boo":"v:喝倒彩,嘘,起哄;n:起哄,大麻;i:嘘",
"boo-boo":"n:擦伤,轻伤",
"boob":"n:蠢人,笨蛋,蠢材,乳房",
"booby":"n:呆子,鲣鸟,蠢材,傻瓜",
"booby hatch":"n:疯人院,精神病院",
"booby trap":"n:陷阱,阴谋",
"boohoo":"n:号哭,哭闹;v:哭闹",
"booing":"v:倒好儿,倒彩;n:倒彩,倒好儿",
"book":"n:书,本,书籍;v:登载",
"book binding":"n:装订",
"book jacket":"n:书皮",
"book up":"v:预定",
"bookbinding":"v:装订;n:装订",
"bookcase":"n:书柜,书橱,书箱",
"booking":"n:预定,预约,售票,挂号,记账,登记",
"booking agent":"n:经纪人",
"booking clerk":"n:货物",
"bookish":"a:书呆子;n:书呆子",
"bookkeeper":"n:会计,簿记员",
"bookkeeping":"n:记账,簿记",
"booklet":"n:小册子;v:折",
"bookmaking":"n:著作",
"bookmark":"n:书签",
"books":"n:经籍,图书,书籍",
"bookseller":"n:书商",
"bookshelf":"n:书架,书橱",
"bookshelves":"n:书架",
"bookshop":"n:书店,书肆,书坊",
"bookstall":"n:书摊,书亭,书店",
"bookstore":"n:书店",
"bookwork":"n:书痴",
"bookworm":"n:书呆子,蠹鱼,衣鱼",
"boom":"n:繁荣,景气,暴涨;v:兴旺,鸣叫;a:景气,高涨,兴旺",
"boomer":"n:巨浪",
"boomerang":"v:自食其果",
"booming":"v:繁荣;a:繁荣",
"boon":"n:恩赐,福利,恩惠,恳求,照顾,恩典",
"boondocks":"n:荒野",
"boor":"n:粗人,农民,乡下人,莽汉",
"boorish":"a:村,粗犷,粗鲁,粗野,蛮,村野,干",
"boost":"v:增加,促进,增强,提高,助,举起,标榜,吹捧,升,升压,推,支援,吹嘘,放大;n:增加,提高,吹捧,加速器,帮助,促进,升,宣传",
"boost up":"v:吹嘘",
"booster":"n:加速器,助推器,放大器",
"boosting":"v:加速,升压",
"boot":"n:靴子,靴,愉快;v:引导,穿,孕穗",
"boot out":"v:解雇",
"booth":"n:摊子,货摊,棚,摊,售货棚,售货摊,投票站,售货亭,窝棚",
"booting":"v:孕穗",
"bootlegger":"n:走私者",
"boots":"n:靴子",
"bootstrap":"v:引导",
"booty":"n:赃物,战利品,缴获,贼赃,赚头,奖品,赃",
"booze":"n:酒,豪饮;v:痛饮,饮酒,贪杯",
"bop":"v:打,打击;n:爵士乐",
"boracic acid":"n:硼酸",
"borax":"n:硼砂,月石",
"bordeaux mixture":"n:波尔多液",
"bordello":"n:妓院",
"border":"n:边界,边境;v:接近,镶,近似",
"border district":"n:边地",
"border on":"n:濒于,滨,搭界,交界,接壤,近似,滨临,濒,接近,毗邻",
"borderland":"n:边地,裔,边疆",
"borderline":"n:界线,国界,边界;a:边缘",
"borders":"n:疆界",
"bore":"n:深井,怒潮,枪膛;v:挖,钻孔,穿,烦扰,打孔,开凿",
"bore bit":"v:钻头",
"bore-hole":"n:钻孔",
"boreas":"n:北风",
"bored":"a:无聊;v:无聊",
"boredom":"n:厌烦,无聊,厌倦,讨厌",
"borehole":"n:炮眼,钻井,钻孔;v:钻孔",
"borer":"n:蛀虫,蛀,钻头,蛀心虫,钻工,钻心虫,钎,镗床,凿岩机,钻机",
"boring":"n:穿孔,钻孔;a:呆板,枯;v:钻孔",
"born":"a:天生;v:生;d:生来",
"borneo":"n:婆罗洲",
"boron":"n:硼",
"borough":"n:区,镇,城,市",
"borrow":"v:借,借用,藉,挪借,假,举债;n:借,借用,博罗,抵押",
"borrowing":"n:借,借用",
"bosh":"n:胡说,废话,空话;v:戏弄",
"bosom":"n:胸怀,胸,怀抱,乳房,胸部,内部,胸膛,内心,中间,襟怀,里面,心胸,当中,怀,里程碑;v:搂抱,隐匿,怀抱",
"boss":"n:老板,上司,头儿,经理;v:统率,支配",
"bossing":"v:肿块;n:肿块",
"bossy":"a:跋扈",
"boston":"n:波士顿",
"boston ivy":"n:爬墙虎",
"bostonian":"a:波士顿",
"bot":"n:马蝇",
"botanical garden":"n:植物园",
"botany":"n:植物学,植物",
"botch":"n:瘤,笨活;v:修补",
"both":"d:并且,皆,都,兼;a:两,双方;r:双方,二者;n:双",
"bother":"v:打扰,烦恼,麻烦,烦,操心,困扰;n:烦扰,操心,吵闹,累赘;a:操神,烦",
"botheration":"n:麻烦",
"bothersome":"a:伤脑筋",
"botswana":"n:博茨瓦纳",
"bottle":"n:瓶子,瓶;v:抑制,隐藏",
"bottle opener":"n:开瓶器,起子",
"bottle up":"v:抑制,隐藏",
"bottled":"a:瓶装;v:瓶装",
"bottleneck":"n:瓶颈;v:阻碍,限制",
"bottling":"v:灌注",
"bottom":"n:海底,船底,底,底层,底部,湖底,最低点,臀部,根据,屁股,水底,船体,下边,根源,下端,基础,底子,精力,持久力,船舶,地基,谷,末端,椅垫,货船,残渣,末尾,睡裤,洼地,尽头;v:打底",
"bottom line":"n:底牌,底线",
"bottoming":"v:闭塞,闭锁,截止,打底",
"bottomless":"a:万丈深渊",
"boudoir":"n:闺房,深闺,阁,闺,闺阁",
"bouffant":"a:鼓胀",
"bough":"n:树枝,绞刑架",
"bought":"v:曲线",
"bouillon":"n:肉汤",
"boulder":"n:卵石,盘石",
"boulevard":"n:大街,林荫道,大道,干道",
"bounce":"v:跳,蹦,弹回;n:猛击;d:突然,猛然",
"bounce back":"v:卷土重来,回声",
"bouncer":"n:大话,谎话,巨人",
"bound":"n:范围,界限;v:约束,邻接,纵步,弹起,弹跳;a:合订,准备,约束,捆缚",
"boundaries":"n:疆界",
"boundary":"n:边界,分界线,边,界面,范围,界限,边线,表面,界,线,疆界,范,际,境,疆,边际,境界,野,垠,分野,接界;a:野",
"boundary line":"n:鸿沟",
"boundless":"a:无限,无边,无垠,无边无际,无穷,无穷无尽,漫漫,漫无边际,无量,无疆,无涯,无际,寥廓;v:无限,无量,无穷无尽;n:汪洋",
"bounds":"n:界限,头;v:限",
"bountiful":"a:富饶",
"bounty":"n:慷慨,赏金,雨露,恩惠,宽大,博爱,津贴,奖金,施舍",
"bouquet":"n:芳香,花束,恭维话,簇,香",
"bourgeois":"n:资产阶级,业主,店主,有产者,商人",
"bourgeoisie":"n:资产阶级,中产阶级",
"bout":"n:发作,回合;v:发作",
"bow":"v:鞠躬;n:弧,福;a:低头,点头,鞠躬",
"bow and arrow":"n:弓箭",
"bow out":"v:停止",
"bowdlerize":"v:删改",
"bowel":"n:肠,内部,内脏,同情",
"bowels":"n:肠,心肠,内部",
"bower":"n:闺房,亭子,卧室;v:荫蔽",
"bowie":"n:猎刀",
"bowing":"v:屈服",
"bowl":"n:碗,盆;v:击倒,打倒,运送,完成",
"bowl over":"v:击倒",
"bowleg":"n:罗圈,罗圈腿",
"bowlegged":"n:罗圈腿;a:罗圈腿",
"bowler":"n:投手",
"bowling":"n:投球,地滚球,保龄球",
"bowstring":"n:绞索,鹏,弦;v:勒死,绞死",
"bowwow":"i:汪汪,毁灭",
"box":"n:箱子,盒子;v:打拳,隔开,囚禁,分隔",
"box in":"v:囚禁",
"box office":"n:票房,售票处",
"box seat":"n:包厢",
"box up":"v:装箱",
"boxcar":"n:棚车,闷罐车,闷子车",
"boxer":"n:拳击手,拳师,义和团",
"boxing":"n:打拳,拳,拳术,拳击",
"boy":"n:男孩,小伙子,儿子,男,少年,小子,青年,服务员,勤杂人员,竖子,仆人,男子,情人,童子",
"boy scout":"n:童子军",
"boycott":"v:抵制",
"boyfriend":"n:男朋友",
"boyishness":"n:孩子气,幼稚",
"boys":"n:哥儿",
"bozo":"n:家伙",
"bra":"n:乳罩,文胸,奶罩",
"brace":"v:振作,支撑;n:支架,支撑,支柱",
"brace up":"v:提起,振,抖搂",
"bracelet":"n:手镯,镯,手铐,镯子,钏",
"bracer":"n:兴奋剂,带",
"braces":"n:背带,括弧",
"bracing":"n:刺激,支柱,背带",
"bracken":"n:羊齿",
"bracket":"n:括号,等级,类别,悬臂,座,斗拱,同类项,支架,阶层,夹子",
"bracketing":"v:划界",
"brackets":"n:括弧,括号",
"bract":"n:托叶,苞",
"brad":"n:销钉",
"brae":"n:山坡,山区,斜坡,山腰",
"brag":"v:吹牛,吹,夸口,自夸,说大话,吹嘘,自诩,吹擂,夸海口,自大;n:牛皮,自大,自夸,大话",
"bragg":"n:布拉格",
"braggadocio":"n:吹牛,夸口;v:吹牛",
"bragger":"n:吹牛",
"bragging":"n:牛皮,大话;v:大话",
"brahmanism":"n:婆罗门教",
"braid":"v:编织,编结;n:发辫,辫,辫绳",
"braiding":"n:编结",
"braille":"n:盲文,盲字",
"brain":"n:头脑,脑,大脑,脑子,脑海,智慧,智力,智囊,聪明人,脑际,智能,脑髓,脑瓜,脑力,脑儿,心劲",
"brain drain":"n:人才外流",
"brain stem":"n:脑干",
"brain truster":"n:参谋",
"brain tumor":"n:脑瘤",
"brain wave":"n:灵感,脑电波,兴会,灵机",
"brain-teaser":"n:难题",
"brainpower":"n:智力,智囊",
"brains":"n:脑浆,脑髓,脑筋,脑,脑汁,头脑,脑子,脑力",
"brainstorm":"v:灵机一动,思潮澎湃,思潮起伏",
"brainwave":"n:灵机",
"braise":"v:焖,烩,扒;n:煤尘",
"brake":"n:灌木丛;v:煞",
"brake shoe":"n:闸皮",
"braking":"v:制动",
"bramble":"n:荆棘",
"brambles":"n:荆棘",
"bran":"n:糠,麸皮,麸子",
"branch":"n:树枝,分支,分行,枝条,枝,部门,转移,分店,支流,分部;v:分流",
"branch out":"v:横生枝节",
"branch water":"n:清水",
"branched chain":"n:支链",
"branching":"n:支流,分流,分支,支脉,转移,支路,支线;v:分叉,支路",
"brand":"n:牌子,商标,烙印,牌号;v:烙",
"brand-new":"a:崭新",
"branding":"n:烙印,标记;v:标记",
"branding iron":"n:烙印,烙铁",
"brandish":"v:挥舞,舞;n:挥舞",
"brands":"n:标志",
"brandy":"n:白兰地,白兰地酒",
"brandy nose":"n:酒渣鼻,酒糟鼻",
"brash":"n:阵雨,骤雨,瓦砾,碎片",
"brasilia":"n:巴西利亚",
"brass":"n:黄铜;a:黄铜;v:付",
"brass hat":"n:大亨",
"brassiere":"n:乳罩,奶罩",
"brassiness":"n:厚颜无耻,黄铜",
"brat":"n:小鬼,兔崽子,子孙,小家伙",
"bravado":"n:虚张声势",
"brave":"v:冒;a:壮烈,凛然,傲,勇;n:勇士,虎,英烈",
"bravely":"d:毅然",
"braveness":"n:勇敢",
"bravery":"n:勇敢,英勇,胆量,胆气,胆,胆力,大胆,刚毅,华丽",
"bravo":"n:歹徒,亡命之徒,好球;v:叫好,亡命徒,喝彩",
"brawl":"v:吵架,吵闹,喧嚷;n:口角,吵闹",
"brawling":"v:喧闹,争吵",
"brawn":"n:膂力,体力,肌肉",
"brawny":"a:粗壮",
"bray":"v:捣碎,叫,喧嚷,嘶叫;n:布雷,喧哗",
"braze":"v:焊接",
"brazen":"a:厚颜无耻,无耻;v:肆无忌惮",
"brazenly":"d:公然,肆无忌惮,悍然,死皮赖脸",
"brazier":"n:火盆,铜匠,烤炉,火锅",
"brazil":"n:巴西",
"brazilian":"a:巴西",
"brazzaville":"n:布拉柴维尔",
"breach":"n:违反,缺口;v:裂开,冲破,裂,违约,违",
"bread":"n:面包,食物,钱,粮食",
"bread board":"n:案板",
"breadbasket":"n:肚子,谷仓",
"breadboard":"n:线路板",
"breadcrumb":"n:面包屑",
"breadth":"n:宽,宽度,宽窄,幅度,幅面,宽狭;a:宽",
"breadwinner":"n:生计,职业",
"break":"v:打破,坏,断,爆发,破裂,抛锚,打碎;n:命运,豁子,中休,逃走,歇气,中止,猛冲,失策,闯进,决口,断面",
"break away":"v:逃脱,逃跑",
"break bread":"v:进餐",
"break down":"v:划分,垮,破坏,出毛病,身心交瘁,搞垮,分析,拆毁,打破,抛锚,破,瘫痪;n:垮",
"break even":"v:均分,得失相当",
"break in":"v:插入,插嘴,就范,破门而入,打断,管制,磨合,闯入",
"break into":"v:乘虚而入,打扰,插入,打断",
"break loose":"v:摆脱,脱离",
"break of day":"n:熹",
"break off":"v:解除,劈,断,结束,吹,擗,退,决绝,摆脱,断开,决裂,绝交,终止",
"break open":"v:裂",
"break out":"v:翻开,丛生,勃发,打开,发作,突出",
"break short":"v:中断",
"break through":"v:破,冲锋,冲破,打开,暴涨,溃,猛涨,出现",
"break up":"v:冲散,分割,分解,翻,分裂,散会,土崩瓦解,拆散,毁坏,分化,驱散,巴,破除,散,停止",
"break with":"v:决裂,绝交,破除,放弃,破",
"break-in":"n:闯入,嵌入,试车,插入",
"breakable":"a:易碎",
"breakage":"n:破裂,破坏,破损,断裂,断路,裂口,毁损",
"breakaway":"n:脱离,分离;a:摆脱;v:摆脱",
"breakdown":"n:分解,故障,崩溃,击穿,破损,衰变,停止,毛病,分析,分类,中断,失败,下降,疲竭,损耗,损坏,挫折,衰弱,衰退,倒塌,损伤,瓦解;v:崩溃,分类,击穿,损坏,瓦解",
"breaker":"n:浪,破碎机,锄,浪花",
"breakfast":"n:早餐,早饭,早点",
"breaking":"n:中断,破坏,折断;v:关掉,断开",
"breaking point":"n:极限,断点",
"breakout":"n:皮疹,暴发,越狱,爆发,突破,突围,皮炎;v:突破,脱逃,暴发",
"breakthrough":"n:突破,突破性;v:贯穿",
"breakup":"n:破裂,崩溃,分裂,分离,停止,脱离,解散,瓦解,完结,分居",
"breakwater":"n:防波堤",
"bream":"v:打扫;n:鳊鱼",
"breast":"n:乳房,奶,乳腺,胸部,胸口,胸膛,胸,胸脯,胸怀,心情,侧面,工作面,心绪,奶子;v:吮吸,登",
"breast cancer":"n:乳腺癌,乳癌",
"breastbone":"n:胸骨",
"breastplate":"n:标牌,鞅",
"breasts":"n:奶",
"breaststroke":"v:俯泳;n:蛙泳",
"breastwork":"n:壁,胸墙",
"breath":"n:呼吸,气,一口气,气息,生气,微风,洋葱,生命,声息,息,生命力,一气;v:呼吸",
"breathe":"v:呼吸,吸,吸入,喘气,呼,喷,吐,低语,发,出气,发散,生存,喘息",
"breathe in":"v:吸入,吸",
"breathe out":"v:呼,呵,哈",
"breather":"n:通气孔,喘息,生物,歇息;v:喘息",
"breathing":"n:呼吸,休息;v:呼吸",
"breathing space":"n:喘息",
"breathing spell":"n:喘息",
"breathless":"a:气喘吁吁",
"breathtaking":"a:惊险",
"breech":"n:尾部,屁股,臀部;v:打",
"breeches":"n:短裤,裤子,马裤",
"breed":"v:繁殖,饲养;n:集团",
"breeder":"n:种畜,饲养员",
"breeding":"n:育种,教养,生育,礼貌,饲养,选种,再生,增殖,孵化,繁育,养育;v:训练,配种,养育,育种,选育",
"breeze":"n:微风,轻风,和风,谣言,煤渣,煤屑;v:逃走,闯入",
"breeziness":"n:活泼,快活,轻快",
"brethren":"n:会友,同业,同胞,同志",
"breve":"n:短音",
"breviary":"n:节略",
"brevity":"n:简洁,简短,短促,短暂",
"brew":"v:酝酿,酿造,泡,酿,冲,酿酒,煮沸,孕育,策划,成熟,调制,紧迫;n:饮料,酿造",
"brewer":"n:阴谋家",
"brewery":"n:酒厂,槽坊,糟行",
"brewing":"v:策划,搀合,酿酒,酿造,酝酿,混合",
"bribe":"v:贿赂,买通,收买,行贿,打点;n:买关节",
"bribed":"v:受贿",
"bribery":"n:贿赂,受贿,行贿,收买",
"bribes":"n:赃物",
"brick":"n:砖,砖头,砖块,积木,茶砖,好汉,面砖",
"brickbat":"n:碎砖",
"bricklayer":"n:瓦匠,瓦工,泥工,泥水匠,泥瓦匠",
"bricklaying":"n:砌砖,瓦工",
"brickwork":"n:砌砖",
"brickyard":"n:砖厂",
"bridal":"a:新娘;n:婚礼",
"bride":"n:新娘,新娘子,新人,新媳妇儿,亲,新妇",
"bride price":"n:聘礼",
"bridegroom":"n:新郎,新郎官",
"bridesmaid":"n:伴娘",
"bridge":"n:桥,桥梁,电桥,梁,鼻梁;v:架桥,渡过,弥合,搭桥,克服",
"bridge over":"v:渡过,克服",
"bridgehead":"n:桥头,桥头堡",
"bridging":"v:分流,架桥,连接,搭桥;n:架桥",
"bridle":"n:辔头,放纵,拉手,束缚,制动器,抑制;v:抑制",
"bridle path":"n:马道",
"bridle road":"v:马道",
"brief":"a:简短,短暂,短;n:概要,通报,案由,公事包,短文,片;v:节录,交代,节略;d:略",
"briefcase":"n:公事包,皮包,手提箱,手提包",
"briefing":"n:简报",
"briefly":"d:略略,简言之,概括;a:不详,简括",
"briefness":"n:简单,简略",
"briefs":"n:内裤,三角裤",
"brig":"n:监狱,警察局;v:监禁",
"brigade":"n:旅,大部队,队,组",
"brigadier":"n:旅长,准将",
"brigand":"n:强盗,土匪,胡匪",
"bright":"a:明亮,聪明,灿烂,光明,亮,光,炯炯,光亮,光辉灿烂,鲜,鲜明,明快,伶俐,璀璨,光华,光灿灿,精光,俊,明灿灿,颖慧,炳,火亮,烈,曈曈,煜煜,昭昭;n:光华,朗,光辉;v:透亮,激",
"bright blue":"n:蓝晶晶,瓦蓝",
"brighten":"v:明亮,晴,快活,亮,闪耀,增光,发光,光大,发亮",
"brightness":"n:亮度,明亮,光,星等,灰度,熹,辉",
"brilliance":"n:光辉,才华,夺目,光耀,头角,鲜明,辉煌,光华,才智,彩,亮度,辉,光泽",
"brilliancy":"n:辉煌,鲜明,鲜艳",
"brilliant":"a:鲜艳,卓越,光辉,漂亮,辉煌,精彩,光彩夺目;v:灿烂夺目,头角峥嵘;n:宝石,钻石",
"brilliantine":"n:发蜡",
"brilliantly":"d:灿然;a:灿然",
"brim":"v:满,漫溢,漾,溢,注满,盈,洋溢;n:水边,岸边",
"brim over":"v:漾,漫溢,漫",
"brimless":"a:无边",
"brimmed":"v:满",
"brimming":"v:横溢",
"brindle":"n:斑,斑纹",
"brine":"n:卤水,盐水,海水,海",
"bring":"v:带来,带,将,提出,引起,拿,生产,控制,导致,提前,产生,抚养,获得,提,迫使,拉,造成,完成,携带,致使,养育,引来,招致,说服,撮合,救活,创造,举出,提起,停下,纳,压低,护送,劝导,鞠养,培育,赍,劝诱,撮,收束,酿成,获利,减低,浓缩,造就",
"bring about":"v:带来,引起,创造,致使,贾,导致,招致",
"bring down":"v:压低,减低,浓缩",
"bring forth":"v:产生,提出",
"bring forward":"v:提前,提出",
"bring in":"v:提出,获利",
"bring off":"v:完成",
"bring on":"v:引起,造成,酿成",
"bring out":"v:生产,说明",
"bring through":"v:救活",
"bring to":"v:引起",
"bring together":"v:撮,收束,撮合,兼",
"bring up":"v:教育,带,培育,抚,毓,粥,抚养,鞠,拉,造就,鞠养,教养,养育,育",
"brink":"n:边缘,堤岸,滨,线,界,缘,边,涯,边沿",
"briny":"n:大海",
"brio":"n:兴奋,愉快",
"brioche":"n:鞋垫",
"briquette":"n:煤球,煤砖",
"brisk":"a:兴隆,活跃,轻快,清爽;v:活泼,活跃",
"brisket":"n:胸部,胸",
"briskness":"n:敏捷",
"bristle":"v:竖起;n:刚毛,鬃毛",
"britain":"n:英国,不列颠",
"britannic":"a:大不列颠",
"british":"a:英国,大不列颠",
"british system":"n:英制",
"brittle":"a:脆,易碎",
"brittleness":"n:脆性,脆弱",
"bro":"n:谷地",
"broach":"v:开,提倡,提议;n:钻头",
"broad":"a:宽阔,宽,广大,广阔,宽广,阔,广,溶溶,远大,博大,泛;n:辽,湖沼,女人",
"broad jump":"n:跳远",
"broad-minded":"a:旷达",
"broadband":"n:宽带",
"broadcast":"v:广播;n:撒播,播音",
"broadcast station":"n:广播电台",
"broadcaster":"n:广播电台",
"broadcasting":"n:广播,播音",
"broadcasting station":"n:台,电台",
"broaden":"v:扩大,加宽,拓宽,放宽;a:广",
"broadening":"v:扩展",
"broadly":"d:广泛,明白,露骨,粗鲁,广,宽",
"broadly speaking":"n:一般地说",
"broadness":"n:宽,明白,粗鲁,广阔,门面,幅",
"broadside":"n:侧面;d:侧向",
"broadsword":"n:腰刀,砍刀,大刀",
"brobdingnagian":"n:巨人",
"brocade":"n:锦缎,织锦,云锦,锦",
"broccoli":"n:花椰菜",
"brochure":"n:小册子",
"broil":"v:烤,酷热,灼热,灸,烤肉,炎热,焙,激动;n:炙,焙,灼热,骚动,争辩,吵闹,烤",
"broiler":"n:笋鸡",
"broiling":"v:灼热",
"broke":"v:废纸;n:废纸",
"broken":"a:破,碎,破碎,破旧;v:残破",
"broken heart":"n:心碎,失恋,失意",
"brokenhearted":"a:柔肠寸断",
"broker":"n:经纪人,掮客,代理人,经纪,牙侩,倒爷,中间人;v:经纪",
"brokerage":"n:回扣,经手费,佣金",
"brolly":"n:降落伞",
"bromide":"n:溴化物",
"bromine":"n:溴",
"bronchi":"n:支气管",
"bronchial":"a:支气管",
"bronchial tube":"n:支气管",
"bronchitis":"n:支气管炎",
"bronchus":"n:支气管",
"bronco":"n:野马",
"broncobuster":"n:牛仔",
"bronze":"n:青铜,古铜色,铜像,铜器",
"bronze medal":"n:铜牌",
"bronzing":"a:烫金;n:红褐色;v:红褐色",
"brooch":"n:胸针,别针",
"brood":"v:沉思;n:同胞,同伙,属,种族,窝,种",
"brooder":"n:暖棚,孵卵器,暖房,育雏器",
"brooding":"v:孵化",
"brook":"n:溪水,溪流,溪;v:耐",
"brooklet":"n:小溪",
"broom":"n:扫帚,帚;v:扫除",
"broomcorn millet":"n:黍",
"broth":"n:肉汤,汤,肉汁,清汤",
"brothel":"n:秦楼楚馆,窑子,窑,妓院,青楼",
"brothels":"n:秦楼楚馆",
"brother":"n:兄弟,弟弟,哥哥,同志,老兄,同胞,哥,会友,同僚,修士,好友,老表,同业",
"brother-in-law":"n:姐夫,妹夫,内弟,妇弟,妹婿,内兄,堂兄弟,大伯,舅子",
"brotherhood":"n:会,同胞,同行,公会,协会,同事,同业,会友,社,团体",
"brotherliness":"n:友爱",
"brotherly":"a:兄弟;n:兄弟",
"brotherly love":"n:情同手足",
"brothers":"n:兄弟,昆仲,伯仲,哥儿俩,弟兄,哥儿们,哥儿",
"brouhaha":"n:吵闹,骚动,喧嚣",
"broussonetia papyrifera":"n:楮",
"brow":"n:额头,眉,山顶,额,眉毛,皱眉头,表情,跳板,智能,陡坡,容貌,悬崖,眼眉,脑门子",
"browbeat":"v:威吓,威逼,欺侮,吓唬,可欺,吓,欺负",
"browbeaten":"v:可欺",
"brown":"n:布朗,棕色,褐色;a:褐,焦黄",
"brown bear":"n:人熊,罴,马熊",
"brown coal":"n:褐炭",
"brown rat":"n:大家鼠",
"brown sugar":"n:黄糖",
"brown trout":"n:鳟,鳟鱼",
"brown-nose":"v:拍马屁",
"brownie":"n:小孩子",
"browning":"n:勃郎宁",
"brownness":"n:褐色",
"brownout":"n:节电",
"brows":"n:眉头",
"browse":"v:浏览,吃,翻阅,放牧;n:嫩草,放牧",
"bruin":"n:熊",
"bruise":"n:伤痕;v:挫伤,擦伤,争斗,殴打",
"bruiser":"n:彪形大汉",
"bruising":"v:捣碎",
"bruit":"n:谣言,传闻,杂音;v:传播",
"brunei":"n:文莱",
"brunt":"n:强攻,撞击,打击力,冲击,突击;v:撞击",
"brush":"v:刷牙;n:灌木丛",
"brush aside":"v:漠视,屏除,置之不理",
"brush off":"v:拂",
"brush up":"v:复习,提高",
"brush-off":"n:拒绝",
"brushing":"v:干扰,卧底;n:擦亮",
"brushoff":"n:拒绝",
"brushstroke":"n:绘画",
"brushwood":"n:枝条",
"brushwork":"n:笔触,画法,绘画",
"brusque":"a:唐突,疾言厉色;v:疾言厉色,唐突",
"brutal":"a:野蛮,兽性,残酷,粗暴,残忍,残暴,暴戾,狠毒,酷,强暴,鹉,惨无人道,暴,暴虐",
"brutality":"n:残忍,蛮横,兽性,兽行;a:残忍",
"brutalize":"v:残忍",
"brute":"n:畜生,动物,劣根性;a:畜生",
"bubble":"n:气泡,泡,幻想,泡沫,冒泡,泡影,水泡;v:沸腾,起泡,涌,兴奋",
"bubble gum":"n:口香糖",
"bubbling":"v:冒泡",
"bubo":"n:鱼口",
"bubonic plague":"n:鼠疫",
"buccaneer":"n:腊肉,海盗,冒险家",
"bucharest":"n:布加勒斯特",
"buck":"v:反对;n:构架,门框;a:雄",
"buck fever":"n:体验,紧张",
"buck up":"v:改进,赶快",
"buckaroo":"n:牛仔",
"bucket":"n:水桶,桶,吊桶,叶片,戽斗,活塞,大量",
"buckeye":"n:橡树",
"bucking":"n:反作用;v:反作用",
"buckle":"v:扣;n:扣子",
"buckler":"v:防护,防卫,防御;n:防御",
"buckling":"v:膨胀,曲率;n:曲率;a:屈曲",
"buckram":"n:硬衬,生硬",
"buckskin":"n:鹿皮",
"bucktooth":"n:龅牙",
"buckwheat":"n:荞麦,荞",
"bucolic":"n:田园诗,乡下人;a:农民,农夫",
"bud":"n:芽,花芽,萌芽,蓓蕾;v:萌发,萌芽",
"budapest":"n:布达佩斯",
"buddha":"n:佛陀,老佛爷,浮图",
"buddhism":"n:佛教,佛门,佛法,空门,山门,佛,佛家",
"buddhist":"n:佛门",
"buddies":"n:哥儿们",
"budding":"n:发芽,含苞,芽接;v:出芽",
"buddy":"n:伙伴,好友",
"budge":"v:动,让步,推动",
"budget":"n:预算;v:支配,预定,安排",
"buenos aires":"n:布宜诺斯艾利斯",
"buff":"n:迷,水牛,野牛;v:缓冲,抛光",
"buffalo":"n:水牛,野牛;v:威吓,迷惑",
"buffalo gnat":"n:蚋",
"buffalo grass":"n:野牛草",
"buffer":"n:缓冲,缓冲区,缓冲器;v:缓和",
"buffet":"n:自助餐;v:殴打",
"buffet car":"v:餐车",
"buffing":"v:磨光,抛光;n:磨光",
"buffoon":"n:小花脸,跳梁小丑,丑角,小丑;v:丑化",
"buffoonery":"n:滑稽,插科打诨,丑态",
"bug":"n:昆虫,迷,虫子,故障,臭虫,窃听,窃听器;v:撤退,离开",
"bugaboo":"n:鬼怪",
"bugbear":"n:妖怪,鬼怪",
"bugger":"v:走开,诅咒,破坏,困扰,滚,闲荡;n:坏东西",
"bugger off":"v:滚,走开",
"buggery":"n:鸡奸",
"bugle":"n:号角,号,军号,夏枯草;v:吹号",
"bugle call":"n:冲锋号,号角",
"bugler":"n:号手,司号员,吹鼓手,号兵",
"build":"v:建造,建,修建,造,盖,建立,建筑,建设,筑,修,修筑,制作,兴建,砌;n:成形,构造,造型,块头",
"build in":"v:制作",
"build up":"v:抬高,起家,集结,积聚",
"build-up":"n:堆积,计算,情节,出现,装配,作图,产生,增长,吹嘘,上升,宣传,发展,蓄积,构造,鼓励,形成,结构,增强,组成,安装,积累,升高,组合;a:集结",
"builder":"n:建设者",
"building":"n:大楼,建筑物,建筑,房子,楼,楼房,房屋,大厦,楼宇,土木,组装,制造,组合,营造",
"buildings":"n:房屋,建筑物",
"buildup":"n:累积,加厚",
"bulb":"n:球,灯泡,电灯泡,球部,鳞茎,烧瓶,真空管,快门,扁桃腺",
"bulgaria":"n:保加利亚",
"bulge":"v:鼓,装满,凸出,膨胀,隆起,努;n:暴涨,优势,优越,肿胀,鼓胀,底边",
"bulging":"a:鼓鼓囊囊,鼓;v:鼓",
"bulimia":"n:贪欲",
"bulk":"n:大部分,体积,大多数,大量,身躯,巨大,块状,大小,大半,主体;v:堆积,膨胀,增大,扩展,增加;a:散装",
"bulkhead":"n:隔板,隔墙;d:隔墙",
"bulkiness":"n:庞大",
"bulking":"v:体积,增量,膨胀;n:增量,体积",
"bulky":"a:粗笨,粗大,粗重",
"bull":"n:公牛,瞎话,训令,多头,工头,大话;v:挤出,说空话,交尾,吹牛;d:特",
"bull market":"n:牛市",
"bull's-eye":"n:靶心,凸透镜",
"bulldog":"n:哈吧狗,大炮,硬汉",
"bulldoze":"v:恐吓,排除,威吓,威胁",
"bulldozer":"n:推土机,压路机",
"bullet":"n:子弹,枪弹,弹,流弹,炮弹,枪子儿,弹头;v:弹",
"bullet hole":"n:弹痕",
"bulletin":"n:公报,公告,简报,快报,告示,会刊,报,布告,通报",
"bulletin board":"n:布告栏,公告牌",
"bulletproof":"v:防弹;n:防弹",
"bullfight":"n:斗牛;v:斗牛",
"bullfrog":"n:牛蛙",
"bullhead":"n:大头鱼",
"bullhorn":"n:扩音器",
"bullies":"n:地痞",
"bullion":"n:金条,纯金,金银",
"bullishness":"n:乐观,强壮",
"bullock":"n:犍牛,犍",
"bullpen":"n:牛栏",
"bullshit":"n:胡说",
"bullwhip":"n:牛鞭",
"bully":"v:欺侮,欺负;n:豪强;a:好",
"bullying":"a:豪横,跋扈;v:气,跋扈;n:气",
"bulrush":"n:菖蒲,灯心草",
"bulwark":"n:屏障,堡垒,防波堤,防御,寨",
"bum":"n:二流子;v:乞讨",
"bumble":"n:妄自尊大",
"bumblebee":"n:土蜂,熊蜂",
"bumf":"n:草纸,公文",
"bummer":"n:游民,失败,懒汉",
"bump":"v:颠簸,撞上,撞,碰到,碰见,颠,谋杀,碰,碰撞;n:才能,瘤;a:困难",
"bump into":"v:击,撞上,撞,碰见",
"bump off":"v:杀死,干掉",
"bump up":"v:增强,提高",
"bumper":"n:保险杠,减震器;a:丰盛;v:撞",
"bumper car":"n:碰碰车",
"bumpkin":"n:土包子,乡巴佬,呆子,泥腿子",
"bumptious":"a:自以为是",
"bumpy":"a:坎坷,磕磕绊绊,疙疙瘩瘩",
"bun":"n:头,酒宴,纂,髽髻,鬏,发髻,饽饽,髽",
"buna":"n:丁腈橡胶,丁苯橡胶",
"bunch":"n:束,朵,瘤,捆,隆起,伙伴,一把,簇,嘟噜;v:把",
"bundle":"n:束,包;v:扎",
"bundle up":"v:捆,扎",
"bung":"n:盲肠,破产,塞子,肛门,故障,死,损坏;v:塞满,堵",
"bungalow":"n:平房",
"bungee":"n:橡皮筋",
"bungle":"n:笨拙,粗制滥造;v:粗制滥造,贻误",
"bunk":"n:床位;v:逃学",
"bunk off":"v:逃走,逃学",
"bunker":"n:掩体,障碍,地堡,料斗,战友,暗堡,煤斗,箱子,漏斗",
"bunny":"n:兔子",
"bunt":"n:抵,短打,矛头,撞,腥黑穗病;v:抵,撞",
"bunting":"n:彩旗,鹀,睡袋,信号旗",
"buoy":"n:浮标;v:激励,鼓舞",
"buoy up":"v:鼓舞,激励",
"buoyancy":"n:浮力,活泼,轻快,开朗,弹性,涨风",
"buoyant":"a:轻飘,轻飘飘,乐呵呵",
"bur":"n:寄生虫",
"burble":"n:空谈,旋涡;v:暗笑",
"burden":"n:负担,重担,包袱,担子,负荷,累赘,要点,责任,义务,主旨,装载量,担,炉料,配料,驮子,重点;v:负,劳累,装货;a:累赘",
"burdening":"n:配料;v:配料",
"burdensome":"a:累赘",
"burdock":"n:牛蒡",
"bureau":"n:局,司,梳妆台,写字台,主席团,办公桌,社,事务所,室,处,编辑部",
"bureaucracy":"n:官僚,官僚主义",
"bureaucrat":"n:官僚,老夫子,官吏,老爷",
"burg":"n:市,镇,城市,城堡,城镇",
"burgeon":"v:发展,发芽;n:嫩芽",
"burgeoning":"v:新兴",
"burger":"n:汉堡,汉堡包,肉丸",
"burgess":"n:市民",
"burgher":"n:市民,公民",
"burglar":"n:窃贼,偷",
"burglarize":"v:偷",
"burglary":"n:盗窃,窃案,盗案",
"burgle":"v:盗窃",
"burgomaster":"n:市长",
"burial":"n:葬礼,埋葬,葬,墓地,丧葬;v:冷却",
"burke":"v:避免,压制,扣压",
"burl":"n:斑点,疵点,线头;v:修",
"burlap":"n:粗麻布,麻袋,麻布",
"burlesque":"n:脱衣舞,笑剧,滑稽戏,漫画,打油诗,杂耍;v:讥笑",
"burliness":"n:结实",
"burly":"a:结实",
"burma":"n:缅",
"burn":"v:烧,燃烧,着;n:火烧;a:辣",
"burn down":"v:焚毁",
"burn out":"v:精疲力尽,焚毁",
"burn up":"v:烧毁,赶路,责备,毁,化",
"burner":"n:灯,炉子,喷灯,燃烧室,香炉,灯头",
"burning":"n:性病,燃烧,烧香,烧制,炎症,磨光;v:擦亮,氧化,煅烧;a:火辣辣",
"burnish":"v:擦亮,磨,光亮,发亮,抛光;n:光滑,光泽;a:光亮",
"burnishing":"v:磨光,抛光;n:磨光",
"burnout":"v:烧坏,烧毁;n:烧毁",
"burns":"n:络腮胡子",
"burnt":"v:焦,糊,煳;a:糊",
"burnt sienna":"n:深褐色",
"burnt umber":"n:赭色",
"burp":"n:饱嗝儿,打嗝;v:打嗝儿",
"burr":"n:毛刺,垫圈,光圈,晕",
"burro":"n:驴子",
"burrow":"v:掘,打;n:穴,避难所,洞穴,窟",
"bursar":"n:账房,大学生",
"bursary":"n:奖学金",
"burst":"v:爆裂,破裂,爆炸,决口,打开,炸,决,突破,闯入,冲破;n:一下子",
"burst forth":"v:迸,勃兴,爆发",
"bursting":"n:爆裂,爆炸;v:断裂,裂开",
"burundi":"n:布隆迪",
"bury":"v:埋,埋葬,埋藏,葬,安葬,埋没,掩埋,下葬,掩蔽,忘却,潜,遮盖,插入,窆,地窖,葬埋,出丧,落葬,瘗;n:地窖",
"burying":"v:埋,埋葬",
"bus":"n:公共汽车,汽车,总线,大客车,巴士,公车,长途汽车,飞机,轿车,客车,母线,客机,服务员",
"bus depot":"n:汽车站",
"bus line":"n:母线",
"bush":"n:灌木,丛林,树林,布什,森林,衬套,套管,套筒,轴瓦;v:丛生,灌",
"bush league":"n:次等,外行",
"bush vetch":"n:野豌豆",
"bushel":"v:修补;n:大量",
"bushido":"n:武士道",
"bushing":"n:轴衬,套管,引线,套筒",
"bushwhack":"v:伏击,披荆斩棘",
"bushwhacking":"v:游击战",
"bushy":"a:菔",
"busily":"d:忙,忙碌,矻矻,繁忙",
"business":"n:生意,企业,公司,事,业务,商业,工作,事情,事业,买卖,商店,事务,营业,交易,行业,职责,商,公干,权利,议程,营业额,事儿,服装,物事,事体,要务,实业,事务所,市面,要事,本分,生业,做功",
"business agent":"n:代理商",
"business card":"n:名片",
"business college":"n:商学院",
"business district":"n:商业区",
"business firm":"n:行",
"businessman":"n:商人,生意人,企业家,实业家,商,私商",
"businessmen":"n:生意人",
"buskin":"n:悲剧,短统靴",
"buss":"n:接吻,吻;v:接吻",
"bust":"v:破坏;n:殴打,失败,逮捕,近景,胸围",
"bust up":"v:破坏,争吵",
"bust-up":"n:破裂,大吵大闹",
"bustard":"n:大鸨,鸨",
"buster":"n:伙计,犁,小子,炸弹",
"bustle":"v:催促,忙;n:奔忙,奔走",
"bustle about":"v:东奔西跑,忙碌,跑跑颠颠,忙活",
"bustling":"a:繁华;v:忙,繁华,门庭若市",
"busy":"a:忙,繁忙;v:占线,有事",
"busyness":"n:繁忙,忙碌",
"but":"c:但,但是,而,可是,不过,可,又,然而,还是;d:无奈;n:反对;p:以外,除_以外;v:除外;a:第",
"but that":"c:但是,然而",
"but then":"n:只是",
"butane":"n:丁烷",
"butch":"n:大老粗;v:屠杀",
"butcher":"v:屠杀;n:小贩,医生,刽子手",
"butcher knife":"n:屠刀",
"butchery":"n:屠杀,屠宰,屠宰场,惨杀,大屠杀,屠场",
"butler":"n:管家,男仆,管事",
"butt":"n:烟蒂,柄,对象;v:插嘴,伸出",
"butt end":"n:大头,残部,枪托",
"butt hinge":"n:铰链",
"butt in":"v:插手,插嘴,打断",
"butt joint":"n:对接",
"butter":"n:黄油,奶油,牛油;v:拍马屁,恭维;a:酥",
"butter up":"v:恭维,拍马屁,巴结",
"butterball":"n:胖子",
"buttercup":"n:茛",
"butterfat":"n:乳脂",
"butterfly":"n:蝴蝶,蝶,胡蝶",
"buttering":"v:奉承",
"buttock":"n:屁股,船尾,纵剖面",
"buttocks":"n:屁股,臀部,臀",
"button":"n:钮扣,按钮,扣子,电钮;v:守口如瓶",
"button up":"v:守口如瓶,系,扣",
"buttonhole":"n:扣眼",
"buttress":"n:垛,垛子;v:支持",
"butty":"n:伙伴,工头,同事,监工",
"butyl alcohol":"n:丁醇",
"butyric acid":"n:酪酸",
"buxom":"a:丰满",
"buy":"v:买,购买,收买,买进,收购,购物,同意,获得,买通,购;n:市,交易",
"buy back":"v:返销",
"buy in":"v:收买,籴",
"buy off":"v:买通,行贿",
"buy out":"v:赎买",
"buy up":"v:买进",
"buyer":"n:买主,买方,采购员",
"buying":"v:购买",
"buzz":"n:流言;d:嗡,嗡嗡;v:嗡嗡,走开",
"buzz off":"v:走开",
"buzz saw":"n:圆锯",
"buzzard":"n:土豹,老糊涂,秃鹰,兀鹰",
"buzzer":"n:蜂鸣器,汽笛,砂轮",
"buzzword":"n:口号",
"by":"p:被,由,用,以,通过,到,为,因,由于,给,将,靠,把,让,坐,当,按,乘,经过,凭,吃,经,前,照,连续,据,借助于,论,为止,对待,沿,靠近,顺,旁,截至;d:过去,越过,经过,流过;v:吃,靠近",
"by all means":"p:只管,百般,务必,万",
"by and by":"d:不久以后",
"by and large":"d:大体上",
"by any means":"p:务必,绝",
"by chance":"p:碰巧,偶,偶尔,碰劲儿,偏巧,巧合;d:侥幸,凑巧",
"by comparison with":"p:与_比较,比较",
"by dint of":"p:靠,用,依靠,凭借,由于",
"by heart":"p:死记,用心",
"by inches":"p:险",
"by means of":"p:用,通过,以,将,依靠,借助于,凭借,假托",
"by no means":"p:并不,绝不;d:决不",
"by order of":"p:按照",
"by reason of":"p:因为,由于,为了",
"by rights":"p:按理",
"by the order of":"p:按照",
"by the way":"p:顺便,就便",
"by virtue of":"p:由于,因为,依靠,凭借",
"by way of":"p:经由,作为,通过,方法,通过_方法,途经,当作,借以,以求",
"by-and-by":"n:将来,未来",
"by-line":"n:副业,支线",
"by-product":"n:副产品",
"bye":"n:小事;v:轮空",
"bye-bye":"i:拜拜,再会;n:床;d:睡觉",
"bygone":"a:过去,往日;n:往事",
"bylaw":"n:会章,细则,附则,规章制度",
"bypass":"v:绕,越过,回避,撇开;n:小道,回避",
"byproduct":"n:副产品",
"byrd":"n:伯德",
"byre":"n:牛棚",
"byroad":"n:岔子,岔道,小路",
"byron":"n:拜伦",
"bystander":"n:旁观者,局外人,观潮派",
"byte":"n:字节",
"byway":"n:小路",
"byword":"n:绰号,口头禅,笑柄,谚语,俗话",
"c":"n:丙",
"c/o":"p:转交,由_转交",
"cab":"n:马车,出租汽车,出租车,驾驶室,夹带;v:作弊",
"cabal":"n:阴谋,派系,朋党",
"cabala":"n:秘传",
"cabana":"n:小屋,浴室",
"cabaret":"n:夜总会,餐馆",
"cabbage":"n:卷心菜,白菜,包心菜,小白菜,甘蓝,洋白菜;v:偷",
"cabin":"n:小屋,舱,木屋,船舱,客舱,机舱,座舱,舱室,卧室;v:隔开",
"cabinet":"n:内阁,柜子,柜,盒,陈列品,阁,橱,箱,柜橱;a:小巧",
"cabinet minister":"n:总长",
"cable":"n:电缆,电报,钢索,缆索,电,缆,缆绳,报,钢丝绳,铁索,索",
"cable length":"n:链",
"caboodle":"n:捆,团,群,堆",
"caboose":"n:守车,厨房",
"cacao":"n:可可树",
"cache":"v:隐藏,贮藏;n:地窖",
"cachepot":"n:花盆,花瓶",
"cachet":"n:称赞,胶囊,威信,身分",
"cackle":"v:咯咯,狞笑;d:咯咯;n:废话",
"cackler":"n:鸡蛋,艺人,碎嘴子",
"cacophony":"n:噪音,杂音",
"cactus":"n:仙人掌,仙人球",
"cadaver":"n:死尸,尸体",
"caddy":"n:箱,茶叶罐,盒,柜",
"cadence":"n:节奏,调子,拍子,音律;v:终止",
"cadenza":"n:终止",
"cadet":"n:次子,弟弟",
"cadge":"v:勒索,敲诈,行乞,乞讨",
"cadger":"n:二流子,寄生虫",
"cadmium":"n:镉",
"cadre":"n:干部,干,骨骼,架子,骨干",
"caesar":"n:独裁者,皇帝,暴君,罗马帝国,政治家",
"caesium":"n:铯",
"cafe":"n:咖啡馆,餐馆,酒馆",
"cafeteria":"n:饭堂",
"caffeine":"n:咖啡因,咖啡碱",
"cage":"n:笼子,笼,鸟笼,罐笼,牢笼,外壳;v:罩",
"caging":"v:锁定",
"cahoot":"n:共谋,同伙,合伙",
"cahoots":"n:共谋,合伙",
"cain":"n:恶魔,凶手",
"cairo":"n:开罗",
"caisson":"n:弹药箱,沉箱,藻井",
"caitiff":"n:胆小鬼",
"cajole":"v:哄骗,勾引,诱骗,引诱",
"cajolement":"n:笼络,诱骗",
"cajoler":"n:骗子",
"cajolery":"n:笼络,引诱,哄骗,诱骗",
"cake":"n:蛋糕,糕饼,饼,糕点,糕,饼饵,烧饼,饽饽",
"caking":"v:结块",
"calabash":"n:葫芦,葫,匏",
"calaboose":"n:监狱,拘留所",
"calais":"n:加来",
"calamitous":"a:惨重,多灾多难;v:多灾多难",
"calamity":"n:灾难,不幸,灾祸,大祸,灾,灾殃,祸殃,眚,危难,殃,遗祸,祸;v:劫",
"calcification":"n:钙化;v:钙化",
"calcify":"v:钙化,僵化,硬化",
"calcine":"v:煅烧,焙烧",
"calcite":"n:方解石",
"calcium":"n:钙",
"calcium carbide":"n:碳化钙",
"calcium carbonate":"n:石灰质",
"calcium oxide":"n:氧化钙",
"calculate":"v:计算,指望,估计,推算,打算,认为,考虑,盘算,想,计量,算,算计,计,演算,预测,筹划,核计,预料,依靠,以为,推测,猜想,揣,核算,打算盘,筹算,划算",
"calculating machine":"n:计算机,计数器,计算器",
"calculation":"n:计算,深思熟虑,算计,心计,精打细算,演算,打算,预测",
"calculator":"n:计算器,计算机,一览表",
"calculus":"n:微积分,演算,牙垢,石,运算,积石,结石",
"calcutta":"n:加尔哥达",
"calendar":"n:日历,日程表,年历,历,历法,历书,月历,挂历,一览表",
"calendar year":"n:历年",
"calender":"n:历法",
"calf":"n:牛犊,犊,腿肚子,仔,牛犊子",
"caliber":"n:口径,孔径,直径,卡钳",
"calibrate":"v:校准,校正,校对",
"calibration":"n:校准,标定,刻度,标准化;v:校准",
"calibre":"n:才干,卡钳,能力,等级,口径,水准,直径,规,内径",
"calico":"n:市布,印花布,洋布,白布",
"california":"n:加利福尼亚",
"californium":"n:锎",
"caliper":"n:卡尺,卡规",
"calipers":"n:卡钳,卡规",
"caliph":"n:哈里发",
"calisthenics":"n:柔软体操",
"call":"v:叫,叫做,称,到,打电话,拜访,看;n:义务",
"call at":"v:访问",
"call back":"v:回电",
"call down":"v:祈求,责骂",
"call for":"v:请求,需要",
"call forth":"v:引起,唤起",
"call in":"v:召见,进见,聘请",
"call number":"v:书号",
"call off":"v:停止",
"call on":"v:拜,号召,拜访,拜客,见,晋见,走,拜会,看望,望,晋谒,看,找,访,谒,进见,探,诣,造访,拜望,探访,探望,谒见,顾,呼吁,上门",
"call out":"v:呼喊,召集,出动,号召",
"call the tune":"v:定调,发号施令,定调子",
"call up":"v:召,召唤,打电话,征召,征集,挂",
"call-back":"n:收回,召回",
"caller":"n:客",
"calligrapher":"n:书法家",
"calligraphist":"n:书法家",
"calligraphy":"n:书法,篆体,篆书,笔迹",
"calling":"n:职业,愿望,到来,感召,呼,叫喊,名称,停靠;v:传唤,停靠",
"calling card":"n:指纹",
"calliper":"n:两脚规,千分尺,千分表,厚度,卡尺,卡钳",
"callistephus chinensis":"n:翠菊",
"callosity":"n:麻木,硬结,胼胝,老茧,胼",
"callous":"a:冷酷,心硬",
"callus":"n:老茧,胼胝,茧子",
"calm":"a:平静,镇静,冷静,风平浪静;v:沉着,从容;n:铸型",
"calm down":"v:弛缓,定,塌,平,平息",
"calmly":"d:平心静气,从容不迫;v:从容不迫",
"calmness":"n:镇定,平静",
"caloric":"n:热",
"calorie":"n:卡,千卡,卡路里",
"calories":"v:卡路里",
"calorimeter":"n:热量计",
"calumniate":"v:污蔑,陷害,诋毁,毁谤,诬蔑,谰,诬害,谮,诬栽,诽谤,訾",
"calumniation":"n:毁谤,诽谤,诬蔑,诬告",
"calumny":"n:诽谤,中伤,诼,谗言,谰言,谣诼,诬蔑",
"calvary":"n:苦恼",
"calve":"v:生,产,分离",
"calyx":"n:萼,花萼",
"cam":"n:凸轮,靠模",
"camaraderie":"n:友谊,友爱",
"camber":"n:弯度,曲面,弯曲",
"cambium":"n:形成层",
"cambodia":"n:柬埔寨",
"cambrian":"n:寒武纪",
"cambrian period":"n:寒武纪",
"cambric":"n:麻纱",
"cambridge":"n:剑桥",
"camcorder":"n:摄像机",
"camel":"n:骆驼,驼色,驼背",
"camel's hair":"n:骆驼绒,驼绒",
"camellia":"n:山茶,茶花,油茶",
"cameo":"n:贝壳,贝雕,浮雕,片断",
"camera":"n:照相机,摄影机,相机,摄像机",
"camera obscura":"n:暗箱",
"cameraman":"n:摄影师",
"cameroon":"n:喀麦隆",
"camouflage":"n:伪装;v:掩饰,装扮,欺瞒",
"camp":"n:营地;v:安营扎寨,手舞足蹈,住宿",
"camp bed":"n:帆布床",
"camp out":"v:露营",
"campaign":"n:运动,战役,游说,炉龄",
"campaigner":"n:老手,老兵",
"campanile":"n:钟楼",
"campfire":"n:营火,篝火,营火会",
"camphor":"n:樟脑,樟树,樟",
"camphor tree":"n:樟",
"camping":"v:露营,野营",
"camping ground":"n:营地",
"campsite":"n:营地",
"campus":"n:校园,大学",
"camshaft":"n:凸轮轴",
"can":"n:罐头;v:辞退,开除,罐头盒;d:好",
"canaan":"n:乐土",
"canada":"n:加拿大",
"canal":"n:运河,水渠,渠,沟渠,渠道,水沟,水道,管,管路,道,沟,漕河",
"canalization":"n:开导",
"canard":"n:谣言,鸭,误传",
"canary":"n:金丝雀",
"canary bird":"n:金丝雀,罪犯",
"canberra":"n:堪培拉",
"cancel":"v:取消,抵消,撤销,删去,退,注销,勾销,解除,销,勾除,相约,作废,撤消,略去,吊销,推倒,推翻,打消;n:删略,消",
"cancel out":"v:相约",
"cancellation":"n:取消,消,注销,对消;v:对消,熄灭",
"cancer":"n:癌症,癌,肿瘤,毒瘤,癌变",
"cancerous":"a:癌",
"candelabrum":"n:烛台",
"candid":"a:坦白,坦率,直率,爽朗,直爽,率直,明,爽直,直心眼儿",
"candidate":"n:候选人,考生;a:候选",
"candied":"a:甜蜜",
"candied fruit":"n:脯",
"candle":"n:蜡烛,烛光,蜡,烛",
"candle holder":"n:蜡台",
"candlelight":"n:烛光,黄昏,烛花,灯火",
"candlepower":"n:烛光",
"candlestick":"n:烛台,蜡台",
"candor":"n:坦率,公正,爽直,直率,率直,直爽,公平,光明",
"candour":"n:坦率,率直,公平,光明,正直",
"candy":"n:糖果,糖,冰糖,软糖,可卡因,砂糖,蜜饯,水果糖,古柯碱",
"cane":"n:手杖,藤条,杖,甘蔗,茎;v:拐",
"canine":"n:犬,犬牙,犬齿;a:犬",
"canine tooth":"n:犬牙",
"caning":"v:鞭打",
"canis major":"n:大犬座",
"canister":"n:罐,手枪",
"canister shot":"n:子母弹",
"canker":"n:溃疡,苦恼;v:腐败,腐蚀",
"cannabis":"n:大麻",
"cannabis sativa":"n:大麻",
"canned":"a:听装",
"cannibalism":"n:残忍",
"cannibalistic":"a:灭绝人性",
"cannibalize":"v:吃",
"canniness":"n:精明",
"cannon":"n:大炮,火炮,机关炮,加农炮,炮,炮口,小偷,榴弹炮,手枪;v:炮轰,开炮",
"cannon cracker":"n:二踢脚",
"cannon fire":"n:炮火",
"cannon fodder":"n:炮灰",
"cannonade":"v:炮击",
"cannonball":"n:炮弹",
"cannot":"v:不可,未能,不得",
"cannula":"n:套管,插管",
"canoe":"n:独木舟,独木船,舟,轻舟,划艇",
"canon":"n:准则,规范,教规;p:经",
"canonical":"a:规范;n:法衣",
"canoodle":"v:爱抚,搂抱",
"canopy":"n:冠,覆盖,盖,天空,幔帐,罩棚",
"canst":"v:能",
"cant":"n:黑话,口头禅;v:侈谈,投掷,倒转",
"cantaloupe":"n:甜瓜",
"cantata":"n:大合唱",
"canteen":"n:水壶,食堂,小卖部,饭堂,水罐,饭盒",
"canter":"n:慢跑,流浪者,流浪汉,小跑;v:慢跑,小跑",
"canterbury":"n:坎特伯雷",
"canticle":"n:赞歌,颂歌",
"cantilever":"n:悬臂,支架",
"canting":"v:倒转",
"canto":"n:歌,旋律,篇章",
"canton":"n:广州,州,镇,村",
"cantonese":"n:粤语",
"cantonment":"n:兵营",
"canvas":"n:帆布,画布,油画,帐篷,天幕,风帆",
"canvass":"v:游说,拉,讨论;n:风帆,天幕",
"canvasser":"n:推销员",
"canyon":"n:峡谷,峡",
"cap":"n:帽子,盖,瓶盖,帽,盖子,军帽,头巾,罩子,便帽,会费,头儿,尖,冕,套,膝盖骨,鞘,柱头,根冠;v:凌驾,戴帽子,胜过",
"capabilities":"n:能量",
"capability":"n:能力,性能,能,才能,容量,能耐,本领,本事,功率,生产率;v:能",
"capable":"a:能,能干,成,干,行;v:能",
"capacious":"a:宽敞",
"capacitance":"n:电容,电容器",
"capacitor":"n:电容器,容电器",
"capacity":"n:能力,容量,身份,量,本领,容积,性能,产量,资格,功率,机能,权力,才干,装载,装载量,地位,身分,器,权能,能量,电容,力,生产额;v:装载",
"caparison":"n:服装",
"cape":"n:斗篷,披肩,海角,岬,岬角,霞帔,大氅,角",
"cape jasmine":"n:栀子,栀",
"cape town":"n:开普敦",
"caper":"v:开玩笑,跳跃,嬉戏",
"capillarity":"n:毛细现象",
"capillary":"n:毛细管,微血管",
"capillary tube":"n:毛细管",
"capital":"n:首都,资本,资金,都,大写字母,会,大写,本,首府,资产,资源,老本,资方,资产阶级,基金,国都,柱头,本金,资本论;d:都",
"capital letter":"n:大写字母",
"capital offense":"n:死罪",
"capital punishment":"n:大辟",
"capital stock":"n:股本",
"capitalism":"n:资本主义",
"capitalist":"n:资本家,财主",
"capitalization":"n:大写,投资",
"capitalize":"v:大写,利用,牟利,利益,自恃,投机倒把",
"capitally":"d:妙",
"capitulate":"v:投降,降",
"capitulation":"n:投降,条件,条款,协定",
"capo":"n:头目",
"capon":"n:阉鸡",
"capping":"v:表土",
"caprice":"n:任性,冷热病,异想天开",
"capricious":"a:任性,反复无常,朝三暮四,变幻莫测",
"capricorn":"n:上校",
"capsicum":"n:辣椒",
"capsize":"v:倾覆,翻身;n:翻船,翻车,翻身",
"capstan":"n:绞盘,绞车",
"capstone":"n:顶部,顶点",
"capsule":"n:胶囊,荚膜,节略,摘要,传感器,提要;v:压缩",
"capsulize":"v:压缩",
"captain":"n:船长,上尉,队长,舰长,机长,头子,组长,管理员,魁首;v:统率,指挥",
"caption":"n:说明,标题,逮捕,题目,标示,提要,节目,字幕",
"captions":"n:字幕",
"captious":"a:吹毛求疵,意气用事;v:吹毛求疵",
"captivate":"v:迷住,征服,逮捕",
"captivation":"n:逮捕,迷惑",
"captive":"n:俘虏,俘,阶下囚;v:俘",
"captivity":"n:囚禁,俘虏,监禁,束缚,被俘",
"capture":"v:缴获,捕获,俘虏,俘获,占领;n:夺得,俘虏,掠夺,猎获,掳掠;d:略",
"car":"n:汽车,小汽车,车辆,轿车,车厢,电车,座车,沼泽,卧车",
"car park":"n:停车场,车场",
"caracas":"n:加拉加斯",
"carafe":"n:玻璃瓶",
"caramel":"n:焦糖,糖蜜,酱色",
"carapace":"n:甲壳,甲,壳",
"carat":"n:开,克拉",
"caravan":"n:大篷车,马帮,商队,马队",
"caravansary":"n:旅馆,马店",
"caraway":"n:香菜",
"carbide":"n:碳化物",
"carbine":"n:卡宾枪,马枪",
"carbohydrate":"n:碳水化合物,糖类",
"carbolic acid":"n:苯酚",
"carbon":"n:碳,副本,碳精,复写纸,炭精,碳精棒",
"carbon black":"n:松烟",
"carbon dioxide":"n:碳酐",
"carbon paper":"n:复写纸,复印纸",
"carbonate":"n:碳酸盐",
"carboniferous":"n:石炭纪",
"carbonize":"v:焦化",
"carbonyl":"n:碳酰基",
"carborundum":"n:金刚砂,碳化硅",
"carboxyl group":"n:羧基",
"carboy":"n:坛,玻璃罩",
"carbuncle":"n:痈,红宝石",
"carburetor":"n:化油器,汽化器",
"carburettor":"n:汽化器",
"carcase":"n:骨架,躯体,尸体,死尸,遗骸,身躯",
"carcass":"n:尸体,躯体,构架,身躯,遗骸,骨架,胴体",
"carcinogen":"n:致癌物",
"carcinogenic":"v:致癌;a:致癌",
"carcinoma":"n:癌",
"card":"n:卡片,纸牌,卡,明信片,名片,手段,怪人,请帖,证,请柬,梳理机,策略,节目单,帖子,戏单,菜单,广告,柬,事物,梳子,帖;v:梳,刷",
"cardboard":"n:纸板,硬纸板",
"cardiac":"n:心脏",
"cardiac muscle":"n:心肌",
"cardigan":"n:羊毛衫",
"cardinal":"n:红衣主教;a:主要",
"cardinality":"n:基数",
"carding":"v:梳理",
"cardiogram":"n:心电图",
"cardiovascular":"a:心血管",
"care":"v:关心;n:思念,监督,维护,忧,忧思",
"care for":"v:看顾,喜欢,照,照拂",
"care of":"p:转交,由_转交",
"career":"n:职业,生涯,前途,前程,成功,经历,专业,遭遇,轨迹,履历;v:飞跑,猛冲",
"careering":"v:全速",
"careerism":"n:野心",
"careerist":"n:野心家",
"carefree":"a:大咧咧,翛然,宽畅,乐天,逍遥自在,优游,恬,畅快",
"careful":"a:仔细,细心,谨慎,细致,慎重,周密,慎,细,精细,重视,仔仔细细,审慎,讲究,兢,昚;v:审;d:谨",
"carefully":"d:小心,谨慎,密切,好生,悉心",
"careless":"a:粗心,粗心大意,大意,随便,不慎,漫不经心,马马虎虎,毛糙,马虎,疏阔,毛手毛脚,粗,失慎;v:失慎,疏忽;d:不慎;n:马大哈",
"carelessly":"d:不经意,草草,苟且;a:不经意",
"caress":"v:爱抚,抚摩;n:拥抱,爱抚",
"caressing":"v:爱抚",
"caretaker":"n:看守",
"cargo":"n:货物,荷重,负荷",
"cargo ship":"n:货轮",
"caribbean":"n:加勒比海",
"caribbean sea":"n:加勒比海",
"caribou":"n:驯鹿",
"caricature":"n:漫画,丑化",
"caricaturist":"n:漫画家",
"caries":"n:龋,龋齿",
"carillon":"n:编钟,钟琴",
"carina":"n:脊",
"carmine":"n:洋红色",
"carnage":"n:残杀,大屠杀",
"carnal knowledge":"n:性关系",
"carnality":"n:光卤石,好色,肉欲,性交,淫荡",
"carnation":"n:肉色",
"carnelian":"n:玛瑙",
"carnival":"n:狂欢节,狂欢,嘉年华会,竞赛,欢宴;v:狂欢",
"carnivorous":"a:肉食",
"carny":"n:哄骗",
"carol":"v:歌唱,欢唱;n:颂歌",
"caroms":"n:克郎球,康乐球",
"carotene":"n:胡萝卜素,叶红素",
"carouse":"v:畅饮,酣饮;n:痛饮",
"carp":"v:吹毛求疵,找岔子,挑剔;n:心皮,鲤",
"carpal":"n:腕骨",
"carpel":"n:心皮",
"carpenter":"n:木匠,木工,曲尺",
"carpenter's square":"n:矩尺,曲尺,矩",
"carpentry":"n:木工",
"carpet":"n:地毯,绒毯,毛毯",
"carport":"n:车棚",
"carpus":"n:手腕子,腕,膝头,腕骨",
"carriage":"n:马车,车厢,举止,运费,车,车辆,风度,座位,姿态;v:运输",
"carriageway":"n:车道,车行道",
"carrier":"n:载波,载流子,航空母舰,载体,填料,带菌者,信差,货架,水管,运输机,信鸽,邮递员,吊架,搬运工",
"carrier bag":"n:拎包,提包",
"carrion":"n:腐肉",
"carrot":"n:胡萝卜",
"carry":"v:进行,带,通过,携带,拿,继续,获得;n:载,云,空,移位",
"carry away":"v:带走",
"carry forward":"v:发扬光大,恢宏,继承",
"carry off":"v:夺得,掳,获得,带走",
"carry on":"v:承,发扬,绍,接着,抱,吊膀子,搞,继续,接班,因,承接,继承",
"carry out":"v:展开,付诸实施,推行,行,执,履,售,逞,开展,践,履行,施行,施",
"carry over":"v:保留,贮存,持续",
"carry through":"v:帮助,维持,进行",
"carry weight":"v:举足轻重,算,重要",
"carry-over":"n:滞销品,滚存,余量,结转",
"carryall":"n:刮刀",
"carrying":"v:运输,运送",
"carrying cost":"n:运输费",
"carsickness":"v:晕车;n:晕车",
"cart":"n:大车,马车,手推车;v:带走,拿走",
"cartage":"n:运费",
"cartel":"n:卡特尔,挑战书",
"carter":"n:卡特,车夫,车把式,车把势,掌鞭",
"cartilage":"n:软骨",
"cartload":"n:大量",
"cartographer":"n:制图员",
"cartography":"n:制图学",
"carton":"n:纸板,纸匣",
"cartoon":"n:漫画,卡通,草图,连环画,动画",
"cartoonist":"n:漫画家",
"cartridge":"n:磁带盒,子弹,弹药,针头,软片,枪子儿,笔芯,胶卷,炮弹,暗盒,枪弹,胶片",
"cartridge clip":"n:弹夹,梭子",
"cartwheel":"n:车轮",
"carve":"v:雕刻,刻,切开,雕,抠,锼,雕镌,镂刻,剜,雕琢,割裂,划分,契,锓,錾,创业,分割,勒,锲,琢,镂,切割,泐",
"carve out":"v:剜,创业,分割",
"carve up":"v:割裂,分割,划分",
"carver":"n:雕刻师",
"carving":"n:雕刻,雕刻品,雕花,版刻",
"casaba":"n:香瓜,甜瓜",
"casablanca":"n:卡萨布兰卡",
"cascade":"n:瀑布;v:串联",
"case":"n:情况,案件,案,案子,箱子,病例,问题,案情,案例,事例,诉讼,患者,格,框架,怪人,外壳,实例,起,袋,箱,状况,判例,病症,套,盒子,块,真相,壳,框,例,盒,鞘,元,迷恋,容器,讼案,组,套子,罩;v:查看,窥探,包,围,观察",
"case in point":"v:例证",
"case law":"n:判例",
"case study":"n:专题",
"casebook":"n:记录",
"casein":"n:酪素,干酪素",
"casement":"n:窗户,窗扇,窗框",
"cash":"n:现金,现款,钱;v:兑付",
"cash crop":"n:经济作物",
"cash in":"v:兑现",
"cashew":"n:腰果",
"cashier":"v:解雇,抛弃;n:司库",
"cashier's cheque":"n:本票",
"cashmere":"n:开司米,羊绒,织物,山羊绒",
"casing":"n:套管,围子,罩子,外胎,套,围墙,装箱;v:罩,包装",
"casino":"n:赌场,夜总会",
"cask":"n:桶",
"casket":"n:匣子,盒子,宝库,棺材",
"caspian sea":"n:里海",
"cassava":"n:木薯",
"casserole":"n:沙锅",
"cassette":"n:录音带,磁带盒,弹夹,暗盒,匣子",
"cassette tape":"n:盒带",
"cassia":"n:桂,桂皮,桂皮树",
"cassia-bark tree":"n:肉桂",
"cassiopeia":"n:仙后座",
"cassock":"n:法衣,教士,袈裟",
"cassocks":"n:法衣",
"cassowary":"n:鹤鸵,食火鸡",
"cast":"v:泄劲,废弃,换,排斥,抛射,唾弃,产,合计,甩掉,逐出,早产,左顾右盼,筹划,撂,抛掷,遗弃,占卜;n:模子,铅版,试,投,特征,种类,铸件",
"cast about":"v:左顾右盼",
"cast aside":"v:唾弃,摒,委,撇,屏,排除,扔,吐弃,扔掉,废弃,抛开,弃绝,撂,抛",
"cast away":"v:丢掉,摈弃,排斥",
"cast down":"v:泄劲",
"cast iron":"n:铸铁,铣铁,生铁",
"cast off":"v:甩掉,脱,抛弃,遗弃",
"cast out":"v:逐出",
"cast-iron plant":"n:蜘蛛抱蛋",
"castaway":"n:光棍,流浪者",
"caste":"n:种姓,等级,阶级,品级",
"caster":"n:铸工",
"castigate":"v:痛责,惩戒,苛责,鞭挞,惩罚,修订,诟病",
"castigation":"n:鞭打",
"casting":"n:铸件,铸造;v:铸造,浇铸,熔铸",
"castle":"n:城堡,建筑物,城,车",
"castle in spain":"n:海市蜃楼",
"castoff":"n:废弃物",
"castor":"n:海狸",
"castor bean":"n:大麻子",
"castor-oil plant":"n:大麻子,蓖麻",
"castrate":"v:去势,删改,阉割,割除,窜改,去雄,阉",
"castration":"n:去雄,窜改,阉割,宫刑;v:阉割",
"castries":"n:卡斯特里",
"casual":"a:随便,偶然,漫不经心,马虎,马马虎虎;n:零工,游民;v:漫",
"casually":"d:偶然,胡乱,临时",
"casualties":"n:死伤,伤亡;v:伤亡",
"casualty":"n:事故,受害者,死伤,灾难,横祸,损坏",
"casuistry":"n:诡辩术",
"cat":"n:猫,人,可怜,猫睛石,遗憾,山猫,猫儿眼",
"cat's eye":"n:猫儿眼,猫眼",
"cataclysm":"n:洪水,天翻地覆,渗出;v:渗出",
"catacomb":"n:陵墓,酒窖",
"catalog":"n:目录;v:编目",
"catalogue":"n:目录;v:编目",
"catalpa":"n:梓树,梓",
"catalysis":"v:催化;n:催化",
"catalyst":"n:催化剂,触媒,引线",
"catalytic":"n:催化剂;a:催化",
"catalyze":"v:催化,触发",
"catamaran":"n:筏,双体船",
"catapult":"v:弹,弹射;n:弹弓",
"cataract":"n:白内障,奔流,内障",
"catastrophe":"n:灾难,灾祸,大祸,突变,浩劫,祸殃,事故,虐,难",
"catcall":"n:集会,嘘声,倒好儿,倒彩",
"catch":"v:抓住,得,着,赶上,赶,捉,发现,捉住,看到,捕捉,抓,引起,接,逮住,传染,听到,获,患,理解,发觉,逮,烧,流行,了解,接球,吸引,捉拿,感染,接着;n:利益,门拉手,噎,陷阱,制动器,把握,捕捉,拉手,凸轮;a:警句",
"catch cold":"n:受凉,感冒,受寒,伤风",
"catch crop":"n:间作",
"catch fire":"v:失火,走水,发火",
"catch it":"v:挨骂",
"catch on":"v:理解",
"catch out":"v:发现,看出",
"catch some z's":"v:小睡",
"catch up":"v:撵",
"catch up with":"v:追上,追",
"catchall":"n:手提包,垃圾箱",
"catcher":"n:接手,除尘器",
"catchment":"n:流域,排水",
"catchup":"n:果酱",
"catchword":"n:口号,标语,流行语",
"catechism":"n:盘问,提问",
"catechize":"v:盘问",
"categorical":"a:斩钉截铁,无条件",
"categorically":"d:断然,概",
"categories":"n:派别",
"categorise":"v:分类",
"categorize":"v:分类",
"category":"n:范畴,种类,类型,类别,类,部属,门类,属,部类,部门,门,品类",
"cater":"v:迎合,面向,投合,投",
"catercorner":"n:对角线",
"caterpillar":"n:毛虫,毛毛虫,履带",
"caterpillar track":"n:链轨,履带",
"caterpillar tread":"n:履带",
"caterwaul":"v:尖叫,追求",
"catfish":"n:鲇鱼,鲇",
"catgut":"n:羊肠线,肠腺",
"cathartic":"n:泻药,打药",
"cathartics":"n:泻药",
"cathay":"n:中国",
"cathedral":"n:教堂,天主堂",
"catheter":"n:导管",
"cathode":"n:阴极,负极,负电极",
"catholic":"n:天主教徒;a:一般",
"catholicism":"n:天主教",
"catholicity":"n:宽宏大量,普遍性",
"cation":"n:阳离子,正离子",
"catkin":"n:柳絮",
"catnap":"v:假寐;n:打瞌睡",
"catnip":"n:荆芥",
"cattail":"n:蒲,香蒲",
"cattle":"n:牛,牲口,家畜,黄牛",
"cattle grid":"n:牛栏",
"cattle ranch":"n:牧场",
"caucasian":"n:白人",
"caucasus":"n:高加索",
"cauldron":"n:鼎",
"cauliflower":"n:菜花,花菜,花椰菜",
"caulk":"v:堵",
"causal":"a:原因",
"causality":"n:因果性",
"causation":"n:引导,引起,导致",
"cause":"n:问题,动机,事件;v:致使,惹,招致;p:因,由;c:故",
"cause of action":"n:案由",
"cause of death":"n:死因",
"causerie":"n:随笔,漫谈",
"causeway":"n:公路,人行道",
"causing":"v:产生",
"caustic":"n:苛性钠,苛性碱;a:腐蚀剂,尖刻",
"caustic potash":"n:氢氧化钾",
"caustic soda":"n:烧碱,苛性钠,苛性碱,氢氧化钠,火碱",
"cauterization":"n:烧灼,麻木;v:烧灼",
"cauterize":"v:烧灼,腐蚀,灸,烙",
"caution":"n:小心,谨慎;v:告诫,警告",
"cautious":"a:谨慎,小心,持重,仔细;v:慎;d:谨",
"cautiously":"d:小心翼翼",
"cautiousness":"n:谨慎",
"cavalcade":"n:车队,船队",
"cavalier":"v:护送;n:骑士",
"cavalry":"n:骑兵,马队,骑,马,铁骑,铁马",
"cavalryman":"n:骑兵,骑",
"cave":"n:洞穴,山洞,洞;v:翻转",
"cave in":"v:下陷,凹,陷,塌陷,下沉,陷落,倒塌,坍方,屈服,塌,坍塌",
"caveat":"n:告诫,警告",
"cavendish":"n:板烟",
"cavern":"n:山洞,洞穴,硐,洞窟,龙洞",
"caviar":"n:鱼子酱,美味",
"cavil":"v:吹毛求疵;n:吹毛求疵",
"caving":"v:窟窿;n:窟窿",
"cavity":"n:腔,洞,空洞,空穴,中空,窟窿,窝,穴,孔穴",
"cavort":"v:跳跃,腾跃,欢跃",
"caw":"d:哑哑;n:呱呱;v:啼",
"cay":"n:沙洲,珊瑚礁",
"cayenne":"n:辣椒,辣椒粉",
"cayenne pepper":"n:辣子,辣椒",
"cayuse":"n:马",
"cd":"n:光盘",
"cease":"v:停止,已,停,结束,终止,停息,休止,停歇,住,罢,休;n:终止,停止;d:已;f:为止",
"cease-fire":"n:停火",
"ceasefire":"n:停火",
"ceaseless":"a:不断,不停",
"ceaselessly":"d:不住,不休,不断",
"ceasing":"v:终止,间断,停止",
"cecum":"n:盲肠",
"cedar":"n:雪松,杉树,柏,柏树",
"cede":"v:割让,放弃",
"ceiling":"n:天花板,顶棚,天棚,生气,升限,隔板,顶板",
"celeb":"n:要人,名人",
"celebrate":"v:庆祝,举行,歌颂,庆贺,欢庆,赞美,过,庆,喜庆,做,发表,表扬,公布,祝贺",
"celebrated":"a:著名,有名;v:鼎鼎大名,大名鼎鼎,著称",
"celebration":"n:庆祝,庆典,仪式,称赞,典礼,赞美",
"celebrities":"n:名流",
"celebrity":"n:名人,闻人,名流,名声,著名,扬名,风云人物",
"celerity":"n:敏捷,迅速,神速",
"celery":"n:芹菜,芹,旱芹",
"celestial":"n:天神,神仙",
"celestial body":"n:光,星球,星体",
"celestial globe":"n:浑天仪,浑象",
"celestial sphere":"n:天球,天体,天球仪",
"celibacy":"n:独身,禁欲,贞洁",
"cell":"n:细胞,牢房,电池,单元,管,容器,单体,元件,槽,蜂房,气囊,小组,格子,花粉囊,舱,隔板,手机,蜂窝,盒",
"cell nucleus":"n:窝",
"cellar":"n:地窖,地下室,酒窖,地窟,地窨子,菜窖,窖",
"cello":"n:大提琴",
"cellophane":"n:玻璃纸,赛璐玢",
"cellular":"a:细胞",
"cellular phone":"n:大哥大,手机",
"celluloid":"n:赛璐珞,电影,假象牙",
"cellulose":"n:纤维素",
"celsius scale":"n:摄氏温度计",
"cement":"v:凝结,胶合,加强,胶结,巩固,强化,接合,粘结,结;n:洋灰,士敏土,胶泥,水门汀",
"cemented":"v:胶结",
"cementum":"n:水泥",
"cemetery":"n:墓地,公墓,坟茔,陵园,坟地,墓茔",
"cenobite":"n:修道士",
"cenotaph":"n:衣冠冢,纪念碑",
"cenozoic":"n:新生界",
"censer":"n:香炉",
"censor":"n:审查,检查员;v:审查,检查,删改",
"censorship":"n:检查,审查,关卡",
"censure":"v:责难,批评;n:指责",
"census":"n:调查,统计;v:统计",
"cent":"n:零钱,分,百,分币",
"centavo":"n:分",
"center":"n:中心,中间,中央,心,圆心,中枢,中,核心,中锋,根源,震源,焦点,顶针,大本营,起源,基点,正中;v:居中",
"center of gravity":"n:重心",
"center on":"n:围绕",
"centigrade":"n:摄氏",
"centigrade thermometer":"n:摄氏温度计",
"centimeter":"n:厘米,公分",
"centimetre":"n:厘",
"centipede":"n:蜈蚣",
"central":"a:中心;n:接线员",
"central america":"n:中美洲",
"central nervous system":"n:中枢神经",
"centralism":"n:集中制",
"centrality":"n:中心",
"centralization":"n:集中,中央集权",
"centralize":"v:集中,一元化",
"centralized":"a:统一,一元化;v:一元化,统一",
"centre":"n:心,中间,站,中;v:居中",
"centrifugal":"a:离心;n:离心机",
"centrifugal pump":"n:离心泵",
"centrifuge":"n:离心机",
"centrist":"n:稳健派,温和派,中间派",
"centuries":"n:千秋",
"century":"n:世纪,百年,百",
"ceramic":"n:陶器;a:陶瓷",
"ceramics":"n:陶瓷",
"cereal":"n:谷类,谷物",
"cereals":"n:稼,粮食作物,粮食",
"cerebellum":"n:小脑",
"cerebral hemorrhage":"n:脑出血,脑溢血",
"cerebrate":"v:思索,思考",
"cerebration":"n:思考",
"cerebrospinal fluid":"n:脑脊液",
"cerebrum":"n:脑,大脑",
"cerement":"n:寿衣",
"ceremonial":"a:礼仪",
"ceremonial occasion":"n:大典",
"ceremonious":"a:隆重",
"ceremony":"n:仪式,典礼,礼节,礼仪,礼,式,典,仪节,虚礼,仪",
"cerise":"n:粉红色;a:水红",
"cerium":"n:铈",
"certain":"a:某些,一定,肯定,某种,一些,某,确定,有把握,必然;r:某些,某个;n:准儿",
"certainly":"d:当然,肯定,一定,无疑,的确,准,保管,决计,必,定然,固,管保,决;v:管保",
"certainty":"n:肯定,把握,必然,确实,确定性,必然性,准谱,确信,准谱儿",
"certificate":"n:证书,证明,证件,证明书,文凭,凭证,证券,证,证明信,执照,据,凭照,照,单据,明证,状;v:鉴定,照",
"certificate of deposit":"n:存单",
"certificate of indebtedness":"n:借据",
"certification":"n:证明书,鉴定,证明",
"certify":"v:证明,批准,宣布,宣称",
"certitude":"n:确定,必然性,确实,确信",
"cerulean":"n:天蓝色",
"cervix":"n:颈,颈部",
"cervix uteri":"n:宫颈",
"cesium":"n:铯",
"cessation":"n:停止,休止,取消",
"cession":"n:割让,转让",
"cesspit":"n:粪坑",
"cesspool":"n:粪坑,粪池,潴",
"cetacean":"n:鲸",
"ceylon":"n:锡兰",
"cf.":"v:参见,参看",
"cha":"n:查",
"chad":"n:乍得",
"chafe":"v:擦伤,焦躁,摩擦,恼怒,发怒,着急,冲洗;n:发火,擦伤,急躁",
"chaff":"n:戏弄;v:打趣",
"chaffinch":"n:花鸡",
"chagrin":"n:悔恨,懊恼,委屈",
"chain":"n:链,链条,链子,锁链,一连串,表链,一系列,连续,项圈,脉;v:把,绵联,连锁",
"chain reaction":"n:连锁反应,链式反应",
"chaining":"v:丈量",
"chains":"n:枷锁,锁链",
"chair":"n:椅子,椅,主席;v:主持",
"chairman":"n:主席,主任委员,主任,议长,委员长,会长",
"chairmen":"n:主席",
"chairperson":"n:主席",
"chalet":"n:小屋",
"chalice":"n:酒杯",
"chalk":"v:记账,记分;n:粉笔,白垩",
"chalk line":"v:划线",
"chalk up":"v:记分,记账",
"chalkboard":"n:黑板",
"chalkiness":"n:白垩",
"challenge":"n:挑战;v:引起,怀疑,需要",
"chamber":"n:室,房间,卧室,腔,寝室,心室,穴,会所,套房,箱,矿车,会议室;a:室内;v:装",
"chamberlain":"n:侍从,管家,收款员",
"chambermaid":"n:侍女,女仆,使女",
"chameleon":"n:变色龙,石龙子",
"chamois":"n:麂皮",
"chamois leather":"n:麂皮",
"champ":"v:不耐烦,咬牙切齿,焦急,嚼;n:嚼",
"champagne":"n:香槟酒,香槟,平野",
"champion":"v:拥护,主持,主张;n:优胜者",
"championship":"n:冠军,锦标赛,提倡,拥护,优胜,冠军赛,锦标,支持",
"championships":"n:锦标赛",
"chance":"n:机会,希望,偶然,可能性,时机,冒险,许多,运气,碰巧,命运,危险,良机,时间,机,侥幸,机缘,机率,形势,偶然性,时,赌博,概率,幸运;v:不期而遇,抓住,发生,遇;a:偶发,侥幸,偶然",
"chance on":"v:不期而遇",
"chance upon":"n:碰见",
"chancel":"n:圣坛",
"chancellery":"n:官邸",
"chancellor":"n:大臣,宰相,总理,校长",
"chanciness":"n:危险性",
"chancre":"n:下疳",
"chancy":"a:危险",
"chandler":"n:零售商",
"chang":"n:常",
"changan":"n:长安",
"change":"v:改变;n:反向,交换,交替,零头,转调,更迭,无常",
"change hands":"n:倒换",
"change over":"v:改变,转入",
"changeability":"n:易变,可变性",
"changeable":"a:多变,变化无常,反复无常,反复,无常,可变,变幻莫测,幻,变",
"changeableness":"n:易变",
"changeless":"v:一成不变;a:一成不变",
"changeling":"n:低能儿",
"changeover":"n:变更,改变,转变,转换",
"changes":"v:变迁",
"changjiang":"n:昌江",
"channel":"n:信道,通道,渠道,航道,海峡,水道,频道,系统,途径,沟,道,沟渠,河槽,河床,管道,电路;v:开,开辟",
"channels":"v:经",
"chant":"v:唱,吟唱;n:赞美诗",
"chantey":"n:船歌",
"chaos":"n:混乱,乱,混沌,浑沌,一团糟;a:紊乱,乱,混乱",
"chaotic":"a:紊乱,扰扰,浊,纷乱,洪荒,乱纷纷,乱糟糟,乱蓬蓬",
"chap":"n:家伙,小伙子,小子;v:皲裂,裂开,龟裂,开口子,小伙子",
"chaparral":"n:树丛",
"chapel":"n:教堂,礼拜",
"chaperon":"v:护送,伴随,陪伴",
"chaplain":"n:牧师",
"chaplet":"n:花冠,项圈",
"chapman":"n:行商",
"chapter":"n:章,部分,数字,分会,符号,回",
"char":"n:炭,沙洲,木炭;v:打杂,炭化",
"character":"n:字符,性格,人,人物,字,字母,人格,数字,品格,符号,特征,性质,性状,特性,角色,人品,品质,文字,名声,地位,品,脚,性,资格,奇人,字儿,记号,人头,声望,质地,角,怪人,脾性,质,骨头,鉴定,身分,秉性,性行;v:画,刻",
"characteristic":"n:特性,特征,特点,性能;a:特有",
"characteristics":"n:特性",
"characterization":"n:表征,鉴定",
"characterize":"v:刻画,描绘,形容,鉴定",
"characters":"n:文字",
"charcoal":"n:木炭,炭,炭画,炭笔,木炭画",
"charcoal gray":"n:深灰色",
"chard":"n:牛皮菜",
"charge":"n:电荷;v:猛攻,冲杀,促,赊购,职掌,充",
"charge card":"n:信用卡",
"charge d'affaires":"v:临时代办",
"charged":"v:带电",
"charger":"n:充电器,战马",
"charges":"n:费用",
"charging":"v:充电,加料,增长;n:进料,炉料",
"chariness":"n:吝啬,谨慎,节俭,小心",
"chariot":"n:战车",
"charisma":"n:魅力",
"charitable":"a:慈善,慈悲",
"charity":"n:慈善,施舍,仁爱,博爱,仁慈,恩赐,慈爱,捐助,抚恤金,善事,宽容,宽大",
"charlatan":"n:骗子,江湖骗子,庸医",
"charlatanry":"a:欺骗",
"charm":"n:魅力,魔力;v:迷,诱惑",
"charmer":"n:魔术师",
"charming":"a:迷人,妩媚,娇",
"charred":"v:焦;a:焦",
"charring":"v:炭化",
"chart":"n:图,图表,地图,表,海图,航海图,表格,地形图,曲线图;v:制图",
"charter":"n:宪章;v:雇",
"chary":"a:吝啬",
"chase":"v:追逐,追赶,追,追求,追捕;n:沟,槽",
"chase after":"v:追逐,追,追赶",
"chase away":"v:赶走",
"chaser":"n:猎人,战斗机,板牙,歼击机",
"chasing":"v:抛光",
"chasm":"n:断层,鸿沟,深渊,分歧,堑,峡谷,陷坑,裂口,空隙,隔阂",
"chassis":"n:底盘,机架,框,体态,拖车,机箱,身段",
"chaste":"a:贞洁,纯洁,贞",
"chasten":"v:惩戒,磨炼,惩罚,推敲,精练,遏制,责罚",
"chasteness":"n:贞节",
"chastise":"v:惩罚,严惩,谴责,打败,惩戒,净化,惩办",
"chastisement":"n:惩罚;v:惩办",
"chastity":"n:贞操,纯洁,贞节,朴素,童贞,操守,贞,节,简洁",
"chat":"v:聊天,闲聊,闲谈,聊;n:闲话,鸣禽",
"chateau":"n:城堡,公馆",
"chats":"n:碎石",
"chattel":"n:动产,物,奴隶",
"chatter":"v:唠叨,震动;n:碎嘴子;d:喳喳",
"chatterbox":"n:话匣子",
"chatterer":"n:画眉",
"chatty":"a:闲",
"chauffeur":"v:开;n:司机",
"chauvinism":"n:沙文主义",
"cheap":"a:便宜,廉价,低廉,蹩脚,粗劣,贱",
"cheap-jack":"a:小贩",
"cheapen":"v:跌价,贬损,减价,便宜",
"cheaply":"d:便宜,廉价",
"cheapness":"n:便宜,廉价",
"cheapskate":"n:小气鬼,守财奴",
"cheat":"v:作弊,欺骗,骗,欺诈,行骗;n:骗子",
"cheater":"n:骗子,眼镜",
"check":"v:检查;n:同意,屋檐,校,校对,斥责,将军,阻止,妨碍,格,答应",
"check in":"v:登记,签到",
"check mark":"v:对号",
"check off":"v:查讫",
"check out":"v:离开",
"check over":"v:检视,检查",
"check stub":"v:存根",
"check up on":"v:查清,检查,核对",
"checkbook":"n:支票簿",
"checked":"v:查讫",
"checker board":"n:棋谱",
"checkerboard":"n:棋盘",
"checking":"v:阻截,检验,验证,核对,校验",
"checklist":"n:清单,名单,目录,调查表",
"checkmate":"v:打败,将军,失败,挫折,击破",
"checkout":"v:测试,检验,检测;n:检验,结账",
"checkpoint":"n:检查站",
"checkroom":"n:衣帽间",
"checkup":"n:检查,核对,查对,对照,检验",
"cheek":"n:颊,面颊,脸,脸蛋,脸皮,厚脸皮,腮帮子,厚颜无耻,腮颊,边框,腮,面皮",
"cheek pouch":"n:肷",
"cheekbone":"n:颧骨,颊骨,颧",
"cheekiness":"n:厚脸皮",
"cheeks":"n:脸蛋儿",
"cheeky":"a:不要脸,厚脸皮;v:涎皮赖脸",
"cheep":"v:吱声",
"cheer":"v:欢呼,高兴;n:心情,振奋,欢声,款待,菜肴",
"cheer up":"v:打气,鼓舞",
"cheerful":"a:愉快,高兴,快乐,快活,快快乐乐,融融,愉悦,宽畅,乐,怡,愉,乐陶陶",
"cheerfulness":"n:愉快,高兴,快活,爽快",
"cheering":"v:鼓励,安慰,喝彩,欢呼",
"cheerio":"i:再会,回见,干杯",
"cheerless":"a:怏怏不乐,冷淡",
"cheers":"n:谢谢,欢呼声;v:干杯",
"cheery":"a:喜气洋洋",
"cheese":"n:乳酪,干酪,奶酪,上品,珍品",
"cheese cutter":"n:自行车",
"cheeseparing":"n:吝啬",
"cheetah":"n:猎豹",
"chef":"n:厨师,炊事员,大师傅,主厨",
"chemical":"a:化学;n:药品",
"chemical bond":"n:化学键",
"chemical change":"n:化学变化",
"chemical energy":"n:化学能",
"chemical formula":"n:化学式",
"chemical industry":"n:化学工业",
"chemical reaction":"n:化学反应",
"chemical warfare":"n:化学战",
"chemicals":"n:化学药品",
"chemist":"n:化学家,药剂师,司药",
"chemist's shop":"n:药房,药店",
"chemistry":"n:化学,化",
"chemotherapy":"n:化疗;v:化疗",
"chen":"n:陈",
"cheque":"n:支票",
"chequer":"n:格子",
"cherish":"v:怀着,抱,珍视,存,珍爱,钟爱,爱,怀,珍惜,爱护,爱惜,心怀,怀抱,赍,含,抚育,惜",
"cherry":"n:樱桃,处女膜,樱,童贞",
"chert":"n:燧石",
"chess":"n:国际象棋,棋,象棋",
"chess board":"n:棋谱",
"chess game":"n:棋局,棋类",
"chessboard":"n:棋盘,枰,局",
"chessman":"n:棋子",
"chest":"n:胸部,胸,胸膛,胸脯,胸腔,箱子,胸口,肺,箱,匣,函,脯,躺柜,笼子,臆,膛,资金,柜子,金库,卧柜,柜,匈",
"chest of drawers":"n:五斗橱",
"chesterfield":"n:睡椅",
"chestnut":"n:栗子,板栗,褐色,栗色,滥调",
"chestnut tree":"n:栗",
"chevalier":"n:骑士,爵士,勇士,武士,义士",
"chevron":"n:袖章",
"chevy":"v:追赶;n:追赶",
"chew":"v:嚼,咀嚼,思考,想,吃,谈话,沉思,咬嚼,讲;n:咀嚼",
"chew over":"v:思考,想",
"chewing gum":"n:口香糖,橡皮糖",
"chi":"n:市尺",
"chic":"a:别致,漂亮;n:时髦",
"chicago":"n:芝加哥",
"chicane":"n:诡辩,狡辩,诈骗;v:诈骗",
"chicanery":"n:诈骗,诡计,狡辩,诡辩",
"chick":"n:雏鸡,鸡雏,小鸟,子鸡,少妇,仔鸡",
"chickadee":"n:山雀",
"chicken":"n:鸡,鸡肉,鸡雏,懦夫,童子鸡,娃娃,油鸡,雏鸡,胆小鬼",
"chicken broth":"n:鸡汤",
"chicken soup":"n:鸡汤",
"chickenhearted":"a:畏怯",
"chickenpox":"n:水花",
"chicory":"n:苣荬菜",
"chide":"v:责备,责骂,呲,教训,呵叱,昧,咆哮",
"chief":"n:酋长,首领,长,领袖;a:首",
"chief executive":"n:元首",
"chief justice":"n:审判长",
"chief of state":"n:元首",
"chiefly":"d:主要,首先",
"chieftain":"n:头目,头子,酋长,土司,族长,地位,队长,首领,酋",
"chigger":"n:恙虫",
"chignon":"n:鬏,髽,髽髻,发髻",
"chilblain":"n:冻疮,冻瘃,瘃",
"child":"n:孩子,儿童,小孩,子女,小儿,小孩儿,婴儿,幼儿,孩童,童,子孙,娃娃,产物,后裔,儿,胎儿,娃,孩子家,孩儿,追随者,孩,小朋友,子弟,稚子,娃子,孺子,弟子,伢,囡,孺,少爷",
"child care":"n:保育",
"childbearing":"n:分娩,生产",
"childbirth":"v:分娩,生产;n:分娩,生产",
"childhood":"n:童年,儿时,幼年",
"childish":"a:幼稚,孩子,稚",
"childishness":"n:童心,稚气,孩子气",
"children":"n:小儿,孩子,小朋友,少儿,儿女,囝,儿童,孥,幼,子弟,子女",
"chile":"n:智利",
"chili":"n:辣椒",
"chili sauce":"n:辣酱",
"chill":"n:扫兴,寒气;v:发冷,冰冻,冷藏;a:寒冷,凉飕飕,寒",
"chiller":"n:冷却器",
"chilliness":"n:疏远,严寒,寒气,冷淡,寒冷",
"chilling":"a:冷森森,冷飕飕;v:淬火",
"chilly":"a:冷飕飕,凉飕飕,辣丝丝,冷森森,料峭,清冷,凄,泠",
"chime":"n:钟声,调和,一致,单调,沟,韵律;v:打,调和,附和,同意,鸣,赞成",
"chime in":"v:插嘴,赞成",
"chimera":"n:怪物,妄想,幻想,奇想",
"chimerical":"a:幻想",
"chimney":"n:烟囱,烟筒,烟尘,灯罩,囱,突",
"chimp":"n:黑猩猩",
"chimpanzee":"n:黑猩猩",
"chin":"v:谈话,讲,闲聊,说,聊天;n:聊天",
"chin music":"v:责骂,口才,空谈,闲谈",
"chin-wag":"n:闲谈",
"china":"n:瓷器,瓷,中,磁,支那,中方,华",
"china aster":"n:翠菊",
"china clay":"n:瓷土,陶瓷",
"china grass":"n:线麻",
"china tree":"n:苦楝,楝树",
"chinaware":"n:瓷器",
"chinchilla":"n:灰鼠,银灰色",
"chine":"n:幽谷,山脊,脊骨,裂纹",
"chinese":"n:中文,国,华,华文,国文,汉文",
"chinese alligator":"n:鼍",
"chinese anise":"n:八角茴香",
"chinese cabbage":"n:白菜,菘,青菜",
"chinese checkers":"n:跳棋",
"chinese chestnut":"n:板栗",
"chinese cinnamon":"n:桂",
"chinese date":"n:枣",
"chinese gooseberry":"n:猕猴桃",
"chinese paddlefish":"n:白鲟",
"chinese parasol":"n:梧桐,荣,梧",
"chinese rhubarb":"n:大黄",
"chinese scholar tree":"n:槐树,槐",
"chinese water chestnut":"n:马蹄",
"chinese white":"n:锌白",
"chink":"n:裂缝,弱点,现款,漏洞,裂口,罅隙,隙;v:开裂,破裂",
"chip":"v:凿,捐助;n:筹,码子,薄片",
"chip away":"v:毁损",
"chip in":"v:捐献,插话,插口,凑钱,捐助,赞助",
"chipboard":"n:刨花板,硬纸板",
"chipper":"a:快乐",
"chipping":"n:碎片,薄片",
"chippy":"n:妓女",
"chirography":"n:书法,笔迹",
"chirp":"n:哨,叽叽喳喳,吱;d:吱,唧唧;v:鸣叫",
"chirps":"v:啾啾",
"chisel":"v:刻,欺诈,琢,雕凿,雕刻,雕,錾,镌;n:凿",
"chit":"n:黄毛丫头,少女,幼儿,小孩,小孩子,幼芽,账单,收条",
"chitchat":"n:闲话;v:聊天,拉扯,闲谈,攀谈,叙谈",
"chitin":"n:壳质",
"chittagong":"n:吉大港",
"chivalrous":"a:侠义,侠",
"chivalry":"n:豪侠",
"chive":"n:小刀,韭菜",
"chloric acid":"n:氯酸",
"chloride":"n:氯化物;a:氯化",
"chlorinate":"v:氯化",
"chlorinated lime":"n:漂白粉",
"chlorinating":"v:氯化",
"chlorination":"n:氯化",
"chlorine":"n:氯,氯气",
"chloroform":"n:氯仿",
"chlorophyll":"n:叶绿素",
"chloroplast":"n:叶绿体,叶绿素",
"chock":"n:楔子;d:完全",
"chocolate":"n:巧克力,可可,朱古力",
"choice":"n:选择,审慎,挑三窝四,精华;a:精,珍视;v:选择",
"choice of words":"n:用语",
"choir":"n:合唱团,队,组,群",
"choke":"v:窒息,堵住,呛,哽,阻塞,堵塞,扼,绞死,抑止,阻止,节流,摆脱,背气,减,噎,抑制;n:噎,喉管,拥塞",
"choke off":"v:摆脱",
"choke up":"v:堵住",
"choked":"v:淤滞",
"choker":"n:领带,钳子,夹具",
"choking":"v:堵塞,阻塞;n:闷气",
"choler":"n:胆汁",
"cholera":"n:霍乱",
"cholesterol":"n:胆固醇",
"choline":"n:胆碱,生化",
"chomp":"n:嚼",
"choose":"v:选择,选,挑选,挑,决定,喜欢,想,选拔,选用,抉择,择,点,取,选取,推举,宁愿,推选,拔取,拣,举,涓,简,遴,物色,抡,推,选购,欲,拣选,看中,别择,卜,评选",
"choosy":"a:挑三拣四",
"chop":"v:砍,劈;n:裂口",
"chop off":"v:刽,切,斩断",
"chop up":"v:割断,切开,菹",
"chop-chop":"d:快快,赶快",
"chophouse":"n:海关",
"chopin":"n:肖邦",
"chopper":"n:斤,斧头,屠刀,柴刀,斧子,劈刀,砍刀,直升机",
"chopping":"n:剁,伐,砍;v:斩断,削球",
"chopping block":"n:俎",
"chopping board":"n:案板,菜板,菜墩子",
"choppy":"v:生涩;a:生涩",
"chopstick":"n:筷子",
"chopsticks":"n:筷,筷子",
"choral":"n:赞美诗",
"chorale":"n:赞美诗",
"chord":"n:弦,和弦,和谐,带;v:弹奏,调和",
"chordate":"n:脊索动物",
"chore":"n:杂务,杂事,零活儿",
"chorea":"n:舞蹈病",
"choreograph":"v:设计,筹划",
"chores":"n:零活儿",
"choroid":"n:脉络膜",
"chortle":"v:哈哈大笑;n:哈哈大笑",
"chorus":"n:合唱,合唱团,大合唱,合唱队;v:合唱",
"chose":"n:动产,物",
"chow":"n:州,吃饭",
"chow mein":"n:炒面",
"chowder":"n:杂烩",
"christ":"n:基督",
"christen":"v:洗礼,命名",
"christendom":"n:基督教徒",
"christian":"n:基督教徒,信徒,正派人,人类",
"christian era":"n:公元",
"christianity":"n:基督教,天主教",
"christmas":"n:圣诞节",
"christmas card":"n:圣诞卡",
"christmas flower":"n:一品红",
"christopher":"n:克里斯托弗",
"chroma":"n:色度",
"chromatic":"a:色散;v:套色",
"chromatic colour":"n:彩色",
"chromatically":"d:上色",
"chromatography":"n:套色版,套色,套印",
"chrome":"n:铬,黄色",
"chroming":"v:镀铬;a:镀铬",
"chromite":"n:铬铁矿,铬铁",
"chromium":"n:铬",
"chromosome":"n:染色体",
"chronic":"a:慢性,长期,痼,锢",
"chronicle":"n:编年史,记录,纪事;v:记录",
"chronicles":"n:汗青,记事,编年史;v:记事",
"chronograph":"n:停表,计时器,秒表",
"chronology":"n:年表,年代学",
"chronometer":"n:天文钟",
"chrysalis":"n:蝶蛹",
"chrysanthemum":"n:菊花,墨菊,菊,黄花,秋菊",
"chub mackerel":"n:鲐,鲐鱼",
"chubby":"a:胖乎乎",
"chuck":"v:扔,抛,辞职,丢弃,停止,浪费,失去,抚摸,逐出;n:爱抚,辞退,放弃,封罐机,伙食,粮食;i:亲爱的",
"chucker-out":"n:保镖",
"chucking":"v:夹具;n:夹具",
"chuckle":"v:暗笑,哈哈大笑;d:咯咯",
"chum":"n:密友,鱼饵,同事",
"chummy":"n:密友;a:热乎",
"chump":"n:发狂,木块",
"chunk":"n:块,大量,块儿;v:截",
"church":"n:教堂,教会,教派,礼拜堂",
"church service":"n:礼拜",
"churchill":"n:邱吉尔",
"churchman":"n:教士,牧师",
"churchyard":"n:墓地,境内",
"churl":"n:吝啬鬼,守财奴",
"churn":"v:翻腾,搅拌;n:搅拌",
"churning":"v:搅拌",
"chute":"n:滑道,急流,瀑布,奔流",
"chutzpa":"n:厚颜无耻,胆大妄为",
"chutzpah":"n:胆大妄为,厚颜无耻",
"chyme":"n:生理",
"cicada":"n:蝉,知了,蜩",
"cicatrice":"n:疤痕,斑痕",
"cicerone":"n:向导",
"cigar":"n:雪茄,雪茄烟,卷烟",
"cigarette":"n:香烟,烟,吸烟,纸烟,烟卷,卷烟,烟卷儿",
"cigarette case":"n:烟盒",
"cigarette holder":"n:烟嘴",
"cigarillo":"n:香烟",
"cilia":"n:睫毛,纤毛,细毛,睫",
"cilium":"n:纤毛",
"cinch":"n:绳结,紧握;v:确保,确定",
"cinchona":"n:金鸡纳霜,奎宁,金鸡纳树",
"cincinnati":"n:辛辛那提",
"cincture":"n:环带,围绕",
"cinder":"n:煤渣,灰烬,骨灰,炉渣",
"cine":"n:电影",
"cinema":"n:电影,电影院,影院,影片,电影厅",
"cinnabar":"n:丹,辰砂,朱砂,丹砂,银朱",
"cinnamon":"n:肉桂,桂皮",
"cipher":"n:密码,小人物,数码,暗码;v:计算",
"circa":"p:大约;d:大约",
"circe":"n:女巫",
"circle":"n:圆,圈子;v:旋,环行,旋转",
"circle around":"v:盘旋",
"circle round":"n:回翔,打圈子,周旋",
"circles":"n:界,林,坛",
"circuit":"n:电路,线路,回路,巡回,环路,周,周游,健身操,通路,流程;v:环行",
"circuitous":"a:迂回,迂曲;v:迂回",
"circuitry":"n:电路,电路图",
"circuits":"n:电路",
"circuity":"n:转弯抹角,迂回,迂曲",
"circular":"n:通知,通告,传单,圆形,通报,团;a:迂回",
"circular measure":"n:弧度",
"circularity":"n:圆,环状,圆形",
"circularize":"v:分发,公布,传递,传阅",
"circulate":"v:循环,流传,流通,散布,传播,传阅,流行,环流,散播,行,流动,流转,运行,周转,巡回",
"circulating":"v:循环",
"circulating decimal":"n:循环小数",
"circulation":"n:循环,流通,发行量,发行,环流,货币,传播,运行,旋转,销路;v:循环,旋转",
"circumcision":"n:割礼,净化",
"circumference":"n:周长,圆周,周围,四周,匝,周,方圆",
"circumlocution":"n:躲闪,偏锋",
"circumnavigation":"v:环行;n:环行",
"circumscribe":"v:限制,限定,约束,框",
"circumscription":"n:区域,花边,限制,范围,定义,界线,限界",
"circumspect":"a:谨,审慎,谨慎;v:小心谨慎;d:谨",
"circumspection":"n:慎重",
"circumstance":"n:情况,环境,情形,形势,境况,事情,机会,命运,详情,情势,事实,事态,细节,情景,境遇,仪式,境,境地,形式,事故,原委,情境",
"circumstances":"n:光景,阵势,境域,事机,景况,情境,情形,环境,景遇,情景,情况,形势,境地,情节,情事,遭际,阵脚,状,境况,情,情势,场景,境遇",
"circumstantial":"a:详细",
"circumvent":"v:围困,包围,围绕",
"circumvention":"n:欺骗,计谋,围困,防止",
"circus":"n:马戏团,马戏,竞技场,杂技团",
"cirque":"n:圆圈",
"cirrhosis":"n:肝硬变,肝硬化",
"cirrus":"n:触须,卷须,阴茎",
"cistern":"n:水槽,水缸,蓄水池,水池,水塔,水塘",
"citadel":"n:城堡,要塞,大本营,根据地,避难所",
"citation":"n:例证,引文,引证,援引,引语,表扬,引用,传讯,奖品,列举,传票,引述,奖状",
"cite":"v:引用,引证,表扬,列举,援引,举,表彰,嘉奖,援用,显扬,召集,罗列,引;n:嘉奖,例证,引文",
"citizen":"n:公民,市民,居民,国民,平民,老百姓",
"citric acid":"n:柠檬酸",
"citron":"n:柠檬色,香橼,枸橼",
"citronella":"n:香茅",
"citrus":"n:柑橘",
"citrus reticulata":"n:柑",
"city":"n:城市,城,市,城里,市内,都市,城池,都会,垣,邑",
"city hall":"n:市政府",
"city man":"n:资本家,实业家",
"cityscape":"n:市容",
"civet":"n:灵猫",
"civet cat":"n:灵猫",
"civic":"a:城市",
"civil":"a:民事,公民,民用,民;n:公民,民",
"civil death":"n:无期徒刑,放逐,褫夺公权",
"civil engineering":"n:土建",
"civil servant":"n:公务员,文官",
"civil service":"n:文职",
"civil year":"n:历年",
"civilian":"n:老百姓,平民,文官,民,市民",
"civilians":"n:老百姓",
"civilisation":"n:开化",
"civilise":"v:教化,开化",
"civility":"n:客气,礼仪,礼貌,文化,文明",
"civilization":"n:文明,文化,开化,教化,文",
"civilize":"v:教化,开化",
"civilized":"a:文明,开化",
"clack valve":"n:止回阀",
"cladding":"n:镀;v:封装",
"claim":"v:声称,要求;n:断言",
"claimant":"n:债权人,索赔,原告",
"claimer":"n:索赔,债权人",
"clairvoyance":"n:洞察力,千里眼",
"clairvoyant":"n:火眼金睛",
"clam":"n:蛤蜊,蛤,河蚌,夹子,蚌,一元,夹具,文蛤,银币;v:三缄其口,嘴紧",
"clam up":"v:三缄其口",
"clamber":"v:爬,攀登,攀援,攀缘",
"clamminess":"n:粘性",
"clammy":"a:潮呼呼",
"clamor":"v:叫嚣,吵嚷,哗,叫喊,叫嚷,鼓噪,喧嚷;n:叫喊,声浪,鼎沸,哗然",
"clamorous":"a:聒噪,闹嚷嚷,闹哄哄",
"clamour":"v:叫嚣,哗;n:鼎沸,哗然,叫喊,哗,喧嚷",
"clamp":"n:夹具;v:钳制",
"clamp down":"v:钳制",
"clampdown":"n:取缔,压制",
"clan":"n:氏族,家族,部族,党派,系,队,集群,小集团,亲属,宗,族",
"clandestine":"a:秘密",
"clang":"n:铿锵,当啷,音调,音色,锒铛,叮当,音质;d:当啷;v:当",
"clanger":"n:过失",
"clank":"v:当啷;n:当啷,叮当;d:当啷",
"clannish":"a:氏族",
"clansman":"n:同宗,族人,宗族;v:同宗",
"clap":"v:鼓掌,拍,拍手;n:淋病;d:啪",
"clapboard":"n:隔板",
"clapper":"n:拍板",
"clappers":"n:拍板,板,鼓板",
"clapping":"v:掌声;n:掌声",
"claret":"a:枣红;n:血",
"clarification":"n:澄清;v:澄清",
"clarified":"a:清;v:清",
"clarify":"v:澄清,阐明,弄清,说明,解释,净化,明了,澄",
"clarinet":"n:黑管,单簧管",
"clarion":"n:号角",
"clarity":"n:清晰,明确,清晰度,明了,清澈,透明",
"clash":"v:冲突;n:抵触",
"clasp":"n:扣子,拥抱,紧握,握手,钩,别针,搂抱;v:紧握",
"clasp knife":"n:折刀",
"class":"n:班,阶级,班级,阶层,课,类,优秀,组,等级,等,纲,级,类别,门类,讲习班,路;v:归类,分类",
"class period":"n:课时",
"classes":"n:班次;v:百",
"classic":"n:名著,典范,古典文学,文豪;a:一流",
"classical":"a:古典,经典;n:经典",
"classicism":"n:古典主义",
"classics":"n:经传,经典;p:经",
"classification":"n:分类,等级,分级,别;d:分级;v:分类",
"classified":"a:机密",
"classifier":"n:量词",
"classify":"v:分类,归入,归类,排队,区,分等;d:分级",
"classmate":"n:同学,同班",
"classroom":"n:教室,课堂,讲堂",
"clatter":"n:哗啦啦,骚动,喧嚷;v:哗啦啦,嘚;d:丁当,叮当",
"clause":"n:条款,从句,分句,条文,项目,条,子句,款项,项",
"clavicle":"n:卷须,锁骨",
"clavier":"n:键盘,键盘乐器",
"claw":"n:爪子,爪,脚爪,钳,魔爪,钩;v:搜刮,逮捕",
"claw hammer":"n:钉锤",
"claws":"n:魔爪",
"clay":"n:粘土,泥土,天性,胶泥",
"clay pigeon":"n:飞碟",
"claymore":"n:剑",
"clean":"v:打扫,擦;a:净;d:完全",
"clean out":"v:淘,打扫",
"clean up":"v:荡涤,廓清,肃清,清,梳洗,理,清除,扫除",
"cleaner":"n:清洁工,洗衣店",
"cleaning":"n:清洗,洗涤,扫除,垃圾,输光;v:扫除,清扫;a:清洁",
"cleanliness":"n:清洁",
"cleanly":"d:统统,完全;a:清白",
"cleanness":"n:清洁",
"cleanse":"v:清洗,洗涤,净化,涤,湔,净,溉,涤荡,消毒,擦拭,洁,蠲,澄清,荡涤",
"cleanser":"n:去污粉,去污剂,清洁剂",
"cleansing":"v:垃圾,净化",
"cleanup":"n:澄清,净化,精炼,提纯,扫除,清除",
"clear":"v:收拾,晴,清除,消除;a:清亮,较,澄澈,分明,粼粼,明,明晰,清朗,一清二白,真确,白,敞亮,脆,溜光,亮堂,通畅,真切,澈,澄彻,昭著,朗朗,醒豁;n:堤,间隙,空隙,洞;d:较",
"clear away":"v:扫除,荡,收拾,扫,粪,洗",
"clear off":"v:一扫而光,摆脱,溜走,清理,清偿,走开",
"clear out":"v:丢弃,腾,离开,逃离",
"clear up":"v:放晴,释,整顿,开朗,消除,清,澄清,涣然冰释,白,消释,结束,完成",
"clear-cut":"a:明确",
"clearance":"n:清除,空隙,净空,间隙,结关,结算,解除,清理,清算,除去,扫除;v:结关",
"clearance sale":"n:贱卖",
"clearheaded":"a:惺惺",
"clearing":"n:清除,除去,扫除,雪冤,清算,昭雪;v:解扣,释放,拆线",
"clearly":"d:真,分明,显而易见;a:逼真",
"clearness":"n:澄清",
"cleat":"n:楔子,羊角,夹板",
"cleavage":"n:分裂,开裂,劈开;v:分裂,开裂",
"cleave":"v:劈开,忠于,裂开,坚持,坚守,破,开,劈",
"cleaver":"n:瓦刀",
"clef":"n:谱号",
"cleft":"n:裂缝,裂口,裂片,裂痕,沟纹",
"cleft lip":"n:兔唇,唇裂",
"clemency":"n:仁慈,宽厚,温和,温暖",
"clench":"v:握紧,决定,解决",
"clenching":"v:咬牙切齿,咬紧牙关",
"clerestory":"n:天窗,长廊,气楼",
"clergy":"n:牧师,神职人员,教士,僧侣",
"clergyman":"n:教士,牧师",
"cleric":"n:教士,牧师",
"clerical":"n:教士",
"clerk":"n:职员,书记,办事员,店员,秘书,书记员,教士,营业员,执事,学者,管理员,牧师",
"clerkship":"n:博学",
"clever":"a:聪明,巧妙,伶俐,机灵,精,鬼,聪颖,巧;n:心灵,神",
"cleverly":"d:灵巧,机敏,伶俐,能干,聪明",
"cleverness":"n:聪明,心眼儿",
"clew":"n:线索,线团,暗示;v:提示",
"cliche":"n:陈词滥调,口头禅",
"click":"v:成功,情投意合,吧嗒,单击,一拍即合;n:棘爪,咯噔,插销,门闩,点击;i:吧哒,吧嗒",
"client":"n:委托人,当事人,顾客,客户,主顾,顾主,附庸国,客人",
"clientele":"n:追随者,常客,委托人,顾客",
"cliff":"n:悬崖,峭壁,山崖,崖,断崖,绝壁,削壁,岩,石壁",
"climacteric":"n:绝经期,更年期,转折点,关口",
"climate":"n:气候,风气,地带,趋势,倾向,思潮,风土,水土,天时",
"climax":"n:高潮,顶峰,高峰,顶点,极点,最高峰",
"climb":"v:爬;n:爬高,山坡",
"climb down":"v:认错",
"climb up":"v:攀登,攀越,攀援,缘",
"climb-down":"n:退让,服输",
"climbers":"n:脚扣",
"climbing":"v:爬升,攀登",
"clime":"n:气候",
"clinch":"n:绳结,铆钉,夹子",
"clincher":"n:定论,夹子",
"cline":"n:倾斜",
"cling":"v:紧贴,粘着,依恋,坚持,巴,依靠,紧握,依附,扒",
"cling to":"v:巴,扒,坚持,固执,依附",
"clinic":"n:诊所,会诊,卫生站,卫生所,门诊部,诊室",
"clinical":"a:临床",
"clinical thermometer":"n:体温计",
"clink":"n:监狱,裂缝,现金",
"clinker":"n:熟料,硬币,现金,饼干,缸砖,炉渣,煤渣,猛击",
"clinking":"v:极",
"clinton":"n:克林顿",
"clip":"n:修剪,卡子,钳,梭子,卡,曲别针;v:飞跑",
"clipboard":"n:剪贴板",
"clipper":"n:剪子",
"clipping":"n:剪报,剪辑,剪裁",
"clique":"n:小集团,集团,私党,派,帮,党,朋党,帮会,派别,派系",
"cliquish":"v:小集团;n:小集团",
"clitoris":"n:阴蒂",
"cloaca":"n:暗渠,泄殖腔,下水道",
"cloacae":"n:厕所,泄殖腔,阴沟,下水道",
"cloak":"n:斗篷,外衣,大氅,伪装,借口,外套,幌子,口实,托辞;v:包庇,盖,遮掩,覆",
"cloakroom":"n:衣帽间",
"clobber":"v:打破;n:衣服",
"cloche":"n:玻璃罩",
"clock":"n:钟,时钟,座钟;v:达到",
"clock up":"v:记录,达到",
"clod":"n:土块,块,傻瓜,乡下人,呆子,老粗",
"clodhopper":"n:土包子,粗人,泥腿子",
"clog":"v:妨碍,塞满,阻塞;n:阻碍,制动器,阻塞,木屐,枷,坠子",
"clog up":"v:湮",
"clogged":"v:淤滞",
"clogs":"n:木屐,呱嗒板儿",
"cloisonne":"n:景泰蓝",
"cloister":"n:修道院,寺庙,隐居,回廊,走廊",
"clone":"n:机器人,复制品",
"close":"v:关闭;a:紧身,窒闷,细密,拢,深,贴心,严紧,亲,小气,严实;n:结束;d:接近",
"close at hand":"v:指日可待,近在眉睫,近便,近在眼前,迫近",
"close call":"n:千钧一发",
"close down":"v:封闭,查封,关,停业,关张",
"close in":"v:逼近",
"close to":"p:附近,将近,近乎,守,跟前,靠近,促,仅,近,接近,临近,阽,邻近,在_附近;d:将近;v:巴",
"close together":"v:紧密,比,密集",
"close up":"v:封闭,关闭,靠拢,收口,闭塞,促",
"close-quarter fighting":"n:短兵相接",
"closed":"a:死,封闭式,放学",
"closed circuit":"n:通路,闭路",
"closed loop":"n:闭环",
"closed-circuit":"a:闭路",
"closed-circuit television":"n:闭路电视",
"closefisted":"v:手紧;a:手紧",
"closely":"d:密切,紧紧",
"closemouthed":"a:嘴紧,口紧",
"closeness":"n:亲密,严密,吝啬,狭窄,精密,密闭,接近,环境",
"closet":"n:壁橱,衣橱,橱,壁柜,密室,碗橱,厕所",
"closing":"n:结束,结账,接点;a:闭路;v:收盘",
"closure":"n:关闭,闭合,停业,合龙,结束,隔板,截止,围墙,关,末尾;v:合龙,截流,合拢,结束,截止,闭合",
"clot":"v:凝固,拥塞,凝结;n:聚集",
"cloth":"n:布,布料,桌布,棉布,布匹,织物,教士,制服,帆,毛织品,呢绒,衣料",
"clothe":"v:衣服",
"clothes":"n:衣服,衣衫,衣裳,服,衣,被褥",
"clothes closet":"n:立柜",
"clothes tree":"n:衣架",
"clothespin":"n:衣夹",
"clothier":"n:裁缝",
"clothing":"n:衣服,衣,服装,衣裳,穿戴;v:装",
"clothing store":"n:服装店",
"clotting":"v:结块,凝结,烧结,凝固",
"cloud":"n:云,乌云,云彩,阴影,浮云,朦胧;v:损伤",
"cloudburst":"n:倾盆,大暴雨,倾盆大雨",
"cloudiness":"n:阴暗,云量",
"clouding":"n:模糊",
"cloudless":"v:万里无云;a:万里无云",
"clouds":"n:云层",
"cloudy":"a:多云,阴,阴天,阴沉,涔涔,叆叇;v:噎",
"clout":"n:影响力,势力,击球,衣服;v:猛击,敲打,击打",
"clove":"n:丁香,峡,山路",
"cloven hoof":"n:狐狸尾巴",
"clover":"n:三叶草,苜蓿,草木犀",
"clover fern":"n:田字草",
"clown":"n:小丑,丑角,守财奴,小气鬼;v:闹笑话,说笑话,逗趣",
"cloy":"v:倒胃口",
"club":"n:俱乐部,会,夜总会,梅花,会所,社,棒,棍棒;v:凑集,贡献,联合",
"club moss":"n:石松",
"cluck":"n:咯咯,咕;v:咕咕,咕;d:咯咯",
"clue":"n:线索,头绪,线团,迹象,头脑,端绪,线;v:提示",
"clump":"n:丛,树丛,根基,一块;v:丛生",
"clumsily":"d:笨拙,拙劣,粗俗,粗陋",
"clumsiness":"n:笨拙",
"clumsy":"a:笨拙,拙劣,笨,拙笨,粗笨,蠢,愚笨,力巴,拙,蠢笨",
"cluster":"n:簇;v:连缀",
"cluster bomb":"n:榴霰弹,子母弹",
"clustering":"v:成群",
"clutch":"v:抓住,抓;n:钩爪",
"clutter":"n:喧闹,喧嚷;v:搅乱",
"cluttered":"a:乱糟糟",
"co":"n:共同,浓缩",
"co-ed":"n:女生",
"co-op":"n:合作社",
"co-operate":"v:合作,互助,协作",
"co-optation":"n:选举",
"co-pilot":"n:驾驶员",
"co-star":"n:配角",
"co-worker":"n:同事,帮手,合作者",
"coach":"n:教练,马车,长途汽车;v:教练",
"coaching":"v:补习",
"coachman":"n:马车夫,车把式",
"coadjutor":"n:助手,副手",
"coagulant":"n:混凝剂",
"coagulate":"v:凝结,凝固,凝聚,结,凝",
"coagulating":"v:凝聚",
"coagulation":"n:凝聚,凝固",
"coal":"n:煤,煤炭,煤块,炭,木炭,石炭,块煤,粉煤,煤碳,乌金",
"coal oil":"n:原油,石油,煤油",
"coal scuttle":"n:煤斗",
"coal seam":"n:煤层",
"coal tar":"n:煤焦油,煤黑油",
"coal-black":"a:漆黑",
"coalesce":"v:联合,合并,融合,愈合,合作,接合,合口,结合",
"coalescence":"n:合并,结合,聚积,联合,愈合;v:愈合,结合,胶着,聚积",
"coalfield":"n:煤田",
"coalition":"n:联盟,联合,结合,合并;v:联合,结合",
"coarse":"a:粗,粗俗,粗糙,粗鄙,麻,奘,难听;v:粗糙",
"coarseness":"n:粗糙,劣等",
"coast":"n:海岸,沿海,海边,海滨,岸,下坡,边疆,滨海,滑坡;v:滑行,一帆风顺",
"coastal":"a:沿岸;n:沿海",
"coaster":"n:滑翔机,滑板,垫子",
"coasting":"v:海岸线",
"coastline":"n:海岸线",
"coat":"n:大衣,上衣,外衣,外套,毛皮,皮毛,短大衣,涂层,被覆,表皮,膜,袄",
"coat rack":"n:衣帽架",
"coating":"n:涂层,糖衣,涂料,被覆,表皮,花呢",
"coatroom":"n:衣帽间",
"coattail":"n:附骥尾",
"coauthor":"n:合作者;v:合著",
"coax":"v:哄,哄骗,劝诱,哄劝,花言巧语;n:同轴电缆",
"coaxial":"a:同轴",
"coaxing":"v:哄骗",
"cob":"v:打碎,捣碎,打;n:穗轴",
"cobalt":"n:钴",
"cobalt blue":"n:深蓝",
"cobber":"n:合伙人,伙伴",
"cobble":"n:鹅卵石,石头子儿,石子,卵石;v:修补,粗制滥造",
"cobbler":"n:鞋匠,皮匠,胡说",
"cobblestone":"n:石子,鹅卵石,石子儿",
"cobra":"n:眼镜蛇",
"cobweb":"n:蜘蛛网,混乱,蛛网,陈腐",
"coca":"n:古柯",
"coca cola":"n:可口可乐,可乐",
"cocaine":"n:可卡因,古柯碱",
"cocci":"n:球菌",
"coccus":"n:球菌",
"coccyx":"n:尾骨",
"cochineal":"n:胭脂",
"cochlea":"n:耳蜗,蜗",
"cock":"n:公鸡;v:竖起",
"cockade":"n:帽章",
"cockatrice":"n:毒蛇",
"cockchafer":"n:金龟,金龟子",
"cockcrow":"n:黎明,日出",
"cockeyed":"a:睐",
"cockfight":"n:斗鸡;v:斗鸡",
"cockfighting":"n:斗鸡;v:斗鸡",
"cockiness":"n:趾高气扬,自大",
"cockle":"n:火炉",
"cockles":"n:波纹",
"cockleshell":"n:小艇",
"cockpit":"n:战场,座舱",
"cockroach":"n:蟑螂,蜚蠊,蜚",
"cockscomb":"n:鸡冠子,鸡冠,鸡冠花",
"cocktail":"n:鸡尾酒",
"cocktail party":"n:鸡尾酒,酒会,鸡尾酒会",
"cocky":"v:趾高气扬,翘尾巴;a:神气",
"coco":"n:椰树,椰子,椰子树",
"cocoa":"n:可可,可可粉,可可茶,可可树,深褐色",
"cocoa butter":"n:药用",
"coconut":"n:椰子,椰树,脑袋",
"coconut milk":"n:椰子汁",
"coconut oil":"n:椰子油",
"coconut palm":"n:椰子树,椰树,椰",
"coconut tree":"n:椰树,椰",
"cocoon":"n:茧,子囊",
"cod":"n:鳕鱼,阴囊,壳,鳕;v:愚弄",
"coda":"n:尾声,结尾",
"coddle":"v:娇养,煮,娇惯,溺爱",
"code":"n:代码,码;v:译",
"coded":"v:编码",
"codeine":"n:可待因",
"coder":"n:编码器",
"codes":"n:码",
"codex":"n:报,抄本,法典,药典",
"codfish":"n:鳕",
"codger":"n:怪人,家伙",
"codicil":"n:附录,备考,附注",
"codify":"v:整理,编纂",
"coding":"n:编码,译码;v:编码",
"coed":"n:树林",
"coefficient":"n:系数,程度,率",
"coefficient of expansion":"n:体胀系数,膨胀系数",
"coelenterate":"n:腔肠动物",
"coerce":"v:强制,胁迫,压服,要,劫,迫使,裹,威逼,挟,拶,勒逼,要挟,裹胁,逼迫,胁,压制,裹挟,勒,强迫",
"coercion":"n:强迫,压制,胁迫",
"coexist":"v:并存,共存,共处",
"coexistence":"n:共处,共存",
"coffee":"n:咖啡,咖啡色",
"coffee bar":"n:小吃店",
"coffee shop":"n:咖啡店",
"coffeehouse":"n:咖啡馆",
"coffer":"n:国库,金库,镶板,藻井,资产,隔离舱;v:贮藏",
"cofferdam":"n:沉箱,围堰",
"coffers":"n:金库",
"coffin":"n:灵柩,棺材,棺,寿材,棺木,陵寝,材;v:收藏",
"coffin nail":"n:烟卷儿",
"cog":"v:行贿,诈骗",
"cogency":"n:中肯,恳切,说服力",
"cogitate":"v:深思;n:深思,思考",
"cogitation":"n:考虑,计划,设计,思考",
"cognate":"n:外戚,亲族",
"cognition":"n:认识,认知,知识",
"cognitive science":"n:认知科学",
"cognizance":"n:审理,记号,监督,认识,观察,承认,管辖,标记",
"cognizant":"a:知道,认识",
"cognomen":"n:别名,绰号,姓",
"cognoscenti":"n:行家",
"cohabit":"v:同居,姘居",
"cohabitation":"n:同居",
"cohere":"v:凝聚,粘合,拼合,粘结,紧密,团结,一致,粘着",
"coherence":"n:同调,仑,凝聚,一致,连贯性,内聚力,拼合,联接,伦次,统一;v:联接",
"coherency":"n:统一,凝聚,同调,内聚力",
"coherent":"a:连贯,相干,接气;v:相干",
"cohesion":"n:团结,内聚力,结合,连着,凝聚;v:结合",
"cohort":"n:共犯,区,助手,同伴,追随者,队,股",
"coif":"n:头巾",
"coiffure":"n:发型,发式",
"coil":"n:线圈;v:绕,盘,蜷曲,卷",
"coiling":"a:卷绕",
"coin":"v:铸造,铸,铸币,制造;n:硬币,钱币,铸币",
"coinage":"n:货币,铸币",
"coincide":"v:一致,重合,巧合,吻合,如出一辙,符合,暗合,相符;a:一致",
"coincidence":"n:巧合,一致,偶合,符合,碰巧,暗合,重合,巧事;v:符合,重合",
"coincidental":"a:偏巧,巧,刚巧",
"coincidentally":"d:偏巧,正巧",
"coining":"v:铸币",
"coir":"n:棕",
"coitus":"n:交媾,交配,交尾,性交;v:交尾,性交",
"coke":"n:焦炭,可口可乐,可乐;v:结焦,炼焦;a:焦",
"coking":"v:结焦,焦化,炼焦",
"col":"n:唣,山坳,山口,坳,山坞",
"colander":"n:漏勺,滤器,筛网",
"cold":"a:冷;n:风寒",
"cold cream":"n:冷霜",
"cold cuts":"n:冷盘",
"cold feet":"n:胆小,害怕",
"cold frame":"n:阳畦,冷床",
"cold front":"n:冷锋",
"cold shoulder":"n:藐视,冷遇,碰一鼻子灰",
"cold storage":"n:冷库",
"cold turkey":"n:即席,莽撞,突然",
"cold water":"n:冷水",
"cold weather":"n:冷天,霜天",
"cold work":"v:冷加工",
"cole":"n:科尔,油菜",
"colic":"n:绞痛,腹痛",
"coliseum":"n:体育馆,戏院,体育场,音乐厅",
"colitis":"n:结肠炎",
"collaborate":"v:合作,勾结,通敌,提携,私通,协调,协作,串通,串通一气,合流",
"collaboration":"n:合作,勾结,协作,通敌,合著,合作化",
"collaborationist":"n:卖国贼",
"collaborator":"n:合作者,卖国贼",
"collage":"n:大杂烩",
"collapse":"v:倒塌,塌;n:虚脱,暴跌,衰弱;a:衰弱",
"collapsed":"a:虚脱",
"collar":"n:领子,衣领,项圈;v:领,捉,捕",
"collarbone":"n:锁骨",
"collate":"v:整理,对照,校对,校,校勘,配页,核对,检查,勘",
"collateral":"n:旁系亲属,抵押品;a:抵押,并行;v:抵押",
"collateralize":"v:抵押",
"collating":"v:核对",
"collation":"n:茶点,整理,对照,核对,校勘,校对;v:对照",
"colleague":"n:同事,同僚,同行,伙伴,同人",
"collect":"v:收集,搜集,聚集,采集,收,集中,镇定,集,领取,收取,收藏,募集,采,汇集,聚积,提取,堆积,整理,捡,征集,征收,募捐,推测,屯,拾取,搜,搜罗,召集,募,收款,凑合,集聚,辑,罗致,齐集,汇总,征发,汇聚,收罗;n:辑",
"collectedly":"d:泰然",
"collection":"n:集合,收集,募捐,采集,美术馆,珍藏,捐款,托收,文集,集;v:录,汇",
"collections":"n:收集",
"collective":"n:大我;a:公",
"collectivism":"v:集体化;n:集体主义",
"collectivity":"n:集团,集体主义,集体,全体,总体",
"collectivization":"n:集体化",
"collectivize":"v:集体化",
"collector":"n:收藏家,集电极,收票员,收款员,集流环",
"colleen":"n:少女,姑娘",
"college":"n:大学,学院,学,院校,高等学校,学会,院,感化院,宿舍,校舍,团体,收容所,黉",
"collide":"v:相撞,碰撞,冲突,撞,抵触,冲撞,碰头,冲,磕碰,撞车",
"collide with":"v:磕碰,碰撞",
"collier":"n:矿工",
"colliery":"n:煤矿",
"collimation":"n:校准,瞄准,光学",
"collision":"n:碰撞,冲突,抵触,碰头,倾轧;v:打击,截击",
"collocate":"v:并列,布置,搭配,排列",
"collocate with":"v:布置,配置",
"collocation":"n:搭配,并列,排列,布置,配置",
"colloid":"n:胶体;a:胶质,胶体",
"colloquialism":"n:口语",
"colloquium":"n:讨论会",
"colloquy":"n:会话,谈话,讨论,会谈",
"collude":"v:共谋,沟通,串通一气,穿连裆裤,勾,串通,通同,拉扯",
"collusion":"n:串通;v:共谋",
"colly":"n:煤灰",
"cologne":"n:科隆,花露水",
"colombia":"n:哥伦比亚",
"colombo":"n:科伦坡",
"colon":"n:结肠,冒号",
"colonel":"n:上校",
"colonialism":"n:殖民主义",
"colonization":"n:移植,殖民,占据;v:占据",
"colonize":"v:殖民,移植,打入",
"colony":"n:殖民地,菌落,集群,群体,属地,集团,群",
"colophon":"n:版权页",
"color":"n:颜色,色彩,彩色,肤色,色,色调,颜料,色素,血色,情调,染料,格调;v:彩色,设色",
"colorado":"n:科罗拉多",
"colorant":"n:着色剂,颜料,染料",
"coloration":"n:染色,着色,色彩;v:染色",
"coloratura":"n:花腔",
"colored":"a:有色,花",
"colorful":"a:多彩,蔚,五颜六色,五彩,花花绿绿,艳,五彩缤纷",
"coloring":"n:伪装,染料,颜料;v:染色",
"coloring material":"n:着色剂,色素",
"colorless":"a:无色",
"colorlessness":"n:无色",
"colors":"n:军旗,旗帜",
"colossal":"a:巨大,庞大",
"colossus":"n:庞然大物,巨人",
"colour":"n:脸色,气色,染料,格调,色调,着色;v:染色;a:彩色",
"colour bar":"n:彩带,色带",
"colour blindness":"v:色盲;n:色盲",
"colour television":"v:彩色电视",
"colour tv":"n:彩电",
"colouration":"n:色彩,染色",
"coloured":"a:有色,黑人,花",
"colourful":"a:五颜六色,艳,花花绿绿;v:五彩缤纷",
"colouring":"n:色彩,着色,特色,外观,伪装,倾向,外貌,血色",
"colourless":"a:无色;v:无色",
"colours":"n:军旗",
"colt":"n:马驹,驹,生手",
"columbia":"n:哥伦比亚",
"columbus":"n:哥伦布",
"column":"n:列,行,栏,专栏,柱,纵队,立柱,塔,支柱,床身,栏目,连杆",
"coma":"n:昏迷,怠惰,麻木",
"comb":"v:梳头,梳,梳理;n:梳,鸡冠,冠,肉冠,蜂房,冠子",
"comb out":"v:淘汰,搜寻,清洗,清查",
"comb-out":"n:搜集,搜罗,清除",
"combat":"n:搏斗,格斗,肉搏;v:反对,抗,防止,反",
"combat zone":"v:战地",
"combatant":"n:战士,战斗员,队员;a:战斗员",
"combination":"n:组合,结合,联合,混合,合并,配合,共谋,化合,总合,同谋,合作",
"combine":"v:结合,合并,联合,化合,合,兼备,并;n:联合",
"combined":"v:联合",
"combining":"v:合成;n:组合",
"combustibility":"n:可燃性",
"combustible":"a:易燃,可燃",
"combustibles":"n:易燃物",
"combustion":"n:燃烧,氧化;v:燃烧",
"come":"v:来,是,到,出来,进来,来到,过来,去,开始,来自,下来,发生,上,传来,出现,得到,出,做,跑,上来",
"come across":"v:不期而遇,迕,遭逢,照面儿,打照面儿,撞,碰见,遇见",
"come alive":"v:活现",
"come apart":"v:崩溃",
"come around":"v:过访,绕道",
"come away":"v:离开",
"come back":"v:再,旋",
"come by":"v:得到,获得",
"come down":"v:落魄,下来,下降,降,落,没落,退步,退烧,降落,败落,降临",
"come forth":"v:出来,涌现,出笼",
"come forward":"v:出面,前进,出头",
"come home":"v:击中要害",
"come in":"v:进来",
"come in for":"v:接受,受到",
"come into":"v:得到,加入",
"come into being":"v:诞生,长,产生,出世",
"come near":"v:差点儿,就,临到,几乎",
"come of age":"v:成年",
"come off":"v:发生,变成,得手,松开,脱开,脱出",
"come on":"v:提出,来,上演",
"come out":"v:出现,达到,出线,出苗,传出,真相大白,出版,出来",
"come over":"v:改变,过来",
"come round":"n:拜访,清醒,恢复",
"come through":"v:传来,来,脱险",
"come to":"v:稣,清醒,苏,总计,底,醒,缓",
"come to grips":"v:交手",
"come to light":"v:东窗事发,显露,出现",
"come together":"v:汇集,聚合,萃,会面,归",
"come up":"v:提出,出土,走近,来,上来,发生,过来",
"come up to":"v:符合,及",
"come upon":"v:逢,碰见,打击,值",
"come-on":"n:引诱,诱惑",
"comeback":"n:恢复,重整旗鼓",
"comedian":"n:丑角",
"comedown":"n:败落,没落",
"comedy":"n:喜剧,喜剧片",
"comeliness":"n:清秀,合宜,适当,美丽",
"comely":"a:标致,明眸皓齿",
"comes":"n:伴星",
"comestible":"v:食物;n:食物",
"comet":"n:彗星,彗,孛,扫帚星",
"comeuppance":"n:因果报应",
"comfit":"n:糖果;v:解劝",
"comfort":"v:安慰;n:愉快,援助,慰劳品,写意,甜水;a:舒适",
"comfort station":"n:洗手间",
"comfort woman":"n:慰安妇",
"comfortable":"a:舒适,舒服,舒舒服服,自在,适意,爽快,小康,自由自在,舒坦,甜美,伏贴,闲适,宽慰;n:小康,快意;v:自由自在",
"comfortably":"d:愉快,安乐",
"comforter":"n:鸭绒被",
"comic":"a:喜剧,俳谐",
"comical":"a:滑稽,俳,哏",
"comicality":"n:滑稽",
"coming":"a:下;n:未来,到达,萌芽",
"comity":"n:礼让,礼貌",
"comma":"n:逗号,逗点",
"command":"v:命令,指挥;n:信号,展望;a:伪",
"command module":"n:驾驶舱",
"command post":"v:指挥部",
"commandant":"n:司令官,指挥官,校长",
"commandeer":"v:征用,征发",
"commander":"n:指挥官,司令官,指挥员,司令,司令员,统帅,船长,指挥,麾下,将领,主将",
"commander in chief":"n:总司令,帅,大帅,统帅",
"commanding officer":"n:司令,舰长,司令员,长官",
"commandment":"n:戒律,戒条,诫",
"commando":"n:突击队,别动队",
"commands":"n:命令;v:命令",
"commemorate":"v:纪念,庆祝",
"commemoration":"n:纪念",
"commemorative":"a:纪念;v:纪念;n:纪念物",
"commence":"v:开始,肇,着手,肇始",
"commencement":"n:开始,发端",
"commend":"v:称赞,赞扬,表扬,推荐,委托,托付,称道,哿,奖,彰,褒奖,褒扬,赞许,称,显扬,夸奖,委任,赞,称许,夸赞;n:嘉奖",
"commendation":"n:奖品,称许,赞美,推荐,赞赏;v:称许",
"commendatory":"a:解说词,褒义",
"comment":"n:评论,意见,批评;v:评说,解说,论说,评注,议论,注释",
"commentary":"n:评论,解说,评注,批评,按语,疏,述评,注释,笺",
"commentate":"v:评注,注释,评论,释义",
"commentator":"n:评论员,政论家",
"comments":"n:按语",
"commerce":"n:商业,贸易,商务,交际,商,社交,交流,性交,应酬",
"commercial":"v:商用;a:商用",
"commercial law":"n:商法",
"commie":"n:共产党员",
"commingle":"v:混合",
"commiserate":"v:同情,哀怜,哀悼,怜悯,悯",
"commiseration":"n:同情,怜悯",
"commissar":"n:政委",
"commissariat":"n:给养,军粮",
"commissary":"n:代理人,代表",
"commission":"n:委员会,佣金;v:启动,代办",
"commissionaire":"n:门警",
"commissioner":"n:长官,专员,特派员,督察",
"commissioning":"v:开工,投产,启动",
"commit":"v:犯,干,承担,做,托,委托,交付,判处,收,委任,累及,提,委,下,付,损坏",
"commit suicide":"v:寻短见,抹脖子,自杀",
"commitment":"n:义务,诺言,委托,许诺,债务,犯罪,关押,交托,托付,买卖,信仰,约束,委任,拘留,提交,投入,赞助,作为",
"committee":"n:委员会,监护人,委",
"committee member":"n:委",
"committeeman":"n:委员",
"commode":"n:马桶,便桶,桶,衣柜,恭桶",
"commodious":"a:宽敞,宽绰",
"commodity":"n:商品,农产品,货物,利益,货,日用品",
"common":"a:共同,常见,普通,普遍,一般,公共,常,平常,平凡;n:通,紫罗兰;v:共有,盛",
"common beet":"n:糖萝卜",
"common cold":"n:伤风,感冒",
"common denominator":"n:公分母",
"common factor":"n:公因式",
"common fault":"n:通病",
"common fraction":"n:简分数",
"common good":"n:克己奉公,公益",
"common ground":"n:共同点",
"common knowledge":"n:常理,常识",
"common law":"n:不成文法",
"common man":"n:平民,白丁",
"common market":"n:共同市场",
"common measure":"n:公约数",
"common people":"n:平民,生角,常人",
"common rush":"n:灯心草",
"common salt":"n:盐巴,氯化钠,石盐",
"common seal":"n:公章",
"common sense":"n:常情,通情达理",
"common stock":"n:普通股",
"common year":"n:平年",
"commonality":"n:通用性,老百姓,共性,民众",
"commonalty":"n:团体,民众,平民,老百姓",
"commoner":"n:平民,白丁,布衣",
"commoners":"n:布衣",
"commonness":"n:普通",
"commonplace":"a:平凡,平庸,如常,简单;n:常事,凡响,凡俗;v:如常",
"commonplace book":"n:备忘录,笔记本",
"commons":"n:平民,民众,食物,化合物,众议院",
"commonweal":"n:公益,共和国,国家",
"commonwealth":"n:联邦,公民,团体,共和国,国家",
"commotion":"n:混乱,动乱,骚动,暴动,骚扰",
"communal":"a:公共;v:公用",
"commune":"v:谈心,内省,商量,交谈;n:沉思",
"communicate":"v:通信,传染,表达,相通,交际,联络,转告,转达,沟通,传达,传送,达,通,传,传授,交通,照会",
"communication":"n:通信,信息,通讯,联系,交通,交际,交换,通讯网,传达,传播,通报,口信,书信,通知,传染,传授;v:通信",
"communications":"n:交通",
"communicator":"n:通信员",
"communion":"n:共享,交流,共有",
"communique":"n:公报",
"communism":"n:共产主义",
"communist":"n:共产党员,共产党",
"communist party":"n:共产党",
"community":"n:社区,社会,群落,共同体,团体,公社,圈子,大家庭,村落,集体,联营,共性,共有,一致,乡镇",
"community chest":"n:公益金",
"commutation":"n:减刑,换算,划拨,换向,交换,整流,抵偿,变换;v:交换,整流",
"commutator":"n:整流器,交换台,交换机,集电极",
"commute":"v:改判,减刑,变换,互换,划拨,减免,整流,交换,折算,抵偿,兑换",
"comp":"n:招待券,恭维话",
"compact":"n:协议,契约;a:紧密,紧凑,严谨,凝练;v:简化",
"compact disc":"n:光盘",
"compacting":"v:镇压",
"compaction":"n:压缩,紧密,致密;v:压缩",
"compactness":"n:精致",
"companion":"n:同伴,伙伴,伴侣,朋友,伴儿,伴星,伴,侣伴,手册,侣;v:交往,同行",
"company":"n:公司,朋友,连,作伴,连队,交往,群,聚会,交际,商号,伴侣,队,消防队,伙,商务,商社,来客,一行,伍,行会,中队;a:伍",
"comparative degree":"n:比较级",
"comparative literature":"n:比较文学",
"comparatively":"d:比较,较,相对,较比,较之,差",
"compare":"v:比较,相比,比,对;n:校,形",
"comparison":"n:比较,对比,比,比喻;v:对比",
"compartment":"n:车厢,间隔,室,舱,船舱",
"compartmentalise":"v:划分",
"compartmentalize":"v:划分",
"compass":"n:罗盘,指南针,圆规;v:了解,计划,图谋,领悟,完成,围绕",
"compasses":"n:规,圆规,两脚规",
"compassion":"n:同情,怜悯,恻隐之心",
"compassionate":"v:同情,体恤;a:怜悯",
"compatibility":"n:协调,兼容,适应,适合,一致",
"compatible":"a:兼容,相容;v:兼容,相容",
"compatibly":"d:和气",
"compatriot":"n:同胞,胞,国人",
"compatriots":"n:国人",
"compeer":"n:同辈,伙伴",
"compel":"v:迫使,强迫,不得不,逼,迫,强制,逼迫,强逼,拶,劫,勒,勒令,推动,驱迫,强使,驱使",
"compendious":"a:言简意赅,简括",
"compendium":"n:大纲,梗概,一览表,纲要,概略,摘要,概论,纲领",
"compensate":"v:补偿,赔偿,酬劳,抵,抵补,抵偿,赔,赓,赔钱,取偿,恤",
"compensation":"n:赔偿,补偿,赔偿费,报酬,薪水;v:补偿",
"compensatory":"v:代偿;a:代偿",
"compere":"v:指挥;n:司仪",
"compete":"v:竞争,比赛,争,比,争胜,匹敌,赛,抗衡,对抗,竞赛",
"competence":"n:能力,胜任,才干,权限,资格,权能",
"competency":"n:权限,资格,能力,权能,胜任",
"competent":"a:能干,称职,行,得力,得用",
"competition":"n:竞争,比赛,竞赛,赛,生存竞争",
"competitiveness":"n:竞争,竞争性",
"competitor":"n:竞争者,选手,敌手",
"compilation":"n:编辑,汇编,汇集",
"compile":"v:编,编纂,编写,编制,汇编,搜集,纂,汇集,辑录,编选,辑,编著,著述,编订,编辑,编造,编撰;n:辑",
"compiler":"n:编译程序,编者,编译器,编辑",
"complacence":"n:满足,自满,骄傲自满,自得",
"complacency":"n:自满,满足,骄傲自满,自得",
"complacent":"a:自满,得意,自鸣得意,踌躇满志,飘飘然,志得意满,得,满;v:志得意满",
"complain":"v:抱怨,发牢骚,埋怨,投诉,申诉,诉苦,控告,控诉,牢骚,怨,叫屈,鸣冤,抗议;n:牢骚",
"complainant":"n:原告",
"complaint":"n:投诉,抱怨,意见,怨言,牢骚,申诉,控诉,指控,怪话,疾患,不平,陈诉;a:不平",
"complaisance":"n:讨好,恳切,殷勤",
"complaisant":"a:婉顺",
"complement":"n:补码,补充,补语,互补;v:补充,补助,填,互补,补足",
"complementarity":"n:补充,互补",
"complementary":"a:互补,补充;v:补充",
"complete":"a:完全;v:完,落成",
"completely":"d:完全,全,十分,全然,清,满,截然,全都,一干二净,根本,透,根,一股脑儿,干净;n:浑然,根;a:完全",
"completeness":"n:完全,完整性,十全,全面",
"completion":"n:完成,结束,实现,毕业,落成,期满,成就",
"complex":"n:复合句;a:错综",
"complex number":"n:复数",
"complexion":"n:肤色,面色,脸色,气色,采,情况;v:采",
"complexity":"n:复杂性,复杂,复合物",
"compliance":"n:服从,答应,依从,顺从,温和,和蔼,应允,盲从",
"compliant":"a:依从",
"complicated":"a:复杂,曲折",
"complication":"n:并发症,复杂,合并症,纠纷,纠葛,枝节,错杂,周折",
"complications":"n:葛藤,并发症;a:曲折",
"complicity":"n:同谋,共犯,共谋,牵连",
"compliment":"n:恭维话,问候,敬意;v:恭维,夸奖,夸赞,恭惟",
"comply":"v:答应,同意,遵照,依从,应允",
"component":"n:部件,分量,成分,元件,组成部分,部分,组件,组分,零件,分,成份,器件,元器件,分力,元,构件",
"component part":"n:成分",
"components":"n:部件",
"comport":"v:相称,表现,举动,行为",
"comportment":"n:举动",
"compose":"v:组成,构成,写,创作,作,谱写,组织,编写,排版,安顿,作曲,编,做,组合,撰述,赋,合成,起草,排字,著,撰著,缀,构,撰,调停,配合,设计,整顿,构想,镇,撰写",
"composed":"a:安详,自若,沉毅,泰然,镇静,安宁;v:从容自若",
"composer":"n:作曲家,设计者,作者",
"composing":"v:排版,排字",
"composite":"n:混合物;a:综合",
"composite material":"n:复合材料",
"composition":"n:作文,成分,组成,成份,结构,文章,构图,复合,构成,作品,和解,性格,合成,协议,组织,作曲,构造,配合;v:组成,合成",
"compost":"n:堆肥,混合物",
"composure":"n:镇静,沉着,泰然自若",
"compote":"n:蜜饯",
"compound":"v:合成,混合;n:院落,大院,村寨,复方,院;a:复合",
"compound eye":"n:复眼",
"compound number":"v:复名数",
"compound sentence":"n:复合句",
"compounding":"v:混合,私了",
"comprehend":"v:理解,包括,了解,认识,领悟,包含,明,理会,照,领,领会,解",
"comprehension":"n:理解,理解力,包含,包括,悟性",
"comprehensive":"a:综合,全面,周全;d:通盘,全盘",
"comprehensiveness":"n:宽广,综合性",
"compress":"v:压缩,加压;n:敷,打包机",
"compressibility":"n:压缩性",
"compression":"n:压缩,加压,紧缩,压抑;v:压缩",
"compressor":"n:压缩机",
"comprise":"v:包括,包含",
"compromise":"v:调和,泄露;n:危及,连累",
"comptroller":"n:审计员",
"compulsion":"n:强迫,强制",
"compulsorily":"d:强迫,强制",
"compunction":"n:后悔,内疚,悔恨,懊悔",
"computation":"n:计算,估计,得数,估算",
"compute":"v:计算,估计,算;n:估计",
"computer":"n:计算机,电脑",
"computer memory":"n:存储器",
"computing":"v:计算",
"comrade":"n:同志,战友,伙伴,同事",
"comradeship":"n:友谊",
"comte":"n:伯爵",
"con":"v:欺骗;n:反对,反对票;p:用,反对;d:反对",
"concatenate":"v:连结,连接",
"concatenation":"n:并列,串联,连锁,连续,连接;v:串联,连接",
"concave":"a:凹;n:凹面,凹",
"concave lens":"n:凹透镜",
"concavity":"n:凹面",
"conceal":"v:隐瞒,掩盖,隐藏,掩饰,藏,遮掩,遮,遮盖,掩藏,隐蔽,埋藏,瞒,隐秘,藏匿,匿,隐,戢,隐私,暗藏,昧,韬,隐没,庇荫,荫蔽,遮藏,包藏,隐匿;n:隐秘",
"concealed":"v:隐",
"concealment":"n:隐瞒,隐藏,隐蔽,隐蔽所,潜伏,隐匿",
"concede":"v:承认,让步,批准",
"conceit":"n:自负,自大,幻想,自满;v:夸赞,理解",
"conceited":"a:骄傲,自负,自大,满,扬扬得意;v:自作聪明",
"conceivability":"n:想得到",
"conceive":"v:想象,设想,想像,想到,怀孕,怀胎,以为,怀,构想,萌生,妊娠,受胎,蓄,陈述",
"conceive of":"v:设想,构想",
"concentrate":"v:集中,专心,集结,浓缩;n:浓缩物",
"concentrate on":"v:留,注",
"concentrated":"a:集中,浓,一,专,专一,密集;v:专",
"concentration":"n:浓度,集中,浓缩,专心,集聚,精选,专一性;v:集聚",
"concentrator":"n:集线器",
"concentric":"a:同心,同轴;v:同心",
"concept":"n:概念,观念,思想;v:构想",
"conception":"n:概念,构想,看法,设想,怀孕,构思,见解,妊娠,机杼,胎儿,心裁,立意;v:构思,怀孕",
"concern":"n:关心,担心;v:参加,忧",
"concerned":"v:忧虑",
"concerning":"p:关于,论及,至于,对于,有关;v:就",
"concerns":"n:关注,关切,关心,关系;v:涉及",
"concert":"n:音乐会,协奏曲;v:协作",
"concerted":"a:一致",
"concerto":"n:协奏曲",
"concession":"n:让步,特许权,特许,租界,租借地,迁就,核准;v:特许",
"conch":"n:海螺,甲,螺号,螺,外耳,法螺,贝壳",
"concierge":"n:门警,门卫,门房,管理员,接待员",
"conciliate":"v:和解,调停,劝慰,说服,安抚,抚慰,赢得,调解",
"conciliation":"n:调解,安抚,妥协;v:调解",
"concise":"a:简明,简洁,精炼,简练,精练,凝练,简约",
"concision":"n:简明,简练,简洁",
"conclude":"v:结束,断定,决定,缔结,断言,推断,订立,闭幕,结,达成,立,告终,终了,订,归纳,议定,终止,毕",
"conclusion":"n:结论,结局,断定,决定,缔结,定论,商定,议定,断语,终结,终了",
"conclusive":"a:确凿",
"concoct":"v:虚构,策划,编造,调制,捏造,调合,图谋,炮制,造,计划",
"concoction":"n:混合,捏造,配制;v:配制,调制",
"concord":"n:和睦,谐声,和声,一致,和谐,协定,协和,谐音,协约;a:和睦",
"concordance":"n:协和,和谐,索引,调和,一致,整合",
"concordant":"a:谐和",
"concordat":"n:协定,协约,协议",
"concourse":"n:汇聚,集合,总汇,合流,马路",
"concrete":"a:具体;n:混凝土;v:结合",
"concretion":"n:结石,结核,凝结,凝固",
"concubinage":"n:纳妾",
"concubine":"n:妾,情妇,姨太太,姨奶奶,媵,侧室;a:小",
"concupiscence":"n:性欲,贪欲",
"concur":"v:一致,同意,并行,并发,合作",
"concurrence":"n:同意,联合,一致,并发,并行,共有,交点,合作",
"concurrent":"n:竞争者",
"concurrently":"d:同时,兼",
"concuss":"v:恐吓",
"concussion":"n:震动,冲击,震荡,撞击,胁迫;v:震荡",
"condemn":"v:谴责,判,责备,定罪,判处,判罪,判刑,处刑,讨,宣告,声讨,谴,问罪,骂",
"condemnation":"n:谴责,判罪,定罪,征用,非难,没收",
"condensate":"n:冷凝,冷凝物,浓缩物",
"condensation":"n:凝结,凝聚,浓缩,冷凝,节本,紧缩,压缩;v:紧缩",
"condense":"v:凝结,压缩,冷凝,缩短,凝聚,冱,删繁就简,加强,浓缩,聚集",
"condensed":"v:凝练",
"condensed milk":"n:炼乳",
"condenser":"n:冷凝器,电容器,容电器",
"condescend":"v:俯就,垂",
"condiment":"n:调味品,佐料,调料,香料",
"condiments":"n:佐料,香料,作料",
"condition":"n:条件,情况,状态,状况,情形,境况,境地;v:检验,候",
"conditioned reflex":"n:条件反射",
"conditioned stimulus":"n:条件刺激",
"conditioner":"n:检查员,教练员,调节器",
"conditioning":"n:调节,整修;v:调节",
"conditions":"n:光景,商情",
"condole":"v:哀悼,吊丧,吊唁,慰问,吊,吊慰",
"condole with":"v:哀悼,吊唁,吊慰",
"condolence":"n:吊慰,吊唁,悼词",
"condom":"n:避孕套",
"condominium":"v:共管;n:共管",
"condone":"v:宽恕,容忍",
"condor":"n:秃鹰,秃鹫,兀鹫",
"conduce":"v:导致",
"conduct":"n:行为;v:实施,为人",
"conductance":"n:导电性,传导",
"conducting wire":"n:导线",
"conduction":"n:传导,导电,引流;v:传导",
"conductor":"n:导体,指挥,导线,售票员,列车员,避雷针,导管",
"conduit":"n:管道,导管,沟渠,水管,水道,暗渠",
"cone":"n:球果,圆锥,圆锥体,锥形,锥面,锥体;a:锥形",
"confabulate":"v:谈心,闲谈",
"confabulation":"n:交谈",
"confection":"n:制造,调制,糖食,蜜饯,糖果;v:调制",
"confectionery":"n:蜜饯,糖果",
"confederacy":"n:联盟,帮派,共谋,联邦,同盟",
"confederate":"n:同谋,党羽;v:结盟",
"confederate rose":"n:芙蓉",
"confederation":"n:联盟,同盟,邦联",
"confer":"v:授予,商议,授,给予,商讨,协商,颁发,商谈,对照,谈判,颁,赉,谋,畀,赐",
"conference":"n:会议,大会,会,协商,商谈,讨论会,谈判,会谈,商议,联合会",
"conferment":"n:给与",
"confess":"v:承认,忏悔,供认,坦白,招供,供,供认不讳,招,交代,自白,表白,录供,自供,证明;n:交待",
"confession":"n:招供,坦白,供认,供词,供,承认,交待,口供,自白;v:供",
"confetti":"n:糖果",
"confidant":"n:密友,知心人,知己",
"confide":"v:吐露,信赖,信任,倾述,委托,信托,交托",
"confidence":"n:信心,信任,自信,秘密,信赖,自信心,信,确信,胆量,信任感;v:置信",
"confidence man":"n:骗子",
"confident":"a:自信,确信,深信;n:知己",
"confidential":"a:机密;n:私房",
"configuration":"n:结构,配置,排列,组合,构造,外形,地形;v:组成",
"configure":"v:配置",
"configuring":"v:架构",
"confine":"v:限于,局限,限制;n:限度",
"confinement":"n:分娩,监禁,拘留,界限,拘束,幽禁,月子,制约,密封;v:制约",
"confines":"n:界限,范围,境界",
"confirm":"v:证实,批准,肯定,确认,印证,巩固,认可",
"confirmation":"n:确认,证实,批准,认可,验证,确实,确定,确证;v:验证",
"confirmed":"v:惯;a:坚定",
"confiscate":"v:没收,征用,充公,抄收,抄查,没,查抄",
"confiscation":"n:没收",
"confiscatory":"a:没收",
"conflagration":"n:火灾,战火,大火",
"conflate":"v:合并",
"conflation":"n:合成,熔合",
"conflict":"v:矛盾,抵牾,争斗,倾轧,斗争,摩擦,战斗,碰头;n:争端,争斗",
"confluence":"n:总汇,汇流,汇聚,会合;v:合流",
"confluent":"n:支流;a:汇流",
"conform":"v:符合,遵守,一致,遵从,遵照,顺应,入,依据,合,依照,印,契合,合乎,绰",
"conform to":"v:顺应,合乎,遵守,入,绰,契合,符合,合,遵从",
"conformable":"a:适合,一致,相似",
"conformance":"n:相似,一致,相符",
"conformation":"n:组成,结构,符合,构造,形态,一致,适应,相应",
"conformity":"n:整合,符合,顺从,适合,遵从,遵照,一致,顺应,相似",
"confound":"v:混淆,混乱,颠倒,挫败,反驳,可恶",
"confoundedly":"d:非常,极度,特别,要命",
"confounding":"v:混杂",
"confraternity":"n:团体,协会,公会",
"confrere":"n:同事,会友",
"confront":"v:面对,面临,对付,遭遇,对照",
"confrontation":"n:对抗,对质,面对;v:对抗",
"confucian":"n:儒家",
"confucianism":"n:儒教,儒学,儒,儒家",
"confucius":"n:孔子,孔夫子",
"confuse":"v:混淆,混,迷惑,搅乱,弄错,淆,淆乱,乱了营,混同,淆惑,荧惑,乱,绕,纷扰,迷,迷离扑朔,淆杂;n:乱,荧惑",
"confused":"a:混乱,糊涂,乱,昏头昏脑,紊乱,颠三倒四,胡涂,乱腾腾,惝怳,乱杂,迷茫,糊里糊涂,缭乱;v:颠倒,昏,迷糊",
"confusing":"v:扑朔迷离",
"confusion":"n:混乱,混淆,慌乱,狼狈,混同,骚乱,紊乱,弥散;a:混乱",
"confusions":"a:浑沌",
"confutation":"n:反证,驳倒",
"confute":"v:驳倒,反驳",
"congeal":"v:凝结,凝固,凝,结,冻结,狞笑",
"congealing":"v:凝固",
"congealment":"n:冻结,凝结;v:冻结",
"congenial":"a:意气相投,投契,投机,投缘;v:意气相投",
"congeniality":"n:合适,适意,意气相投",
"congenital":"a:先天性;n:先天",
"congenital disease":"n:胎毒",
"conger":"n:海鳗",
"conger eel":"n:海鳗",
"congeries":"n:堆,聚集,堆积;v:堆积",
"congest":"v:充血,充满,充斥,汇集,拥塞",
"congested":"v:壅塞",
"congestion":"n:充血,拥挤,拥塞,充满,聚集,稠密,充斥,过剩;v:聚集,充血,堆积",
"conglomerate":"n:砾岩,集团,砂礓;v:凝聚,堆集,团",
"conglomeration":"n:堆集,集团,砾岩,凝聚",
"congo":"n:刚果",
"congo red":"n:刚果红",
"congratulate":"v:祝贺,庆幸,恭贺,庆贺,敬贺,道贺,祝,庆",
"congratulation":"n:祝贺,贺辞,祝词",
"congratulations":"n:恭喜,祝词,贺词;v:恭喜",
"congratulatory":"a:祝贺",
"congregate":"v:聚集,集合",
"congregation":"n:会众,教区,集会,听众,行政区,聚集,农庄,集合",
"congress":"n:国会,代表大会,集会,众议院,协会,交际,大会;v:道喜,集合,开会",
"congressman":"n:众议员",
"congruence":"n:和谐,一致,适合",
"congruency":"n:适合",
"congruity":"n:一致,适合,调和",
"conic":"n:圆锥",
"conic section":"n:圆锥曲线",
"conifer":"n:针叶树",
"coniferous tree":"n:针叶树",
"coning":"v:整形",
"conjecture":"v:猜测,推测;n:设想",
"conjoin":"v:结合,连接,联合",
"conjoint":"a:夫妇",
"conjugate":"v:变化,连接,成对,成婚,交尾,结合,伴随",
"conjugation":"n:接合,联合,配合,拼合,结合",
"conjunction":"n:结合,连词,连接,联系,合,连;v:合,会合,连接",
"conjunctiva":"n:结膜",
"conjunctive":"n:连词;a:连接",
"conjunctivitis":"n:结膜炎",
"conjuncture":"n:场合,地步,结合,紧要关头,连接,局面,商情",
"conjuration":"n:祈求,咒语,恳求",
"conjure":"v:变戏法,祈求",
"conjurer":"n:魔术师",
"conjuring":"v:魔术",
"conk":"n:鼻子,故障,头;v:出毛病",
"conn":"v:船",
"connect":"v:连接,接通,衔接,接,连,联想,连通,接头,连结,通,连续,联合,交接,接合,结,沟通,毗,关",
"connected":"v:连通",
"connecticut":"n:康涅狄格",
"connecting":"v:连接",
"connection":"n:连接,关系,联系,接线,结合,客户,套管,瓜葛;v:结合,连接,连通",
"connections":"n:来头",
"connective":"n:连词;a:连接",
"connective tissue":"n:结缔组织",
"connector":"n:连接器,插头,接头",
"connexion":"n:联想;v:连接",
"conniption":"n:歇斯底里,激怒",
"connivance":"n:默许,纵容,放任",
"connive":"v:纵容,默许,同谋,打佯儿,私通,共谋,放纵,开绿灯,放任",
"connive at":"v:放纵,纵容,打佯儿,默许",
"connoisseur":"n:鉴赏家,行家,权威,内行",
"connotation":"n:涵义,内涵,言外之意,含蓄",
"connote":"v:意味着,包含,含蓄,暗示,指点,意味,内涵",
"conquer":"v:征服,克服,攻克,打败,制服,抑制,打下,改正,攻陷,刘,得胜,亡,占领",
"conqueror":"n:胜利者",
"conquest":"n:征服,赢得,战胜,攻克,获得",
"consanguinity":"n:血亲,亲族,血缘",
"conscience":"n:良心,道德,天良,心肝,本心",
"conscienceless":"a:丧尽天良;v:丧尽天良",
"conscientious":"a:认真,负责,经心,正大光明,老老实实,自觉,切实",
"conscientiously":"d:切实,老老实实",
"conscious":"a:自觉",
"consciousness":"n:意识,知觉,感觉,觉悟,精神,神志,自觉,自觉性",
"conscript":"v:征募,征召,征兵",
"conscription":"n:征兵,征发,征集,征募,征用",
"consecrate":"v:奉献,尊崇,供奉,献给",
"consecration":"n:献身,供献,奉献",
"consensus":"n:一致,舆论,同意,同感,合意",
"consent":"v:同意,答应;n:承诺,谐调",
"consequence":"n:后果,结果,重要,影响,成果,结论,痛痒,果",
"consequent":"n:结果,结论,后项",
"consequently":"d:因此,结果,因而,所以,以致;c:于是,以致,故,于是乎,因此",
"conservancy":"n:保护,管理,管理局,保存,保管,水土保持",
"conservation":"n:保护,守恒,保守,保存,维持",
"conservatism":"n:保守主义,守旧",
"conservative":"n:保守派,守旧派,防腐剂,稳健派;a:古雅,古板",
"conservative party":"n:保守党",
"conservatives":"n:保守派",
"conservator":"n:监督,监护人",
"conservatory":"n:防腐剂,暖房,库房,温室",
"conserve":"v:守恒,保存;n:果酱,涵养,蜜饯",
"conserves":"n:蜜饯",
"consider":"v:考虑,认为,研究,想,看,以为,给,算,审议,着想,思考,思量,体谅,论,斟酌,寻思,估量,算计;d:酌量",
"considerable":"a:可观,大大;v:少不了",
"considerably":"d:相当,颇",
"considerate":"a:周到,体谅,周至,慎重,到",
"consideration":"n:考虑,讨论,体谅,审议,理由,关心,思考,原因,尊敬,敬意,报酬,度,照顾,补偿,商量,体恤,打算;v:计算",
"considering":"p:考虑到,顾及,对于,鉴于;d:委实",
"consign":"v:托运,寄售,委托,交付,寄寓,交货,托付,用作,寄存,存,发货,当作",
"consignee":"n:收件人",
"consignment":"n:寄售,托运,发货,寄存,交货,交付,委托",
"consist":"v:包括,构成,在于,包含,一致,在内,生存,适合,共存,并存,并立",
"consistence":"n:稳定,结实,稠度,坚固,坚强,浓度,坚定,相容,一致,调和",
"consistency":"n:一致,浓度,稠度,调和,坚定,结实,稳定,质地,密度,相容,坚固",
"consistent":"a:一致,一贯,相容,连贯;v:身体力行,相容,始终不渝",
"consistently":"d:总,一向",
"consistory":"n:集会",
"consolation":"n:安慰,慰问,抚恤,慰藉,安抚,抚恤金",
"console":"v:安慰;n:操纵台,悬臂",
"consolidate":"v:合并,巩固,整顿,统一,整理,加固,强化,巩,愈合,固,加强,整饬",
"consolidated":"a:巩固",
"consolidation":"n:合并,凝固,巩固,愈合;v:结合,固化",
"consomme":"n:清汤",
"consonance":"n:一致,和谐,调和,协和,共鸣;v:共鸣",
"consonant":"n:辅音,子音",
"consort":"n:合作,伙伴,配偶,协力,会员,协同;v:相称,调和,一致",
"consortia":"n:联合",
"consortium":"n:财团,共同体,协会,组合",
"conspectus":"n:大纲,概念,一览,大要,纲要,梗概",
"conspicuous":"a:引人注目,显眼;v:引人注目",
"conspiracy":"n:阴谋,密谋,共谋,反叛,合谋;v:合谋",
"conspirator":"n:阴谋家,奸贼,同谋",
"conspire":"v:密谋,巧合,串通一气,阴谋,串通,合谋,图谋,协同,同谋,串,协力,共谋",
"constable":"n:警察,警官,巡警",
"constabulary":"n:警察",
"constancy":"n:坚贞,恒久,恒心,不屈不挠,坚定,坚忍不拔,忠实",
"constant":"n:常数;a:常,一定;p:经",
"constantly":"d:不断,经常,时刻,一直,老是,时时,历来,长川,常川",
"constants":"n:常数",
"constellation":"n:星座,型,配合,星宿,座,丛",
"consternation":"n:惊愕,恐怖,惊惶失措",
"constipate":"v:便秘",
"constipation":"n:便秘",
"constituency":"n:选区,选民,订户",
"constituent":"n:成分",
"constituents":"n:组分",
"constitute":"v:构成,组成,引起,任命,占,设立,制定,指定,等于,组合",
"constitution":"n:宪法,制定,体质,体格,章程,组织,法规,构成,构造,结构,设立,章,宪,政体,成分,素质",
"constitutional":"n:宪制",
"constitutionalism":"n:立宪,宪政",
"constitutionality":"n:法治,立宪,合法性",
"constrain":"v:约束,强逼,强迫,束缚,压抑,拘,监禁,逼迫,强制",
"constrained":"a:拘束",
"constraint":"n:约束,制约,强制,压抑,强迫,拘泥;v:约束,制约,拘束",
"constrict":"v:收缩,阻碍,收敛,压缩,妨害,压迫,缩小",
"constriction":"n:收缩,收敛,收紧,狭窄,压缩,分割;v:分割",
"constrictor":"n:括约肌",
"construct":"v:构成,建造,构造,造,建设,建筑,建,修建;n:构想",
"construction":"n:建筑,建设,结构,建造,施工,工程,解释,构造,设计,建筑物,作图,编排,土木,架设,铺设,布景",
"construction industry":"n:建筑业",
"constructive":"a:建设性",
"constructivism":"n:美术",
"constructor":"n:建设者",
"construe":"v:解释,分析,串讲;n:解释,直译",
"consul":"n:领事",
"consulate":"n:领事馆,馆",
"consult":"v:商量,请教,查,征询,查阅,看,考虑,参考,磋商,咨询,参照,协商,参阅,相商,参看,接洽,合计,会诊,筹商,计议,讲,参见,查考,商榷,谋;n:商",
"consultant":"n:顾问,医生",
"consultation":"n:磋商,协商,商量,会诊,参考,会议,查阅,鉴定;v:会诊",
"consultative":"a:商议",
"consumable":"n:消费品",
"consume":"v:消耗,烧毁,吃光,耗费,消费,毁灭,浪费,空耗,枯萎,耗,消灭,耗损,消磨",
"consumer":"n:消费者,用户",
"consumerism":"n:消费,销售",
"consummate":"v:完成,作成,圆房;a:完美,精湛",
"consummation":"n:终结,完成,终极,完备,顶点,完全,成就,极端",
"consumption":"n:消费,消耗;v:耗尽,消费",
"contact":"v:联系,接触;n:交涉,相切,合同,接点,门路,熟人,交道",
"contact lens":"n:隐形眼镜",
"contacts":"n:门道",
"contagion":"n:蔓延,传染,传染病,流行,歪风邪气;v:传染",
"contagious disease":"n:传染病",
"contagiousness":"n:传染",
"contain":"v:含有,包含,包括,含,装有,包,牵制,遏制,克制,容纳,等于,忍耐,蕴含,盛,包藏,蕴涵,含蓄,娠,韫,蕴藏,涵,寓于,涵盖,拦截,牵掣,容,寓,自制,包容,蕴",
"container":"n:容器,集装箱,货柜,货箱,笼子,匣,箱",
"containment":"n:容积",
"contaminant":"n:污染物",
"contaminate":"v:污染,沾染,染,毒害,染毒,沾污,损害",
"contamination":"n:污染,污物,染毒,污秽,混合",
"contemn":"v:藐视,蔑视",
"contemplate":"v:打算,沉思,注视,期待,玩味,企图,思虑,默想,预期,深思,熟思",
"contemplation":"n:沉思,凝视,注视,打算,静观,计划,默祷,默想,企图,预期,期待",
"contemporaries":"n:时人",
"contemporary":"n:同龄人,今人,现代;a:当代,现代",
"contempt":"n:轻蔑,轻视,鄙视,不顾,藐视,不管,屈辱,耻辱;v:鄙夷,鄙视",
"contemptible":"a:可鄙,卑鄙,卑鄙无耻",
"contemptuous":"a:轻蔑;v:轻蔑",
"contend":"v:斗争,争夺,争,抗争,争论,竞争,争辩,主张,周旋,角逐,战斗,夺,博取,争鸣;n:角",
"contender":"n:竞争者",
"content":"n:内容,含量;a:甘心,满,喜欢",
"contented":"a:满足,乐滋滋;v:陶",
"contention":"n:论点,争论,主张,竞争,斗争;v:争论",
"contentment":"n:满足,满意,知足,陶",
"contents":"n:目次,篇目,目录",
"contest":"v:争夺,竞争;n:争论",
"contestant":"n:选手,竞争者",
"context":"n:上下文,条件,范围,来龙去脉,场合,组织,语境,关节,处境",
"contiguity":"n:接近,邻接,接触",
"contiguous":"a:连接,邻接,接近;v:相邻",
"continence":"n:克制,自制,禁欲;v:节制,节欲",
"continent":"n:大陆,洲,陆地,大洲",
"continental shelf":"n:大陆架,陆架,陆棚",
"continental slope":"n:大陆坡",
"contingency":"n:偶然,万一;a:不测",
"contingent":"n:部分,份额;a:不虞",
"continual":"a:不断,连续",
"continuance":"n:持续,继续,连续,连续性,续篇",
"continuation":"n:继续,延续,持续,续篇,延长,连续;a:连续;v:继续",
"continue":"v:连亘,承接,续;p:继;d:再;a:连续",
"continued":"v:持续",
"continuing":"a:连续",
"continuity":"n:连续性,连续,连贯性,继续,连锁,剪辑;a:连续",
"continuous":"a:连续,不断,继续,连绵,绵绵,连亘,联绵,绵,绵联,累,续",
"continuously":"d:不断,一直,接连不断,一个劲,直,接二连三,连,连着,马不停蹄,源源,源源不绝;v:接连不断,源源不绝,无间;a:缕缕",
"continuum":"n:连续",
"contort":"v:扭曲,扭,曲解",
"contortion":"n:曲解,脱节",
"contour":"n:轮廓,等高线,环路,略图,形势,外形,大要,概略,回路",
"contraband":"n:走私,黑货,违禁品,禁运品,私货",
"contraception":"n:节育,避孕;v:避孕",
"contraceptive":"n:避孕药",
"contract":"v:收缩;n:聘书,契,契文,契据,契纸,文契",
"contraction":"n:收缩,压缩,缩短,萎缩,缩减,狭窄,挛缩,缩小,挛,收敛;v:缩短,收缩,缩小,压缩,萎缩",
"contractor":"n:承包商,承包人,包工,承包方,承包户",
"contradict":"v:矛盾,反驳,驳斥,抵触,否认,顶撞,顶嘴,驳,反对,诡,抗辩,抵牾,相斥",
"contradiction":"n:矛盾,相反,驳斥,反驳,抗辩,否认,否定,茅盾,抵触",
"contradictorily":"d:相反,反驳,矛盾",
"contradictory":"n:矛盾",
"contradistinction":"n:对比",
"contraindicate":"v:禁忌",
"contraindication":"n:禁忌症,禁忌",
"contralto":"n:女低音",
"contrariety":"n:对立面,反对,矛盾",
"contrarily":"d:恰恰相反,反之,逆;c:相对而言",
"contrariness":"n:别扭,反对,乖张,对立,相反",
"contrariwise":"d:反之",
"contrary":"n:对立物;a:左,反;v:相反",
"contrast":"v:对照;n:对比度",
"contrasting":"v:对立",
"contravene":"v:违反,触犯,反驳,抵触,犯,推翻,违背,否定",
"contravention":"n:违反,反驳,否定,违背",
"contribute":"v:贡献,捐献,捐助,捐款,投稿,捐,捐赠,出力,醵,补助,建树,捐输,捐资",
"contributing":"a:特约",
"contribution":"n:贡献,捐款,稿件,捐助,捐赠,捐献,投稿,赠送,功绩,分担,稿子,功劳,建树,来稿",
"contributory":"a:有助于",
"contrite":"a:悔罪",
"contrition":"n:悔改,悔恨,悔罪,悔悟",
"contrivance":"n:设计,奸计,计策,装置,发明,诡计,计划,设备",
"contrivances":"v:枉费心机",
"contrive":"v:设法,发明,设计,计划,挖空心思,枉费心机,企图,图谋,创制",
"contriver":"n:发明者,设计者",
"control":"v:控制;n:压制,克,留底,束,统制,手心,存根,驾驶,核对,对照",
"control board":"n:控制台",
"control center":"n:主脑",
"control rod":"n:操纵杆,控制棒",
"control room":"n:调度室",
"control stick":"n:控制棒",
"control tower":"n:塔台",
"controller":"n:控制器,调节器,管理员,操纵杆,检查员,整流器;v:提调",
"controversy":"n:争论,争议,论战,辩论;v:争论",
"controvert":"v:攻击,争论,反驳,辩驳",
"contumacy":"n:抗拒",
"contumely":"n:侮辱,谩骂",
"contuse":"v:挫伤,殴打",
"contusion":"n:挫伤,擦伤;v:挫伤",
"conundrum":"n:谜,谜语",
"convalesce":"v:养病,康复,休养,疗养,复元,静养,养,瘳,恢复",
"convalescence":"n:恢复期,恢复,康复",
"convection":"n:对流,环流,传送",
"convene":"v:召开,召集,召,召唤,集会,集合,聚集",
"convener":"n:召集人",
"convenience":"n:方便,便利,便,厕所,适合,方便之门,顺便",
"convenient":"a:方便,便,便利,利,便当,手;n:手",
"conveniently":"d:顺便,便,顺手,随手,信手",
"convent":"n:修道院",
"conventicle":"n:集会",
"convention":"n:会议,习俗,公约,大会,传统,协定,惯例,习惯,约定,常规,俗套,集会,常理,俗,老规矩,向例,旧框框,框框;v:约定;a:俗",
"conventional":"a:惯例",
"conventionalism":"n:惯例",
"conventionality":"n:传统,惯例,照例,习俗,因袭,套子",
"conventioneer":"n:到会者",
"conventions":"n:条条框框",
"converge":"v:集中,收敛,汇集,会聚,汇聚,汇流,归,丛集,酋,会合,会集,沓,云集,汇",
"convergence":"n:收敛,聚合,汇合,会聚;v:会聚",
"converging":"v:会聚",
"conversant":"a:精",
"conversation":"n:谈话,谈,会话,对话,交往,交际,性交;v:谈,谈话,对话",
"conversational":"a:会话式",
"conversazione":"n:座谈会",
"converse":"v:交谈,谈话;a:相反;n:逆命题",
"conversely":"c:反之;d:反过来",
"conversion":"n:转换,转变,转化,变换,改造,换算,兑换,变更,调换,改装,更换;v:兑换,调换,换位,转化",
"convert":"v:转换,转变,转化,变成,变换,兑换,换算,改装,改造,改变,折,化,兑,更改,折兑,换位,更换,折算,改制,改编",
"converter":"n:变频器,转炉,变压器,变流器",
"convertibility":"v:兑换;n:兑换",
"converting":"v:再生",
"convex":"a:凸;n:凸面",
"convex lens":"n:凸镜,火镜,凸透镜",
"convex polygon":"n:凸多边形",
"convexity":"n:凸面",
"convey":"v:输送,表达,转达,传达,运送,传递,通知,传送,传导,通报,传,转运,抒,输,传播,偷,运输,搬运",
"conveyance":"n:运送,运输,输送带;v:运输",
"conveyer belt":"n:输送带",
"conveying":"v:传输",
"conveyor":"n:运输机,输送带",
"conveyor belt":"n:输送带",
"convict":"n:囚犯,犯人,罪犯,囚徒;v:判刑,判罪",
"conviction":"n:信念,定罪,确信,信仰,悔罪,服罪,坚信",
"convince":"v:说服,服",
"convinced":"a:服服帖帖",
"convincing":"a:平服",
"conviviality":"n:欢宴",
"convocation":"n:集会,召集",
"convoke":"v:召,召开,召集",
"convolution":"n:回转,回旋,盘旋,旋绕,涡流",
"convolve":"v:卷绕,缠绕,盘旋",
"convoy":"v:引导;n:护航",
"convulse":"v:震撼,摇动,抽风",
"convulsion":"n:动乱,痉挛,震动,激动,搐搦,抽搐;v:抽搐",
"convulsions":"v:惊厥",
"cony":"n:狗鱼,兔",
"coo":"v:咕;n:咕",
"cook":"v:做饭,做,烹调,烹饪,烧,煮,做菜;n:库克,炊事员,大师傅",
"cook up":"v:胡诌,炮制,伪造,造,编造,诌,编,虚构",
"cookbook":"n:菜谱,食谱",
"cooked":"a:熟",
"cooker":"n:炊具,炉,饭锅",
"cookery":"n:烹饪法,厨房,烹调法",
"cookhouse":"n:厨房,野营",
"cookie":"n:饼干,亲爱的,糕点",
"cooking":"n:炊事,做菜,烹调,中馈;v:中馈,烹饪",
"cooking stove":"n:灶,炉灶",
"cooking utensil":"n:炊具",
"cool":"a:淡然,风凉;v:散热;n:镇定,平静",
"cool down":"v:冷却,降温",
"cool it":"v:心平气和",
"cool off":"v:凉快",
"cool one's heels":"v:坐冷板凳",
"coolant":"n:冷却剂,冷冻剂",
"cooler":"n:冷却器,冷却剂,冷饮,散热器,监狱,冰箱",
"coolie":"n:苦力",
"cooling":"v:散热,降温,冷却;n:冷却;a:降温",
"coolly":"d:冷,冷淡,冷静,沉着",
"coolness":"n:冷静,清凉,爽气",
"coon":"n:浣熊,机灵鬼",
"coop":"n:笼,笼子,罩,牢狱,棚;v:罩,禁闭",
"cooper":"v:修理",
"cooperate":"v:合作,配合,协作,搭档",
"cooperation":"n:合作,协作,互助;v:协作",
"cooperative":"n:合作社",
"cooperatively":"d:联手",
"cooperator":"n:合作者",
"coordinate":"v:调整,照应,配合,相辅而行,接应;n:坐标,坐标系",
"coordinate axis":"v:坐标轴",
"coordinates":"n:套装",
"coordination":"n:协调,协作,配合;v:协作",
"coot":"n:傻瓜",
"cootie":"n:虱子",
"cop":"v:认罪,偷,赢得,抓住,捕捉,招认,逮捕;n:捕捉",
"cop out":"v:认罪",
"cope":"v:应付,对付,克服,应,对抗;n:罩袍",
"cope with":"v:对,顶,应",
"copenhagen":"n:哥本哈根",
"copernicus":"n:哥白尼",
"copier":"n:复印机",
"coping":"n:顶盖",
"copious":"a:沛,洋洋",
"copper":"n:铜;a:铜",
"copper glance":"n:辉铜矿",
"copper mine":"v:铜矿",
"copper nose":"n:酒渣鼻",
"copperplate":"n:铜板,铜版",
"copra":"n:椰干",
"copse":"n:丛林",
"copter":"n:直升飞机",
"copula":"n:系词,交媾",
"copulate":"v:交尾,交媾,结合,连接,性交,交配",
"copulation":"n:交尾,交配,联系;v:性交",
"copulative":"a:交媾;n:连词",
"copy":"v:复制;n:正片",
"copy editor":"n:编审",
"copy out":"v:誊清,誊录,照抄,誊,抄写",
"copybook":"n:习字帖,字帖,字帖儿",
"copying":"n:复写,誊写;v:抄写,复印",
"copyist":"n:抄手",
"copyright":"n:版权,著作权",
"coquetry":"n:媚态,卖俏,撒娇,玩弄,妖娆",
"coquette":"n:卖俏,蜂鸟",
"coquettish":"a:妖,娇媚,轻佻,骚,扭扭捏捏,风骚",
"coral":"n:珊瑚,珊瑚虫,瑚",
"coral snake":"n:银环蛇",
"cord":"n:绳子,索;v:累,堆积",
"cordage":"n:绳索",
"cordial":"a:热诚,亲切;n:补药,补品;v:倾心",
"cordiality":"n:热诚;a:热诚",
"cording":"n:花边,绳索;v:花边",
"cordite":"n:无烟火药",
"cordon":"n:警戒线,封锁线",
"corduroy":"n:灯芯绒,条绒,灯心绒",
"core":"n:核心,中心,芯,芯子,地核,心,岩心,精髓;v:铁心",
"corgi":"n:狗",
"coriander":"n:芫荽,香菜",
"corinthian":"a:花花公子",
"cork":"n:瓶塞,软木,软木塞,栓皮,塞子;v:制止",
"cork tree":"n:黄檗",
"cork up":"v:抑制",
"corker":"n:定局",
"corking":"d:非常,极",
"corm":"n:球茎",
"cormorant":"n:墨鸦,鱼鹰,鸬鹚,水老鸦",
"corn":"n:玉米,谷物,小麦,玉蜀黍,谷粒,鸡眼,谷类,玉米粒,苞米,子;v:成熟",
"corn oil":"n:玉米油",
"corncob":"n:棒子",
"corncrake":"n:秧鸡",
"cornea":"n:角膜",
"corner":"n:角落,角,拐角,墙角,困境;v:囤积居奇,拐,紧逼",
"corner kick":"n:角球",
"cornerstone":"n:基石,基础,柱石",
"cornet":"n:短号",
"cornfield":"n:稻田,麦田",
"cornflower":"n:矢车菊",
"cornice":"n:飞檐",
"corniness":"n:谷类",
"cornmeal":"n:玉米面",
"corns":"n:五谷",
"cornstalk":"n:高个子,麦秸",
"cornucopia":"n:丰盛,聚宝盆,丰富,丰饶",
"corny":"a:老掉牙",
"corolla":"n:花冠",
"corollary":"v:推论;n:推论",
"corona":"n:日冕,电晕,谷,冠,花冠,华,光环",
"coronal":"n:花冠,冠",
"coronation":"n:加冕礼;v:加冕",
"coronet":"n:花冠",
"corp":"n:公司",
"corporal":"n:下士,班长;a:肉体",
"corporal punishment":"n:刑法,刑",
"corporate":"a:社团",
"corporation":"n:公司,企业,商行,社团,法人,团体,公会,协会",
"corporeality":"n:肉身,物质性",
"corps":"n:团体,兵团,校友会",
"corpse":"n:尸体,死尸,遗骸,尸首,僵尸,尸,行尸走肉,尸身,骨",
"corpulence":"n:肥胖",
"corpulent":"a:胖,肥大,肥胖",
"corpus":"n:汇编,基金,集成,本钱,体,躯体,身体,语料,文集,主体,资本,全集,资料",
"corpus luteum":"n:黄体",
"corpuscle":"n:微粒,粒子,细胞,血球",
"corral":"v:围,围捕,捕获,获得,取得;n:栅栏",
"correct":"v:纠正,校正,改正;a:不错,对头;n:纲",
"correcting":"v:校正",
"correction":"n:修正,校正,改正,矫正,勘误表,纠正,补正,教养,惩罚,刊误;v:校正,订正,修正",
"correctness":"n:正确性",
"corrector":"n:校对",
"correlate":"v:相关,关联,照应",
"correlation":"n:相关,对比,关联",
"correlative":"n:伙伴",
"correspond":"v:相当,对应,相应,通信,一致,相符,符合,等于,切合,配合,合乎",
"correspondence":"n:信件,通信,一致,对应,函件,通讯,件,书简,函电,书札,符合,相当",
"correspondent":"n:记者,通讯员",
"corresponding":"v:对应,相应",
"corridor":"n:走廊,过道,楼道,廊,甬道,穿廊,廊子,通路",
"corrigenda":"n:正误表",
"corroborate":"v:证实,确定,印证,确认",
"corroboration":"n:证实,坚定,验证,确定,加强,坚固;v:验证",
"corrode":"v:腐蚀,磨蚀,侵蚀,销蚀,蚀,剥蚀,腐化",
"corroded":"v:腐",
"corroding":"v:腐蚀",
"corrosion":"n:腐蚀,侵蚀,溶蚀,铁锈;v:生锈,锈蚀,腐蚀,溶蚀",
"corrosive":"n:腐蚀剂",
"corrugated":"v:瓦楞",
"corrugation":"n:皱纹,皱褶,波纹,沟纹,棱,起皱",
"corrupt":"v:腐化,贪,恶化;a:墨",
"corrupted":"v:糜烂",
"corruption":"n:腐败,贪污,腐化,堕落,舞弊,败坏,贿赂,墨,讹误;v:贪污",
"corruptness":"n:腐败",
"corsage":"n:胸部,腰身",
"corsair":"n:海盗",
"corsica":"n:科西嘉",
"cortege":"n:行列",
"cortes":"n:议会,国会",
"cortex":"n:皮层,皮质,皮,外皮",
"cortisone":"n:可的松",
"corundum":"n:金刚砂,刚石,刚玉",
"coruscate":"v:焕发,闪烁",
"coruscation":"n:焕发,闪光",
"cosh":"n:棍棒",
"cosign":"v:联署",
"cosine":"n:余弦",
"cosiness":"n:安乐,舒适,适意",
"cosmetic":"n:化妆品,美容术",
"cosmetics":"n:脂粉,化妆品",
"cosmetology":"n:美容术,美容;v:美容",
"cosmic dust":"n:宇宙尘",
"cosmonaut":"n:太空人,宇航员",
"cosmopolitanism":"n:世界主义",
"cosmos":"n:宇宙,和谐,秩序",
"cossack":"n:哥萨克人,骑警",
"cosset":"n:宠儿;v:宠爱",
"cost":"n:费用,成本,价格;v:耗",
"cost accounting":"v:成本会计",
"costa":"n:肋骨",
"costa rica":"n:哥斯达黎加",
"costar":"v:合演;n:配角",
"costliness":"n:奢华,昂贵,高价",
"costly":"a:贵,昂贵,值钱,华贵,费钱,讲究,高昂",
"costs":"n:诉讼费",
"costume":"n:服装,戏装,衣服,服饰,装束,女装,女服",
"costumes":"n:衣饰",
"cosy":"v:哄骗,奉承,讨好;a:伏贴",
"cot":"n:帆布床,套子,吊床,余切,吊铺,槛,舍,小屋,罩子",
"cotangent":"n:余切",
"cote":"n:槛,笼,栏",
"coterie":"n:圈子,同行,小集团,小圈子",
"cottage":"n:村舍,农舍,别墅,小屋,茅舍,庐",
"cotter":"n:销,制销;v:制销",
"cotton":"n:棉花,棉,棉布,棉线,花,脱脂棉;v:欢迎,交好",
"cotton gin":"n:轧花机",
"cotton grass":"n:羊胡子草",
"cotton mill":"n:棉纺厂",
"cotton plant":"n:草棉",
"cotton rose":"n:木芙蓉",
"cotton wool":"n:棉绒,棉絮",
"cottonseed":"n:棉籽",
"cottonseed oil":"n:棉子油",
"cotyledon":"n:子叶",
"couch":"n:睡椅,窝,躺椅,卧榻,床,底子,巢穴;v:隐伏,表述,睡,埋伏,躺",
"couch grass":"v:茅草;n:茅草",
"couchette":"n:卧铺",
"cougar":"n:美洲豹,美洲狮",
"cough":"v:嗽,提供,吐;n:咳",
"cough up":"v:吐,提供",
"could":"v:可以,想,能,要",
"coulomb":"n:库仑",
"council":"n:议会,委员会,理事会,讨论,协商,参议,忠告,参议会,公会,劝告,计议",
"council board":"n:会议,会议桌",
"councillor":"n:顾问,议员,委员,理事",
"councilman":"n:议员",
"councilor":"n:议员,参赞,顾问,委员,参议员",
"counsel":"n:辩护人,忠告;v:告诫,商榷",
"counsellor":"n:领队,顾问,谋士",
"counselor":"n:顾问,参赞,律师,参事,辅导员",
"count":"v:数,重要,算,指望,计数,认为;n:总计",
"count off":"v:编号",
"count on":"v:信赖,倚,自恃,倚赖,依仗,指,指靠,负,依靠",
"countable":"a:屈指可数",
"countdown":"n:读数",
"countenance":"n:脸,表情,面容,容貌,脸色,支持;v:鼓动,默认",
"counter":"n:计数器,柜台;v:筹,反,反抗,逆转,反击",
"counter check":"n:提款单",
"counteract":"v:抵消,抵制,抵抗,中和,反作用,败,抵销,杀,解,阻碍,打破",
"counteraction":"n:抵消,对抗,反动,反作用,中和",
"counteractive":"a:反对",
"counterappeal":"n:抗诉;v:抗诉",
"counterargument":"n:抗辩",
"counterattack":"v:回击,反攻,反击,还击;n:反攻",
"counterbalance":"v:抵消;n:抗衡",
"counterblast":"n:逆风",
"counterclaim":"v:反诉,索赔;n:反诉",
"counterfeit":"v:伪造;n:赝品,画像;a:伪造",
"counterfoil":"n:票根,存执,存根",
"countermand":"v:收回,召回,取消,撤回",
"countermeasure":"n:对策,干扰",
"counteroffensive":"n:反击,反攻;v:反攻",
"counterpane":"n:床罩",
"counterpart":"n:对手,副本,对方,复本",
"counterpoint":"n:对偶,对比,对照",
"counterpoise":"n:均衡,秤锤;v:均衡,抵补,补偿",
"counterrevolution":"n:反革命",
"counterrevolutionary":"n:反革命",
"countersign":"v:承认,会签,同意;n:暗号,会签,口令",
"countersignature":"n:会签",
"countersink":"v:钻孔",
"countervail":"v:抵消,补偿,抵销,对抗",
"counterweight":"n:砝码,抗衡",
"counting":"v:计数;n:计算",
"countless":"a:无数,不计其数,累累;v:更仆难数,不可胜数,数不胜数,车载斗量,指不胜屈",
"countries":"n:国家",
"countrified":"a:土头土脑,土里土气,土气",
"country":"n:国家,国,乡下,乡村,乡间,地方,地区,祖国,农村,土地,国土,国度,范围,国民,家乡,故乡,乡,民众,邦,领域,平野,室,江山",
"country house":"n:别墅",
"country of origin":"n:原产地",
"country-dance":"n:土风舞",
"countryman":"n:同胞,乡下人,同乡,乡巴佬",
"countrymen":"n:同乡,同胞,国人",
"countryside":"n:农村,乡村,乡下,田园,地方,村野,乡",
"countrywide":"a:全国,全国性;n:全国性",
"county":"n:县,县份",
"coup":"n:政变;v:政变",
"coup d'etat":"n:政变",
"couple":"v:连接,结合,交尾,结婚,交配,搂抱,配合,拥抱;n:两口子,偶合,交媾",
"coupled":"v:结合",
"coupler":"n:车钩",
"couplet":"n:对联,对",
"coupling":"n:联结,车钩,挂钩;v:联接,交尾,结合,耦合",
"coupon":"n:赠券,票,优待券,通票,副券,试件,试样",
"courage":"n:勇气,精神,胆量,胆子,胆,魄力,胆力,气魄,肝胆",
"courageous":"a:勇敢,英勇,勐,敢,勇;v:敢",
"courier":"n:信使,跑腿儿",
"course":"n:课程,航线,航向,课,方针,过程,航道,行动,路线,教程,疗程,进程,经过,科目,轨道,程序,方法,道,球场,航迹,行为,历程,经历,走向,里程;v:移动,赶",
"course of action":"n:作法",
"course of study":"n:业,教程",
"courser":"n:猎狗,骏马,军马",
"coursing":"n:运行,奔驰,追赶",
"court":"n:法庭,法院,法官,宫廷,球场,院子,朝廷,庭院;v:夺取",
"court-martial":"n:军事法庭",
"courteous":"a:客气,客客气气",
"courtesan":"n:花",
"courtesy":"n:礼貌,礼,礼节,行礼,礼数,亲切,请安,好意",
"courtesy of":"p:因为,由于",
"courthouse":"n:法院",
"courting":"v:求爱",
"courtliness":"n:殷勤,周到,谦恭,礼让",
"courtroom":"n:法庭,堂",
"courtship":"n:求婚,求爱,求偶,奉承,讨好",
"courtyard":"n:院子,庭院,院落,门庭,庭,大院,庭除,天井,院",
"cousin":"n:表妹,堂兄弟,表弟,表兄弟,表姐,堂兄,表亲,表哥,亲戚,中表,同辈,伙伴,叔伯,表姐妹,远亲,老表,堂姊妹",
"cousins":"n:叔伯",
"cove":"n:湾,拱,河湾",
"coven":"n:集会",
"covenant":"n:契约,协议书;v:缔结,契约",
"cover":"v:覆盖,被;n:隐蔽",
"cover plate":"v:盖板",
"cover up":"v:饰,韬,隐讳,掩盖,遮藏,遮掩,遮盖,埋,埋没,掩饰,文,隐匿",
"cover-up":"n:掩盖,障眼法,掩眼法",
"coverage":"n:报导,覆盖,范围,总额;v:覆盖",
"coverall":"n:罩衣",
"covered wagon":"n:棚车,闷子车,航空母舰",
"covering":"n:外壳,蒙皮,被覆,篷,外胎;v:覆盖",
"coverlet":"n:被单,床罩,盖子,桌布,罩子,床单",
"covert":"a:变相,偷偷摸摸,隐藏;v:变相",
"covertly":"d:偷,偷偷,偷偷摸摸",
"covet":"v:垂涎,觊觎,贪图,贪求,眼红,图,妄想,眼馋;a:眼热",
"covetous":"a:饕,眼红,馋",
"cow":"n:奶牛;v:威吓",
"cow dung":"n:牛粪",
"cow manure":"n:牛粪",
"coward":"n:胆小鬼,懦夫,孱头,胆小如鼠,狗熊,孬种",
"cowardice":"n:怯懦,胆怯,懦弱,胆小",
"cowardliness":"n:怯懦,懦弱,胆小",
"cowardly":"a:懦怯,懦弱,胆小,胆怯;d:懦怯,胆小怕事,胆怯;n:鼠胆;v:贪生怕死",
"cowboy":"n:牛仔,牧童",
"cower":"v:畏缩,退缩,瑟缩",
"cowherd":"n:牛倌,牛郎,牧童",
"cowhide":"n:牛皮",
"cowl":"n:睡帽,僧袍",
"cowling":"n:外壳,帽,盖",
"coworker":"n:合作者,同事",
"cowpox":"n:牛痘",
"cowpuncher":"n:牛郎",
"cowrie":"n:宝贝",
"cowshed":"n:牛棚,牛舍,牛房",
"cox":"n:艇长,舵手",
"coxcomb":"n:花花公子,鸡冠花",
"coxswain":"n:舵手,艇长",
"coy":"a:怕羞,扭扭捏捏,不好意思,羞答答,忸怩",
"coyote":"n:恶棍",
"coypu":"n:海狸鼠",
"cozen":"v:蒙",
"cozenage":"n:欺骗",
"coziness":"n:舒适",
"cozy":"a:舒适",
"crab":"n:螃蟹,蟹,蟹肉;v:贬损,干涉,挑剔,发牢骚,抱怨,苛责",
"crab louse":"n:阴虱",
"crack":"v:裂;n:警句,缺点,罅隙,一会儿,自夸,打击,缝子,罅漏,裂化,俏皮话,挖苦话,夹缝;d:啪,劈啪,喀嚓,嘎;a:精锐,特等,精干;i:吧",
"crack down":"v:打击,镇压",
"crack up":"v:垮,吹捧,夸奖",
"crack-up":"n:衰弱;a:精神衰弱",
"crackdown":"n:取缔,猛击,制裁,镇压;v:痛击",
"cracked":"a:钻石",
"cracker":"n:饼干,鞭炮,爆竹",
"crackerjack":"a:能手,专家,能干",
"cracking":"v:裂开,裂化,开裂;n:裂化",
"crackle":"v:劈里啪啦,生气勃勃;d:劈里啪啦;n:裂纹",
"crackpot":"n:疯子,怪人;a:疯子",
"crackup":"n:相撞,坠毁,崩溃",
"cradle":"n:摇篮,发源地,吊架;v:抚养",
"cradling":"v:摇篮,抚育",
"craft":"n:船,手艺,飞机,技巧,诡计,工艺,飞船,手腕,技术,行业,艺术,专业,驳船,技能,同业,同行,手工业",
"craftiness":"n:狡猾,权诈,诡计多端",
"craftsman":"n:手艺人,工匠,匠人,巧匠,技工,匠",
"craftsmanship":"n:手艺,技艺,工,工力,工艺,匠心,功,技术",
"craftsmen":"n:工匠",
"crafty":"a:狡猾,狡黠,狡诈,奸诈,阴险,滑头滑脑,佼,鬼,滑,猾,奸猾;n:贼",
"crag":"n:岩,喉咙",
"craggy":"a:嶙峋",
"cram":"v:塞满,挤,死记硬背,塞入,充塞,填入,死记",
"cramming":"v:塞满",
"cramp":"n:约束;v:禁闭,痉挛",
"cramp iron":"n:夹子",
"cramped":"a:局促,狭窄;v:逼",
"cramps":"v:抽风",
"crane":"n:吊车,起重机,鹤;v:伸,吊",
"cranium":"n:头骨,头颅,颅,脑颅,脑壳",
"crank":"n:曲柄,怪人,弯曲,幻想",
"crankiness":"n:狂妄",
"crankshaft":"n:曲轴",
"cranky":"a:古怪",
"cranny":"n:裂缝,裂口",
"crap":"n:垃圾,粪便,吹牛,废料;v:出岔",
"crap up":"v:出岔",
"crape":"n:绉布,黑纱,绉纱",
"crash":"v:坠毁,失事;n:毁坏,破产,失败,粉碎,瓦解,粗布;d:哐啷",
"crash land":"v:迫降",
"crasher":"n:不速之客,痛击",
"crate":"n:柳条箱,筐子;v:装箱",
"crater":"n:火山口,弹坑,陨石坑",
"cravat":"n:领带,围巾",
"crave":"v:渴望,需要,恳求,恳请,要求,热中,乞求,热望",
"craven":"n:胆小鬼,懦夫;a:懦怯",
"craving":"n:渴望,恳求,热望,恳请,烟瘾",
"craw":"n:喉咙,胃,嗉囊,嗉子",
"crawl":"v:爬,爬行;n:爬泳,围栏,爬行",
"crawler":"n:爬行动物,虱子,懒汉,罩衣",
"crawling":"v:折皱",
"crayfish":"n:龙虾",
"crayon":"n:蜡笔,碳精棒,粉笔",
"craze":"n:裂纹,热;v:狂妄",
"craziness":"n:发狂",
"crazing":"v:裂纹,开裂;n:裂纹",
"crazy":"a:疯,怪诞不经,狂;v:痴迷,怪诞不经",
"creak":"d:吱,咯吱,嘎;v:嘎;i:呀",
"cream":"n:奶油,雪花膏,乳脂,乳酪,精华,香脂,奶油色,华,精英,妙处,乳剂,膏,菁华;v:去掉,提取",
"cream cheese":"n:乳酪",
"cream off":"v:提取,去掉",
"cream-colored":"a:米黄",
"creaming":"v:乳化",
"crease":"n:折痕,皱纹,皱褶;v:挼,皱,擦伤",
"creased":"a:皱皱巴巴,纵",
"create":"v:创造,产生,造成,引起,制造,创作,生成,设立,创设,造,缔造,创制,建造,创,发牢骚,封爵,编造,建设,滋生,掀起",
"creation":"n:创造,创作,宇宙,发生,建设,创设",
"creations":"n:创作",
"creative":"v:独创;a:独创",
"creativeness":"n:创造性,才思",
"creativity":"n:创造性,创造力",
"creator":"n:创世主,上帝",
"creature":"n:动物,生物,家伙,东西,工具,家畜,走狗,奴才",
"creatures":"n:众生,牛马",
"credence":"n:供桌,凭证,国书,信任,信用;v:信任",
"credential":"n:凭证,证件,国书,文凭",
"credentials":"n:证件,国书,证书,凭证",
"credibility":"n:可靠性,可信性",
"credible":"a:可信",
"credibly":"d:确实",
"credit":"n:信贷,信用,贷款,荣誉;v:归,信用,信,信任,放款;a:光荣",
"credit card":"n:信用卡",
"credit side":"n:付方",
"creditability":"n:可信性",
"creditable":"a:体面",
"creditably":"d:不愧",
"creditor":"n:债主,债权人,债权,贷方",
"credo":"n:信条,教义",
"credulity":"n:轻信",
"credulous":"a:见风是雨",
"creed":"n:信条,教义,教条,宗派,主义,纲领",
"creek":"n:支流",
"creep":"v:爬,出现,爬行,产生,蔓延,蠕动,发痒;n:蠕动",
"creeper":"n:爬山虎,爬虫,蠕虫,马屁精,啄木鸟",
"creepers":"n:爬山虎",
"creeping":"a:蜿蜒,悄悄的;v:漂移,蠕动",
"cremains":"n:骨灰",
"cremate":"v:火化,烧化,焚化,火葬",
"cremation":"n:火葬,烧化;v:火葬,火化",
"crematory":"n:火葬场",
"crenellation":"n:箭垛子",
"crepe":"n:绉布,皱,绉",
"crescendo":"n:进展,渐进",
"crescent":"n:月牙,新月,弦月,伊斯兰教,娥眉月",
"cress":"n:水芹",
"crest":"n:峰,山顶,脊,浪头,山脊,冠子,鸡冠,峰值,分水岭,冠,羽冠;v:冠",
"crested myna":"n:八哥",
"crestfallen":"a:灰溜溜,丧家之犬,颓靡",
"cretaceous":"n:白垩",
"cretaceous period":"n:白垩纪",
"crete":"n:克里特岛",
"cretinism":"n:呆小症",
"crevasse":"n:决口,裂口,裂隙",
"crevice":"n:缝,裂缝,裂隙,隙,夹缝",
"crew":"n:船员,水手,机组,乘务员,群,组,班,队,包乘组,船夫",
"crew member":"n:乘务警,乘务员,乘员",
"crewman":"n:船员,乘务员",
"crib":"n:仓库,小屋,脚手架,酒吧,框,食槽,山顶;v:拘禁",
"cribbing":"v:作弊",
"cricket":"n:板球,蟋蟀,光明正大,蛐蛐儿,促织",
"crier":"n:法警",
"crime":"n:犯罪,罪行,罪,罪恶,辜,罪戾,戾,蠢事",
"crime rate":"n:犯罪率",
"crimea":"n:克里米亚",
"criminal":"n:罪犯,犯人;a:刑事",
"criminal law":"n:刑律",
"criminal record":"n:前科",
"criminality":"n:罪行,犯罪,罪恶",
"criminally":"d:犯罪",
"criminology":"n:犯罪学",
"crimp":"v:阻碍,妨碍,卷,卷曲,诱骗;n:障碍",
"crimson":"n:紫红色,深红;a:绯红,赤红",
"cringe":"v:卑躬屈节;n:畏缩",
"cringing":"v:卑躬屈节,低三下四;a:低三下四",
"crinkle":"v:起皱,皱;n:皱纹,折痕",
"cripple":"n:瘸子,残废;v:致残",
"crippled":"a:残废,废;v:废",
"crisis":"n:危机,紧要关头,危险期,难关,节骨眼,转折点,临界,恐慌;a:临界",
"crisp":"a:脆,脆生,酥脆,油酥,酥;v:卷曲,起皱;n:脆",
"crisscross":"v:纵横交错,交错;n:抵触,混乱,字母",
"crisscrossing":"v:纵横交错",
"criteria":"n:标准",
"criterion":"n:标准,准则,准绳,基准,准,臬,判定,艺,判别式,圭臬,轨范,则",
"critical":"a:危急,临界,批评,严重,紧急,吃紧,革,生死存亡,紧要,打紧,凶险,危重,中肯,沉重,笃",
"critical point":"n:紧要关头",
"criticise":"v:批评",
"criticism":"n:批评,评论,批判,非难,鉴定,审定,校勘",
"criticize":"v:批评,说,评论,挑剔,批判,指责,非难,批斗,非议,批驳,批,评,揭批,鉴定,贬责,刺,校勘",
"critique":"n:批评,批判,评论,鉴定,检阅;v:批判",
"croak":"v:抱怨,发牢骚,死;n:牢骚,怨言;d:呱呱",
"croatia":"n:克罗地亚",
"crochet":"n:钩",
"crock":"n:缸,坛子,废物,胡说,罐;v:衰竭,掉色",
"crock up":"v:衰竭",
"crockery":"n:陶器,瓦器,瓦罐",
"crocodile":"n:鳄鱼,鳄",
"crocodile tears":"n:鳄鱼眼泪",
"crocus":"n:藏红花,庸医",
"croft":"n:宅地",
"crone":"n:干瘪",
"crony":"n:老友,密友",
"cronyism":"n:友谊",
"crook":"n:骗子,坏蛋,恶棍;v:弯曲",
"crooked":"a:歪,弯,卑鄙,弯曲;v:贼,歪七扭八,曲,歪斜;d:歪七扭八;n:贼",
"croon":"v:哼,哼唱",
"crop":"n:庄稼,作物,农作物,产量,收成,收获;v:发芽",
"crop failure":"n:荒,饥,凶,荒歉,歉,歉收",
"crop out":"v:露出",
"crop up":"v:出现,发生,来",
"cropland":"n:农田,田",
"cropper":"n:庄稼,佃农,割草机,收割机,作物",
"cropping":"v:剪切,栽培",
"crops":"n:庄稼,农作物,稼",
"crosier":"n:拐杖",
"cross":"v:过,穿过;n:不幸,挫折,骗局;a:十字",
"cross out":"v:删除,杠,涂,一笔抹煞,勾,勾除,抹",
"cross product":"n:矢量积",
"cross section":"v:截面,抽样,样品,剖面",
"cross-country":"a:越野",
"cross-examination":"n:盘问",
"cross-eye":"n:斗眼",
"cross-legged":"n:二郎腿;d:盘膝",
"cross-pollination":"n:异花传粉",
"cross-question":"v:盘问",
"cross-refer":"v:对照,参照",
"crossbar":"n:裳,闩",
"crossbeam":"n:横梁,大梁",
"crossbow":"n:弩弓,弩",
"crossbred":"n:杂种",
"crossbreed":"n:杂种;v:杂交",
"crosscurrent":"n:逆流,横流",
"crosscut":"n:捷径,石门",
"crossfire":"v:干扰;n:干扰",
"crossing":"n:交叉,横渡,渡口,杂交,挫折,阻碍,阻挠,划线,路口,相交,交叉点;v:交叉,相交",
"crossing over":"n:交换",
"crossly":"d:横,斜",
"crossness":"n:别扭",
"crossover":"n:截面,天桥,交叠,交叉,交换,岔道,相交,交叉点;v:相交,交叉",
"crosspiece":"n:档儿",
"crossroad":"n:十字路口,立交桥",
"crossroads":"n:歧路,十字街头,十字路口",
"crosstalk":"n:串话;v:串话",
"crosswalk":"n:斑马线",
"crosswise":"d:交叉,横向;n:横向",
"crotch":"n:裤裆,裆,胯,丫杈,桠杈,岔口,树杈",
"crotchet":"n:怪癖",
"crotchety":"a:生气",
"crouch":"v:蹲,蹲伏;n:蹲",
"croup":"n:臀部",
"crow":"v:啼;n:老鸦,老鸹,鸦",
"crowbar":"n:撬棍,撬棒,短路器,断裂,撬杠",
"crowd":"n:人群,群众;v:拥挤,塞满",
"crowd out":"v:排挤,挤出",
"crowd together":"v:辏,丛集,丛,簇",
"crowded":"v:肩摩踵接;a:拥挤",
"crowfoot":"n:撬棍,吊索",
"crowing":"v:加冕",
"crown":"n:王冠;v:戴,酬劳",
"crown imperial":"n:皇冠",
"crown prince":"n:东宫",
"crowning":"n:终结,加冕;a:登峰造极,至高无上;v:至高无上",
"crucial":"a:紧要",
"crucian carp":"n:鲋",
"crucible":"n:坩埚,熔炉",
"crucifix":"n:十字架",
"crucifixion":"n:刑罚",
"crucify":"v:折磨",
"crude":"a:粗,粗糙,粗暴;n:原油",
"crudeness":"n:芜杂",
"crudity":"n:生,生硬",
"cruel":"a:残忍,残酷,狠心,凶狠,残暴,心狠,惨无人道,野蛮,厉害,暴虐,心毒;d:非常",
"cruelty":"n:残忍,残酷,虐待,残暴,刻毒,冷酷",
"cruise":"v:巡逻,巡游,巡航;n:游览,旅行,巡游,周游,巡逻",
"cruise missile":"n:巡航导弹",
"cruiser":"n:巡洋舰,游艇",
"crumb":"n:面包屑,团粒,少许,碎片,点滴",
"crumble":"v:崩溃,崩塌,破碎,倒塌,瓦解,土崩瓦解,粉碎,崩,灭亡,溃散,消灭,坍塌",
"crumbling":"v:摇摇欲坠",
"crumbs":"n:屑,渣",
"crummy":"a:丰满",
"crumple":"v:崩溃,皱,起皱,打皱,击溃",
"crumpled":"a:皱皱巴巴,纵;v:皱皱巴巴",
"crunch":"n:咬;v:咬",
"crusade":"n:十字军,讨伐;v:开战,讨伐",
"cruse":"n:壶,瓦罐,坛子",
"crush":"v:粉碎;n:迷恋",
"crusher":"n:破碎机",
"crushing":"a:粉碎;v:粉碎",
"crust":"n:地壳,外壳,外表,表面,外皮,厚颜无耻,老面皮;v:结痂",
"crustacean":"n:甲壳动物",
"crusted":"v:陈年",
"crustiness":"n:顽固,硬壳,倔强,执拗",
"crusty":"a:乖戾",
"crutch":"n:拐杖,依靠,支柱;v:拐,支撑",
"crux":"n:关键,要点,难题,症结,难处,难点,坩埚",
"cry":"v:哭,叫;n:谣传,运动,口号,呐喊,哀求,呼吁;d:哇哇",
"cry for":"v:请求,恳求",
"cry out":"v:叫唤,大叫,吆喝,喊,喊叫,呼,呐喊",
"cry out for":"v:急需",
"crying":"v:哭声",
"cryogenics":"n:低温学",
"crypt":"n:地窖,地穴",
"cryptogram":"n:密码,暗号,隐花植物",
"cryptographer":"n:密码员",
"cryptology":"n:隐语",
"crystal":"n:晶体,水晶,结晶,石英,结晶体,厕所,晶粒,预言,占卜",
"crystal ball":"n:玻璃球",
"crystal clear":"a:湛,滢,清澈,鲜明",
"crystal lattice":"n:晶体点阵",
"crystalline":"a:粼粼,结晶体;n:水晶体",
"crystalline lens":"n:水晶体,晶状体",
"crystallization":"n:结晶,结晶体,明朗化",
"crystallize":"v:结晶;n:结晶",
"crystallography":"n:结晶学,晶体学",
"cub":"n:仔畜,仔,生手,子畜,幼畜",
"cuba":"a:古",
"cube":"n:立方体,立方,四面体",
"cube root":"n:立方根",
"cubic":"n:四方",
"cubic measure":"n:容积,容量",
"cubic meter":"n:立方",
"cubicle":"n:室,部分,段",
"cubism":"n:立体派",
"cuboid":"n:长方体",
"cuckold":"n:王八,乌龟;v:戴绿帽子",
"cuckoldry":"n:通奸,私通",
"cuckoo":"n:杜鹃,布谷鸟;a:笨,傻",
"cucumber":"n:黄瓜,胡瓜",
"cuddle":"v:搂;n:搂抱,拥抱",
"cudgel":"n:棍棒,棒,棒子,木棒,哨棒",
"cue":"n:暗示,指示,线索,发辫,提示,暗号,刺激,角色,心情",
"cuff":"n:袖口,手铐,打,袖头,罗口",
"cuisine":"n:菜肴,厨房,烹调法,烹饪",
"culinary art":"n:烹饪",
"cull":"v:采,选拔,摘,拣;n:等外品",
"culling":"v:精选,选择",
"culmination":"n:高潮,极度,绝顶,成就,顶点,极点,完成",
"culottes":"n:裙裤",
"culprit":"n:罪犯,犯人,未决犯,嫌疑犯,犯罪",
"cult":"n:崇拜,信徒,祭礼,信仰,迷信,异教,礼拜,邪教",
"cultivate":"v:培育,耕种,培养,种,养成,耕作,开垦,种植,养,培植,垦,莳,树,陶,栽培,中耕,护养,耪,修,追求,培,磨炼,养殖,谋求,教化,垦殖,培训,发展,耕,植",
"cultivated land":"n:耕地",
"cultivation":"n:栽培,耕种,耕作,开垦,修养,养殖,农垦,教养,培养,造林;v:耕耘,耕作",
"culture":"n:文化,修养,文明,栽培,养殖,教养;v:培养,养殖",
"culture medium":"n:培养基",
"cultured":"a:斯文,文雅",
"culvert":"n:涵洞,暗渠,涵,阴沟",
"cum":"p:兼,和,附属,与;v:附有",
"cumber":"v:妨碍,拖累,妨害,阻碍,阻塞;n:妨碍",
"cumberland":"n:坎伯兰",
"cumbersome":"a:笨重,笨,滴里嘟噜,缛,粗笨,冗长",
"cumin":"n:小茴香",
"cummerbund":"n:腰带,腰围",
"cumulative":"a:滚存",
"cumulonimbus":"n:积雨云",
"cumulus":"n:积云,堆",
"cumulus cloud":"n:积云",
"cuneiform":"n:楔形,楔形文字",
"cunning":"a:狡猾;n:诡诈,贼,巧妙",
"cunt":"n:女人",
"cup":"n:杯子,杯,茶杯,银杯,奖杯,酒,酒杯,冷饮,饮酒;v:拔罐子",
"cupboard":"n:柜橱,柜子,橱柜,柜,碗柜,餐具柜",
"cupid":"n:爱神",
"cupidity":"n:贪婪,贪欲,贪心",
"cupola":"n:化铁炉",
"cupric sulphate":"n:硫酸铜",
"cur":"n:恶狗",
"curative":"n:药品,医药",
"curator":"n:馆长,监护人,保管员,学监",
"curb":"n:制止,路肩,镶边;v:制止,束缚",
"curbside":"n:街道",
"curdle":"v:凝结,凝固,狞笑,凝;n:结块",
"cure":"v:治疗,治愈,治,医治;n:疗程,补救,处治,对策,疗养",
"curfew":"n:宵禁;v:宵禁",
"curie":"n:居里",
"curing":"v:养护,硬化,治疗;n:治愈",
"curio":"n:古玩,骨董,古董",
"curiosity":"n:好奇心,好奇,珍品,古董,奇人",
"curious":"a:奇怪,奇异,稀奇古怪,希奇",
"curiously":"d:很,非常",
"curium":"n:锔",
"curl":"v:卷曲,蜷曲;n:拳",
"curl up":"v:旋绕,翘,蜷缩",
"curler":"n:卷发夹",
"curlicue":"n:花饰",
"curliness":"n:卷曲,旋涡",
"curling":"v:卷曲;n:卷曲",
"curly":"a:卷,鬈",
"currency":"n:货币,通货,通用,流通,传播,流传,行情,币,钱钞,宝,钿",
"current":"n:电流;a:现,流,通行;v:通用,通行,融",
"current assets":"n:流动资金",
"currently":"d:现在,通常,这会儿,流畅,现,一般",
"curricula":"n:课程",
"curriculum":"n:课程",
"curriculum vitae":"n:履历,履历表",
"curry":"v:鞭笞,打;n:咖喱,咖哩",
"curry favor":"v:钻营",
"curse":"v:诅咒,咒骂,骂;n:祸乱",
"cursed":"v:狗;n:狗",
"curses":"n:咒语",
"cursive":"n:草书;a:草书",
"cursive script":"n:草书",
"cursor":"n:指示器,游标",
"cursory":"a:浮光掠影,肤皮潦草;v:浮光掠影",
"curtail":"v:缩减,削减,缩短,节减,省略,剥夺,褫夺",
"curtailing":"v:缩短",
"curtailment":"n:削减",
"curtain":"n:窗帘,幕,帘子,幕布,门帘,帘,围子,垂帘,幔帐,隔壁;v:遮蔽,剧终,隐藏",
"curtain call":"n:谢幕",
"curtain raiser":"n:小事",
"curtness":"n:草率,简略",
"curvature":"n:曲率,弯曲",
"curve":"n:曲线,弯,弯曲,弧形;v:弯",
"curved":"v:弓形,弯;a:弯曲;n:弓形",
"cushion":"n:垫子,靠垫;v:掩饰",
"cusp":"n:牙齿,波峰,交点,尖头,尖端",
"cuspid":"n:犬齿",
"cuspidor":"n:痰盂",
"cuss":"n:咒骂,粗话,坏话,诅咒;v:咒骂,诅咒",
"cussedness":"n:乖戾",
"custard":"n:蛋羹",
"custodian":"n:监护人,保管人,门卫,管理员",
"custody":"n:拘留,保管,监护,看守,管理,监禁,收容",
"custom":"n:风俗,海关,习惯,习俗,惯例,关税,习惯法,规矩,常规,风,遗俗,流俗;a:俗;v:定制",
"customarily":"d:通常,素来,照例",
"customary":"a:惯用,惯;v:惯",
"customer":"n:顾客,客户,主顾,人,家伙,买主,观众,店客,顾主,听众,客",
"customhouse":"n:海关,关",
"customize":"v:定制,定做",
"customs":"n:关税,海关,进口税",
"customs duty":"n:关税",
"cut":"v:切;n:插画",
"cut across":"v:穿越,跨,跨越",
"cut away":"v:逃走",
"cut back":"v:削减,修剪,减少",
"cut down":"v:伐,刈,斩断,减削,芟除,缩短,压缩,裁,紧缩,削减,裁减",
"cut in":"v:插嘴,打岔",
"cut off":"v:湔,戬,删除,割断,绝,刽,断开,割切,断,关闭,祝,阻隔",
"cut out":"v:断开,收起,止,剪裁,截取,删除,删削,剜",
"cut price":"n:降价",
"cut short":"v:打断,截断",
"cut-in":"n:接通,开动",
"cutback":"n:减产,剪枝,倒叙",
"cute":"a:哏,乖巧;v:讨人喜欢",
"cuticle":"n:表皮,皮面",
"cutie":"n:美人,情人,尤物",
"cutlass":"n:短剑",
"cutlery":"n:刀具",
"cutlet":"n:肉排,肉片",
"cutoff":"n:断开,运河,捷径,近路,中止,停车,切断,熄火;v:断开,熄火",
"cutout":"n:排气阀,保险装置,断开,剪纸",
"cutter":"n:刀具,门牙,截煤机,切割机",
"cutthroat":"n:凶手;a:凶残",
"cutting":"n:扦插,插条,加工,切断,路堑,剪辑;v:刻,切割,开凿,采掘,切削,伐木,剪辑,削球;a:厉害,尖利",
"cutting angle":"n:切削角",
"cutting edge":"n:尖端,前沿",
"cutting out":"v:剪贴",
"cutting tool":"n:刀具",
"cuttle":"v:折叠",
"cuttlefish":"n:乌贼,墨鱼,鲗",
"cutup":"n:痛骂,打击",
"cutworm":"n:地蚕,毛虫,地老虎",
"cyan":"n:青色",
"cyanide":"v:氰化",
"cyanogen":"n:氰",
"cybernetics":"n:控制论",
"cyclamen":"n:仙客来",
"cycle":"n:循环,周期,摩托车,自行车,周;v:轮转",
"cycling":"v:循环",
"cyclometer":"n:里程表,计程表",
"cyclone":"n:旋风,气旋,羊角,扶摇",
"cyclopedia":"n:百科全书",
"cygnus":"n:天鹅",
"cylinder":"n:汽缸,气缸,圆柱,圆筒,圆柱体,滚筒,钢瓶,柱,量筒",
"cynical":"a:冷嘲热讽;v:冷嘲热讽",
"cynicism":"n:玩世不恭,愤世嫉俗,讥诮,冷言冷语,冷笑",
"cynosure":"n:北极星,指针",
"cypher":"n:密码",
"cypress":"n:柏树,扁柏,柏木,刺柏,柏",
"cyprus":"n:塞浦路斯",
"cyst":"n:囊肿,囊,膀胱,胞",
"cystitis":"n:膀胱炎",
"cytology":"n:细胞学",
"cytoplasm":"n:细胞质",
"czar":"n:沙皇",
"czech":"n:捷克",
"czechoslovakia":"n:捷克斯洛伐克",
"dab":"n:啄,比目鱼,些许,名手,能手,少量;v:啄,潮湿;a:潮湿",
"dabble":"v:涉猎,蘸,浸,喷水,沾,浅尝",
"dabbler":"n:二百五,爱好者,半吊子,半瓶醋",
"dace":"n:鲮,土鲮鱼,鲮鱼",
"dacron":"n:涤纶,的确良",
"dactyl":"n:手指,脚趾",
"dad":"n:爸爸,爸,爹,爹爹,父;i:神",
"dada":"n:爸,爸爸",
"daddy":"n:爸爸,爹爹,爹,父,老爹",
"dado":"n:墙裙",
"daffodil":"n:水仙",
"daft":"a:傻,发痴",
"dagger":"n:短剑,匕首,尖刀,匕,敌意,短刀,攮子",
"dahlia":"n:大丽花,西番莲",
"dahomey":"n:达荷美",
"daily":"d:每天;n:日,生计,朝夕;a:日常",
"dainties":"n:珍馐",
"daintily":"d:好看,考究,优雅,好吃,讲究",
"daintiness":"n:美味,优雅,优美,讲究,考究,美丽",
"dainty":"a:轻巧,纤巧,羞,细巧;n:美味",
"daiquiri":"n:鸡尾酒",
"dairy":"n:奶制品",
"dais":"n:高台,平台,上座,讲坛,讲台,台,华盖,坛",
"daisy":"n:上品",
"dalai lama":"n:达赖喇嘛",
"dale":"n:山谷",
"dalian":"n:大连",
"dallas":"n:达拉斯",
"dalliance":"n:调笑,调戏,混日子,调情",
"dally":"v:玩弄,浪费,憧憬,戏弄,想象,调戏,闲荡,延误,调情,嬉戏",
"dam":"n:水坝,坝,堤坝,大坝,水闸;v:截流,阻塞",
"dam up":"v:抑制",
"damage":"v:损坏;n:毁损,残,祸害,代价",
"damaged":"v:缺损,破损;a:破",
"damages":"n:赔偿费",
"damascus":"n:大马士革",
"damask":"n:锦缎,缎子,花布",
"dame":"n:女人,夫人,少女,主妇,太太,妇女",
"damming":"v:回水,筑坝",
"damn":"v:该死,指责,咒骂,攻击,毁坏,咒;n:些微,诅咒,讨厌",
"damnable":"a:可憎",
"damnation":"n:诅咒,该死,破灭,毁坏,痛骂,指责",
"damned":"d:非常,极;n:狗",
"damning":"v:咒诅,诅咒",
"damp":"n:潮湿;v:减震;a:湿漉漉",
"dampen":"v:沮丧,挫伤,减少,扫兴,抑制,缓冲,减轻",
"dampener":"n:减震器",
"dampening":"n:阻尼;v:衰减",
"damper":"n:减震器,风门",
"damping":"v:减震,缓冲,衰减;n:衰减",
"dampness":"n:潮湿,润湿,受潮,潮气,湿气,湿度",
"damsel":"n:小姐",
"damson":"n:紫色",
"dance":"v:跳舞;n:舞曲",
"dance floor":"n:舞池",
"dance hall":"n:舞场",
"dancer":"n:舞蹈家,舞女,舞客",
"dancing":"v:舞,跳跃;n:舞蹈,跳舞;a:婆娑",
"dandelion":"n:蒲公英",
"dander":"n:头皮屑,怒气",
"dandle":"v:娇养,宠爱,舞弄,逗弄",
"dandruff":"n:头皮屑,头皮",
"dandy":"n:花花公子,上品,纨绔子弟,快艇",
"danger":"n:危险,威胁,危险性,风险,险情,危,危险物,险地,殆,险象;a:危险",
"dangerous":"a:危险,险,险恶,危,悬乎,革,悬",
"dangerously":"d:危险",
"dangle":"v:摇摆,尾随,追逐,悬垂,悬挂",
"dank":"n:潮湿,沼泽地;a:潮呼呼",
"danube":"n:多瑙河",
"daphne":"n:瑞香",
"dapple":"n:斑纹",
"dare":"v:敢,竟敢,敢于,胆敢;n:挑战,胆量,勇气,挑逗",
"daredevil":"n:鲁莽,胆大妄为;v:胆大妄为;a:冒失鬼",
"daring":"n:气魄;a:意气风发;v:敢",
"dark":"a:黑;n:阴影,傍晚,愚昧,隐晦,墨,无知,暗黑,暗色,隐秘",
"dark blue":"n:沧,藏青",
"dark horse":"n:黑马",
"dark red":"n:恹,绀,绯",
"darken":"v:阴,蒙蔽",
"darkie":"n:黑人",
"darkly":"d:模糊,暗,暗中,黑,毒,恶,秘密,暗地里",
"darkness":"n:黑暗,浓,无知,蒙昧,阴险,幽暗,秘密,墨黑,阴暗,含糊",
"darkroom":"n:暗室,暗房",
"darling":"n:亲爱的,宝贝;a:心爱",
"darn":"v:织补,他妈的,补缀,缝补,补丁",
"darning":"n:织补,缝补",
"dart":"n:刺,飞弹,突进,标枪;v:放射,发射",
"darts":"n:镖",
"darwin":"n:达尔文",
"darwinism":"n:进化论",
"das kapital":"n:资本论",
"dash":"n:挡泥板,愣劲儿,笔触,门面,打击,虎劲;v:奔跑",
"dashboard":"n:挡泥板",
"dasher":"n:搅拌器",
"data":"n:事实,数据,知识,材料,资料",
"database":"n:数据库",
"date":"n:日期,约会,日子;v:始",
"date from":"n:追溯",
"date line":"n:日界线",
"date palm":"n:海枣",
"date stamp":"n:日戳",
"dater":"n:日戳",
"dating":"v:幽会",
"datum":"n:资料,基准,论据,基线,基点",
"daub":"v:涂,涂抹,溜,刷,抹;n:胶泥,涂料,涂抹",
"dauber":"n:精神,半吊子,勇气,泥水匠",
"daubing":"n:炉衬,涂料;v:炉衬,涂料",
"daughter":"n:女儿,产物,姑娘,闺女,赔钱货;a:女",
"daughter-in-law":"n:儿媳妇,儿媳",
"daunt":"v:恐吓,威吓,难倒,吓,压",
"dauntless":"a:百折不挠,无畏;v:无畏,百折不挠",
"davenport":"n:书桌",
"david":"n:大卫,戴维",
"davis":"n:戴维斯",
"davit":"n:吊杆",
"davy":"n:戴维,发誓",
"davy jones's locker":"n:海底",
"dawdle":"v:磨蹭,耗,泡蘑菇,磨,蘑菇,混日子,挨,泡,游荡",
"dawdling":"v:磨洋工",
"dawn":"n:黎明,拂晓,曙光,清晨;v:渐悟,黎明,破晓;d:一大早",
"dawn redwood":"n:水杉",
"dawning":"n:东方,曙光,醒悟,拂晓,端绪,开端,黎明;v:开始",
"day":"n:天,日子,白天,日,白昼,战斗,节日,胜利,朝,日光,寿命,白日,昼,戴,大白天",
"day after day":"n:日复一日",
"day book":"n:日记簿",
"day by day":"d:每天;a:天天",
"day care":"n:日托",
"day laborer":"n:日工",
"day lily":"n:黄花,萱",
"day of judgment":"n:末日",
"day off":"n:假日,休假",
"day shift":"n:白班儿",
"day-to-day":"a:日常",
"daybreak":"n:拂晓,黎明,曙,清晨;v:天亮",
"daydream":"n:白日梦,幻想,空想,梦话,白日作梦,幻梦;v:痴心妄想,遐想,做梦",
"daydreamer":"n:空想家",
"daydreaming":"v:痴心妄想",
"daylight":"n:日光,白天,白昼,天光,拂晓,黎明,昼,公开,视力,发表,智力,间隔",
"daylong":"d:终日;a:终日",
"days":"n:年头,日子,时,时光,年月",
"daytime":"n:白天,大白天,日,白昼,昼,白日",
"daze":"n:恍惚,迷乱;v:耀眼",
"dazed":"a:昏沉,迷茫",
"dazzle":"v:晃,闪;n:荧惑,闪耀",
"dazzled":"v:目眩",
"dazzling":"a:耀眼,刺眼,琳琅满目;v:灿烂夺目,琳琅满目",
"db":"n:分贝",
"dc":"n:直流电,直流",
"ddt":"n:滴滴涕",
"de":"n:从,关于",
"deacon":"v:蒙混;n:执事",
"deactivate":"v:解散,吊销",
"deactivation":"n:钝化",
"dead":"a:沉寂,全然;d:十足;n:死者;v:僵死",
"dead ahead":"n:正前方",
"dead body":"n:尸身,死尸,尸首",
"dead end":"n:绝境,此路不通,绝路,尽头,终点,末路,穷途末路,僵局",
"dead letter":"n:虚文,空文,死信",
"dead person":"n:死人",
"dead room":"n:消声室",
"dead sea":"n:死海",
"dead weight":"n:重担,自重,重负,净重",
"deaden":"v:减弱,缓和,走味",
"deadened":"v:隔音,削弱",
"deadline":"n:期限,限期",
"deadliness":"n:致命",
"deadlock":"n:僵局;v:搁浅,弄僵",
"deadlocked":"v:僵,胶着;a:僵",
"deadly":"a:致命,死,致死;d:非常,极;v:致死,致命",
"deadness":"n:死,死气沉沉,走味",
"deadwood":"n:优势,枯枝,陈货",
"deaf":"n:耳聋,聋子;a:聋",
"deaf-aid":"n:助听器",
"deaf-and-dumb":"a:聋哑",
"deaf-mute":"n:聋哑人,聋哑,聋哑症",
"deafen":"v:淹没",
"deafening":"a:山响",
"deafness":"n:耳聋,聋",
"deal":"v:处理;n:密约,协议,政策,数额,松木,协定,交",
"deal out":"v:分配",
"dealer":"n:商人,贩子,商,经销商,庄家,贩",
"dealership":"n:代理权,经销权",
"dealing":"n:交易,生意,分配,行为,处置,待遇,交际,举动",
"dealings":"n:来往,往来;v:往还",
"dean":"n:系主任,院长,教务长,教长,学监,深谷",
"dear":"a:亲爱的,亲爱,贵;n:心尖,爱人,宠物;d:贵;i:呀",
"dearly":"d:昂贵,深深地",
"dearness":"n:高价,贵重,亲爱",
"dearth":"n:饥荒,缺乏,饥馑",
"deary":"n:亲爱的,心肝",
"death":"n:死,死亡,死刑,死神,死因,毁灭,谋杀,死命,杀气,惨死;v:长眠,坐化;d:终",
"death duty":"n:遗产税",
"death knell":"n:丧钟",
"death penalty":"n:死刑",
"death tax":"n:遗产税",
"death's head":"n:骷髅",
"deathbed":"n:临终",
"deathless":"a:永恒",
"deathly":"d:非常,十分;a:致命",
"deathtrap":"n:死地",
"debacle":"n:瓦解,崩溃,毁灭,泛滥,山崩,解冻,溃散;v:山崩",
"debar":"v:禁止,阻拦,排除,阻止,防止",
"debarkation":"n:上岸,登陆;v:上岸",
"debarment":"n:阻止,阻拦",
"debase":"v:降低,贬值,贬低,庸俗化,堕落,败坏,贬损",
"debasement":"n:降低",
"debate":"v:辩论,讨论,考虑;n:论争",
"debauch":"v:伤害,诱奸,败坏,勾引,沉湎酒色,放荡;n:放荡",
"debauched":"a:荒淫",
"debauchery":"n:放荡,诱奸;v:奸污",
"debenture":"n:债券",
"debilitated":"a:虚弱",
"debility":"n:虚弱;a:虚弱,衰弱",
"debit":"n:借方,收方",
"debit side":"n:收方",
"debouch":"v:进入,流出,溢出",
"debrief":"v:报告",
"debris":"n:碎片,瓦砾,碎石,废墟,断垣残壁",
"debt":"n:债务,债,债款,借款,欠款,亏欠,帐,饥荒,罪孽,恩,窟窿,亏空;v:亏欠",
"debtor":"n:债务人,负债人,债户,借方",
"debug":"v:调试,驱除,调整,调谐",
"debugging":"n:查错程序;v:调试",
"debunk":"v:揭穿,暴露",
"dec":"n:十二月,12月",
"decade":"n:秩,十",
"decadence":"n:堕落,衰退,颓废,退步",
"decadency":"n:衰微",
"decadent":"a:颓废,浇,颓败;v:浇;n:黄色",
"decamp":"v:逃之夭夭,溜掉,开小差,逃亡,逃走,拔营",
"decant":"v:倾注,下,倒入,卸,滗",
"decapitate":"v:斩首,解雇,杀头",
"decapitation":"n:斩首,解雇",
"decapitator":"n:刽子手",
"decay":"v:衰落,腐烂,衰减,衰变;n:衰微",
"decayed":"v:败,烂,朽,腐朽;a:腐败,烂,腐朽,零落",
"decaying":"a:衰朽;v:衰落",
"decease":"v:亡故,永眠;n:死,死亡",
"deceased":"v:先,已故;d:先;c:故;a:已故",
"decedent":"n:死者",
"deceit":"n:欺骗,欺诈,诈,诡计",
"deceitful":"a:狡诈,诡,奸猾,巧;n:贼",
"deceive":"v:欺骗,骗,瞒,蒙蔽,蒙骗,诓,行骗,欺瞒,诳,蒙,蒙哄,耍弄,诖,误解,欺诈,谩,诓骗,瞒哄,欺,欺哄,虞,罔,愚弄,诈欺,赚,糊弄",
"deceiver":"n:骗子",
"decelerate":"v:减速,减退",
"deceleration":"n:减速",
"decelerator":"n:减速器",
"december":"n:十二月,12月",
"decency":"n:礼仪,正派,端庄,庄重,合宜,适当,礼节,风化,体统,面子",
"decent":"a:像样,正派,正经,大方",
"decentralise":"v:疏散,分散",
"decentralization":"n:分散",
"decentralize":"v:分散,疏散",
"deception":"n:欺骗,骗局,欺诈,哄骗,受骗,掩饰,诈欺;v:掩饰",
"decibel":"n:分贝",
"decide":"v:决定,解决,判决,决心,断定,判断,定,裁决,下决心,决,判定,选定,判,作主,定夺,断,评判,夺,主宰,裁,裁断",
"decided":"a:明显;v:铁板钉钉",
"decidedly":"v:毫不迟疑,断;d:决然",
"decider":"n:决赛",
"decimal":"a:小数;n:小数",
"decimal point":"n:点",
"decimal system":"n:十进制",
"decimeter":"n:分米",
"decimetre":"n:分米",
"decipher":"v:破译,辨认,解释;n:译码",
"deciphering":"v:解密",
"decipherment":"n:解释,译文,辨认",
"decision":"n:决定,判决,决心,决议,决断,裁判,主意,判定;v:判定,裁断",
"decision maker":"n:决策者",
"decisive":"a:果断",
"decisiveness":"n:决断,决定性",
"deck":"v:打扮,装,装点,修饰;n:舱面",
"deck chair":"n:躺椅",
"deck out":"n:装扮,装饰,妆饰",
"declaim":"v:朗诵,朗读,演说,攻击",
"declamation":"n:演说,朗读,雄辩",
"declaration":"n:宣言,声明,说明,宣布,申报,陈述,宣告,公告;v:告",
"declare":"v:宣布,声明,申报,宣称,声称,公布,宣告,断言,申明,声言,徇,告,报关,披露,报,布,发表,摊牌,宣示,招,指控,陈述,宣,声;n:布",
"declension":"n:衰退,堕落,衰微,倾斜",
"declination":"n:倾斜,衰微,偏差,拒绝,磁偏角,偏转,谢绝,偏角",
"decline":"v:下降,谢绝,衰退,拒绝;n:下落,下坡;a:衰微",
"decliner":"n:拒绝",
"declining":"a:颓败,微;n:婉言谢绝",
"declivity":"n:坡度,倾斜,斜坡",
"decode":"v:译码,解码;n:译码",
"decoder":"n:解码器,译码器",
"decoding":"n:译码,解码;v:译码,解码",
"decolletage":"n:女服",
"decompose":"v:分解,腐烂,还原,破坏,分析,衰变,剖析",
"decomposition":"n:分解,腐朽;v:分解",
"decompress":"v:放松,松弛,减压",
"decompression":"n:减压,降压",
"decontaminate":"v:净化,消毒",
"decontamination":"n:净化",
"decor":"n:装饰,布置",
"decorate":"v:装饰,布置,修饰,油漆,张挂,缀,装潢,染色,饰,粉刷,装点,修,装,装扮",
"decoration":"n:装饰,装饰品,勋章,奖章,装潢,装璜,染色,张挂",
"decorations":"n:饰物",
"decorous":"a:厚重",
"decorum":"n:礼貌,礼节,礼仪,端庄,体统,正派",
"decoupage":"n:剪影",
"decouple":"v:减震",
"decoy":"n:诱饵,骗局,迷魂阵,游子,圈套;v:诱骗,引诱",
"decrease":"v:减少,减小,下降,减弱,减轻,减退,掉,减,减损,减缩",
"decree":"n:命令,法令,判决;v:判决",
"decrement":"n:递减,减缩,消耗;v:缩减,减缩",
"decrepit":"a:老弱,老,飒,衰老,龙钟;v:衰朽",
"decrepitude":"n:衰老,老朽",
"decry":"v:谴责,诋毁,贬值",
"decrypt":"v:解密",
"decryption":"n:译码",
"dedicate":"v:献给,献身,奉献,贡献,献出,献上,奉,供奉,献",
"dedicated":"a:耿耿",
"dedication":"n:献身,奉献,题辞,献辞,题词",
"deduce":"v:推断,推导,推论,演绎,推演,演,裁度;n:演绎",
"deduct":"v:扣除,扣,推论,演绎,刨,减,除去",
"deducting":"v:减去",
"deduction":"n:推断,推论,扣除,演绎,折扣,演绎法;v:推论,推断",
"deductive":"a:演绎",
"deed":"n:行为,行动,事迹,契约,契据,文契,功绩,证书,契纸,实行;v:举,立据",
"deem":"v:认为,相信,想,以为",
"deep":"a:深;n:深处;d:深",
"deep red":"n:绯,绛",
"deep water":"n:深水",
"deep-rooted":"a:根深蒂固,刻骨",
"deep-seated":"a:根深蒂固",
"deepen":"v:加深,深化,加重",
"deepening":"v:加深",
"deeply":"d:深,深深地,深深,熟;v:盛;a:痛",
"deer":"n:鹿",
"deerskin":"n:鹿皮",
"deescalate":"v:缩小",
"deface":"v:毁伤,毁坏,磨灭",
"defacement":"n:毁损,磨损,磨灭",
"defalcate":"v:监守自盗,亏空",
"defamation":"n:毁谤",
"defame":"v:诋毁,诽谤,毁,诋,丑化,谤,毁谤,抹黑,中伤",
"default":"n:拖欠,缺乏,欠缺,违约;v:拖欠,违约",
"defeat":"v:打败,击败;n:废除",
"defeated":"a:溃败",
"defecate":"v:澄清,净化,遗矢,大便",
"defecation":"v:澄清;n:澄清",
"defect":"n:缺陷,缺点,毛病;v:背叛,开小差,逃跑,失,逃走,陷,反水",
"defection":"n:脱党,变节,叛党,背信,背叛",
"defective":"n:废品",
"defector":"n:叛徒",
"defects":"n:弊端",
"defence":"n:防御,辩护,防卫,防务,答辩,保卫,抗辩,防备,堡垒",
"defend":"v:辩护,保卫,保护,防守,捍卫,维护,防卫,防御,守,辩解,抵抗,困守,守护,戍,防,捍,驻守,卫,固,否认,抗辩,守卫,戍守,保",
"defendant":"n:被告,被告人",
"defender":"n:辩护人,保护人",
"defenders":"n:守军",
"defense":"n:防务,保卫;v:防御",
"defense secretary":"n:国防部长",
"defenseless":"a:手无寸铁;v:手无寸铁",
"defensive":"n:守势",
"defensiveness":"n:守势",
"defer":"v:听从,推迟,遵从,拖延,延期,服从,延迟,展缓,推,迁延,因循,暂缓,慢",
"deference":"n:尊敬,尊重,服从,敬意,依从",
"deferential":"a:恭敬",
"deferment":"n:延期,迟延,展期;v:延期",
"deferred":"a:推迟",
"defiance":"n:蔑视,违抗,反抗,挑战,挑衅;v:挑衅",
"deficiency":"n:缺乏,缺陷,不足,短缺,亏空,缺失,欠缺,陷,罅漏,荒歉",
"deficient":"a:不足,残,亏短,短少;v:亏短,短少,缺乏",
"deficit":"n:赤字,亏损,不足,短缺,欠缺,透支,亏空,亏蚀;a:入超;v:透支",
"deficit spending":"n:超支",
"defile":"v:损坏,污损;n:险隘,峡谷",
"define":"v:定义,确定,规定,明确,限定",
"definite":"a:确定,一定,肯定,确切",
"definitely":"d:肯定,明确,一定,绝对,决然,准,决计,的确,决,定,定然",
"definiteness":"n:确定性",
"definition":"n:定义,轮廓,明确,解说,清晰度,限定,名称,界说",
"definitive":"a:决定性",
"deflate":"v:紧缩,泄气,挫伤,收缩",
"deflect":"v:偏转,偏离,偏斜,偏移,转向",
"deflection":"n:挠度,偏转,偏差,偏斜",
"deflector":"n:空气",
"deflower":"v:破坏,奸污",
"defoliate":"v:落叶",
"defoliation":"n:落叶",
"deform":"v:变形,损坏",
"deformation":"n:变形,形变,畸形,损伤",
"deformed":"a:畸形",
"deformity":"n:畸形,残疾,残废,残疾人,丑陋,缺陷",
"defraud":"v:绷,诈欺,骗取,诈骗,诈取",
"defray":"v:支付",
"defrayal":"n:支付",
"defrost":"v:解冻,化冻",
"deft":"a:偏转,手巧,麻利,轻巧;v:手巧",
"defunct":"a:死者;n:死人,死者",
"defy":"v:违抗,蔑视,无视,藐视,抗,不顾;a:傲;n:挑战",
"degas":"v:排气",
"degaussing":"v:消磁",
"degeneracy":"n:退化;v:退化",
"degenerate":"v:变质,退化,变性;a:腐败;n:败类",
"degeneration":"n:退化,颓废;v:退化",
"degradation":"n:堕落,退化,降级,剥蚀;v:降级,减低",
"degrade":"v:堕落,降级,降低,减少,降格,退化,消退,下降,贬职,贬",
"degrading":"a:下贱,低三下四",
"degrease":"v:脱脂",
"degree":"n:程度,学位,度,度数,地位,地步,等级,阶层,学术,幂,次,音程,级",
"degrees":"n:度数",
"dehumidify":"v:除湿",
"dehydrate":"v:脱水",
"dehydrated":"v:失水",
"dehydration":"n:脱水;v:脱水",
"deification":"n:神化",
"deify":"v:神化,崇拜",
"deign":"v:赐予,俯就",
"deities":"n:神灵,神明",
"deity":"n:神,上帝,神道,造物主,神物,天神",
"dejected":"a:垂头丧气,沮丧,潦倒,消沉,忧郁,灰溜溜,颓唐,郁悒,糟心;v:沮,无精打采,郎当;n:郎当",
"dejection":"n:沮丧,粪便,气馁,失意,灰心,排泄物",
"del":"n:删除",
"delaware":"n:特拉华",
"delay":"v:耽搁;n:延缓",
"delayed":"a:迟",
"delectation":"n:愉快,娱乐,享受",
"delegate":"v:委派,委托,委任;n:委员,特派员",
"delegation":"n:代表团,委派,派遣",
"delete":"v:删除,删去,作废,勾,刊落,删汰,裁剪,删,删削,芟除;d:略",
"deleterious":"a:有害,有毒;v:有毒",
"deletion":"n:删除,缺失",
"delhi":"n:德里",
"deliberate":"v:考虑,商讨,商议;a:缜密,酌量;d:蓄意,酌量",
"deliberately":"d:故意,有意,存心,偏,有心,偏偏",
"deliberation":"n:深思熟虑,慎重,沉着,细心,审议,协商,故意,评议",
"delicacies":"n:珍馐,甘旨,佳肴",
"delicacy":"n:美味,微妙,优美,柔弱,美食,敏感,体贴,鲜,错,精巧,羞,馐,脆弱,甘旨,娇气,精致,审慎,鲜嫩,周到,山珍海味,正派",
"delicate":"a:微妙,娇嫩,精致,细巧,清淡,嫩,纤弱,娇小,纤巧,娇,细嫩,脆弱,工,鲜,羞,秀气,柔嫩,鲜嫩,难人,细,小巧;n:工;v:致",
"delicatessen":"n:熟食",
"delicious":"a:好吃,鲜美,喷香,美味,鲜,旨;n:美味",
"delight":"n:高兴,乐趣,愉快,快乐;v:聊,悦,快乐",
"delighted":"a:欢喜,痛快,欣喜,愉悦,甜滋滋;v:喜欢",
"delightedly":"d:欢欢喜喜",
"delightful":"a:愉快,宜人,喜悦",
"delightfully":"d:欣然,大喜",
"delimit":"v:划定,划界,划",
"delimitation":"n:划界",
"delimiting":"v:定义",
"delineate":"v:勾画,叙述,划,描述,画,描写,描摹",
"delineation":"n:轮廓,描写,叙述,略图,图形,描画",
"delinquency":"n:失职,犯罪,过失,失职罪,罪过,罪行,错失",
"deliquesce":"v:液化,扩散",
"delirious":"a:狂,神不守舍;v:神不守舍",
"delirium":"n:谵妄;v:妄想",
"deliver":"v:发表,送,接生,投递,送交,拯救,传递,救,交付,输送,分娩,交,传送,发货,助产,传达,解救,移交,表达,递送,发,致,讲述,付,投,吐露,发出,给与,投球,下,递交,陈说,提,投送,转交,分发,加,抛,释放,供给,引渡,传;a:助产",
"deliverance":"n:救援,陈述,救助,判决,解救,发表,释放,意见",
"deliverer":"n:救星",
"delivery":"n:交货,交付,投递,传送,传递,讲演,输送,发货,引渡,分娩,生产,救助,口才,释放,发送,投球,陈述,交割,运送;v:发送,分娩,生产,输送,传递,发出,交付",
"deliveryman":"n:送货员",
"deliverymen":"n:送货员",
"delta":"n:三角洲,三角形",
"delude":"v:欺骗,惑,迷惑,哄骗,蒙骗",
"deluge":"n:倾盆大雨,洪水,暴雨;v:泛滥",
"delusion":"n:幻想,错觉,幻觉,妄想,误会,迷惑,误解,谬见;v:妄想",
"delve":"v:探究,钻研,挖掘;n:坑,穴",
"demagnetization":"n:消磁",
"demagnetize":"v:消磁",
"demand":"v:要求;n:销路",
"demarcate":"v:划界,分开,区别,标定",
"demarcation":"n:分界,划分,区分,标定;v:划界",
"demarcation line":"n:界线,线",
"dematerialize":"v:消失",
"demean":"v:表现,举动,损坏",
"demeanor":"n:态度,举动,风度,品格,品行,行为",
"demeanour":"n:举止,风采",
"dementia":"n:痴呆;a:痴呆",
"demerit":"n:缺点,错处,短处,功过,过失,过,错",
"demesne":"n:领域,领地,占有,范围",
"demijohn":"n:坛子",
"demimondaine":"n:交际花",
"demimonde":"n:妓女",
"demise":"n:让位,逝世,死;v:遗赠",
"demo":"n:示威,示范",
"demob":"n:复员军人",
"demobilization":"n:复员,遣散",
"demobilize":"v:复员,解散,遣散",
"democracy":"n:民主,民主主义,老百姓",
"democratic":"a:民主;n:民主党派",
"demodulate":"v:解调,检波",
"demodulation":"n:解调,检波",
"demodulator":"n:解调器,检波器",
"demography":"n:人口学",
"demolish":"v:拆除,拆毁,推翻,破坏,炸毁,毁坏,拆迁,爆破",
"demolition":"n:爆破,摧毁,拆除,拆毁;v:拆毁",
"demon":"n:恶鬼,怪,妖怪,妖精,凶煞,妖,精,魅,邪气;a:精",
"demonology":"n:牛鬼蛇神",
"demons":"n:牛鬼蛇神,魔怪",
"demonstrably":"d:确然",
"demonstrate":"v:证明,表明,演示,显示,示威,说明,示范,证实,展示,表演,论证,表示,证,指,指明;n:证",
"demonstration":"n:示威,游行,证明,示范,表明,论证,表示,实证,说明;v:论证,游行,操演;a:确实",
"demoralized":"v:沮",
"demos":"n:民众,平民,人民",
"demote":"v:降级,贬斥,贬黜,谪,贬",
"demotion":"n:降职,降级",
"demulcent":"n:镇静剂",
"demur":"n:异议;v:反对,迟疑,抗辩",
"demure":"a:端庄,娴静",
"demurrer":"n:反对,异议,抗辩;v:抗辩",
"demystify":"v:启发",
"den":"n:巢穴,窝,贼窝,老巢,穴;v:穴居",
"denature":"v:变性",
"denatured alcohol":"n:变性酒精",
"deng xiaoping":"n:邓小平",
"denial":"n:否认,否定,克制",
"denier":"n:纤度",
"denigrate":"v:污蔑,诽谤",
"denigration":"n:诽谤",
"denim":"n:工作服,工装裤",
"denizen":"n:居民,外来语;v:移植",
"denmark":"n:丹麦",
"denominate":"v:称呼,定名,命名",
"denomination":"n:派别,教派,单位,面额,面值,票额,宗派,教门,名目,命名,种类,名称",
"denominator":"n:分母",
"denotation":"n:外延,命名,标志,名称,指示,符号,表示",
"denote":"v:表示,指示,意味着",
"denouement":"n:收场",
"denounce":"v:谴责,告发,指责,斥责,揭发,控诉,谴,讨,指斥,诟病,怒斥,申讨,贬斥,问罪,斥,恐吓,声讨,驳斥,斗",
"dense":"a:稠密,浓密,密集,茂密,密,黑压压,密密层层,密实,浓,浓厚,密致,繁密,匝,密密匝匝,浓重,森森,稠,森然;n:匝",
"denseness":"n:稠密,稠度;a:稠密",
"density":"n:密度,浓度,密集,比重,浓厚,深浅,疏密度,稠度,稠密,疏密,愚钝,密;a:密",
"dent":"n:进展;v:凹,削减,削弱;a:凹",
"dental":"n:齿音;a:牙齿",
"dental caries":"n:龋齿,龋,蛀齿",
"dented":"a:凹",
"dentifrice":"n:牙粉,牙膏",
"dentin":"n:牙质",
"dentist":"n:牙医",
"dentistry":"n:牙科",
"denture":"n:假牙",
"denudation":"n:剥蚀,滥伐;v:剥蚀",
"denude":"v:溶蚀,剥夺,剥蚀,脱毛;n:脱毛",
"denunciation":"n:谴责,指责,告发,控诉,恐吓,弹劾,揭发,警告",
"denver":"n:丹佛",
"deny":"v:否认,拒绝,否定,抵赖,谢绝,不予,否,推卸,狡赖,谰",
"deodorant":"n:除臭剂",
"deodorize":"v:除臭",
"deodorizer":"n:除臭剂",
"depart":"v:离开,走,动身,消失,偏离,发车,出发,出境,起程,死亡,开行,出动",
"department":"n:部门,系,部,车间,科,处,局,口,学部,课,专栏",
"department head":"n:系主任",
"department store":"n:百货公司,百货商店,百货大楼",
"departure":"n:离开,启程,出发,背离,偏差,偏离,违反,起程,逝世,开行;v:离开",
"depend":"v:取决于,靠,依赖,依靠,看,有赖于,信赖,在于,信任,凭,寄,赖,相关,赖以,依凭,从属,聊,挟,下垂,傍,悬挂,依托,仰,倚,据为己有,归依",
"depend on":"v:归依,凭借,恃,挟,取决于,有赖于,在,在于,指,靠,据为己有,据,依托,倚靠,看,系,依凭,寄,赖,仰,依,仗,傍,凭,倚",
"depend upon":"v:依靠",
"dependable":"a:可靠,准,靠得住,牢靠,实在,把稳,可信,塌实,踏实",
"dependant":"n:侍从,食客",
"dependence":"n:依赖,依赖性,隶属,依靠,信赖,信任,靠山,凭借,未决,可靠性;v:信任",
"dependency":"n:属地,依赖,属国,依存,从属,附庸",
"dependent":"n:侍从;a:依靠",
"dependent clause":"n:从句",
"dependent upon":"n:依靠",
"dependents":"v:属;n:家属",
"depending on":"p:取决于,依赖,靠,依靠",
"depict":"v:画,描绘,描写,写,描画,摹写,影,描摹,描,叙述,刻画,摹绘",
"depiction":"n:叙述,描写;v:描绘",
"deplete":"v:消耗,耗尽,减少,放血,损耗",
"depletion":"n:耗尽;v:耗尽",
"deplore":"v:痛惜,悲叹,悲悼,抱憾,悔恨",
"deploy":"v:部署,展开,散开,班,布,配备,张开;n:布",
"deployment":"n:部署,展开",
"depolarize":"v:消除",
"deponent":"n:证人",
"deport":"v:驱逐,放逐,举动,输送,运输",
"deportation":"n:移送",
"deportment":"n:态度,举止,行为,仪态,姿态,概,器宇",
"depose":"v:废黜,放置",
"deposit":"v:沉积;n:押租,藏,仓库,寄存",
"depositary":"n:保管人,仓库",
"deposition":"n:沉积,淤积,沉淀,笔供,沉着,口供,罢免,供,寄存,免职,证言;a:沉着;v:供",
"depositor":"n:储户,存户,存款人",
"depository":"n:仓库,藏,保管人,寄存处",
"deposits":"n:储蓄",
"depot":"n:仓库,车站,兵站,火车站,厂,航空站,厂子,补给站,贮藏;v:贮藏",
"deprave":"v:堕落,败坏,腐蚀,腐化,弄坏",
"depraved":"a:卑鄙,腐化;v:腐烂",
"depravity":"n:堕落,腐败,邪恶,腐化",
"deprecate":"v:反对,贬低,抗议",
"deprecation":"n:反对",
"depreciate":"v:贬值,折旧,跌价,贬低,贬抑,毛,贬,减价",
"depreciation":"n:折旧费,贬值,损耗,折旧,藐视,减价",
"depreciation rate":"n:折旧率",
"depredation":"n:劫掠",
"depress":"v:降低,抑制,压低,减少,压抑,懊丧,沮",
"depressant":"n:镇静剂",
"depressed":"a:沮丧,消沉,萧条,抑郁,闷,沉闷,苦闷,阴郁,郁悒,郁郁,沉郁,忧愁,忧烦,嗒然,凋敝,郁闷;v:凹陷,郁郁不乐,忧闷,搔,陷落",
"depressing":"a:不景气,沉闷;v:抑制",
"depression":"n:萧条,情绪,不景气,沮丧,洼地,凹陷,降低,洼,沉陷,低气压区,低压,潭,忧闷,陷落;v:凹陷,沉陷,降低",
"depressurization":"n:降压",
"deprivation":"n:剥夺,缺乏,丧失,免职,废止",
"deprive":"v:剥夺,夺去,免职,夺,褫夺",
"depth":"n:深度,深,深渊,深刻,厚,纵深,深沉,深奥,当中,内部,低沉,海,深厚,深浅,奥妙,进深;a:深刻,厚,深奥",
"depth bomb":"n:深水炸弹",
"depth gauge":"n:水尺",
"depths":"n:深处",
"deputation":"n:代表团,委派,代表,代理",
"depute":"v:委托",
"deputize":"v:代表",
"deputy":"n:副手,代表,代理人,代理,副,管理员,帮办,代办",
"derail":"v:脱轨,出轨;n:开关",
"derailleur":"n:变速器",
"derailment":"n:出轨",
"derange":"v:扰乱,打乱",
"deranged":"a:紊乱,错乱;v:错乱",
"derangement":"n:扰乱,混乱;a:狂乱",
"derelict":"a:遗弃",
"dereliction":"n:遗弃,疏忽,懈怠,放弃,玩忽职守",
"deride":"v:嘲笑,揶揄,愚弄,嘲弄,讥诮,嘲,笑骂,讥笑,笑,嘲讽,损",
"derision":"n:嘲笑,笑柄",
"derivation":"n:推导,派生,引出,由来,起源,出处,词源,衍生,衍生物",
"derivative":"n:导数,衍生物,派生词;a:衍生",
"derive":"v:得到,推导,来自,派生,衍生,取自,推演,推论,汲取,推究,起源于",
"dermatitis":"n:皮炎",
"dermatology":"n:皮肤科",
"dermis":"n:真皮",
"derogate":"v:贬损,减损,毁损,贬低",
"derogation":"n:减损,毁损",
"derogatory":"a:毁损",
"derrick":"n:井架,起重机,吊杆,钻塔,小偷",
"derriere":"n:臀部",
"derv":"n:柴油",
"desalination":"n:淡化",
"desalinize":"v:淡化",
"descant on":"v:评论,详述",
"descartes":"n:笛卡儿",
"descend":"v:下,下来,下降,降落,下去,降,涉及,屈就,沦落,遗传",
"descendant":"n:子孙,后代,后裔,门生,弟子,后嗣,后人,后辈",
"descendants":"n:根,后人,子孙,后代,儿孙,后辈,苗裔,子孙后代",
"descent":"n:世系,血统,倾斜,斜坡,家世,下坡,后裔,下降,世袭,门第,一代,继承,子孙,降格,降下",
"describe":"v:描述,描写,叙述,形容,描绘,画,写,描画,记述,运行,刻画,摹状,评述,状,抒写,名,作图,摹写;n:状",
"describer":"n:记录器",
"description":"n:描述,说明,描写,叙述,记载,说明书,种类,记述,性质,定名,刻划,色,绘制,作图,划界;v:划界,叙述,定名",
"descriptive":"n:描述性;a:描述性",
"descry":"v:发现,望见,瞵,看到",
"desecrate":"v:亵渎,污辱",
"desensitization":"n:脱敏",
"desensitize":"v:脱敏",
"desert":"v:抛弃;n:功劳,美德,沙地,沙漠地;a:旷",
"deserted":"a:空荡荡,清冷,荒僻;v:冷落,冷僻,冷,荒僻,清冷",
"deserter":"n:逃兵,逃亡者",
"desertification":"n:沙化",
"desertion":"n:开小差,遗弃,抛弃,脱党,逃走,舍弃,荒废",
"deserts":"n:赏罚",
"deserve":"v:值得,应得,应有,配,自作自受,该当,当,担当",
"deserved":"v:应得",
"desiccant":"n:干燥剂",
"desiccate":"v:干燥,脱水",
"desiccated":"v:干裂",
"desiccation":"v:萎缩,干裂;n:萎缩",
"design":"n:图案,计划,图样,企图,结构;v:留给,草拟,筹划,打样",
"designate":"v:指定,任命,指明,指派,划定,委派,选定,选派,指出,标志",
"designation":"n:名称,指定,称呼,任命,定名,铭牌,称号,记号,选派,指出;v:指定,定名",
"designedly":"d:故意,特意",
"designer":"n:设计者,设计师,设计员,制图员,设计家",
"designing":"n:设计",
"designs":"n:目的",
"desirability":"n:愿望",
"desirable":"a:可取;v:要得",
"desire":"n:欲望,愿望;v:欲",
"desirous":"a:想,欲",
"desist":"v:停止,打断,偃,断念,止住",
"desk":"n:书桌,办公桌,桌子,桌,写字台,课桌,台子,组,案,席位,部,台,司",
"desktop":"n:桌面",
"desolate":"a:凄凉,荒凉,萧索,悲凉,冷淡,冷清,清冷,荒,冷冷清清,冷落,萧萧,萧瑟,萧条,苍凉;v:荒",
"desolation":"n:荒凉,凄凉,荒芜,废墟,荒废,寂寥,荒地,孤独",
"despair":"v:失望;n:失望;a:绝望",
"desperado":"n:亡命徒,亡命之徒,无赖",
"desperate":"a:不顾死活,殊死,绝;v:亡命",
"desperately":"d:拼命,极,非常,死命,没命,殊死",
"desperateness":"n:拼命,绝望",
"desperation":"n:绝望,拼命;v:急中生智;a:情急",
"despicable":"a:卑鄙,卑劣,可鄙,猥鄙,鄙,恶劣,贱",
"despise":"v:鄙视,轻视,看不起,蔑视,藐视,不齿,鄙薄,菲薄,鄙弃,鄙夷,蔑,侮蔑,薄,轻蔑,鄙,藐,傲视,看不上眼",
"despising":"v:轻蔑",
"despite":"p:尽管,不顾,不管,即使,无论,凭,任凭;n:侮辱,憎恨,恶意,怨恨,恨;c:不管,尽管",
"despoil":"v:掠夺,抢劫,剥夺",
"despoliation":"n:掠夺",
"despond":"v:灰心,泄劲,失望,消沉;n:失望,沮丧",
"despondence":"n:丧气",
"despondency":"n:沮丧",
"despondent":"a:抑郁,懊丧,嗒然",
"despot":"n:暴君,霸,豪强,魔王,霸王",
"despotic":"a:专制;n:专制",
"despotism":"n:专制,苛政,暴政",
"dessert":"n:点心,甜品",
"destabilization":"n:扰动",
"destabilize":"v:扰动",
"destination":"n:目的地,目的,终点,目标,预定,注定",
"destine":"v:注定,预定,命定,指定",
"destiny":"n:命运,命,天命,天数,数,气运",
"destitute":"a:赤贫,凋敝,寒苦,空乏,穷乏,穷困,竭蹶",
"destitution":"n:贫困,穷困,缺乏,赤贫,贫穷",
"destroy":"v:破坏,摧毁,毁,毁灭,毁坏,消灭,炸毁,摧残,歼灭,捣毁,搞垮,灭,杀死,糟,摧,坏,击破,破,戕,隳,扑灭,驱除,撕碎,漼,打碎,歼,肃清,打掉,祸害,杀害,击毁;n:祸害",
"destroyer":"n:驱逐舰",
"destruction":"n:破坏,毁灭,灭亡,驱除,杀害,消灭,覆灭,扑灭",
"destructive":"a:破坏,害",
"desuetude":"n:废除,废止",
"desultory":"a:杂乱",
"detach":"v:分离,拆开,除去,分开",
"detached":"a:超然",
"detached house":"n:单门独户",
"detaching":"a:先遣;v:先遣",
"detachment":"n:超然,分离,小分队,超脱,支队,派遣,释放,拆开,分队;v:释放,分离",
"detail":"n:细部,小事,细目,零件,详图,元件;v:详述",
"detailed":"a:详细,详尽,细,详详细细,绵密,细密",
"details":"n:底蕴,详情,底子,细节;v:端详",
"detain":"v:拘留,扣,扣留,收押,羁留,押,扣押,管押,拘,羁,羁押,禁,看押",
"detainment":"n:扣留,留置;v:扣留",
"detect":"v:检测,发现,察觉,发觉,检波,探头,刺探,刺,觉察,清查,解调,侦,窥见",
"detecting":"v:检波,检测",
"detection":"n:检测,探测,发现,检验;v:检验,探测",
"detective":"n:侦探,警探,探,暗探,包打听,密探;v:探",
"detective story":"n:侦探小说",
"detector":"n:探测器,检波器,检测器,指示器,探头",
"detente":"n:缓和",
"detention":"n:拘留,监禁,卡住,扣压,阻止;v:拘留,扣押",
"detention house":"n:拘留所",
"deter":"v:制止,妨碍,阻止,威慑,防止",
"detergent":"n:洗涤剂,去污剂,清洁剂",
"deteriorate":"v:恶化,变质,退化,降低,逆转,弄坏,败坏,堕落",
"deterioration":"n:恶化,退化,变质,颓废,衰败,损耗,堕落,凋萎",
"determent":"n:威慑,制止",
"determinant":"n:行列式,因子,限定词,定子",
"determinate":"a:限定",
"determination":"n:决心,测定,确定,决定,测量,鉴定,判决,规定,消失,终止,限定;v:测量,测定",
"determinative":"n:限定词",
"determine":"v:决定,决心,确定,测定,下决心,决意,断定,判定,判断,限制,决,鉴定,了结,限定,终止,规定,铁;n:铁",
"determined":"a:坚决,果;v:铁,果;n:铁",
"determinedly":"d:毅然,决然",
"determiner":"n:限定词,定子,因子",
"determining":"v:判定",
"determinism":"n:宿命论,决定论",
"deterministic":"a:宿命论",
"deterrence":"n:威慑,制止",
"deterrent":"a:威慑",
"detest":"v:憎恶,憎恨,嫌恶,愤恨,看不惯,憎,嫌,耆,厌,厌腻",
"detestable":"a:可憎,可恨,可恶,讨嫌",
"detestation":"n:讨厌,憎恶,嫌恶",
"dethrone":"v:废黜,推翻,罢免",
"detonate":"v:爆炸,起爆,爆破,爆发,触发,引爆,发火",
"detonation":"n:爆炸,爆发",
"detonator":"n:雷管,引信",
"detour":"n:绕道,曲折,弯路;v:绕道,迂回",
"detoxification":"n:解毒,中和",
"detoxify":"v:解毒",
"detract":"v:分散,降低,减损,诬蔑,伤害,转移,损坏",
"detraction":"n:减除,贬低",
"detriment":"n:损害,伤害",
"detrimental":"a:有害,不利",
"detritus":"n:碎石,碎末",
"detroit":"n:底特律",
"deuce":"n:不幸,倒楣,平分,胆小鬼",
"deuce-ace":"n:倒楣",
"deuced":"a:极,非常,很,过度,异常",
"deuterium":"n:氘,重氢",
"devaluation":"n:贬值,贬低",
"devalue":"v:贬值,贬低,贬",
"devastate":"v:破坏,摧残,蹂躏",
"devastation":"n:破坏,荒废",
"develop":"v:发展,开发,发育,研制,发生,产生,出现,培养,发达,展开,养成,显影,显示,发现,发,变成,冲洗,长,开展,进展,扩大,演变,发扬,进化,衍,扩展,拓,揭露,扬厉,衍变,滋长,冲凉,恢宏,哺育,发扬光大,演,推移,冲,恢廓",
"developed":"a:发达",
"developer":"n:显影剂",
"developing":"v:开拓,显像,开发;n:显像",
"development":"n:发展,开发,发育,研制,成长,显影,发达,进化,建设;v:建设,展开,发育",
"developments":"n:动态",
"deviant":"a:异常",
"deviate":"v:偏离,背离,违背,越轨,离开,脱离,偏移,越,误入歧途;n:脱离",
"deviation":"n:偏离,偏差,背离,偏向,偏移,偏转,偏斜,倾,脱离,误差,越轨",
"device":"n:设备,装置,器件,设计,方法,手段,诡计,着,策略,计划,图案,意志,器具,商标,招,着数,花样,器械,欲望,图样,招数,谋略",
"devil":"n:魔鬼,恶魔,恶棍,怪;v:纠缠,折磨",
"devilish":"d:极,非常",
"devilment":"n:怪事,恶作剧",
"devilry":"n:恶作剧,恶行,魔法,妖术,胡作非为",
"devils":"n:凶神恶煞",
"deviltry":"n:恶行",
"devious":"a:歪",
"devise":"v:设计,发明,创造,制定,图谋,策划;n:遗赠",
"devitalize":"v:衰弱",
"devoid":"a:缺乏,没有",
"devolution":"n:授权,转移,退化;v:退化",
"devolve":"v:移交,授予,转移",
"devolve on":"v:移交,转移",
"devonian":"n:泥盆纪",
"devote":"v:致力,贡献,倾注,听任,献,扑,敬业",
"devoted":"a:深爱,虔诚,热情,专;v:专",
"devotedly":"d:一个心眼,一心,忠实",
"devotee":"n:信徒",
"devotion":"n:献身,忠诚,热爱,热情,热诚,信仰,忠心,祈祷,信心,热心,利用,专心",
"devotional":"a:虔敬",
"devour":"v:吞噬,吞,吞没,吃光,挥霍,吞灭,吞食,倾听,毁灭,凝视",
"devout":"a:虔诚",
"dew":"n:露水,露,水分",
"dewdrop":"n:露珠,露",
"dewey":"n:手枪",
"dexterity":"n:灵巧,敏捷,熟练,巧妙",
"dexterous":"a:灵巧,利落,麻利,手巧,圆熟;v:手巧",
"dextrose":"n:葡萄糖",
"di":"n:狄",
"diabetes":"n:糖尿病,多尿症,消渴",
"diabolic":"a:毒辣,万恶;n:万恶",
"diabolical":"v:穷凶极恶;a:穷凶极恶",
"diabolism":"n:魔术,妖术,恶行,着魔",
"diadem":"n:王冠,王位,花环",
"diagnose":"v:诊断,判断,确诊",
"diagnoses":"n:诊断",
"diagnosis":"n:诊断;v:诊断",
"diagnostic":"n:特征,征候;a:诊断",
"diagonal":"n:对角线;a:斜",
"diagonally":"d:斜",
"diagram":"n:图,图表,图解,图形,简图,作图;v:图解",
"dial":"n:刻度盘,拨号盘;v:打",
"dialect":"n:方言,土话,白,地方话,语调,谈吐",
"dialectic":"a:辩证法",
"dialectical":"a:辩证",
"dialectics":"n:辩证法",
"dialing":"v:拨号;n:拨号盘",
"dialling":"v:拨号",
"dialog":"n:问答,问答题,对白;v:对话",
"dialog box":"n:对话框",
"dialogue":"n:对话,会话,对白,台词,问答题,问答;v:对话",
"dialysis":"n:透析;a:分解",
"diam":"n:直径",
"diameter":"n:直径,径",
"diamond":"n:钻石,金刚石,方块,钻,金刚钻,菱形,棒球场,球场,煤",
"diamond dust":"n:冰晶",
"diamonds":"n:方块",
"diapason":"n:音域,旋律,范围,领域,和声,音叉,和谐",
"diaper":"n:尿布,裤子,手巾",
"diaphragm":"n:膜片,隔板,横膈膜,隔膜,薄膜,膈,膈膜,光圈,膜",
"diarrhea":"n:腹泻;v:腹泻",
"diarrhoea":"v:腹泻;n:河鱼",
"diary":"n:日记,日志,日记簿",
"diaspora":"n:散居",
"diastole":"n:舒张",
"diastolic":"a:舒张",
"diathermy":"n:电疗",
"diatom":"n:硅藻",
"dibble":"n:点播器,点;v:点播,点种",
"dice":"n:骰子,色子;v:投",
"dichotomy":"n:二分法;v:均分",
"dick":"n:家伙,侦探,声明",
"dickens":"n:困难",
"dicker":"v:讨价还价,还价;n:讨价还价,谈判",
"dickey":"n:公驴,驴,小鸟",
"dicky":"n:小鸟,公驴",
"dicotyledon":"n:双子叶植物",
"dicta":"n:格言,名言",
"dictaphone":"n:录音机",
"dictate":"v:口授,听写,命令,口述;n:指令",
"dictation":"n:口述,听写,口授,命令,指令;v:听写",
"dictator":"n:独裁者",
"dictatorial":"v:独断;a:专横",
"dictatorship":"n:专政,独裁;a:独裁",
"diction":"n:文辞,措词,辞,措辞,文句,字;v:措辞",
"dictionary":"n:词典,字典,辞典,字书,辞海,辞书",
"dictum":"n:名言,格言,断言,断定,声明",
"didactics":"n:教学法",
"diddle":"v:浪费;n:诈骗",
"dido":"n:开玩笑",
"die":"v:死,去世,死去,死亡,消失,逝世,枯死,老,熄灭,没,消逝,渴望,枯萎,丧生,一命呜呼,亡,断气,没命,淘汰;n:硬模;i:乌呼,呜呼;c:故",
"die away":"v:消失,消逝",
"die back":"v:枯萎",
"die out":"v:亡,熄灭,泯,灭绝,灭亡,磨,淘汰,消灭",
"die-hard":"n:死顽固",
"dielectric":"n:电介质,介质,绝缘体",
"dies":"n:假日",
"diesel":"n:柴油,内燃机",
"diesel engine":"n:狄塞耳机",
"diet":"n:饮食;v:节食",
"dietary":"n:食谱",
"dietetics":"n:营养学",
"diethyl ether":"n:乙醚",
"differ":"v:不同,不一,相差,不等,拧",
"difference":"n:差别,分歧,差异,差,区别,差距,差额,分别,争论,不和,歧异,别,异样,特殊性;d:分别",
"different":"a:不同,各,异,各种各样,两样,二,歧异,各别,左,歧,两歧,殊;r:各",
"differential":"n:微分,差异",
"differential calculus":"n:微分学,微积分",
"differential coefficient":"n:导数",
"differential equation":"n:微分方程",
"differentiate":"v:区别,区分,分化,辨别,鉴别,判别,划,分别,辨,分,分辨,变异,别,划分",
"differentiation":"n:分化,区别,差别,划分,变异,区分;v:分化",
"differently":"d:各别",
"difficult":"a:难,困难,艰难,艰苦,深,拗,繁重,艰,疑难;d:难以",
"difficulties":"n:疾苦,风浪,苦衷,痛痒",
"difficulty":"n:困难,难关,异议,难处,难度,难点,障碍,纠葛,难事,苦处,疾,争论,疑难,逆境;a:颠连",
"diffidence":"n:胆怯,羞怯,疑惑,谦虚,猜疑;a:羞怯",
"diffident":"a:虚,不好意思,心虚",
"diffract":"v:衍射,分解",
"diffraction":"n:衍射",
"diffuse":"v:扩散,传播,发,散布,散发,散开,渗出,漫射,发散,弥散,播散;a:散开,冗赘",
"diffusion":"n:扩散,传播,漫射,散布,弥散,冗长,发散;v:扩散",
"dig":"v:挖,掘,挖掘,喜欢,凿;n:讽刺,住处,挖掘;a:抠搜",
"dig into":"v:钻",
"dig out":"v:飞奔",
"dig up":"v:搜集,扒,坌",
"digest":"v:消化;n:文摘",
"digestion":"n:消化;v:消化",
"digestive":"a:助消化",
"digestive system":"n:消化系统",
"digestive tract":"n:消化道",
"digger":"n:挖掘机",
"digging":"n:掘,采掘,挖掘,住处;v:采掘",
"diggings":"n:宿舍,矿区,矿山,寓所",
"digit":"n:数字,数位,位,位数,手指,阿拉伯数字,指",
"digital":"n:手指;a:数字式",
"digital watch":"n:电子表",
"digitalis":"n:洋地黄;a:洋地黄",
"digitize":"v:数字化",
"dignified":"a:威严,庄严,端庄,稳重,凝重,厚重,持重,俨然",
"dignitary":"n:显贵,要人,高官",
"dignity":"n:尊严,庄严,体面,端庄,威严,高贵,身份,威风,尊贵,高位;a:威严",
"digress":"v:离题,脱轨",
"digression":"n:离题,插话,闲话",
"digressive":"a:闲",
"dihedral":"n:二面角",
"dike":"n:河堤;v:打扮,筑堤",
"dilapidated":"v:残破,东倒西歪,破败;a:残败",
"dilapidation":"n:崩塌,浪费,破败,破旧,破烂",
"dilatation":"n:膨胀;v:扩展",
"dilate":"v:扩大,扩张,详述,膨胀,胀,细说;a:胀",
"dilation":"n:扩大,扩张,伸缩,膨胀;v:扩张",
"dilator":"n:扩张器",
"dilatory":"a:迟迟,拖拉,迂缓,迟,拖沓",
"dilemma":"n:进退两难,困境,左右为难,窘境,谷",
"diligence":"n:勤奋,勤勉,努力",
"diligent":"a:勤奋,辛勤,勤劳,用功,勤快,勤勉,勤,颉,孜孜,懋,手勤;v:孜孜不倦",
"diligently":"d:孜孜不倦,用心",
"dilly":"n:矿车,马车",
"dilly-dally":"v:泡",
"dillydally":"v:蘑菇,犹豫,吊儿郎当,蹭,闲逛,磨蹭",
"diluent":"n:稀释剂",
"dilute":"v:稀释,冲淡;a:稀释",
"diluted":"v:稀薄",
"dilution":"n:稀释,削弱,削减,冲淡,简化;v:简化,稀释",
"dim":"a:朦胧,暗淡;v:暗淡",
"dime":"n:毛,角,小钱",
"dimension":"n:尺寸,大小,维,面积,尺度,容积,体积,度",
"dimensionality":"n:幅员,度数",
"dimensions":"n:规模,尺寸",
"diminish":"v:减少,缩小,减小,减低",
"diminution":"n:减少,减缩,减小;v:减缩,减小,缩减,缩小",
"diminutive":"n:爱称",
"dimity":"n:麻纱",
"dimly":"d:暗淡,隐隐约约,依稀,影影绰绰,模糊;a:恍惚",
"dimmed":"v:迷糊",
"dimness":"n:暗淡,愚钝,模糊,蒙昧",
"dimple":"n:酒涡,笑窝,波纹,酒窝,酒窝儿,笑靥,笑涡,颊窝,涟漪,酒靥,印痕",
"dimwit":"n:傻子,笨蛋",
"din":"n:吵闹,喧嚣,噪声,嘈杂,喧闹;v:喧闹,喧嚷,喧嚣;d:哇啦",
"dinar":"n:第纳尔",
"dine":"v:吃饭,宴请,进餐,吃馆子",
"dine out":"v:吃馆子",
"diner":"n:餐车",
"ding":"n:丁",
"ding-dong":"d:丁当,叮当;n:叮咚",
"dingbat":"n:玩意儿,东西",
"dinge":"n:黑人",
"dinghy":"n:赛艇,舢板",
"dinginess":"n:肮脏,暗淡",
"dingle":"n:幽谷;v:震动",
"dining":"v:进餐,吃饭",
"dining car":"n:餐车",
"dining room":"n:餐厅,饭厅,餐房",
"dining table":"n:饭桌",
"dink":"v:装饰,打扮",
"dinner":"n:晚饭,晚餐,宴会,正餐,午宴,席,飧,夜饭",
"dinner pail":"n:饭盒",
"dinner party":"n:应酬,饭局,宴会",
"dinner service":"n:餐具,食具",
"dinnerware":"n:餐具",
"dinosaur":"n:恐龙",
"dint":"n:凭借,打击,力量,靠,作用;v:卧底",
"diocesan":"n:主教,教区;a:主教",
"diocese":"n:教区",
"diode":"n:二极管",
"diopter":"n:屈光度",
"dioptre":"n:屈光度",
"diorama":"n:西洋景,透视缩影",
"dip":"v:蘸,浸入;n:蜡烛",
"dip into":"v:浏览",
"diphtheria":"n:白喉",
"diploma":"n:文凭,公文,奖状,执照",
"diplomacy":"n:外交,权谋",
"diplomat":"n:外交官,外交家",
"diplomatic corps":"n:外交团",
"diplomatist":"n:外交官",
"dipper":"n:勺子,勺,蠡,提,舀子,杓;v:提",
"dipping":"v:浸渍,进入;n:药浴",
"dire straits":"n:困厄,惨境",
"direct":"v:倾注,支配,执导,教正,节制,主持,主办,指令,饬令,督;d:一直,笔直;a:直系",
"direct current":"n:直流电,直流",
"direct dye":"n:直接税",
"directing":"v:指向",
"direction":"n:方向,向,方面,指导,指挥,指示,管理,方,命令,倾向,导演,吩咐,范围,纵向,方位,趋向,去向;v:指导",
"directional":"a:定向",
"directional antenna":"n:定向天线",
"directions":"n:说明",
"directive":"n:指示,指令,命令,训令,方针",
"directly":"d:立刻,马上,直,径直,面,立即,不久,一头;n:面",
"directness":"n:直接,率直,笔直,坦白",
"director":"n:董事,主任,董事会,导演,经理,院长,指挥,社长,司长,厅长,理事,指导员,指示器,董,校长,长官,导师",
"directorate":"n:理事会,董事会",
"directory":"n:目录,指南,董事会,名录,汇编,通讯录,理事会,手册",
"dirge":"n:挽歌,哀歌,哀乐,悲歌,挽词",
"dirigible":"n:飞艇,飞船",
"dirk":"n:短剑,匕首",
"dirt":"n:灰尘,污垢,尘土,污物,肮脏,尘埃,尘垢,垢污,土地,烂泥,泥土,腻,闲谈,灰土,砾石,培土,下流话,油垢,秽土,卑鄙,下贱,聊天,泥垢,糖",
"dirtily":"d:卑鄙,龌龊,下贱",
"dirtiness":"n:下贱,龌龊,卑鄙",
"dirty":"a:脏,肮脏,下流,污浊,脏污,埋汰,难听,脏乎乎,乌七八糟,淫秽,秽;v:腻,腌,沾污",
"dirty linen":"n:家丑",
"dirty money":"n:不义之财",
"dirty trick":"n:坏,鬼,鬼把戏",
"dirty word":"n:脏字",
"dis":"v:蔑视",
"disability":"n:伤残,残疾,无能,无力",
"disabled":"a:残废,废;v:废,残废",
"disablement":"n:无能,残废",
"disabuse":"v:纠正,释疑",
"disadvantage":"n:不利,缺点,弊,坏处,损害,损失,不便,弊病,冤,弊端;v:损害",
"disadvantageous":"a:不利",
"disaffect":"v:不服",
"disaffection":"n:不满,不服,不平,厌恶",
"disaffiliate":"v:拆散,分离",
"disaffiliation":"n:脱离",
"disagree":"v:不合,争执,有害,争持,不服,拧,不对",
"disagreeable":"a:讨厌,别扭;v:讨厌",
"disagreeably":"d:无聊,讨厌",
"disagreement":"n:不合,争论,不和,差异,异词,异议",
"disallow":"v:拒绝,不许,不准,不行,驳回",
"disappear":"v:消失,不见,失踪,消,绝迹,没,消散,泯灭,缺少,云散,冰释,风流云散",
"disappearance":"n:不见,消失,缺少",
"disappoint":"v:受挫,辜负",
"disappointed":"a:失望,惘然,怅怅,凉,颓然;v:怅然,失意",
"disappointing":"v:大煞风景,泄气;a:差劲",
"disappointment":"n:失望,挫折,失意,沮丧",
"disapprobation":"n:非难,指责",
"disapproval":"n:非难,不准",
"disapprove":"v:反对,不准,指责,不满",
"disapprovingly":"d:不以为然",
"disarm":"v:缴械,消除,缓和,冰释",
"disarmament":"n:裁军;v:裁兵",
"disarrange":"v:扰乱,搅乱,混乱",
"disarrangement":"n:混乱,紊乱",
"disarray":"v:搅乱;n:混乱",
"disassemble":"v:拆卸,拆除,卸,分解,拆开,拆散",
"disassociate":"v:分裂",
"disassociation":"v:分离;n:分离",
"disaster":"n:祸乱;v:患,劫;a:不测",
"disastrous":"a:惨,惨重",
"disavow":"v:否认,抵赖,赖,推卸,推翻",
"disavowal":"n:否认",
"disband":"v:解散,遣散",
"disbandment":"n:解散",
"disbelief":"n:怀疑",
"disbelieve":"v:怀疑,疑",
"disburse":"v:支付,支,支出,付出,分配,分散",
"disbursement":"n:支付,支出",
"disc":"n:圆盘,唱片;v:轮,盘",
"disc harrow":"n:圆盘耙",
"discard":"v:抛弃,扔掉,放弃,丢弃,丢掉,弃置,废,解雇,摈除,排摈,废弃,屏除,垫,弃掷,屏弃,摈,摈弃;n:抛弃,废渣,废品,丢弃",
"discern":"v:分辨,看出,认出,识别,鉴别,洞察,辨别,分清,裁",
"discerning":"a:明",
"discernment":"n:眼力,洞察力,辨别",
"discharge":"v:履行;n:免职,免除,排泄物,退伍,卸货",
"discharge pipe":"n:排水管",
"discharging":"v:放电",
"disciple":"n:门徒,信徒,弟子,追随者,门人,学生,门下,徒弟,使徒,教友,门生",
"discipline":"n:纪律,学科,训练,锻炼;v:训导,磨砺,操练",
"disclaim":"v:否认,放弃",
"disclaimer":"n:放弃,弃权,否认",
"disclose":"v:透露,泄露,分解,揭发,露出,说穿,揭开,披露,表明,漏,捅,声张",
"disclosure":"n:泄露,公开,揭发,暴露,败露,显示",
"disco":"n:迪斯科",
"discolor":"v:变色,褪色,污染,落色",
"discolour":"v:脱色,落色",
"discombobulate":"v:破坏,扰乱,打乱",
"discombobulation":"n:扰乱",
"discomfit":"v:击溃,破坏,打败,打乱",
"discomfiture":"n:挫败,困窘",
"discomfort":"n:不适,困难,不安;a:不适",
"discommode":"v:打扰",
"discompose":"v:扰乱",
"discomposed":"a:手足无措",
"discomposure":"n:不安,失常",
"disconcert":"v:挫败,窘,破坏,打乱",
"disconcerted":"a:手足无措",
"disconcerting":"a:难为情",
"disconnect":"v:切断,截断,断开,割断,解开,分离,拆开,退隐,断路,分开,隔开,脱钩,销声匿迹,折断,挂断",
"disconnecting":"v:拆开",
"disconnection":"n:分离,开路,断开,拆开,断路,绝缘;v:拆开",
"disconsolate":"a:愁,惆怅",
"disconsolately":"d:哭丧着脸",
"discontent":"n:不满,牢骚,不平",
"discontented":"a:不满",
"discontentment":"n:不满",
"discontinuance":"n:撤销,停止,断绝,中止,废止",
"discontinuation":"n:停止",
"discontinue":"v:停止,中断,暂停,停刊,终止,停办,下马,中止,放弃,撤销",
"discontinuity":"n:间断,中断,断绝",
"discontinuous":"v:停止;a:停止",
"discord":"n:不和;a:不和;v:冲突",
"discordance":"n:不和,倾轧",
"discotheque":"n:迪斯科,夜总会",
"discount":"v:减弱,贴息,扣,忽视,低估,藐视;n:贴现率,贴现,折头,回扣,扣头,贴息,缺憾",
"discountenance":"v:反对",
"discourage":"v:阻止,劝阻,妨碍,泼冷水,阻碍,挫伤",
"discouraged":"v:灰,失意,意懒心灰;a:凉;n:灰",
"discouragement":"n:挫折,气馁,泄气,失意,沮丧",
"discourse":"n:谈话,讲道,讲话;v:论说,说教,谈",
"discourteous":"a:失礼",
"discourtesy":"n:失礼,无礼,粗鲁",
"discover":"v:发现,发觉,泄露,揭示,找,显示,看到,露出,现出,发,看出",
"discovery":"n:发现,发觉,发展,显示,显露",
"discredit":"v:抹黑;n:疑惑;a:臭",
"discredited":"a:不得人心",
"discreet":"a:慎重,持重,重;d:谨",
"discrepancy":"n:出入,差别,矛盾,差异,差额,不合",
"discretion":"n:谨慎,判断,慎重,自由,判断力,斟酌,高低,辨别,离散,间断",
"discriminate":"v:歧视,区别,辨别,区分,排斥,判,辩证,判明,甄别,鉴别,识别,辨析,判别",
"discrimination":"n:歧视,眼力,甄别,排斥;v:甄别",
"discursive":"a:海阔天空,漫无边际,天南海北;d:海阔天空",
"discus":"n:铁饼,盘,花盘",
"discuss":"v:讨论,谈,谈论,商量,研究,商讨,论述,议论,讲,评论,商谈,论,谈话,详述,商议,辩论,商榷,念叨,商计,商洽,榷,审议,讨,研讨,议;n:商",
"discussion":"n:讨论,论述,辩论,讨论会,议论,审议,商议,详述",
"disdain":"v:不屑,鄙视;n:鄙视,轻视",
"disdainful":"v:轻蔑;a:轻蔑",
"disease":"n:疾病,病,病害,病态,疾,病症,腐败,瘅,症,弊病,毛病,邛,瘵,风,症候,证",
"disembark":"v:下船,卸载,卸下,上岸,登陆",
"disembody":"v:遣散",
"disembowel":"v:吐",
"disencumber":"v:摆脱,消除",
"disengage":"v:松开,挣脱,解除,放开,解开,放出",
"disengagement":"n:脱离,分离,离析,解雇,闲暇,解除,解约,自由,解开",
"disentangle":"v:解脱,解决,清理,解开",
"disestablish":"v:废除",
"disesteem":"n:冷遇,轻视;v:轻视,厌恶",
"disfavour":"n:疏远,不利,冷淡,失宠,厌弃;v:嫌弃,疏远",
"disfigure":"v:毁容,损害",
"disfigurement":"n:破相",
"disgorge":"v:吐,呕吐,流出",
"disgorgement":"n:吐",
"disgrace":"n:耻辱,丢脸,失宠,屈辱;v:玷污,贬黜",
"disgraced":"a:羞",
"disgraceful":"a:可耻,难看,不名誉,寒碜,丑,臭",
"disgruntled":"a:怏怏",
"disguise":"v:掩饰,隐瞒,装扮,假扮;n:借口,幌子",
"disgust":"n:厌恶;v:嫌恶,恶;a:恶",
"disgusting":"a:恶心,臭,恶劣;v:不堪入目,德行,穷极无聊,讨厌,不堪入耳,作呕;n:德行",
"dish":"n:菜,盘子,盘,碟子,菜肴,盘状;v:打败",
"dish out":"v:上菜,分发",
"dish towel":"n:搌布",
"dish up":"v:提出,炮制",
"dish washer":"n:洗碗机",
"dishabille":"n:混乱,便服,杂乱",
"dishcloth":"n:搌布,抹布",
"dishcloth gourd":"n:丝瓜",
"disheartened":"a:悲观失望,凉,沮丧;n:灰;v:灰",
"dished":"a:瘪,凹;v:凹陷",
"dishevel":"v:搅乱",
"disheveled":"a:蓬乱;v:披头散发",
"dishevelled":"a:蓬乱,散乱,乱蓬蓬;v:披头散发",
"dishonesty":"n:阴险,狡猾",
"dishonor":"v:玷辱,羞辱,丢面子,拒付,拒收,败坏;n:耻辱",
"dishonorable":"a:不端,鬼祟",
"dishonour":"n:不名誉,拒收,丢脸,侮辱,拒付;v:丢面子,羞辱,败坏,侮辱,奸污",
"dishonourable":"a:鬼祟,不端",
"dishwasher":"n:洗碗机",
"disillusion":"n:幻灭;v:醒悟",
"disillusionment":"n:幻灭",
"disinclination":"n:不愿,厌恶",
"disinclined":"a:不愿",
"disinfect":"v:消毒,洗净,杀菌;n:消毒剂",
"disinfectant":"n:消毒剂",
"disinfection":"n:消毒,灭菌",
"disinherit":"v:废",
"disintegrate":"v:解体,土崩瓦解,蜕变,崩,崩溃,分化,分裂,衰变,分解,碎,瓦解,溃散,冰消瓦解",
"disintegration":"n:蜕变,瓦解,崩溃,分裂,衰变,溅射,溃散;v:衰变,蜕变",
"disinterest":"n:冷淡",
"disinterested":"a:无私",
"disinterment":"v:发掘;n:发掘",
"disinvestment":"n:蚀本",
"disjoint":"v:脱位,解体,脱臼,拆散,分离,脱开,打乱,脱节",
"disjunction":"n:间断,分离,折断;v:间断",
"disk":"n:磁盘,盘,圆盘,软磁盘,唱片,花盘,铁饼,盘状;v:灌",
"diskette":"n:磁盘,磁碟,软磁盘",
"dislike":"v:讨厌;a:反感,恶;n:讨厌",
"dislocate":"v:脱臼,失调,脱位",
"dislocation":"n:混乱,断层,脱臼,移动,错位,打乱,脱位,转移,位移;v:错位,脱位,移动,转移",
"dislodge":"v:去除,驱逐,赶走",
"disloyal":"a:不义,贰",
"disloyalty":"n:不义,二心,贰心",
"dismal":"a:阴郁,暗淡,惨淡,悲凉,暮气沉沉,黯淡,黯淡无光",
"dismantle":"v:拆卸,拆开,拆除,解体,卸,拆,脱掉,下,摧毁,撤除,拆散,拆毁",
"dismantlement":"v:拆卸;n:拆卸",
"dismantling":"v:拆散,拆卸",
"dismay":"n:沮丧,惊愕;v:灰心,沮丧",
"dismayed":"v:心慌",
"dismember":"v:剐,割裂,瓜分,肢解,支解",
"dismemberment":"n:肢解,支解;v:肢解,拆散",
"dismiss":"v:解雇,辞退,打发,开除,撤职,解,解散,免职,放学,散会,驳回,忘掉,辞,消除,屏除,撇开,遣散,放弃,革,黜,裁,搁置,罢免,断,摈斥,撸,革出,免,革职,罢,罢职,摒,革除,开革",
"dismissal":"n:解雇,免职,开除,驳回,撤职,遣散,解散",
"dismount":"v:下马;n:下马",
"dismounting":"v:拆散,拆卸",
"disney":"n:迪斯尼",
"disobedience":"n:不孝",
"disobey":"v:违抗,不服,违,逆,违拗,违忤,迕,拗,抗命,违逆",
"disoblige":"v:得罪",
"disorder":"n:混乱,紊乱,骚乱,骚动,杂乱,缺陷;a:混乱,杂乱;v:颠三倒四",
"disordered":"v:颠倒;a:乱",
"disorderliness":"n:混乱,骚乱",
"disorderly":"a:杂乱;v:错落",
"disorganise":"v:打乱,瓦解",
"disorganization":"n:混乱,瓦解,分裂,紊乱",
"disorganize":"v:打乱,扰乱,瓦解",
"disorganized":"a:杂乱无章",
"disparage":"v:贬损,轻视,轻蔑,指责,污蔑,作践,贬低",
"disparagement":"n:轻蔑,轻视,贬损,贬低",
"disparity":"n:悬殊,差别,差异,剪刀差,差价,不同,不等,差距",
"dispassion":"n:冷静,公平",
"dispassionately":"d:平心静气",
"dispatch":"v:派,发出,发送,派遣,打死;n:快信",
"dispatcher":"n:调度员,调度,提调,发送者,收发;v:提调",
"dispatching":"v:发送",
"dispel":"v:消除,驱散,消释,祛除,拨,冲散,打消,散,释,消解,排解,排遣,消,祛,解",
"dispensary":"n:诊疗所,药房,门诊部,酒店",
"dispensation":"n:处理,天命,豁免,施行,不用,管理,制度,体制,天道,处方,分配,免除,执行",
"dispense":"v:发,免除,放弃,分配,免,分发,摆脱,豁免,配,屏除,施与,施行,实施,发放,摈除,发配",
"dispense with":"v:摈除,屏除,放弃,离,免",
"dispenser":"n:药剂师",
"dispersal":"n:分散,驱散",
"dispersant":"n:分散剂",
"disperse":"v:驱散,散开,分散,消散,散,散布,弥散,传播,驱,疏开,疏,部署,发,挥,散射,冲散,解散,涣,打散",
"dispersed":"v:疏散",
"disperser":"n:分散剂",
"dispersion":"n:分散,散布,色散,弥散,消散,离散,散射,疏散,传播,散开;v:疏散",
"dispersive":"a:散",
"dispirited":"a:颓废,颓丧,心灰意冷,沮丧,委靡,萎靡,丧气,颓唐;v:郎当,意懒心灰,委靡不振;n:郎当",
"displace":"v:取代,置换,顶替,撤换,替换,转移,错位",
"displacement":"n:位移,置换,排水量,取代,移动,代替,转移,流离失所;v:顶替,转移,移动,置换",
"display":"v:显示;n:展览品,展示,陈设",
"displease":"v:触怒,得罪",
"displeased":"a:不悦",
"displeasure":"n:不快,生气,发怒",
"disport":"v:游戏,娱乐,耍,玩耍,玩;n:玩耍,娱乐",
"disposable":"a:一次性",
"disposal":"n:处理,处置,安排,出售,使用权,布置,配置;v:处理",
"dispose":"v:处理,布置,安排,除掉,脱手,处置,解决,杀掉;n:布",
"dispose of":"v:了,解决,出脱,脱手,出手,处置",
"disposed":"a:愿意,乐意",
"disposition":"n:性格,性情,脾气,气质,生性,倾向,意向,布置,处置,处理,神意,气性,质地,安排,素质,天命,性,性质,秉性,脾性,体性,心性,意气",
"dispossess":"v:剥夺,霸占,逐出",
"dispossession":"n:强占,霸占,抢夺",
"dispraise":"n:非难,骂,毁谤,指责,贬损",
"disproof":"n:反证,反驳;v:反驳",
"disproportion":"n:失调",
"disprove":"v:驳斥,反驳,反证",
"disputation":"n:辩论,争论,议论",
"dispute":"v:争论;n:纷争,事端",
"disquiet":"n:不安,忧虑;v:打搅,忧虑",
"disquietude":"n:不安,焦虑,忧虑",
"disquisition":"n:研究",
"disregard":"v:无视,不顾;n:轻视,不理;c:不管",
"disrepair":"n:破损,失修;v:失修",
"disreputable":"a:不名誉",
"disrepute":"n:丢脸,声名狼藉",
"disrespect":"n:失敬,失礼,无礼;v:失礼,无礼",
"disrespectful":"a:谩",
"disrupt":"v:破坏,分裂,搞垮,打断,断裂",
"disruption":"n:分裂,中断,瓦解;v:分裂,击穿",
"dissatisfaction":"n:不满,不平,失望",
"dissatisfied":"a:不满",
"dissect":"v:剖析,解剖,切割,分割,切开,剖,析,剖解,剖开",
"dissection":"n:解剖,切割;v:解剖",
"dissemble":"v:掩饰,假装,矫,隐藏,作伪,矫饰,作假",
"dissembler":"n:伪君子",
"disseminate":"v:传播,普及,撒,散布;n:布",
"dissemination":"n:传播,散布,转播,播种,浸染",
"dissension":"n:纠纷,分歧,讧,不合,冲突,倾轧",
"dissent":"n:异议,异同",
"dissertation":"n:论文,论述,论",
"disservice":"n:危害,损害,伤害",
"dissever":"v:分割,分离,分裂,分手",
"dissidence":"n:异议,不同",
"dissident":"n:异己",
"dissimilarity":"n:不同,差别,差",
"dissimilitude":"n:相异,对比,不同",
"dissimulate":"v:假装,作伪,掩饰,作假",
"dissimulation":"n:掩饰",
"dissipate":"v:浪费,消散,驱散,挥霍,暴殄天物,放荡,散失,放电",
"dissipated":"a:放荡;v:糜烂",
"dissipation":"n:放荡,损耗,消遣,消散,消耗,娱乐;a:糜费;v:浪费",
"dissociate":"v:分离,分裂,游离,离异",
"dissociation":"n:分解,分离,分裂,变异,离异;v:离析",
"dissolute":"a:放荡,放浪,风流,荒淫,猖,荡,佚,荒,浪荡,放肆,腐化",
"dissolution":"n:解散,溶解,崩溃,解除,消亡,分离,腐朽,消失,液化,解体,清算,分解,死亡,废除,融化,取消",
"dissolve":"v:溶解,消失,解散,溶,解开,解除,融化,崩溃,溶化,失效,化,揭开,软化,分解,融解,摧毁,打破,撤消,废除,化解,冰消瓦解,取消,冰释",
"dissonance":"n:倾轧,不和",
"dissuade":"v:劝阻,告诫,劝止,劝戒",
"dissuasion":"n:劝戒,制止,告诫,劝阻",
"dissuasive":"a:劝阻",
"distaff":"n:妇道,母系",
"distance":"n:距离,远处,地,远方,路,路程,疏远,远离,隔阂,远近;v:距,超过,隔开,胜过",
"distant":"a:遥远,远,辽,生分,悠远,邈,疏,逖,遥,遐,幽幽,悠然,辽远",
"distaste":"n:厌恶",
"distasteful":"a:反感",
"distemper":"n:疾病,骚动,不安",
"distend":"v:膨胀;a:胀",
"distension":"n:膨胀",
"distention":"n:膨胀",
"distill":"v:蒸馏,渗出,提制,提取,滴落",
"distillate":"n:浓缩物,精华",
"distillation":"n:蒸馏,升华;v:升华,蒸馏",
"distiller":"n:糟行,蒸馏器",
"distillery":"n:糟行,槽坊,酒厂",
"distinct":"a:不同,明显,清楚,清晰,明晰,分明,各别,缪,清,鲜明,洗,明;v:洗",
"distinction":"n:区别,区分,差别,荣誉,特征,特性,卓越,盛名,别,优越,甄别;v:甄别",
"distinctive":"a:独特,与众不同,鲜明;v:与众不同",
"distinctiveness":"n:特殊性",
"distinctly":"d:显然,真,各别;a:逼真",
"distinctness":"n:不同",
"distinguish":"v:区别,区分,辨别,分辨,辨认,识别,分清,别,分,区,分辩,判,判明,鉴别,辨,分别,甄,仳,判别,划清",
"distinguished":"a:杰出,卓越,杰,挺,特出,卓著;v:鹤立鸡群,达,挺",
"distort":"v:歪曲,变形,扭曲,失真,曲解,枉;n:扭曲",
"distortion":"n:失真,变形,歪曲,畸变,曲解,扭曲,窜改,扭转",
"distract":"v:分散,分心,排遣,岔开,消遣,娱乐",
"distracted":"a:怅惘,六神无主,凄迷;v:愣",
"distraction":"n:发狂,消遣,分心,娱乐,排遣,心烦",
"distress":"n:痛苦,苦恼,不幸,悲痛,危难,烦恼,苦难,贫苦,悲叹,灾殃,愁苦,苦楚,穷困,苦痛,愁闷;v:悲痛,扣押,愁苦,困厄,愁闷",
"distressed":"a:苦恼,悲痛,哀伤,痛心,忧戚,忧伤,愁,酸楚;v:愁",
"distribute":"v:分布,分配,分发,散发,发给,配,发行,分,区分,发布,颁布,俵,经售,分送,颁,实施,发,分开,经销,配给,散,散布,播撒,拆",
"distributed":"a:分布式",
"distribution":"n:分布,分配,分发,销售,布局,分类,配置;v:分布,分配",
"distributor":"n:批发商,配电盘",
"district":"n:地区,区,管区,教区,路,分区,区间,行政区,地域,市区,地段,区域,地带",
"district of columbia":"n:哥伦比亚",
"distrust":"n:猜疑,疑惑;v:怀疑",
"distrustful":"v:疑神疑鬼;a:疑神疑鬼",
"disturb":"v:打扰,扰乱,打搅,干扰,惊动,搅扰,扰动,搅,搅乱,烦扰,侵犯,扰,骚乱,相扰,打岔,捣乱,妨碍,妨害,捣,骚,娆,失调,撄,骚动",
"disturbance":"n:扰动,干扰,骚乱,动乱,失调,乱子,闹乱子,骚动,变乱,丧乱,妨害,纷乱,闹事,侵犯,风波,事端;v:干扰",
"disturbances":"n:风风雨雨",
"disturbed":"a:不安",
"disturbing":"a:骚",
"disunion":"n:分裂,分离,不和,倾轧;v:分裂",
"disunite":"v:分裂,不和,分离",
"disunited":"n:一盘散沙;v:一盘散沙",
"disunity":"n:离心离德;v:离心离德",
"disuse":"v:不用,废止,废弃,废;n:废弃",
"disused":"a:废",
"ditch":"n:水渠,沟槽,沟渎,沟子,明沟,渠道,阳沟;v:抛弃,出轨,甩开,摆脱,抛开",
"ditch reed":"v:芦苇",
"ditching":"v:抛开",
"dither":"v:犹豫不决,发抖,颤动,颤抖,优柔寡断,三心二意;n:发抖,颤抖",
"ditto":"v:同上,重复,复制;n:复制品,副本,同上;d:如前所述",
"ditty":"n:小调,唱,小曲儿,小曲;v:唱",
"ditty bag":"n:针线包",
"diuresis":"n:利尿",
"diuretic":"n:利尿剂",
"diurnal":"n:日记,周日,日报;a:白天",
"divan":"n:大楼,咖啡馆,会议,沙发床,委员会,局,法庭",
"dive":"v:跳水,潜入,俯冲,潜水;n:猛冲",
"diver":"n:潜水员",
"diverge":"v:发散,偏离,分歧,分岔,分开,离,岔开,分叉",
"divergence":"n:发散,偏差,分歧,离题,出入;v:发散",
"divergent":"a:歧",
"diverging lens":"n:发散透镜",
"divers":"n:指头",
"diverse":"a:不同,别的",
"diversification":"n:多样化,形形色色;v:多样化",
"diversified":"a:参差,多种,多种多样;v:多种,花花搭搭",
"diversify":"v:多样化",
"diversion":"n:娱乐,改道,转移,消遣,佯攻,转向,排遣,转换,挪用,偏转,转角",
"diversity":"n:多样性,多样,差异,参差,多种,异样,驳杂,不同,繁多;a:不同",
"divert":"v:转移,挪用,引水,排遣,佯攻,转向,移用,改行",
"dives":"n:富豪,豪富",
"divest":"v:剥夺,脱去",
"divestiture":"n:剥夺",
"divestment":"n:剥夺",
"divide":"v:划分,分,分裂,分开,分割,除,表决,分担,分配,分享,隔开,分隔,分离,离间,区分,分派,劈;n:分界线,分裂,分,分配,分水岭,分界",
"dividend":"n:被除数,股利,股息,红利,分红,报酬,红,利息,份儿",
"dividends":"n:股息",
"divider":"n:分规,减速器,除数,分线规,两脚规",
"dividers":"n:分线规,两脚规,规",
"dividing line":"n:分界",
"divination":"n:占卜,占卦,卜卦,预言;v:占卜",
"divine":"v:猜测,察觉,推测;n:神学家,造物主;a:神乎其神",
"diving":"v:潜水",
"diving suit":"n:潜水衣",
"divinities":"n:神灵,神明",
"divinity":"n:神学,神,神奇,神力,神人,神威,神道,天使,上帝",
"division":"n:师,除法,部门,分,表决,部分,分裂,师团,分割,刻度,分配,部,区分,区域,节,分派,选区,隔墙,辑,间隔,门,分界,分开,组,分隔,倾轧,司;v:分割,分隔,分裂",
"divisor":"n:除数,因子,约数",
"divorce":"n:离婚;v:脱离,分离,离异",
"divorcement":"n:离婚",
"divot":"n:草皮",
"divulge":"v:泄露,泄漏,透露,宣布,暴露,走漏,揭发,透漏,公布,漏",
"divvy":"v:分享,分配,分摊;n:份儿",
"dixie cup":"n:纸杯",
"dizziness":"n:眩晕,头晕,头昏;v:头昏,头晕",
"dizzy":"v:晕,昏眩,目眩,做,头昏;a:晕晕忽忽,昏天黑地,晕乎乎",
"djibouti":"n:吉布提",
"do":"v:做,工作,干,为,进行,完成,作,行,搞,行动,处理,弄,办,产生,洗,表现,带来,对待,从事,利用,适合,行事,千万,欺骗,烧,担任,加以,收拾,修理,闹,翻译,整,参观,服刑,访问,煎,款待,游览,杀死,搞垮,招待,上演,改写,逛,作到,预备,修缮,抄,打败,解答,受得了,忍,创作;n:行动,成功",
"do away with":"v:屏除,摆脱,去掉,废除",
"do good":"n:有益",
"do in":"v:搞垮",
"do one's best":"v:卖,一力,尽心竭力,尽力而为",
"do up":"v:系,修缮,收拾",
"do well":"v:做好,搞好",
"dobbin":"n:驽马,驮马",
"doc":"n:大夫,医生",
"docent":"n:讲师",
"docile":"a:驯服,驯良,服贴,温驯;v:驯化",
"docility":"n:驯良,听话,温顺",
"dock":"v:对接,缩减,剪短,装卸,削减,会合;n:草本植物,飞机库,海港",
"docket":"n:议事日程,购货证,摘要,概略,签条,标签",
"dockyard":"n:船坞",
"doctor":"n:医生,大夫,博士,医师,巫医;v:修复,阉割,诊治",
"doctrine":"n:学说,原则,教义,说,论,主义,教训,道,教条;v:说",
"document":"n:文件,文献,证件,件,公文,凭证,文书,书,证书",
"documentary":"n:记录片",
"documentary film":"n:纪录片,记录片",
"documentation":"n:文档,案例",
"dod":"n:国防部",
"dodder":"v:摇晃,摇摆,哆嗦;n:菟丝子",
"dodge":"v:躲开,躲,避开;n:搪塞,推托,闪开",
"dodgem":"n:碰碰车",
"dodger":"n:传单",
"dodging":"v:遮光",
"doer":"n:实干家;v:做",
"doeskin":"n:做",
"doff":"v:落,废除,脱去,脱",
"dog":"n:狗,犬;v:尾随,钉梢,浮夸;d:非常",
"dog collar":"n:项链",
"dog days":"v:伏,伏天,炎暑,暑天",
"dog star":"n:天狼星",
"dogged":"a:顽强,固执;v:牛脾气;n:打油诗",
"doggedness":"n:犟劲",
"doggerel":"n:打油诗,顺口溜",
"doggone":"d:非常,极;n:诅咒",
"dogleg":"n:急转弯,扭曲;v:偏转",
"dogma":"n:教条,教义,信条",
"dogmatism":"n:教条主义,武断",
"dogsbody":"n:部下",
"dogtrot":"n:小跑",
"dogwood":"n:山茱萸",
"doing":"n:做,举动,干,所作所为,活动,行动,实行",
"doings":"n:举动,活动",
"doldrums":"n:郁闷,沉闷,忧郁,萎靡不振",
"dole":"n:多尔,施舍,悲叹;v:施舍",
"doleful":"a:悲戚,哀",
"doll":"n:洋娃娃,玩偶;v:浓妆艳抹",
"doll up":"v:浓妆艳抹",
"dollar":"n:美元,美金,美钞,财富",
"dollop":"n:少量,一块,一点儿",
"dolly":"n:手推车",
"dolomite":"n:白云石",
"dolor":"n:忧伤",
"dolour":"n:悲哀",
"dolphin":"n:海豚,海猪",
"dolt":"n:呆子,傻瓜,笨蛋",
"domain":"n:区域,领域,域,范围,领地,领土,范畴,王国,畴,房地产,域名,版图,疆域,特长,产业,地盘,管区",
"domain name":"n:域名",
"dome":"n:大厦,拱顶,脑袋,丘,殿宇,窟窿,头",
"domestic":"a:家用;n:佣人,家",
"domestic animal":"n:家禽,牲,畜生,畜",
"domestic fowl":"n:家畜,家鸡",
"domesticate":"v:驯养,驯,驯化,培养,引入,驯服",
"domestication":"n:驯化,驯养",
"domesticity":"n:家务,家风,深居简出",
"domicile":"v:安家,居住;n:住所",
"dominance":"n:优势,控制,支配,显性,统治,优越;a:显性",
"dominant":"n:主因,要素,主导;v:占优势;a:占优势",
"dominate":"v:支配,控制,统治,高耸,把持,左右,俯视,驾驭,操纵,占优势,主宰,把,控,高出,霸,超出,独揽,把揽,称霸,优于,独霸",
"domination":"n:统治,操纵,支配,控制,优势,把持,主宰,天下",
"domineer":"v:跋扈,横行霸道,惧内,作威作福,称王称霸",
"domineering":"a:跋扈,专横,霸道",
"dominica":"n:多米尼加",
"dominion":"n:统治,支配,领地,主权,版图,领土,加拿大,统治权",
"dominoes":"n:骨牌,牙牌",
"don":"n:导师,顿河,专家,名家,院长,绅士;v:穿上",
"dona":"n:夫人",
"donate":"v:捐,捐献,捐赠,输,布施,捐助,送,赠送,献,赠予",
"donation":"n:捐赠,捐款,赠品,捐献,赠送,布施",
"done":"d:已经;a:熟",
"dong":"n:董",
"donkey":"n:驴,驴子,蠢驴,傻瓜,笨蛋,毛驴,拖拉机",
"donkey engine":"n:卷扬机,小汽车,绞车",
"donor":"n:施主",
"doodad":"n:便宜货,装饰品",
"doodle":"v:哄骗;n:傻瓜",
"doodlebug":"n:飞弹,战车",
"doohickey":"n:窍门",
"doom":"n:厄运,恶运,劫数,末日;v:命定,覆灭",
"doomed":"v:死路;n:死路",
"doomsday":"n:末日",
"door":"n:门,门口,房门,门户,门径,门路,入口,通道,户,口,宅门,关口",
"doorbell":"n:门铃",
"doorjamb":"n:枨",
"doorkeeper":"n:门卫,门警,门房",
"doorman":"n:门房,门卫,门子",
"doormen":"n:门卫",
"doorplate":"n:门牌",
"doorsteps":"n:除",
"doorway":"n:门口",
"dope":"n:安眠药,明胶,傻子,预测,食品,麻醉品,涂料;v:解,预测,麻痹",
"dope off":"n:昏睡",
"dopey":"a:呆,笨,傻",
"doping":"v:掺杂",
"doppler":"n:多普勒",
"dorm":"n:宿舍",
"dormancy":"n:休眠,潜伏,休止,睡眠,蛰伏;v:休眠,蛰伏",
"dormant":"v:休眠,隐,蛰伏;a:隐",
"dormer":"n:老虎窗",
"dormitory":"n:宿舍,寝室",
"dorsal fin":"n:背鳍",
"dory":"n:快艇",
"dosage":"n:剂量,配药,配料,剂,下药",
"dose":"n:剂量;v:服药",
"dosimeter":"n:量筒",
"doss":"n:床位,睡眠;v:睡",
"dossier":"n:卷宗,卷,档案,案卷",
"dot":"n:点;v:打点",
"dot matrix":"n:点阵",
"dotage":"n:老糊涂,溺爱",
"dotard":"v:做;n:老糊涂",
"dote":"v:溺爱,宠爱,衰老,疼,宠,钟爱;a:昏聩",
"double":"v:对折;n:诡计,替身,幽灵,双倍,变奏曲,副本,回避,折回,折叠,重叠;a:兼,复;d:加倍",
"double cross":"n:两面三刀,违约,出卖,欺骗",
"double dutch":"n:天书",
"double entendre":"n:双关语,含糊其词",
"double entry":"n:复试",
"double salt":"n:复盐",
"double star":"n:双星",
"double talk":"n:黑话",
"double up":"v:对折",
"double-dealer":"n:两面派",
"double-dealing":"n:奸诈",
"double-decker":"n:双层床",
"double-quick":"a:快步;d:迅速",
"doubles":"n:副本,双打,复制品",
"doublespeak":"n:欺人之谈",
"doublet":"n:马甲,工装",
"doubling":"v:加倍,折回,成双,迂回,重叠,重合,对折",
"doubly":"d:倍加,倍增",
"doubt":"n:疑虑,疑问,疑惑,疑心,疑点;v:狐疑,疑",
"doubtful":"a:可疑,不明不白,疑",
"doubtless":"d:多半,必定;v:无庸置疑",
"doubtlessly":"d:无疑",
"douche":"v:冲洗;n:冲洗",
"dough":"n:面团,钱,现钞",
"doughy":"a:软弱无力;v:软弱无力",
"douglas":"n:道格拉斯",
"dour":"a:沉",
"douse":"v:洒,放松,浸;n:浸,浇,洒",
"dousing":"v:泼,泡",
"dove":"n:鸽子,乳鸽,鸽",
"dover":"n:多佛",
"dovetail":"n:晚礼服;v:吻合",
"dowager":"n:贵妇",
"dowdy":"a:寒酸,邋遢;n:寒酸气",
"dowel":"n:销子,销钉",
"dower":"v:赋予,陪送;n:嫁妆",
"down":"d:放下,在下,下,直到,下降;n:岗,落魄,嫌恶,鸭绒,羽绒,憎恶,挫折,绒;v:打倒,击倒;p:往_下",
"down feather":"p:绒羽",
"down payment":"n:定金",
"downbeat":"n:下降,衰落",
"downcast":"a:垂头丧气,丧气,颓靡,低落;n:灭亡,陷落,下落,没落,俯视",
"downdraft":"n:下降",
"downer":"n:失意",
"downfall":"n:垮台,倒台,堕落,大雨;v:垮台,倒台,坍方",
"downgrade":"v:贬低;n:下坡",
"downhearted":"a:消沉,心灰意冷,意懒心灰;v:意懒心灰",
"downhill":"d:下坡,降下;n:山坡,下坡路",
"downing street":"n:首相,现政府",
"download":"v:下载",
"downplay":"v:贬低,低估",
"downpour":"n:倾盆大雨,大暴雨,瓢泼,暴雨,照射",
"downright":"d:透顶,干脆;a:直性子,透顶;n:直性子",
"downriver":"a:下行,下水;v:下水,下行",
"downside":"n:下边,缺点",
"downsize":"v:裁减,裁员,减小",
"downstairs":"n:楼下",
"downstream":"v:下水,顺水,下行;a:下游,下水,下行;n:下游",
"downtown":"n:市中心,闹市,街市,闹市区;a:闹市区,商业区",
"downturn":"n:衰退;v:衰退",
"downward":"a:下;n:下",
"downwards":"d:以后,以下,以来",
"downwind":"n:下风;a:顺风;d:下风",
"downy":"a:毛茸茸,茸茸,软绵绵,茸",
"dowry":"n:陪嫁,陪送,天赋,才能,财礼,嫁妆",
"dowse":"v:淬火",
"doyen":"n:老前辈,老资格",
"doze":"v:打瞌睡,打盹,瞌睡;n:假寐",
"doze off":"v:眯盹儿,打盹儿",
"dozen":"n:打,许许多多",
"dr":"n:博士",
"drab":"n:乏味,单调,妓女;a:乏味,单调;v:处理",
"drabness":"n:死气沉沉",
"draco":"n:飞龙",
"draft":"n:草案,草稿,汇票;v:设计,挑选,征,征兵,制定,起,画,征召,汲取,征集,选派",
"draft beer":"n:生啤酒",
"draft horse":"n:驮马",
"drafted":"v:草;a:草",
"drafting":"n:制图;v:制图",
"draftsman":"n:绘图员,制图员",
"draftsmen":"n:绘图员",
"drag":"v:拖;n:制动器,刹车",
"drag in":"v:累及,牵扯,牵涉,牵绊,拉扯",
"drag on":"v:旷日持久,拖,迟延,拖延",
"drag one's feet":"v:裹足不前",
"drag one's heels":"v:拖拖拉拉",
"drag out":"v:拖延,拉,挨,延长,拉长",
"dragging":"v:带走",
"dragnet":"n:法网,拖网",
"dragon":"n:龙",
"dragonfly":"n:蜻蜓,蚂螂",
"dragoon":"n:暴徒",
"drain":"n:下水道,引流,排水沟;v:排泄,宣泄",
"drainage":"n:排水,引流,水系,下水道,污水,流域;v:引流",
"drainage basin":"n:流域",
"drainage ditch":"n:排水沟",
"drainage system":"n:水系",
"drainer":"n:下水道",
"draining":"v:排水",
"drainpipe":"n:排水管",
"dram":"n:微量,少许,少量;a:少量",
"drama":"n:戏剧,戏剧性,戏,剧本,剧,话剧,戏曲,剧作",
"dramamine":"n:乘晕宁",
"dramatics":"n:演出,演技,作假",
"dramatis personae":"n:剧中人",
"dramatist":"n:剧作家,戏剧家,剧作者",
"dramatization":"n:编剧",
"dramatize":"v:作假",
"drape":"v:披,覆盖,装饰;n:窗帘,帘",
"draped":"v:酩酊大醉",
"draper":"n:布店",
"draperies":"n:帷幔",
"drapery":"n:毛织物,衣饰,服装,织物,布匹,呢绒,绸缎,帷幕",
"drastic":"d:大刀阔斧;a:断然",
"drat":"v:诅咒",
"draught":"n:穿堂风,过堂风,气流,草稿,挽具,吃水,通风",
"draughts":"n:跳棋",
"draughtsman":"n:绘图员,制图员,棋子",
"draw":"v:画,和,吸引,拉,下;n:拈阄",
"draw a line":"v:划线",
"draw away":"v:离开",
"draw back":"v:收缩,作罢,远离,后退,缩,退,拉开,拉起,缩回",
"draw close":"v:逼近,靠拢",
"draw in":"v:拉,吸入",
"draw near":"v:逼近,临近,傍",
"draw off":"v:脱去,退走,排出,转移",
"draw out":"v:出车,起,拉,离开,提取,延长,曼延,提,抽出,拉长,抽取",
"draw the line":"v:限制",
"draw together":"v:接合,靠拢,纠集,括",
"draw up":"v:起草,编制,订,开具,拟定,制,制定,编造,拟议,搞,开列",
"drawback":"n:缺点,障碍,弊病,弊端,失误,退款,不利,回火,退税,妨碍,缺陷;v:退税,退款",
"drawbacks":"n:弊端",
"drawbridge":"n:吊桥",
"drawer":"n:抽屉,橱柜,屉,制图员,衬裤,屉子,抽斗",
"drawers":"n:内裤,衬裤,小衣",
"drawing":"n:画,图画,图,绘画,图样,图纸,素描,图形,牵引,拈阄,退火,引诱,制图,抽签,开发,描画;v:拉制,制图,提款,拉伸,拔",
"drawing board":"n:图板,画板",
"drawing off":"n:引出,拔取",
"drawing paper":"n:画纸",
"drawing pin":"n:摁钉儿",
"drawing room":"n:接见,花厅",
"drawings":"v:提款",
"drawl":"v:慢条斯理",
"dray":"n:大车",
"dread":"v:怕;n:担心;a:恐惧",
"dreadful":"a:可怕,恐怖,害怕;v:害怕",
"dreadfully":"d:非常,极,特别",
"dream":"v:梦想,梦见,做梦;n:美景,梦寐",
"dream up":"v:凭空捏造,虚构",
"dreamer":"n:空想家",
"dreamland":"n:梦境,梦乡,幻境,睡乡",
"dreamworld":"n:梦境",
"dreary":"a:凄凉,惨淡,萧",
"dredge":"v:疏浚,挖掘;n:拖网",
"dredge up":"v:疏浚,罱,捻",
"dredger":"n:挖泥船,挖掘机",
"dregs":"n:沉渣,糟粕,渣滓,脚,残渣,渣",
"drench":"v:淋,浸泡,通晓,浸润",
"drenched":"a:湿淋淋;v:湿淋淋",
"dresden":"n:德累斯顿",
"dress":"v:磨光,修整,装潢,耕作,乔装打扮;n:小衣裳,童装,衣装",
"dress circle":"n:包厢",
"dress down":"v:磨光,修饰,训斥",
"dress suit":"n:大礼服,晚礼服",
"dress up":"v:隐瞒,饰,装,乔装,打扮,乔装打扮,伪装,装扮,妆饰",
"dresser":"n:梳妆台,化装师,镜台",
"dressing":"n:衣服,包扎,敷料,打扮,肥料,修饰,填料,装束,追肥;v:上浆,整修",
"dressing case":"n:镜匣",
"dressing gown":"n:晨衣",
"dressing room":"n:化妆室,更衣室,后台",
"dressmaker":"n:裁缝",
"drew":"v:滴",
"dribble":"n:滴,微雨,毛毛雨,盘球,少量,哈喇子,涓滴,运球;v:运,运球",
"driblet":"n:少量,渐渐,涓滴",
"dried fruit":"n:果脯",
"drier":"n:干燥剂",
"drift":"v:漂流;n:要点,动向,偏差,绞刀,流程",
"drift apart":"v:疏远",
"drift away":"v:抛开",
"drift ice":"n:浮冰,撕",
"drifter":"n:流浪者",
"drifting":"v:不定,掘进;a:不定",
"driftwood":"n:寄生虫",
"drill":"v:钻探;n:耩子,教练,凿岩机,钻床,垄沟",
"drill bit":"n:钻头,钻",
"drill hole":"n:钻孔",
"drill press":"n:钻床",
"drill rig":"n:穿孔机",
"drill rod":"n:钎",
"drill steel":"n:钢钎",
"driller":"n:教练,钻床",
"drilling":"n:条播,卡其,钻孔,钻井,操练,训练;v:钻探,打眼,掘进",
"drilling bit":"n:钻头",
"drilling platform":"n:钻台",
"drillmaster":"n:教练,教官",
"drink":"v:喝;n:饮品",
"drink down":"v:灌醉,借酒消愁",
"drink in":"v:汲取,爱好",
"drinker":"n:酒徒,饮水器",
"drinking":"v:饮,喝,喝酒",
"drinking glass":"n:酒杯",
"drinking vessel":"n:酒具,觞",
"drinking water":"n:饮水,饮用水,吃水",
"drip":"v:滴;n:滴,滴水,点滴,恭维话",
"dripping":"n:水滴,滴;v:淋淋,涔涔;a:淋淋",
"drive":"v:开车,开,驾驶,驾车,驱动,驱车;n:旅程,驱使,击球,流放,劲头,动力",
"drive away":"v:赶走,赶跑,祛",
"drive back":"v:却",
"drive in":"v:掘进",
"drive off":"v:轰,驱散,赶走,祛",
"drive out":"v:驱逐,祛除,打掉,逐",
"drive up":"v:哄抬",
"drivel":"n:口水,哈喇子,胡说;v:胡说,浪费,胡扯",
"driven":"a:从动",
"driver":"n:司机,驾驶员,车夫,打桩机,推进器,监工,夯",
"driveway":"n:车道,公路,马路",
"driving":"v:驾驶,掘进;a:主动",
"driving license":"n:驾驶证",
"drizzle":"n:细雨,毛毛雨,小雨;v:蒙蒙",
"drizzly":"a:蒙蒙,潇潇",
"drogue":"n:浮标",
"droll":"a:开玩笑,说笑话",
"drollery":"n:滑稽戏,漫画,滑稽,笑话",
"dromedary":"n:单峰骆驼",
"drone":"n:雄蜂,靶机;d:嗡,嗡嗡;v:偷懒,混日子",
"drool":"n:哈喇子,胡话,唾液,梦话,口水;v:垂涎,流口水",
"droop":"v:垂,低垂,枯萎,衰弱,耷拉;n:下垂,低垂,颓丧",
"drooping":"d:冉冉;v:冉冉",
"droopy":"a:倦意",
"drop":"v:掉,下降;n:伞降,踏板,耳坠,点滴,落差,水果糖,陡坡",
"drop away":"v:离开",
"drop back":"v:后退,退后",
"drop behind":"v:落后,落伍",
"drop dead":"v:翘辫子",
"drop down":"v:顺流而下,下降,踣",
"drop hammer":"n:落果",
"drop in":"v:拜访,串门子",
"drop off":"v:死去,掉队,掉落,减弱",
"drop out":"v:掉队,退出,脱扣,落伍,退学",
"drop shot":"v:短球",
"drop-off":"n:陡坡,衰减",
"droplet":"n:滴,水珠",
"dropper":"n:支脉,挂钩,滴管",
"dropping":"n:降下,空投,点滴,粪",
"droppings":"n:粪,屎",
"dropsy":"n:水肿,积水;v:浮肿",
"drosophila melanogaster":"n:果蝇",
"dross":"n:杂质,渣滓,废物,糟粕,废渣,糟",
"drought":"n:干旱,旱灾,旱情,旱,干渴,旱魃;v:短少",
"drove":"n:人群,土路;v:买卖,赶",
"drown":"v:淹死,溺水,淹没,溺死,沉没,埋头,冲淡,消,解,灭,溺",
"drowned":"v:淹没",
"drowning":"v:溺水",
"drowse":"v:打盹儿,打瞌睡",
"drowsiness":"n:睡意,嗜睡",
"drowsy":"a:瞌睡,蒙胧,困倦,惺忪;v:嗜睡",
"drub":"v:跺脚,敲击,打败",
"drubbing":"n:殴打,击破",
"drudge":"n:苦工",
"drudgery":"n:苦工",
"drug":"n:药,药物,药品,麻醉药,麻醉剂,药剂,毒,麻醉品;v:毒化,麻醉",
"drug addict":"n:瘾君子",
"drug addiction":"n:毒瘾,吸毒",
"drug trafficking":"v:贩毒",
"druggist":"n:药剂师,司药",
"drugstore":"n:药房,杂货店,药店",
"druid":"n:巫师",
"drum":"n:鼓,鼓声;v:打响,鼓吹",
"drumbeat":"n:鼓声",
"drumbeats":"n:鼓点子",
"drummer":"n:鼓手,鼓师",
"drumstick":"n:鼓槌",
"drunk":"a:喝醉;n:酒宴;v:醉",
"drunkard":"n:醉汉,酒鬼,醉鬼",
"drunken":"a:酕醄",
"drunkenly":"d:醉",
"drunkenness":"n:醉态,放纵,放荡,酩酊,酒色",
"drupe":"n:核果",
"druthers":"n:偏爱",
"dry":"a:干,干燥,干旱;v:烘干,干涸,晾干,住嘴;n:干燥,干旱",
"dry cell":"n:干电池",
"dry cleaner":"v:干洗店",
"dry dock":"n:船坞",
"dry ice":"n:旱冰,干冰",
"dry nurse":"n:保姆",
"dry out":"v:晾干",
"dry rot":"n:腐化",
"dry up":"v:戾,住嘴,干涸,瘪,竭,干巴",
"dry-nurse":"v:保育,抚育",
"dryer":"n:烘缸,烘炉,干燥剂",
"drying":"v:烘干;a:干燥",
"dryness":"n:干燥;v:节制",
"du":"n:杜",
"dual":"a:双重,二元;n:对偶,双数,双",
"dualism":"n:二元论,两重性",
"dualistic":"a:二元",
"duality":"n:二重性,对偶,两重性",
"dub":"v:配音,刺;n:撞,戳,水塘,刺",
"dubbing":"v:复制,配音;n:配音,译制",
"dubiety":"n:怀疑,疑心",
"dubious":"a:暧昧,可疑,不三不四,不明不白",
"dublin":"n:都柏林",
"ducat":"n:金钱,入场券,现款,货币",
"duchy":"n:公国",
"duck":"n:鸭子,鸭;v:闪避,躲避,逃走,埋头",
"duckbill":"n:鸭嘴兽",
"ducked":"v:鸭嘴兽",
"ducking":"v:帆布,闪避",
"duckling":"n:鸭黄",
"duckweed":"n:浮萍,紫萍,薄,萍,水萍,绿萍",
"ducky":"n:亲爱的",
"duct":"n:管道,管,导管,渠道,沟,墨斗,涵管,管子,孔道,槽",
"ductile":"a:可塑性",
"ductility":"n:延性,韧性,可塑性,塑性",
"ducting":"n:管道",
"dud":"n:失望,瞎炮,哑弹,失败,衣服",
"dude":"n:花花公子",
"dudgeon":"n:愤怒,生气,愤恨",
"due":"a:由于,到期;n:费用;v:到期,应得,应有",
"due east":"n:正东",
"due south":"n:正南",
"due to":"p:定于,由于,由,因为",
"duel":"v:决斗,斗争;n:抗争,竞争,斗争",
"dueling":"v:斗争,决斗",
"duelling":"v:斗争",
"duenna":"n:保姆",
"dues":"n:费,会费",
"duet":"n:二重唱,二重奏",
"duff":"n:布丁,假货,煤屑,屁股,臀部;v:伪造",
"duffer":"n:笨蛋,行商,废物",
"dug":"v:探究",
"dugout":"n:地下室,地洞,岩洞,独木舟,洞穴",
"duke":"n:公爵,樱桃,君主,司令官,公,首领,千岁,手",
"dukedom":"n:公国",
"dulcimer":"n:扬琴,洋琴",
"dull":"a:乏味,单调,呆滞,枯燥,呆板,暗淡,清淡;v:愣,懵,冥顽不灵",
"dullard":"n:笨蛋",
"dullness":"a:迟钝;n:迟钝",
"duly":"d:准时,及时,按时,正好",
"dumas":"n:小说家",
"dumb":"a:哑;v:哑",
"dumb show":"n:手势",
"dumbbell":"n:蠢材,哑铃,笨蛋",
"dumbfound":"v:呆若木鸡,发呆",
"dumbfounded":"v:发呆,呆若木鸡,目瞪口呆;a:目瞪口呆",
"dumbness":"n:哑",
"dumbstruck":"a:呆若木鸡;v:呆若木鸡",
"dumdum":"n:达姆弹",
"dumdum fever":"n:黑热病",
"dummy":"n:哑巴,样品,笨蛋,傀儡,样本",
"dump":"v:倾销;n:金钱,小钱",
"dumping":"n:倾销,垃圾,抛弃,倾倒;v:报废,倾销",
"dumpling":"n:汤团,团,圆子,团子,饺,饺子,角",
"dumps":"n:沮丧,郁闷,忧郁",
"dumpy":"a:矮胖,粗墩墩,矮墩墩",
"dun":"v:逼债,讨债",
"dunce":"n:劣等生,低能儿,蠢货",
"dunderhead":"n:傻瓜,蠢才,蠢材",
"dune":"n:沙丘",
"dung":"n:肥料,粪,粪肥,屎,粪便,坢",
"dung beetle":"n:虼螂",
"dungeon":"n:地牢",
"dunghill":"n:堆肥,粪堆",
"dunk":"v:浸泡",
"dunkirk":"n:敦刻尔克",
"duo":"n:二重唱,二重奏",
"duodecimal notation":"n:十进制",
"duodenum":"n:十二指肠",
"duologue":"n:对话,对白",
"dupe":"v:欺哄,欺蒙,戏弄,蒙蔽,耍弄,愚弄,诈骗,欺骗,蒙,欺瞒",
"duplex":"a:双,倍加,复式",
"duplicate":"v:复制,重复,复写;n:副本,复制品,复本;a:倍加,复本,重",
"duplicating":"v:转录,复印",
"duplication":"n:重复,复制,重叠;v:复写,重复,复制",
"duplicator":"n:复印机",
"duplicity":"n:口是心非,重复,奸诈",
"durable":"a:耐久,耐用,持久,经久,耐,耐穿,皮实,结实,牢",
"durable goods":"n:耐用品",
"durably":"d:持久",
"durance":"n:持续,监禁",
"duration":"n:持续,宽度,持久,期间,龄,时值",
"duress":"n:强制,胁迫,强迫,监禁",
"during":"p:期间,其间;n:其间",
"dusk":"n:黄昏,暮色,薄暮,擦黑儿,垂暮,晚半晌,下晚儿,荫,昏;v:昏",
"dusky":"a:昏暗,昏黑,灰蒙蒙,黑糊糊",
"dust":"n:灰尘,尘土,尘埃,粉尘;v:蒙蔽",
"dust coat":"n:外罩,风衣",
"dust cover":"n:护封,书皮,防尘罩",
"dust devil":"n:沙柱,沙暴",
"dust jacket":"n:护封",
"dustbin":"n:垃圾箱",
"duster":"n:掸帚,掸子,除尘器,喷粉器,清洁工",
"dusting":"n:打扫,鞭打,撒布,颠簸",
"dustman":"n:清洁工,瞌睡虫,火夫",
"dustpan":"n:簸箕,箕,畚箕;v:扶箕",
"dutch":"a:荷兰",
"duties":"n:税捐,职务",
"duty":"n:职责,责任,职务,义务,任务,职守,关税,税,本分,重任,负荷,班,责,职,孝顺,职能,义,尊敬,兵役,功,勤,守备,敬意,勤务,职掌,礼拜,职分,功课,庶务;v:职掌",
"duvet":"n:羽绒被",
"dwarf":"n:矮子,侏儒,矬子",
"dwarfism":"n:矮小",
"dwell":"v:居住,住居,栖止,踌躇,停顿;n:间歇,延长",
"dweller":"n:居民",
"dwelling":"n:住处,住宅,居住,寓所;v:停止",
"dwelling house":"n:住宅",
"dwindle":"v:减少,缩小,消失,退化,减小,衰落,消灭",
"dwindle away":"v:消灭,消失",
"dyad":"n:双方",
"dye":"v:染,染色,染上,着色;n:色调",
"dye-works":"n:染坊",
"dyeing":"n:染色,染色法;v:染色",
"dyestuff":"n:染料,染色剂,颜色,颜料",
"dying":"a:临终,垂死,不行,切盼,渴望",
"dynamic":"a:能动,力度,活跃,轰轰烈烈;n:动态,动力",
"dynamics":"n:力学,动力,原动力,动态,力度,动力学",
"dynamism":"n:精力,劲头,活力,魄力",
"dynamite":"v:爆破;n:炸药",
"dynamiter":"n:爆破手",
"dynamo":"n:发电机",
"dynasty":"n:王朝,朝代,皇朝,朝,代",
"dysentery":"n:痢疾,痢",
"dysfunction":"n:失灵,损坏;v:损坏,失灵",
"dyspepsia":"n:食积",
"dysprosium":"n:镝",
"e":"n:鄂",
"e.g.":"d:例如",
"each":"r:每;a:人,各;n:人;d:一一",
"each other":"r:互相,彼此,相互,相,交",
"eager":"a:急切,心切,切;n:潮",
"eagerly":"d:眼巴巴;a:渴",
"eagerness":"n:渴望,热情,热忱,殷切",
"eagle":"n:鹰,雄鹰,老鹰",
"eagle ray":"n:鲼",
"ear":"n:耳朵,耳,听觉,注意,倾听,听力,麦穗,穗;v:抽穗",
"ear hole":"n:外耳门",
"eardrum":"n:鼓膜,耳鼓,耳膜",
"earful":"n:训斥,怨言",
"earl":"n:伯爵,伯",
"earlier":"d:先",
"earliest":"d:早",
"earliness":"n:早期,早,早熟",
"earlobe":"n:耳垂",
"early":"d:早;a:早期,早",
"early days":"n:前期",
"earmark":"n:标记,特征;v:标志",
"earmuff":"n:耳套",
"earmuffs":"n:护耳",
"earn":"v:挣,赚,收入,赢得,获得,博得,赚取,创收,创获;n:生财",
"earnest":"a:认真,热心,诚恳,恳切,诚挚,严肃,踏实,真诚;n:诚挚,定钱,预兆,保证金;d:正经八百",
"earnest money":"n:定金,定钱",
"earnestly":"d:切切,切实",
"earnestness":"n:诚,热心,真挚",
"earning":"v:收入",
"earnings":"n:收入,利润,赢利,工资,报酬,收缩,所得,收益;v:收缩",
"earphone":"n:耳塞,耳机,听筒",
"earplug":"n:耳塞",
"earring":"v:抽穗;n:耳环",
"earrings":"n:耳环,耳坠子",
"ears":"n:灯花",
"earsplitting":"a:震耳欲聋;v:震耳欲聋",
"earth":"n:地球,大地,地面,泥土,世界,土,地上,土壤;v:下世",
"earth up":"v:培",
"earthen":"a:陶;n:瓦",
"earthenware":"n:陶器,陶",
"earthiness":"n:土性,土质",
"earthing":"n:接地;v:接地",
"earthling":"n:世人,人类",
"earthquake":"n:地震,震,动乱,地动",
"earthshaking":"a:翻天覆地,惊天动地",
"earthwork":"n:土方,土堤",
"earthworm":"n:蚯蚓,曲蟮,蚓,小人",
"earwax":"n:耳垢,耵聍,耳屎",
"ease":"n:自在,轻松;v:放松,减缓,散心",
"ease off":"v:缓和,放松",
"ease up":"v:放松,散心",
"easel":"v:放松;n:画架",
"easement":"n:便利,减轻,缓和,解除,使用权,舒适",
"easily":"d:容易,轻易,易于,动不动,便,顺利,动辄,动,多半,安逸,一动,远远,顺顺当当,悠然,流畅;v:动",
"easiness":"n:容易,安逸,温和,从容,安乐",
"easing":"n:屋檐;v:屋檐",
"east":"n:东方,东,东部,东风,东边,东面,东头;a:左",
"east africa":"n:东非",
"east timor":"n:东帝汶",
"easter":"n:复活节,大风",
"easter day":"n:复活节",
"easterly":"n:东风;a:东",
"eastern":"a:东方,东",
"eastern hemisphere":"n:东半球",
"easting":"n:东方",
"eastward":"n:东方",
"easy":"a:容易,易,大方,安逸,安心,轻巧,便利,浅,便当,平易,浅明,顺顺当当,宽慰,清爽;n:老好人;d:安然",
"easy chair":"n:安乐椅",
"easy going":"n:顺遂,随和",
"easy mark":"n:傻瓜,糊涂虫",
"eat":"v:吃,吃饭,食物,用,喝,腐蚀,食,食用,进食,蛀,餐,进,吃喝,发怒,唼,生气,消磨,吞灭,茹,饵,消耗;n:餐,食物",
"eat away":"v:腐蚀",
"eat in":"v:腐蚀",
"eat into":"v:蛀",
"eat up":"v:消耗,吞灭",
"eatable":"n:吃食,食品,食物;v:食物",
"eatables":"n:食物,吃食",
"eatery":"n:餐馆",
"eating":"v:吃,食物",
"eating house":"n:饮食店,食堂,餐馆,馆子,饭铺",
"eats":"n:食物",
"eave":"n:屋檐",
"eaves":"n:屋檐,檐,檐子,宇,房檐",
"eavesdrop":"v:偷听,窃听",
"eavesdropping":"v:偷听",
"ebb":"v:减退,落潮,落槽,退潮,衰退,退;n:落潮,衰落",
"ebony":"n:乌木",
"ebullience":"n:沸腾,奔放,起泡;v:沸腾",
"ebullition":"n:迸发,沸腾;v:沸腾",
"eccentric":"a:古怪;n:怪癖,偏心轮;v:腐蚀",
"eccentricity":"n:怪癖,反常,偏心",
"ecclesiastic":"n:牧师",
"ecclesiastical robe":"n:法衣",
"echelon":"n:梯次,梯队,集团",
"echinoderm":"n:棘皮动物",
"echo":"v:呼应;n:摹仿,重复",
"eclipse":"n:日蚀,蚀;v:蚀,超越,超拔",
"eclipsing":"v:遮蔽",
"ecliptic":"n:黄道",
"eclogue":"n:田园诗,牧歌",
"ecology":"n:生态学,生态",
"economic":"a:经济",
"economical":"a:经济,节俭,俭朴,俭约,克己,俭省,约,仔细",
"economics":"n:经济学,经济",
"economize":"v:节约,节省,厉行节约,节,撙,省,缩;n:节",
"economizer":"n:节油器",
"economy":"n:经济,节约,秩序,组织;v:节约",
"economy class":"n:经济舱",
"ecstasy":"n:狂喜,出神,入迷,销魂",
"ectopic pregnancy":"n:宫外孕",
"ecuador":"n:厄瓜多尔",
"ecuadorian":"n:厄瓜多尔",
"eczema":"n:湿疹,湿气",
"eddy":"n:旋涡,涡流,漩涡;v:旋转",
"edema":"n:水肿;v:浮肿",
"eden":"n:乐园,伊甸园",
"edge":"n:边缘,边,边界,尖锐,刀刃,沿;v:促",
"edge in":"n:插身,插话",
"edge tool":"n:利器",
"edgewise":"n:沿边;d:沿边",
"edginess":"n:紧张,锋利",
"edging":"n:镶边,边缘,边材,滚边;v:镶边",
"edible":"a:食用;n:食品,食物;v:食用,食物",
"edibles":"n:吃食,食物",
"edict":"n:法令,敕,布告,命令",
"edification":"n:开导,启发,建筑物,教诲,教导",
"edifice":"n:建筑,大厦,建筑物,体系,结构",
"edify":"v:启发,建筑,教导,教诲,训导,开导,熏陶",
"edinburgh":"n:爱丁堡",
"edison":"n:爱迪生",
"edit":"v:编辑,主编,编,剪辑,校订,编排,订正,评阅;n:辑,社论,编辑,校订",
"editing":"v:编辑",
"edition":"n:版本,本,版,本子",
"editor":"n:编辑,编者,主编,主笔,编辑器",
"editor in chief":"n:主编,主笔",
"editorial":"n:社论,社评",
"editorial department":"n:编辑部",
"educate":"v:教育,培养,培植,训练,造,教训,育,教导,教养,陶,调教,栽培,教化;n:教养",
"education":"n:教育,训练,教学,教养,教育学,培养,饲养,文化,训导,陶",
"educationist":"n:教育家",
"educator":"n:教育家",
"educe":"v:唤起,演绎,引出,离析,推断",
"eduction":"n:析出,离析,抽出,推断,引出;v:引出,离析",
"eel":"n:鲡,鳗,鳗鲡,鳝鱼,白鳗,鳝",
"eeriness":"n:神秘,可怕",
"efface":"v:忘却,磨,抹煞,漠视,隐退,擦掉,磨灭",
"effacement":"n:擦掉",
"effect":"n:效应,作用,效果,结果;v:引起,达到,招致,导致,造成",
"effecting":"v:产生",
"effective":"a:有效,管用,管事,灵验",
"effectively":"d:实际上",
"effectiveness":"n:效率,有效,有生力量,效益,效用,有力",
"effector":"n:感受器",
"effectual":"v:行之有效;a:行之有效",
"effectually":"d:实际上",
"effectuate":"v:贯彻,实行,完成,实现",
"effeminacy":"n:娇气,柔弱",
"effeminate":"a:柔弱",
"effendi":"n:权贵,学者,先生,阁下",
"efferent":"n:传出神经",
"efferent nerve":"n:传出神经",
"effervesce":"v:兴奋,冒泡",
"effervescence":"n:冒泡,活泼",
"effervescent":"a:生气勃勃;v:生气勃勃",
"efficacious":"a:灵验,有效,管事,管用",
"efficacy":"n:效力,效用,证验,功力,生产率,效能,功效,效验,功",
"efficiency":"n:效率,效能,功效,能力,性能,有用功,生产率,效果,生产能力,效用,实力,效",
"efficient":"a:得力",
"effigy":"n:像,雕像,画像,肖像",
"efflorescence":"n:全盛,斑疹,开花,疹,风化,盐霜,结果",
"effluence":"n:放出,发出,放射,流出;v:放射,发出",
"effluent":"n:废水,污水,支流",
"effluvium":"n:恶臭,臭气",
"effort":"n:努力,工作,尽力,尝试,成就,气力,全力,力气,运动,雄辩,作用力,张力,周章,杰作",
"effrontery":"n:厚颜无耻,放肆",
"effulgence":"n:灿烂,光辉",
"effulgent":"a:绚",
"effuse":"v:流出,发出,吐露",
"effusion":"n:流出,显露,流血,流露,渗出,抒发,吐露,喷发,溢出;v:流出,渗出",
"effusive":"v:溢于言表;a:溢于言表",
"egalitarianism":"n:平均主义",
"egg":"n:鸡蛋,蛋,卵,卵子;v:撺弄,纵容",
"egg on":"v:纵容,撺掇,撺弄",
"egg roll":"n:蛋卷,春卷",
"egg white":"n:蛋青",
"egg yolk":"n:蛋黄",
"egghead":"n:秀才,理论家",
"eggplant":"n:茄子,茄",
"eggshell":"n:蛋壳",
"ego":"n:自私;r:自我",
"egocentricity":"n:利己",
"egoism":"n:利己主义",
"egoistic":"a:自私自利;v:自私自利",
"egos":"n:利己主义,自我",
"egotism":"n:自负,自私自利,利己主义,自高自大,唯我主义,自大",
"egotistic":"v:纵容,自私自利;a:自私自利",
"egregiousness":"n:非常",
"egress":"n:出口,外出;v:外出",
"egret":"n:白鹭,鹭鸶,鹭",
"egypt":"n:埃及",
"egyptian":"n:吉普赛",
"eh":"i:哎,啊",
"eiderdown":"n:鸭绒,鸭绒被",
"eigenvalue":"n:特征值",
"eight":"a:八,捌",
"einstein":"n:爱因斯坦",
"einsteinium":"n:锿",
"either":"c:或;r:二者;d:也",
"eject":"v:弹射,驱逐,逐出,喷射,排出,发射,排,喷发;n:投射",
"ejecta":"n:渣,废物",
"ejection":"n:喷射,逐出,喷发,发射,排出,推出",
"ejector":"n:发射器",
"eke":"v:补充;a:增加,补充;d:也,又",
"elaborate":"v:阐述,推敲,铺陈,铺叙,发挥;a:详密",
"elaborately":"d:精心",
"elaborateness":"n:费神",
"elaboration":"n:推敲,精巧,苦心经营,铺叙",
"elan":"n:干劲",
"elapse":"v:过去,经过,流逝,逝去,消失,推移,消逝,迁流;n:消逝",
"elastic":"n:松紧带;a:伸缩,活泛;v:弹,伸缩",
"elastic band":"n:皮筋儿,橡皮筋,橡皮圈",
"elasticity":"n:弹性,伸缩性,灵活性,松紧,弹力",
"elate":"v:鼓舞",
"elated":"a:高昂,高兴,兴高采烈,欢畅;v:喜欢,快意,扬扬自得;n:兴奋,快意;d:扬扬自得",
"elation":"n:得意,振奋,得意洋洋,兴高采烈",
"elbow":"n:肘部,肘,胳膊肘,扶手,曲折,急弯,肘子,胳膊肘子,胳膊肘儿,拐脖儿",
"elbow grease":"n:苦干,重活",
"elbow joint":"n:肘关节",
"elder":"n:长辈,长者,长老,前辈;a:长,年高,年长",
"elders":"n:尊亲",
"eldest":"a:大,长",
"elect":"v:选举,选,决定,推举,推选,推,举",
"election":"n:选举,当选,选择;v:选举,选择",
"electioneer":"v:竞选",
"elective course":"n:选修课",
"elector":"n:选民",
"electorate":"n:选民,选区",
"electric":"n:电气",
"electric arc":"n:电弧",
"electric battery":"n:电池",
"electric cell":"n:电池,光电管",
"electric chair":"n:电椅",
"electric clock":"n:电钟",
"electric drill":"n:电钻",
"electric eye":"n:光电管,光电池",
"electric furnace":"n:电炉",
"electric heater":"n:电炉",
"electric meter":"n:电表,电度表",
"electric motor":"n:电滚子",
"electric potential":"n:电势",
"electric range":"n:电灶",
"electric resistance":"n:电阻",
"electric shaver":"n:电须刀",
"electric shock":"n:触电",
"electric switch":"n:开关",
"electrical":"a:电气;n:电气",
"electrical condenser":"n:电容器",
"electrical engineering":"n:电工",
"electrician":"n:电工",
"electricity":"n:电,电流,电学,紧张,强烈,静电,电荷,热心",
"electrification":"n:充电,电化,电气化,激动,带电;v:带电",
"electrified":"v:带电",
"electrify":"v:电气化,通电,带电",
"electrocardiogram":"n:心电图",
"electrochemical":"a:电化",
"electrocution":"n:电刑",
"electrode":"n:电极,焊条",
"electroencephalogram":"n:脑电图",
"electrolysis":"v:电解;n:电解",
"electrolyte":"n:电解质,电解液",
"electrolytic":"a:电解质;n:电解质",
"electrolyze":"v:电解",
"electromagnet":"n:电磁铁",
"electromagnetic radiation":"n:电磁辐射",
"electromagnetic wave":"n:电磁波",
"electromagnetism":"n:电磁学,电磁",
"electromechanical":"a:机电",
"electromotive force":"n:电动势",
"electron":"n:电子",
"electron gun":"n:电子枪",
"electron optics":"n:电子光学",
"electron volt":"n:电子伏特",
"electronic computer":"n:电脑",
"electronic organ":"n:电子琴",
"electronics":"n:电子,电子学",
"electrophoresis":"n:电泳",
"electroplate":"v:电镀",
"electroplating":"v:电镀",
"electroscope":"n:验电器",
"electrostatics":"n:静电学",
"elegance":"n:雅致,精致,大雅",
"elegant":"a:讲究,风雅,典雅,文雅,清雅,雅致,精美,闲雅,雅,郁郁,飘逸,文,秀美,秀,秀气,婉,翩翩",
"elegy":"n:挽词,哀歌,挽歌,挽诗,悲歌",
"element":"n:元素,元件,单元,元,因素,要素,部分,成分,素,分子,电池,分队,大纲,单体,原理,原种,零件,初步,电极",
"elementary":"a:基本,初等,初级,起码,初,低级",
"elementary school":"n:小学,完小",
"elements":"n:自然力",
"elephant":"n:大象,象",
"elephantiasis":"n:肿大",
"elephantine":"a:庞大",
"elevate":"v:鼓舞,抬高,提升,举起,升降,提拔",
"elevated":"a:高架",
"elevation":"n:高度,海拔,仰角,高程,上升,高地,高处,标高,升级,正面图,挺起,高举,高升,上进,高尚,向上,正视图,主视图;a:高尚",
"elevator":"n:电梯,升降舵,谷仓,升降机;v:电镀",
"eleven":"n:球队",
"elf":"n:恶人,矮子,灵,淘气鬼,小人",
"elicit":"v:得出,引出",
"elicitation":"n:引导,启发,引出;v:引出",
"elide":"v:删节,取消,忽略,削减,省略",
"eligibility":"n:合格",
"eliminate":"v:消除,排除,消灭,淘汰,干掉,排出,除去,刷,肃清,消泯,除,根绝,蠲,芟,消,根除,肃,逐出,清除,洗,治,清洗,屏除,清剿,锄,汰",
"elimination":"n:消除,消灭,排除,淘汰,淘汰赛,除去,消散,弃置;v:消散",
"elision":"n:删节,省略",
"elite":"n:精英,精华,核心",
"elitist":"a:高贵",
"elixir":"n:灵丹妙药,酏剂,仙丹,酏",
"elizabeth":"n:伊丽莎白",
"elizabethan":"n:剧作家",
"elk":"n:麋,驼鹿",
"ellipse":"n:椭圆,椭圆形",
"ellipsis":"n:省略;v:省略",
"ellipsoid":"n:椭球,椭圆,椭面,椭圆体",
"ellipsoidal":"a:椭圆体",
"elliptic":"a:椭圆",
"elm":"n:榆树,榆木,榆",
"elongate":"v:拉长,伸长,延伸,引出,延长",
"elongation":"n:伸长,延长;v:伸长",
"elope":"v:私奔,逃亡,奔,出走,逃走",
"elopement":"v:私奔;n:私奔",
"eloquence":"n:雄辩,口才,修辞,辩才,谈锋,唇吻",
"eloquent":"a:意味深长,伶牙俐齿,口若悬河,利;v:意味深长",
"else":"d:其他;a:旁;r:其它,其他;n:旁",
"elsewhere":"r:他;d:别处",
"elucidate":"v:说明,阐明,释,阐发,解释",
"elucidation":"n:说明",
"elude":"v:躲避,难倒,逃避,闪避,避免",
"elusive":"a:不可捉摸;v:不可捉摸",
"elysian fields":"n:极乐世界",
"elysium":"n:福地",
"emaciate":"v:消瘦,减少,减弱,衰弱",
"emaciated":"v:枯瘦,瘦瘠,瘦弱,鸠形鹄面,消瘦,瘦;a:枯瘦,消瘦,瘦瘠,瘦弱,瘦",
"emaciation":"n:消瘦,瘦弱;a:消瘦",
"emanate":"v:放射,发散,发源,起源,拉长,发出;n:发散,发出",
"emanation":"n:放射;v:放射",
"emancipate":"v:解放,解脱",
"emancipation":"n:解放,解脱",
"emancipator":"n:救星",
"emasculate":"v:阉割,去势,去雄,减弱",
"emasculation":"n:去雄,柔弱,阉割,去势",
"embalm":"v:防腐,铭记",
"embank":"v:筑堤",
"embankment":"n:堤岸,路堤,堤,堤防,子堤,防,塘,坝,筑堤",
"embargo":"n:禁运,禁止,限制;v:禁止,禁运,停止,封",
"embark":"v:开始,从事,装载,登机,载,装货,装",
"embarkation":"n:乘船,装载;v:装载",
"embarrass":"v:为难,妨碍,窘,窘迫,阻碍,将军,捉弄,过不去;n:将军",
"embarrassed":"a:难为情,不好意思,窘迫,尴尬,窘,困窘,难堪,羞涩,羞赧",
"embarrassing":"a:难为情,难看;n:不好意思",
"embarrassment":"n:困窘,窘迫",
"embassy":"n:大使馆,使馆,差使,使节,馆",
"embed":"v:嵌入,植入,栽种,装入",
"embedding":"v:植入",
"embellish":"v:修饰,美化,润色,雕琢,装饰,润,修,缀,点缀",
"embellishment":"n:藻",
"ember":"n:余烬",
"embers":"n:余烬",
"embezzle":"v:盗用,贪污,中饱私囊,舞弊,监守自盗,挪用,侵吞,克扣,盗取,吞没",
"embezzlement":"n:贪污,舞弊,墨;v:贪污",
"embezzler":"n:贪污犯",
"embitter":"v:加重,激怒",
"emblazon":"v:装饰,颂扬",
"emblem":"n:标志,符号,类型,徽章,会标,标记,典型;v:标志,象征",
"emblematic":"a:象征性",
"embodiment":"n:化身,体现,统一体",
"embody":"v:体现,包括,表达,包含,收录,收编,归并,含蓄",
"embolden":"v:壮胆,鼓舞,鼓励",
"embolism":"n:栓塞",
"embossing":"v:轧花",
"embouchure":"n:河口",
"embower":"v:围绕",
"embrace":"v:拥抱,包括,接受,怀抱,信奉,包含,环绕,围绕,搂,抱,看出,交媾,交配,囊括;n:接受,包含,领会,交尾",
"embrasure":"n:炮眼,枪眼",
"embroider":"v:绣花,绣,刺绣,修饰,扎花,添枝加叶,润色",
"embroiderer":"n:刺绣工",
"embroidery":"n:刺绣,绣,绣花,绣品,修饰,黹,绣房,粉饰,刺绣品,润色",
"embroil":"v:卷入,卷,搅乱,牵连",
"embryo":"n:胚,胚胎,雏形,胎,胎儿,胚芽",
"embryology":"a:胎生学;n:胚胎学",
"emcee":"n:司仪;v:主持",
"emend":"v:校正,校勘,校订,订正,改正",
"emendation":"n:校订,增删,校勘,订正,修改;v:校勘,增删",
"emerald":"n:绿宝石,翡翠,祖母绿,鲜绿色;a:翠绿",
"emerge":"v:出来,出现,产生,显露,暴露,展现,诞生,呈现,浮现,脱颖而出,涌,发生,出苗,露头,现出",
"emergence":"n:出现,发生,浮现,羽化;v:羽化",
"emergency":"n:急诊,应急,事变,缓急,急症,燃眉之急,急事;a:急",
"emergency exit":"n:太平门",
"emergent":"a:紧急,急",
"emery":"n:金刚砂",
"emery wheel":"n:砣子",
"emetic":"n:催吐剂",
"emigrant":"n:移民,侨民;a:移居",
"emigrate":"v:移居,移民,出境,迁出,侨居",
"emigration":"n:移民,侨居",
"emigre":"n:移民,逃亡者",
"eminence":"n:显赫,要职,出众;v:隆起",
"eminent":"a:显赫,卓,头角峥嵘,卓然,卓著,达,卓跞;v:头角峥嵘,达",
"emir":"n:酋长",
"emirate":"n:酋长国",
"emissary":"n:密使,使者,间谍",
"emission":"n:发射,散发,排放,放射,发出,传播,排出,发行,遗精;v:放射,发射",
"emission spectrum":"n:发射光谱",
"emissivity":"n:发射率,放射性",
"emit":"v:发射,发出,出,发,散发,放射,放出,发表,冒,遗精,颁布,发行,流泻,吐露,放",
"emitter":"n:发射极,发射器,辐射源",
"emmet":"n:蚂蚁",
"emolument":"n:报酬,津贴,薪水,禄,薪金",
"emotion":"n:感情,激动,情感,情绪,感,感动",
"emotionalism":"n:多愁善感",
"emotionality":"n:激动",
"emotionalize":"v:感情用事,动感情",
"empathize":"v:移情",
"empathy":"n:移情,同感",
"emperor":"n:皇帝,帝王,皇上,圣,大帝,帝,官家,皇,帝君,天王,驾",
"emphasis":"n:强调,重点,注重,加强,着重,显著,重要性,偏重,鲜明",
"emphasise":"v:强调",
"emphasize":"v:强调,着重,注重,抓,偏重",
"emphysema":"n:肺气肿",
"empire":"n:帝国",
"empiric":"n:庸医",
"empiricism":"n:经验主义",
"empiricist":"n:庸医",
"emplacement":"n:炮位,位置,安放;v:安置",
"employ":"v:雇用,使用,采用,雇,用,聘请,使,录用,雇佣;n:职业",
"employee":"n:雇员,雇工,工作证",
"employer":"n:雇主",
"employment":"n:工作,职业,雇用,使用,雇佣,业,利用,活儿,消遣",
"emporium":"n:商场,商城",
"empower":"v:授权,准许",
"empress":"n:皇后,女皇,皇太后,娘娘,女王,后",
"emptiness":"n:空虚,空,无能,虚;a:虚",
"empty":"a:空;v:腾出;n:徒,空车",
"empty talk":"n:言之无物,空论,空话,空谈",
"empty words":"n:空话",
"empty-handed":"a:空手;v:妙手空空",
"emptying":"v:放空",
"empyrean":"n:天空,太空,苍穹,苍天",
"emu":"n:鸸鹋",
"emulate":"v:仿真,比,仿效;a:仿真",
"emulation":"n:仿真,仿效,竞赛,竞争;a:仿真",
"emulator":"n:竞争者,仿真器,模拟器",
"emulsification":"v:乳化;n:乳化",
"emulsify":"v:乳化",
"emulsion":"n:乳剂,乳胶,乳液,乳浊液",
"en":"n:用,像,授权",
"en bloc":"n:全体,总共",
"en masse":"n:一起",
"en route":"a:途中,路上",
"enable":"v:使,允许,启动,使得",
"enabling":"v:启动",
"enact":"v:颁布,规定,扮演,制定,演出",
"enactment":"n:法律,法规,法令,上演,条例,颁布,制定",
"enamel":"n:搪瓷,釉质,珐琅质,珐琅,洋瓷;v:烧蓝,烤蓝;a:搪瓷",
"enameling":"v:烧蓝",
"enamor":"v:迷恋",
"encamp":"v:安营,扎营,驻,露营",
"encampment":"n:营地,宿营,扎营,野营,驻地,露营",
"encapsulate":"v:压缩",
"encapsulating":"v:封装",
"encapsulation":"n:封装",
"encase":"v:包装,围绕,装箱",
"encasement":"n:装箱,包装",
"encephalitis":"n:脑炎,大脑炎",
"enchain":"v:链,束缚",
"enchant":"v:迷住,蛊惑,迷",
"enchanting":"a:迷人,俏生生;v:引人入胜",
"enchantment":"n:魅力,着迷,妖术,迷惑",
"enchantress":"n:女巫",
"encipher":"v:加密,制定",
"encircle":"v:包围,环抱,环,环绕,拱,圈,合围,围绕,困;n:内切圆",
"encirclement":"n:环绕",
"enclave":"n:飞地",
"enclose":"v:附上,附,围,圈,装,密封,围住,包裹,围绕,包,包围,遮蔽;n:附笔",
"enclosed":"v:封闭式",
"enclosure":"n:围栏,围墙,附件,空间,围绕,封装,隔离;v:封装,隔离",
"encode":"v:编码",
"encoded":"v:编码",
"encoder":"n:编码器",
"encoding":"v:编码",
"encomium":"n:颂词,称赞,赞美",
"encompass":"v:包含,包围,萦,贯彻,围绕,完成",
"encore":"n:重演",
"encounter":"v:遇到;n:遭际",
"encourage":"v:鼓励,助长,怂恿,支持,激励,鼓动,赞助,促进,提倡,劝,勉励,奖,策励,勖,徕,鞭策,激扬,钊,勉,打气,励,劭,兴,砥砺",
"encouragement":"n:鼓励,奖励,助长",
"encouraging":"a:激扬,振奋人心;v:振奋人心",
"encroach":"v:侵占,侵犯,侵蚀,侵害,蚕食,侵越,染指,侵略,侵入,侵袭,侵凌",
"encroach upon":"v:干犯,侵袭",
"encroachment":"n:侵占,侵害,侵犯,侵蚀,蚕食,侵入",
"encrypt":"v:编码",
"encryption":"n:加密",
"encumber":"v:妨碍,阻碍,拖累,打扰,烦扰",
"encumbrance":"n:累赘,阻碍;a:累赘",
"encyclical":"n:通告",
"encyclopedia":"n:百科全书",
"end":"n:结束;v:终了;d:已,终",
"end point":"n:终端",
"end product":"n:成品",
"end up":"v:死,告终,最后,收场,结束,阻碍,终结,终了",
"end-all":"n:终结,结尾",
"endanger":"v:危及,危害",
"endangerment":"n:危害",
"endearment":"n:亲爱,爱抚",
"endeavor":"v:力图,竭力,尽力,致力;n:钻劲,尽力",
"endeavour":"v:竭力,致力,力图",
"endemic":"n:地方病",
"ending":"n:结尾,结局,结束,词尾,结果,终止,最后,死,完事;v:终;d:终",
"endive":"n:苣荬菜",
"endless":"a:没完没了,无尽无休,无穷无尽,无尽,无穷,漫长;v:无尽无休,不已,无穷无尽,永无止境",
"endlessly":"d:不休,不已",
"endocrine":"n:激素,内分泌,内分泌腺",
"endorse":"v:赞同,批准,背书,签署,拥护,赞成,批转,签注,签收,批注,保证,承认,担保",
"endorsement":"n:背书,签注,赞同",
"endoscope":"n:内窥镜",
"endoscopes":"n:内窥镜",
"endothermic":"v:吸热;a:吸热",
"endow":"v:捐助,赋予,授予",
"endowment":"n:天赋,捐款,捐助,基金,天资,捐赠,才能,养老金,才,资,天才,天分",
"endowments":"n:天赋",
"ends":"n:粗纱,两端",
"endue":"v:赋予,穿上",
"endurable":"a:恒久",
"endurance":"n:耐力,耐性,忍耐,持久力,持久,耐劳,耐久;a:持久",
"endure":"v:忍受,受,容忍,忍耐,忍,持久,持续,支持,承受,挨,耐,熬,禁,续航,耐受,搁,堪,挺,咬紧牙关,磨难,茹,耐久,忍让,禁受;p:经",
"enduring":"a:持久",
"enema":"v:灌肠;n:灌肠",
"enemy":"n:敌人,仇敌,仇人,敌方,对头,强敌,敌国,冤家,敌手,仇家,敌寇,敌伪,寇仇,贼;a:时间",
"energetic":"a:有力,生气勃勃,积极,刚健,精神焕发,带劲,风发,起劲,盛,有劲,精神抖擞,上劲,雄健,奕奕;v:盛,生气勃勃",
"energetically":"d:大力,上劲,力,起劲;n:力",
"energize":"v:通电,激励,用力,接火,活动,加强",
"energizing":"v:激发",
"energy":"n:能量,能,能源,精力,活力,干劲,力,能力,劲,气力,生动,精,劲头;a:精;v:能",
"enervate":"v:削弱",
"enervated":"v:娇贵",
"enfant terrible":"n:莽汉",
"enfold":"v:抱,包,折叠,包裹,拥抱",
"enforce":"v:实施,迫使,实现,施行,厉行,强迫,坚持,强制,推行,严肃",
"enforcement":"n:实施,强制",
"enfranchise":"v:释放",
"engage":"v:答应,从事,啮合,保证,雇,交战,参加,订婚,聘请,请,雇用,约定,衔接,聘用,预定,约束,允诺,延,订约,经营,录用,接触,做,聘任,受聘,延聘,咬合,预约,束缚,延请,应承,定,定亲,聘",
"engagement":"n:订婚,婚约,约会,交战,债务,约定,义务,聘约,契约,职业,雇用,咬合,约束;v:订婚,交战,约束,接合",
"engels":"n:恩格斯",
"engender":"v:产生,造成,发育,酿成,成形,生殖,形成",
"engine":"n:发动机,引擎,机车,火车头,机器,蒸汽机,方法,机,手段,车头,机械,工具,轮机",
"engine driver":"n:司机,大车",
"engine room":"n:机房",
"engineer":"n:工程师,司机;v:制造",
"engineering":"n:工程,工程学,工,管理,工事,土木工程,操纵",
"england":"n:英国,英格兰",
"english":"n:英语,英文,英吉利,英军",
"english system":"n:英制",
"english walnut":"n:胡桃",
"engorge":"v:贪吃,狼吞虎咽",
"engorgement":"n:狼吞虎咽,充血,肿胀",
"engrave":"v:刻,镌刻,雕刻,印,铭刻,铭记,契,锓,印刷,镂,雕版,雕镌,勒,锲,錾,铭,牢记,锼,镌,刻字,镂刻,雕,刊刻",
"engraver":"n:雕刻师",
"engraving":"n:版画,雕刻,版刻",
"engross":"v:吸引,占用",
"engulf":"v:吞没,席卷,吞噬",
"enhance":"v:增加,增强,提高,加强,增进,长,发扬光大,夸张,宣扬",
"enhancement":"n:增强,增加;v:提高,放大",
"enigma":"n:谜,哑谜,闷葫芦",
"enigmatic":"a:莫测高深,阴阳怪气",
"enjoin":"v:命令,要求,禁止,嘱咐,诰,吩咐,告诫,责成,嘱",
"enjoy":"v:喜欢,玩,享受,欣赏,享有,喜爱,乐,享用,观赏,享,负,纳;a:受用",
"enjoyable":"a:欣喜,适意,写意;v:有意思",
"enjoyment":"n:享受,愉快,欣赏,享乐,乐事,享有,欢乐,乐,写意;v:享受",
"enlarge":"v:放大,扩大,扩充,详述,增大,扩展,扩张,肿大,扩,扩大化,斥,放,弘,加大,释放",
"enlargement":"n:放大,肿大,扩大,增大;v:增补",
"enlarger":"n:放大器",
"enlighten":"v:开导,开窍,启发,启蒙,照明,照耀,迪,教导,启",
"enlightened":"a:开明,开通,亮堂,亮,豁朗",
"enlightenment":"n:开导,启蒙,启发,启迪,启示,教化,启蒙运动,教益",
"enlist":"v:支持,入伍,参军,赞助,参加,协助,从军,招,招募,征召,投军,应募,征募,报名,募,偏袒,从戎,收罗,从征,列入,应征",
"enlistment":"n:入伍,征募,谋取,征兵,募兵",
"enliven":"v:活跃,搞活,抖擞",
"enmesh":"v:绊住,络",
"enmity":"n:敌意,仇恨,怨恨,仇,不和,嫌,嫌隙,嫌怨,冤仇,怨,憎恨;v:怨恨,怨",
"ennoble":"v:抬高",
"ennui":"n:无聊,厌倦",
"enormity":"n:巨大,庞大",
"enormous":"a:巨大,庞大",
"enormously":"d:极其,大大",
"enormousness":"n:巨大,庞大",
"enough":"d:够;a:够用;n:充足,满足,足够;v:足够",
"enquire":"v:调查,打听,询问,问讯,讯问",
"enquiry":"n:询问",
"enrage":"v:激怒,触怒,气,惹恼",
"enraged":"a:气冲冲,激愤",
"enrich":"v:丰富,充实,裕,浓缩;a:充裕",
"enrichment":"n:丰富",
"enrol":"v:吸收,招,编入,登记",
"enroll":"v:吸收,登记,招收,报名,入学,入伍,招,参军,录取,编入",
"enrollment":"n:注册,入学,登记,入伍,登记表",
"enrolment":"n:注册,登记",
"ensconce":"v:安放,隐藏,掩蔽,安置",
"ensemble":"n:整套,总体,剧团,全体,合唱,整体,合奏,文工团,重唱,歌舞剧,集合,重奏,合唱曲,全套",
"enshrine":"v:奉祀,收藏",
"enshroud":"v:掩盖,包藏,隐蔽",
"ensign":"n:少尉,军旗,团旗,徽章,标志",
"enslave":"v:奴役,征服,奴化,强制,奴,役使",
"enslavement":"n:奴役,束缚",
"ensnare":"v:诱捕,陷害,诱惑,绊住",
"ensue":"v:结果",
"ensure":"v:保证,确保,保,担保,保障,保险,务使",
"entail":"v:需要,限定,带来,引起,转给",
"entangle":"v:缠住,困恼,绊住,缭,萦,纠,连累,迷惑,绞",
"entanglement":"n:混乱,纠葛,缠住,为难,障碍物,纠纷,牵连",
"entente":"n:协约国,协约,协商,协定",
"enter":"v:进入,参加,进来,进,进去,开始,入,登记,加入,着手,记录,感到,提出,训练,出场,上场,占有,入学,申报,晋,参,上,编入,结成,录取,入会,写入,出台,登,构成",
"enter upon":"v:就,开始,着手",
"enteric fever":"n:伤寒",
"entering":"v:输入,进入",
"enteritis":"n:肠炎",
"enterprise":"n:企业,事业,进取心,计划,事业心,兴办,胆识,业,开创",
"entertain":"v:招待,款待,接受,请,容纳,怀抱,含有,待,答应,待承,飨,心怀,宴请,款",
"entertaining":"n:招待,款待;a:有趣",
"entertainment":"n:娱乐,招待,款待,宴会,文娱,应酬,招待会,余兴,游艺,游艺会,怀抱,采纳",
"enthalpy":"n:焓",
"enthral":"v:迷惑,迷住,奴役",
"enthrall":"v:迷住,奴役,迷惑",
"enthrone":"v:尊崇,崇拜",
"enthronement":"n:即位",
"enthuse":"v:热心",
"enthusiasm":"n:热情,热心,积极性,激情,热诚,干劲,意兴,兴头",
"enthusiast":"n:爱好者,迷",
"enthusiastic":"a:热情,热烈,热心,起劲",
"enthusiastically":"d:起劲,兴致勃勃,踊跃",
"entice":"v:诱,诱惑,怂恿,引逗,饵,纵容,啖,勾引,撩逗,引诱",
"enticement":"n:诱惑性,诱饵",
"entire":"a:整个,全部,全,完整,全面,举,终;n:整体,种马,通,全体,周,封套;d:终;v:举",
"entirely":"d:了,全,全然,根本,统统,满,截然,统;a:完全;v:统",
"entirety":"n:始终,全体,总体,全部,首尾,始末,完全,整体",
"entitle":"v:叫做",
"entitlement":"n:称号,权利",
"entity":"n:实体,统一体,本质,存在,实物,形体,形",
"entomb":"v:收殓,埋葬",
"entomology":"n:昆虫学",
"entourage":"n:周围,随员,随从,环境,亲随,左右",
"entrails":"n:内脏;a:脏",
"entrain":"v:夹带,产生,输送,导致,带走",
"entrainment":"v:带走;n:带走",
"entrance":"n:入口,门口,门,大门,出场,进口,口,开始,会费,起初,就职,入场费,上场门,学费,着手,进出口;v:迷住,入场,进入,就职",
"entrance examination":"n:高考",
"entrance hall":"n:门厅",
"entrant":"n:新生",
"entrap":"v:陷,坑害,陷入,坑,诱捕,俘获",
"entrapment":"n:俘获,截留;v:俘获",
"entreat":"v:恳求,求,请求,央求,哀求,恳,祈,对待,央,求告",
"entreaty":"n:恳求,请求,哀求",
"entree":"n:主菜",
"entrench":"v:盘踞,窃据,接近,固守,掘",
"entrenchment":"n:堑壕,战壕",
"entrepreneur":"n:企业家,承包人",
"entropy":"n:熵",
"entrust":"v:托,委托,托付,委,嘱托,赋予,寄,信托,央托,付托,拜托,嘱",
"entry":"n:通道,河口,记载;v:输入,进入",
"entwine":"v:绞,编,缠绕,捻",
"enumerate":"v:列举,举出,罗列,数,点,计算,枚举,数落,举,历数",
"enumeration":"n:点,细目,计算,详述,数,列举;v:列举,枚举",
"enunciate":"v:发音,发表,阐明,宣布",
"enunciation":"n:宣告,阐明,发表,口齿",
"enuresis":"n:遗尿症,遗尿;v:遗尿",
"envelop":"v:笼罩,包围,包,包裹,遮掩,包抄,笼,蔽,兜抄,封",
"envelope":"n:信封,封,外壳,信皮儿,纸袋,封皮,气囊,信皮,蒙皮,函",
"envelopment":"n:包围,封,封皮,封套,包",
"envenom":"v:毒害,毒化",
"envious":"a:热,眼馋",
"environ":"v:包围,围绕",
"environment":"n:环境,外界,周围,四周,围绕",
"environs":"n:郊区,近郊,城郊,附近",
"envisage":"v:设想,想像,想象,展望,观察,正视,面对",
"envision":"v:想像,展望,预见",
"envoy":"n:特使,使节,使者,专使,代表,公使,外交官;v:使",
"envoy extraordinary":"n:特使",
"envy":"v:羡慕;n:妒忌;a:艳",
"enzyme":"n:酶,酵素",
"eon":"n:永世,万古",
"epaulet":"n:肩章",
"ephedrine":"n:麻黄素",
"ephemeral":"n:朝露;a:朝露",
"ephemeris":"n:历书",
"epic":"n:史诗,叙事诗,诗史",
"epicenter":"n:震中,中心",
"epicentre":"n:中心,震中",
"epicure":"n:美食家",
"epicurean":"n:美食家",
"epidemic":"n:流行病,蔓延,流行,传播;a:传染病",
"epidemic disease":"n:瘥,疫疠,疫",
"epidermis":"n:表皮,皮面,浮皮儿,壳,外皮",
"epiglottis":"n:会厌,会厌软骨",
"epigram":"n:警句",
"epigraph":"n:碑文,墓志,引语,题字,铭文",
"epigraphy":"n:金石学,碑文,铭文",
"epilepsy":"n:癫痫,羊痫风,痫,羊角风,羊癫风",
"epilogue":"n:收场,后记,结论,尾声",
"epinephrine":"n:肾上腺素,肾上腺",
"epiphany":"n:出现,领悟",
"episcopacy":"n:主教",
"episode":"n:插曲,发作,幕,片段,插话;v:穿插",
"epistemology":"n:认识论",
"epistle":"n:书信",
"epitaph":"n:墓志铭,墓志",
"epitaxy":"n:外延",
"epithelium":"n:上皮组织",
"epithet":"n:称号,绰号",
"epitome":"n:缩影,摘要,节录,提要,梗概",
"epitomise":"v:象征",
"epitomize":"v:集大成,概括,象征",
"epoch":"n:时代,时期,纪元,世,期,纪,时世",
"epoch-making":"a:划时代",
"epoxy":"n:环氧树脂",
"epsom salts":"n:泻盐",
"epuration":"n:提纯",
"equal":"v:是个儿,均,对等;a:相同,同样,均等,当,均;n:对手",
"equal sign":"n:等号",
"equal to":"v:埒,当,匹敌",
"equaling":"v:均等,等于",
"equality":"n:平等,相等,等式,同等,一样,均等;v:相等",
"equalization":"n:均衡,均匀,相等,均等,平均",
"equalize":"v:均等,补偿,相等,调整",
"equalling":"v:均等",
"equally":"d:一样,平均,一律,并",
"equanimity":"n:平静,镇定,沉着",
"equate":"v:等同,划等号,等量齐观;a:均衡",
"equating":"v:均衡",
"equation":"n:方程,方程式,平衡,等式,差,相等,均衡,均匀;v:相等",
"equator":"n:赤道,圆",
"equatorial guinea":"n:赤道几内亚",
"equestrian":"n:骑手",
"equiangular":"a:等角;n:等角",
"equilateral":"n:等边;a:等边",
"equilibration":"n:平衡,均衡,对消,均势,相称;v:对消",
"equilibrium":"n:平衡,均衡,均势,稳定,不偏不倚,平静,均衡论,相称",
"equine":"n:马",
"equinoctial":"n:赤道",
"equinox":"n:春分,秋分点",
"equip":"v:装备,装有,训练,配备,整装,带有",
"equipage":"n:服饰,设备,随员,装备,马车,用具",
"equipment":"n:设备,装备,装置,器材,配备,配件,备,技能;v:备",
"equipoise":"n:相称",
"equipped":"a:整装",
"equitable":"a:合理,公平,公,平允,义",
"equitation":"n:骑马",
"equity":"n:股票,公正,股本,公平,对等,证券",
"equivalence":"n:等价,等值,等效,相等,同类,相当;v:等价",
"equivalency":"n:同等学历,同义,相当,当量,等值,均等,同类,等价,等效,相等",
"equivalent":"n:当量,等价;a:相等,等效;v:等效,等值",
"equivalent weight":"n:当量",
"equivocal":"a:模棱,含糊其词,暧昧;v:含糊其词",
"equivocate":"v:模棱两可,躲闪,支吾,拐弯抹角,推诿,含糊其词,支支吾吾",
"equivocation":"n:含糊其词;v:含糊其词",
"era":"n:时代,代,年代,纪元,时世,世",
"eradicate":"v:消灭,根除,根绝,破除,铲除,扑灭,除根,拔除",
"eradication":"n:根除,扑灭,消灭",
"erase":"v:擦,擦掉,消除,抹掉,删去,除去,抹,清除",
"eraser":"n:橡皮,橡皮擦,黑板擦,刮刀",
"erasure":"n:删去,擦掉,抹煞,抹掉;v:消音",
"erbium":"n:铒",
"ere":"p:在_以前,在_之前,之前,以前;c:与其",
"erect":"v:建立,竖起;a:直",
"erecting":"v:装配",
"erection":"n:直立,架设,建筑物,树立,建设,设立,装配",
"erectness":"n:竖起,建造",
"eremite":"n:隐士",
"erg":"n:尔格",
"ergo":"d:因此",
"ergot":"n:麦角",
"erie":"n:偷听",
"ermine":"n:貂皮,银鼠,貂",
"erode":"v:侵蚀,腐蚀,冲刷,蚀,毁坏,衰落,啮,剥蚀",
"eros":"n:精力,性欲,性爱,生命力",
"erosion":"n:侵蚀,糜烂,磨蚀;v:剥蚀,糜烂",
"erotic":"n:黄色",
"eroticism":"n:色情",
"err":"v:蹉,错,漫游",
"errand":"n:差事,差使,使命,差,口信",
"errant":"n:游侠",
"errata":"n:勘误表",
"erratic":"a:古怪;n:怪人",
"erratum":"n:勘误表,错误",
"erroneous":"a:错误,错,悖,谬,讹;n:讹舛",
"error":"n:错误,误差,差错,错,出错,过失,过,误,谬误,谬,偏差,舛,咎,阙,讹谬,差池,乖舛,误信,参差,纰缪,违法,不韪,讹误,非,谬见,谬种,误解,罪过;v:误",
"errors":"n:非",
"ersatz":"n:代用品",
"erst":"d:从前,往昔",
"erstwhile":"d:从前,往昔",
"eruct":"v:打嗝",
"eructation":"n:嗳气,打嗝儿",
"erudite":"a:渊博,奥博,渊深,饱学,博识,宏赡,博学,陆海潘江,博大,该博",
"erudition":"n:博学,学问,学识",
"erupt":"v:爆发,喷发,爆裂,迸发,涌出,暴发,勃发,大作",
"eruption":"n:喷发,爆发,疹,迸发,暴发,疹子",
"eruptive":"a:火成岩",
"erysipelas":"n:丹毒",
"erythrocyte":"n:红细胞,红血球",
"erythrocyte sedimentation rate":"n:血沉",
"escalate":"v:升级",
"escapade":"n:恶作剧,逃走,逃避",
"escape":"v:逃跑,逃走,逃脱,逃避,逃;n:出口,摆脱,逃亡",
"escape from":"v:逃脱,脱",
"escape hatch":"v:出路,办法",
"escape valve":"v:安全阀",
"escape velocity":"v:脱离速度",
"escapee":"n:逃亡者,逃犯",
"escapement":"n:出口,摆轮",
"escaping":"v:溢出",
"escapism":"n:空想,幻想",
"escarpment":"n:悬崖",
"eschew":"v:避免,避开",
"escort":"v:护送;n:警卫,护航舰",
"escrow":"n:证书",
"esophagus":"n:食道,食管",
"esoteric":"a:奥秘,秘传,秘事",
"esoterica":"n:秘书",
"espalier":"n:园艺",
"especial":"a:特别",
"especially":"d:特别,尤其,尤,格外,特,分外,特意",
"esperanto":"n:世界语",
"espionage":"n:间谍,谍报,监视,谍",
"esplanade":"n:广场,平地",
"espousal":"n:结婚,拥护,婚礼,支持",
"espouse":"v:信仰,拥护,采纳",
"esprit":"n:才智,活气",
"espy":"v:看见,发现,看出,窥见,窥探",
"esquire":"n:先生,地主,绅士,乡绅;v:护送",
"essay":"n:文章,论文,短文,小品文;v:企图",
"essayist":"n:散文家",
"essence":"n:本质,精华,实质,要素,精,精髓,精神,香料,香气,香精,质,本原,根本性,粹,精英,物;a:精",
"essential":"a:基本,要,主要,必要,必不可少;n:本性,必备;v:必需",
"essential condition":"n:必要条件",
"essentially":"d:基本上,本质,根本,本来,必定",
"essentials":"n:概要,纲要,要端,要点,要义,要领",
"establish":"v:建立,确定,制定,确立,成立,证实,设立,创办,创建,树立,安排,建,安顿,开辟,树,奠定,规定,开办,设,建设,创,创设,制,置,开设,奠,创立,缔造,立,安置,植,串联,缔结",
"established":"a:既定,成;v:定,公认",
"establishment":"n:建立,家庭,编制,学校,制度,确定,当局,企业,收入,设立,机关,开设,设置,研究所,定居,商店,定员,制定,创设,产业",
"estate":"n:财产,遗产,产业,庄园,房地产,所有权,财产权,阶层,地位;v:产",
"estate tax":"n:遗产税,财产税",
"esteem":"v:认为,尊重,尊敬;d:尚;n:敬意",
"ester":"n:酯",
"estimable":"a:难能可贵",
"estimate":"v:揣度,度,估量,核计,量,估,评断,出价,计量,判断,掂掇,估测,评估,测度,揣,揆度,尊重;n:预测,数值,估价单,估量,目测",
"estimation":"n:估计,尊敬,评价,判断,尊重,预算,意见,概算,测定",
"estonia":"n:爱沙尼亚",
"estrange":"v:隔离,离间",
"estrangement":"n:隔阂,隔膜",
"estrogen":"n:雌激素",
"estrus":"n:发情,发情期,动情",
"estuarine":"a:河口",
"estuary":"n:港湾,河湾,河口,江湾",
"et":"n:以及,外星人",
"etc":"d:等,等等,云云;r:什么的",
"etch":"v:蚀刻,腐蚀,描述,铭刻,刻划,浸蚀",
"etching":"v:腐蚀,浸蚀,蚀刻",
"eternal":"a:永恒,千古",
"eternal life":"n:永生",
"eternally":"d:万古,万古千秋",
"eternity":"n:永恒,永生,来世,万年;a:万年,不朽",
"ethane":"n:乙烷",
"ethanoic acid":"n:乙酸,醋酸",
"ethanol":"n:乙醇,酒精,醇",
"ether":"n:乙醚,醚,苍天,灵气",
"ethic":"n:伦理",
"ethics":"n:伦理学,伦理,道德",
"ethiopia":"n:埃塞俄比亚",
"ethiopian":"n:黑人",
"ethnology":"n:人种学",
"ethos":"n:风气,性格,气质",
"ethylene":"n:乙烯",
"etiology":"n:病因,病原,病源",
"etiquette":"n:礼节,礼仪,仪式,成规,礼数;v:礼节",
"etude":"n:练习曲",
"etymology":"n:词源,词源学,语源学",
"eucalyptus":"n:桉树,玉树,有加利",
"eucharist":"n:圣餐",
"euchre":"v:打败",
"eugene":"n:尤金",
"eugenics":"n:优生学",
"eulogise":"v:颂扬,赞扬",
"eulogist":"n:吹鼓手",
"eulogize":"v:称颂,赞美,称赞,讴歌,歌颂,颂,誉,赞扬,赞颂,颂扬",
"eulogy":"n:称赞,赞词,颂词,颂扬,赞颂,颂",
"eunuch":"n:宦官,太监,宦,阉人,阉宦,阉寺,阳痿;v:委托,信托",
"euphemism":"n:婉词,婉辞,婉言",
"euphemistic":"a:委婉",
"euphony":"n:悦耳,和谐",
"euphrates":"n:幼发拉底河",
"eurasia":"n:欧亚大陆",
"euro":"n:欧元",
"europe":"n:欧洲,欧",
"europium":"n:铕",
"eustachian tube":"n:咽鼓管,耳咽管",
"euthanasia":"n:安乐死",
"evacuate":"v:疏散,撤出,撤走,撤离,抽空,撤退,大小便,排泄,放空,腾出,撤",
"evacuation":"n:疏散,撤退,撤离,排泄物,排泄,放空,抽空,腾出",
"evade":"v:回避,逃避,避,避开,规避,躲避,避免,搪,逭,闪避,闪躲,避讳,辞,逃,漏,偷漏,搪塞,逃遁,逋,躲闪,推脱",
"evaluate":"v:评价,估计,估价,评估,评定,考评,评骘,作价,评说,品第",
"evaluation":"n:评价,估价,鉴定;v:鉴定,赋值",
"evanescence":"n:消散,消失,幻灭,瞬息",
"evangelize":"v:传教",
"evaporate":"v:蒸发,消失,汽化,破灭,跑,散失,挥发,跑墒,蒸,死亡,消灭,浓缩,发射",
"evaporated milk":"n:炼乳",
"evaporation":"n:蒸发,消散,浓缩;v:蒸发",
"evaporator":"n:汽化器",
"evasion":"n:逃避,偷漏,规避,回避",
"evasive":"a:闪烁;v:躲躲闪闪,拐弯抹角,闪烁",
"evasiveness":"n:推诿",
"eve":"n:前夕,前夜,关头",
"even":"d:也,甚至,都,连,更,还,更为,甚至于,即,乃至,就是;a:就是,双,匀和;c:尚且,乃至,甚或,即或,即使,即便,即若,哪怕,即令;n:亭,黄昏,偶数;v:平",
"even as":"c:正如,正当",
"even if":"c:就,哪怕,就算,纵然,纵令,纵;a:即使",
"even so":"c:虽然如此,即使如此",
"even though":"c:尽管,纵然,便,纵,纵使,即令,即或,纵令,即便,哪怕",
"even up":"p:取齐,匀,找齐,拉平",
"evenhanded":"a:公允",
"evening":"n:晚上,傍晚,晚,晚会,夜晚,黄昏,晚间,夜,晚年,下晚儿,末期,暮年,后晌",
"evening dress":"n:晚礼服,夜礼服",
"evening gown":"n:晚礼服",
"evenly":"d:平",
"evenness":"n:平等,平均,平坦",
"evensong":"n:黄昏",
"event":"n:事件,事情,大事,活动,项目,事变,动作,经历;c:故",
"eventful":"a:多事",
"eventuality":"n:不虞,万一,偶然性",
"eventually":"d:终于,最后,终,终究,到头来,终归,总归,终久,竟",
"eventuate":"v:起,发生,终归,结果",
"ever":"d:永远,要是,从,曾经,不断,老是,始终,到底,尝;r:多会儿;v:尝",
"ever since":"c:自从",
"ever so":"a:非常",
"everest":"n:珠穆朗玛",
"evergreen":"n:常绿树,万年青,常绿植物;a:常青",
"everlasting":"a:永恒,永久,经久不衰;n:无穷,永久,鼠曲草;v:天长日久",
"evermore":"d:永远,今后,始终,将来",
"evert":"v:颠覆,推翻,翻转",
"every":"a:每,一切,各,凡是,凡,各位,各家,诸;r:各个,各位,各,每,一切,诸",
"every so often":"d:不时,时常",
"every time":"c:一,每当,每逢",
"everybody":"r:人,大家,人人,大伙儿,各位,大伙,诸位;n:大家伙儿,人人,众人,人",
"everyday":"a:日常,每天,经常,见天;d:经常,每天,见天;n:见天,平日",
"everyman":"n:普通人",
"everyone":"r:每,大家,诸位,大伙,各人,各位,列位;n:人人",
"everything":"r:一切,万物,凡事,万事,一应;n:凡事,万事",
"everywhere":"d:到处;r:各地;n:遍地,四外;v:漫",
"evict":"v:驱逐,收回",
"eviction":"n:驱逐,收回",
"evidence":"n:证据,证明,根据,证词,证人,迹象,痕迹;v:显示,征",
"evident":"a:明显,显而易见,昭彰,焯,彰,昭著;d:显然",
"evidently":"d:显而易见,分明",
"evil":"n:罪恶,恶;a:奸;v:作恶",
"evil spirit":"n:妖怪,白虎星,祟,恶鬼,邪魔,魅,妖魔,煞,妖,妖精",
"evildoer":"n:坏人,妖孽,坏分子,奸人,歹徒",
"evildoers":"n:奸宄,妖魔鬼怪",
"evildoing":"n:恶行,坏事",
"evilness":"n:邪恶",
"evince":"v:表示,显示,表明",
"evocation":"n:唤起,召唤,招魂,引起",
"evoke":"v:引起,唤起,激起,勾,召唤,招致,移送",
"evolution":"n:进化,进化论,演化,发展,演变,形成,发生,发育,开展,放出,展开,开方,沿革;v:演变,展开,演进",
"evolutionism":"n:进化论",
"evolve":"v:发展,进化,演变,演化,放出,展开,制订,演,离析,进展,嬗,发出,推移,衍变",
"ex":"p:不,为,不包括,因,从,无,由;n:考试;v:考试",
"ex-husband":"n:前夫",
"ex-wife":"n:前妻",
"exacerbate":"v:恶化,加剧,愤慨,激怒",
"exacerbation":"n:恶化,加重;v:加重",
"exact":"v:索取,诛求,逼使,急需,强求,强制;a:正确",
"exacting":"a:苛",
"exaction":"n:勒索,强求",
"exactitude":"n:正确,精确,严格,精密,需要,严正",
"exactly":"d:就,正是,确切,正好,恰好,十分,究竟,恰恰,恰,正,整整,刚好,毫厘不爽,刚刚,就是,活,刚",
"exactness":"n:正确,精确度,需要",
"exaggerate":"v:夸大,夸张,夸大其词,言过其实,过甚,讦,张皇,张大,铺张,夸诞,张,侈,夸,渲染;a:张皇",
"exaggeration":"n:夸张,大言,水分",
"exalt":"v:激发,赞扬,高举,抬高,发扬,加强,褒奖,提高,提升,捧,升起",
"exaltation":"n:兴奋,得意,高举,晋升,精炼,升高,提拔",
"exalted":"a:高昂",
"exam":"v:考试;n:考试",
"examination":"n:考试,检查,检验,观察,试,调查,考察,审查,测验,审问,询问,检察,诊察;v:测验,考试,试,询问",
"examination paper":"n:试卷,考卷,考题,卷子,卷",
"examine":"v:检查,考察,研究,考,检验,观察,查看,测试,审查,诊察,查验,考查,调查,审问,剖析,察,问,考核,检视,查,稽,盘,审,验,甄,核查,稽核,检,剖,检点,查考,鉴,审议,核,推究,核实,考试",
"examiner":"n:考官,考生,检查员,主考官,检察官",
"example":"n:例子,榜样,实例,典型,事例,范例,例证,例,典范,模范,先例,例题,表率,样板,训,比方,样本,标杆,标兵;v:训",
"exasperate":"v:加剧,激怒,加重,触怒,愤激",
"exasperating":"a:可气",
"exasperation":"n:恼怒,愤激,愤怒,愤,恶化,加剧,激化",
"excavate":"v:挖,挖掘,发掘,开挖,掘开,凿,采掘,开掘,开凿,刨",
"excavation":"n:挖掘,发掘,挖方,洞,穴,出土文物,坑道,开凿",
"excavator":"n:挖掘机,挖土机,电铲,掘土机",
"exceed":"v:超过,过,逾越,高于,出乎,超出,凌驾,出,突出,越,领先,不止,超,胜过,似,优于,逾",
"exceeding":"d:极度,极端;v:超出;a:极度",
"exceedingly":"d:非常,极,极其,太,异常,杀,极度;v:不得了",
"excel":"v:擅长,超过,胜过,过人,精通,优于,逸,盖,突出,轶",
"excellence":"n:优秀,杰出,长处,优点,卓越,优越,卓绝",
"excellency":"n:阁下,美德",
"excellent":"a:优秀,优良,大好,优异,棒,绝妙,妙,高超,精良,精,没有说的,特异,优等,高强,秀,优,崭,顶呱呱,卓,徽,呱呱叫",
"excelsior":"n:精益求精",
"except":"p:除了,除;c:但是,只是,除非;n:以外,之外;v:除外",
"except for":"p:除了,除,除去,之外,除_以外,除外,以外,除_之外,除开",
"except that":"c:除了,不过,特",
"excepting":"p:除_外,外;c:要不是;v:除外",
"exception":"n:例外,反对,异议,除去,除外,不服",
"exceptional":"a:特殊,个别;d:特",
"exceptionally":"d:格外",
"excerpt":"v:摘抄;n:节录,选录,抽印",
"excerpts":"v:摘抄,摘记;n:摘录",
"excess":"n:超过,过剩,过度,多余;v:过剩,过量",
"excessive":"a:过,过度,过量,过分,溺,逾分,亢,奢,淫,浮,无度,溢;v:溢;d:过度",
"excessively":"d:过,过于,太;a:滥",
"exchange":"v:交换;n:贴水",
"exchange rate":"n:兑换率,外汇率",
"exchequer":"n:国库,财源,资金,金库",
"excise":"v:切除,割除,摘除,切开,切割;n:消费税",
"excision":"n:删除,切除,分割;v:分割",
"excitability":"n:兴奋性",
"excitation":"n:激发,激励,兴奋;v:激发,激励",
"excite":"v:兴奋,激动,引起,激发,激起,刺激,唤起,激励,鼓励,腾;a:激动",
"excited":"a:亢奋",
"excitedly":"d:兴奋,激昂;a:兴冲冲",
"excitement":"n:兴奋,激动,骚动,刺激,振奋,激昂;v:兴;a:激动",
"exciting":"a:兴奋,来劲,扣人心弦,热闹;v:激发,扣人心弦",
"exclaim":"v:惊叫,呼喊,惊呼,惊叹",
"exclamation":"n:呼喊,惊叫,叹词,感叹,感叹词",
"exclamatory":"a:感叹",
"exclude":"v:排除,排斥,拒绝,排挤,驱除,排,刨",
"excluding":"p:以外,除_外,之外,除_以外,除_之外,外;v:在外",
"exclusion":"n:排除,排斥,除去,杜绝,拒绝",
"exclusive":"a:排外",
"exclusive right":"n:专有权",
"exclusiveness":"n:排他性",
"exclusivity":"n:排他性,排外,拉山头,专有权",
"excommunicate":"v:开除,破门",
"excommunication":"n:逐出",
"excoriate":"v:苛责,呵斥,磨损,擦伤",
"excrement":"n:粪便,排泄物,矢,粪,屎",
"excrescence":"n:赘疣,瘤",
"excreta":"n:排泄物",
"excrete":"v:分泌,便溺,排泄,拆",
"excretion":"n:排泄物,分泌物,分泌,排泄;v:分泌",
"excruciation":"n:苦恼,拷问,酷刑,折磨",
"exculpate":"v:辩白,开脱",
"exculpation":"n:昭雪,开脱,辩白",
"excursion":"n:游览,离题,冲程;v:郊游",
"excursionist":"n:游客",
"excusable":"v:情有可原;a:情有可原",
"excuse":"n:借口;v:担待,表白,饶,饶恕,原宥,宽假",
"exec":"n:执行",
"execrate":"v:咒骂,憎恨,憎恶,诅咒,嫌恶,痛骂",
"execration":"n:憎恨,痛骂",
"execute":"v:执行,处死,处决,完成,实行,演,履行,实施,措,枪毙,奏,作成,贯彻,行刑,正法,执,施行,施",
"execution":"n:执行,完成,实行,演奏,履行,技巧,效果,正法;v:执行",
"executioner":"n:刽子手",
"executioners":"n:刀斧手",
"executive":"n:董事,州长,国王,总经理",
"executor":"n:执行者",
"exegesis":"n:注释,注疏,注解",
"exemplar":"n:典型,样本,标本,模范",
"exemplification":"n:范例,举例,例证,模范",
"exemplify":"v:概,示范;d:概",
"exempt":"v:免,豁免,赦免,免除,豁",
"exemption":"n:免税,免除,豁免",
"exercise":"n:运动,锻炼,练习;v:演习,操,操练,操演",
"exert":"v:施加,努力,用,发挥,施,竭尽,尽,卖力,卖力气,行使,使出",
"exertion":"n:努力,运用,行使,尽力",
"exes":"n:费用",
"exeunt":"v:退场",
"exfoliate":"v:剥落",
"exfoliation":"n:剥落",
"exhalation":"n:发泄,蒸发,薄雾,发散,喷发",
"exhale":"v:散发,渗出,发泄,乎,喷发,蒸发,呼,放出",
"exhaust":"v:耗尽,排气,疲惫不堪,枯竭,用尽;n:出口,抽空",
"exhaust fan":"v:抽风机;n:抽风机",
"exhaust valve":"v:排气阀",
"exhausted":"a:精疲力竭,筋疲力尽,精疲力尽,疲惫不堪,困乏,疲乏,疲顿,困顿,疲,累死,委顿,绝,乏,困惫,劳累;v:枯竭,绝,衰竭,疲惫",
"exhaustion":"n:精疲力尽,耗尽,枯竭,疲惫,引出,穷尽,劳瘁,用尽,抽空;v:引出,耗尽",
"exhaustive":"a:详尽,尽",
"exhibit":"v:展出,显示;n:证件,展",
"exhibition":"n:展览会,展览,显示,表演,陈列;v:显出,展览",
"exhibition hall":"n:展览馆",
"exhilarated":"v:喜冲冲",
"exhilarating":"a:来劲",
"exhilaration":"n:兴奋,愉快,豪兴,高兴",
"exhort":"v:激励,戒,勉励,劭,丁宁,叮嘱,劝诫,告诫,劝告,钊,箴,告戒,嘱咐,叮咛,劝导,催促",
"exhortation":"n:劝告,箴言,规劝,劝勉",
"exhumation":"n:掘墓,发掘",
"exhume":"v:掘墓",
"exigency":"n:危急,紧急状态,事变",
"exile":"n:流亡,流放,放逐;v:流亡",
"exist":"v:存在,在,有,生存,生活,存,现有,传代,生,生息,立",
"existence":"n:存在,生活,生存,生命,生物,实体,实在",
"existing":"v:现,现存;a:现有",
"exit":"n:出口,出路,门,离去,退出,下场,进出口,太平门,外出,去路,死亡;v:退出,离去,死,去世,下,出境",
"exocrine":"a:外分泌",
"exodus":"n:外流,退出,离去;v:外流",
"exonerate":"v:免除,开释,解除,昭雪,解脱,开脱",
"exoneration":"n:解除,免除,免罪,昭雪",
"exorbitance":"n:过分,混乱,过度",
"exorbitant":"a:高昂",
"exorcise":"v:驱除,傩",
"exorcism":"n:驱邪,咒语",
"exoskeleton":"n:外壳,外骨骼",
"exothermic":"a:放热",
"exothermic reaction":"n:放热反应",
"exotic":"n:舶来品,外来语,外来货;a:稀奇古怪",
"exotica":"n:古董,珍品",
"exoticism":"n:外来语",
"expand":"v:膨胀,扩大,发展,扩展,扩充,展开,扩张,张开,伸展,伸缩,放,广,扩建,详述,延伸,展,壮大,张,膨,恢廓,扩,弘,斥,拓;a:胀,广",
"expanse":"n:辽阔,太空,扩张,膨胀,展开",
"expansion":"n:膨胀,扩展,发展,扩大,扩张,展开,扩建,伸展,详述,辽阔,阐述,伸缩,张开;v:扩大,扩展,扩张,展开",
"expansive":"a:广阔",
"expatiate":"v:漫游,详述",
"expect":"v:希望,预料,期望,想,期待,预计,以为,预期,料想,料到,怀孕,盼望,料,期,意,等候,意料,预想,盼,望,鹄候,匡,想得到,意想,算计,逗留,守候,料及,推想",
"expectancy":"n:期待,期望,预期,期望值",
"expectant":"a:期待,预期",
"expectation":"n:期望,希望,期望值,期待,前程,望,估计",
"expectorate":"v:啐,吐",
"expectoration":"n:唾液",
"expedience":"n:上策,私利,权宜,权宜之计,便利,方便",
"expediency":"n:权宜之计,方便,便利,权变,权,上策",
"expedient":"n:权宜;v:权变;a:机动",
"expedite":"v:加速,加快,发送,促进,派遣,催",
"expediter":"n:促进派",
"expedition":"n:远征,探险队,探险,迅速;v:探险,调查,探查",
"expeditiousness":"n:速成",
"expel":"v:开除,驱逐,逐出,排出,赶走,革,革出,革除,驱遣,驱,驱赶,斥退,逐,窜,赶",
"expend":"v:花费,消耗,花,耗尽,花消,付出,化,支出,耗费,销,费,出,使用",
"expendable":"n:消耗品",
"expenditure":"n:开支,支出,费用,开销,花费,经费,消费,杂费,用度,费",
"expenditures":"n:用项",
"expense":"n:费用,开支,开销,代价,用费,费,消费,牺牲,出项,花消,消耗,用度,损失",
"expenses":"n:用,花费,资,费用,支出,开支",
"expensive":"a:贵,昂贵,高,高昂",
"experience":"v:发现,体会,知道,领教,尝,历经;n:见识",
"experienced":"a:老练,熟,老成,练达;v:练",
"experiment":"v:试验,实验;n:试验",
"experimentation":"n:实验,试验",
"expert":"n:专家,行家,内行,能手,通;a:拿手",
"expertise":"n:专长,鉴定",
"expertly":"d:擅",
"expiate":"v:赎,抵罪,抵偿,补偿",
"expiation":"n:抵偿",
"expiatory":"a:赎罪",
"expiration":"n:终止,断气,截止,届满,满期,死亡",
"expire":"v:到期,期满,死,满,满期,届满,过期,断气,消灭",
"expiry":"n:满期,死亡,终了,完满,断气,终止",
"explain":"v:解释,说明,说,讲解,辩解,讲,阐明,解答,详述,解,诠,释,训,陈说,置辩,白,陈,笺,阐,讲明,破解,申,阐释,喻,分解,声辩,详,交代",
"explanation":"n:解释,说明,辩解,和解,注释,剖白",
"expletive":"n:语助词",
"explicate":"v:阐明,辩明,解释,发展,讲,说明,引申,阐发",
"explication":"n:解说,解释,张开,说明,阐明",
"explicit":"a:明确,明白,详细,一清二楚,显然;d:显然",
"explode":"v:爆炸,戳穿,炸,爆破,爆发,打破,开花,爆,大作,激发,轰,推翻",
"exploder":"n:雷管,信管",
"exploit":"n:伟业,功勋;v:钻空子",
"exploitation":"n:开发,剥削,利用;v:开发",
"exploiter":"n:剥削者",
"exploits":"n:功业;v:烈",
"exploration":"n:勘探,探索,探险,探测,调查,探究;v:探索,勘探,探究",
"exploratory":"a:试探性;n:试探性",
"explore":"v:探索,探险,考察,勘探,研究,寻求,探测,查勘,调查,发掘,探,寻索,试探,测定,探查",
"explorer":"n:探险家,探针",
"exploring":"v:探测,扫描",
"explosion":"n:爆炸,爆发,激增,炸裂;v:展开",
"explosive":"n:炸药,爆破音",
"explosiveness":"n:爆炸",
"expo":"n:展览会,博览会",
"exponent":"n:指数,幂,典型,解说员,样品",
"exponential":"a:指数",
"exponential function":"n:指数函数",
"export":"v:出口,输出,排出,带走;n:呼叫,输出口",
"exportation":"n:输出,出口,呼叫",
"expose":"v:暴露,曝光,揭露,露出,揭发,揭穿,裸露,露,招致,陈列,揭,袒露,抖搂,捅,举发,暴光,拆穿,曝,发,戳穿,招惹",
"exposed":"a:裸露",
"exposition":"n:解释,博览会,讲解,说明,解说,展览,展览会,注释,暴露,陈列,曝光",
"expositor":"n:解说员",
"expostulate":"v:规劝,劝导,劝戒,诤",
"expostulation":"n:劝戒,劝导,忠告",
"exposure":"n:暴露,曝光,照射,揭发,辐射,曝晒,揭露,曝露,朝向,方位,暴光;v:照射",
"expound":"v:阐明,说明,解释,阐述,讲解,阐释,陈述,论述,论说,发挥,发明,详述,引申",
"express":"v:表示,表达,表现;n:快递;a:特快",
"express mail":"v:快件,快信",
"expression":"n:表情,表达式,表达,表示,神情,表现,公式,神色,说法,神态,脸色,神气,语句,态度,神采,词句,符号,声调,劲,腔调;v:压榨",
"expressions":"n:词句",
"expressive":"a:传神,抒情",
"expressway":"n:高速公路",
"expropriate":"v:征用,剥夺,没收,搜刮,接收,没",
"expropriation":"n:征用",
"expulsion":"n:开除,驱逐,逐出,喷溅,排气",
"expunge":"v:除名,勾销,抹掉,删去,消灭,除去",
"expurgate":"v:删去",
"expurgation":"n:删改",
"exquisite":"a:精致,精巧,讲究,精湛,精美,奇巧,细腻,高超,玲珑,细,细巧,考究,工巧;n:工",
"exquisiteness":"n:奇巧",
"extant":"a:现存",
"extemporaneous":"a:即席,即兴;d:即席",
"extempore":"v:即兴;n:即兴之作;d:即席",
"extemporization":"n:即兴之作,即兴诗",
"extend":"v:扩大,伸展,延长,扩展,延伸,伸出,伸,推广,延续,提供,展开,给予,扩充,引申,扩张,宽,达,发放,舒展,延展,发挥,扣押,铺,踢腿,估价,扩;a:宽",
"extensibility":"n:延伸度",
"extension":"n:扩大,分机,扩建,扩展,伸直,延期,延伸,范围,伸长,延长,伸展,扩张,外延,支线,广度,蔓延;v:扩展,扩张,开拓,伸长",
"extension cord":"n:连接线",
"extensive":"a:广泛,辽阔,广大,广阔,广博,洽,大规模,泛,恢宏,宽旷;v:泛",
"extensively":"d:广",
"extensiveness":"n:广大,大量",
"extent":"n:程度,范围,扣押,度,限度,地步,广度,宽度,面,长度,区域,外延,界,界限,分量,幅度",
"extenuate":"v:减轻,掩饰,藐视,低估",
"extenuation":"n:衰减,酌量,减轻,减小,降低,阻尼;v:减小",
"exterior":"n:外表,外观,外部,外貌,表面,外景,外边,外面,外形",
"exterior angle":"n:外角",
"exterminate":"v:消灭,灭绝,殄,毁灭,剪,剿,灭,湔,扑灭,剿灭,根除,剪除,消泯,剿除,夷,根绝",
"extermination":"n:灭绝,消灭,根除,扑灭",
"exterminator":"n:灭火器",
"external":"n:形式,外观,外形,表,国外,外面,外貌,外部;a:外部,外,对外,外来,外面,外在",
"external angle":"n:外角",
"external storage":"n:外存",
"externalization":"n:客观性",
"extinct":"v:熄灭,消灭,消亡;a:消亡",
"extinction":"n:灭绝,消灭,熄灭,废除;v:熄灭",
"extinguish":"v:熄灭,扑灭,消灭,压制,灭,偿清,废除,取消,殄,熄",
"extinguisher":"n:灭火器",
"extinguishing":"v:熄灭",
"extirpate":"v:根除,根绝,扑灭,殄,切除",
"extirpation":"n:根绝,摘除;v:摘除",
"extol":"v:称颂,吹捧,显扬,颂扬,夸奖,赞美,捧,赞颂,称赏,歌颂,称赞",
"extort":"v:逼,追逼,刮,逼迫,强求,讹,榨取,搂,索取,讹赖,搜刮,勒索,敲诈,曲解",
"extortion":"n:敲诈,勒索;v:敲诈勒索",
"extra":"a:额外,外加;n:号外,赠品;d:倍加;v:外加",
"extra large":"a:海",
"extract":"v:提取,开采,摘录,析取,取出;n:片断;a:精",
"extracting":"v:开方",
"extraction":"n:提取,血统,开方,出身,引出,摘录,抽出,发射,回采,家世,精炼;v:引出,发射",
"extractor":"n:分离器",
"extracts":"n:摘录,撮要;v:摘抄,摘记",
"extracurricular":"a:课外",
"extradite":"v:引渡,送还",
"extragalactic nebula":"n:河外星系,河外星云",
"extramarital":"a:婚外",
"extraordinarily":"d:非常,出奇,异乎寻常,异常,倍加,格外,贼;n:贼;a:出奇",
"extraordinary":"a:非常,非凡,了不起,异乎寻常,出奇,异,不同凡响,诡,卓跞,了不得,妙不可言,特出,超绝,峥嵘;v:不同凡响",
"extrapolate":"v:推断,推测,推论",
"extrapolation":"n:推论,推断;v:推论",
"extras":"n:杂费",
"extraterrestrial":"n:外星人,宇航员",
"extraterritoriality":"n:治外法权",
"extravagance":"n:挥霍,浪费,奢侈,奢侈品,淫糜,排场,铺张,过分",
"extravagant":"a:奢侈,铺张,铺张浪费,奢华,大手大脚,阔绰,阔气,华,奢靡,靡,奢;v:奢华,铺张浪费",
"extravaganza":"n:幻想曲",
"extreme":"a:极端;n:末端,困境;d:极端,太",
"extreme point":"n:端点",
"extremely":"d:极,极为,非常,极其,极端,十分,太,极度,异常,要死,要命,不堪,绝顶,精,绝,倍加,贼,万状,不亦乐乎,万般,十二分,至,不得了,顶,奇,穷,死;a:精,痛;n:贼;v:不得了",
"extremeness":"n:走极端",
"extremes":"n:极端",
"extremist":"n:过激",
"extremity":"n:手,极端,极度,端,末端,肢,边远,绝境,足,极限,极性,尽头,最后;v:端;a:边远",
"extricate":"v:摆脱,放出,游离",
"extrication":"n:放出,脱出,游离",
"extrinsic":"a:外在",
"extroversion":"n:外向",
"extrude":"v:挤压,挤出,伸出,压挤,冲压,模压,喷发,逐出,突出",
"extrusion":"n:挤压,挤出,压制,喷发,压挤,逐出;v:挤出,挤压",
"exuberance":"n:充沛,繁茂,丰富,茂盛,充溢",
"exuberant":"a:旺盛;v:充溢,生机盎然",
"exudation":"n:流出,分泌,渗出;v:渗出",
"exude":"v:渗出,放出,发散,流出,沁,溢出",
"exult":"v:狂喜;n:欢跃",
"exultant":"a:眉飞色舞",
"exultation":"n:得意,狂喜,大喜,欢跃",
"exulting":"a:扬扬自得",
"eye":"n:眼睛,眼,眼光,注视,注意;v:注视",
"eye disease":"n:眼病",
"eye socket":"n:眶,眼窝",
"eyeball":"n:眼球,眼仁,眼珠儿,眼珠子,睛;v:打量,眼球",
"eyeball to eyeball with":"p:面对面,与_面对面",
"eyebrow":"n:眉毛,眉,眼眉,滴水",
"eyedropper":"n:滴管",
"eyeful":"n:满眼",
"eyeglass":"n:眼镜,目镜,镜片",
"eyeglasses":"n:眼镜,叆叇",
"eyelash":"n:睫毛,眼睫毛,睫",
"eyelet":"n:枪眼,针眼,炮眼",
"eyelid":"n:眼皮,眼睑",
"eyepiece":"n:目镜,接目镜",
"eyes":"n:眼目",
"eyesight":"n:视力,眼力,眼神,目光,目力,眼界,见解,观察,视觉",
"eyesore":"n:眼中钉",
"eyewash":"n:吹牛,欺诈",
"eyewitness":"n:目击者,见证人",
"eyre":"n:巡回",
"ezekiel":"n:法语",
"fabian":"n:费边主义",
"fable":"n:寓言,无稽之谈,传说,情节;v:杜撰,虚构",
"fabric":"n:织物,结构,布,组织,织品,建筑物,质地,工厂,建造;v:建造",
"fabricate":"v:制造,制作,装配,构成,编,伪造,编造,捏造,臆造,杜撰,造,诌,创立,建造,虚构,凭空捏造,向壁虚造,胡诌,组成,构,捏,捏合,假造,向壁虚构",
"fabricated":"a:虚妄,莫须有;v:无中生有",
"fabrication":"v:制造,加工,制作,装配;n:诈语",
"fabulous":"a:骇人听闻,莫须有",
"facade":"n:表面,外表,虚伪,场面,浮面,正面,门面,外观",
"face":"n:脸,面孔,脸色;v:临;p:冲",
"face cream":"n:香脂",
"face powder":"n:扑粉",
"face time":"n:曝光,会面,亮相,露脸",
"face to face":"a:对面,相对,迎面,对,当面;d:对面",
"face to face with":"p:面对面,与_面对面",
"face value":"n:面值",
"face-lift":"n:整容",
"face-off":"n:对抗;v:摊牌",
"faced":"v:面对",
"faceplate":"n:花盘",
"facial":"n:美容",
"facial expression":"n:颜色,面色,脸色,容",
"facial nerve":"n:面神经",
"facial tissue":"n:纸巾",
"facile":"a:温和",
"facilitate":"v:促进,便利,有助于,简化,促成,助长",
"facilities":"n:设施,设备,事业",
"facility":"n:设备,装置,熟练,便利,容易,工具,机构,流畅,简易,灵巧,器材,轻便,柔和,机敏",
"facing":"n:着色,贴边,袖章;v:冲,镶边;p:向着",
"facsimile":"n:摹本,复制品;v:复制",
"facsimile machine":"n:传真机",
"fact":"n:事实,实际,论据,证据,实情;a:实",
"faction":"n:党,派,派别,门户,宗派,帮派,朋党,宗,内讧,小集团,山头",
"factionalism":"n:派性,宗派主义",
"factions":"n:派系",
"factor":"n:因素,因子,要素,系数,因数,条件,率,代理商,基因,经纪人;v:因式分解",
"factorial":"n:阶乘",
"factory":"n:工厂,厂,厂子,厂家",
"factory price":"n:出厂价",
"factual":"a:照实",
"factually":"d:实际上",
"faculty":"n:能力,才能,教职员,官能,机能,系,手腕,公会,技能,特权,学院,权能,院",
"faculty member":"n:科员",
"fad":"n:时尚,嗜好,热",
"fade":"v:消失,褪色,凋谢,消逝,褪,掉色,减弱,退,隐没,退色,衰老,走色,凋落,离开,落色,萎谢,消退",
"fade away":"v:消逝,消失,消退",
"faded":"a:蔫耷耷,蔫蔫",
"fading":"v:减小,衰落,隐没,脱色,退色;n:阻尼",
"faerie":"n:妖精,仙境",
"fag":"n:烟头,苦工;v:辛劳,拆散",
"fag end":"n:残渣,末端,零头,烟头,上当,废渣,废品,吃亏,渣滓",
"faggot":"n:柴,薪,柴草,柴火;v:束",
"fahrenheit":"n:华氏温度计",
"fahrenheit scale":"n:华氏温度计",
"fail":"v:不,失败,衰退,歉收,倒闭,辜负,不足,落空,告吹,忘记,破产,衰竭,漂,衰弱,砸,不遂,断,绝,砸锅,错误,败,泡汤,亏负;n:落第,失败,失误",
"failing":"n:缺点,失败,短处,弱点,过失;p:没有,如果没有;v:损坏;a:失败",
"faille":"n:罗缎",
"failure":"n:失败,故障,破坏,失效,损坏,缺乏,不足,倒闭,事故,衰竭,断裂,破产;v:损坏",
"faint":"a:微弱;v:头晕,背,发昏;n:昏厥;d:微微",
"fainting":"v:昏倒,昏厥",
"faintly":"d:隐约,隐隐约约,隐隐,恍惚;a:恍惚",
"faintness":"n:模糊,眼花",
"fair":"n:交易会,集市,展览会;d:十分,好;a:公正,公道;v:均等,誊清,整流,持平,差强人意",
"fair to middling":"v:中不溜儿,马马虎虎",
"fair-minded":"a:大公无私",
"fairing":"n:礼物",
"fairly":"d:相当,还,简直,完全,比较,顺利,较,较比,蛮,适当",
"fairness":"n:公正,公平,光明正大,晴朗,流线型,适当,洁白",
"fairway":"n:航道,航路,通道",
"fairy":"n:仙女,妖精,灵,化境",
"fairy godmother":"n:救星",
"fairy story":"n:童话",
"fairy tale":"n:童话,谎言,神话",
"fairyland":"n:幻境,仙境",
"fait accompli":"n:既成事实",
"faith":"n:信仰,信心,信念,信任,忠诚,信,教义,诚实,忠实,信用,信义,诚意,誓约,教,信条;v:信任",
"faithful":"a:忠实,忠诚,可靠,坚贞;v:守节;n:信徒",
"faithfulness":"n:诚实,正确,忠心,忠实",
"fake":"v:伪造,假装;n:骗子,诈骗,冒充,冒牌货,线圈;a:冒牌",
"faker":"n:冒牌货,骗子",
"fakir":"n:行者",
"falcon":"n:猎鹰,鹘,隼",
"fall":"v:跌倒,掉,落,摔,倒,下降,下,摔倒;n:衰退,瓦解,倾泻",
"fall apart":"v:分崩离析,圮,散架,破碎,散,四分五裂",
"fall asleep":"v:成眠,入梦,着,睡觉",
"fall away":"v:变节,抛弃,疏远",
"fall back":"v:倒退,撤退,退路",
"fall behind":"v:掉,落后,退步,拖欠,退后",
"fall down":"v:马,失败,塌,毙,跌倒,跋,倒下,跌交,坍塌,栽倒",
"fall in":"v:入列,站队,跌入",
"fall in line":"v:排队",
"fall in love":"v:红绳系足,相爱",
"fall into":"v:分为,中,开始,堕入,沦",
"fall off":"v:脱落,脱,离开,下降,弛,减退,缩小,衰退,跌落",
"fall out":"v:翻,反目,破脸,发生,争吵",
"fall over":"v:倒下",
"fall short":"v:不足",
"fall short of":"v:缺乏,不及,差",
"fall through":"v:吹,流产,砸锅,砸,破产,失败,黄,中断",
"fall under":"v:列入",
"fallacy":"n:谬论,谬误,错误,谬见,妖言,错觉,邪说,谬传,谬种",
"fallback":"n:撤退,退却;v:撤退",
"fallen":"a:恶魔",
"faller":"n:落体",
"fallibility":"n:虚妄",
"falling":"n:下降,凹陷,陷落,垮台,崩塌,堕落;a:泫然",
"falling off":"n:衰败,衰落,减少",
"falling out":"n:不和,冲突,争执",
"fallopian tube":"n:输卵管",
"fallout":"n:原子尘",
"fallow":"n:休耕地,休闲,休闲地",
"falls":"n:瀑布",
"false":"a:假,虚假,虚伪,伪,虚",
"false alarm":"n:虚惊",
"false fruit":"n:假果",
"false return":"n:虚报",
"falsehood":"n:谎言,假话,撒谎,谎话,谬误,虚伪,谎,虚妄,诳语,谬,错误,谬论,诈语",
"falsely":"d:冒,误,虚妄",
"falseness":"n:错误,虚伪,欺骗",
"falsetto":"n:假嗓子,小嗓,小嗓儿",
"falsification":"n:窜改,伪造,篡改,歪曲,畸变,弄虚作假",
"falsifier":"n:篡改,说谎",
"falsify":"v:歪曲,伪造,篡改,矫揉造作,作假,窜改,撒谎,挢,误用",
"falsity":"n:虚伪,谎言,欺诈",
"falter":"v:蹒跚,颤抖,踌躇,支吾,摇晃,迟疑,结巴,畏缩,支支吾吾;n:踌躇,结巴,摇晃,支吾",
"faltering":"a:颤巍巍",
"fame":"n:名声,名,声誉,名誉,声望,名气;v:盛传",
"familiar":"a:面熟,亲昵,熟,眼熟;n:常客,亲友",
"familiar spirit":"n:妖精",
"familiarity":"n:熟悉,精通,融洽,爱抚,亲近,面熟,亲密,深交",
"familiarization":"n:精通,通俗化,亲密,熟识",
"familiarize":"v:熟习",
"family":"n:家庭,家,家人,家族,人家,家属,子女,系,科,家子,亲属,种族,语族,语系,户,门,族,门第,氏族,眷属,老小,类别,同僚,人种,亲族,民族,派别",
"famine":"n:饥荒,荒,饥饿,饥馑,饥,荒歉",
"famish":"v:挨饿,饿",
"famous":"a:著名,名,有名,出名,闻名,著称,驰名,知名,名扬四海,闻;v:闻名,显扬,闻,著称,驰名",
"fan":"n:球迷,扇子,迷,风扇,爱好者;v:刺激,煽",
"fanatical":"a:狂热",
"fanaticism":"a:狂热;n:狂热",
"fancier":"n:空想家,爱好者",
"fanciful":"a:架空,空幻;v:架空",
"fancy":"v:认为,想像;n:想像;a:新奇",
"fancy man":"n:情夫,情郎",
"fancy woman":"n:妓女",
"fancywork":"n:刺绣品",
"fandango":"n:胡闹",
"fanfare":"n:鼓吹,夸耀",
"fang":"n:尖牙,毒牙,犬牙,爪,尖端,牙根,齿,方",
"fanlight":"n:气窗",
"fanning":"v:展开",
"fanny":"n:屁股",
"fantasia":"n:幻想曲",
"fantasize":"v:幻想,梦想",
"fantastic":"a:离奇,异想天开,荒诞,荒,无稽,荒诞不经,匪夷所思,荒唐,怪诞不经,岂有此理,神乎其神;v:异想天开,岂有此理,怪诞不经,见鬼",
"fantasy":"n:幻想,想入非非,幻梦,幻想曲;v:梦想,想像",
"far":"d:很;a:远",
"far cry":"n:天壤之别",
"far east":"n:远东",
"farad":"n:法拉",
"faraway":"a:遥远,幽幽,偏远,辽,嘏,辽远,逖",
"farce":"n:闹剧,笑剧,滑稽,滑稽戏,趣谈,丑剧,趣剧,闹戏",
"fare":"v:吃,处境,旅行,去;n:捕获量,车钱",
"fare-thee-well":"n:完善",
"farewell":"i:再见,告辞,一路平安,再会;v:告辞;n:告别",
"farina":"n:淀粉,花粉",
"farinaceous":"a:粉状",
"farm":"n:农场;v:出租,稼穑",
"farm worker":"n:农业工人",
"farmer":"n:农民,农夫,庄稼人,庄户人,农,庄稼汉",
"farmhand":"n:农业工人,雇农",
"farmhouse":"n:农舍,农家,庄家,田舍,庐舍",
"farming":"n:农业,饲养,农活,耕种,耕作;v:耕作",
"farmland":"n:农田,田地,田,畎亩,畴,田畴,耕地",
"farmstead":"n:田庄,农场",
"farrago":"n:混杂,大杂烩",
"farrier":"n:兽医",
"farrow":"v:产",
"farsighted":"a:目光如炬",
"fart":"v:放,放屁;n:屁",
"farther":"d:加之,更,还",
"fascia":"n:绷带,招牌,带,腰带",
"fascicle":"n:束,簇,分册",
"fascinate":"v:吸引,迷住,入迷,迷,迷人,诱惑,抓",
"fascinating":"a:迷人;v:引人入胜",
"fascination":"n:魅力,着迷,迷恋,神魂颠倒,入迷",
"fascist":"n:法西斯",
"fashion":"n:方式,时装,时兴,式样,时髦,服装,款式,方法,潮流,风格,时尚;v:造,作,改革,铸成",
"fashionable":"a:时髦,流行,时兴,入时,摩登;v:风靡,时兴",
"fashionably":"d:赶时髦,流行",
"fast":"a:快;d:疾,忽忽;n:斋戒,斋期,禁食,绝食;v:禁食",
"fast asleep":"v:熟睡",
"fast break":"n:快攻",
"fast day":"n:斋戒日",
"fast food":"n:快餐",
"fast lane":"n:快车道",
"fasten":"v:系,拴,锁,固定,坚持,抓紧,缯,加固",
"fasten on":"v:抓紧",
"fastener":"n:钮扣,卡,纽扣,卡子,夹子",
"fastening":"v:连接",
"fastidious":"a:吹毛求疵,考究,挑三窝四;v:吹毛求疵,挑三窝四",
"fasting":"v:禁食;n:禁食",
"fastness":"n:放荡,急速,坚固,迅速,要塞,坚牢,堡垒,固定",
"fat":"n:脂肪;a:肥囊囊,肥实",
"fatal":"v:致命;a:致命",
"fatal accident":"n:失事",
"fatalism":"n:宿命论",
"fatalistic":"a:听天由命,宿命论;v:听天由命",
"fatality":"n:死亡,惨死,命运,灾害,灾难",
"fatality rate":"n:死亡率",
"fate":"n:命运,结局,天命,灾难,数,命,气运,大数,毁灭,死亡,运,死活,运道,气数,灭亡",
"fathead":"n:饭桶,呆子",
"father":"n:父亲,爸爸,大,父,爹,祖先,爸;v:治理,生,产生,创作;a:严",
"father christmas":"n:圣诞老人",
"father-in-law":"n:岳父,公公,翁婿,丈人,舅父,外舅,岳丈",
"fatherland":"n:祖国",
"fatherly":"a:慈爱",
"fathom":"v:领会,捉摸,测,推测,看穿",
"fathomless":"v:深不可测;a:深不可测",
"fatigue":"n:疲劳,劳累,疲乏,累活;a:疲劳;v:疲劳",
"fatigued":"a:疲乏,困顿,困乏,累,劳顿,疲倦,委顿;v:顿,累,疲劳,委顿,疲倦",
"fatness":"n:肥胖,肥沃",
"fatso":"n:胖子",
"fatten":"v:催肥,增大,蹲膘,肥育,育肥,增多,上膘,抓膘",
"fattening":"v:肥育",
"fatty":"a:脂肪;n:胖子",
"fatty liver":"n:脂肪肝",
"fatuity":"n:愚昧,愚蠢,蠢事,昏庸",
"fatuous":"a:昏庸,愚昧,憧",
"faucet":"n:水龙头,龙头,插口",
"fault":"n:故障,断层,缺点,错,过错,过失,毛病,过,事故,缺陷,责任,不是,岔子,缺,错处,罪过,短处,短;v:犯规,挑剔,尤;a:短",
"faultfinder":"n:刺儿头,刺头",
"faultfinding":"n:挑剔,找岔子;a:吹毛求疵",
"faultiness":"n:缺陷",
"faulting":"n:故障;v:故障",
"faultless":"a:完美无缺,白璧无瑕",
"faux pas":"n:失误,失礼,过失,失足",
"favor":"v:赞成,偏袒,支持,偏爱;n:提倡,情,照顾,爱好,光,雨露,宽恕,礼物,利益,人情,许可,德,徽章,亲切",
"favorable":"a:有利,优厚,占便宜,优惠,利",
"favored":"v:受宠",
"favorite":"n:宠儿,亲信",
"favoritism":"n:偏爱,宠爱,偏袒",
"favour":"n:支持,照顾,赞成,欢心;v:倾斜;a:厚,右",
"favourable":"a:有利,优惠;v:占便宜",
"favourite":"n:宠儿,红人,宠物,亲信",
"favouritism":"n:偏袒",
"fawn":"v:巴结,拍马,讨好,谄媚,阿谀逢迎,拍,生,摇尾乞怜;n:羔,羔子",
"fax":"n:传真,传真机;v:传真",
"fay":"n:仙女;v:接合",
"faze":"n:混乱,忧虑,狼狈;v:惊扰,困扰,打扰",
"fealty":"n:效忠,忠诚,诚实,孝顺",
"fear":"v:怕,害怕;n:机遇",
"fearful":"a:可怕,懔,惶恐,鲟鱼,寒,凛,凶,兢,寒心",
"fearfully":"d:十分",
"fearfulness":"n:可怕",
"fearless":"v:无畏;a:无畏",
"fearlessness":"n:无畏",
"feasibility":"n:可行性,可能性",
"feasible":"a:可行,切实,使得;v:使得",
"feast":"n:宴会,宴席,盛宴,节日;v:赴宴,享受",
"feat":"n:功绩,技艺,武功,武艺,技术,本领,功劳",
"feather":"n:羽毛,毛,心情,翎毛,微波,服装,羽,状态,种类,服饰;v:减弱",
"feather bed":"n:闲职",
"feather one's nest":"v:营私",
"feathering":"n:羽毛,桂皮,树皮",
"feathery":"a:软绵绵",
"feats":"n:功勋,功绩",
"feature":"n:特征,特点,特性,部件,容貌,五官,特色,相貌,特写,性能,面貌,正片,故事片,面目,特辑,形状,点;v:放映",
"feature article":"n:特写",
"feature film":"n:正片",
"features":"n:面貌,嘴脸,眉眼,长相,面目,特性,眉目",
"feb":"n:二月,2月",
"february":"n:二月,2月",
"feces":"n:粪便,粪,渣滓,屎,排泄物,矢",
"fecundity":"n:富饶,肥沃,生育力,多产",
"federate":"v:联合",
"federation":"n:联盟,联邦,同盟,联合会",
"fee":"n:费用,学费,费,会费,手续费,所有权,税,入场费,赏金,小账,封地,聘金,薪水,报酬;v:雇用",
"fee tail":"n:继承权",
"feeble":"a:弱,衰弱,虚弱,微弱,软弱,乏力,软塌塌,苍白,软,衰惫,软绵绵",
"feebleness":"n:虚弱",
"feed":"v:喂;n:补给,草料",
"feed grain":"v:饲料",
"feed in":"v:进料",
"feedback":"v:回复,反馈;n:反馈,回复",
"feeder":"n:奶瓶,饲养员,支脉,支线,食客,支流",
"feeder line":"n:支线",
"feeding":"n:饲养,喂食,进料,牧场;v:供电,饲养",
"feedlot":"n:牧场",
"feedstock":"n:进料",
"feel":"v:感到,觉得,感觉,着,想,认为,摸,同情,感,感受,摸索,觉,以为,觉察,作,觉着,触,感知,试探,体谅;n:号,感受,触觉",
"feel for":"v:摸,同情",
"feel like":"v:想",
"feel out":"v:试探,摸",
"feeler":"n:触角,触须,手指,探子,探针,厚薄规,靠模",
"feeling":"n:感情,感觉,情绪,心情,情感,感受,情,感,心,反感,看法,知觉,同情,恶感,气氛,情调,预感,感想,体谅,思绪,怜悯,感触,手感,触觉",
"feelings":"n:情面,情怀,情,寸心,脸",
"feet":"n:脚,英尺",
"feign":"v:假装,伪造,装,装作,装模作样,捏造,佯,诈,装扮,伪装,佯装,装假",
"feint":"n:佯攻;v:佯攻,假装,装作;a:淡,假",
"feldspar":"n:长石",
"felicitate":"v:庆幸,祝贺,庆祝,庆贺",
"felicitation":"n:庆祝,祝贺",
"felicitous":"a:贴切",
"felicity":"n:幸福,巧妙,幸运;a:幸福,幸运",
"fell":"v:打倒,砍伐,击倒,伐,砍;n:羊毛,兽皮,毛皮",
"fella":"n:伙伴",
"feller":"n:樵夫",
"felling":"v:砍伐,采伐,伐木;n:兽皮",
"fellow":"n:家伙,小伙子,同伴,伙计,伙伴,同事,汉子,同类,小子,伴侣,佬,瓜,帮手,鬼,竖子,对手,同辈,徒",
"fellow traveler":"n:同路人",
"fellow worker":"n:同事",
"fellows":"n:侪辈,对手",
"fellowship":"n:奖学金,交情,会,团体,提携,友谊;v:参加",
"felon":"n:重犯,甲沟炎",
"felony":"n:重罪",
"felt":"n:毛毡,油毡,毡子,毡,毛布,油毛毡",
"felt hat":"v:毡帽,呢帽",
"fem":"n:女子",
"female":"n:雌;a:雌性,女,母",
"feminine":"a:女性;n:阴性",
"femininity":"n:女性,温柔,柔弱",
"feminism":"n:女性",
"feminize":"v:女性化",
"femur":"n:股骨,腿,髁,大腿",
"fen":"n:沼泽,汾",
"fence":"n:篱笆,栅栏,围栏,围墙;v:隔开,防护,闪开,防御,挡住",
"fencing":"n:围墙,栅栏;v:击剑",
"fend":"v:扶养,躲开,防御,力争,照料,供养,闪避,努力",
"fend off":"v:架,躲开",
"fender":"n:挡泥板,挡板,挡",
"feng":"n:冯",
"fenland":"n:沼泽地",
"fennel":"n:茴香",
"feral":"a:野生",
"ferment":"n:酵素,酶,酵子,扰动;v:酝酿",
"fermentation":"n:发酵;v:发酵",
"fermium":"n:镄",
"fern":"n:蕨类植物,羊齿,氟利昂",
"ferocious":"a:凶,凶猛,恶狠狠,凶恶,凶残,狰狞,鸷,残,恶,犷,悍,狞",
"ferocity":"n:凶猛,残暴,野蛮,暴行,凶焰",
"ferret":"v:查出,搜寻;n:侦探,鞋带,搜索",
"ferret out":"v:查获,查出,清查",
"ferrite":"n:铁氧体",
"ferromagnetic":"a:铁磁",
"ferrule":"n:箍",
"ferry":"n:渡船,渡轮,渡口;v:渡过",
"ferryboat":"n:渡船,渡轮",
"fertile":"a:肥沃,富饶,肥,膏腴,肥美,沃",
"fertiliser":"n:肥料",
"fertility":"n:肥力,肥沃,丰富,生育力,丰饶,多产,丰产,繁殖力,膏腴,生产能力,生产力",
"fertilization":"n:受精,施肥,受胎,授粉;v:受孕",
"fertilize":"v:施肥,肥,授粉,受孕,受胎",
"fertilizer":"n:肥料,肥",
"ferule":"n:戒尺,纪律",
"fervency":"n:炽热,热烈,热情,热心",
"fervent":"a:热情,热烈,热切,慷慨,火热",
"fervor":"n:热情,激情,白热,高温",
"fervour":"n:高温",
"fess":"n:中线",
"fester":"n:恶化,化脓,脓疮,郁积,溃烂;v:化脓,溃烂,烂,恶化,烦恼",
"festival":"n:节日,音乐节,会演,佳节,节",
"festivities":"n:过节",
"festivity":"n:喜庆,欢宴,节日,欢乐",
"fetal movement":"n:胎动",
"fetch":"v:取,接,弄,赶上,使出,抵达,到达,航行,读取",
"fetch up":"v:到达",
"fete":"n:节日;v:宴请",
"fetish":"n:迷信,偶像",
"fetishism":"n:拜物教,迷信",
"fetter":"n:脚镣;v:束缚",
"fettle":"v:小题大做,整顿;n:状况,状态",
"fetus":"n:胎儿,胎",
"feud":"n:不和,仇隙,世仇,仇恨,纠纷,宿仇,封地,争执",
"feudalism":"n:封建主义,封建,封;a:封建",
"fever":"n:发热,热病,热度,狂热,兴奋,热;v:烧,发热,发烧;a:狂热",
"fever pitch":"n:狂热",
"feverish":"a:狂热,翻腾,暴躁;v:翻腾",
"few":"a:少,少数;r:少数",
"fewness":"n:少数,少",
"fiance":"n:未婚夫",
"fiancee":"n:未婚妻",
"fiasco":"n:惨败,大败",
"fiat":"n:法令,命令,认可,许可",
"fiat money":"n:流通券",
"fib":"v:击",
"fiber":"n:纤维,须根系,麻,须根,纸板",
"fiber optics":"n:光纤",
"fiberboard":"n:纤维板",
"fiberglass":"n:玻璃丝,玻璃纤维",
"fibers":"n:纤维",
"fibre":"n:筋,素质,麻,硬纸板,棕毛,性格,纤维板",
"fibre optics":"n:光导纤维",
"fibril":"n:根毛",
"fibrin":"n:纤维蛋白,纤维素",
"fibula":"n:腓骨",
"fickle":"a:朝三暮四;v:薄幸",
"fickleness":"n:浮躁",
"fiction":"n:小说,虚构,捏造;v:虚构",
"fictitious":"a:假想,虚拟;v:虚拟,子虚乌有",
"ficus carica":"n:无花果",
"fiddle":"v:摆弄;n:提琴",
"fiddle with":"v:搬弄,摆弄,鼓捣,乱动,拨弄",
"fiddle-faddle":"v:无事忙;n:胡扯",
"fiddler":"n:骗子",
"fidelity":"n:忠诚,忠实,真实,保真度,逼真度,翔实;a:忠诚",
"fidget":"v:坐立不安,烦躁;n:烦躁",
"fidgety":"v:心神不定;a:心神不定",
"fiduciary":"v:信托;a:信托",
"fief":"n:封地,采地",
"fiefdom":"n:封地",
"field":"n:田野,字段,领域,田地,场,田间,场地,田,方面,范围,野外,战场,牧场,原野,旷野,运动场,球场,画面,视野,庄稼地,舞台,油田,战役,园地,环境,界,畎亩,战斗,垌,田亩,粮田,底子,镜头;v:接,守",
"field cricket":"n:蟋蟀",
"field crop":"n:大田作物",
"field glasses":"n:千里眼",
"field gun":"n:野战炮",
"field horsetail":"n:问荆",
"field lens":"n:物镜",
"field mouse":"n:野鼠",
"field of fire":"n:射界",
"field of vision":"n:眼界,视域",
"field officer":"n:校",
"field strength":"n:场强",
"field work":"n:实地调查",
"fields":"n:田畴,地",
"fieldwork":"n:实地调查,野战;v:实习",
"fiend":"n:魔鬼,恶魔,魔,魔王,能手,迷,凶神,凶煞",
"fiendish":"a:凶狠,獠,凶恶",
"fiends":"n:凶神恶煞,魔怪",
"fierce":"a:激烈,凶猛,猛烈,凶,愤怒,凶恶,残忍,恶,厉害,骄,鹉;v:激",
"fiercely":"a:横暴,狂怒,凶猛;d:横,猛",
"fierceness":"n:凶猛",
"fieriness":"n:猛烈",
"fiery":"a:火红,火,火热,火暴,烈,炯炯有神",
"fiesta":"n:假日",
"fife":"n:笛子,横笛;v:吹",
"fifty":"a:半百",
"fifty-fifty":"n:对半;a:均摊",
"fig":"n:无花果,一点儿,琐事,图表;v:打扮",
"fig out":"n:装饰",
"fig up":"n:振奋",
"fight":"v:战斗,打,作战,斗争;n:竞争",
"fight back":"v:抵抗,卷土重来,回击",
"fight down":"v:抑制,克服",
"fight off":"v:击退,辟",
"fighter":"n:战斗机,战士,斗士,拳击手,歼击机,兵士",
"fighting":"n:刀兵,战斗,战争,作战;v:兵戈,战斗,刀兵",
"figment":"n:虚构",
"figuration":"n:成形,形像,轮廓,修饰,定形,图像,外形",
"figure":"n:数字,人物,身材,人影,数,计算,身影;v:象征,懂,合计,描写,图解,数,领会,判断,推测",
"figure of speech":"n:比喻,修辞",
"figure out":"v:合计",
"figure skating":"n:花样滑冰,想象",
"figurehead":"n:傀儡,架空",
"figurine":"n:俑",
"filament":"n:灯丝,游丝,花丝",
"filamentary":"n:纤维;a:纤维",
"filbert":"n:榛",
"filch":"v:偷,偷窃",
"file":"n:文件,档案,卷宗,案卷;v:告发",
"file in":"n:鱼贯而入",
"files":"n:案卷,档案",
"filial":"a:孝顺",
"filial duty":"n:孝道",
"filial love":"n:孝心",
"filibuster":"v:掠夺,妨碍;n:海盗",
"filigree":"n:花丝",
"filing cabinet":"n:档案柜",
"filings":"n:木屑",
"fill":"v:充满,满,填写,装满,填,填补,灌,填充,注满,充填,满足,充,上,充塞,充实,补;n:饱满",
"fill in":"v:代替,浇铸,填,镶嵌",
"fill out":"v:填写",
"fill up":"v:填充,垫,补",
"fill-in":"n:临时,摘要,替工",
"filled":"a:满,满满当当,饱满",
"filler":"n:填料,补白,漏斗,填充物",
"fillers":"n:珍闻",
"fillet":"n:肉片,鱼片,腰部,带子;v:修",
"filling":"n:填补;v:装填,充填,填充",
"fillip":"v:弹指,刺激,激励;n:弹指,小事,琐事",
"film":"n:电影,影片,胶片,胶卷,薄膜,膜,片子,软片,膜片,影片儿,薄雾,镀层",
"film festival":"n:影展",
"film producer":"n:制片",
"film projector":"n:电影机,放映机",
"filter":"n:过滤器,滤器,滤波器;v:淋,渗入",
"filtering":"v:过滤,滤波",
"filth":"n:污秽,污物,污垢,污,垢,淫猥,渍;a:淫猥",
"filthiness":"n:污秽",
"filthy":"a:脏,肮脏,污秽,龌龊,污,污浊,恶浊,乌七八糟,垢,淫秽,不干不净",
"filthy lucre":"n:不义之财,赃款",
"filtrate":"n:滤液;v:过滤",
"filtration":"n:过滤;v:过滤",
"fin":"n:垂尾,脚蹼",
"fin whale":"n:长须鲸",
"finagle":"v:欺骗",
"final":"n:决赛,最后,结局,终极;a:终结,极;v:终结",
"final decision":"n:定案",
"final examination":"n:大考",
"final judgment":"n:终审,盖棺论定",
"final result":"n:结局",
"finale":"n:大团圆,结局,收尾",
"finalise":"v:完结",
"finality":"n:定局,结尾,终结,权威性,最后",
"finalize":"v:完结",
"finally":"d:终于,最后,最终,总算,结果,终,到底,算,临了,末后,末了,到头来,归根结蒂,归根到底",
"finals":"n:决赛",
"finance":"n:财政,财务,资金,金融,财政学,岁入;v:筹资",
"financial":"a:财政",
"financial condition":"n:经济",
"financier":"n:金融家,资本家",
"financing":"n:理财;v:筹资",
"finch":"n:鸣禽",
"find":"v:发现,找到,觉得,发觉,了解,看见,获得,裁决;n:发现",
"find fault":"v:抓茬儿,吹毛求疵,评头论足,挑毛拣刺,找茬儿,挑错,挑刺儿,挑毛病",
"find out":"v:查清,追究,了解,探悉,发觉,追查",
"finder":"n:测距器,探测器",
"finding":"n:发现,评定,零件,判决;v:探测,测定,寻找",
"findings":"n:发现",
"fine":"a:好,优秀,细;v:晴;n:罚金",
"fine spray":"n:雾",
"fine-toothed comb":"n:篦子",
"fineness":"n:精致,纯度,精美,优良,光洁度,敏锐,细微,纤度;a:精美",
"finery":"n:服饰,装饰,精炼炉,时髦",
"finespun":"a:细纺",
"finesse":"n:技巧,策略,手段,手腕",
"finger":"v:指出;n:钩爪,警察",
"finger alphabet":"n:手势语",
"finger-pointing":"n:责难,指责",
"fingerboard":"n:键盘,指路牌",
"fingering":"n:指法",
"fingerling":"n:小事,鱼秧",
"fingernail":"n:指甲,爪",
"fingernails":"n:指甲",
"fingerprint":"n:指纹,指印,手印,手模",
"fingertip":"n:指尖",
"finicky":"a:娇气,娇",
"fining":"n:澄清,精制;v:精炼",
"finis":"n:终结,结尾",
"finish":"v:了,完成,结束,完,已,吃光,粉刷,尽,完事;n:精加工,死,完结,文雅;d:已,终",
"finish off":"v:结果,一扫而光,毁掉,杀死,包圆儿,解决,煞尾",
"finish up":"v:完成,包圆儿",
"finished":"a:绝,利落,精制品;v:绝",
"finisher":"n:刽子手",
"finishing":"v:结尾,精加工,结束",
"finite":"a:有限",
"fink":"n:工贼,告密者,乞丐;v:撤退,退缩",
"finland":"n:芬兰",
"fir":"n:冷杉,杉木,枞树,枞",
"fir tree":"n:枞树,冷杉",
"fire":"v:解雇;n:鸣放,热烈,光辉,发热,发烧",
"fire beetle":"n:萤火虫",
"fire control":"n:火控",
"fire engine":"n:救火车",
"fire escape":"n:太平门,太平梯",
"fire hose":"n:水龙",
"fire pit":"n:塘,火坑",
"fire station":"n:消防站",
"fire truck":"n:消防车",
"fire up":"n:生火,生气",
"fire-raising":"n:纵火",
"fire-resistant":"a:耐火",
"firearm":"n:步枪,手枪,火器,枪",
"firearms":"n:枪械,枪炮,枪支,火,武器",
"fireball":"n:火球,燃烧弹",
"firebomb":"n:燃烧弹",
"firebox":"n:燃烧室",
"firebrand":"n:火把",
"firebrick":"n:火砖,耐火砖",
"firebug":"n:萤火虫",
"firecracker":"n:爆竹,炮仗",
"firecrackers":"n:鞭炮,炮",
"firedamp":"n:沼气",
"firefly":"n:萤火虫,萤火虫儿,萤",
"firehouse":"n:消防队",
"firelight":"n:炉火,火光,营火",
"fireman":"n:司炉,火夫",
"fireplace":"n:壁炉",
"fireplug":"n:消火栓",
"firepower":"n:火力",
"fireproof":"a:耐火;v:防火",
"fireproofing":"n:耐火材料,耐火;v:耐火材料",
"firer":"n:火器",
"fireside":"n:家,家属,家庭",
"firestone":"n:燧石",
"firewall":"n:防火墙",
"firewater":"n:烈酒,烧酒",
"firewood":"n:木柴,柴,劈柴,柴火,柴禾,荛,薪,樵,柴草",
"firework":"n:焰火,烽火",
"fireworks":"n:烟花,焰火,花炮,烟火,花",
"firing":"n:射击,解雇,烘烤,司炉;v:启动,射击,烧结,点火",
"firing chamber":"n:燃烧室",
"firing line":"n:第一线,火线",
"firing range":"n:靶场,射击场",
"firm":"a:坚定,坚决,牢固,稳固,坚强,牢,巩固,硬,紧,稳,狠,坚,牢稳,刚烈,刚强,坚固;n:公司,商行,商号,厂商;d:确,刚;v:鼓励",
"firmament":"n:天穹,天空,苍穹,太空,苍天",
"firmer":"a:凿子",
"firmly":"d:牢牢,紧紧,决然,妥贴,毅然,确,狠狠;a:妥贴",
"firmness":"n:坚定,稳固,坚固",
"firmware":"n:操作系统,固件",
"first":"n:元,甲等,头,头等,甲;a:首,首屈一指;d:先,首先;r:乍",
"first cause":"n:原动力,造物主,根源",
"first class":"n:一流,甲等,头路",
"first cousin":"n:近亲",
"first half":"n:上半场",
"first lady":"n:第一夫人",
"first lieutenant":"n:中尉",
"first of all":"n:其一",
"first quarter":"n:上弦",
"first step":"n:初步",
"first water":"n:第一流,优等",
"first-aid kit":"n:急救箱",
"first-class":"a:头等,第一流,上好,一等",
"first-rate":"a:第一流,优等,一等,头等",
"firstborn":"n:长子,头胎",
"firsthand":"a:原始,亲身",
"firstly":"d:首先;r:其一",
"fiscal":"n:检察长,检察官",
"fish":"v:钓鱼;n:美元,东西,鱼雷,生手",
"fish cake":"n:鱼丸",
"fish farm":"n:养鱼,鱼场",
"fish fry":"n:鱼秧子,鱼花,炸鱼",
"fish glue":"n:鳔",
"fish louse":"n:鲺",
"fish oil":"n:鱼油",
"fish-liver oil":"n:鱼肝油",
"fishbowl":"n:鱼缸",
"fisher":"n:渔夫,渔船",
"fisherman":"n:渔民,渔夫,渔人,渔工,渔船,渔户",
"fishermen":"n:渔民",
"fishery":"n:渔业,渔场,渔捞,水产业",
"fishes":"n:鱼类",
"fishhook":"n:钓钩,钓,鱼钩,渔钩;v:钓",
"fishing":"n:钓鱼,捕鱼,渔业;v:捕鱼,打捞,钓鱼",
"fishing boat":"n:渔舟",
"fishing gear":"n:渔具,鱼具",
"fishing line":"n:缗,纶",
"fishing net":"n:渔网",
"fishing rod":"n:钓竿",
"fishing season":"n:渔汛",
"fishing tackle":"n:钓具,渔具",
"fishing vessel":"n:渔轮",
"fishmonger":"n:鱼贩",
"fishnet":"n:渔网,罟,鱼网",
"fishpond":"n:鱼塘",
"fishy":"a:不是味儿,蹊跷,腥气",
"fissile":"a:核燃料",
"fission":"v:裂变,分裂;n:裂开",
"fissure":"n:裂缝,裂隙,缝,节理,裂纹;v:裂开",
"fist":"v:拳,紧握,掌管;n:拳头,拳,手",
"fistfight":"n:格斗,互殴",
"fisticuffs":"n:斗殴",
"fit":"v:得,合适,合身,适合;n:阵,诗歌,适当,妥当;a:健康",
"fit in":"v:适合",
"fit out":"v:配备,装配",
"fitful":"a:不定",
"fitment":"n:家具,设备",
"fitness":"n:健康,恰当,合理,适当",
"fitter":"n:钳工,装配工,碎片",
"fitting":"n:装置,设备;a:服贴;v:接头,装配",
"fittings":"n:配件",
"five":"a:五",
"fix":"v:固定,安排,决定,确定,修理,定,准备,上,选定,规定,操纵;n:饮料,困境",
"fix up":"v:安顿,布置,打扮,置,安排,骘",
"fixate":"v:凝视,注视,注意,固定",
"fixation":"n:固定,凝固,安置,凝视,定影;v:定影",
"fixative":"n:定影液,固色剂",
"fixed":"a:固定,死,一定;v:划一不二,定",
"fixed-point part":"n:尾数",
"fixer":"n:定影剂",
"fixing":"v:调味品,定影,修理,固定,装饰,配料,整理",
"fixity":"n:固定",
"fixture":"n:固定,夹具,卡具",
"fixtures":"v:装修",
"fizz":"v:兴奋;n:活跃",
"fizzle":"n:失败;v:告吹",
"fizzle out":"v:黄,告吹",
"fjord":"n:峡江",
"flab":"n:软组织;a:松弛",
"flabby":"a:松弛,虚弱,软弱",
"flaccid":"a:萎蔫;v:萎蔫",
"flaccid paralysis":"n:痿",
"flaccidity":"n:软弱",
"flack":"n:广告,高射炮,宣传,宣传员",
"flag":"n:旗帜,旗子,旗,标志,淡薄;v:衰退",
"flag of truce":"n:白旗",
"flagellate":"n:鞭毛藻,鞭毛虫;v:鞭打",
"flagellation":"n:鞭打",
"flagellum":"n:鞭毛",
"flagging":"n:下垂,松弛",
"flagman":"n:信号兵,旗手",
"flagon":"n:酒壶",
"flagpole":"n:旗杆",
"flagrant":"a:昭彰;v:臭名远扬",
"flagrantly":"d:悍然,明目张胆,横加",
"flagship":"n:旗舰",
"flagstaff":"n:旗杆,杠",
"flagstone":"n:石板",
"flail":"n:连枷;v:抽打",
"flair":"n:天资,天赋,眼力,才能,嗅觉,眼光",
"flak":"n:高射炮,谩骂,反对,谴责",
"flake":"n:薄片,片;v:衰退",
"flake out":"v:衰退,昏倒",
"flaking":"v:制片",
"flaky":"a:古怪,油酥",
"flamboyance":"n:浮夸,火红,艳丽,浮华",
"flamboyant":"a:好大喜功",
"flame":"n:火焰,火苗;v:点燃,发光,加热,闪光",
"flame-out":"v:熄火",
"flamethrower":"n:喷火器",
"flaming":"a:火红;v:火",
"flamingo":"n:火烈鸟",
"flammability":"n:可燃性",
"flan":"n:毛坯",
"flange":"v:镶边",
"flank":"n:侧面,侧翼,翼侧,面,厢房",
"flannel":"n:法兰绒,绒布,花招",
"flap":"v:摆动,拍打;n:盖,兴奋,边,活瓣,恐慌,瓣",
"flapjack":"n:烙饼,粉盒",
"flapper":"n:苍蝇拍,苍蝇拍子,小姑娘",
"flare":"v:摇曳,勃然大怒;n:张开,闪耀,光斑,光焰,火光,夸示",
"flare pass":"v:短传",
"flare up":"v:爆发,勃然大怒,发火,发怒,冒火,起火,犯,发作,炸,大发雷霆,动火,动怒,毛;d:动怒",
"flare-up":"n:盛况,狂欢,闪光,火焰,激怒,焚烧",
"flares":"n:喇叭裤",
"flaring":"v:蜿蜒",
"flash":"v:闪;n:闪现,一瞬间,肩章,刹那,黑话,短讯,焕发",
"flash point":"n:发火点",
"flashback":"n:倒叙;v:回火,倒叙",
"flashbulb":"n:闪光灯",
"flashgun":"n:闪光灯",
"flashing":"n:闪光;v:喷溅",
"flashlight":"n:手电筒,电筒,闪光灯,手电,闪光,电棒;v:闪光",
"flashy":"a:浮华,华",
"flask":"n:瓶,烧瓶,壶",
"flat":"n:公寓;a:没精打采;v:丢弃",
"flat bone":"n:扁骨",
"flatbed":"n:平板车",
"flatcar":"n:平板车,敞车,平车",
"flatfish":"n:比目鱼,偏口鱼",
"flatfoot":"n:警察,扁平足,平足",
"flathead":"n:傻子",
"flatiron":"n:熨斗,烙铁",
"flatland":"n:坝,平地",
"flatlet":"n:套房",
"flatly":"d:断然",
"flatness":"n:单调,平滑,萧条,平坦,果断",
"flats":"n:公寓,台面",
"flatten":"v:倒伏,碾,精简,压缩,打倒",
"flattening":"v:平整,矫正;n:扁率;a:平整",
"flatter":"v:奉承,谄媚,拍,吹捧,恭维,阿谀奉承,巴结,阿谀,捧场,拍马屁,捧,谄谀,拍马,阿谀逢迎,恭惟,逢迎,献媚,戴高帽子,吹,鼓励",
"flattering":"v:讨人喜欢",
"flattery":"n:奉承,恭维话,阿谀奉承,恭维,巴结,谬奖,高帽子,高帽儿,高帽",
"flattop":"n:航空母舰",
"flatulence":"n:空谈,星团,自负",
"flaunt":"v:夸耀,炫耀,飘扬,挥舞,宣扬,标榜,蔑视,逞,藐视,挥动;n:招展,夸耀,招摇,飘扬,夸示",
"flavor":"n:味道,风味;v:调味",
"flavoring":"n:调料,调味,香料,调味料,调味品,齐,佐料",
"flavors":"n:香精",
"flavour":"n:味道,风味,香味,气息,意味,情趣;v:调味",
"flavouring":"n:调味料,香料,佐料,调味,调料",
"flavours":"n:香精",
"flaw":"n:缺陷,缺点,裂纹,裂缝,漏洞,瑕疵,漏子,破绽,疵,疵点",
"flawless":"a:完美,滴水不漏,天衣无缝",
"flax":"n:亚麻,亚麻布,麻绳,麻纺,胡麻,麻",
"flay":"v:盘剥,掠夺,抨击,抢夺",
"flea":"n:跳蚤,虼蚤,蚤",
"flea market":"n:跳蚤市场",
"fleck":"n:标记,斑,雀斑,斑纹,斑点,微粒",
"fledgling":"n:雏儿,新手,雏鸟",
"flee":"v:逃离,逃跑,逃避,逃走,逃,消失,跑,奔逃,避开,逋,遁,避,出奔,亡,亡命,脱逃,窜,披靡,逃遁,逸,奔,出亡,逃之夭夭,消散,出逃",
"fleece":"v:刮,敲竹杠,搜刮,装饰,诈取;n:衬里",
"fleet":"v:变换;n:机群",
"fleeting":"v:稍纵即逝",
"fleetly":"d:浅",
"fleetness":"n:飞快,快速",
"flesh":"n:肉,肉体;v:发胖",
"fleshy":"a:肥厚,瓤,躯壳",
"flex":"v:弯,弯曲,窝;n:弯曲",
"flexed":"a:屈曲",
"flexibility":"n:灵活性,弹性,柔性,适应性,塑性,应变力,机动性,伸缩性",
"flexible":"a:灵活,柔软,弹性,软,柔,活动,机,机动,能上能下,活泛,软和,圆通;n:机,弹性;v:伸缩",
"flick":"n:抽动,斑点,毛皮,污点;v:弹,飘扬",
"flicker":"v:闪烁,摇曳;n:忽悠",
"flickering":"v:时隐时现",
"flier":"n:飞行员,梯级",
"flight":"n:班机,航班,楼梯,逃跑,飞翔,逃走,溃逃,航程,外逃;v:飞逝,飞行",
"flight attendant":"n:空中小姐,空姐",
"flight of steps":"n:阶梯,台阶",
"flightiness":"n:轻浮",
"flighty":"a:轻浮,浮",
"flim-flam":"n:胡扯",
"flimflam":"n:诡计,胡说,胡言乱语,梦话,欺诈;v:欺骗,欺诈",
"flimsiness":"n:脆弱",
"flimsy":"n:电报,薄纸;a:薄,单薄",
"flinch":"v:畏缩,退缩,畏缩不前;n:畏缩,退缩",
"fling":"v:扔,摔,抛,甩掉;n:踢",
"fling off":"v:甩掉",
"flint":"n:燧石,火石,打火石,燧",
"flint glass":"n:铅玻璃",
"flintlock":"n:火枪",
"flinty":"a:强硬",
"flip":"v:翻,弹,发疯,抽打,抽,抛掷,入迷;n:鸡尾酒,弹,筋斗,飞行,抛;a:冒失",
"flip one's lid":"v:大发雷霆",
"flip-flap":"n:烟火,爆竹,触发器",
"flip-flop":"n:触发器",
"flippancy":"n:轻率,无礼",
"flippant":"a:油头滑脑,轻口薄舌,轻浮",
"flipper":"n:挡泥板",
"flirt":"v:调情,玩弄,挥动,卖俏,摆动,调戏,挑逗,吊膀子,浅尝",
"flirt with":"v:调戏,玩弄,招,嬲,浅尝,吊膀子",
"flirtation":"n:调情,挑逗,调戏",
"flit":"v:飞,掠过,搬家,飞来,搬走,死亡,离开,移居,搬移,迁移",
"flitting":"v:搬运,搬移",
"float":"v:漂浮,漂,浮;n:菲律宾,浮船坞",
"floatation":"n:实行,设立,发行",
"floater":"n:浮子,游民,浮标,临时工",
"floating":"v:浮动,漂游,变色;a:浮动,流动",
"floating bridge":"n:浮桥",
"floating dock":"n:浮船坞",
"flock":"n:群;v:蜂拥",
"floe":"n:浮冰",
"flog":"v:鞭打,抽打,驱使,挞,鞭,胜过,拷,鞭挞,鞭笞,迫使",
"flogging":"n:鞭打",
"flood":"n:洪水,水灾,泛滥;v:沦陷,漫溢,进水,泛,灌溉;a:滥",
"flood plain":"n:冲积平原",
"flood tide":"n:潮汛,大潮,高峰",
"floodgate":"n:闸门,大量,水闸,闸,制约,水门",
"flooding":"n:泛滥,灌溉,变色,漫灌,充溢,血崩;v:血崩,漫灌",
"floodlight":"n:探照灯",
"floor":"n:地板,地,地面,楼,楼板,楼层,底;v:难倒,打败",
"floor board":"n:地板",
"floor lamp":"n:落地灯",
"floorboard":"n:地板",
"flop":"v:失败,跳动,上床;n:床,过夜;d:扑通",
"flophouse":"n:监狱",
"flopping":"v:扑通",
"floppy disk":"n:软磁盘,软盘",
"flora":"n:植物,草木",
"floral envelope":"n:花被",
"florence":"n:佛罗伦萨",
"florentine":"a:佛罗伦萨",
"florescence":"n:开花,花期",
"florid":"a:绚丽;n:红润",
"florida":"n:佛罗里达",
"floridness":"n:华丽",
"florist":"n:花匠,花店",
"floss":"n:绒毛,丝棉,丝绵",
"flotation":"n:发行",
"flotilla":"n:船队",
"flotsam":"n:废料,废物,零碎",
"flounce":"v:挣扎,跳动",
"flounder":"n:比目鱼,挣扎",
"flour":"n:面粉,粉,面,粉末,白面",
"flour mill":"n:磨坊",
"flourish":"v:茂盛,挥舞,繁荣,盛行,活跃,兴旺发达,发,繁盛,欣欣向荣,夸示,抡,手舞足蹈,舞,摇动;n:花边,兴旺,挥舞,丰富多彩,茂盛,繁荣,花招,挥动;a:发",
"flourishing":"a:发达,繁华,兴隆,炽盛,繁荣,兴盛,昌明;v:盛,兴旺,华;n:华",
"flout":"n:嘲笑,侮辱,侮慢;v:轻视,藐视,嘲笑",
"flow":"v:行经;n:飘拂,丰满,洋溢,月经,滔滔,川流不息,飘动,飘扬",
"flow away":"v:流逝,流失",
"flow chart":"n:框图",
"flow diagram":"n:框图,流程图",
"flow out":"v:倾泻",
"flow rate":"v:流量",
"flow sheet":"n:流程图",
"flowchart":"n:流程图",
"flower":"n:花,鲜花,花儿,花朵,花卉;v:成长,兴旺",
"flower arrangement":"n:插花",
"flower bed":"n:花坛",
"flower bud":"n:花芽,骨朵,蕾,蓓蕾",
"flower head":"n:头状花序",
"flower petal":"n:花瓣",
"flower stalk":"n:花柄",
"floweriness":"n:绚烂",
"flowering":"n:开花;v:显露",
"flowering plant":"n:显花植物",
"flowerpot":"n:花盆",
"flowers":"n:花卉",
"flowery":"a:花,花哨;n:花哨",
"flu":"n:流感,感冒,伤风",
"flub":"n:错误,过失",
"fluctuate":"v:波动,起伏,增减,变动,涨落,徘徊,浮动;n:涨落",
"fluctuating":"v:波动",
"fluctuation":"n:波动,起伏,涨落,脉动,踌躇",
"fluctuations":"v:脉动",
"flue":"n:烟道,火龙,拖网",
"flue pipe":"n:烟道",
"fluency":"n:流利,流畅",
"fluent":"a:流利;n:变量,变数,水流",
"fluently":"d:流利,滚瓜烂熟",
"fluff":"v:弹,忘记,起毛,说错;n:绒羽,错误,说错,汗毛",
"fluffy":"a:蓬松,暄,松软,蓬",
"fluid":"n:流体,液体,流质,液;a:流质",
"fluid mechanics":"n:水力学",
"fluidity":"n:流质",
"fluke":"n:侥幸,肝蛭,倒楣,幸运",
"flume":"n:水槽,渡槽,峡谷,风洞,垮台",
"flummox":"v:狼狈;n:失败",
"flunk":"v:放弃,失败;n:失败",
"flunky":"n:奴才,走狗,仆从,马屁精",
"fluorescence":"n:荧光",
"fluorine":"n:氟",
"fluorite":"n:萤石,氟石",
"flurried":"a:毛,慌里慌张,张皇,慌张,慌,慌乱;v:慌,张皇,毛,慌乱,慌张",
"flurry":"n:暴雨,阵风,慌张,飓风,小雪,风雪,混乱,疾风;v:慌张,匆忙,搅乱",
"flush":"v:冲;n:激增,新鲜,奔流,辉耀,激发;a:饱满",
"flushed":"v:扬扬自得;d:扬扬自得",
"fluster":"v:喝醉,混乱,惊慌失措,慌张,扰乱,着慌;n:醉,混乱,激动",
"flustered":"a:张皇;v:张皇,慌张",
"flute":"n:笛子,长笛,横笛,笛,凹槽",
"fluting":"n:凹槽",
"flutter":"v:飘扬,拍,拍打,飘动,飘,抖动,颤动,招展,飘荡,扑,扇,振,坐立不安,浮动,飞舞,扑棱,披拂;n:波动,不安,飘扬,焦急",
"flux":"n:磁通量,流,流动,熔剂,流量,焊剂,带,地带,电通量,流出,腰带,波动,腹泻;v:涨,流出,流动,涨潮,熔化",
"fly":"v:飞,飞行;n:飞花",
"fly ash":"v:浮尘,烟尘,粉煤灰",
"fly sheet":"n:传单,广告,小册子",
"fly the coop":"v:逃跑",
"fly-by-night":"n:夜游神",
"flyaway":"n:海市蜃楼",
"flyby":"n:飞越;v:飞越",
"flycatcher":"n:捕蝇器,蝇虎",
"flying":"n:飞花,飞跑;v:飞行",
"flying bird":"n:飞鸟",
"flying boat":"n:飞船",
"flying bomb":"n:飞弹",
"flying field":"n:机场",
"flying fish":"n:飞鱼",
"flyleaf":"n:扉页",
"flyover":"n:飞越,旱桥;v:飞越",
"flypaper":"n:捕蝇纸",
"flyswatter":"n:苍蝇拍子,苍蝇拍,蝇拍",
"flytrap":"n:捕蝇器",
"flywheel":"n:飞轮",
"fm":"n:调频",
"foal":"n:马驹,驹子;v:生",
"foam":"n:泡沫,泡沫塑料;v:汹涌,起泡",
"fob":"n:诡计",
"focal point":"n:重点",
"focal ratio":"n:焦比",
"focus":"n:焦点;v:注视,对光",
"focus on":"n:眷注,注",
"focusing":"v:聚焦,调焦",
"fodder":"n:饲料,弹药,刍秣,料,粗饲料,草料",
"foe":"n:敌人,敌,仇敌,冤家,穷寇,敌军,对手,仇家,仇人,敌手,寇仇,冤头,仇,强敌,敌兵",
"foetal circulation":"n:胎位",
"foetus":"n:胎",
"fog":"n:雾,浓雾,雾气,灰雾,烟雾,迷惑不解,模糊;v:蒙蔽",
"foggy":"a:漠漠",
"foible":"n:缺点,癖好",
"foil":"n:衬托,箔;v:挫败,打破,衬托",
"foist":"v:挡住,隔开",
"fold":"v:折叠,包;n:圈,洼;d:嗡",
"fold up":"v:关门大吉,倒闭",
"folder":"n:文件夹,折;v:折",
"folding":"v:折皱,褶皱,轮牧,折叠,折页;n:折页,折皱",
"folding chair":"n:折椅",
"folding money":"n:巨款,纸币",
"foldout":"n:插页,折页",
"foliage":"n:树叶,叶子,叶",
"folio":"v:对折,对开;n:页码,对折;a:对开",
"folk":"n:人们,家属,老百姓,民,民间,亲属,世人,人民,亲戚,种族;a:土",
"folk dance":"n:秧歌,土风舞",
"folk music":"n:民谣,民乐",
"folk song":"n:风谣,山歌",
"folklore":"n:民俗学",
"folks":"n:乡亲",
"folksong":"n:民歌",
"folkway":"n:民俗,习惯",
"folkways":"n:民俗",
"follicle":"n:卵泡,毛囊,囊",
"follicular":"a:卵泡",
"follies":"n:活报剧",
"follow":"v:跟着,跟,接着,遵循,注意,跟随,追随,随后,随,从事,照,听从,则,继,回答,追求,注视,仿效,追赶,遵从,伴随,了解,仿照,沿袭,因袭,接续,照办,穷追,信奉,率,倾听,因循,追击,准,领悟,相随,遵行,一板一眼;p:因,从,由,继,循;n:法,追随,跟随",
"follow out":"v:完成",
"follow suit":"v:踵武,如法炮制",
"follow up":"v:回答,追击;n:后续",
"follow-through":"n:网球",
"follow-up":"n:随访;v:跟进",
"follower":"n:追随者,部下,跟随者,徒,学生,手下,门徒,门下,随员,属下,从,弟子,推杆,信徒",
"following":"p:在_以后,之后,以后,在_之后;n:下面,追随者,随员,部属;v:跟踪,隔;d:随着;a:下列",
"folly":"n:愚蠢,蠢事,傻话,愚笨,放荡,罪恶",
"foment":"v:激起,助长,煽动,热罨,挑拨,挑起,酝酿,热敷",
"fomentation":"n:助长,煽动",
"fond":"a:喜欢,爱好",
"fondle":"v:抚摸,抚弄,抚爱,抚摩,盘弄,爱抚",
"fondness":"n:喜爱,喜欢,宠爱,溺爱,嗜好,轻信",
"font":"n:字体;v:浇铸",
"fontanel":"n:囟门",
"food":"n:食物,食品,粮食,饭,菜,伙食,食粮,粮,食,膳食,食料,材料,餐,养料,饭食,口腹,吃食,资料,馔",
"food chain":"n:食物链",
"food court":"n:食品街",
"food cycle":"n:食物链",
"food for thought":"n:心事",
"food grain":"n:粮食作物",
"foodstuff":"n:食品,粮食",
"fool":"v:骗;n:憨子,笨伯;a:愚",
"fool around":"v:闲荡,瞎闹,不务正业",
"fool away":"v:浪费,虚度",
"fool's gold":"n:黄铜矿,黄铁矿",
"fool's paradise":"n:黄梁美梦",
"foolhardiness":"n:匹夫之勇,蛮干",
"foolhardy":"a:槔,有勇无谋,愣,暴虎冯河,愣头愣脑;v:有勇无谋",
"fooling":"v:开玩笑,戏弄",
"foolish":"a:愚蠢,傻,蠢,愚笨,笨,痴呆,蠢笨,愚,呆笨,浑;v:混",
"foolishly":"d:瞎",
"foolishness":"n:愚蠢,傻气,鲁莽,傻劲,傻劲儿",
"foot":"n:脚,脚步,足;v:结,跳,跳舞",
"foot race":"n:竞走",
"foot soldier":"n:马前卒",
"foot up":"n:总计",
"footage":"n:尺码,长度",
"football":"n:足球,橄榄球,玩物",
"footfall":"n:脚步",
"foothold":"n:立足之地,立足点,凉鞋,据点",
"footing":"n:基础,关系,立足点,基址;v:合计",
"footlights":"n:脚灯",
"footman":"n:步兵,侍者,马弁,仆从,跟班",
"footmen":"n:侍者,步兵",
"footnote":"n:脚注,注脚",
"footpath":"n:人行道,小路,走道,径,蹊",
"footprint":"n:脚印,足迹,躅,踪迹,踪,蹊",
"footsie":"n:调情,脚;v:调戏",
"footstep":"n:脚步,脚印,履,武,足迹,步子,踏板,支座,台阶",
"footsteps":"n:后尘,脚步",
"footstool":"n:大地",
"footwear":"n:鞋袜",
"footwork":"n:步法",
"fop":"n:花花公子",
"foppery":"n:打扮",
"for":"p:为,给,用,以,为了,向,对于,于,由于,替,作为;c:盖",
"for a while":"p:一忽儿,小,片刻",
"for anything":"p:无论如何",
"for dear life":"p:拼命",
"for example":"p:比方,比如,譬如,如,拿,比如说;d:比方",
"for fear of":"p:以免,害怕",
"for good":"p:永久,永远",
"for instance":"d:比如,比如说,如",
"for lack of":"p:因缺乏",
"for sake of":"p:为了,起见,为了_起见",
"for sale":"p:出售",
"for sure":"d:确定,准保,确实",
"for the benefit of":"p:利益,为了_的利益",
"for the moment":"p:姑,暂",
"for the purpose of":"p:为了",
"for the sake of":"p:为了",
"forage":"n:饲料,草料,粮秣;v:掠夺",
"foray":"n:突袭,侵略,摧残,掠夺;v:突袭",
"forbear":"v:克制,忍耐,隐忍,节制,抑制,自制;n:先驱",
"forbearance":"n:克制,忍耐,忍让",
"forbears":"n:太祖,祖先,祖宗,宗",
"forbid":"v:禁止,不准,不许,阻止,禁,取缔,妨害",
"forbidden":"v:禁用,不可;a:不可",
"forbidden city":"n:故宫",
"force":"n:力,力量,部队;v:驱迫;d:强行;a:威武",
"force majeure":"n:不可抗力",
"force out":"n:挤出",
"force-out":"n:封杀",
"forced":"v:凿空",
"forced sale":"n:拍卖",
"forceful":"a:有力,强有力,遒,有劲,苍老,强劲,雄浑,带劲,泼辣,挺拔",
"forcefully":"d:使劲",
"forceps":"n:焊钳,镊子,钳子",
"forces":"n:部,人马",
"forcing":"v:加压;n:强制",
"ford":"v:蹚;n:水体,浅滩,津",
"fording":"n:渡口;v:渡口",
"fore":"n:头",
"forearm":"n:前臂",
"forebear":"n:祖宗,祖先",
"forebode":"v:预示,预感,预言,预知",
"foreboding":"n:预感,预示,预知,预报,先兆",
"forecast":"n:预报,预测;v:展望",
"forecaster":"n:预报员",
"forecasting":"v:预报,预测",
"foreclose":"v:逐出,排除,妨碍,结束,停止",
"foreclosure":"v:妨碍,结束,阻止;n:妨碍,结束,阻止",
"forecourt":"n:前院",
"forefather":"n:祖先,前人,祖宗,老祖宗,先人",
"forefathers":"n:祖辈,祖先,祖宗,太祖,先世,宗,前人",
"forefinger":"n:食指;v:填写",
"forefoot":"n:前脚",
"forefront":"n:第一线,中心,前列",
"foregoing":"v:上面;n:上面",
"foregone conclusion":"n:定局",
"foreground":"n:前景,前台",
"forehead":"n:前额,额头,额,脑门子,脑门,脑门儿,颡,眉宇",
"foreign":"a:外国,对外,外来,洋,番;n:番",
"foreign aid":"n:外援,援外",
"foreign country":"n:异域,异国,外国,外,夷,异邦",
"foreign exchange":"n:外汇",
"foreign minister":"n:外长",
"foreigner":"n:外国人,洋人,夷,外地人,外族,老外,外人,陌生人",
"foreigners":"n:老外",
"foreknow":"v:预知",
"foreknowledge":"n:先见之明,预知;v:预知",
"foreleg":"n:前肢",
"forelimb":"n:前肢,上肢",
"foreman":"n:工头,领班,工长,监工,工段长",
"foremost":"a:前沿;d:首先",
"forename":"n:名",
"forenoon":"n:上午,午前,前晌,前半天,上半天,前半晌,上半晌,头晌",
"foreordain":"v:注定",
"forepart":"n:前面",
"forerunner":"n:先驱者,先驱,先导,前兆,先行者,祖先,前驱,嚆矢",
"forerunners":"n:先进",
"foresee":"v:预见,预知,料到,未卜先知,逆料,看穿",
"foreseeable":"a:能掐会算",
"foreshadow":"v:预示;n:预兆",
"foreshadowing":"v:预测,铺垫;n:前兆,伏笔",
"foreshore":"n:海滩",
"foreshorten":"v:省略,缩短",
"foreshortening":"v:减缩",
"foresight":"n:远见,预见,深谋远虑,远谋,眼光,远景,远虑",
"foreskin":"n:包皮",
"forest":"n:森林,林木,丛林,林子,林区,林,山林",
"forestall":"v:阻碍,抢先,垄断,阻止,防止,囤积居奇",
"forestation":"n:造林",
"forestry":"n:林业,森林学,林地,林,林学",
"foretaste":"n:预兆,征兆,预感,预示",
"foretell":"v:预言,预卜,卜,兆,预示;n:兆",
"foretelling":"v:预言",
"forethought":"n:远见卓识,深谋远虑,预谋",
"forever":"d:永远,永生,永久,永世,恒久,万古,万古千秋,永,终古,不断,长;a:永久,长;v:永生;n:万古",
"forewarn":"v:有言在先",
"forewarning":"v:前兆",
"foreword":"n:序文,叙言,题词,序言,弁言,引言,前言,小引",
"forfeit":"v:丧失,失去,失掉,罚;n:罚金",
"forfeiture":"n:没收,丧失,罚金",
"forgather":"v:聚会,交往",
"forge":"v:锻造,伪造;n:锻炉",
"forged":"v:假,伪;a:假,伪",
"forger":"n:锻工",
"forgery":"n:伪造,伪造罪,伪造品",
"forget":"v:忘,忘记,忘掉,忘却,忘怀,遗忘,谖,失记,佚",
"forgetful":"a:健忘,马大哈,健旺,丢三落四,昏头昏脑;v:丢三落四;n:马大哈",
"forgetfulness":"n:忘性",
"forging":"n:锻件,锻造;v:锻造",
"forgive":"v:原谅,宽恕,饶恕,饶,恕,宥,假借,涵容,宽宥,原宥,宽贷,包容,谅,贷,宽假,免除,宽饶,包涵,担待",
"forgiveness":"n:饶恕",
"forgiving":"a:宽大为怀;v:宽大为怀",
"forgo":"v:放弃,谢绝",
"fork":"n:叉子,岔口,岔路,分岔;v:支付,分歧,交付",
"forked":"v:丫杈,桠杈;a:分叉;n:丫杈",
"forking":"v:分叉;n:分支",
"forklift":"n:叉车,铲车,铲运车",
"forlorn":"a:凄迷",
"forlornness":"n:愁思",
"form":"n:形式;v:建造,塑造,养,造,编成,裁,成型,构",
"form of address":"n:称呼",
"formal":"a:正式,正儿八经",
"formaldehyde":"n:甲醛",
"formalin":"n:福尔马林",
"formalism":"n:形式主义",
"formalities":"n:手续",
"formality":"n:礼节,拘谨,俗套,形迹",
"formalization":"n:定形",
"formalize":"v:形成",
"format":"n:格式,形式,格式化,安排,规格,间架;v:构成,设计",
"formation":"n:形成,结构,队形,层,构成,建造,组织,组,队列,构造;v:形成,成形,建造,组成",
"former":"a:前,原来,原,旧,昔,先是;n:靠模,样板,先是;c:故",
"formerly":"d:以前,从前,过去,前,曾,当初,原本,在先,向日;n:当初,以往",
"formic acid":"n:蚁酸",
"formica":"n:酚醛,胶木",
"formidable":"a:艰巨,强大,堂堂,利害,厉害",
"forming":"v:成型,成形;n:成型,成形",
"formosa":"n:台湾",
"formula":"n:公式,方案,配方,提法,套语,式,程式,准则,处方,套,表述,式子,方子",
"formulae":"n:公式",
"formulate":"v:制定,规定,计划,制订,配制,构想,创制",
"formulating":"v:公式化",
"formulation":"n:表述,提法,讲法,说法;v:公式化",
"fornicate":"v:私通,通奸",
"fornication":"n:拱顶,私通,通奸",
"forsake":"v:遗弃,放弃,抛弃,丢弃,革除,舍弃,背叛,摽",
"forsaken":"v:飘零",
"forsooth":"d:的确",
"forswear":"v:放弃,背弃",
"forsythia":"n:连翘",
"fort":"n:堡垒,要塞,碉堡,炮位,堡,市集,炮台",
"forte":"n:擅长,长,拿手好戏,长处;d:加强",
"forth":"d:爆发,向前,以后",
"forthcoming":"n:临近,来临",
"forthright":"a:简捷,直爽,明朗,豪爽,痛痛快快,痛快,粗豪,爽直,明快,快,直性;d:立刻;n:直性子",
"forthwith":"d:立即,立刻,即时",
"fortification":"n:防御工事,堡垒,要塞,强化,高墙,坚;a:坚",
"fortifications":"n:碉堡,工事",
"fortify":"v:加强,增强,设防,鼓舞",
"fortitude":"n:刚毅,坚毅,坚忍,不屈不挠",
"fortnightly":"n:双周刊,半月刊",
"fortress":"n:堡垒,要塞,堡",
"fortuitous":"a:偶然,偶发,巧",
"fortuity":"n:偶然性,偶然",
"fortunate":"a:幸运;v:走运",
"fortunately":"d:幸好,幸亏,幸而,好在,多亏;v:亏;a:凑巧",
"fortune":"n:财产,命运,运气,好运,幸运,财富,时运,命,巨富;v:运",
"forum":"n:论坛,讲坛,讨论会,座谈会,广场,坛",
"forward":"d:向前,前进,出来;v:促成,促进;n:期货",
"forwarding":"n:推进,运输,托运,促进",
"forwardness":"n:进取,鲁莽,热心,早熟,进步,唐突",
"fossil":"n:化石",
"fossil oil":"n:石油",
"fossilize":"v:过时,僵化,陈腐",
"foster":"v:助长,扶植,促进,养育,培养,培育,鼓励,培植,怀抱,养,栽培,寄,培,哺育,抚养,抚育,扶养",
"foster child":"n:养女",
"foster daughter":"n:养女,义女",
"foster father":"n:养父",
"foster mother":"n:养母",
"foster son":"n:养子,义子",
"foster-mother":"v:收养,抚养",
"foul":"v:污染,犯规;a:污浊,卑污,恶浊,脏,污秽;n:脏物",
"foul ball":"n:界外球",
"foul play":"n:欺诈,暴行",
"foul up":"v:砸",
"foul-smelling":"a:臭乎乎",
"foul-up":"n:故障,混乱,乱七八糟",
"fouling":"v:污垢",
"found":"v:建立,创建,创办,成立,创立,开办,建,设立,铸造,开创,立,熔铸,创,打基础,缔造,设,开设,树立,创设",
"foundation":"n:基础,地基,基金会,根据,根本,房基,根基,建立,基金,底子,根,依据,创立,根底,墙脚,底色,地脚,模型,底,底座,基业,建设,捐款,衬里,创设,宅基,址,基,财团",
"founder":"n:创始人;v:陷落,损害,破坏",
"foundering":"v:陷落",
"founding":"v:熔铸,铸造",
"founding father":"n:元勋",
"foundling":"n:弃儿,弃婴",
"foundry":"n:铸造;v:铸造",
"fount":"n:源泉",
"fountain":"n:喷泉,源泉,泉,喷水池,泉水,饮水器,河源,根源",
"fountain pen":"n:钢笔,自来水笔,金笔",
"fountainhead":"n:源泉,水源,源头,根源,泉源,源,本源",
"four":"a:四",
"four-letter word":"n:粗话",
"foursome":"n:双打",
"fowl":"n:鸡,家禽,飞禽",
"fox":"n:狐狸,狐皮,狐,绳索;v:欺诈,褪色,欺骗",
"foxglove":"n:毛地黄,洋地黄",
"foxhole":"n:避弹坑",
"foxiness":"n:褐斑",
"foxtail millet":"n:小米,粟",
"foxy":"a:滑头,刁滑,滑头滑脑,油滑",
"foyer":"n:门厅,休息室,炉",
"fracas":"n:吵闹,斗殴",
"fraction":"n:分数,分,一些,碎片,分式;a:分毫;d:分级",
"fractional":"a:零",
"fractional distillation":"n:分馏",
"fractionate":"v:分馏",
"fractionation":"n:分馏",
"fracture":"n:断裂,骨折;v:破裂",
"fradicin":"n:新霉素",
"fragile":"a:易碎,脆,脆弱,娇,娇嫩",
"fragility":"n:易碎性,脆性,虚弱,脆弱,脆弱性;a:脆弱",
"fragment":"n:碎片,碎块,片段,片断;v:碎裂,分裂,分段",
"fragmentary":"a:残缺不全,戋戋,碎,零星,零碎,鸡零狗碎,残缺,零零星星",
"fragmentation":"n:断裂,分割;v:分裂,断裂,分割",
"fragmenting":"v:分割",
"fragments":"n:一鳞半爪,断编残简,碴,碴儿,鳞爪,碎片",
"fragrance":"n:香味,芳香,香气,芬芳,香水,清香,馨香,芬,馥,芳泽,芗",
"fragrant":"a:芳香,芬芳,甜蜜,香,芬,喷香;n:芳香",
"frail":"a:脆弱,单薄,衰弱,娇嫩,薄弱;n:少妇,少女",
"frailty":"n:弱点,过失,脆弱;a:脆弱",
"frame":"n:框架,帧,框,构架,身躯,结构;v:组织,坑害,设计,作出",
"frame of mind":"n:情绪,心气",
"frame of reference":"n:参照系",
"frame up":"n:图谋",
"frame-up":"n:阴谋,陷害,诬害",
"framework":"n:结构,骨架,框架,体制,组织,构架,架子,骨骼,骨,机构",
"framing":"n:结构,骨骼,组织,编制,镶,构想,框架,计划",
"franc":"n:法郎",
"france":"n:法国,法兰西",
"franchise":"n:选举权,特权,控制权,公民权,豁免权,特许权;v:特许",
"franchiser":"n:经销商",
"frangibility":"n:脆弱性,脆弱",
"frank":"a:坦率,坦白,老实,直率,明白,率直,率,直肠子,直心眼儿,爽直,直爽,爽快,直,耿直;v:释放,豁免;n:直肠子",
"frankincense":"n:乳香",
"franking":"v:邮费;n:邮费",
"franklin":"n:富兰克林",
"frankly":"d:平心而论,实际上",
"frankness":"n:坦白,率直,襟怀坦白",
"frantic":"a:狂暴,狂妄",
"frantically":"d:疯了呱几",
"fraternal":"n:兄弟;a:兄弟",
"fraternise":"v:友善,亲近,私通,亲如兄弟",
"fraternity":"n:博爱,友爱,同行,平等,同仁,会友",
"fraternize":"v:友善,亲如兄弟,亲近,通敌,私通",
"fratricide":"n:兄弟",
"frau":"n:妻",
"fraud":"n:骗子,欺诈,欺骗,骗局,舞弊,诈欺,弊",
"fraudulence":"n:欺诈",
"fraudulent":"a:奸诈",
"fraudulently":"d:冒",
"fraught":"n:货物",
"fraulein":"n:姑娘",
"fray":"v:磨,磨损;n:辩论,吵架",
"frazzle":"v:磨损,疲倦;n:累倒",
"freak":"n:怪事,异想天开,怪胎,畸形,奇想,怪物,斑点,条纹",
"freakish":"a:异想天开",
"freckle":"n:雀斑,斑点",
"free":"v:解放,解脱,解救;a:倜傥,旷达;d:免费;n:空闲",
"free kick":"n:任意球",
"free of charge":"v:白,免票,分文不取",
"free port":"n:自由港",
"free rein":"n:随意",
"free time":"n:工夫,余暇,空儿,空,空闲",
"free will":"v:自愿",
"free-for-all":"n:大吵大闹,打群架",
"freebie":"n:赠品",
"freebooter":"n:海盗",
"freedman":"n:自由民",
"freedom":"n:自由度,随意,特权,自由王国,特许,优美;a:自由",
"freely":"d:自由,自如,纵横;a:自如;n:浪",
"freeman":"n:公民,自由民",
"freestyle":"n:爬泳",
"freeway":"n:高速公路",
"freeze":"v:结冰,冻,冻结,冷;n:结冰,冷遇,凝冻;a:冷",
"freeze out":"v:排斥",
"freezer":"n:冰箱,冷冻机,电冰箱,冷库,冷藏车,冷藏库",
"freezing":"v:天寒地冻,凝固,冷冻;n:冻结,结冰",
"freezing mixture":"n:冷冻剂",
"freight":"n:货物,货运,运费;v:充满",
"freight elevator":"n:起重机",
"freighter":"n:货轮,货船,运输机,货主",
"french":"n:法文,法兰西",
"french bean":"n:豆角,豆角儿,菜豆",
"french chalk":"n:滑石粉",
"french horn":"n:圆号",
"french window":"n:落地窗",
"frenzied":"a:狂乱,疯狂",
"frenzy":"n:狂乱",
"freon":"n:氟利昂",
"frequency":"n:频率,次数,频,频度,周率,视频,屡次,频仍",
"frequency band":"n:频段",
"frequency modulation":"n:调频",
"frequent":"a:常,频繁,频仍,勤",
"frequenter":"n:常客",
"frequently":"d:经常,常常,常,往往,频繁,时常,频频,数,不时,屡次三番,屡次,频,一动;v:动",
"fresco":"v:壁画;n:壁画",
"fresh":"a:新鲜,新,清新,鲜;d:刚,新,才;n:开始,泛滥",
"fresh breeze":"n:疾风",
"fresh fish":"n:鲜鱼",
"fresh gale":"n:大风,强风",
"fresh water":"n:甜水,淡水,淡水湖",
"freshen":"v:添,盥洗,刷新",
"freshen up":"v:盥洗",
"freshener":"n:清凉剂",
"freshly":"d:新,刚,新近,才;a:新",
"freshman":"n:新手",
"freshmen":"n:新手",
"freshness":"n:清新,新",
"freshwater":"a:淡水;n:淡水",
"freshwater mussel":"n:河蚌",
"fret":"v:发愁,烦恼,侵蚀;n:烦恼",
"friar":"n:修道士,修士",
"friary":"n:修道院",
"fricative":"n:摩擦音,擦音",
"friction":"n:摩擦,摩擦力,冲突,阻力,不和,倾轧;v:摩擦",
"friday":"n:礼拜五,周五",
"fridays":"d:星期五",
"fridge":"n:冰箱,冷冻机",
"fried rice":"n:炒饭",
"friend":"n:朋友,老朋友,交,友人,友好,友,自己人,家属,助手,熟人,随从;c:故;a:友好",
"friendless":"a:孤单",
"friendliness":"n:友谊",
"friendly":"a:友好,友善,好,和气,近乎,和睦",
"friendship":"n:友谊,友情,交,深交,情谊,谊,交情,交谊,情义,和气",
"frig":"v:冰箱",
"frigate":"n:护卫舰,护航舰",
"fright":"n:惊吓,恐怖,恐慌;a:恐慌",
"frighten":"v:吓,害怕,惊恐,吓倒,惊,吓唬,恐吓,吃惊,恫吓,惊吓,恫;a:吃惊",
"frightened":"a:恐惧,恐慌,惊骇,毛",
"frightening":"a:可怕,吓人,怕人",
"frightful":"a:可怕;v:害怕",
"frightfully":"d:非常",
"frightfulness":"n:丑恶,恐怖",
"frigid":"a:冷淡,寒冷",
"frigidity":"n:冷淡,寒冷,索然无味;a:寒冷",
"frill":"n:妇女",
"frills":"n:臭架子",
"fringe":"n:条纹,边缘,刘海儿,穗子,流苏,重影,穗,边沿;v:镶边,围绕",
"fringe benefit":"n:油水",
"fringed pink":"n:蘧",
"frisk":"v:搜身;n:欢跃",
"fritter":"v:消耗;n:碎片,烙饼",
"fritter away":"v:消磨,浪费",
"frivolity":"n:轻浮,轻佻",
"frivolous":"a:轻浮,轻佻,轻薄,癫狂,不三不四,薄,佻",
"frizzle":"d:吱;n:卷发",
"fro":"d:去,回",
"frock":"n:外衣,僧袍,工装,工作服,军大衣",
"frog":"n:青蛙,蛙,蛤蟆,虾蟆,田鸡",
"frogman":"n:蛙人,潜水员",
"frogmen":"n:蛙人",
"frolic":"v:嬉戏;n:玩乐",
"from":"p:从,就,来,由,来自,于,离,自,开始,跟,起,打,连,级,经由,诸,打从;n:级,由;r:诸",
"from lack of":"p:因缺乏",
"frond":"n:叶子,卷曲,叶;v:卷曲",
"front":"n:前线,战线,前面;v:领导;a:前",
"front door":"n:前门,正门",
"front line":"n:前线",
"front matter":"n:前言",
"front porch":"n:前沿",
"front room":"n:前房",
"front tooth":"n:板牙,门牙",
"frontage":"n:面临,正面,前面,眼界",
"frontal":"n:舌面前音,正面",
"frontal bone":"n:额骨",
"frontier":"n:边境,边界,边疆,前沿,尖端,边陲,边地,国境,边,边缘",
"frontiers":"n:疆界",
"frontispiece":"n:门脸",
"frost":"n:霜,霜冻,严寒,冷淡,冰冻,扫兴;v:冰冻",
"frostbite":"n:冻疮;v:冻伤",
"frostbitten":"v:霜害",
"frosting":"n:糖霜",
"frosty":"a:冷,冷冰冰,冷若冰霜,严寒",
"froth":"n:泡沫,空谈,沫子,泡,废物,沫,渣滓,空想",
"frown":"v:皱眉头,皱眉;n:皱眉",
"frown upon":"v:看不惯",
"frozen":"v:结冰,冰冻",
"fructify":"a:结实;v:结实",
"fructose":"n:果糖",
"frugal":"a:俭,仔细,节俭,克己,俭约,约,俭省",
"frugality":"n:俭朴,节俭,节约",
"frugally":"d:俭省",
"fruit":"n:水果,果实,结果,果子,果,成果,果品,收获,结晶,收入;a:实,结实;d:果",
"fruit bat":"n:果蝇",
"fruit grower":"n:果农",
"fruit juice":"n:露,果子露",
"fruition":"n:实现,成就,享用,享有;v:享受,享用",
"fruitless":"a:白搭,无效;v:白搭,一无所获",
"fruits":"n:果实",
"frump":"n:老古董,老顽固",
"frustrate":"v:挫败,破坏,阻挠,摧折,挫,挫折",
"frustrated":"a:惘然",
"frustrating":"v:泄气,大煞风景",
"frustration":"n:挫折,失败,挫败",
"fry":"n:鱼秧,烦恼,鱼苗,鱼花;v:煎,炒,油炸",
"fryer":"n:肉用鸡",
"frying pan":"n:锅子",
"fuck all":"v:绝非",
"fuck off":"v:滚开,滚蛋",
"fucking":"v:干",
"fuddle":"n:一团糟,烂醉;v:灌醉,糊涂",
"fuddy-duddy":"n:老古董",
"fudge":"v:捏造;n:胡言,梦话",
"fuel":"n:燃料,薪;v:加油",
"fueling":"v:加油",
"fuelling":"v:加油",
"fugitive":"n:逃犯,亡命之徒,逃亡者,流浪者",
"fugitive from justice":"n:逃犯",
"fuji":"n:富士山",
"fulcrum":"n:支点,支柱",
"fulfil":"v:完成,履行,执行,满足,应验;d:遂",
"fulfill":"v:了,完成,履行,满足,达到,应验,兑现,执行,符合,落实,满,履,遂,遵守,酬;d:遂",
"fulfillment":"n:履行,完成",
"fulfilment":"n:实践",
"full":"a:满,充分,全,完全,客满,整整,饱满;n:充分;v:圆,宽大,充盈,充,满;d:整整",
"full blood":"n:纯种",
"full dress":"n:大礼服",
"full general":"v:上将",
"full house":"n:爆满",
"full moon":"n:望",
"full of life":"n:跃然纸上,盎,活泼,生机盎然",
"full page":"n:整版",
"full point":"n:句号",
"full stop":"v:终止符",
"full-bodied":"a:魁梧",
"full-length":"a:全身,全长",
"full-scale":"a:完整",
"full-time":"a:全日制",
"fullback":"n:后卫,足球",
"fuller's earth":"n:硅藻土",
"fullness":"n:丰满,丰富,充满,充实,浓度,完全,洪亮,满,纯度,强烈,深度",
"fully":"d:完全,充分,十分,足足,足,大,饱,备,悉数,透;a:完全,酣畅,饱,充分",
"fully grown":"a:成",
"fulminate":"v:爆炸,爆发,轰鸣,怒骂,声色俱厉,义正辞严;n:雷汞",
"fulmination":"n:闪电,爆炸",
"fumble":"v:摸索,摸,搜寻,摸弄,失球;n:失球,摸索",
"fume":"v:冒,冒烟;n:激怒,香气,水蒸气,发怒",
"fumigate":"v:烟熏,熏蒸,熏,烧",
"fun":"n:娱乐,意思,趣事,兴趣,来头,逗乐;v:开玩笑",
"funafuti":"n:富纳富提",
"function":"n:函数,功能,作用,职能,机能,职务,职责,宴会,集会;v:运行",
"function word":"n:虚字",
"functional":"a:实用",
"functional illiterate":"n:半文盲",
"functionality":"n:机能",
"functionary":"n:官员,职员",
"fund":"n:资金,基金,钱,款项;v:投资",
"fundamental":"n:基本,根本,原则,基音,原理,基础,元;a:基本",
"fundamental law":"n:大法,基本法",
"fundamentally":"d:根本,基本",
"fundamentals":"n:纲要",
"funding":"v:资金",
"funds":"n:经费",
"funeral":"n:葬礼,丧礼,丧葬,丧事,出丧,搞垮,后事,白事",
"funeral home":"n:殡仪馆",
"funeral parlor":"n:殡仪馆",
"funeral parlour":"n:殡仪馆",
"fungi":"n:霉菌",
"fungoid":"n:真菌",
"fungus":"n:真菌,菌,菌类,木耳,菌子",
"funk":"v:抽烟,畏缩,吸,吸烟,害怕;n:惊惶,胆小鬼,惊慌,恐怖",
"funk hole":"n:防空壕",
"funky":"a:古怪",
"funnel":"n:漏斗,烟囱;v:汇集",
"funnily":"d:有趣",
"funny":"a:滑稽,可笑,奇怪,好笑,逗,发噱;v:逗;n:笑话",
"funnyman":"n:丑角",
"fur":"n:毛,毛皮,皮毛,皮衣,皮货,皮,舌苔,兽皮,皮子,茸毛,蓬松,水锈",
"fur coat":"n:裘",
"fur seal":"n:腽肭兽,海獭,海熊",
"furbish":"v:翻新,刷新,修复,研磨,擦亮,温习,磨光",
"furious":"a:狂暴,怒,气愤,怒气冲天,暴怒,气冲冲,盛怒,气鼓鼓,猖獗,狂怒,恼怒,怒冲冲,眼红,气汹汹;v:盛怒",
"furiously":"d:怒冲冲",
"furl":"v:卷起,收,拉拢,嗡;n:折,卷;d:嗡",
"furling":"v:收拢",
"furlong":"n:浪",
"furlough":"n:休假,假",
"furnace":"n:炉子,火炉,熔炉,高炉,加热炉,炉,锅炉,坩埚,磨炼,核反应堆",
"furnace lining":"n:炉衬",
"furnace room":"n:燃烧室",
"furnish":"v:提供,布置,供给,装,装修,供应,具,装备,配料,资;n:具",
"furnishing":"n:家具,设备",
"furnishings":"n:家具,陈设",
"furniture":"n:家具,设备,器具",
"furor":"n:狂热,狂怒,热烈,众怒",
"furore":"n:激情",
"furriness":"n:毛皮",
"furring":"n:水垢,毛皮,木板,舌苔",
"furrow":"n:皱纹,沟,车辙,耕地;v:犁地,开",
"further":"d:更,再,愈加,而且,进一步;v:增进,促进,推动",
"furtherance":"n:促进,助长,推动",
"furthermore":"d:而且,此外,与此同时,更,同时,除此之外,更加,进而,再则,何况;c:此外,并且,与此同时,再者,况且,再说",
"furtive":"a:鬼鬼祟祟,窥,贼头贼脑,鬼祟,偷偷摸摸,鬼头鬼脑",
"furtively":"d:偷偷摸摸,躲躲闪闪",
"fury":"n:愤怒,狂怒,盛怒,猛烈,怒火,狂暴,冤魂,怒,泼妇;v:暴怒",
"fuse":"n:保险丝;v:融解,熔炼,熔解,溶解;a:融和",
"fusee":"n:骨瘤,雷管",
"fuselage":"n:机身",
"fusing":"v:熔断,溶解",
"fusion":"n:聚变,融合,合并,熔化,熔解,联合;v:熔化",
"fusion bomb":"n:氢弹",
"fuss":"v:大惊小怪;n:抗议,吹捧,心烦",
"futile":"a:一场空,白搭,枉然;v:无效,白搭",
"futilely":"d:干",
"futility":"n:无效,一场空,无益,无用",
"future":"n:前途,未来;a:将来",
"future tense":"n:将来时",
"futures":"n:期货",
"futurism":"n:未来派",
"futuristics":"n:未来学",
"futurity":"n:将来,后人,未来,远景",
"futurology":"n:未来学",
"fuze":"n:引信",
"fuzz":"n:细毛,侦探,警员,绒毛,茸毛,警察",
"g-force":"n:地心引力",
"g-man":"n:密探",
"gab":"n:废话,空谈;v:闲聊,空谈",
"gabardine":"n:华达呢",
"gabbing":"v:滔滔不绝",
"gabble":"v:叽里咕噜,飞溅",
"gabby":"a:碎,絮叨;v:絮叨",
"gable":"n:山墙,山",
"gable wall":"n:房山,山墙",
"gabon":"n:加蓬",
"gabriel":"n:号手",
"gad":"n:游荡,棍,闲逛;v:蔓延,闲荡",
"gadfly":"n:牛蝇,虻,牛虻",
"gadget":"n:圈套",
"gadolinium":"n:钆",
"gaff":"n:鱼叉,愚弄,挂钩,花招,挖苦,嘲笑,苦境,苦难,刑罚",
"gaffe":"n:出丑",
"gaffer":"n:工长,老头儿,雇主,经理,老板,领班,工头",
"gag":"n:笑话;v:钳制,堵塞",
"gage":"n:吃水,挑战,挑衅,帽子,抵押品",
"gaiety":"n:喜庆,乐事,快活",
"gain":"v:获得,得到;n:赢利",
"gain ground":"v:进展,抬头,壮大",
"gainer":"n:胜利者",
"gaining":"v:获益;n:收益",
"gains":"n:所得,收益,收获,果实",
"gainsay":"v:否认,否定,反驳,驳;n:否认,矛盾",
"gait":"n:步法,速度",
"gaiter":"n:绑腿,护腿",
"gaiters":"n:绑腿",
"gal":"n:姑娘,女孩",
"gala":"n:盛装,庆祝,欢庆,节日",
"galactic":"a:星系",
"galaxy":"n:星系,银河系,银河,河外星系,天河",
"gale":"n:大风,暴风,疾风",
"galen":"n:郎中",
"galena":"n:方铅矿",
"galilean":"n:基督教徒",
"galilee":"n:门廊,门厅",
"galileo":"n:伽利略",
"gall":"n:恶毒,胆汁,胆囊,苦胆;v:侮辱,擦伤",
"gall bladder":"n:胆囊,胆",
"gallant":"a:英勇,勇敢,雄赳赳,赳赳,豪侠,勇;n:豪侠,情郎;v:调情,求爱",
"gallantly":"d:雄赳赳",
"gallantry":"n:勇敢,殷勤,豪侠",
"gallbladder":"n:胆囊,胆",
"gallery":"n:美术馆,画廊,坑道,旁听席,阳台,长廊,观众,听众,回廊,走廊,楼台,地道,摄影室,看台,通道,巷道,游廊,穿廊,工作台",
"galley":"n:厨房,军舰",
"gallic":"a:法国",
"gallimaufry":"n:混合,杂凑",
"galling":"v:咬住,擦伤",
"gallium":"n:镓",
"gallivant":"v:游荡,闲逛,寻欢作乐",
"gallon":"n:加仑",
"gallop":"v:奔驰;n:急驰,快步,飞驰",
"gallows":"n:绞刑,绞刑架,绞架,架子,吊杆",
"gallows tree":"n:绞刑架",
"galoot":"n:蠢货,傻瓜",
"galore":"d:许多,多,丰盛;a:许多;n:充足",
"galosh":"n:胶靴,套鞋",
"galoshes":"n:雨鞋,雨靴,胶鞋,胶靴",
"galvanic battery":"n:原电池",
"galvanism":"n:电疗,有力",
"galvanization":"n:电镀",
"galvanize":"v:激励,刺激,电镀",
"galvanized iron":"n:白铁皮",
"galvanometer":"n:电流计,电表,电流表",
"gambia":"n:冈比亚",
"gambit":"n:策略,开场白,开始",
"gamble":"v:赌博;n:赌博,赌",
"gambler":"n:赌徒,冒险,赌客,投机",
"gambling":"n:投机,赌博,冒险;v:赌博",
"gambling den":"n:赌窟",
"gambling house":"n:赌场",
"gambol":"v:跳跃,活蹦乱跳,撒欢儿,欢跃;n:欢跃,跳跃",
"game":"n:比赛,游戏,运动,运动会,把戏,盘,赛,娱乐,花招,猎物,野味,计划,局,竞赛,职业,策略,胆量,勇气,诡计,事业,对策,戏谑;v:打赌",
"gamecock":"n:斗鸡;v:斗鸡",
"gameness":"n:兴致勃勃,勇气",
"games":"n:运动会,竞技",
"gamesmanship":"n:小动作",
"gamester":"n:赌徒,赌棍",
"gamete":"n:配子",
"gamin":"n:顽童",
"gaminess":"n:勇敢",
"gaming":"n:赌博",
"gamma ray":"n:丙种射线,伽马射线,光子",
"gammon":"v:打败,愚弄,击败,装假;n:火腿,胡说",
"gamut":"n:音阶,音域,全体",
"gander":"v:游荡;n:傻瓜",
"gang":"n:帮,团伙,党,一头,大量,路程,把子,同轴,徒;v:结伙,串通一气,成群结队,穿连裆裤,行走,朋比为奸,串通,通同",
"gang up":"v:串通,串通一气,穿连裆裤,串,通同,朋比为奸",
"ganges":"n:恒河",
"ganging":"v:成群",
"ganglia":"n:神经节",
"ganglion":"n:神经节,中心",
"gangplank":"n:跳板",
"gangrene":"n:坏疽,堕落,腐败;v:腐烂",
"gangster":"n:歹徒,匪徒,流氓,恶棍",
"gangway":"n:舷梯,过道,通路,木桥,舷门",
"ganja":"n:大麻",
"gannet":"n:鲣鸟",
"gansu":"n:甘肃",
"gansu province":"n:陇",
"ganymede":"n:侍者",
"gao":"n:高",
"gaol":"v:监禁,坐牢;n:牢狱",
"gaoler":"n:看守",
"gap":"n:差距,间隙,缺口,空白,间隔,距离,中断,空隙,隔阂,豁口,缝隙,缺陷,裂缝,空当儿,空子,裂口,分歧,空当,脱漏,空当子,空缺,山口,山峡,隘口,沟槽,空白点,缺门;v:间断,裂",
"gape":"v:裂开,张口,开裂,张开,瞠目结舌;n:哈欠,豁口,张口",
"gaping":"a:目瞪口呆",
"garage":"n:车库,车行,汽车间,机库,飞机库",
"garb":"n:外衣,僧袍,服装,外表,装束;v:装扮",
"garbage":"n:垃圾,废话,废物,食品,废料,脏土",
"garbage can":"n:垃圾桶,保洁箱,垃圾箱",
"garbage down":"n:狼吞虎咽",
"garbage truck":"n:垃圾车",
"garble":"v:断章取义,歪曲",
"garden":"n:花园,园子,园,菜园,园地,公园,庭园,果园,圃,园圃,园囿",
"garden of eden":"n:伊甸园",
"garden party":"n:游园会",
"garden pea":"n:豌豆",
"gardener":"n:园丁,花匠,圃",
"gardenia":"n:白兰花,栀子",
"gardening":"n:园艺",
"gardens":"n:园林",
"gargle":"v:漱口,发出,漱;n:含漱剂",
"garish":"a:扎眼,花哨,花花绿绿,花里胡哨",
"garland":"n:花环,花冠",
"garlic":"n:大蒜,蒜,蒜头",
"garment":"n:衣服,服装,衣着,风衣,衣,外观,外表",
"garner":"n:获得,加纳,收集,蓄积,谷仓;v:积累",
"garnet":"n:石榴石",
"garnish":"v:装饰;n:装饰品,修饰",
"garnishee":"v:扣押,扣发",
"garnishment":"n:装饰,装饰品",
"garret":"n:阁楼,顶楼,亭子间",
"garrison":"v:驻守;n:驻军,要塞,守备,卫戍区,戍;a:卫戍",
"garrison cap":"n:船形帽",
"garrulity":"n:饶舌,絮语",
"garrulous":"a:贫,婆婆妈妈,絮叨,贫气,贫嘴,嘴碎,絮;v:絮,絮叨,饶舌",
"garrulousness":"n:贫嘴",
"garter":"n:吊袜带",
"garters":"n:袜带,吊袜带",
"gary":"n:蛋白",
"gas":"n:气体,煤气,气,汽油,瓦斯,燃气,毒气;v:充气",
"gas burner":"n:煤气灯,煤气灶",
"gas chamber":"n:贮藏室",
"gas cooker":"n:瓦斯炉",
"gas engine":"n:内燃机",
"gas fitting":"n:接管",
"gas lamp":"n:煤气灯",
"gas meter":"n:煤气罐",
"gas pressure":"n:气压",
"gas pump":"n:加油站,鼓风机",
"gas shell":"n:毒气弹",
"gas station":"n:加油站",
"gas stove":"n:煤气炉,煤气灶,瓦斯炉",
"gas turbine":"n:气轮机,燃气轮机",
"gas up":"v:充气",
"gas well":"v:火井",
"gasbag":"n:气囊,话匣子",
"gaseous":"a:气体",
"gash":"n:裂纹,裂缝",
"gasket":"n:垫圈,填料,衬垫,垫片",
"gasoline":"n:汽油",
"gasoline tank":"n:汽油桶",
"gasp":"v:透不过气,喘;n:气喘,屏息",
"gasping":"v:气急",
"gassing":"v:出气,吹气;n:烧,充气",
"gastric acid":"n:胃酸",
"gastric lavage":"n:洗胃",
"gastritis":"n:胃炎",
"gastroenteritis":"n:胃肠炎",
"gastronome":"n:美食家",
"gastronomy":"n:烹调法",
"gate":"n:大门,门,门口,城门,闸门,门扇,隘口,街道,入场费,门径,门首,方法,关隘,关口,街门",
"gatehouse":"n:门楼,门房",
"gatekeeper":"n:门房,门警",
"gates":"n:盖茨",
"gateway":"n:门口,途径,门户,门道,入口,手段,通路,门洞",
"gather":"v:聚集,采集,收拾,收集,采,聚,集合,搜集,推测,恢复,积聚,得出,增加,收,集聚,想见,拢,齐集,推断,接近,云集,振作,化脓,集,收罗,摘,撮,攒,增长,蓄积,引入,逼近,缝,搜罗,扒,合拢,捡,缩,累积,搂,收款,总,总括,皱,聚首,配页,约集,招集,采撷,团聚,汇总,收取,搜;n:收缩,会集,聚集",
"gather in":"v:收",
"gather up":"v:搂,扒,收集,合拢,总括,拢,收拾",
"gathering":"n:集会,聚集,联欢会,会,积聚,搜集;v:俘获,聚会",
"gaucherie":"n:笨拙",
"gaudiness":"n:华美",
"gaudy":"a:花哨,大红大绿;n:招待会,宴会",
"gauge":"n:表;v:量",
"gauging":"n:校准,测量;v:测量,检测",
"gaunt":"a:瘦削,累累,消瘦",
"gauntlet":"n:手笼",
"gauze":"n:纱布,纱,冷布,薄雾,纨",
"gavel":"v:要求",
"gay":"a:鲜艳,快乐,欢乐",
"gaze":"v:凝视;n:目光,凝视,注视",
"gazebo":"n:阳台,凉亭,露台,塔楼",
"gazelle":"n:羚羊",
"gazette":"n:报纸,公报,学报,新闻纸;v:公告",
"gb":"n:大不列颠",
"gdansk":"n:格但斯克",
"ge":"n:葛",
"gear":"n:挡,齿轮,装置;v:开动,传动,促进",
"gear lever":"n:操纵杆",
"gear up":"v:促进",
"gear wheel":"n:齿轮,牙轮",
"gearbox":"n:变速箱",
"gearing":"n:传动,啮合",
"gearshift":"n:换挡,变速",
"gecko":"n:蝎虎,壁虎,蛤蚧,守宫",
"gee":"n:咑,家伙;i:哎呀",
"gee-gee":"n:马",
"geek":"n:艺人,家伙,傻子",
"geese":"n:鹅",
"geezer":"n:老家伙",
"geisha":"n:艺妓",
"geisha girl":"n:艺妓",
"gel":"n:凝胶",
"gelatin":"n:明胶,胶质,胶",
"geld":"v:减弱,阉割",
"gelding":"n:去势",
"gem":"n:宝石,珍品,珠宝,瑰宝,珠玑,珍宝,精华,佳作,宝物,珍珠",
"gemini":"n:双子座",
"gemstone":"n:宝石",
"gen":"n:发生器,基因,发电机",
"gendarme":"n:警察,宪兵",
"gender":"n:性",
"gene":"n:基因,细胞",
"genealogy":"n:家谱,世系,宗谱,系统,系谱学,血统",
"general":"a:一般,普遍,普通,总的,总,大;n:将,将官;d:大概;v:通行",
"general agent":"n:总代理",
"general headquarters":"n:大本营,总部",
"general knowledge":"n:常识,见闻",
"general store":"n:百货公司",
"generalissimo":"n:总司令,大帅,大元帅",
"generalist":"n:通才,多面手",
"generality":"n:一般性,大多数,概括,普遍性,一般,概要,广义,梗概,通则,大部分,共性",
"generalization":"n:推广,概括,概念,广义,一般化,归纳,综合,总结;v:推广",
"generalize":"v:推广,归纳,概括,普及,概,综合,通用化",
"generalized":"v:广义;n:广义",
"generally":"d:一般,通常,常常,平常,普通,大概,大凡,泛泛,概;n:素日",
"generalship":"n:将才",
"generate":"v:产生,生成,引起,导致,发生,生育,造成,生殖,发,酿成",
"generation":"n:一代,生成,产生,代,世代,发电,发生,振荡,时代,生殖,形成,世,生育;v:产生,振荡",
"generations":"n:世代",
"generator":"n:发电机,发生器,母线,振荡器,电滚子",
"generosity":"n:慷慨,肚量,宽大,盛意,洪量,雅量;a:宽大",
"generous":"a:慷慨,大方,宽宏大量,宽厚,豁达,宽,够意思,厚,慨,厚重,惠,大量,落落大方;v:落落大方,豁",
"generously":"d:慨然",
"genesis":"n:发生,起源,缘起,创始",
"genetic":"a:基因",
"genetics":"n:遗传学",
"geneva":"n:日内瓦",
"genghis khan":"n:成吉思汗",
"genial":"a:和蔼可亲,亲切,和善,和暖,暖,和煦",
"geniality":"n:亲切,和蔼,温和,温暖,舒适",
"genie":"n:妖怪",
"genii":"n:精灵",
"genital":"a:阴;n:生殖器",
"genitalia":"n:生殖器",
"genitals":"n:生殖器",
"genitive":"n:所有格",
"genius":"n:天才,天赋,精神,特质,天资,恶魔,才子,思潮,特征,奇才,天分,风气,神仙",
"genoa":"n:热那亚",
"genocide":"v:灭种;n:斩尽杀绝",
"genre":"n:类别,样式,类型,体裁,风俗画,流派",
"genre painting":"n:风俗画",
"gens":"n:氏族",
"gent":"n:绅士,人",
"genteel":"a:优雅,文绉绉",
"gentian":"n:龙胆",
"gentian violet":"n:龙胆紫,甲紫",
"gentile":"n:异教徒",
"gentility":"n:文雅;a:高尚",
"gentle":"a:温柔,温和,轻,和,柔和,平缓,文雅,和气,斯文,温存,慈爱,和易,习习,软和,优柔;v:驯服,抚弄;n:绅士",
"gentle breeze":"n:和风",
"gentle wind":"n:和风,轻风",
"gentlefolk":"n:名门",
"gentleman":"n:绅士,先生,君子,正人君子,黑人,君,侍从,处士,随从,议员",
"gentlemen":"n:绅士",
"gentleness":"n:温顺",
"gentlewoman":"n:贵妇人,淑女,女士,侍女",
"gentlewomen":"n:侍女,淑女",
"gently":"d:轻轻,好声好气,轻手轻脚,平缓,逐渐,柔和,徐徐",
"gentry":"n:绅士,贵族,伙伴,士绅,绅",
"genuflect":"v:跪拜,屈服,屈从",
"genuflection":"n:屈从,屈服,跪拜",
"genuine":"a:真正,真,真诚,道地,地地道道,真挚,纯真,地道",
"genus":"n:属,类,种类",
"geochemistry":"n:地球化学",
"geography":"n:地理,地理学,地形,布局,地势,地志",
"geology":"n:地质学,地质",
"geometer":"n:槐蚕,尺蠖",
"geometric progression":"n:几何级数",
"geometric series":"n:几何级数,等比数列",
"geometrid moth":"n:尺蠖蛾",
"geometry":"n:几何,几何学",
"geomorphology":"n:地貌学,地形学",
"george":"n:乔治",
"georgetown":"n:乔治敦",
"georgette":"n:乔其纱",
"georgia":"n:格鲁吉亚",
"georgian":"n:格鲁吉亚",
"geothermal energy":"n:地热",
"germ":"n:病菌,细菌,胚芽,萌芽,微生物,种子,根源,幼芽,病原菌,起源;v:萌芽,发生",
"germ plasm":"n:遗传物质",
"germ warfare":"n:细菌战",
"german":"a:德国;n:德文",
"germanic":"n:日耳曼;a:德国",
"germanium":"n:锗",
"germany":"n:德国,德意志",
"germinal":"n:春天",
"germinate":"v:发芽,萌发,出苗,萌芽,滋芽,萌,发生,发育,出芽;n:萌芽",
"germination":"n:发芽,萌芽,发生;v:催芽,发生",
"germs":"n:病菌",
"gerontology":"n:老年学",
"gerund":"n:动名词",
"gestapo":"n:盖世太保",
"gestate":"v:酝酿,妊娠,怀孕,孕育",
"gestation":"n:妊娠,怀孕,孕育,孵化,孵卵,孕期,酝酿;v:孵化,怀孕,孵卵,妊娠",
"gestation period":"n:妊娠期",
"gesticulate":"v:指手划脚,比画,比,比划,打手势",
"gesticulation":"n:打手势,姿势",
"gesture":"n:手势,姿势,表示,姿态,举止,样子,仪态;v:比,比画",
"get":"v:得,得到,起来,获得,买,该,起床,弄,出去,了解,收到,离开,摆脱;n:幼畜,薪资,子,产量,赢利",
"get about":"v:行动,走动,传开",
"get across":"v:通过",
"get ahead":"v:成功,超过",
"get along":"v:投合,对,进展,离开,处,有起色,过日子",
"get along with":"v:相处,混,与,合得来",
"get around":"v:规避",
"get at":"v:达到,发现",
"get away":"v:脱身,滚蛋,拔腿,滚,滚开,逃走",
"get back":"v:追回,回家,找回,禁止",
"get by":"v:度日,过得去,蒙混过关",
"get down":"v:搞垮",
"get going":"v:出发",
"get hold of":"v:搞,抓住,捉住",
"get in":"v:进站,进来,进去,买进,收割",
"get into":"v:扎,自讨苦吃,自作自受,进,钻",
"get married":"v:娶亲,从良,成婚,出阁,出门,嫁人,完婚,出嫁",
"get moving":"v:动",
"get off":"v:获释,动身,下车",
"get on":"v:穿上,进展,相处,搭上,上",
"get on with":"v:继续,相处",
"get out":"v:离开,滚开,取出,出去",
"get over":"v:摆脱,克服,越过,欺骗,越",
"get rid of":"v:摈,摈除,蝉蜕,弭,屏,驱遣,攘除,改掉,屏除,摒,除,解除,清除,破,挣脱,摒除,涤荡,去,剔除,排除,祛除,卸,干掉",
"get started":"v:发动,开始",
"get stuck":"v:上当,陷,卡,卡住",
"get the hang":"v:有门儿",
"get through":"v:完工,了解,完成",
"get to":"v:到,渐渐",
"get together":"v:张罗,聚会,聚,聚集,会,纠结;n:联欢",
"get up":"v:起床,兴,作,起身,起,起来",
"get well":"n:康复,好",
"get-up-and-go":"n:精力",
"getaway":"n:逃走,逃跑;v:启程",
"getup":"n:打扮,格式,野心,装订,精力,式样,装束,风度,服装,外表",
"gewgaw":"n:便宜货",
"geyser":"n:间歇泉",
"ghana":"n:加纳",
"ghastly":"a:惨白,阴森",
"ghat":"n:山脉,山隘,山路",
"ghee":"n:酥油",
"ghost":"n:鬼,鬼魂,幽灵,亡灵,阴魂,魂灵,微量,幽魂,鬼物,亡魂,幻象,幻像,异物,灵魂,阴影,幻影,一点儿;v:作祟",
"ghostliness":"n:幽灵",
"ghostwrite":"v:捉刀",
"gi":"n:兵士,军用品",
"giant":"n:大汉,巨星;a:巨型",
"giant panda":"n:大猫熊,猫熊",
"giant water bug":"n:田鳖",
"gibbet":"n:绞架,臂,绞刑;v:吊死,绞死",
"gibbon":"n:长臂猿",
"gibe":"n:嘲笑;v:嘲笑,奚落",
"giblets":"n:内脏,什件儿",
"gibraltar":"n:直布罗陀",
"giddiness":"n:眩晕,眼花",
"giddy":"v:昏眩,晕,头晕,眩晕,头昏;a:头晕,轻佻,晕晕忽忽,头昏眼花",
"gift":"n:礼物,天赋,礼品,才能,天才,赠送,赠品,天资,禀赋,秉赋,捐款,礼,赠礼;v:天赋,赠送,授予,赐,赠与",
"gifts":"n:才华",
"gig":"n:吊桶,怪人,快艇,鱼叉,记过;v:戳,激励,刺激",
"gigantic":"a:巨大,庞大,硕大无朋,巨;v:排山倒海",
"giggle":"v:傻笑,痴笑;n:痴笑",
"gild":"v:镀金,修饰;n:行会,协会",
"gild the lily":"v:画蛇添足",
"gilding":"n:金箔,镀金,粉饰;v:烫金,镀金;a:烫金",
"gill":"n:鳃;v:除去",
"gill fungus":"n:蕈",
"gilt":"n:金钱",
"gimlet":"n:手钻",
"gimmick":"n:花样,诀窍,噱头,鬼花招,手法",
"gimmickry":"n:花招,伎俩",
"gimp":"n:精神,活力,瘸子",
"gin":"n:轧花机,网,陷阱,打桩机;v:轧花,轧",
"ginger":"n:姜,精神,生姜,姜芋,加把劲;v:鼓舞",
"gingerly":"d:小心翼翼,战战兢兢",
"gingivitis":"n:齿龈炎",
"ginkgo":"n:白果,银杏",
"ginning":"v:原棉",
"ginseng":"n:人参,参,棒槌,党参",
"giraffe":"n:长颈鹿",
"gird":"v:准备,嘲笑,束,围绕,佩;n:嘲笑",
"girder":"n:大梁,柁,房柁,房梁",
"girdle":"n:腰带,带,环带;v:围,包围",
"girl":"n:姑娘,女孩,女孩子,女,女儿,女朋友,少女,女郎,丫头,女仆,姑娘家,闺女,大姑娘,妮,妹子,娃,情人,妮子,赔钱货,妮儿,妞,姑娘儿;a:女",
"girlfriend":"n:女友,女朋友",
"girlie":"a:姑娘,女人",
"girth":"n:腰身,周长,大小;v:包围,围绕",
"gist":"n:要点,大意,精神,主旨,领,大要,要领;v:领",
"give":"v:给,把,说,放弃,发出,给予,与,交给,送给,进行,提出,送,产生,发生,引起,演出,发,作出,让步,放,牺牲,举出,赠送,生,恢复,予以,让给,授予,赋予,放出,捅,屈服,散发,失去,投降,断,得出,适应,捐助;n:给予,适应性",
"give away":"v:捅,屈服,泄漏",
"give back":"v:退后,送还,交还,恢复,退回,发还,退,退还,还",
"give birth":"v:分娩",
"give forth":"v:发表,发出",
"give in":"v:就范,攘,甘拜下风,退让,屈膝,屈服",
"give notice":"v:通知",
"give off":"v:分枝,放出,冒,发出",
"give out":"v:发放,放,散,散发,放出,发",
"give thanks":"v:称谢",
"give the eye":"v:丢眼色",
"give up":"v:罢手,废,豁,交,戒,让,拚,丢手,付诸东流,改掉,打退堂鼓,打消,弃,舍,牺牲,丢弃,忌,舍弃,作罢,断,割舍",
"give vent":"v:闹",
"give way":"v:让路,退,毁坏,让",
"give-and-take":"n:互让",
"giveaway":"n:暴露,赠品",
"given":"v:给定,设,铸造;a:特定,一定;p:由于",
"given name":"n:名",
"giving":"v:礼物",
"gizzard":"n:砂囊,胃,喉咙,胗",
"glacial epoch":"n:冰期",
"glacial period":"n:冰期",
"glaciation":"n:积冰",
"glacier":"n:冰川,冰河",
"glad":"a:高兴,乐意,欢喜,欣喜,快慰,欣欣",
"gladden":"v:欢喜,鼓舞",
"glade":"n:沼泽地",
"gladiola":"n:菖兰",
"gladiolus":"n:菖兰,唐菖蒲",
"gladly":"d:乐",
"gladness":"n:高兴",
"glamor":"n:魔法,魔术;v:迷住",
"glamorize":"v:美化",
"glamour":"n:魅力,魔力;v:迷惑,迷住",
"glance":"v:扫视,浏览,闪耀;n:闪光",
"glance over":"v:翻阅",
"gland":"n:腺",
"glans":"n:龟头",
"glare":"n:闪光,闪耀,著名,瞪眼,显眼;v:瞪,怒目而视,瞪眼,闪耀",
"glaring":"a:鲜艳",
"glass":"n:玻璃,眼镜,玻璃杯,酒杯,镜子,望远镜,显微镜,镜,车窗,瓶胆,水杯,玻璃缸,料器;v:反映",
"glass eye":"n:假眼",
"glass fiber":"n:玻璃纤维,玻璃丝",
"glass wool":"n:玻璃丝",
"glasses":"n:镜子,眼镜",
"glassful":"n:量杯",
"glasshouse":"n:暖房,温室",
"glassware":"n:料器,料",
"glauber's salt":"n:芒硝",
"glaucoma":"n:青光眼,绿内障",
"glaze":"n:釉料;v:上光,擦亮",
"glazing":"n:光泽,釉;v:上光;a:上光",
"gleam":"v:闪烁,发光;n:闪现",
"gleaming":"v:明晃晃;a:明晃晃",
"glean":"v:搜集,拾,收集,发现,查明",
"gleaner":"n:割捆机",
"gleaning":"v:搜集,拾遗",
"glee":"n:高兴,狂欢,快乐",
"glen":"n:峡谷,山谷,幽谷",
"glib":"a:油,油腔滑调;v:油腔滑调;n:油嘴",
"glide":"v:滑行,流逝;n:滑道,流逝",
"glide by":"v:飞逝,消逝",
"glider":"n:滑翔机",
"gliding":"v:滑翔,下滑",
"glimmer":"n:微光;v:闪烁",
"glimmering":"v:闪烁",
"glimpse":"n:瞥见;v:瞥见",
"glint":"v:窥视,闪光,掠过,闪现,闪耀,反射;n:闪光,微光",
"glissando":"n:滑音",
"glisten":"v:闪闪,发光,闪耀,忽闪,闪光,闪烁,反光,辉耀;n:闪光,光辉",
"glistening":"a:闪闪,曈曈,熠熠;v:琳琅满目",
"glitch":"n:过失",
"glitter":"n:闪闪,烁烁,灿烂;v:忽闪",
"glitterati":"n:知名人士",
"glittering":"a:闪闪,烁烁,绿莹莹;v:琳琅满目",
"glitz":"n:耀目",
"gloaming":"n:暮色,黄昏,薄暮",
"gloat":"v:欣喜若狂,垂涎,沾沾自喜,自负;n:垂涎",
"global":"a:全球,全球性;n:世界",
"globalism":"n:全球性",
"globe":"n:地球,世界,灯罩,地球仪,球,眼球,天体,灯泡",
"globular":"a:球形",
"globule":"n:药丸,血球",
"glockenspiel":"n:编钟,钟琴",
"gloom":"n:黑暗,忧郁,悲哀,幽暗,背阴处,灰暗",
"gloominess":"n:幽暗",
"gloomy":"a:阴暗,阴郁,暗淡,阴沉,阴森,黯淡,幽暗,痹,惨淡,森,黯然,抑郁,郁郁,暮气沉沉,郁,涔涔,沉郁,晦,黯,惨白,灰暗,灰色,苦闷,郁闷,郁悒,黯淡无光,灰溜溜;n:灰色",
"glorification":"n:赞颂",
"glorify":"v:赞美,光,颂扬,崇拜,美化,夸赞,装饰",
"glorious":"a:光荣,光辉,辉煌,灿烂,荣,壮丽,光彩,光,光耀,美好",
"gloriously":"d:堂堂皇皇",
"glory":"n:荣誉,光荣,荣耀,壮观,光辉,壮丽,光,繁荣,光环;v:欢跃,狂喜,得意;a:光荣",
"gloss":"n:光泽,平滑,解释;v:发光,注释,搪塞",
"gloss over":"v:隐讳,粉饰",
"glossary":"n:词汇表,字汇,词汇",
"glossopharyngeal nerve":"n:舌咽神经",
"glossy":"a:光,润泽,光滑,油亮,油汪汪;v:溜",
"glottal":"a:喉音",
"glottis":"n:声门",
"glove":"n:手套",
"gloves":"n:手套",
"glow":"v:发光,灼热,焕发,燃烧;n:白热,鲜明",
"glow lamp":"v:辉光灯",
"glower":"v:怒视,凝视;n:凝视,灯丝",
"glowing":"a:炽热,红通通;v:发光",
"glowworm":"n:萤火虫,萤,萤火虫儿",
"glucose":"n:葡萄糖",
"glue":"v:粘,贴,胶合,胶结;n:胶水,胶",
"glued":"a:胶结",
"gluey":"a:胶",
"gluing":"v:胶合",
"glum":"a:愁闷,阴冷",
"glut":"v:供过于求,狼吞虎咽;n:供过于求,充斥",
"gluten":"n:面筋",
"glutinous":"a:粘,黏;v:粘",
"glutton":"n:狼獾,饕餮",
"gluttonous":"a:餮,馋嘴,馋,贪嘴,下作",
"gluttony":"n:贪食",
"glycerin":"n:甘油",
"glycerol":"n:甘油,醋精",
"glycogen":"n:牲粉,糖元,糖原,肝糖",
"glycol":"n:甘醇",
"glyph":"n:雕像",
"gmt":"n:格林威治",
"gnarl":"n:瘤,节;v:扭",
"gnarled":"a:古怪",
"gnash":"v:咬牙,咬啮;n:咬",
"gnat":"n:蚊子,蚊",
"gnaw":"v:咬,啃,侵蚀,啮,折磨,唼,消耗,苦恼,腐蚀",
"gnaw at":"v:咬,侵蚀",
"gnawing":"a:揪心;n:咬",
"gneiss":"n:片麻岩",
"gnome":"n:矮子,格言,守护神",
"go":"v:去,就,走,出去,打算,进行,继续,下去,领会,犯;n:进行,一口气;f:之;i:跑",
"go about":"v:流传,传开,尽力,荡,忙于,着手,周旋",
"go across":"v:横穿",
"go after":"v:跟随,追,骛,追求",
"go against":"v:悖,顶,拂,背道而驰,触犯,佛,犯,离,违反",
"go ahead":"v:上,前进",
"go all out":"v:大干,卖劲,放手,鼓足",
"go along":"v:随行,进行",
"go around":"v:踅,跑遍,流行,团团转,围绕",
"go away":"v:颠,带走,离去,走开,走,离开",
"go back":"v:返回,研究,还,回,退回,走下坡路",
"go back on":"v:违背,背叛,失",
"go bad":"v:变质,腐败,坏",
"go by":"v:称为,走过,依照,凭,经过",
"go down":"v:屈服,落,减少,减退,吞服,沉没,跌落,减弱,跌,伏,下去,平静,下降",
"go far":"v:足够,耐久",
"go for":"v:找,袭击,赞成",
"go forth":"v:发行,外出",
"go forward":"v:上进,前",
"go home":"v:腐败",
"go in":"v:开进,进入,参与,进去",
"go into":"v:放出,究,加入,成为,深究,调查,进入,从事",
"go off":"v:逃走,进行,出嫁,发火,拐走,经过,喋喋不休,抢走,死,挥发",
"go on":"v:接近,下去,接着,进行,继续,延续,责骂,胡作非为,依据,过去",
"go out":"v:出,出外,出版,出国,出去,过去,下台,倒塌,退职,辞职,衰老",
"go over":"v:参观,成功,过去,阅,走过,过,越过,渡过,延期,温,转向,复习,温习",
"go through":"v:钻,过,经过,审查,完成,经验,通行,熬,穿,涉,通过",
"go to":"v:总共,去,如,通,投,造,赴,前去,投奔,就,上,下",
"go to bed":"v:睡觉,歇,歇息,就寝",
"go to pieces":"v:崩溃",
"go to sleep":"v:入睡,睡觉",
"go to war":"v:打仗,大动干戈",
"go under":"v:潜入,沉没",
"go up":"v:破产,上浮,失败,增长,上涨,提价,上去,死,升班,升级,腾贵,上,升",
"go with":"v:了解,就,配合,处理,领会,打伙儿,带有,伴随",
"go wrong":"v:出错,出乱子,出毛病",
"go-ahead":"n:活力,许可,精力",
"go-around":"n:回旋,回合,拖延,躲闪",
"go-between":"n:冰人,媒人,中间人,中人,媒",
"go-cart":"n:手推车",
"go-slow":"n:怠工",
"goad":"v:驱使,刺激,唆使,煽动,激励,策动",
"goal":"n:目标,球门,目的,守门员,目的地,终点,门球",
"goalie":"n:守门员",
"goalkeeper":"n:守门员,门将",
"goat":"n:山羊,牺牲品,羊皮",
"goatherd":"n:牧羊人",
"goatskin":"n:山羊皮",
"gob":"n:许多,矿渣,大量,水兵;v:吐",
"gobbet":"n:石块",
"gobble":"v:吞并,狼吞虎咽,吞,吞噬,并吞",
"gobble up":"v:嘬,吞噬,狼吞虎咽,吞并,并吞",
"gobbledygook":"n:官腔,官样文章",
"gobi":"n:戈壁滩",
"goblet":"n:高脚杯,酒杯,觚",
"goblin":"n:精,小鬼,煞,魅,妖魔,妖怪,恶鬼,妖;a:精",
"god":"n:上帝,神,天,上天,天主,老天,偶像,主,天神,神道,爷,神像,造物主,天公;v:神化",
"god's will":"n:天意,天命",
"goddamn":"i:该死",
"goddess":"n:女神,天仙,娘娘,圣母,神女",
"godfather":"n:教父,首领,监护人",
"godhead":"n:神",
"godparent":"n:教父",
"gods":"n:神灵,神明",
"goer":"n:路人",
"gofer":"n:听差,皱褶",
"goggle":"n:瞪眼",
"goggles":"n:护目镜,风镜",
"going":"n:进行,行走,出发,道路,动身,举动,出行",
"going-over":"n:申诉,检查,痛打",
"goiter":"n:甲状腺肿,大脖子病,瘿",
"goitre":"n:大脖子病",
"gold":"n:黄金,金,金子,镀金,金色,金币,金箔,金钱,财富,包金,币",
"gold coast":"n:黄金海岸",
"gold leaf":"n:金箔",
"gold medal":"n:金牌",
"gold mine":"n:金矿,金山,宝库",
"gold plate":"n:镀金",
"gold standard":"n:金本位制",
"golden":"a:金,金色,金黄,金灿灿,黄灿灿,黄澄澄;n:金色",
"golden boy":"n:红人",
"golden delicious":"n:金冠",
"golden eagle":"n:鹫",
"golden mean":"n:黄金分割,中庸之道,中庸",
"golden oriole":"n:黄鹂",
"golden thread":"n:黄连",
"goldenrod":"n:黄花",
"goldfinch":"n:金翅雀",
"goldfish":"n:金鱼",
"goldfish bowl":"n:金鱼缸",
"golf":"n:高尔夫球,高尔夫",
"goliath":"n:巨人",
"gomuti palm":"n:桄榔,榔",
"gonad":"n:生殖腺,性腺,卵巢",
"gondola":"n:吊篮,短舱,敞篷车",
"gondola car":"n:敞车",
"gong":"n:锣,巩,铜锣,龚,纪念章",
"gonna":"v:快要",
"gonorrhea":"n:淋病,白浊",
"gonorrhoea":"n:淋病",
"goo":"n:臭味,伤感,甜言蜜语,雾",
"goober":"n:花生",
"good":"a:好,良好;n:甜头,用处;v:要得",
"good example":"n:旗帜,楷模",
"good faith":"n:信义",
"good fortune":"n:幸运,造化,幸,嘏,休",
"good luck":"n:彩头,菔,福,洪福,顺风,祺,幸运",
"good manners":"n:好气儿",
"good morning":"n:早,早安",
"good night":"n:晚安",
"good person":"n:好人,良人",
"good sense":"n:贤哲",
"good temper":"n:好性儿",
"good turn":"n:好事",
"good will":"n:善意,厚意",
"good-by":"i:告别",
"good-bye":"i:再见,再会,慢走;n:告别,再见",
"good-for-nothing":"n:饭桶,废人,窝囊废;a:不郎不秀",
"good-looking":"a:好看;n:天资",
"good-tempered":"a:好性儿",
"goodbye":"i:再见",
"goodman":"n:主人",
"goodness":"n:善良,美德,养分,仁慈,优点,精华,优势",
"goods":"n:货物,商品,货,物品,制品,货色,动产,坯布,财宝",
"goodwill":"n:友好,情意",
"goody":"n:糖果,好汉,英雄,甜食",
"gooey":"a:糖蜜",
"goof":"v:出错,混日子,闲荡;n:糊涂虫,傻瓜,疏忽",
"goofball":"n:兴奋剂,镇静剂,饭桶",
"googly":"n:板球",
"gook":"n:废物",
"goon":"n:打手,暴徒,无赖",
"goose":"n:鹅,傻瓜,倒彩;v:促进,推动",
"goose down":"n:鹅绒",
"goose egg":"n:鹅蛋",
"goose grass":"n:蟋蟀草",
"goose skin":"n:鸡皮疙瘩",
"gooseberry":"n:醋栗",
"gopher":"n:听差",
"gorbachev":"n:戈尔巴乔夫",
"gore":"n:角,血块;v:顶",
"gorge":"n:峡谷;v:狼吞虎咽",
"gorgeous":"a:艳丽,华丽,斑斓,绚,华贵,华美,绚烂,绮,绚丽,绮丽,富丽堂皇,艳",
"gorgeousness":"n:华丽",
"gorilla":"n:大猩猩,猩猩,打手,凶手",
"gormandize":"v:狼吞虎咽,吞食;n:大吃大喝",
"goshawk":"n:苍鹰",
"gosling":"n:傻瓜",
"gospel":"n:福音,信条,真理,福音书,真实,主义",
"gossamer":"n:游丝",
"gossip":"n:流言蜚语,闲话,闲谈,闲聊;v:扯,学舌,搬弄是非,道听途说",
"gossipy":"a:学舌,多嘴,婆婆嘴;v:多嘴",
"gothic":"n:哥特式;a:哥特式",
"gouge":"n:凿,骗子,凿孔;v:欺诈",
"gouging":"v:欺诈",
"gourd":"n:葫芦,蠡,脑瓜,匏",
"gourmand":"n:美食家,饕餮",
"gout":"n:痛风,嗜好,块,水道,味道",
"govern":"v:统治,治理,支配,控制,调节,管理,左右,抑制,指挥,指导,治,管,操纵,遏制,管辖,压制,艾,辖制,执掌,运转,统辖,统摄,统制,辖,宰",
"governance":"n:统治,支配,管理",
"governing":"v:调整,节制",
"government":"n:政府,政体,内阁,政治,管理,政权,政治学,支配,朝",
"government bond":"n:公债",
"government man":"n:官吏",
"government office":"n:府,公署,官署,公廨",
"government officials":"n:公职,官员",
"government security":"n:公债",
"governor":"n:州长,总督,省长,统治者,市长,老板,头领,县长,控制器,司令官,调节器,太守",
"governorship":"n:总督",
"gown":"n:长袍,睡衣,大褂,袍子,罩袍,法官,袍,褂,外衣",
"grab":"v:抓,抢,绰,窃夺,霸占,夺去,抄;n:挖掘机",
"grace":"n:优雅,风度,优美,慈悲,恩,宽限,仁慈,光,体面,恩惠,风雅,美德,天恩,斯文,恩德,宽厚,恩赐,美容,恩典,飘逸,善意,特权,特赦权,装饰音;v:装饰,宽限",
"graceful":"a:优美,妩媚,婀娜,娟秀,曼,阿,娟,雅,绰约,端丽,秀美,雍容,高雅,婷,婉,飘逸,帅",
"gracefulness":"n:彩",
"gracious":"a:宽厚,光",
"grackle":"n:白头翁",
"grad":"n:毕业生,梯度,校友",
"gradation":"n:等级,阶段,层次,灰度,分级,分等;d:分级",
"grade":"n:成绩,等级,分数,级别,年级,等;v:打分;d:分级",
"grade point":"n:评分",
"grade school":"n:小学",
"grades":"n:分数",
"gradient":"n:梯度,坡度,倾斜度,斜坡,斜率",
"grading":"n:粒度,分级,等级,分段,级差,校准;v:分级,筛分;d:分级",
"grads":"n:档级,梯度",
"gradually":"d:逐渐,渐渐,慢慢,逐步,缓缓,浸,渐;v:浸",
"graduate":"n:毕业生,量杯,刻度;v:卒业",
"graduate student":"n:研究生",
"graduated":"a:量杯",
"graduation":"n:毕业,刻度,浓缩",
"graffito":"n:岩画",
"graft":"v:嫁接,移植;n:嫁接,移植,贪污,接穗,受贿",
"grafting":"v:嫁接,移植",
"grail":"n:砾石,杯,鹅卵石,圣杯",
"grain":"n:粮食,谷物,颗粒,谷粒,粒,晶粒,粒子,纹理,种子,粒度,粮,谷子,特性,食粮,子粒,子实,脾气,颜色,质地,籽粒,些微,原粮,征购粮;v:分岔",
"grain alcohol":"n:乙醇",
"grain field":"n:粮田",
"grain sorghum":"n:高粱",
"graininess":"n:粒状",
"grains":"n:稼",
"gram":"n:克,绿豆,公分",
"gram atom":"n:克原子",
"grammar":"n:语法,文法,语法学,文理,入门",
"grammar school":"n:小学,初级中学",
"gramme":"n:克",
"gramophone":"n:留声机,电唱机,唱机,话匣子",
"granada":"n:石榴",
"granary":"n:粮仓,谷仓,仓廪,廪,廒",
"grand":"a:隆重,盛大,宏伟,雄伟,宏大,堂皇,浩,壮,宏,盛,雄;v:盛装,盛;n:王",
"grand duchy":"n:公国",
"grand larceny":"n:勒索,敲诈",
"grand prix":"n:大奖赛",
"grand slam":"n:全胜",
"grand total":"n:累计,总值",
"grandad":"n:爷爷,老大爷,公公",
"grandaunt":"n:伯祖母,姑奶奶,叔祖母,姑婆,姨婆",
"grandchild":"n:孙女,孙子,外孙女,外孙",
"grandchildren":"n:外孙女",
"granddad":"n:公公,老伯,爷爷,老伯伯",
"granddaughter":"n:孙女,外孙女",
"grandee":"n:高官,显贵",
"grandeur":"n:壮观,崇高,富丽堂皇,伟大,豪华;a:壮观",
"grandfather":"n:祖父,爷爷,外祖父,外公,祖先,祖,爷,公公,老爷,老爷儿,老大爷,始祖",
"grandiloquence":"n:豪语,夸大,豪言壮语,夸张",
"grandiose":"a:洋洋大观,沾沾自喜,壮",
"grandiosity":"n:夸张,堂皇,宏大,宏伟,辉煌,铺张",
"grandma":"n:奶奶,姥姥,外婆,老太婆,姥",
"grandmother":"n:祖母,奶奶,外婆,老奶奶,外祖母,老娘,婆婆,姥姥,姥",
"grandnephew":"n:侄孙",
"grandness":"n:伟大,宏伟,庄严,壮观,堂皇,华丽,宏大",
"grandniece":"n:侄孙女",
"grandpa":"n:爷爷,老伯伯,老爷儿,老爷爷,老公公,公公,外公,老大爷,大爷,老爷",
"grandparents":"n:祖父母",
"grandson":"n:孙子,外孙,孙",
"grandstand":"n:看台",
"granduncle":"n:叔祖",
"grange":"n:农舍,庄园,谷仓",
"granger":"n:农夫",
"granite":"n:花岗岩,花岗石",
"grannie":"n:外婆,老奶奶,奶奶",
"granny":"n:老大娘,奶奶,阿妈,阿婆,老婆婆,老婆儿,老老",
"grant":"v:答应,承认;n:赠款,给与,锡,答应,津贴,许可,承认",
"grant-in-aid":"n:补助金,拨款,助学金",
"granular":"a:粒状",
"granularity":"n:粒度",
"granulation":"n:颗粒",
"granule":"n:颗粒,粒子,粒,米粒,团粒,砂砾",
"grape":"n:葡萄,葡萄酒",
"grape juice":"n:葡萄汁",
"grape sugar":"n:葡萄糖",
"grapefruit":"n:柚子",
"grapeshot":"n:霰弹",
"grapevine":"n:小道消息,谣言,传闻,小广播",
"graph":"n:图表,图形,曲线图,图解,胶版;v:图解",
"graph paper":"n:图纸,方格纸",
"graphic":"n:图表,图像;a:传神,图示;v:图示",
"graphics":"n:书法,图解,制图学",
"graphite":"n:石墨,青灰,炭精,笔铅,煤精",
"graphology":"n:图解法",
"grapple":"v:扭打,搏斗,扭,抓住,钩住,拼杀,格斗;n:扭打,紧握,格斗",
"grasp":"v:抓住,掌握,理解,会,紧握;n:把握,把,领会,统制",
"grasping":"v:夹住",
"grass":"n:草,草地,青草,牧草,牧场,春天,禾草,芦笋;v:告密,打倒,放牧",
"grass roots":"n:草根,根源",
"grasshopper":"n:蚱蜢,蝗虫",
"grassland":"n:草地,牧场,草场,芜",
"grasslands":"n:草原",
"grate":"n:炉箅子,壁炉;v:轧,激怒,磨损,磨擦",
"grateful":"v:知情;a:荷",
"grater":"n:磨光机",
"gratification":"n:喜悦,满足,奖金",
"gratified":"a:快,称意,甜丝丝,甜滋滋;v:甜丝丝,甜滋滋,快",
"gratify":"v:满足,奖赏,可意",
"gratifying":"a:可喜,喜人;v:沁人心脾",
"grating":"n:光栅,格子,摩擦",
"gratis":"d:免费,无偿;a:白;v:免费",
"gratitude":"n:谢意,感谢,谢忱,礼物,感纫",
"gratuitous":"a:平白,无故,无偿;v:平白",
"gratuitously":"d:无偿,平白,等闲;a:等闲",
"gratuity":"n:服务费,养老金,赏金,小费,小帐",
"gravamen":"n:不平,诉苦",
"grave":"n:坟墓,死,墓;a:危重,庄;v:铭刻",
"grave mound":"n:坟头",
"gravel":"n:砾石,砂砾,砂石,料石;v:激怒",
"graveness":"n:严重性,重大",
"graver":"n:雕刻师,雕刻刀,刻刀",
"gravestone":"n:墓碑,神道碑",
"graveyard":"n:墓地,坟地,坟茔,墓园,墓场",
"graveyard shift":"n:夜班",
"gravimeter":"n:比重计",
"graving":"v:雕刻,雕刻品",
"gravitate":"v:倾向,吸引,沉降,沉淀",
"gravitation":"n:引力,万有引力,重力,地心引力,吸引力,下沉,倾向",
"gravitational attraction":"n:万有引力",
"gravitational force":"n:地心引力",
"gravity":"n:重力,引力,严重性,严肃,庄重,重要性,重量,认真,危险性",
"gravity meter":"n:比重计",
"gravy":"n:肉汁",
"gray":"n:灰色,灰;a:苍苍",
"gray matter":"n:智力,主意,点子,人脑",
"graybeard":"n:老翁,老人,老头",
"grayness":"n:灰色",
"graze":"v:吃,擦伤,放牧,掠过,轮牧;n:畜牧,牧草",
"grazing":"n:牧场,牧草,牧地,放牧;v:轮牧,牧地,放牧",
"grease":"n:油脂,油;v:贿赂",
"greasepaint":"n:油彩",
"greaser":"n:加油器,修理工",
"greasiness":"n:滑溜,油污",
"greasy":"a:油腻,腻,腻人,肥;v:腻",
"great":"a:大,伟大,重大,了不起,宏大,伟岸,弘,了不得,浩;n:名家,大师,王",
"great britain":"n:英国",
"great burdock":"n:牛蒡",
"great divide":"n:生死线,分界线",
"great grandfather":"n:太公",
"great lakes":"n:五大湖",
"great power":"n:大国,大功率,伟力",
"great wall":"n:长城",
"great year":"n:大年",
"great-aunt":"n:姑婆",
"great-nephew":"n:侄孙",
"greatest":"a:莫大,太;d:太",
"greatly":"d:大,非常,大大,大为,甚,深,盛,老大;v:盛",
"greatness":"n:伟大,大,高尚,巨大",
"greece":"n:希腊",
"greed":"n:贪婪,贪心;a:贪心",
"greediness":"n:贪吃",
"greedy":"a:贪婪,贪,贪心,贪嘴,馋,嘴馋,婪,下作,饕,馋嘴,餮;v:贪欲,贪",
"greek":"n:希腊语,一窍不通",
"greek alphabet":"n:希腊字母",
"green":"n:绿色,草地,蔬菜;a:生,绿茸茸,绿生生,绿茵茵,绿葱葱,碧油油,绿莹莹;v:少不更事,绿化",
"green bean":"n:青豆",
"green bristlegrass":"n:莠",
"green foxtail":"n:狗尾草",
"green gram":"n:绿豆",
"green light":"n:放行,绿矾,准许",
"green manure":"n:压青",
"green onion":"n:大葱,青蒜",
"green paper":"n:绿皮书",
"green pea":"n:豌豆",
"green pepper":"n:灯笼椒,青椒",
"greenback":"n:美钞",
"greener":"a:生手",
"greenery":"n:绿叶,植物",
"greenhorn":"n:生手,门外汉",
"greenhouse":"n:温室,暖房,洞子,花房",
"greening":"n:绿化",
"greenish yellow":"n:苍黄",
"greenland":"n:格陵兰",
"greenness":"n:鲜绿色,绿色,新鲜",
"greenroom":"n:后台",
"greens":"n:菜,菜蔬,青菜,蔬菜",
"greensward":"n:草地,草坪,草皮",
"greenwich":"n:格林威治",
"greenwich mean time":"n:格林威治时间",
"greenwood":"n:绿林",
"greet":"v:迎接,打招呼,欢迎,问候,招呼,致敬,迎,叫,迎候",
"greeting":"n:问候,称呼,敬礼",
"greetings":"n:贺词",
"gregarious":"a:群居",
"gregorian calendar":"n:西历",
"gremlin":"n:小鬼",
"grenade":"n:手榴弹,催泪弹,榴弹,灭火弹",
"grenadine":"n:糖浆",
"grey":"n:灰;a:花白,苍苍",
"grey matter":"n:灰质,智力,头脑",
"grey-haired":"a:白发苍苍,白发",
"greyness":"n:灰色",
"grid":"n:电力网,箅子,格子,格,栅极",
"griddle":"n:鏊子,筛子;v:筛",
"griddlecake":"n:烤饼,薄饼",
"gridiron":"n:支子",
"grief":"n:悲伤,悲哀,痛苦,忧伤,忧愁,悲,哀痛,痛,哀思,不幸,灾难,困难,沉痛,哀,麻烦;a:痛,哀痛",
"grievance":"n:冤情,不满,抱怨,怨气,牢骚,不平,恩怨,苦难;a:不平",
"grieve":"v:伤心,悲伤;n:监工",
"grieved":"v:酸,酸楚,悲痛,悄,凄恻,哀伤,撕心裂肺,惨然;a:悲痛,惨然,酸楚,哀伤,凄恻,心酸",
"grievous":"a:严重,惨无人道,惨重,悲哀",
"griffin":"n:生手",
"griffon vulture":"n:兀鹫",
"grill":"v:烤;n:烤肉",
"grille":"n:孵卵器,铁门,网屏",
"grilled":"v:炙烤;a:炙烤",
"grim":"a:冷酷,严酷,严峻,厉",
"grimace":"n:鬼脸,怪相,愁眉苦脸",
"grime":"n:污垢,泥垢;v:腻",
"grimness":"n:严格",
"grimy":"a:腻",
"grin":"v:咧,含笑",
"grind":"v:磨,研,碾,研磨,折磨,转动;n:刻苦,用功,苦差,开玩笑,苦活,讥讽",
"grind down":"v:磨,折磨,碾碎",
"grind out":"v:苦学",
"grinder":"n:磨床,粉碎机,磨工,牙齿,碾,臼齿",
"grinding":"n:摩擦,磨削,研磨,粉碎;a:粉碎;v:磨光",
"grinding wheel":"n:砂轮",
"grindstone":"n:砂轮",
"grinning":"a:笑嘻嘻",
"grip":"n:控制,掌握,夹,理解力,手提包,支配,把,握力;v:咬住,攥,把握,了解",
"gripe":"n:紧握,制动器,把手,柄,不平,愤怒;v:发牢骚,压迫,激怒,诉苦,握紧",
"grippe":"n:流感",
"gripper":"n:夹具",
"grisliness":"n:可怕",
"grist":"n:麦芽,许多,大量",
"gristle":"n:脆骨,软骨",
"grit":"n:沙子,勇气,种,沙砾,砂砾,砂,刚毅;v:研磨,摩擦,轧",
"grits":"n:玉米粥",
"gritty":"a:牙碜",
"grizzle":"v:啼哭,烦恼,烦躁;n:灰色",
"grizzled":"a:花白;v:华",
"groan":"v:呻吟;n:叹息;d:吱,咯吱;i:哼",
"groat":"n:少量",
"groceries":"n:杂货,杂品",
"grocery":"n:杂货,杂货店,食品店,副食品",
"grocery store":"n:杂货店",
"grog":"n:熟料,耐火材料",
"groggy":"a:头昏眼花",
"groin":"n:腹股沟,防波堤,鼠蹊,海堤,丁坝",
"grok":"v:理解",
"grommet":"n:垫圈",
"groom":"v:培训,修饰;n:男仆",
"groomsman":"n:伴郎,男傧相",
"groove":"n:沟,凹槽,习惯,车辙,常规,槽,矿井,沟纹,惯例,矿山;v:灌",
"grope":"v:摸索,探索,摸;n:摸索,探索",
"grope for":"v:探索,摸索,摸",
"grosbeak":"n:蜡嘴雀",
"grosgrain":"n:罗缎",
"gross":"a:毛,总的,总;v:收入,总计;n:总额",
"gross profit":"n:毛利",
"gross ton":"v:总吨位",
"grossly":"d:非常",
"grotesque":"a:怪模怪样,不伦不类;n:怪象",
"grotesqueness":"n:奇特",
"grotto":"n:岩洞,石窟,洞穴,穴",
"grouch":"n:不满,怨气,牢骚;v:发牢骚",
"grouchy":"a:闹别扭",
"ground":"n:地面,地,土地,理由,大地;v:打基础,着陆",
"ground floor":"n:底层",
"ground glass":"n:玻璃粉",
"ground plan":"n:平面图,草案",
"ground rent":"n:徭役地租,租子",
"ground rule":"n:程序",
"ground zero":"v:弹着点",
"grounder":"n:地滚球",
"groundhog":"n:土拨鼠",
"grounding":"n:基础,底子;v:接地",
"groundless":"a:凭空,莫须有,平白无故,飞,风;v:飞;n:风",
"groundlessly":"d:凭空,瞎,平白无故",
"groundnut":"n:花生,落花生",
"grounds":"n:庭园,根据",
"groundwater":"n:地下水",
"groundwork":"n:基础",
"group":"n:小组,群,组,集团,团体,群体,起,队,集体,批;v:成群,配合,编",
"grouper":"n:石斑鱼",
"grouping":"n:搁浅,集团,接地;v:分组,成群,集聚",
"grouse":"n:松鸡;v:抱怨,发牢骚",
"grout":"v:灌浆;n:石灰浆",
"grouting":"v:灌浆",
"grove":"n:树林,树丛,林子,园林,树行子,丛,林",
"grovel":"v:拜倒,卑躬屈节,摇尾乞怜,跪倒,请求,奴颜婢膝,趴",
"grow":"v:长,生长,种,长大,增长,种植,发展,成长,产生,增加,起,变成,栽培,生,留,发育,出现,形成,培养,出落,滋长,壮大,下去,蓄,栽,发芽,培育,滋,兴起,栽种,植,生息,秧,艺,殖,息,养",
"grow up":"v:成长,兴起,成年,生长,成人",
"grower":"n:植物",
"growing":"v:成长,发达,发育",
"growl":"v:咆哮,鸣不平,轰鸣,怒吼;n:筛子,咆哮,不平",
"grown":"a:成熟",
"growth":"n:生长,增长,发展,成长,发育,瘤,培养,分枝,长势,产物,栽培;v:生长,发育",
"growth hormone":"n:生长激素",
"growth ring":"n:年轮",
"groyne":"n:防波堤,海堤,丁坝",
"grub":"n:掘,蛴螬,土蚕,地蚕;v:挖掘,除根,掘",
"grubstake":"n:贷款,资金",
"grudge":"n:怨恨;v:怨,怨尤,怀恨,怨艾,怨望,妒忌,羡慕,怨恨",
"grudging":"a:不愿",
"grudgingly":"d:勉强",
"gruel":"n:糜,餬;v:累倒,惩罚",
"grueling":"a:惩罚,痛打",
"gruelling":"a:痛打",
"gruesome":"a:阴森",
"gruff":"a:粗鲁,粗暴,粗重,倔,粗",
"grumble":"v:抱怨,发牢骚;n:不平,牢骚,怪话",
"grump":"v:发牢骚;n:发火",
"grunt":"n:咕哝,牢骚,猪肉;v:咕哝",
"grunting":"d:咕噜;v:咕噜",
"gu":"n:谷,古",
"guam":"n:关岛",
"guan":"n:关",
"guangzhou":"n:广州,广",
"guarantee":"v:保,允诺,管,包管;n:担",
"guarantees":"n:抵押品",
"guarantor":"n:保证,保人,担保人,保,保证人;v:保",
"guaranty":"n:保证,保证书,抵押品",
"guard":"v:卫,卫护,把,扼守,防守,护,监守,防卫,戍守,镇;n:警备",
"guard boat":"n:巡逻艇,警戒艇",
"guard of honor":"n:仪仗队",
"guard's van":"n:守车",
"guardhouse":"n:警卫室,禁闭室",
"guardian":"n:监护人,保护人,管理员",
"guardianship":"v:监护,守护;n:守护",
"guardrail":"n:栏杆",
"guardsman":"n:卫兵,哨兵",
"guatemala":"n:危地马拉",
"gudgeon":"n:鲍,傻子,诱饵,饵,枢轴",
"guerrilla force":"n:游击队",
"guerrilla theater":"n:活报剧",
"guess":"v:猜,猜测,猜想;n:推测",
"guesstimate":"v:瞎猜,估摸;n:瞎猜,猜测",
"guesswork":"n:猜测,推测",
"guest":"n:客人,宾客,来宾,旅客,顾客,客,来客,宾朋,宾;v:招待,款待",
"guesthouse":"n:宾馆,迎宾馆,招待所",
"guests":"n:堂客,宾朋,宾客",
"guff":"n:胡说,闲聊,瞎扯",
"guffaw":"n:大笑,狂笑,哄笑,捧腹大笑;v:哄笑,大笑,狂笑,捧腹大笑",
"guidance":"n:指导,制导,导航,引导,教导,导管,诱导,领导,指引;v:教导,诱导,指导,引导",
"guide":"v:指导;n:先导",
"guidebook":"n:指南",
"guideline":"n:方针,准",
"guidelines":"n:方针,机宜,准则",
"guidepost":"n:路标,指路牌",
"guides":"n:导轨",
"guiding":"v:定向,制导,主导,导航,导向,控制",
"guild":"n:协会,行会,同业公会",
"guildhall":"n:会馆",
"guile":"n:狡诈,狡猾,狡计,诡计,滑头滑脑",
"guileless":"a:朴实,光明",
"guillemot":"n:海鸠",
"guillotine":"n:断头台,剪床,闸刀,铡刀",
"guilt":"n:罪,内疚,罪行,罪过,辜",
"guiltiness":"n:罪恶",
"guiltless":"a:没有",
"guilty":"a:内疚",
"guilty conscience":"n:内疚",
"guinea":"n:几内亚",
"guinea corn":"n:高粱",
"guinea pig":"n:豚鼠,天竺鼠",
"guinea-bissau":"n:几内亚比绍",
"guise":"n:打扮,借口,姿态,服装,外观,态度,伪装",
"guitar":"n:吉他,六弦琴",
"gulch":"n:深谷,峡谷",
"gulden":"n:盾",
"gulf":"n:鸿沟,深渊,海湾,分歧,隔阂,悬殊,涡;v:卷进,吞没",
"gulf states":"n:墨西哥湾",
"gull":"n:笨蛋,鸥,欺诈",
"gullet":"n:喉,食道,咽喉,海峡,食管,水槽,齿槽,水道,咽",
"gullible":"a:可欺",
"gully":"n:沟,沟壑,山沟,涧,沟渠,阴沟",
"gulp":"v:狼吞虎咽,吞;n:吞咽",
"gum":"n:口香糖,齿龈,胶水,胶,牙龈,眼眵,眼屎,树胶,树脂,牙床,橡皮糖,橡胶,齿根",
"gum tree":"n:桉树",
"gumbo":"n:浓汤",
"gumdrop":"n:水果糖",
"gumming":"v:胶合",
"gummy":"a:胶",
"gumption":"n:事业心,进取心,精明能干",
"gums":"n:齿龈",
"gumshoe":"n:刑警;v:侦察",
"gumshoes":"n:胶鞋",
"gun":"n:枪,炮,手枪,枪支,火炮,枪杆子,猎枪,加农炮,强盗,信号,罪犯;v:击倒",
"gun barrel":"n:枪管,炮筒",
"gun carriage":"n:炮车",
"gun down":"v:击倒",
"gun turret":"n:炮楼",
"gunboat":"n:炮艇,炮舰",
"gunboat diplomacy":"n:炮舰外交",
"gunfight":"n:枪战",
"gunfire":"n:炮火,炮击",
"gung ho":"a:热心",
"gunner":"n:炮手,枪手,射手,炮兵",
"gunnery":"n:射击,枪炮,重炮",
"gunning":"n:射击,打猎",
"gunny":"n:麻布",
"gunny sack":"n:麻包",
"gunnysack":"n:麻包,麻袋",
"gunpoint":"n:枪口",
"gunpowder":"n:火药,黑色火药",
"guns":"n:枪炮",
"gunshot":"n:射击,炮弹,射程,炮击,枪弹",
"gunslinger":"n:枪手",
"gunwale":"n:船舷",
"gurgle":"v:咕嘟",
"gurgling":"v:淙淙",
"guru":"n:头面人物,领袖,头目,头头,权威",
"gush":"v:涌,涌出,喷,喷发,瀵;n:涌出,冲动",
"gussy":"v:装饰",
"gust":"n:阵风,阵,迸发,欣赏;v:享受",
"gusto":"n:兴致勃勃,热忱,滋味,劲,爱好,趣味,嗜好",
"gut":"n:肠,勇气,肚子,内脏,实质,香肠,胆,海峡;v:狼吞虎咽",
"guts":"n:胆量,胆魄,胆,种,毅力",
"gutter":"n:沟,水槽,排水沟,贫民区,水沟,明沟,贫民窟;v:流",
"guy":"n:家伙,人,小伙子,朋友,怪人,佬,逃亡;v:嘲笑,挖苦,糟蹋,逃走",
"guyana":"n:圭亚那",
"guzzle":"v:大吃大喝,狂饮",
"guzzler":"n:酒鬼",
"gym":"n:体操,体育馆,健身房,体育课,体育场",
"gym suit":"n:运动服",
"gymkhana":"n:运动会",
"gymnasium":"n:体育馆,健身房",
"gymnastic":"a:健身操",
"gymnastics":"n:体操",
"gymnosperm":"n:裸子植物",
"gyp":"n:石膏,骗局,骗子,苦难;v:骗,欺骗",
"gypsum":"n:石膏",
"gypsy":"n:吉卜赛;v:流浪",
"gyrate":"v:旋转;n:旋转",
"gyration":"n:回转,回旋,旋转;v:回转",
"gyro":"n:陀螺,回转仪",
"gyroscope":"n:陀螺,回转仪",
"h-bomb":"n:氢弹",
"ha":"i:哈",
"ha-ha":"i:哈哈;n:嘲笑",
"habiliment":"n:服装,制服,装备,服饰,礼服,职业,衣服",
"habit":"n:习惯,习性,体质,老脾气,嗜好,性情,举止;v:装扮",
"habitat":"n:自然环境,住所,原产地,产地",
"habitation":"n:居住,住宅,宅邸",
"habitual":"v:惯;a:惯用",
"habitually":"d:素常,素",
"habituate":"v:上瘾",
"habituation":"n:适应,习惯性",
"habitue":"n:常客",
"hacienda":"n:矿山,种植园",
"hack":"n:劈,出租汽车,警察,刻痕,砍,鹤嘴镐,伤痕,守车,打手,砖坯;v:干咳,整修,翻;a:苦工,雇佣",
"hack saw":"n:锯条,弓锯",
"hacker":"n:黑客",
"hacking":"v:开槽",
"hackle":"v:梳理,砍掉",
"hackles":"v:梳理",
"hackney":"v:滥用,出租;n:出租汽车",
"hackneyed":"a:滥",
"hacksaw":"n:钢锯,弓锯",
"hades":"n:阴曹,阴间",
"haematite":"n:赤铁矿",
"haematology":"n:血液学",
"haemoglobin":"n:血红蛋白,血红素",
"haemorrhoid":"n:痔疮",
"hafnium":"n:铪",
"haft":"n:把,柄,把柄",
"hag":"n:母夜叉,女巫,砍伐;v:砍",
"haggard":"a:憔悴,枯槁,鸠形鹄面,累累",
"haggle":"v:讨价还价,争论不休,斤斤计较,争辩,计较,烦恼,较量;n:讨价还价,争论",
"hail":"n:冰雹,雹,雹子,招呼,欢迎,致意;i:揍,喧闹,骂;v:来自,欢呼,招呼",
"hail-fellow":"n:密友",
"hailstone":"n:冰雹,雹子",
"haiphong":"n:海防",
"hair":"n:头发,发,毛,毛发,汗毛,老年,茸毛,麻刀,髯,些微",
"hair drier":"n:吹风机",
"hair dryer":"n:吹风机",
"hair follicle":"n:毛囊",
"hair oil":"n:发乳",
"hair seal":"n:海豹",
"hair spray":"n:发胶",
"hair style":"n:发式",
"hair tonic":"n:生发油",
"hairbreadth":"n:间不容发",
"haircloth":"n:毛织品",
"haircut":"n:理发,发式",
"hairdo":"n:发型,发式,烫发",
"hairdresser":"n:理发员",
"hairdressing":"n:理发业,梳头,头油,剪发,理发,美容,洗发;v:洗发",
"hairgrip":"n:发夹",
"hairnet":"n:发网,网子",
"hairpiece":"n:假发",
"hairpin":"n:发卡,发簪,笄,簪,发夹",
"hairsplitting":"n:烦琐哲学,吹毛求疵",
"hairspring":"n:游丝",
"hairstyle":"n:发型",
"hairy":"a:毛茸茸,毛烘烘",
"haiti":"n:海地",
"haitian":"a:海地",
"hakeem":"n:医师,学者,医生",
"hakim":"n:法官,医师",
"hakka":"n:客家人",
"halberd":"n:戟",
"halcyon":"n:翠鸟,鱼狗,翡翠",
"hale":"v:拖曳",
"half":"n:半;a:半拉;d:一半;v:参半",
"half step":"n:半音",
"half-and-half":"n:混血儿",
"half-breed":"n:混血儿",
"half-caste":"n:混血儿",
"half-length":"n:半身像",
"half-life":"n:半衰期",
"half-mast":"v:下半",
"half-moon":"n:半月形",
"half-price":"d:半价",
"half-wit":"n:笨蛋",
"half-witted":"a:低能",
"halfback":"n:足球,前卫,中卫",
"halfheartedness":"n:贰心,二心",
"halfpenny":"n:铜币",
"halftone":"n:半音",
"halfway":"n:半道,半道儿,半路,半途,中道,中途;a:半,中途,半路,半途,半道儿;d:半途,几乎",
"halide":"n:卤化物",
"halite":"n:石盐,岩盐",
"halitosis":"n:口臭",
"hall":"n:大厅,门厅,走廊,厅,厅堂,大礼堂,过道,府第,会堂,过厅,讲堂,堂,机房,殿,庭,宅邸,馆",
"hallmark":"n:特点,标志",
"hallow":"v:尊敬;n:圣人",
"halloween":"n:万圣节",
"hallucination":"n:错觉,幻觉,梦幻泡影",
"hallucinations":"n:梦幻泡影",
"hallucinogen":"n:迷幻药",
"hallucinogenic":"a:迷幻药",
"hallway":"n:过道,门厅,穿堂,穿堂儿",
"halo":"n:晕,光环,光晕,光辉;v:晕",
"halogen":"n:卤素,卤,卤质",
"halogens":"n:卤素",
"halt":"v:停,停止,站住,站;n:立定",
"halter":"n:缰绳,绞索;v:束缚,抑制,绞死",
"halve":"v:平分,等分;n:等分",
"halves":"n:一半",
"halving":"v:等分;n:等分",
"ham":"n:火腿,腿,村庄",
"hamate bone":"n:钩骨",
"hamburg":"n:汉堡包,汉堡",
"hamburger":"n:汉堡包",
"hamilton":"n:汉密尔顿",
"hamlet":"n:村落,小村,村子,庄子,村庄,庄,村",
"hammer":"v:钉,灌输;n:链球,锤骨",
"hammer out":"v:尽力,手脚",
"hammerhead":"n:傻子,白痴,笨蛋,锤头",
"hammering":"v:锻造",
"hammock":"n:吊床,吊铺",
"hamper":"v:妨碍,牵制,挡住,梗阻,阻挠,碍手碍脚",
"hamster":"n:仓鼠",
"hamstring":"n:肌腱",
"han":"n:汉人,汉水,汉代",
"han dynasty":"n:汉朝",
"hand":"n:手,人,把,把手;v:施,相传,相沿,交代;a:手摇",
"hand brake":"n:手闸",
"hand down":"v:耷拉,流传,传递,传,传授,垂,相沿,遗传,相传,遗,遗留",
"hand drill":"n:手钻,手摇钻",
"hand in glove":"n:一气",
"hand in hand":"v:携手",
"hand out":"v:施,交出,散发",
"hand over":"v:递交,交接,递给,交代,交付,移交,递,交,缴,送交",
"hand saw":"n:手锯",
"hand towel":"n:手巾,毛巾",
"hand truck":"n:手推车,手车",
"handan":"n:邯郸",
"handbag":"n:手提包,提包,旅行包",
"handball":"n:手球",
"handbarrow":"n:小车,手推车",
"handbill":"n:传单,广告,招贴",
"handbook":"n:手册,指南,便览,小册子",
"handcart":"n:小车,手车,手推车",
"handclasp":"n:握手,握别",
"handcraft":"n:手工艺,手工",
"handcuff":"n:手铐",
"handcuffs":"n:手铐",
"handful":"n:一小撮,少数,一把,少量,把子",
"handgun":"n:短枪,手枪",
"handhold":"n:紧握,线索,把握,握住,把柄,把手;v:紧握",
"handicap":"n:障碍;v:掣肘,妨碍",
"handicapped":"a:残废;n:残疾人",
"handicraft":"n:手工艺,手工艺品,手工业,手艺,工艺,手工",
"handicrafts":"n:手艺",
"handily":"d:便",
"handiness":"n:敏捷,简便,轻便,巧妙",
"handiwork":"n:手工,活计,工艺品",
"handkerchief":"n:手帕,手绢,头巾,帕,围巾",
"handle":"v:处理;n:辫子,打交道",
"handlebar":"n:把手,车把",
"handler":"n:处理机,教练",
"handling":"n:处理,管理,操纵;v:处理,操作,加工",
"handling charge":"n:手续费",
"handmade":"a:手工",
"handmaid":"n:婢女,侍女,女仆",
"handout":"n:救济品,讲义,传单",
"handpick":"v:精选",
"handrail":"n:扶手,栏杆",
"handsaw":"n:手锯",
"handset":"n:手机",
"handshake":"n:握手",
"handshaking":"n:握手",
"handsome":"a:漂亮,英俊,俊,俊美,体面,倩,秀丽,姣,俏丽,嫣,艾,俏,帅气;n:玉",
"handspring":"n:翻筋斗",
"handstand":"v:倒立,拿顶,竖蜻蜓,拿大顶;n:竖蜻蜓,倒立,拿顶",
"handwork":"n:手工",
"handwriting":"n:书法,笔迹,字迹,手迹,手写体,笔势,手写",
"handwritten":"a:手写",
"handy":"a:方便,简便,灵便,顺手,手;n:手;v:得心应手",
"handyman":"n:勤杂工",
"hang":"v:挂,悬挂,绞死,挂断,闲荡,搭,吊;n:大意",
"hang around":"v:闲荡",
"hang back":"v:逡巡,退缩,退却",
"hang on":"v:取决于",
"hang out":"v:居住,闲荡",
"hang together":"v:齐心协力,抱,连贯",
"hang up":"v:张挂,中止,挂断",
"hang-up":"n:障碍,烦恼,苦衷,疙瘩",
"hangar":"n:飞机库",
"hangdog":"a:卑躬屈节",
"hanger":"n:衣架,吊架,吊钩,钩子,刽子手,绝壁,挂钩,悬崖",
"hanger-on":"n:食客,随从,帮闲",
"hanging":"n:绞刑,绞死,壁挂,斜坡,脚手架,悬挂,吊死,悬吊",
"hanging wall":"n:顶板",
"hangman":"n:刽子手",
"hangnail":"n:倒刺",
"hangout":"n:巢穴,住处",
"hangover":"n:酲",
"hangup":"n:心事,障碍",
"hangzhou":"n:杭",
"hank":"n:绞,优势,控制,束;v:绞",
"hanker":"v:渴望,垂涎欲滴,企求,贪,追求,贪求,垂涎,渴求,热望,热中,追",
"hankie":"n:手帕",
"hanoi":"n:河内",
"hanover":"n:汉诺威",
"hanoverian":"n:汉诺威",
"hao":"n:郝",
"hap":"n:幸运,机会",
"haphazard":"n:偶然性",
"haploid":"n:单倍体",
"haply":"d:或许",
"happen":"v:发生,出,碰巧,出现,正巧,赶巧,临到,刚巧,临头",
"happening":"n:事件;c:故",
"happenings":"n:动静",
"happily":"d:欢欢喜喜,乐,偶然",
"happiness":"n:幸福,快乐,福,愉快,幸运,吉庆,陶,欢悦,适当,乐子;a:幸福",
"happy":"a:幸福,快乐,高兴,愉快,快活,美满,快,乐意,欢乐,喜欢,美好,喜悦,舒畅,喜庆,乐陶陶,乐,乐和,陶,甜蜜,欣喜,愉,欢喜,欣忭,怿,美滋滋,甜滋滋,衎,吉庆,宽畅,怡,忭,乐悠悠,陶陶,甜津津,怡然,恺,宽舒,甜丝丝,僖;v:喜欢,舒畅",
"happy event":"n:喜庆,喜",
"harangue":"n:高谈阔论,长篇大论,训斥;v:高谈阔论,讲话",
"harass":"v:骚扰,折磨,袭扰,窜扰,扰,胡缠,扰乱,搅扰,捣,烦扰,缠绕",
"harassment":"n:折磨,烦恼,袭扰,忧虑;v:折磨",
"harbinger":"n:先驱,预兆;v:预告,预示",
"harbor":"v:窝藏;n:海港",
"harbour":"v:心怀,藏匿,庇荫,潜伏,蓄,包含,躲藏,停泊,包庇,窝,包藏,抱,怀抱,存;n:避风港",
"hard":"a:难,艰苦,硬,困难,辛苦,艰难,苦,坚硬,繁重;d:刚,好容易;n:铁",
"hard cash":"n:现金,硬币,现钱",
"hard cheese":"n:倒霉",
"hard coal":"n:白煤",
"hard copy":"n:清稿",
"hard currency":"n:硬币,硬货,硬通货",
"hard disc":"n:硬盘",
"hard disk":"n:硬盘",
"hard drink":"n:烈酒",
"hard drug":"n:毒品,麻醉品",
"hard rush":"n:灯心草",
"hard surface":"n:硬面,壳",
"hard time":"n:不景气",
"hard to please":"a:挑三窝四",
"hard up":"n:窄,窄巴,拮据,紧,困厄,紧巴巴,窘困,困顿,凄惨,窘",
"hard-of-hearing":"a:耳背",
"hardback":"n:精装书",
"hardboard":"n:硬纸板",
"hardcore":"a:碎石",
"hardcover":"a:精装",
"harden":"v:硬化,坚定,板,板结,凝固,硬结",
"hardened":"v:惯,老,麻木不仁;a:板结,老",
"hardener":"n:锻件,锻工",
"hardening":"v:凝固,淬火,硬化;n:硬结",
"hardhearted":"a:心硬;v:忍心",
"hardihood":"n:卤莽,傲慢,大胆,强壮,刚毅",
"hardiness":"n:结实,强壮,勇气,耐劳,傲慢,大胆,耐性;a:厚颜无耻",
"hardliner":"n:强硬派",
"hardly":"d:难以,才,不大,仅,刚刚",
"hardness":"n:硬度,坚固,困难,硬性",
"hardship":"n:艰苦,困苦,艰难,苦难,艰辛,苦头,苦,磨难,虐待,辛酸,罪,苦处,压制,风浪,风霜,千辛万苦,瘼,忧患,厄;a:颠连,困苦",
"hardships":"a:艰辛;n:疾苦",
"hardware":"n:硬件,计算机,机器,部件,五金,零件,构件,小五金,硬货",
"hardware store":"n:五金店",
"hardwood":"n:桢,硬木",
"hardworking":"a:勤劳,勤奋,孜孜,胼手胝足,辛勤,勤快,手勤,用功,刻苦,勤",
"hare":"n:野兔,兔子;v:飞跑",
"harelip":"n:缺嘴,豁嘴,兔唇,唇裂",
"harem":"n:妻妾,后宫,闺房",
"hark":"v:听",
"harlequin":"n:五颜六色,丑角",
"harlot":"n:婊子,妓,妓女,淫妇,娼妓",
"harlotry":"n:卖淫",
"harm":"n:贼,病;v:损伤,危害,误,病",
"harmed":"v:死伤",
"harmful":"a:有害,不良,害,不利",
"harmfulness":"n:危害性",
"harmless":"a:无害;v:无害",
"harmonic":"n:谐音;a:谐美",
"harmonica":"n:口琴",
"harmonious":"a:和谐,和,融洽,和睦;n:叶",
"harmonization":"n:和谐,一致,调和",
"harmonize":"v:协调,调和,和谐,调停,调,协和;n:协和",
"harmony":"n:和声,协调,和睦,融洽,调和,谐调,雍,适应;a:和睦",
"harness":"n:马具,挽具;v:驾",
"harp":"n:竖琴;v:唠叨",
"harpoon":"n:鱼叉,标枪",
"harrier":"n:侵略者",
"harrow":"v:折磨,抢劫,掠夺,耙;n:耙",
"harrumph":"v:埋怨",
"harry":"v:骚扰,掠夺,折磨,驱赶;n:恶魔",
"harsh":"a:刺耳,严酷,苛刻,刻薄,鬼,刻,粗重;v:粗糙",
"harum-scarum":"a:轻举妄动,冒失鬼",
"harvest":"n:收获,收成;v:获,获得",
"harvest fly":"n:蝉",
"harvest mouse":"n:巢鼠",
"harvest time":"n:秋",
"harvester":"n:收割机",
"hash":"n:复述,麻醉品,大杂烩,推敲,重申,传闻;v:重提,剁",
"hasp":"n:扣子,纺锭",
"hassle":"n:争吵,争辩;v:找麻烦",
"hassling":"v:口角,争吵",
"hassock":"n:蒲团,草丛",
"haste":"n:匆忙,草率,仓促,轻率,急速,紧迫;v:催促,匆忙,赶紧;a:草率",
"hasten":"v:赶紧,加速,赶快,促进,忙,赶忙,催,催促,趋,催逼,趱;d:赶紧",
"hastily":"d:匆忙,急忙,草草,仓促,匆促,匆,贸然,急急忙忙,率尔;a:匆猝,仓促,匆忙",
"hastiness":"n:急速,火急,轻率,慌忙",
"hasty":"a:仓促,匆促,轻率,造次,仓猝,率,草,急速;v:造次",
"hasty pudding":"n:玉米粥,面糊",
"hat":"n:帽子,帽,礼帽,帽头;v:冠",
"hatband":"n:帽带",
"hatch":"v:孵,策划,孵化;n:闸门,便门",
"hatchet":"n:斧头,斧子,斧",
"hatchet man":"n:走狗,走卒",
"hatching":"v:孵化;n:阴影",
"hatchway":"n:舱口",
"hate":"v:恨,不愿;n:怨恨;a:恶",
"hateful":"a:可恨,可恶,可憎",
"hatred":"n:仇恨,憎恨,敌意,憎恶,仇,仇怨,冤,怨毒,忾,恶意",
"hatter":"n:毛皮",
"haughtily":"d:昂然",
"haughtiness":"n:傲慢,傲气",
"haughty":"a:傲慢,高傲,傲,骄矜,倨,骄慢,亢,高慢,拿架子,傲岸",
"haul":"v:拉,拖,投降,牵,曳,牵引,降,拘捕,跩",
"haulage":"n:搬运费,拖曳,牵引力",
"hauler":"n:搬运工",
"haulier":"n:绞车,搬运工",
"haunch":"n:腰部,屁股,臀部",
"haunches":"n:股",
"haunt":"v:出没,缠,作祟,缠住;n:巢穴,鬼,渊薮",
"haute cuisine":"n:佳肴,名菜",
"hauteur":"v:吃,使,有;n:傲慢",
"havana":"n:哈瓦那",
"have":"v:有,知道,具有,进行,受,作,带,了解,取得,生,接受,拿,表现,有着,拥有,懂得,享受,含有,忍受,从事,遭受,经受,具备,打击,占有,体验,攻击,持有,备,胜过,备有,打败,具,戏弄,拥;n:诈骗,具",
"have a fit":"v:生气,大发雷霆",
"have a look":"v:查看",
"have on":"v:戏弄",
"have-not":"n:穷国,穷人",
"haven":"n:避难所,港口;v:掩护",
"haversack":"n:背包,挎包",
"having":"v:财产,所有",
"havoc":"n:摧残,浩劫,洗劫;v:毁灭;a:混乱",
"haw":"n:山楂果,花园,山楂,红果,红果儿;i:呃;v:查",
"haw-haw":"i:哈哈,哄笑",
"hawaii":"n:夏威夷",
"hawk":"v:攫取,咳嗽;n:骗子",
"hawker":"n:贩,小贩",
"hawksbill turtle":"n:玳瑁",
"hawser":"n:钢缆,缆,缆索",
"hawthorn":"n:山楂,查,楂",
"hay":"n:干草,枯草,饲草,草料,海,成果,酬报,床",
"haycock":"n:草堆",
"haydn":"n:海顿",
"hayrick":"n:草垛",
"haystack":"n:草垛",
"hazard":"n:危险,冒险,风险;v:冒险",
"haze":"n:烟雾,薄雾,渺茫,疑惑,阴霾;v:烦恼,欺侮,戏弄,折磨",
"hazel":"n:榛子,榛",
"hazelnut":"n:榛子,榛",
"haziness":"n:朦胧",
"hazy":"a:朦胧,暗,迷漫,淡薄,淡漠",
"he":"r:他,其,人家,彼;n:渠",
"he-man":"n:男子汉",
"head":"n:头,头部,脑袋,头脑,脑子,主任,头颅;v:反抗;a:总",
"head and shoulders above":"p:超出",
"head blight":"n:赤霉病",
"head cold":"n:伤风",
"head gate":"n:闸门,进水闸",
"head nurse":"n:护士长",
"head of state":"n:元首",
"head off":"v:阻止,拦截",
"head start":"n:让步,抢先",
"head word":"n:中心词",
"head-on":"d:迎面",
"headache":"n:头痛,头疼,难题;a:头痛;v:头疼",
"headband":"n:头巾",
"headdress":"n:发式,头巾,头饰",
"header":"n:标题,报头,头部,底板,头领,刽子手",
"headgear":"n:帽,安全帽,首饰,帽子,头饰",
"headiness":"n:顽固",
"heading":"n:标题,航向,方向,抽穗,题名,打尖,头球,斩首,题词;v:吐穗,抽穗",
"headlamp":"n:照明灯",
"headland":"n:岬,岬角,河源,角,地头",
"headless":"a:不慎;d:不慎",
"headlight":"n:车灯",
"headline":"n:标题,要",
"headlong":"d:一头",
"headman":"n:头人,工头,组长,工长,领班,头领,刽子手,酋长,首领",
"headmaster":"n:校长",
"headmen":"n:头人",
"headnote":"n:眉批",
"headphone":"n:耳机,头巾,盔,帽子,听筒,才智",
"headphones":"n:听筒",
"headpiece":"n:顶部,盔,上部,帽子",
"headquarter":"v:大本营,司令部",
"headquarters":"n:总部,司令部,指挥部,大本营,部,总局,本部,当局",
"headroom":"n:净空",
"headset":"n:耳机",
"headsman":"n:刽子手",
"headstall":"n:羁,笼头",
"headstand":"n:倒立",
"headstock":"n:车头,井架",
"headstrong":"a:任性,顽固;v:刚愎自用",
"headwaiter":"n:领班",
"headway":"n:前进,进展,净空",
"headwind":"n:逆风",
"headword":"n:标题,词头",
"heal":"v:愈合,治愈,痊愈,治,医治,封口,收口,养,愈",
"healing":"n:治疗;v:治愈",
"health":"n:健康,身体,卫生,干杯,兴旺;a:健康",
"health food":"n:滋补品",
"healthiness":"n:健康",
"healthy":"a:健康,健,卫生,顽健,康健",
"heap":"n:堆,许多;v:堆叠,堆积,累积",
"heap up":"v:堆叠,堆,累积",
"heaps":"d:极其,非常;n:堆",
"hear":"v:听到,听,听见,听说,听取,审理,得知,闻,得悉,倾听,允许,承认,耳闻,服从,审问",
"hearer":"n:听众",
"hearing":"n:听觉,听,听力,审讯,审问",
"hearing aid":"n:助听器",
"hearsay":"n:谣传,道听途说,传闻,传言,风闻,流言蜚语,风传,风言风语,小道消息,闻;v:闻,谣传",
"hearse":"n:柩车,殡车,灵车,灵;v:埋葬",
"heart":"n:心,心脏,心灵,心肠,感情,内心,心情,心头,热情,心地,心底,勇气,心胸,中心,绝望,良心,核心,肠,心田,胸部,精神,本质,灵魂,心口,心境,胸怀,心曲,胸,意中人,勇士,大本营,方寸,精华,精髓,灵台,心魄,重心,气质,心尖,要点,胸臆,心扉,德,心眼儿",
"heart attack":"n:心脏病,心力衰竭",
"heart disease":"n:心病",
"heart ventricle":"n:心室",
"heart-to-heart":"a:贴心",
"heartache":"n:痛心,忧戚,伤心",
"heartbeat":"n:心跳,感情,动力;v:心跳",
"heartbreak":"n:悲伤,悲痛",
"heartbroken":"a:断肠",
"heartburn":"n:不满,妒忌",
"hearten":"v:鼓舞,激励,振作,鼓励",
"heartening":"a:可喜",
"heartfelt":"a:衷心,真心,深切,由衷",
"hearth":"n:炉膛,灶台,震源",
"hearthstone":"n:家庭",
"heartily":"d:非常,热烈,完全,亲切;a:热烈",
"heartiness":"n:诚恳,诚实,热心",
"heartless":"a:无情,无情无义,丧尽天良,没良心,没心肝,狠心;v:没良心,无情无义,丧尽天良",
"heartrending":"a:回肠荡气,揪心",
"heartstrings":"n:心弦",
"heartthrob":"n:爱人,情人,感伤,心悸,心跳",
"hearty":"a:爽朗,亲切;n:运动员",
"heat":"n:热,热量;v:发怒,刺激,激动",
"heat content":"n:焓",
"heat dissipation":"n:散热",
"heat energy":"n:热能",
"heat of fusion":"n:熔解热",
"heat of vaporization":"n:汽化热",
"heat rash":"n:汗疹",
"heat up":"v:剧增,溜,热,加剧,馏,升温",
"heater":"n:加热器,暖气,手枪,雪茄烟,散热器",
"heath":"n:荒地",
"heathen":"n:异教徒",
"heathenish":"a:异教",
"heathenism":"n:异端,野蛮,异教",
"heating":"v:供暖,发热,加热,采暖,供热;n:供暖,加热,暖气,灼热",
"heating oil":"n:燃料油",
"heatproof":"a:耐热",
"heatstroke":"v:中暑;n:中暑",
"heave":"v:起伏,拉,扔,挺起,抛,发出,凸起,胀,隆起,呕吐,拉起;n:拉,呕吐,起伏,波动,举,举起,隆起",
"heave up":"v:呕吐",
"heaven":"n:天堂,天空,天,苍天,天国,上天,上帝,苍穹,神,极乐世界,霄汉,昊,堪舆,乐园,霄",
"heavenly":"d:极,天堂;v:天造地设;a:天造地设",
"heavenly body":"n:星,星体,星球",
"heavens":"n:老天爷",
"heaver":"n:投手,杠杆,挑夫,重量",
"heaves":"n:肺气肿",
"heavily":"d:重",
"heaviness":"n:疲倦,悲哀,迟钝,重,沉重,抑郁,痛苦",
"heaving":"v:举起",
"heavy":"a:沉重,重,重型,惨重,笨重,繁重,沉甸甸,沉,沉沉,笨,酷烈,瓢泼;n:巨浪,强盗,恶棍",
"heavy hitter":"n:大亨,大人物",
"heavy hydrogen":"n:氘,重氢",
"heavy water":"n:重水",
"heavyhearted":"a:忡,忧郁",
"hebrew":"n:希伯来,犹太人",
"heck":"i:决不",
"heckle":"v:诘问,梳理;n:梳理",
"hectare":"n:公顷,顷",
"hectic":"a:紧张,兴奋;n:潮红",
"hector":"v:吓唬,威吓",
"hedera helix":"n:常春藤",
"hedge":"v:闪烁其词;n:藩篱",
"hedgehog":"n:刺猬,猬,豪猪",
"hedgerow":"n:绿篱",
"heebie-jeebies":"n:颤抖",
"heed":"v:注意,听,听从,留心,留意;n:留意",
"heedless":"a:苟",
"heedlessly":"d:没头没脑",
"heehaw":"v:傻笑,大笑",
"heel":"n:跟,脚后跟,后跟,脚跟,小偷;v:供给,紧跟",
"heft":"n:影响,体重,重量",
"heftily":"d:重地",
"hegemony":"n:霸权,霸权主义,霸,霸主",
"hegira":"n:公元",
"heifer":"n:女人",
"height":"n:高,高度,身高,个子,高矮,高峰,顶点,绝顶,身长,个儿,海拔,个头,高贵,卓越,山丘,高低,个头儿;a:高",
"heighten":"v:提高,增加,加高,加深,增大,增强,增高,加强,升高,加剧",
"heinous":"a:滔天",
"heir":"n:继承人,后嗣,后代,嗣,储",
"heirloom":"n:传家宝",
"heist":"n:劫夺,拦劫,偷窃;v:偷,劫夺",
"helen":"n:海伦",
"helical":"n:螺线;a:螺线",
"helicopter":"n:直升飞机,直升机",
"heliotrope":"n:鸡血石,青莲色",
"helium":"n:氦",
"helix":"n:螺旋线,螺旋,螺线管,耳轮,蜗牛",
"hell":"n:地狱,见鬼,恶魔,垃圾箱;v:急驰",
"hell on earth":"n:活地狱,人间地狱",
"hell-for-leather":"a:不顾一切",
"hellcat":"n:悍妇,泼妇,巫婆",
"hellion":"n:坏人,恶棍",
"hello":"i:喂,欸,你好,哎;v:你好",
"helm":"n:舵;v:指挥,跺脚,驾驶,掌握",
"helmet":"n:头盔,钢盔,遮阳帽,帽,盔,帽盔儿,飞行帽,警察",
"helmsman":"n:舵手,艄公",
"helmsmen":"n:舵手",
"helot":"n:奴隶",
"help":"v:帮助,帮,帮忙;n:补救,客,济,佣人;i:救命",
"help out":"v:协助,周济,周恤",
"helper":"n:助手,帮手,下手,僚佐,副手,帮工",
"helping":"n:支援,帮助,客",
"helpless":"a:无能为力,六神无主,身不由己,六亲无靠;v:身不由己,无能为力",
"helplessly":"d:眼巴巴,眼睁睁",
"helpmate":"n:伴侣,配偶,合作者",
"helsinki":"n:赫尔辛基",
"helter-skelter":"n:慌张,狼狈",
"helve":"n:柄,柯",
"hem":"v:包围;n:贴边",
"hem in":"v:环,环抱,困,围困",
"hematite":"n:赤铁矿",
"hematology":"n:血液学",
"hemisphere":"n:半球,范围,领域",
"hemline":"n:底边,贴边",
"hemlock":"n:铁杉",
"hemoglobin":"n:血红蛋白,血色素,血红素",
"hemophilia":"n:血友病;v:便血",
"hemorrhage":"v:失血,出血;n:出血",
"hemorrhoids":"n:痔疮",
"hemp":"n:炱,麻,线麻,纤维,大麻,麻刀",
"hemstitch":"n:花边",
"hen":"n:母鸡,草鸡,惧内;v:聊天",
"hence":"d:因此,所以,用,仍,此后,从此,今后,乃,爰;c:故,因此,于是",
"henceforth":"d:今后,从今;n:此后",
"henchman":"n:狗腿子,心腹,亲信,腹心,仆从,党徒,腿子",
"henchmen":"n:仆从,党羽",
"henna":"n:红褐色,指甲花",
"henpecked":"v:惧内",
"henry":"n:亨利,亨",
"heparin":"n:肝素",
"hepatitis":"n:肝炎,肝病",
"hepatitis b":"n:乙肝",
"her":"r:她,其,伊人,人家",
"herald":"v:欢呼,宣布,通告,预告,传达,通报;n:先声,使者,预兆",
"heraldry":"n:豪华",
"herb":"n:草药,药草,草本植物,香草,牧草,草",
"herb of grace":"n:芸香",
"herbaceous":"a:草本",
"herbage":"n:牧草,草,草本,草本植物",
"herbal":"a:草本",
"herbal medicine":"n:草药",
"herbalist":"n:药农",
"herbicide":"n:除草剂,除莠剂",
"herbivore":"n:食草动物",
"herbs":"n:草本植物,药草",
"hercules":"n:大力士",
"herd":"v:牧畜,成群,看管,牧放;n:民众",
"herdsman":"n:牧民,牧人,倌,牛倌",
"herdsmen":"n:牧人,牧民",
"here":"r:此间,此地,这儿,这里,这边,这时,此处,此;d:此,这时;n:这里",
"hereabouts":"d:附近",
"hereafter":"n:今后,来世,此后,未来,以后,将来,往后,嗣后;d:以后,此后",
"hereby":"d:特此,兹,以此",
"hereditary":"v:世袭,遗传;a:遗传",
"hereditary disease":"n:遗传病",
"heredity":"n:遗传,传统,继承,遗传性",
"herein":"d:焉",
"hereinafter":"d:以下",
"hereof":"d:此,本",
"heresy":"n:异端邪说,异端,异教,左道旁门,旁门左道,邪教,邪门歪道,妖言,邪说",
"heretic":"n:异教徒",
"heretical":"a:邪,左",
"hereto":"d:至此",
"heretofore":"d:迄今,以前,迄今为止",
"hereunder":"d:在下",
"hereunto":"d:到此为止",
"hereupon":"d:于是",
"herewith":"d:因此",
"heritage":"n:遗产,传统,继承权",
"hermaphrodite":"n:雌雄同体,雌雄同株,两性人,阴阳人",
"hermaphroditic":"a:雌雄同体",
"hermit":"n:隐士,隐逸,蜂鸟,逸民,隐君子",
"hermit crab":"n:寄居蟹",
"hermitage":"n:修道院",
"hernia":"n:疝,疝气,小肠串气,突出",
"hero":"n:英雄,主人公,俊杰,主人翁,勇士,壮士,俊,豪杰,神人;a:俊",
"heroes":"n:英雄好汉,英杰,英豪,英雄豪杰",
"heroic":"a:英勇,豪迈,壮烈;n:英烈,史诗",
"heroic poetry":"n:壮歌",
"heroically":"d:大义凛然",
"heroin":"n:海洛因,吗啡,海洛英",
"heroine":"n:女主人,烈女,主人翁,巾帼英雄",
"heroism":"n:豪气",
"heron":"n:苍鹭",
"herpes":"n:疱疹",
"herring":"n:鲱鱼",
"hertz":"n:赫兹,赫",
"hesitance":"n:踌躇,犹豫",
"hesitancy":"n:踌躇",
"hesitate":"v:犹豫,迟疑,踌躇,犹犹豫豫,不愿,彷徨,含糊,口吃;a:犹疑,犹豫",
"hesitating":"v:迟疑",
"hesitation":"n:犹豫,踌躇,口吃,含糊",
"hesperus":"n:长庚星,金星",
"hessian":"n:麻布,流氓",
"heterodoxy":"n:异端,左道旁门,异教,邪门歪道,邪说",
"heterogeneity":"n:驳杂",
"heterogeneous":"a:驳杂,参差,错杂;v:错杂",
"hew":"v:开辟,劈,砍,坚持,遵守,剁,伐",
"hew out":"v:开辟",
"hewing":"v:采掘",
"hex":"n:术士,巫婆,魔力;v:迷惑",
"hexadecimal":"n:十六进制",
"hexagon":"n:六边形",
"hexameter":"n:六言诗",
"hey":"i:喂,嘿,啊,哎呀,哎",
"heyday":"n:极盛,年轻力壮,盛世,高兴",
"hf":"n:高频",
"hi-fi":"n:音响",
"hiatus":"n:间断,空隙,中断,裂缝,缺失;v:中断",
"hibachi":"n:火盆",
"hibernate":"v:冬眠;n:蚕眠",
"hibernation":"n:冬眠,过冬;v:蛰伏",
"hiccough":"n:打嗝",
"hiccup":"v:打嗝,呃逆,打嗝儿;n:打嗝",
"hickey":"n:粉刺,疙瘩",
"hickory":"n:山核桃",
"hickory nut":"n:山核桃",
"hidden":"v:潜,阴,隐伏,暗,不可告人,幽;a:阴,不可告人,暗",
"hide":"v:藏,隐藏,掩饰,隐瞒,遮掩,躲藏,遮盖,掩藏,暗藏,躲避,没,埋伏,瞒;n:隐秘,皮肤,皮子",
"hide out":"v:躲闪",
"hide-and-seek":"n:捉迷藏,躲闪",
"hideaway":"n:隐蔽所",
"hideous":"a:可怕,丑恶,丑,狞,媸,狰狞",
"hideout":"n:巢穴,窝,隐藏",
"hiding":"n:痛打,鞭打,躲藏,隐匿",
"hierarchy":"n:层次",
"hieroglyph":"n:象形文字,图画文字",
"hieroglyphic":"n:象形文字",
"higgledy-piggledy":"a:混乱",
"high":"a:高,高级,高等,高昂,崇高,高耸,高贵;n:高位;d:上游",
"high blood pressure":"n:高血压",
"high energy physics":"n:高能物理",
"high frequency":"n:高频",
"high gear":"n:全速",
"high jinks":"n:喧闹",
"high noon":"n:顶峰",
"high pitch":"n:高音",
"high profile":"n:高姿态",
"high quality":"n:优质,优等",
"high school":"n:中学,高中",
"high spirits":"n:昂扬,高兴,快乐",
"high spot":"n:名胜,特点,古迹",
"high tech":"n:高科技",
"high technology":"n:高技术",
"high treason":"n:叛逆",
"high wind":"n:大风",
"high-five":"n:庆祝",
"high-flown":"a:夸张",
"high-mindedness":"n:高尚",
"high-pressure":"v:逼使,强制",
"high-sounding":"a:冠冕堂皇,高调",
"high-spirited":"a:勇敢",
"high-tech":"n:高技术,高科技",
"high-tension":"a:高压",
"high-water mark":"n:绝顶,最高点",
"highball":"n:汽水",
"highbrow":"n:知识分子",
"higher":"a:高等,高级",
"higher education":"n:高等教育",
"higher-up":"n:领导,上级,要人,上司",
"highest":"a:无上,首;d:太",
"highfalutin":"n:大话;a:冠冕堂皇",
"highland":"n:高地,高原",
"highlight":"v:强调,突出,突显;n:要点,要闻",
"highly":"d:高度,很,非常,高",
"highness":"n:殿下,高度,高尚,高位,高贵,高,高价",
"highroad":"n:大路,公路,通路",
"highway":"n:公路,大路,途径,马路,坦途,通路,总线",
"highway robbery":"n:敲竹杠,路劫",
"highwayman":"n:强盗",
"hijack":"v:劫持",
"hijacker":"n:劫持犯",
"hike":"v:涂改,行军,增高,拉起,散步,远足;n:行军",
"hiking":"n:远足",
"hilarity":"n:狂欢,欢乐,热闹,高兴",
"hill":"n:山,丘陵,斜坡,山区,山包,冈峦,土堆,土墩,高地,陵",
"hillbilly":"n:乡下人,土头土脑,粗人",
"hillock":"n:堆,墚,丘,土堆,山冈子,山岗子,岗,山冈,岗子,陁,陀",
"hills":"n:冈峦,丘陵,群山",
"hillside":"n:山坡,山腰,衍,陂",
"hilltop":"n:山顶,山头",
"hilt":"n:刀柄,柄,把,刀把子",
"him":"r:彼,人家,他",
"hinayana":"n:下乘,小乘",
"hind":"n:雇农",
"hinder":"v:妨碍,阻碍,拦阻,阻止,伤,作梗,遮拦,妨害,拦,挠,碍,碍手碍脚,阂,干碍,阻挠;a:障碍;n:障碍",
"hindquarter":"n:牛肉,后肢",
"hindquarters":"n:屁股",
"hindrance":"n:妨碍,妨害,拦路虎,障碍",
"hinduism":"n:印度教",
"hindustan":"n:印度",
"hinge":"n:铰链,合叶;v:铰",
"hinge on":"n:取决,依赖",
"hint":"n:提示,少许;v:点",
"hinterland":"n:内地,腹地",
"hip":"n:臀部,屁股,臀围,屋脊;v:扼死",
"hip joint":"n:髋关节",
"hipbone":"n:胯骨,髋骨,坐骨,胯",
"hippie":"n:嬉皮士",
"hippo":"n:河马",
"hippopotamus":"n:河马",
"hipster":"n:行家",
"hire":"v:租,雇用,雇,出租;n:租借,租金,酬金",
"hire out":"v:出租",
"hired":"a:御用",
"hired man":"n:佣工",
"hireling":"n:佣工",
"hirer":"n:租户,雇主",
"hiring":"v:雇佣,租赁",
"hiroshima":"n:广岛",
"his":"r:其,乃",
"hiss":"v:嘘",
"histamine":"n:组织胺,组胺",
"histology":"n:组织学",
"historic":"a:历史性",
"historical":"a:历史",
"historicity":"n:历史性,真实性",
"historiographer":"n:史官",
"historiography":"n:史学",
"history":"n:历史,经历,史册,史,来历,史书,历史学,往事,诗史,沿革,史籍,预处理,大事记",
"histrionic":"a:装腔作势,演员",
"histrionics":"n:戏剧性",
"hit":"v:打,击中,得,打中,打击,袭击,达到,揍,找到,想到,批评,命中,侵袭,发现,殴打,中,抨击;n:碰撞,批评",
"hit home":"v:击中要害",
"hit the ceiling":"v:生气,暴跳如雷,发脾气",
"hit the sack":"v:睡觉",
"hit-or-miss":"a:胡乱",
"hitch":"n:故障;v:协调,挂",
"hitch up":"v:拉起,套",
"hitchhike":"v:搭便车",
"hitching":"v:车钩,挂钩;n:车钩",
"hitherto":"d:迄今,至今",
"hitler":"n:希特勒",
"hive":"n:蜂巢,蜂房,蜂箱,蜂群;v:分离",
"hive off":"v:分离,分群",
"hive up":"v:割舍",
"hoar":"n:灰白色,霜",
"hoard":"v:积蓄,贮藏,攒,囤积,囤聚,心怀;n:贮藏,宝库",
"hoarding":"n:广告牌,囤积,埋藏,贮藏",
"hoariness":"n:古老,灰白",
"hoarse":"a:嘶哑,沙哑;v:哑",
"hoarseness":"n:沙",
"hoary":"a:灰白",
"hoary willow":"n:雪柳",
"hoax":"v:戏弄,欺骗,诓骗,赚;n:骗术,骗局,愚弄,戏弄",
"hob":"n:捣乱,恶作剧",
"hobble":"v:蹒跚,疙疙瘩瘩,阻碍",
"hobby":"n:爱好,嗜好,木马,兴趣,竹马",
"hobbyhorse":"n:嗜好,竹马,木马",
"hobbyist":"n:爱好者",
"hobgoblin":"n:淘气鬼,怪物,妖怪,小鬼",
"hobnail":"n:大头针",
"hobnailed":"a:土头土脑",
"hobnob":"n:聚会,恳谈;v:恳谈",
"hobo":"n:流浪汉",
"hock":"n:监牢,抵押,典当,吊钩;v:典当,抵押",
"hockey":"n:曲棍球,冰球",
"hocus-pocus":"n:咒语,欺骗;v:戏弄",
"hod":"n:煤斗",
"hodgepodge":"n:大杂烩",
"hoe":"n:锄头;v:锄,菑,挖掘",
"hoedown":"n:打群架,土风舞,闹事,吵闹,争论",
"hog":"n:猪,生猪,肥猪,猪肉;v:剪短,抢占,攫取",
"hog badger":"n:猪獾",
"hog-nosed badger":"n:猪獾",
"hogging":"v:弯曲",
"hogwash":"n:泔水,泔,废话,泔脚,潲,猪食",
"hoi polloi":"n:老百姓,群众,名流",
"hoist":"n:举;v:举起,提升,揭,升",
"hoisting":"n:起重,提升;a:起重;v:吊装",
"hoity-toity":"a:傲慢",
"hokkaido":"n:北海道",
"hold":"v:举行,有,认为,拿,坚持,保持,抓住,把,握,控制,想,持有;n:同期,威力,预约,载",
"hold back":"v:憋,踌躇,拉后腿,拦,截留,拦阻,取消,压抑,保留,克制,敛,忍",
"hold close":"v:抱紧",
"hold dear":"v:重视,爱惜,爱,珍重",
"hold down":"v:压",
"hold forth":"v:提供",
"hold in":"v:窝火,约束,窝,抑制",
"hold off":"v:拖延,不可向迩,挡住",
"hold on":"v:继续,保守,抓住",
"hold one's own":"v:招架",
"hold out":"v:熬,支持,挺,主张",
"hold over":"v:延迟,留任,推迟",
"hold sway":"v:当道",
"hold the line":"v:坚守,坚定不移",
"hold tight":"v:薅,揪",
"hold up":"v:拦路抢劫,搂,抢劫,竖起,耽搁,支,挢,提出,抓起,堵塞,举,搴,耽误,扶,龟缩,举起,拦截,推举,支援,阻挡,阻断,阻截,拦击,撩,跷,扣压,拦劫,敲竹杠",
"hold water":"v:成立,言之有理,站住脚,站住",
"holder":"n:支架,暗盒,烟嘴,烟嘴儿,把手,夹,杆,架,容器,货主,夹具",
"holding":"n:所有,持有,所有权,矿区,享有;v:裁定",
"holdout":"n:坚持,伸出,延续,抵抗,提供",
"holdover":"n:残余,遗物",
"holdup":"n:停顿,阻滞;v:路劫",
"hole":"n:洞,孔,窟窿,空穴,窝,漏洞,坑,洞穴,穴,口;v:开,蛰居,穿,挖,离群索居",
"hole up":"v:躲藏,蛰居,离群索居",
"holiday":"n:假日,假期,节日,假;v:休假",
"holidays":"n:假期",
"holiness":"n:神圣,纯洁",
"holing":"a:贯通;v:贯通",
"holland":"n:荷兰",
"holler":"v:大喊大叫,欢呼,抱怨,诉苦,叫喊;n:呼叫,呼救",
"hollow":"a:凹,虚空,干;n:窟窿,洞穴,窝,虚空;v:凹陷,掏;d:彻底,完全",
"hollow out":"v:掏,镂空,刳",
"hollowness":"n:中空",
"holly":"n:冬青",
"hollyhock":"n:蜀葵",
"hollywood":"n:好莱坞",
"holmium":"n:钬",
"holocaust":"n:大屠杀,浩劫",
"hologram":"n:全息照相",
"holographic":"a:全息",
"holography":"n:全息摄影,全息照相",
"holy":"a:神圣",
"holy communion":"n:圣餐",
"holy father":"n:圣父,罗马教皇",
"holy joe":"n:信徒",
"holy land":"n:圣地",
"holy man":"n:道人",
"holy spirit":"n:圣灵",
"homage":"n:效忠,敬意,尊敬,服从,顺从,臣服",
"home":"n:家;d:回国,在家;v:归航,回老家,居住",
"home base":"n:根据地",
"home office":"n:总公司",
"home page":"n:主页",
"home secretary":"n:内务",
"home truth":"n:老生常谈",
"homecoming":"n:归国,回老家",
"homeland":"n:本国,祖国,家园,故国,故土",
"homeless":"a:飘零,露宿风餐;v:飘零",
"homelessness":"n:无家可归",
"homelike":"a:宾至如归",
"homeliness":"n:朴素",
"homely":"a:家常",
"homemaker":"n:主妇",
"homemaking":"v:治家;n:家政",
"homeostasis":"n:动态平衡",
"homer":"n:荷马,通信鸽,归航台,信鸽",
"homesick":"a:想家,思乡;v:思乡",
"homesickness":"n:乡思,乡愁",
"homespun":"n:钢花呢,土布",
"homestead":"n:家宅,田产,宅基,农场,家园",
"hometown":"n:家乡,故乡,籍,乡,里",
"homework":"n:作业,功课,作业题",
"homicide":"n:杀人,杀人罪;v:凶杀",
"homily":"n:布道,讲道",
"homing":"v:归航,归位,引导,寻的;n:导航,归航,归来",
"hominid":"n:人类,原人",
"hominy":"n:玉米粥",
"homo sapiens":"n:新人",
"homogeneity":"n:同性,均匀,同一性",
"homogeneous":"a:均匀,清一色",
"homogenize":"v:调匀",
"homograph":"n:同形词",
"homologous":"a:对应;v:对应",
"homologue":"n:同系物",
"homology":"n:相同,相应,符合,透射,同调;v:透射",
"homomorphism":"n:同形",
"homonym":"n:同名,同音词;v:同名",
"homophone":"n:同音字;v:同音",
"homophony":"n:同音",
"homosexual":"a:同性恋",
"homosexuality":"n:同性恋,同性恋爱;v:同性恋",
"homunculus":"n:矮子",
"honcho":"n:头头,头头儿,老板",
"honduras":"n:洪都拉斯",
"hone":"v:磨,抱怨,千锤百炼;n:油石",
"honest":"a:诚实,老实,正直,正,老老实实,真诚,实在,普通,廉洁,纯正,正经,正派;n:正大;v:雅正",
"honestly":"d:老老实实,实在",
"honesty":"n:诚实,老实,正直,公正,守信用,廉耻,清廉,贞节",
"honey":"n:蜂蜜,蜜,宝贝,甘美;v:奉承;a:甜蜜",
"honeybee":"n:蜜蜂",
"honeycomb":"n:蜂窝,蜂巢,蜂巢胃;v:削弱",
"honeydew melon":"n:哈蜜瓜",
"honeyed":"n:蜜;v:蜜",
"honeyed words":"n:甜言蜜语,迷魂汤",
"honeymoon":"n:蜜月",
"honeysuckle":"n:忍冬,金银花,苜蓿",
"hong kong":"n:港",
"hong kong dollar":"n:港币",
"honing":"v:珩磨",
"honk":"v:按,叫,发出",
"honky":"n:白人",
"honolulu":"n:檀香山,火奴鲁鲁",
"honor":"n:荣誉,光荣;v:尊重,敬重",
"honorable":"a:体面,尊贵,光彩,高贵,贵,荣幸,光耀",
"honorarium":"n:报酬,车马费,谢礼",
"honorary":"a:名誉,荣誉;n:名誉",
"honored":"a:好看",
"honorific":"n:尊称,敬语",
"honour":"n:荣幸,光荣,名誉;v:敬重,褒,表彰,戴,兑现,接受;a:光荣,尊荣",
"honourable":"a:贵,尊贵,荣幸,高贵,光耀,刚正,光彩,体面",
"honoured":"a:好看",
"honshu":"n:本州",
"hoo-ha":"n:骚动,骚乱",
"hooch":"n:烈酒",
"hood":"n:罩,车篷,头巾;v:隐蔽",
"hoodlum":"n:无赖,流氓,强盗,恶棍,阿飞,歹徒,光棍,暴徒",
"hoodoo":"v:倒霉;n:恶运",
"hoodoos":"n:石林",
"hoodwink":"v:骗,欺骗,罔,戏弄,愚弄,隐蔽,谩,蒙骗,欺瞒,哄骗,蒙蔽,欺蒙,蒙哄,赚",
"hooey":"n:废话,胡说,胡言乱语",
"hoof":"v:走,踏,踢,跳舞;n:蹄,蹄子",
"hoofer":"n:黑人",
"hoofs":"n:蹄",
"hook":"n:钩,钩子,吊钩;v:摽,联网,欺骗",
"hookah":"n:水烟筒",
"hooker":"n:妓女",
"hookup":"n:联系",
"hookworm":"n:钩虫",
"hookworm disease":"n:钩虫病",
"hooky":"n:逃学,旷课;v:扒窃",
"hooligan":"n:流氓,无赖,阿飞",
"hooliganism":"n:流氓,流气",
"hoop":"n:铁环,环,箍,篮;v:拥抱,包围",
"hoopla":"n:喧闹,大话",
"hoosegow":"n:警卫室,厕所,监狱",
"hoot":"v:叫,喝倒彩,起哄;d:呜呜,呜;n:起哄",
"hooter":"n:汽笛",
"hooting":"v:倒彩,倒好儿;n:倒彩,倒好儿",
"hooves":"n:蹄",
"hop":"v:跳跃,走开,搭乘;n:弹跳,舞会,跳跃",
"hope":"v:希望;n:沼泽,冀望,冀",
"hopeful":"a:乐观,有望;v:有望",
"hopefully":"d:有望",
"hopeless":"a:无望,不可救药,没辙,不可收拾,绝;v:不可救药,无望,不可收拾",
"hopelessness":"n:绝望;a:绝望",
"hopper":"v:漏兜;n:漏斗",
"hops":"n:酒花",
"hopscotch":"n:跳房子",
"horde":"n:群;v:成群",
"horizon":"n:地平线,眼界,水平线,天边,视野,天际,范围,见识,水平仪,地层,水平面",
"horizontal":"n:水平线;a:纵",
"hormone":"n:激素,荷尔蒙,内分泌",
"horn":"n:喇叭,角,号角,角质,犄角,圆号,触须,号,管,海角,力量;v:干涉",
"horn in":"n:干涉,闯入",
"hornblende":"n:角闪石",
"hornet":"n:蚂蜂,黄蜂,马蜂,胡蜂",
"horoscope":"n:八字",
"horrible":"a:可怕,恐怖;v:不得了",
"horrified":"v:悚然",
"horrify":"v:瘆",
"horrifying":"v:触目惊心,骇人听闻;a:触目惊心,骇人听闻",
"horror":"n:恐怖,嫌恶,战栗,惊骇,痛恨",
"horse":"n:马,马匹,木马;v:嘲弄",
"horse around":"v:行乐,胡闹,闹着玩儿",
"horse botfly":"n:马蝇",
"horse chestnut":"n:七叶树",
"horse doctor":"n:兽医",
"horse mackerel":"n:金枪鱼",
"horse race":"n:跑马",
"horse racing":"n:赛马",
"horseback":"n:马背",
"horsefly":"n:虻",
"horsehair":"n:鬃毛,马鬃",
"horselaugh":"n:大声,哄笑",
"horseman":"n:骑兵,骑手",
"horsemanship":"n:马术,骑术",
"horsemen":"n:骑手",
"horseplay":"n:恶作剧;v:哄",
"horsepower":"n:马力",
"horses":"n:马匹",
"horseshit":"n:狗屁,马粪",
"horseshoe":"n:马掌;v:掌",
"horseshoe crab":"n:鲎",
"horsetail":"n:木贼,马尾",
"horsewhip":"n:马鞭,枚",
"horticulture":"n:园艺",
"horticulturist":"n:园艺家",
"hose":"n:软管,水龙,水管,袜子,短袜,长统袜,水龙带,短统袜,叶鞘,袜",
"hosiery":"n:袜子",
"hospice":"n:收容所,救济院",
"hospitable":"a:好客,殷勤,殷",
"hospital":"n:医院,病院,院",
"hospitality":"n:好客,殷勤,款待,适宜,宜人,厚谊",
"hospitalize":"v:入院",
"host":"n:主人,主机,主,寄主,许多,宿主;v:做主,款待",
"hostage":"n:人质,肉票,抵押品,票",
"hostel":"n:招待所,客店,旅社,宿舍,客栈,旅店",
"hostelry":"n:旅馆,客栈",
"hostess":"n:女主人,空中小姐,主妇,舞女",
"hostile":"a:敌对",
"hostilities":"n:战事",
"hostility":"n:敌对,敌意,敌视,战斗,仇恨,仇怨",
"hostler":"n:马夫",
"hot":"a:热,闷热,辣;d:犹豫不决",
"hot air":"n:不经之谈",
"hot dog":"n:热狗",
"hot line":"n:热线",
"hot pepper":"n:番椒,辣子",
"hot plate":"n:煤气炉",
"hot seat":"n:电椅",
"hot spring":"n:汤泉",
"hot springs":"n:汤",
"hot water":"n:温水,汤",
"hot weather":"n:暑",
"hot-water bag":"n:热水袋",
"hot-water bottle":"n:汤壶,热水袋",
"hotbed":"n:温床,策源地",
"hotchpotch":"n:大杂烩,浓汤,全家福,杂烩,杂拌儿",
"hotel":"n:旅馆,饭店,宾馆,旅社,逆旅,酒楼,客舍,宅邸",
"hotfoot":"n:恶作剧,震惊",
"hothead":"n:愣头愣脑,愣头儿青",
"hothouse":"n:温室,暖房,干燥室",
"hothouses":"n:温室",
"hotly":"d:热",
"hotness":"n:热心,热烈,暑热",
"hotshot":"n:大亨,大人物,能人,快车,要人",
"hound":"v:追逐;n:狗",
"hour":"n:小时,时间,钟头,时刻,现在,钟点,时,课时,时代",
"hour circle":"n:子午线",
"hour hand":"n:时针",
"hourglass":"n:漏壶,漏刻,漏,沙漏;v:漏",
"hourly":"a:时时,常常;d:时时",
"house":"n:房子,家,房屋,屋,房,住宅,所,房间,门,家务,家庭;v:庇护,安置,收容,接待,居,留宿,嵌入,舍",
"house mouse":"n:鼷鼠,家鼠",
"house of commons":"n:下院,众议院",
"house of detention":"n:拘留所",
"house of god":"n:教堂,寺庙",
"house of lords":"n:上院,参议院",
"house party":"n:家宴",
"houseboat":"n:游艇",
"houseboy":"n:童仆",
"houseboys":"v:竖;n:童仆",
"housebreaker":"n:窃贼",
"houseclean":"v:打扫,大扫除,清理,改革",
"housecleaning":"n:清洗,清理,大扫除",
"housecoat":"n:便服",
"housefly":"n:家蝇",
"household":"n:家庭;a:家用",
"householder":"n:住户,房主,户主,户长,家长",
"housekeeper":"n:管家,主妇,姆,保姆,马夫",
"housekeeping":"n:家政",
"housemaid":"n:女仆,使女",
"houseman":"n:男仆",
"housemaster":"n:主人",
"houseroom":"n:卧室",
"houses":"n:房屋",
"housetop":"n:屋顶",
"housewife":"n:主妇,家庭妇女",
"housework":"n:家务,家务活",
"housing":"n:住房,住宅,套,外壳,掩护,避难所,罩;v:罩",
"houston":"n:休斯敦",
"hovel":"n:茅舍,陋室",
"hover":"v:盘旋,徘徊,翱翔,飞翔,萦回;n:翱翔",
"hovercraft":"n:气垫船,气垫,水翼船",
"how":"d:怎么,怎样,多么,怎;r:如何,怎么样,若何,怎,怎么,怎的,怎生,怎样,咋,怎地,怎么着;n:方法;v:争;a:恶",
"howe":"n:豪,洼地",
"however":"d:不过,却,可是,不管怎样,无论如何,则,虽然如此,只是,无奈;c:无论,不管,可是,然而,虽然,然",
"howitzer":"n:榴弹炮,榴霰弹",
"howl":"v:呼啸,怒吼,嚎叫,怒号;n:嚎哭,号,叫声",
"howsoever":"d:不管怎样,无论如何",
"hp":"n:马力,惠普",
"hua":"n:花,华",
"hub":"n:轮毂,中心,集线器,枢,毂,插孔,枢纽,衬套,中枢",
"hubble-bubble":"n:骚动",
"hubbub":"n:乱糟糟,喧嚷,喧哗,喊声;v:喧嚷;a:乱糟糟",
"hubby":"n:丈夫",
"hubris":"n:傲慢,狂妄自大",
"huckleberry":"n:越橘",
"huckster":"v:零售,叫卖,讨价还价,吹嘘;n:行商",
"huddle":"n:拥挤,会议,混乱;v:拥挤",
"hue":"n:色彩,色,样子,色调,色相,特色,形式",
"huff":"v:喘气,吓唬,吹气,激怒;n:发怒",
"hug":"v:拥抱,坚持,拥,搂,搂抱,偎抱;n:拥抱",
"huge":"a:巨大,庞大,巨,浩大,巨幅,庞",
"hugeness":"n:巨大",
"hugger-mugger":"n:混乱,秘密",
"hugo":"n:雨果",
"hui":"n:惠",
"hula":"n:呼啦",
"hull":"n:船身,船体,船壳,外壳,衣服,膜片,豆荚,机身",
"hullabaloo":"n:哇啦,吵闹,喧嚣,喧哗;d:哇啦;v:喧嚣",
"hullo":"i:喂",
"hum":"v:哼;n:哼哼;d:嗡嗡,嗡;a:恶;i:嗯",
"human":"n:人,人类,人道",
"human being":"n:人,人类,有生",
"human body":"n:人体,皮囊,人身",
"human nature":"n:人之常情",
"human race":"n:人类",
"human waste":"n:人粪尿",
"humane":"a:人道;n:人道",
"humaneness":"n:深情",
"humanism":"n:人道主义,人本主义,人文主义",
"humanitarian":"n:慈善家",
"humanitarianism":"n:人道主义",
"humanities":"n:人文科学,人文",
"humanity":"n:人类,人,人性,人道,仁爱,人情,人们,人性论,博爱,仁",
"humanize":"v:人格化",
"humankind":"n:人类,人",
"humanness":"n:为人",
"humble":"a:卑微,谦卑,低微,微贱,卑贱,卑下;v:菲薄",
"humbleness":"n:谦逊",
"humbug":"v:哄,哄闹,哄骗,诈骗,欺骗,哄弄,行骗;n:骗子,糖果,空话,谎言",
"humdrum":"n:单调,无聊;a:平凡",
"humerus":"n:肱骨",
"humid":"a:潮湿,湿,温湿",
"humidification":"n:湿润",
"humidify":"v:潮湿",
"humidity":"n:湿度,水分,湿气,潮气,潮湿;a:潮湿",
"humiliate":"v:羞辱,凌辱,污辱,作践,摧残,折辱,侵凌,侮;n:羞辱",
"humiliation":"n:屈辱,耻辱,羞辱,奇耻大辱;v:羞辱",
"humility":"n:谦卑,谦恭,谦逊,谦让,谦虚谨慎",
"hummer":"n:蜂鸣器",
"humming":"v:哼唱",
"hummingbird":"n:蜂鸟",
"humor":"n:幽默,诙谐,风趣;v:风趣,哄",
"humorless":"a:一本正经",
"humorous":"a:幽默,诙谐,谐,俳",
"humour":"n:幽默感,心情,情绪,风趣;v:哄,迎合,纵容",
"hump":"n:驼峰,驼背;v:飞跑,拱",
"humpback":"n:弓背,罗锅儿,驼背,驼子",
"humpbacked":"a:驼,驼背,罗锅儿",
"humus":"n:腐殖质,腐殖土",
"hun":"n:匈奴",
"hunan province":"n:湘,湖南",
"hunch":"v:弓,隆起,推进;n:堆,隆起",
"hunchback":"n:驼背,罗锅儿,驼子,弓背,罗锅",
"hunchbacked":"a:弓背,罗锅儿",
"hundred":"a:百,许多,佰;n:许多",
"hundredfold":"n:百倍",
"hungary":"n:匈牙利,匈",
"hunger":"n:饥饿;v:挨饿,渴求",
"hungriness":"n:渴望,荒漠,饥饿",
"hungry":"a:饿",
"hunk":"n:大片",
"hunker":"n:保守派,臀部",
"hunks":"n:吝啬鬼,守财奴",
"hunt":"v:打猎,追捕,猎取,捕猎,搜寻,猎,驱赶;n:探求,搜索,田",
"hunter":"n:猎人,猎手,猎狗,猎犬,猎户",
"hunting":"v:搜索,狩猎,寻找,摆动,探求;n:追寻",
"hunting dog":"n:猎犬",
"hunting ground":"n:猎场",
"huntsman":"n:猎人,猎户",
"huntsmen":"n:猎人",
"hurdle":"n:障碍,跨栏,困难,篱笆,跳栏;v:突破,跳栏",
"hurdle race":"n:跳栏",
"hurl":"v:投,投掷,吐,投球,推翻,猛冲,拽",
"hurler":"n:投手",
"hurling":"n:投掷",
"hurrah":"n:欢呼声;v:欢呼",
"hurricane":"n:飓风,急风暴雨,暴风骤雨,飙,疾风暴雨,狂飙",
"hurried":"a:仓促,急煎煎,急促;v:造次",
"hurriedly":"d:匆匆,慌忙,急忙,仓促,连忙,急匆匆,匆猝,赶忙,急急忙忙;a:匆匆忙忙,匆猝,仓促",
"hurry":"v:赶快,忙,催,催促;n:慌忙,混乱,手忙脚乱,慌张,席不暇暖,骚动",
"hurt":"v:伤,伤害,损害;n:苦痛,伤痛",
"hurtfulness":"n:伤害",
"hurtle":"v:猛冲;n:碰撞",
"husband":"n:丈夫,男人,夫,女婿,夫婿,夫子,人夫,管家,爱人,官人,当家的,汉子,老公,老伴儿,夫君,老倌,爷们;v:耕,栽培",
"husbandman":"n:农民,农夫",
"husbandry":"n:管理,农业,耕种,节俭,节约,务农,耕作",
"hush":"v:掩盖,秘而不宣;n:静寂,秘而不宣",
"hush up":"v:缄默",
"hush-hush":"a:封锁,机密",
"husk":"n:糠,外皮;v:碾场",
"huskiness":"n:沙",
"husky":"a:沙哑;v:哑;n:沙",
"hussar":"n:轻骑兵",
"hussy":"n:荡妇",
"hustle":"v:欺骗,奔忙,挤出,逼使;n:努力,推",
"hustler":"n:骗子,妓女",
"hut":"n:小屋,草屋,茅舍;v:舍",
"hutch":"n:笼,箱,小屋,舍",
"hyacinth":"n:水葫芦,风信子",
"hybrid":"n:杂种,混合,杂交种,混血儿,混合物,混血种,节点;v:混合",
"hybridise":"v:杂交",
"hybridism":"n:杂交,杂种",
"hybridization":"n:杂交;v:杂交",
"hybridize":"v:杂交",
"hydra":"n:水螅",
"hydrant":"n:水龙头",
"hydrate":"n:水合物;v:水合",
"hydrated lime":"n:熟石灰",
"hydration":"n:水合,水化;v:水合",
"hydraulic press":"n:液压机",
"hydraulics":"n:水力学,水利",
"hydrazine":"n:肼",
"hydride":"n:氢化物",
"hydro":"n:水上飞机",
"hydrocarbon":"n:烃,碳氢化合物",
"hydrocephalus":"n:脑积水",
"hydrochloric":"n:盐酸",
"hydroelectricity":"n:水电",
"hydrofoil":"n:翼,水翼船",
"hydrogen":"n:氢,氢气",
"hydrogen chloride":"n:氯化氢",
"hydrogen cyanide":"n:氰化氢",
"hydrogen peroxide":"n:过氧化氢",
"hydrogen sulfide":"n:硫化氢",
"hydrogenate":"v:氢化",
"hydrogenation":"v:氢化;n:氢化",
"hydrology":"n:水文学,水文",
"hydrolysis":"v:水解;n:水解",
"hydrolyze":"v:水解",
"hydromechanics":"n:流体力学",
"hydrophobia":"n:恐水病,狂犬病",
"hydroplane":"n:水上飞机",
"hydrosphere":"n:水圈,水界,水气",
"hydrotherapy":"n:水疗",
"hydroxide":"n:氢氧化物",
"hydroxyl radical":"n:羟基",
"hyena":"n:鬣狗",
"hygiene":"n:卫生,卫生学",
"hygienic":"a:卫生",
"hygienics":"n:卫生学",
"hygrometer":"n:湿度计",
"hymen":"n:处女膜",
"hymeneal":"n:婚姻",
"hymn":"n:赞美诗,赞歌",
"hype":"n:花招",
"hyperbola":"n:双曲线",
"hyperbole":"n:夸张",
"hyperboloid":"n:双曲面",
"hypercritical":"a:吹毛求疵;v:吹毛求疵",
"hyperlink":"n:超级链",
"hypersensitive":"v:神经过敏;a:神经过敏",
"hypersensitivity":"n:过敏性",
"hypersonic":"a:超子",
"hypertension":"n:高血压",
"hypertrophy":"n:肥大;a:肥大",
"hyphen":"n:连字号,连接号",
"hyphenation":"n:连字号",
"hypnosis":"n:催眠术,催眠",
"hypnotic":"n:催眠药;a:催眠;v:催眠",
"hypnotism":"n:催眠,催眠术",
"hypnotize":"v:催眠",
"hypo":"n:海波,大苏打,刺激",
"hypochondria":"n:疑心病",
"hypocrisy":"n:虚伪,伪善,假意,假仁假义",
"hypocrite":"n:伪君子,乡愿,假道学",
"hypocritical":"a:虚伪,伪善,假惺惺;v:酸文假醋",
"hypocritically":"d:假惺惺",
"hypodermic syringe":"n:注射器",
"hypoglossal nerve":"n:舌下神经",
"hypoglycemia":"n:低血糖",
"hypotenuse":"n:弦,斜边",
"hypothalamus":"n:下丘脑",
"hypothermia":"n:降温,低温",
"hypotheses":"n:假设,假说",
"hypothesis":"n:假设,假说,假定,前提,臆说,假想",
"hypothesize":"v:假设,假定,假想",
"hypothetical":"a:假设,假想",
"hypoxia":"n:缺氧",
"hysteresis":"n:滞后",
"hysteria":"n:歇斯底里,癔病",
"hysteric":"n:歇斯底里,发狂",
"hysterics":"n:哄笑",
"i":"r:我,人家,咱们,俺,在下,小弟;n:兄弟,自我,意大利;a:余,愚",
"ibex":"n:羱羊,羱",
"ibidem":"d:同上",
"ibis":"n:红鹤,鹮",
"ice":"v:冰,结冰;n:冷淡",
"ice age":"n:冰川期",
"ice bag":"n:冰袋",
"ice cream":"n:冰淇淋,冰糕,冰激凌",
"ice crystal":"n:冰花,冰晶",
"ice floe":"n:冰排",
"ice pick":"n:冰镐",
"ice rink":"n:冰场",
"ice skate":"n:溜冰鞋,冰刀",
"ice storm":"n:冰雹",
"ice-cold":"a:冰冷,冰凉",
"iceberg":"n:冰山",
"iceboat":"n:破冰船",
"icebox":"n:冰箱",
"icebreaker":"n:破冰船",
"icecap":"n:冰盖",
"iced":"v:冰镇",
"iceland":"n:冰岛",
"ichthyology":"n:鱼类学",
"icicle":"n:冰柱,冰凌,冰锥",
"icicles":"n:树挂",
"iciness":"n:冰冷",
"icing":"n:糖衣,糖霜,积冰",
"icon":"n:偶像,雕像,画像,圣像,肖像,人像,影像",
"iconography":"n:插图,图解",
"ictus":"n:发作,冲击;v:冲击,发作",
"icy":"a:冷冰冰,冽",
"id":"v:识别",
"idea":"n:想法,主意,思想,意见,观念,概念,念头,观点,计划,意思,见解,想象,打算,见,计,点子,意念,念,构想,主,想像,心劲,主题,心裁,心头,理念,心思,意,主见,定盘星,稿子,辙,观;v:见,构想",
"ideal":"n:理想,典型,抱负,天造地设,志气,志愿,志,模范,志向;v:天造地设",
"idealism":"n:唯心论,唯心主义",
"idealist":"n:空想家;a:唯心",
"idealistic":"a:唯心",
"idealization":"n:理想化;v:简化",
"idealize":"v:理想化",
"ideas":"n:脑筋",
"idem":"r:同上",
"identical":"a:相同,同一,一致,雷同,清一色",
"identically":"d:同样,同一",
"identification":"n:标识,识别,鉴定,身份证,证明,确认,认证,辨识,同化,认出;v:识别,认证",
"identifier":"n:标识符,标识号,编号",
"identify":"v:识别,对,鉴定,鉴别,认同,辨认,认,确认;n:同一性",
"identifying":"v:标识;n:标识",
"identity":"n:身份,身分,恒等式,一致,个性,同一性,本体,正身,同一",
"ideogram":"n:表意文字",
"ideograph":"n:表意文字",
"ideologist":"n:理论家,空想家,思想家",
"ideologue":"n:理论家,空想家",
"ideology":"n:意识形态,思想,观念形态,空论,思想体系,空想",
"idiocy":"n:白痴",
"idiom":"n:成语,惯用语,方言,土语,风格,熟语,口碑,习用语",
"idiosyncrasy":"n:特性,特质,个性",
"idiot":"n:白痴,笨蛋,蠢货,草包,憨子,傻子,痴子,蠢材,蠢物,蠢驴,呆子",
"idiot box":"n:电视机",
"idiotic":"a:痴,憨痴,呆头呆脑,痴呆",
"idle":"a:闲,闲散,懒惰,空闲,懒,怠惰,呆滞,磨;v:吃喝玩乐,蹉跎,懒,虚度,空耗,怠;n:空闲",
"idle talk":"v:空话,清谈,空谈,闲谈",
"idleness":"n:懒惰,失业,无益,空闲,无效",
"idler":"n:空载,闲人,空车,二流子,懒汉",
"idling":"v:空转,空载,慢速;n:空载",
"idol":"n:偶像,泥胎,幻像,偶,幽灵,谬见,谬论,幻象",
"idolize":"v:崇拜",
"idyll":"n:田园诗,牧歌",
"idyllic":"n:诗情画意,田园诗;a:诗情画意",
"ie":"d:即",
"if":"c:就,如果,要是,要,若,假如,如,假若,而,是否,倘若,假使,即使,万一,若是,倘使,假设,假,设;v:使,是否,脱;n:条件;a:中频,假;d:如",
"if not":"c:若非",
"if only":"c:只要",
"igneous":"a:火成岩",
"ignis fatuus":"n:鬼火",
"ignite":"v:点燃,点火,引火,燃烧,引燃,燃,发火,引爆,起爆,燃点",
"ignition":"n:点火,燃烧,起爆,点燃;v:点燃,点火",
"ignominious":"a:可耻",
"ignominy":"n:耻辱,可耻,不名誉,污辱",
"ignoramus":"n:笨蛋,门外汉,愚人",
"ignorance":"n:无知,愚昧,蒙",
"ignorant":"a:无知,愚昧,蒙昧,愚味,孤陋寡闻,茫然,蚩,侗,懵懂,愚蒙,胸无点墨,浑浑噩噩,瞳,瞀,颛,茫,懵,儒,固陋,昧;v:孤陋寡闻,有眼无珠;n:胸无点墨",
"ignore":"v:忽视,不理,忽略,无视,置之不理,不顾,抹煞,驳回,忽,漠视,冷;a:冷",
"ileum":"n:回肠",
"ilium":"n:肠骨,髂,髂骨",
"ilk":"n:家族,同类",
"ill":"n:疾病,罪恶,病痛,灾难;d:坏,笨,恶劣;a:邪恶,不善",
"ill at ease":"a:拘束,惴惴不安,忐忑不安,窘",
"ill fame":"n:恶名",
"ill luck":"n:恶运,厄运",
"ill will":"n:恶意,嫌,嫌隙",
"ill-being":"n:不幸,病态,贫穷",
"ill-fated":"a:倒霉",
"ill-mannered":"a:粗鲁",
"ill-treat":"v:虐待",
"ill-treatment":"n:虐待,糟塌,滥用",
"illegal":"a:非法,不法;v:禁用",
"illegality":"n:不法,犯规,违法",
"illegibility":"n:模糊不清",
"illegible":"a:潦草",
"illegitimacy":"n:私生,不法,非法,违法",
"illiberality":"n:吝啬",
"illicit":"a:非法,私",
"illimitable":"a:无边无际",
"illinois":"n:伊利诺斯",
"illiteracy":"n:文盲,睁眼瞎子,蒙,错误,失学",
"illiterate":"n:文盲;a:不识一丁",
"illiterate person":"n:白丁",
"illness":"n:病,疾病,病症,矜,疴,瘵,证,症,恙,疾,毛病",
"illogicality":"n:矛盾",
"illuminant":"n:光源",
"illuminate":"v:照亮,启发,照,阐明,说明,照明,照射,装饰,启蒙,照耀",
"illuminated":"a:火亮;v:火亮",
"illumination":"n:照,照明,照射,明亮,彩灯,启发,光照,启蒙,阐明,照度;v:照射",
"illumine":"v:照亮,启发",
"illusion":"n:幻想,幻觉,错觉,梦幻,假象,幻影,虚幻,镜花水月,玄想,痴想,幻景,梦幻泡影,幻梦,妄想",
"illusionist":"n:魔术师",
"illusions":"n:空中楼阁",
"illusive":"a:空幻",
"illusory":"a:虚幻,虚无缥缈;v:虚无缥缈",
"illustrate":"v:说明,举例,阐明",
"illustration":"n:插图,说明,图解,例证,实例,插画",
"illustrious":"a:显赫,赫赫有名;v:闻达",
"image":"n:象,图象,像,图像,影象,影像,形像;v:象征",
"imagery":"n:成像,雕像,像,画像,意象,比喻,肖像",
"imaginary":"a:假想,虚幻,空幻;n:虚幻",
"imagination":"n:想象力,想像力,想象,想像,创造力,空想,假想,悬想,妄想;v:想象",
"imagine":"v:想象,想像,设想,猜想,推想,虚悬,悬,想得到,悬拟,假想,企图,悬想,意想,推见,推测,想见",
"imaging":"v:成像;n:映象",
"imago":"n:成虫,成,像",
"imam":"n:阿訇,教长",
"imbalance":"n:失调,差额",
"imbecile":"a:低能,昏庸;n:笨伯,低能儿",
"imbecilic":"a:痴愚",
"imbecility":"n:痴愚,低能,愚痴,愚笨",
"imbibe":"v:吸收,喝,接受,饮",
"imbroglio":"n:纠葛,误解,纷乱",
"imbue":"v:充满,灌输,濡染,鼓吹,灌注,渗透,浸染",
"imitate":"v:模仿,模拟,学,仿效,冒充,仿造,假充,踵武,仿制,象,摹仿,模,伪造,仿办,师法,仿照,师,效,效仿,仿,拟,则,照猫画虎,摹拟,依傍",
"imitation":"n:模仿,仿效,模拟,仿造,拟态,复制品,学习,师;a:冒牌,人造",
"imitator":"n:模拟器",
"immanence":"n:固有,内在",
"immaterial":"a:不在乎",
"immature":"a:幼小",
"immaturity":"n:生硬,幼稚",
"immeasurable":"a:无限;v:不可估量,无量",
"immediacy":"n:直接",
"immediate":"a:立即,直接,即,即时,立,紧接着",
"immediately":"d:立即,立刻,马上,紧接着,当即,当下,顿时,即刻,连忙,随即,应时,旋踵,迅即,立地;n:当时",
"immediateness":"n:直接",
"immense":"a:巨大,宏大,庞大,嘏",
"immensely":"n:无限,巨大,广大;d:无任",
"immenseness":"n:无限",
"immensity":"n:庞然大物,无限,广大",
"immerse":"v:浸,浸泡,沉浸,浸入,陷入,浸没,濡染,沐浴,濡,浸沉,卷入",
"immersed":"v:专心致志",
"immersion":"n:浸渍,浸,浸没,专注,专心,沉浸,浸礼;v:浸渍",
"immigrant":"n:移民,侨民",
"immigrate":"v:迁移,移",
"immigration":"n:移民,移居",
"imminence":"n:迫近,危急,急迫",
"imminent":"a:迫在眉睫,一触即发,紧迫,迫近;v:一触即发,迫近,迫在眉睫",
"immobile":"a:稳定",
"immobilization":"n:固定",
"immoderate":"a:无度",
"immoderately":"d:滥;a:滥",
"immodesty":"n:放肆,卤莽,莽撞",
"immolate":"v:牺牲,毁灭,杀戮",
"immolation":"n:牺牲品",
"immoral":"a:不道德",
"immorality":"n:不道德,邪恶",
"immortal":"n:神人,仙人,神仙,仙子,真人;a:不朽,永生,长生不老;v:长生不老,永生",
"immortality":"n:不朽",
"immortally":"d:很,非常",
"immovability":"n:不动产,固定",
"immovable":"a:不动产",
"immune":"a:免疫",
"immunise":"v:免疫",
"immunities":"n:豁免",
"immunity":"n:免疫,免疫力,免疫性",
"immunization":"n:免疫,免除;v:免除",
"immunize":"v:免除",
"immure":"v:监禁,禁闭",
"imp":"n:小淘气;v:加强,增大,补充",
"impact":"n:影响,冲击,关系,碰撞;v:装填,撞击,冲击,碰撞,塞满",
"impaction":"n:撞击,嵌入;v:撞击",
"impair":"v:损害,减少,削弱,妨害,毁损,伤害,害,损伤",
"impairment":"n:损害,故障",
"impale":"v:刺穿,穿刺",
"impalement":"n:围栏",
"impart":"v:告诉,传授,给予,通知,传",
"impartial":"a:公正,公平,不偏不倚,持平,公道,公;v:持平",
"impartiality":"n:不偏不倚,公平",
"impartially":"d:秉公",
"impassable":"a:不可逾越,过不去;v:不可逾越",
"impasse":"n:僵局,绝境,穷途末路,绝路,末路,死结,死胡同,死路",
"impassioned":"a:慷慨激昂;v:慷慨激昂",
"impassiveness":"n:冷漠",
"impatience":"n:不耐烦,急躁,渴望",
"impatient":"a:急于,急,急躁,性急,心急,焦躁,急切,急赤白脸",
"impeach":"v:弹劾,控告,检举,怀疑,参,举报,责难,指责,抨,弹,责问,告发",
"impeachment":"n:控告,指责",
"impeccability":"n:无罪",
"impedance":"n:阻抗",
"impede":"v:妨碍,阻碍,牵掣,干碍,掣肘,格,遮拦,妨,遮,阻",
"impediment":"n:障碍,妨碍,阻碍",
"impedimenta":"n:辎重,行李",
"impel":"v:激励,促使,驱使,迫使,推动,感召,强迫,推进,策励,激扬",
"impeller":"n:叶轮,推进器,转子",
"impend":"v:临头,吊,悬挂,逼近",
"impenetrability":"n:无情",
"impenetrable":"a:不可理喻",
"impenitence":"n:顽固",
"imperative":"n:命令,条例,规则;a:急切,急迫",
"imperatively":"d:切切",
"imperceptible":"a:不知不觉",
"imperceptibly":"d:不知不觉,无形;a:不知不觉,无形",
"imperfect":"n:缺,缺略",
"imperfection":"n:缺陷,缺点,缺欠,缺略,缺,不足",
"imperial":"n:龙;a:帝国",
"imperial decree":"n:圣旨",
"imperialism":"n:帝国主义,帝",
"imperil":"v:危及,危害,威胁",
"imperious":"a:专横",
"imperishable":"a:浩气长存",
"impermanence":"n:无常,暂时",
"impermanent":"a:无常",
"impermissible":"a:使不得",
"impersonality":"n:客观",
"impersonate":"v:体现,扮演,模仿,饰",
"impersonation":"n:扮演,体现,假冒,模仿",
"impersonator":"n:演员",
"impertinence":"n:无礼,鲁莽,傲慢,不得要领,离题,弄错",
"impertinent":"a:不逊",
"impetigo":"n:癞疮,脓疱病,黄水疮",
"impetuosity":"n:急躁,冲动,急性病,狂热,猛烈,激烈,冲力,轻举妄动;v:轻举妄动",
"impetuous":"a:急躁,感情用事,迅疾,毛,卞,浮躁,狷,躁;v:造次;n:急性子",
"impetuously":"d:率尔",
"impetus":"n:促进,动力,推动,声势,刺激,动量,势头",
"impiety":"n:不孝",
"impinge":"v:影响,撞击,冲击,侵犯,碰撞,打,接触,侵害,打击,击",
"impinge on":"v:冲击,打击",
"impingement":"v:弹跳,撞击;n:撞击,弹跳",
"impinging":"v:碰撞,弹跳",
"implacability":"n:执拗",
"implacable":"a:死",
"implant":"v:植入,嵌入,移植,注入,插入,植,灌输",
"implantation":"n:植入,嵌入,种植,灌输,鼓吹,插入",
"implement":"v:落实,施行,推行;n:器具",
"implementation":"n:执行,贯彻,实行,履行,落实;v:执行",
"implementer":"n:设备",
"implements":"n:农具,器物",
"implicate":"v:牵扯,牵累,牵连,连累,株连,挂累,攀,涉,牵缠,缠绕;n:含意",
"implication":"n:含义,牵连,暗示,含意,含蓄,蕴含,牵涉,弦外之音,实质,蕴涵,结论,暗中,瓜葛,意味,意蕴,音儿,纠缠,话音,隐含,干系,涵义,言外之意,口气",
"implicit":"a:含蓄,涵蓄,暗示;v:暗示",
"implore":"v:恳求,乞求,央求,哀求;n:求饶",
"imply":"v:意味着,暗示,包含,蕴涵,蕴含,暗含,含蓄,寓,默示,寓于",
"impolite":"v:失礼;a:非礼",
"impoliteness":"n:失礼,无礼",
"import":"n:进口;v:输入,说明,引进,含有",
"importance":"n:重要,重要性,意义,自大,有力,骄傲,痛痒,显著",
"important":"a:重要,要,重大,许多,大,要紧,紧要,重,打紧,鼎",
"importation":"n:输入,进口",
"importer":"n:进口商",
"imports":"n:舶来品",
"importune":"v:纠缠,泡蘑菇,强求",
"importunity":"n:强求",
"impose":"v:强加,征收,征,利用,课,施加,欺骗,施,放置,强迫,强求;n:课,冒名顶替",
"imposing":"a:堂堂,雄伟;d:巍然",
"imposingly":"d:堂而皇之",
"imposition":"n:课税,哄骗,税,负担,征税,强加",
"impossible":"a:叵",
"impost":"n:进口税,关税,税",
"impostor":"n:骗子,冒牌",
"imposture":"n:冒名顶替",
"impotence":"n:无能,虚弱,衰弱,阳萎,阳痿,无力,无效",
"impotency":"n:天阉",
"impotent":"v:软弱无力;a:软弱无力",
"impound":"v:没收,拘禁,蓄水,充公",
"impoverished":"a:贫困,贫穷,贫苦,穷苦,竭蹶",
"impoverishment":"n:耗尽;v:耗尽",
"impracticable":"a:架空,不切实际,疏阔;v:架空",
"impractical":"a:酸,虚浮;v:行不通",
"imprecate":"v:诅,诅咒,咒",
"imprecation":"n:咒语",
"impregnable":"a:坚不可摧,毫不动摇,固若金汤",
"impregnate":"v:注入,浸透,灌注,怀孕,渗透,受精",
"impregnation":"n:浸染,浸渍;v:浸渍,怀孕",
"impresario":"n:经理,指挥,导演",
"impress":"v:征用;n:特征,痕迹,印记",
"impression":"n:印象,感觉,影响,感想,印痕,痕迹,效果,想法,意见,印数,印刷品,印次",
"impressionism":"n:印象派",
"impressions":"n:感想,观感",
"impressive":"a:显赫,可观,蔚,威风,赫然,感人肺腑",
"impressively":"d:赫然",
"imprimatur":"n:批准",
"imprint":"n:痕迹,印痕;v:盖,印刷",
"imprinter":"n:印刷机",
"imprinting":"n:印记",
"imprison":"v:监禁,关押,束缚,禁锢,囚禁,囚,收监,下狱,锢,幽,幽禁,限制,圄,禁;n:关押,监禁",
"imprisonment":"n:徒刑,关押,束缚,徒",
"impromptu":"d:即席,即兴",
"improper":"a:不当,不端;v:失宜,欠妥,失当",
"improve":"v:改进,改善,提高,好转,利用,增加,进步,改良,增进,改动,健全,琢磨,壮,升值",
"improvement":"n:改进,改善,进步,改良,好转,装修,利用,起色,增进,矫正;v:矫正,改进,改善",
"improver":"n:见习生,学徒",
"improvidence":"n:目光短浅,浪费",
"improvident":"a:目光短浅",
"improving":"n:精炼;v:精炼",
"improvisation":"n:急就章",
"improvise":"v:随机应变,凑合",
"imprudence":"n:轻率,鲁莽",
"imprudent":"a:毛手毛脚",
"impudence":"n:厚颜无耻,冒失,无礼",
"impudent":"a:无耻,厚颜无耻,胆大妄为;v:胆大妄为",
"impugn":"v:指摘,攻击,打击,责难",
"impulse":"n:冲动,脉冲,冲量,推动,兴奋,搏动;v:推动,冲动,鼓舞",
"impulsion":"n:冲力,冲动,刺激,推动力,脉冲,推进,鼓舞",
"impulsive":"a:浮躁,孟浪",
"impunity":"n:无罪",
"impurity":"n:杂质,混合物,下流,不道德,污垢",
"imputation":"n:归罪,责怪,归咎,毁谤",
"impute":"v:归于",
"in":"p:就,用,到,于,将,进来,其中,进去,进,里,期间,其内,之内;d:到达,在家,在内,得到,流行,成功,时髦,一致;n:里;r:其中;v:进",
"in a flash":"p:转瞬,须臾之间,弹指之间,霍地,瞬间,转眼,俯仰之间,即刻",
"in a nutshell":"p:简而言之,简言之",
"in a way":"p:一点,稍为",
"in accordance with":"p:根据,按,一致,以,秉承,照,与_一致,针对,因,禀承,依据",
"in addition to":"p:之外,除外,除_之外",
"in advance":"p:事前,先行,先头,提前,先,头里,早",
"in advance of":"p:之前,在_之前,优于",
"in agreement":"p:合辙",
"in agreement with":"p:同意,符合,赞同",
"in aid of":"p:求助于",
"in all":"p:统共,一总,凡,共总,总计,共,合共",
"in all probability":"p:十之八九",
"in any case":"p:左右,好歹",
"in any event":"p:左不过,无论如何",
"in back of":"p:后面,在_后面",
"in behalf of":"p:代表,为了",
"in between":"p:中间,在_中间,在中间",
"in brief":"d:简言之,总而言之,总的来看,简而言之",
"in cahoots with":"p:与_联手,联手",
"in care of":"p:万一",
"in case":"c:要,倘若,万一,假如,倘使,傥,设,一旦,倘然",
"in case of":"p:如果,假使",
"in charge of":"p:负责,主管",
"in cold blood":"p:冷静",
"in common":"p:同",
"in common with":"p:一样,与_一样,一致,与_一致",
"in company with":"p:一起,与_一起",
"in comparison to":"p:比较,与_比较",
"in comparison with":"p:与_比较",
"in compliance with":"p:如,比较",
"in conclusion":"p:总之,最后,结束;d:如上所述,综上所述",
"in conflict with":"p:冲突,与_冲突",
"in conformity with":"p:一致,与_一致,本着,一鼻孔出气",
"in connection with":"p:有关,与_有关,针对",
"in consequence of":"p:缘故,由于_缘故",
"in consideration of":"p:由于,考虑到,鉴于",
"in contact with":"p:联系,与_联系",
"in contrast to":"p:相反,与_相反",
"in contrast with":"p:与_相反,相反",
"in course of":"p:在,中,在_中,在_之中,之中,正在",
"in default of":"p:因没有",
"in deference to":"p:服从",
"in defiance of":"p:不顾,无视",
"in detail":"p:一五一十",
"in disregard of":"p:不顾",
"in earnest":"p:真心诚意,老老实实",
"in evidence":"p:明显",
"in excess of":"p:超过,多于",
"in exchange for":"p:交换,以_交换",
"in expectation of":"p:指望,期待",
"in face of":"p:面临,面前",
"in fact":"p:实际上",
"in favor of":"p:赞同,支持",
"in favour of":"p:赞成,支持",
"in force":"p:生效,现行",
"in front":"p:在先,头里,先头,前边,前面",
"in front of":"p:前面,前,面前,在_之前,在_前面,之前,前边,前头,在_前",
"in fulfillment of":"p:完成,履行,实现",
"in full swing":"p:欢,热火朝天",
"in gear":"p:正常",
"in general":"p:一般,总的来看,总之",
"in good order":"p:井井有条,整饬,整齐,有条不紊,天下大治",
"in good spirits":"p:神采奕奕",
"in good taste":"p:大方,雅观",
"in good time":"p:刚巧,恰好,适时,久而久之",
"in great confusion":"p:乱成一团",
"in haste":"p:匆匆,匆忙,赶紧,急忙,连忙,迫不及待,急切",
"in high spirits":"p:来劲,神采奕奕,兴致勃勃,起劲,带劲,意气风发",
"in hope of":"p:期待,希望",
"in hopes of":"p:希望,期待",
"in justification of":"p:辩护,为_辩护",
"in keeping with":"p:一致,与_一致",
"in kind":"p:同样",
"in lieu of":"p:代替",
"in light of":"p:根据,按照,本着",
"in line with":"p:符合,根据",
"in low spirits":"p:忽忽不乐,委靡不振,无精打采,沉闷,闷闷不乐,失神,垂头丧气",
"in memoriam":"p:追念,纪念",
"in memory of":"p:纪念,追念",
"in name":"p:名义",
"in name only":"p:徒有其名",
"in need of":"p:需要",
"in no time":"p:快要,立即,转脸,即将",
"in obedience to":"p:顺从,服从",
"in operation":"p:现行,生效",
"in opposition to":"p:相反,反对,反抗,与_相反,与_相对,相对",
"in order":"p:井然有序,整齐划一,整整齐齐,挨次,秩序井然,整齐",
"in order for":"p:为了",
"in order that":"c:为了,以便,为着,俾",
"in order to":"p:为了,以,用以,为着,俾,以求",
"in other words":"d:换言之,换句话说",
"in particular":"p:尤其,特别",
"in passing":"p:顺带,附带",
"in perpetuity":"p:永远",
"in person":"p:亲",
"in place":"p:恰当,到处,处处",
"in place of":"p:代替,取代",
"in point of":"p:关于,就_而言,而言",
"in practice":"p:实际上,事实上",
"in preference of":"p:选择",
"in preference to":"p:选择",
"in principle":"p:大体上;d:大体上",
"in private":"p:私下",
"in process of":"p:在,在_过程中,正在",
"in proportion to":"p:与_成比例",
"in public":"p:明处,大庭广众;n:大庭广众",
"in pursuit of":"p:追求,寻求",
"in quest of":"p:寻找,寻求,追求,为了_追求,为了_寻求,探求",
"in re":"p:关于",
"in reality":"p:其实,实际上",
"in recognition of":"p:因,公认",
"in reference to":"p:关于",
"in regard to":"p:关于,有关,对于,鉴于",
"in relation to":"p:关于,相比,与_相比",
"in reply to":"p:答复",
"in respect of":"p:关于,就",
"in return for":"p:报答,作为_的报答",
"in search of":"p:寻找,寻求,查究",
"in secret":"p:私下",
"in short":"p:简言之,一句话,简而言之;c:总的来说,总的说来;d:简言之",
"in short order":"p:立即",
"in spite of":"p:尽管,不顾,不管",
"in stock":"p:现货,存货,现存",
"in straitened circumstances":"p:困顿,贫困,穷困,拮据,窘,困窘,清寒",
"in support of":"p:支持,支援,维护",
"in terms of":"p:根据,按照,论,在_方面",
"in the air":"p:空际",
"in the back of":"p:在_后面",
"in the bargain":"p:除外",
"in the beginning":"p:起初,起头",
"in the case of":"p:下,在_情况下",
"in the course of":"p:在_期间,期间",
"in the end":"p:究竟,终久,端的,竟,终,算,卒,到底,归根结蒂,末了,终归,最后;d:竟",
"in the event of":"p:发生,如果_发生",
"in the face of":"p:面对,面临",
"in the favor of":"p:同意,赞同",
"in the flesh":"p:本人",
"in the front of":"p:前面,在_前面,在_之前,之前",
"in the interest of":"p:为了,利益,为了_的利益",
"in the least":"p:毫,绝,全然",
"in the light of":"p:鉴于,根据,按照",
"in the main":"p:大抵,基本,基本上",
"in the matter of":"p:而论,就_而论,关于",
"in the meantime":"p:同时",
"in the middle of":"p:在_之中,之中",
"in the midst of":"p:之中,在_之中",
"in the name of":"p:名义,凭,以_名义",
"in the order of":"p:大约",
"in the place of":"p:代替",
"in the presence of":"p:面前,在_面前",
"in the process of":"p:过程中,在_过程中",
"in the south":"p:南面",
"in the vicinity of":"p:邻近,在_附近,在_邻近,附近",
"in the way of":"p:方面,关于_方面",
"in time":"p:合拍,如期,恰好",
"in token of":"p:表示,作为_标志,标志",
"in touch with":"p:联系,与_联系",
"in truth":"p:其实,确实,实际上",
"in turn":"p:挨个,反过来,分批,顺序,依次,顺次,以次;d:分批",
"in unison":"p:一致,一齐",
"in vain":"d:白费,白,无效,干,落空,徒,白白,空,唐,枉,一场空,白搭,虚",
"in view of":"p:由于,基于",
"in virtue of":"p:由于,依靠,凭借;d:借助",
"in vivo":"a:体内",
"in vogue":"p:流行,时兴",
"in want of":"p:需要,缺少",
"in writing":"p:书面",
"inability":"n:无力,无能为力,无能",
"inaccessible":"a:闭塞,可望而不可即",
"inaccuracy":"n:错误,误差",
"inaccurate":"a:疏阔",
"inaction":"n:故障,迟钝,怠惰,懒散,无为",
"inactivate":"v:钝化,撤销",
"inactivation":"n:钝化,僵化;v:僵化",
"inactive":"a:消极,被动",
"inactivity":"n:无为",
"inadequate":"a:不足,不够,绌,勉强,贫",
"inadvertence":"n:错误,粗心大意,疏忽",
"inadvertent":"a:漫不经心,粗心大意,不慎;v:无意",
"inadvertently":"d:无意,无心;v:无心",
"inadvisable":"a:不宜",
"inamorata":"n:恋人",
"inane":"a:空洞",
"inanimate":"a:冥顽不灵,没精打采",
"inanity":"n:空虚,虚空,愚妄,无知,空洞;a:空虚",
"inappropriate":"a:不当,不宜,失宜;v:失宜,失当",
"inarticulate":"a:笨口拙舌,哑口无言,嘴笨",
"inasmuch as":"c:因为,由于",
"inattention":"n:漫不经心,疏忽,粗心",
"inattentive":"a:心不在焉,粗疏,大意,松散;v:心不在焉,失神",
"inaugural":"a:就职",
"inaugurate":"v:开始,开幕,开辟,揭幕,创始,开张",
"inauguration":"n:开幕式,开张,开始",
"inauspicious":"a:不祥,凶",
"inborn":"a:天赋,天生;n:先天",
"inc":"n:公司",
"incalculable":"v:不可估量;a:不可估量",
"incandescence":"n:白热",
"incandescent lamp":"n:白炽电灯,白炽灯",
"incantation":"n:咒语,妖术,念咒;v:咒",
"incapable":"a:无能,无法,无力;v:无力",
"incarcerate":"v:监禁,禁闭",
"incarceration":"n:监禁",
"incarnadine":"n:肉色",
"incarnate":"v:体现,实现",
"incarnation":"n:化身,体现",
"incendiary":"n:燃烧弹,易燃物;v:纵火;a:纵火",
"incense":"n:香,香气,奉承;v:香;a:香",
"incentive":"n:鼓励,刺激;v:激怒,刺激,动机",
"inception":"n:开始,开端,发端",
"incertitude":"n:怀疑",
"incessant":"v:无尽无休,不已,不置;a:不停,无尽无休",
"incessantly":"d:不断,不置;v:接连不断,连天",
"incest":"n:乱伦",
"inch":"n:英寸,个子,身段,少量,少许;v:渐进",
"inchon":"n:仁川",
"inchworm":"n:尺蠖,槐蚕",
"incidence":"n:入射,影响,发生,关联,负担,入射角,着落,倾角,接合",
"incident":"n:事件,事情,事故,事变,枝节,插话,事端;c:故",
"incidental":"n:杂费,杂项;a:偶然",
"incidental music":"n:配音,配乐",
"incidentally":"d:附带;v:捎带",
"incidentals":"n:杂费",
"incinerate":"v:煅烧,焚化",
"incineration":"n:焚烧,煅烧",
"incinerator":"n:焚化炉,火葬炉",
"incipience":"n:初期",
"incipient":"a:开始",
"incise":"v:切割,雕刻,切入,切开",
"incision":"n:切开,刀口,切入,雕刻",
"incisive":"a:锋利,尖锐,犀利,辟,精辟;v:辟",
"incisor":"n:门牙,门齿,板牙",
"incite":"v:煽动,激励,挑拨,挑动,主使,策动,扇,招,刺激,调唆,鼓励,唆使,煽,扇动,指使,撮弄,鼓,鼓捣,怂恿,教唆,撩拨,挑,拨弄,挑唆,鼓动,授意",
"incitement":"n:刺激;v:刺激,激发",
"incivility":"n:粗野",
"inclemency":"n:酷寒",
"inclination":"n:趋势,点头,倾斜,嗜好,志趣,倾向,倾斜角,倾角,斜度,斜面,鞠躬,偏流,歪斜,斜角,交角,斜坡,磁偏角,坡度",
"incline":"v:倾向,倾斜,低头,侧;n:斜坡,斜面,坡度;a:歪",
"inclined":"a:偏斜,歪,斜",
"include":"v:包括,包含,收入,带,算,包,收录,归入,编入,赅,包罗,括,囊括",
"including":"p:包括,连,在内;n:以内;v:以内",
"inclusion":"n:包括,包含,杂质;v:包含",
"inclusive":"a:在内",
"incognito":"v:隐姓埋名;a:隐姓埋名",
"incoherence":"n:不着边际,支离破碎",
"incoherent":"a:不相干,颠三倒四;v:不相干",
"income":"n:收入,收益,进款,所得,经济,入;v:收",
"income tax":"n:所得税",
"incoming":"a:入射,进入,到来;n:进来,岁入,收入;v:进入",
"incommensurable":"n:无理数",
"incommode":"v:妨碍,打扰",
"incommunicable":"a:沉默寡言",
"incomparable":"a:无比,无与伦比;v:无与伦比,无可比拟",
"incomparably":"d:无比",
"incompetence":"n:无能",
"incompetent":"a:无能,蹩脚,不才;v:力不胜任",
"incomplete":"a:片,残缺,缺略,秃,残,缺,残缺不全",
"incompletely":"d:悬而未决",
"incompleteness":"n:缺略",
"incomprehensible":"a:莫名其妙,百思不解,没头没脑,不知所云;v:不知所云,百思不解",
"inconceivability":"n:不可思议",
"inconceivable":"a:不可思议,不堪设想",
"inconclusive":"a:模棱两可",
"inconclusiveness":"n:不得要领,无效",
"incongruous":"a:格格不入;v:格格不入",
"inconsequential":"a:无关紧要;v:无关紧要",
"inconsiderable":"a:微不足道;v:微不足道,不足道",
"inconsideration":"n:轻率,粗心",
"inconsistency":"n:出入",
"inconspicuous":"a:不起眼",
"inconstancy":"n:反复无常,易变",
"inconstant":"a:易变",
"incontestability":"n:无可争辩",
"incontestable":"v:无可争辩;a:无可争辩",
"incontinence":"n:失禁",
"incontinent":"a:立即",
"incontrovertible":"v:无可争辩;a:无可争辩",
"inconvenience":"n:麻烦;v:麻烦",
"inconvenient":"a:不便,麻烦",
"incorporate":"v:合并,混合,并入,结合,体现,包括,并,划归,收编;a:合并",
"incorporation":"n:结合,编入,结社;v:结合",
"incorrect":"a:错误,不对,左",
"incorrectness":"n:错误",
"incorrigible":"v:惯,屡教不改;a:屡教不改",
"increase":"v:增加,提高,增长,增大,增,增强;n:繁殖",
"increasingly":"d:越来越,日益,愈,愈加,益发,格外",
"incredible":"a:玄,玄乎,荒诞",
"incredulity":"n:怀疑",
"increment":"n:增量,增长,增值,利润;v:生长,增值",
"incremental":"a:增加",
"incriminate":"v:连累,控告,归罪",
"incrustation":"n:镶嵌,疮痂,水垢,水碱,外壳,水锈,外皮,硬壳",
"incubate":"v:培养,孵,想,孵卵,孵化,沉思,潜伏,策划",
"incubation":"n:潜伏期,孵卵;v:孵化",
"incubator":"n:孵卵器",
"incubus":"n:梦魇,恶梦",
"inculcate":"v:灌输,教育",
"inculcation":"n:灌输",
"inculpate":"v:归罪,诬赖,控告",
"incumbency":"n:在职,执政,任职,任期,义务,职责",
"incumbent":"a:现任",
"incumbent on":"n:义不容辞",
"incur":"v:招致,讨,招惹,吃,招,承受,致",
"incurable":"v:不可救药;a:不可救药",
"incursion":"n:流入,侵袭,袭击,进入,侵略,侵入",
"indebted":"a:负债累累,入不敷出",
"indebtedness":"n:债务,负债,受惠",
"indecency":"n:无礼,下流,流氓,粗鄙",
"indecent":"a:不明不白,歪,亵,猥",
"indecision":"n:犹豫不决,优柔寡断",
"indecisive":"a:优柔寡断;v:优柔寡断",
"indecorous":"v:欠妥;a:欠妥",
"indeed":"d:的确,真,确实,实际上,实在,真正,固然,真的,诚然,委实,到底,直,真个,确定,诚,正经,敢情;a:诚,良,正经",
"indefatigable":"v:孜孜不倦;a:不懈",
"indefatigably":"d:孜孜不倦",
"indefinable":"a:无名",
"indefinite":"a:活络,不定",
"indefinite article":"n:不定冠词",
"indefinitely":"d:不定",
"indefiniteness":"n:不定,含糊",
"indelible":"v:不可磨灭;a:不可磨灭",
"indelicacy":"n:粗俗,下流,淫猥",
"indemnification":"n:保障,补偿,赔偿,赦免",
"indemnify":"v:赔偿,保障,保护,赔款,补偿",
"indemnity":"n:赔款,保障,赔偿费,赦免,补偿,赔偿",
"indent":"v:订约",
"indentation":"n:凹槽,凹入,凹陷,空格;v:凹陷,凹入;a:低凹",
"indention":"n:凹入",
"indenture":"n:合同,契约,货单,证书,凭单",
"independence":"n:独立,独立性,自立,自主,无关,自主权;v:无关",
"independent":"a:独立,单独",
"independent clause":"n:主句",
"independent variable":"n:自变量,自变数",
"independently":"d:独力",
"indescribable":"a:不可名状,无名;v:莫可名状",
"indescribably":"d:别提",
"indestructible":"a:坚不可摧",
"indeterminably":"d:不定",
"indeterminacy":"n:犹豫不决",
"indeterminate":"a:不定",
"index":"n:索引,指数,标志,标记,指标,引得,食指,指针;v:引得,指明,指出",
"index finger":"n:二拇指",
"indexer":"n:索引",
"indexing":"v:索引,检索,搜索;n:索引",
"india":"n:印度,天竺",
"india ink":"n:墨汁,墨",
"india rubber":"n:橡胶,橡皮",
"indian":"n:印第安人,印度,印第安,印第安语",
"indian corn":"n:苞米",
"indian mallow":"n:苘麻",
"indian mustard":"n:芥菜",
"indian ocean":"n:印度洋",
"indian summer":"n:秋老虎,小阳春",
"indiana":"n:印第安纳",
"indianapolis":"n:印第安纳波利斯",
"indicant":"n:病症",
"indicate":"v:表示,表明,指示,指出,显示,指,需要,预示,标志,主,示,标明,暗示,标示,象征,指点",
"indicating":"v:指示",
"indication":"n:迹象,指示,显示,表示,指出,象征,读数,迹,适应症,征兆,征候;v:显示",
"indicator":"n:指示器,指示剂,显示器,指针,示功器,标识",
"indict":"v:控告,告发,告状",
"indictment":"n:起诉书,控告,起诉,诉状,告发",
"indifference":"n:冷淡,中立,中性,不在乎",
"indifferent":"a:冷漠,冷淡,淡漠,苟,淡,平庸,漠,薄,没精打采,漠然,平平,淡然",
"indifferently":"d:漠然",
"indigence":"n:穷困,贫穷",
"indigenous":"a:土,土生土长;v:土生土长",
"indigestion":"n:积,结症,杂乱,生硬,食积",
"indignant":"a:气愤,慨,忿怒,激愤,不平,恼怒,气哼哼;v:义愤填膺,激愤",
"indignantly":"d:义愤填膺",
"indignation":"n:愤慨,愤怒,义愤;a:愤怒,愤慨",
"indignity":"n:侮辱,屈辱;a:无礼",
"indigo":"n:靛蓝,靛青;a:靛蓝",
"indigo plant":"n:蓝,蓼蓝",
"indirect":"a:间接,委",
"indirection":"n:迂回,间接",
"indiscreet":"a:轻率;v:失礼",
"indiscretion":"n:轻率",
"indiscriminately":"d:滥;a:滥",
"indispensable":"a:必需,必不可少,必要;v:必需",
"indisposed":"a:不好过,不适",
"indisposition":"n:病痛,厌恶",
"indisputable":"v:无可争辩,颠扑不破,无可讳言;a:无可争辩,无可讳言",
"indissolubility":"n:永久性",
"indissoluble":"a:不解;v:不解",
"indistinct":"a:含混,漫漶,含混不清,隐隐约约,隐约,影影绰绰,苍茫,若隐若现,笼统,隐隐,迷漫;v:若隐若现,若明若暗",
"indistinctly":"d:影影绰绰,隐约,隐隐",
"indite":"v:写",
"indium":"n:铟",
"individual":"n:个人,个体;a:个别,单个",
"individualise":"v:个性化",
"individualism":"n:个人主义,利己主义,个性",
"individuality":"n:个人,个性,个体,人格",
"individualize":"v:一一列举,个性化",
"individually":"d:逐个,单个儿",
"individuate":"v:个性化",
"individuation":"n:个体化",
"indivisibility":"n:不可分割",
"indivisible":"n:微量;a:不可分割",
"indo-european":"n:印欧语",
"indochina":"n:印度支那",
"indoctrinate":"v:灌输,教训",
"indoctrination":"n:教导",
"indolence":"n:懒惰,好逸恶劳",
"indolent":"a:懒散,疏懒,惰,怠惰,懒怠,怠,懒",
"indomitable":"a:顽强;d:刚",
"indonesia":"n:印度尼西亚",
"indoor":"n:内部,室内;a:内部",
"indubitable":"a:无可置疑;v:无可置疑",
"induce":"v:引起,诱发,诱导,引诱,诱,感应,引导,招引,劝诱,导致,勾,招致,催生,敦促,劝导,归纳",
"induced abortion":"n:人工流产,堕胎",
"inducement":"n:引诱,诱导,动机,劝诱,诱因;v:引诱",
"induct":"v:感应,介绍,引导,引入,就职",
"inductance":"n:电感",
"induction":"n:归纳,诱导,感应,就职,归纳法,诱发,入会,吸入;v:归纳,诱导",
"induction coil":"n:感应圈",
"inductive":"a:归纳;n:感性",
"inductor":"n:电感",
"indulge":"v:纵容,放纵,惯,迁就,沉溺,纵情,姑息,纵,娇纵,助长,醉,逞,张,迷,赦免,酗酒,堕入,沉迷,娇养,湎,放任,宽纵,恕罪",
"indulgence":"n:嗜好,纵容,放任,沉迷,沉溺,恩惠,特惠,纵情,赦免,娇养,免罪",
"indulgent":"a:纵容",
"industrial":"n:产业",
"industrial disease":"n:工业病,职业病",
"industrial revolution":"n:工业革命,产业革命",
"industrialisation":"n:工业化",
"industrialist":"n:实业家,产业工人",
"industrialization":"v:工业化;n:工业化",
"industrialize":"v:工业化",
"industrially":"d:企业",
"industrious":"a:勤奋,勤劳,辛勤,孜孜,勤,手勤",
"industriously":"d:努力",
"industry":"n:工业,行业,勤劳,勤奋,产业,事业,业,工,刻苦,实业",
"indwell":"v:内在",
"inebriate":"n:酒徒,醉鬼,酒鬼;v:灌醉",
"inebriation":"n:如痴如醉,高兴",
"ineffective":"v:无效;a:不力",
"ineffectiveness":"n:无效",
"inefficiency":"n:无能,无效",
"inefficient":"a:无效",
"inelegance":"n:粗俗,生硬",
"ineptitude":"n:拙笨,无能,愚笨",
"inequality":"n:不等式,高低,起伏",
"inert":"a:呆滞,麻木不仁;v:麻木不仁",
"inertia":"n:惯性,惰性,惯量,迟钝,无力",
"inertness":"n:惯量,惰性",
"inessential":"v:无关宏旨;a:无关宏旨",
"inestimable":"v:不可估量;a:不可估量",
"inevitability":"n:必然性",
"inevitable":"a:必然",
"inexhaustible":"a:无穷,无穷无尽;v:无穷无尽",
"inexorable":"a:无情",
"inexpedient":"a:失策",
"inexpensive":"a:廉价,便宜,贱,廉",
"inexperienced":"a:嫩,陌生;v:乳臭未干",
"inexpert":"a:生手",
"inexplicable":"a:莫名其妙",
"infamous":"a:臭名昭著,臭名远扬;v:臭名远扬,臭名昭著",
"infamy":"n:出丑,恶名,声名狼藉;v:唾弃",
"infancy":"n:幼年,初期,孩提,幼儿期",
"infant":"n:婴儿,幼儿,赤子,婴,生手",
"infant prodigy":"n:神童",
"infant school":"n:幼稚园",
"infanticide":"n:溺婴",
"infantile":"a:幼小",
"infantry":"n:步兵",
"infantryman":"n:步兵",
"infarct":"n:梗塞,梗死;v:梗死",
"infarction":"n:梗塞;v:梗塞",
"infatuated":"a:迷恋,痴;v:痴迷",
"infatuation":"n:迷恋,痴心,迷惑;v:迷恋",
"infect":"v:感染,传染,毒化,招,毒害,传",
"infection":"n:感染,传染,影响;v:感染",
"infelicity":"n:不幸",
"infer":"v:推断,推测,暗示,表示,意味着,猜想,测,推导,推见,推度,推理,推演,臆测,推论,测出,测度,推,想见,犹豫,裁度",
"inference":"n:结论,推断,推理,推论,含蓄,论断,演绎,含意;v:推论,推理",
"inferior":"a:低劣;n:次品,潮",
"inferiority":"n:低级,次等,次级,下等,下级,劣等,下位",
"inferiority complex":"n:妄自菲薄",
"infernal":"a:阴间",
"infernally":"d:非常",
"inferno":"n:地狱,高温",
"infertile":"a:贫瘠,瘦瘠",
"infertility":"n:贫瘠",
"infest":"v:蔓延",
"infestation":"n:蔓延,侵扰;v:蔓延",
"infidel":"n:异教徒",
"infidelity":"n:失真,背信",
"infield":"n:可耕地",
"infighting":"n:混战,拳击",
"infill":"n:填入",
"infilling":"n:填充物",
"infiltrate":"v:打入,渗透,渗入,浸润,通过,混进,侵袭,渗滤",
"infiltration":"n:浸润,渗入,通过,渗滤;v:浸润",
"infinite":"a:无限,无穷,无边无际;n:无穷;v:无穷无尽",
"infinitesimal":"n:无穷小,无限小",
"infinitude":"n:无穷,无限",
"infinity":"n:无限,无穷大,无数;a:无数",
"infirmary":"n:医务室,诊所,医院",
"infirmity":"n:虚弱,弱点,疾病,优柔寡断,缺点,癃,懦弱,衰弱",
"infix":"v:插入,进入;n:中缀,插入",
"inflame":"v:发炎,煽动,刺激,加剧,着火,激怒,燃烧",
"inflammability":"n:可燃性",
"inflammable":"a:易燃",
"inflammation":"n:炎症,发炎,激动,炎;v:发炎,发光",
"inflate":"v:打气;a:胀",
"inflated":"a:暴涨,浮",
"inflation":"n:通货膨胀,膨胀,充气,自负,夸张,暴涨,补给,打气",
"inflection":"n:衍射,凹陷;v:凹陷",
"inflexibility":"n:刚性,刚度",
"inflexible":"a:刻板,死,死板,机械,呆滞,一成不变,硬性,执著,板板六十四,拘板;v:一成不变",
"inflexibly":"d:一个心眼",
"inflexion":"n:转调,弯曲",
"inflict":"v:加以,加刑,予以",
"infliction":"n:遭受,加刑,强加;v:加刑",
"inflorescence":"n:花序,开花,花朵",
"inflow":"n:流入,注入,渗透,吸入;v:渗滤,流入,渗透",
"influence":"v:影响;n:感应",
"influential":"a:声势浩大,显要;v:声势浩大",
"influenza":"n:流感,感冒,伤风",
"influx":"n:流入,注入,河口;v:流入",
"inform":"v:通知,告诉,告发,报告,告知,打招呼,告,启,出首,报信,奉告,语,打小报告,检举,诉,喻,照,知照,密告,诉冤,知",
"informal":"a:随便,非正式;d:便",
"informality":"n:非正式",
"informant":"n:告密者",
"information":"n:信息,资料,消息,情报,数据,知识,知,报道,报告,报导,信,通知,学识,告发,声息,耳目,风,见闻;v:知",
"information science":"n:信息学,情报学",
"information technology":"n:资讯",
"informer":"n:告密者,密探",
"infra":"d:次,下",
"infraction":"n:违反,违法,背信",
"infrared":"n:红外线",
"infrequency":"n:稀少",
"infringe":"v:侵犯,违反,破坏,违犯,侵凌,违约",
"infringement":"n:侵犯,违约,违反",
"infuriate":"v:触怒,激怒",
"infuse":"v:灌输,注入,泡,沏,浸透,输液,激发,鼓舞,灌注,浸渍",
"infusion":"n:输液,注入,浸渍,浸剂,灌输;v:浸渍,输液",
"ingenious":"a:巧妙,巧,绝妙,精巧,快,神妙,奇巧;v:神妙莫测",
"ingenuity":"n:独创性,巧妙,机灵,独出心裁,匠心,精巧,机智",
"ingenuous":"a:憨",
"ingest":"v:接待,摄取,吸收,摄食,吸纳,咽下",
"ingestion":"n:摄取,吸收,摄食,咽下",
"ingoing":"a:进入",
"ingot":"n:锭,铸模",
"ingrain":"n:本质",
"ingrained":"v:根深蒂固;a:根深蒂固",
"ingratiate":"v:讨好,巴结,取悦",
"ingratiating":"a:巴结",
"ingratiatingly":"d:讨好,巴结",
"ingratiation":"n:逢迎",
"ingratitude":"n:忘恩负义",
"ingredient":"n:配料,成分,组成部分,配方,要素",
"ingress":"n:进食,进入,入口;v:进入",
"inhabitant":"n:居民,住户",
"inhalation":"n:吸入",
"inhalator":"n:防毒面具",
"inhale":"v:吸气,吃,吸,吸入,喝,出气",
"inharmonious":"a:忤,不对",
"inhere":"v:含有,固有,属于",
"inherent":"a:固有,内在,天生",
"inherit":"v:继承,遗传,承袭,嗣,世袭,韶",
"inheritance":"n:遗产,继承,遗传,继承权,遗赠,天赋,承受,遗传性",
"inheritor":"n:继承人",
"inhibit":"v:抑制,禁止,压抑,阻止,压制,约束",
"inhibition":"n:抑制;v:抑制",
"inhomogeneity":"n:复杂性",
"inhuman":"a:残酷,野蛮,非人,不人道,灭绝人性,惨",
"inhumanity":"n:无情,野蛮,残忍,灭绝人性",
"iniquity":"n:罪过,罪恶,不法,憝,不义",
"initial":"a:最初,初始,初步,初级;n:序;v:草签",
"initialization":"n:初始",
"initialize":"v:预置",
"initially":"d:最初,起初,开始",
"initiate":"v:开始,启动,发动,开创,引发,创始,发起,倡言,提议,肇始,启蒙,启,首倡,倡导,倡议,启发,起头,兴办,引进,首创,倡首,发端",
"initiation":"n:开始,起爆,引发,创始,启发;v:引发",
"initiative":"n:主动权,倡议,积极性,主动性,能动性,发端,着手;a:主动",
"initiator":"n:倡议者,创始人",
"inject":"v:注射,注入,喷射,注满,打针,插入",
"injection":"n:注射,喷射,注入,打针,针剂,针,注射液,注满,入轨;v:注射,注入",
"injector":"n:喷嘴,注射器",
"injunction":"n:禁令,命令,指令",
"injure":"v:伤,伤害,损害,损伤,毁伤,损坏,残,加害,贼,病,毁坏;a:残;n:贼",
"injurious":"a:害",
"injury":"n:受伤,伤,伤害,损害,毁坏",
"injustice":"n:不平,不义,冤屈;a:不平",
"injustices":"n:冤案",
"ink":"n:墨水,油墨,墨,墨汁;v:签名",
"ink bottle":"n:墨水瓶",
"inkiness":"n:漆黑,墨黑;a:墨黑",
"inkling":"n:暗示,端绪,端倪",
"inkwell":"n:墨水池",
"inland":"n:国内,内陆,内地;a:内陆,内地",
"inlay":"v:镶,插入,嵌入,嵌镶,镶嵌",
"inlet":"n:进口,湾,入口,输入,引入;v:引进,插入",
"inmate":"n:居民",
"inn":"n:客栈,旅店,客店,客舍,住处,栈,下店,旅舍,逆旅,栈房,店;v:下店",
"innards":"n:内脏",
"innate":"a:固有,天生,天赋,先天性;n:先天,天",
"innateness":"n:先天性",
"inner":"n:内;a:里面",
"inner ear":"n:迷路",
"inner mongolia":"n:内蒙古",
"inner tube":"n:里带,内胎",
"innervate":"v:刺激",
"innervation":"n:支配",
"inning":"n:回合,盘",
"innings":"n:局",
"innocence":"n:无罪,无辜,清白,天真,天真无邪,无知,单纯,良性",
"innocent":"a:清白,天真,单纯;v:无罪",
"innocuous":"v:无毒,无害;a:无害",
"innominate bone":"n:胯骨",
"innovate":"v:创新,改革,刷新,革新,创始",
"innovation":"n:革新,创新,改革;v:革新",
"innuendo":"n:影射,含沙射影;v:含沙射影",
"innuendos":"n:影射",
"innumerable":"a:无数,不计其数,不可胜数;v:车载斗量,不可胜数,指不胜屈,更仆难数",
"inoculate":"v:接种,嫁接,注入,打针,灌输,播种,移植,预防注射",
"inoculation":"n:接种,孕育,灌输;v:孕育",
"inordinate":"a:紊乱,奢,熬夜,不规则",
"inorganic":"a:无机",
"input":"n:投入;v:输入",
"inquest":"n:调查,验尸,审讯,判决,陪审团,查询;v:审讯",
"inquietude":"n:焦虑,不安;a:焦虑",
"inquire":"v:问,打听,询问,调查,问候,了解,查问,探问,查询,请问,探询,探讨,寻问,查究,问讯,探索,打探,盘问,会见,寻根究底,质问,打问,询,探",
"inquiry":"n:调查,询问,打听,查询;v:询问,预审",
"inquisition":"n:调查,审理,讯问,审查",
"inquisitor":"n:审问者",
"inroad":"n:损害,侵犯,袭击,进犯",
"inrush":"n:流入,闯入",
"ins":"n:输入",
"insane":"a:疯狂,疯,疯人院,癫狂,疯癫,痴,疯病;v:疯癫",
"insane asylum":"n:精神病院",
"insanity":"n:神经错乱;a:疯狂",
"insatiable":"a:贪心",
"inscribe":"v:刻,题写,登记,铭记,题赠,泐,勒,记,落款,铭,题字,雕,题,写,牢记",
"inscription":"n:铭文,碑文,题词,题字,碑铭,登记,铭刻,注册,铭,署名",
"inscrutability":"n:不可思议",
"inscrutable":"a:神妙莫测;v:神妙莫测",
"insect":"n:昆虫,虫,虫子,蛊,小人",
"insect powder":"n:杀虫剂",
"insecticide":"n:杀虫剂",
"insects":"n:虫豸",
"inseminate":"v:播,播种,栽,受胎",
"insemination":"n:受孕,播种",
"insensate":"a:顽",
"insensibility":"n:不在乎",
"insensitive":"a:麻木不仁,木人石心,麻木",
"insensitivity":"n:迟钝",
"inseparable":"a:不可分割,紧密",
"insert":"v:插入,嵌入,插,刊登,镶;n:插页,衬垫",
"insertion":"n:插入,嵌入;v:附着,插入",
"inset":"n:插页,附图,水道,镶边,插图,流入;v:镶边,镶,插入,镶嵌,嵌入",
"inshore":"n:沿海;a:近海;d:沿海",
"inside":"n:里面,内部;p:中;a:在内,内幕,里面;d:在内;r:其中",
"inside information":"p:内情,底蕴;n:内情",
"inside of":"p:之内,在_之内",
"insider":"n:知情人",
"insides":"n:内脏",
"insidious":"a:阴险,阴毒",
"insight":"n:见识,洞察力,眼光,见地;v:顿悟",
"insignia":"n:符号,国徽,徽,勋章,徽章,帽章,章",
"insignificance":"n:不足道,低微",
"insignificant":"a:微不足道,无关紧要,渺小,无关大局,藐小;v:无关紧要,无关大局,无关宏旨,微不足道,不足道",
"insincere":"a:二心,贰心;n:二心",
"insincerity":"n:贰心,假意,伪善",
"insinuate":"v:暗示,隐射,射,含沙射影,影射",
"insinuation":"n:暗示,言外之意;v:暗示",
"insipid":"a:乏味,寡,索然,干巴巴,平淡,无味,索,平淡无奇",
"insipidity":"n:枯燥,无味,平淡",
"insist":"v:坚持,咬定",
"insistence":"n:坚持,强调",
"insobriety":"n:酗酒",
"insole":"n:鞋垫",
"insolence":"n:傲慢,横蛮",
"insolent":"a:目空一切,强横,张狂",
"insolvency":"n:破产",
"insomnia":"n:失眠,失眠症;v:失眠",
"insomuch":"d:因为",
"insouciance":"n:满不在乎,漫不经心",
"inspect":"v:检查,视察,检阅,徼,检,阅,鉴,视,检验,稽查,监,审查,考察,省视,校验,考",
"inspection":"n:检查,视察,观察,检验,检阅,参观,校验,审查,验证;v:验证,观察",
"inspector":"n:检查员,监察员,稽查",
"inspector general":"n:总监,检察长",
"inspiration":"n:灵感,鼓舞,启示,吸气,鼓动,激励,灵机,感化,指示,授意;v:吸气",
"inspirational":"a:灵感",
"inspire":"v:鼓舞,激发,激励,授意,启发,振奋,灌注,吸气,激动,吸,指示,吸入,注入",
"inspiring":"a:振奋人心;v:振奋人心",
"inspirit":"v:激励,激发,振奋",
"instability":"n:反复无常,三心二意",
"install":"v:安装,装,设置,装置,建立,安置,安上,安,安设",
"installation":"n:安装,设施,设备,装置,就职,设置,就任,安置",
"installment":"n:分期付款",
"installment plan":"n:分期付款",
"instance":"n:例子,例证,事例,场合,实例,起,例,要求,比方,建议,样本,范例",
"instant":"n:瞬间,时刻;a:即时;d:瞬间",
"instantaneous":"a:瞬时;d:瞬间",
"instantaneously":"d:瞬时,瞬刻",
"instantly":"d:立即,连忙,顷刻,一霎那,一转眼,刹时,当下,即刻",
"instate":"v:担任,安置,任命,设置",
"instead":"d:代替,反倒,反过来,顶替,反转来;c:反过来说",
"instead of":"p:代替,而不是",
"instep":"n:跗,脚背,跗面,脚面",
"instigate":"v:煽动,唆使,策动,鼓动,挑唆,打边鼓,调弄,竦,挑,挑拨,怂恿,嗾,调唆,煽,扇动,唆,指使,发动,挑起,主使,嗾使,策划,教唆,扇,撮弄",
"instigation":"n:鼓动,刺激,挑起,煽动",
"instillation":"n:注入,滴剂,灌输",
"instinct":"n:本能,直觉,天性,天才,生性,才能",
"institute":"n:研究所,学院;v:创立,建立,创制,设",
"instituted":"v:设立",
"institution":"n:机构,制度,所,会,机关,学会,协会,惯例,设立,规定,制定,社,会址,院址,名人,校址,院,创设,馆",
"institutions":"n:典章",
"instruct":"v:指示,通知,教,指令,指导,吩咐,命令,教诲,教授,谕,教导,授,饬,傅,嘱咐,传授,导;n:教授",
"instructed":"a:刊授",
"instruction":"n:指令,指示,说明,命令,教育,指导,指点,教导,训令,教训,教诲,细目",
"instructions":"n:指令,训令,批件,批示,训词,指示",
"instructor":"n:教练,讲师,教员,教官,辅导员,傅",
"instrument":"n:仪器,乐器,工具,仪表,手段,器械,文件,械,证件,证券,仪",
"instrument of torture":"n:刑具",
"instrumental":"a:仪器",
"instrumentality":"n:工具,媒介,手段,帮助",
"instrumentation":"n:手段",
"insubordination":"n:反抗",
"insubstantial":"a:单薄",
"insufficiency":"n:不足,不够,支绌,缺乏,缺口",
"insufficient":"a:不够,不足;v:缺乏,亏短",
"insular":"a:岛",
"insularity":"n:岛国",
"insulate":"v:绝缘,隔离",
"insulation":"n:绝缘,绝热,隔离,孤立",
"insulator":"n:绝缘体,绝缘子,瓷瓶,电介质",
"insulin":"n:胰岛素",
"insult":"v:侮辱;n:袭击,凌辱,攻击",
"insuperable":"a:不可逾越;v:不可逾越",
"insurance":"n:保险,保险业;v:保险",
"insurance policy":"n:保单",
"insure":"v:保险,保证,投保,保障",
"insured":"n:被保险人",
"insurer":"n:保险人",
"insurgence":"n:暴动,起义,反叛,叛变;v:反叛",
"insurgency":"n:暴动,起义,叛变",
"insurmountable":"v:不可逾越;a:不可逾越",
"insurrection":"n:暴动,叛乱,起义,反叛,造反;v:起义,反叛,暴动",
"intact":"a:完整,完好无损;v:完好无损,完,完好无缺",
"intaglio":"n:凹版",
"intake":"n:摄取,吸入,进水闸,收纳;v:吸收,摄取",
"intangible":"a:不可捉摸,无形;v:不可捉摸",
"integer":"n:整数,整体,整型",
"integral":"n:积分,整体;v:缺一不可;a:缺一不可",
"integral calculus":"n:积分,积分学",
"integrate":"v:结合,统一,积分,协调;n:积分",
"integrated":"a:完整,高风亮节",
"integrated circuit":"n:集成电路",
"integration":"n:积分,一体化,综合,整合,结合,集成,合并",
"integrator":"n:积分器",
"integrity":"n:正直,完整性,诚实,完全,完整,气节,操守,健全,综合性,品节",
"integument":"n:果皮,外皮",
"intellect":"n:才智,智力,头脑,理智,理解力,智能",
"intellectual":"n:知识分子,文化人,书生,知识",
"intellectuality":"n:知识分子,理智,智能,智力",
"intellectualize":"v:思考,推理",
"intelligence":"n:智力,情报,智慧,聪明,消息,信号,才智,智能,信息,脑子,神智,谍报,智,资质,天使,心眼儿,心眼,灵,灵性,通知,资",
"intelligence agent":"n:谍报员,谍",
"intelligent":"a:聪明,机灵,聪慧,聪颖,惺,颖慧,懂事;n:心灵",
"intelligentsia":"n:知识界,知识分子",
"intelligibility":"n:明了,清晰度",
"intemperance":"n:酗酒,放纵,过度,激烈,过激,暴饮",
"intemperate":"a:荒唐",
"intend":"v:打算,想,拟,准备,企图",
"intended":"n:未婚夫,未婚妻;a:打算",
"intense":"a:强烈,紧张,激烈,激越,隆,尖锐,剧",
"intensely":"d:强烈",
"intensification":"n:强化,加强,加厚,加剧",
"intensify":"v:加紧,加强,加剧,激化,加厚,加温,增光,强化",
"intensity":"n:强度,强烈,烈度;v:加剧",
"intensive":"a:集约,密集",
"intent":"n:意图,目的,意义,图,故意,含义",
"intention":"n:意图,打算,用意,意向,目的,用心,动机,念头,意旨,心意,心,意义,图,心眼儿,心肠,愈合,概念,心怀,心路,作用,心气,心术,心田,意",
"intentional":"a:故意,蓄意;d:蓄意",
"intentionally":"d:有意,故意,故,存心,明知故犯;c:故",
"intently":"d:密切",
"intentness":"n:热心",
"inter":"v:埋葬,葬,下葬,葬埋,安葬;p:互相",
"interact":"v:相互作用,互动,关联;n:相互作用",
"interaction":"n:相互作用,干扰,感应,关联,互动",
"interactive":"a:交互,会话型",
"interactivity":"n:相互作用",
"intercede":"v:求情,说情,调解,调停,讲情",
"intercept":"v:拦截,截取,截,阻截,截断,截击,迎击,相交,交叉,窃听,中止,阻止,邀;n:拦截,截断,截击,交叉点",
"interception":"n:截取,阻止,截留,折射,遮断,窃听;v:截击,中断",
"interceptor":"n:截击机",
"intercession":"n:仲裁,说情,说项,调解",
"interchange":"v:互换,交流,替换;n:交替",
"intercom":"n:对讲机",
"intercommunicate":"v:互通,交流",
"intercommunication":"v:连通;n:连通",
"interconnect":"v:关联,互联",
"interconnection":"n:连接,互连,互联;v:连接",
"intercontinental":"a:洲际",
"intercourse":"v:来往,往还,性交,交媾,往复;n:来往,交际,神交,往来,往复",
"interdict":"n:禁令;v:禁止,制止,阻断",
"interdiction":"n:阻断,拦阻,禁止,制止;v:拦阻",
"interdisciplinary":"a:跨学科",
"interest":"n:兴趣,利益,利息,爱好,利率,兴味,利润,利,影响,利害,有趣,股份,关注,趣味,情趣,权利,兴致,事业,重要性,乐趣,来头,味道,劲,势力,意思;v:致,聊,兴",
"interesting":"a:有趣,好看,带劲,好玩,好玩儿;v:有意思,入味",
"interface":"n:接口,界面;v:交流,交谈;a:临界",
"interfacing":"n:衬布",
"interfere":"v:干涉,干预,妨碍,干扰,管,打扰,抵触,挡横儿,排解,阻挡,冲突,打岔,调停",
"interference":"n:干涉,干扰,干预,妨碍,打扰,冲突,抵触;v:干扰,干涉",
"interferon":"n:干扰素",
"interim":"n:期中,间歇,暂时,临时;a:暂时",
"interior":"n:内部,内地,腹地,室内,里面;a:内陆",
"interject":"v:插入,插话",
"interjection":"n:插入,叹词,感叹词",
"interlace":"v:交织,编织,交错,夹杂",
"interlacing":"v:交织,交错",
"interlard":"v:混入",
"interleave":"n:交错;v:交替",
"interlining":"n:夹层",
"interlink":"v:连结,套,连环;n:连环",
"interlock":"v:交错,联结,连锁,连结,闭锁;n:连结,连锁",
"interlocking":"v:犬牙交错",
"interlope":"v:闯入,干涉",
"interlude":"n:插曲,穿插,间歇;v:穿插",
"intermarry":"v:通婚,结婚",
"intermediary":"n:媒介,中间人,中人,工具,中,手段,中介,窗口",
"intermediate":"n:中间,中间人,中介,中;a:中间,中级",
"intermediately":"d:调解",
"interment":"n:埋葬,葬礼",
"intermezzo":"n:插曲,间奏曲",
"interminable":"a:没完没了",
"intermingle":"v:混合,混杂,掺杂",
"intermission":"n:中断,间隔,停顿,中止,间歇",
"intermittently":"d:断断续续",
"intermix":"v:混杂,混合",
"intern":"v:拘留,扣留,拘押,拘禁",
"internal":"a:内部,内脏,对内,家;n:国内,内部,家",
"internal combustion":"n:内燃机",
"internal secretion":"n:内分泌",
"international":"a:国际,公",
"international waters":"n:公海",
"internationalise":"v:国际化",
"internationalism":"n:国际主义",
"internationalization":"n:国际化",
"internationalize":"v:国际化",
"internecine":"a:自相残杀",
"internet":"n:因特网",
"internment":"n:拘留,扣留,收容",
"internship":"n:实习",
"interpenetrate":"v:渗透,贯通",
"interplanetary":"a:星际",
"interplay":"v:相互作用;n:相互作用",
"interpolate":"v:插入,羼,窜改,增添",
"interpolation":"n:插入,窜改;v:插入",
"interpose":"v:插,插入,干预,提出,介入,调解,介,插嘴",
"interposition":"n:干涉,插入,调停;v:调停",
"interpret":"v:解释,翻译,说明,口译,讲,译,讲解,演奏,传译,阐释,解,笺",
"interpretation":"n:解释,说明,演奏,翻译,表演,译码",
"interpreter":"n:翻译,译员;v:口译",
"interregnum":"n:间歇,中断",
"interrogate":"v:盘问,询问,审问,讯问,审讯,责,诘,质问,诘问,审,问,查问,鞫;n:讯",
"interrogating":"v:询问",
"interrogation":"n:讯问,审问,询问,质问,审讯;v:询问",
"interrogative":"n:问句,疑问词,疑问句;a:提问",
"interrogator":"n:审问者",
"interrogatory":"n:质问,讯问,疑问,审问",
"interrupt":"v:打断,中断;n:中断",
"interrupter":"n:障碍物",
"interruption":"n:中断,打岔,打断,插话,间断,停止,中止;v:停止,中止",
"intersect":"v:相交,交叉,相切,交,交错",
"intersection":"n:交叉,路口,交点,相交,交叉点;v:交叉,相交",
"intersection point":"n:交点,垂足,交叉点",
"intersperse":"v:散布,点缀,装饰,夹",
"interspersion":"n:点缀,装饰,散布",
"interstellar":"n:星际;a:星际",
"interstice":"n:间隙,空隙,裂缝",
"intertwine":"v:交织,编织,缠绕",
"intertwining":"v:纵横交错",
"interval":"n:间隔,区间,间距,间歇,间断,间隙,空隙,音程,课间,空当儿,隙",
"intervene":"v:调停,干预,介入,干涉,排解,干与,插入,介于",
"intervention":"n:干预,干涉,介入,调解,妨碍,调停,排解",
"intervertebral disc":"n:椎间盘",
"interview":"v:采访;n:面谈",
"interviewer":"n:访员",
"interweave":"v:交织,混杂,穿插",
"intestinal":"a:肠",
"intestinal obstruction":"n:肠阻塞",
"intestine":"n:肠,肠儿,肠管,大肠",
"intestines":"n:肠,肠子",
"intimacy":"n:亲密,亲热,亲近,亲切感,密切,友好",
"intimate":"a:亲密,密切;v:宣布;n:知己,知心人",
"intimation":"n:通知,暗示,告知,宣布;v:暗示",
"intimidate":"v:吓唬,压,恫吓,恐,威逼,吓,恫,恐吓,威吓",
"intimidation":"n:恐吓,恫吓,威胁",
"into":"p:到,变成,进,迫使,里,劝说,之内,到_里;v:进",
"into contact with":"p:联系,联络,与_联络,与_联系",
"into the bargain":"p:外带",
"intolerable":"a:难堪,要不得;v:要不得",
"intolerance":"n:固执",
"intonation":"n:语调,发音,音准,调门,抑扬顿挫,声调,转调,发声,吟诵,咏唱,腔调,调门儿",
"intone":"v:吟诵,咏,咏唱,吟咏,咏叹,讽,叹",
"intoxicant":"n:麻醉品",
"intoxicate":"v:陶醉,沉醉",
"intoxicated":"v:醉",
"intoxication":"n:中毒",
"intractable":"a:任性",
"intravenous drip":"n:点滴",
"intravenous injection":"n:静脉注射",
"intrepid":"a:强悍",
"intricacy":"n:错综,复杂,曲折",
"intricate":"a:复杂,曲折,错综,错",
"intrigue":"n:阴谋;v:筹谋,哄骗,私通",
"intriguer":"n:阴谋家",
"intriguing":"a:鬼祟,奇妙",
"intrinsic":"a:固有,内在,先天性",
"introduce":"v:介绍,引进,提出,引入,采用,开始,插入,推广,引见,引种,带领,引导,绍介",
"introducing":"v:引入",
"introduction":"n:介绍,引进,采用,引入,前言,入门,导言,引言,引种,绪论,初步,导论,引子,抛砖引玉,序,序曲,引导,序言,简介,推广,发凡,概说,绪言,传入,讲话,总论,概论",
"introductory":"a:介绍,序;n:序",
"introspect":"v:反思,反省,内省",
"introspection":"n:内省,反省;v:反思",
"introversion":"n:内向,反省",
"introverted":"a:内向,内向型",
"intrude":"v:打扰,入侵,侵越,闯入",
"intruder":"n:轰炸机",
"intrusion":"n:侵扰,侵入,入侵,闯入,打扰,干涉,妨碍",
"intrusive":"a:入侵",
"intuition":"n:直觉,直感",
"inundate":"v:淹没,漫,滔,灭,滥,泛滥,淹,泛",
"inundated":"a:滥",
"inundation":"n:泛滥,水灾,淹没,水患",
"inure":"v:适用,生效,锻炼",
"invade":"v:侵入,入侵,侵袭,侵犯,侵略,来犯,进犯,挤满,寇,宰割,生效,凌,侵权,入寇,打扰,适用,窜犯,侵",
"invader":"n:侵略者",
"invalid":"n:病人,病号,病秧子;v:废,无效;a:废,病恹恹",
"invalidation":"n:失效,无效",
"invalidism":"n:虚弱,伤残;v:伤残",
"invalidity":"n:无效",
"invaluable":"a:价值连城,金不换",
"invar":"n:殷钢",
"invariable":"a:常,一成不变;n:常数;v:一成不变",
"invariably":"d:总是,总,常常,无不,不免",
"invariant":"n:标量",
"invasion":"n:侵略,侵犯,侵入,侵害",
"invective":"n:谩骂,抨击",
"inveigh":"v:痛骂",
"inveigle":"v:诱惑,诱骗",
"invent":"v:发明,编造,创造,捏造,虚构,编,创作,虚悬,假造",
"invented":"a:虚妄;v:虚拟",
"invention":"n:发明,创造,发现,创造力,虚构,捏造",
"inventiveness":"n:独创性,发明,匠心",
"inventor":"n:发明家,发明者",
"inventory":"n:存货,清单,目录,盘存,清册;v:盘存",
"inverse":"a:相反;v:倒,倒置,倒转;n:反向",
"inversion":"n:反向,颠倒,反转,倒置,转换;v:转化,倒置,倒转,交换",
"invert":"v:倒置,转化,反转,颠倒",
"inverted":"v:倒",
"inverted comma":"n:引号",
"inverter":"n:变频器,变流器",
"inverting":"v:换向",
"invest":"v:投资,投入,赋予,买进",
"investigate":"v:调查,研究,审查,追查,探讨,考察,察访,侦查,查访;d:竟",
"investigation":"n:调查,研究,审查,侦查;v:调查",
"investigator":"n:研究者,侦查员",
"investiture":"n:赋予,装饰,服装,授权",
"investment":"n:投资,投资额,投入,覆盖,封锁,授权",
"investor":"n:投资者",
"inveterate":"a:根深蒂固,痼",
"invigilate":"v:看守,监考",
"invigilator":"n:监视器",
"invigorate":"v:活跃,激励,提神,鼓舞,健,搞活",
"invigoration":"n:滋补,鼓舞",
"invincibility":"n:无敌",
"invincible":"v:百战百胜,无敌,战无不胜;a:百战百胜",
"inviolability":"n:神圣",
"invisible":"a:无形,隐形",
"invisibly":"d:无形中",
"invitation":"n:邀请,请帖,诱惑,招待,吸引,帖,敦请,帖子",
"invite":"v:邀请,请,邀,让,引起,吸引,约请;n:招待",
"invocation":"n:祈求,行使,咒语,援引,祈祷,符咒,发动",
"invoice":"n:发票",
"invoke":"v:援引,援用,恳求,乞求,引起,实行,行使,产生",
"invoking":"v:调用",
"involuntarily":"d:不由自主,身不由己,不禁",
"involuntary":"a:身不由己",
"involuntary muscle":"n:不随意肌",
"involute":"v:消失,消散,卷起;n:渐开线",
"involution":"n:方,错综复杂,复归,退化,卷绕,乘方,纠缠,卷入,自乘,复旧,萎缩;v:复归,退化",
"involve":"v:涉及,包括,包含,牵涉,有关,涉,牵扯,牵连,波及,带累,引起,连累,牵,牵累,关,累,拉扯,自乘,牵缠,拖累,攀,累及",
"involved":"v:绕脖子",
"involvement":"n:卷入,事,参与;v:参与",
"invulnerable":"a:无懈可击",
"inward":"n:进口货,内部,内心,里面,肠,胃;a:里面",
"inwardly":"d:暗自,暗地,暗地里,内里,暗暗",
"iodine":"n:碘,碘酊",
"ion":"n:离子",
"ionization":"n:电离",
"ionize":"v:电离",
"ionosphere":"n:电离层",
"iota":"n:微小,一点;a:分毫",
"iou":"n:白条,欠条",
"iowa":"n:衣阿华",
"ipecac":"n:吐根",
"ipso facto":"n:事实上",
"iq":"n:智商",
"iran":"n:伊朗",
"iraq":"n:伊拉克",
"iraqi":"n:伊拉克人",
"irascibility":"n:肝气,肝火",
"irascible":"a:急躁,暴躁,暴",
"ire":"n:忿怒,愤怒",
"ireland":"n:爱尔兰",
"iridescence":"n:虹彩",
"iridescent":"a:服装;n:服装",
"iridium":"n:铱",
"iris":"n:虹膜,蝴蝶花,光圈,虹,虹彩,隔膜",
"irish":"n:怒火",
"irish potato":"n:马铃薯",
"iron":"n:铁;v:消除",
"iron age":"n:末世",
"iron horse":"n:机车",
"iron man":"n:银元,铁汉",
"iron out":"v:消除",
"iron-gray":"a:灰白色",
"ironic":"a:反语",
"ironical":"a:反语",
"ironmongery":"n:五金店",
"ironware":"n:铁器",
"ironwork":"n:铁工,铁活,锻铁",
"irony":"n:讽刺,讥讽,反话,反语",
"irradiate":"v:照射,辐照,照耀,焕发;n:辐照",
"irradiation":"n:照射,辐照,照耀,扩散,阐明,发光;v:扩散,照射",
"irrational":"a:无理数",
"irrational number":"n:数",
"irrawaddy":"n:伊洛瓦底江",
"irreclaimable":"a:怙恶不悛",
"irrefutable":"a:颠扑不破,无可争辩,确凿;v:颠扑不破,无可争辩",
"irregular":"a:不规则,邪,错落,花花搭搭,参差不齐,七扭八歪,参差;v:错落,舞弊;n:邪门儿",
"irregularities":"n:舞弊",
"irregularity":"n:不规则,例外,非正式,违法乱纪,邪门儿",
"irregulars":"n:次货",
"irrelevance":"n:不相干",
"irrelevant":"a:无关痛痒,不着边际,无关宏旨;v:无关宏旨,无关痛痒",
"irremediable":"v:不可收拾;a:不可收拾",
"irreproachable":"a:无可非议",
"irresistible":"a:势不可挡,势不可当",
"irresolute":"a:憧",
"irresoluteness":"n:临渊羡鱼",
"irresolution":"n:优柔寡断",
"irresponsible":"n:溜肩膀;a:敷衍塞责",
"irresponsibly":"d:混;v:混",
"irretrievable":"a:不可救药;v:不可救药",
"irreverence":"n:无礼,非礼",
"irreversible":"v:不可逆转;a:不可逆转",
"irrigable":"a:水浇地",
"irrigate":"v:灌溉,浇,浇灌,灌,沃,注,滋润,冲洗,溉",
"irrigation":"n:灌溉,灌,水利,冲洗;v:冲洗,灌,灌溉",
"irrigation ditch":"n:渠道",
"irritability":"n:感应,过敏性,兴奋性,肝气;v:过敏",
"irritable":"a:烦躁,暴躁,急躁,暴,毛躁,火暴",
"irritant":"n:刺激",
"irritate":"v:激怒,刺激,生气,刺,蜇,撄,怄",
"irritated":"a:急,恼火,恼,烦燥;v:急",
"irritating":"a:恼人",
"irritation":"n:愤怒,刺激,发炎,生气,焦躁,疼痛,兴奋,烦扰,激怒",
"irruption":"n:闯进",
"irruptive":"a:是",
"irving":"n:欧文",
"is":"v:现在时,单数",
"isaiah":"n:以赛亚",
"isinglass":"n:鱼胶,鳔胶",
"islam":"n:伊斯兰教,伊斯兰,回教,穆斯林,清真教",
"islamabad":"n:伊斯兰堡",
"islamic":"a:清真",
"island":"n:岛,岛屿,海岛,安全岛",
"islands":"n:群岛,岛屿",
"isle":"n:岛",
"islet":"n:胰岛,孤岛,屿",
"ism":"n:学说,制度,主义",
"isobar":"n:等压线",
"isolate":"v:分离,孤立,隔离,隔绝,绝缘,离析,割裂",
"isolated":"v:隔绝,隔离;a:孤立",
"isolation":"n:隔离,孤立,分离;v:隔离,分离,分隔,离析",
"isolator":"n:隔离器,绝缘体",
"isometric line":"n:等角线",
"isomorphism":"n:同性,同形;a:同性",
"isosceles":"a:等腰",
"isosceles triangle":"n:正三角形",
"isotherm":"n:等温线",
"isothermal":"n:等温线;a:等温",
"isotope":"n:同位素",
"isotropy":"a:各向同性",
"israel":"n:以色列,犹太人",
"israeli":"n:犹太人",
"israelite":"n:犹太人",
"issuance":"n:颁布,发行,配给",
"issue":"v:发出,发布,发行,发,发表,发给;n:颁布,流出,商讨,涌出,出口,放出,成绩,河口",
"issuer":"n:出版者,发行者",
"istanbul":"n:伊斯坦布尔",
"isthmus":"n:地峡,峡",
"it":"r:它,其,it;n:傻瓜",
"italian":"n:意大利语",
"italics":"n:斜体字",
"italy":"n:意大利,意",
"itch":"n:热望;v:发痒,痒,痒痒,渴望;a:痒",
"itchy":"a:刺挠,痒痒,刺痒",
"item":"n:项目,项,节目,事项,条款,条,名堂,一则,个,件,节,细目;v:端;d:同上",
"itemize":"v:分类,举出",
"items":"n:名目,品目",
"iterate":"v:反复,重复",
"iteration":"v:迭代;n:迭代",
"itinerant":"a:游,巡游",
"itinerary":"n:路线,航线,旅程",
"its":"a:厥;r:其",
"itself":"r:自身,自己,本身;n:本色",
"ivory":"n:象牙,牙,牙雕,弹子,獠牙,乳白色,牙齿,牙质,象牙质",
"ivory coast":"n:象牙海岸",
"ivory tower":"n:象牙塔",
"ivy":"n:常春藤",
"jab":"v:戳,猛击;n:刺",
"jabber":"v:闲聊,磨嘴皮子,叽里咕噜,磨嘴皮;n:碎嘴子",
"jabbering":"v:结结巴巴,滴里嘟噜;a:结结巴巴",
"jack":"n:千斤顶;v:责备",
"jack up":"v:抬高",
"jack-o'-lantern":"n:磷火",
"jack-tar":"n:水手",
"jackal":"n:骗子,走狗,豺,豺狼",
"jackass":"n:公驴",
"jackboots":"n:马靴",
"jackdaw":"n:寒鸦",
"jacket":"n:上衣,夹克,外衣,外套,护封,皮,套,上装,外壳,茄克衫,上身,袄,套筒,毛皮,救生衣,罩,皮毛,盒;v:打",
"jackhammer":"n:风镐,气锤",
"jackpot":"n:困境,赌注",
"jackson":"n:杰克逊",
"jackstraw":"n:稻草人",
"jacob's ladder":"n:绳梯",
"jacob's staff":"n:测距器,支架",
"jade":"n:玉,玉石,碧玉,劣马;a:疲倦;v:精疲力尽",
"jade green":"n:玉色",
"jadeite":"n:翡翠,翠,硬玉",
"jag":"v:戳,刺;n:酒席",
"jagged":"a:参差;n:参差不齐",
"jaguar":"n:美洲豹",
"jail":"n:监狱;v:监禁",
"jail delivery":"n:劫狱",
"jailer":"n:狱吏",
"jailhouse":"n:监狱",
"jakarta":"n:雅加达",
"jalopy":"n:老爷车,车辆",
"jalousie":"n:百叶窗",
"jam":"v:叉,强行,塞满;n:干扰,酒席,可卡因,拥挤,窘境",
"jamaica":"n:牙买加",
"jamb":"n:边框,矿柱",
"jambalaya":"n:混合物,杂烩",
"jammed":"v:壅塞",
"jamming":"v:干扰;n:抑制",
"jan":"n:一月,1月",
"jangle":"n:空谈,口角,吵闹;v:争论,吵架,丁零当郎",
"janitor":"n:门房,幽门,传达;v:传达",
"january":"n:一月,元月,1月",
"japan":"n:和,东瀛,日,日本国,扶桑",
"japan allspice":"n:腊梅",
"japanese":"n:日语,日文",
"japanese cedar":"n:柳杉",
"japanese persimmon":"n:柿子",
"japanese red pine":"n:赤松",
"jape":"n:嘲弄,笑柄,戏言,笑料,愚弄,笑话;v:嘲弄,戏谑",
"jar":"n:罐子,瓶,瓶子;v:振动",
"jargon":"n:术语,行话;v:震动,刺激",
"jarring":"n:争执,冲突,振动,倾轧;a:刺耳,牙碜;v:抖动",
"jasmine":"n:茉莉,栀子,草茉莉",
"jasper":"n:墨绿色,碧玉",
"jaundice":"n:黄疸,妒忌,猜忌",
"jauntily":"d:扬扬得意",
"jauntiness":"n:快活",
"jaunty":"a:扬扬得意",
"java":"n:爪哇",
"javanese":"a:爪哇",
"javelin":"n:标枪,投枪",
"jaw":"n:颌,颚,爪;v:嚼舌头",
"jawbone":"n:颚骨,信用",
"jay":"n:花花公子",
"jazz":"n:爵士乐;v:游荡",
"jealous":"a:嫉妒,醋心",
"jealousy":"n:妒忌,猜忌,醋劲,醋劲儿,醋意",
"jean":"n:工装裤",
"jeans":"n:牛仔裤",
"jeep":"n:吉普车,吉普,新兵",
"jeer":"v:嘲笑;n:起哄,戏弄",
"jehovah":"n:耶和华",
"jejunum":"n:空肠",
"jell":"n:胶状物;v:定形",
"jelly":"n:果冻,冻,胶状物,冻儿,肉冻;v:冻",
"jellyfish":"n:水母,海蟹,海蜇",
"jenghiz khan":"n:成吉思汗",
"jennet":"n:驴骡",
"jenny":"n:卷扬机",
"jeopardize":"v:危及,危害,妨害",
"jeopardy":"n:危险,危难",
"jerk":"v:晃动;n:傻瓜",
"jerkin":"n:猎装",
"jerks":"v:抽搐",
"jerky":"a:生涩",
"jersey":"n:运动衫",
"jerusalem":"n:耶路撒冷",
"jerusalem artichoke":"n:菊芋",
"jest":"n:戏谑,玩笑,俏皮话;v:嘲弄,谐戏;a:谐谑",
"jesting":"v:滑稽,笑话",
"jestingly":"d:闹着玩",
"jesus":"n:耶稣",
"jet":"n:射流;v:喷吐,气流;c:可是;a:喷气式",
"jet lag":"n:疲累",
"jet stream":"n:射流",
"jet-black":"a:乌黑,乌油油,黑油油",
"jettison":"n:放弃,丢弃,抛弃",
"jetty":"n:码头,防波堤,丁坝,埠;v:伸出,突出",
"jew":"n:犹太人,犹太,犹太教徒,奸商,守财奴",
"jewel":"n:珠宝,宝石,钻,钻石,明珠,宝玉",
"jeweler":"n:珠宝商",
"jewelery":"n:珠宝",
"jeweller":"n:珠宝商",
"jewellery":"n:珠宝,珍宝",
"jewelry":"n:珠宝,饰物,珍宝",
"jewess":"n:犹太人",
"jewry":"n:犹太人",
"jezebel":"n:淫妇",
"ji":"n:冀,姬,吉",
"jiao":"n:焦",
"jib":"v:后退,讨厌,退缩,踌躇不前;n:吊杆",
"jibe":"v:嘲笑,符合,讥笑,嘲弄;n:讥笑",
"jiffy":"n:一会儿,瞬间",
"jig":"v:跳荡,筛,跳,跳动,跳跃;n:样板",
"jigger":"n:量杯,辘轳",
"jiggery-pokery":"n:阴谋,诡计,诈骗",
"jigsaw":"n:钢丝锯",
"jilt":"v:抛弃",
"jim crow":"n:黑人;a:歧视",
"jimmy":"n:撬棍,煤车;v:撬",
"jimsonweed":"n:曼陀罗",
"jingle":"v:丁零当郎,铿锵;d:丁当,叮当;n:顺口溜,丁当",
"jingoism":"n:沙文主义",
"jinks":"n:狂欢",
"jinrikisha":"n:人力车,黄包车",
"jinx":"n:白虎星;v:倒霉",
"jitney":"n:便宜货",
"jitter":"v:颤动,振动,战战兢兢,抖动,跳动,颤抖;n:恐慌",
"jitterbug":"v:跳动",
"jitters":"n:神经过敏",
"jittery":"a:人心惶惶,躁,惶恐不安",
"jive":"v:花言巧语,取笑,欺骗;n:废话,摇滚乐",
"job":"n:工作,事,职位,任务,职业,职务,结果,事情,职责,产品,饭碗,活计,事件;v:打杂",
"job's tears":"n:薏苡",
"jobber":"n:包工,零工",
"joblessness":"n:无业",
"jock":"n:运动员",
"jockey":"v:欺骗;n:小伙子",
"jocosity":"n:滑稽,开玩笑,戏谑",
"jocular":"a:诙谐",
"jocularity":"n:滑稽",
"jocund":"a:欢乐",
"jocundity":"n:欢乐,快活,愉快",
"jodhpur breeches":"n:马裤",
"jog":"v:慢跑,唤起,小跑,提醒;n:漫步",
"jog trot":"n:常规",
"joggle":"n:接口",
"joggling":"v:抖动",
"john":"n:约翰,警察,侦探,厕所,新兵,家伙",
"johnson":"n:约翰逊",
"join":"v:参加,加入,连接,联合,会合,毗连,汇合,连,结合,接合,合,接,并;n:结合;p:从",
"join forces":"v:合力,并力",
"joiner":"n:木工",
"joinery":"n:木工",
"joining":"n:接缝,连接,结合;v:接合,配种",
"joint":"n:关节,节理;v:连接,接合,联合,拔节,接头,结合;a:共",
"joint-stock company":"n:股份公司",
"jointing":"n:连接,接合,焊接,节理,填料;v:节理,联结,拔节",
"jointly":"d:共同,联名;n:旅",
"joist":"n:工字钢",
"joke":"n:笑话,玩笑;v:愚弄,谐戏,耍笑",
"joker":"n:东西,伏笔,家伙",
"jollification":"n:欢乐,欢宴,热闹,庆祝",
"jolliness":"n:欢乐,快活,愉快,高兴",
"jollity":"n:欢乐,欢宴,快活,欢庆",
"jolly":"d:很;n:水兵,奉承;v:开玩笑,戏弄",
"jolly along":"v:高兴",
"jolt":"n:摇晃,震惊;v:猛击,摇动,摇晃",
"jonah":"n:灾星",
"jones":"n:琼斯",
"jonquil":"n:水仙",
"jordan":"n:约旦,乔丹",
"joseph":"n:约瑟夫",
"josh":"v:开玩笑,说笑,哄骗,戏弄;n:嘲笑,说笑",
"joss house":"n:庙",
"joss stick":"n:香",
"jostle":"v:挤,竞争,推,撞,拥挤;n:拥挤,撞,挤",
"jot":"n:一点,少量",
"jottings":"n:随感,随笔,杂记",
"joule":"n:焦耳",
"jounce":"n:颠簸,摇晃,震动;v:摇晃,震动,颠簸",
"journal":"n:杂志,日记,期刊,刊物,日志,报纸,学报,报刊,日记账,通报,分类账,日报,报",
"journalist":"n:记者,报人",
"journey":"n:旅行,旅程,旅途,路程,路,行程,途,道路;v:技工",
"journeyman":"n:帮工,雇工",
"journeymen":"n:雇工",
"joust":"n:斗争",
"jove":"n:木星",
"joviality":"n:高兴,快活,愉快",
"jovian planet":"n:类木行星",
"jowl":"n:颊,下颚,下巴,下颌",
"joy":"n:高兴,欢乐,快乐,乐趣,乐事,愉快,欢欣,寻欢作乐,欢心,喜气;v:高兴,欢欣,享受;a:乐不可言,欢欣",
"joyful":"a:愉快,高兴,快意,衎,快乐,乐,痛快,忻,开怀,开心,欣,恺,融融,欣喜,欢喜,乐陶陶,喜悦,愉,忭,快活,愉悦;n:快意",
"joyfully":"d:欢欢喜喜,欣然",
"joyous":"a:欢乐,喜悦,欢娱,欣忭,欢,快活,喜庆",
"joystick":"n:操纵杆",
"ju":"n:居",
"jubilant":"a:开怀,喜庆,欢",
"jubilation":"n:欢腾,欢呼,庆祝,欢欣,喜悦,禧",
"jubilee":"n:欢乐,佳节",
"judaism":"n:犹太教",
"judas":"n:犹大,叛徒",
"judder":"v:颤动,振动,颤抖,摇动;n:颤抖",
"judea":"n:犹太",
"judge":"v:判断,看;n:鉴赏家,审判长",
"judgement":"n:判断力,意见,评价,审判,看法,裁决,见识,眼力,公正,裁判,指责,鉴定,论断,批评",
"judging":"v:判定",
"judgment":"n:判断,判断力,判决,看法,意见,报应,评价,见识,批评,眼力,裁判,审判,公正,鉴定,见地,断语,恶报,评判,论断,指责",
"judgment day":"n:末日",
"judicatory":"n:法院",
"judicature":"n:司法,审判员,司法权,裁判,法院;a:司法",
"judicial":"a:司法,法庭",
"judicial review":"n:再审",
"judiciary":"n:司法,法官,司法部",
"judo":"n:柔道",
"jug":"n:罐子,水壶,罐,缸,盂;v:监禁",
"juggle":"v:玩,变戏法,窜改,耍,舞,歪曲,颠倒,欺骗,撮弄,监禁,诈取;n:积木",
"juggler":"n:魔术师,骗子",
"jugglery":"n:把戏,戏法,花招,魔术",
"juice":"n:果汁,汁,汽油,电,汁液,精力,汁水,电流,肉汁,糖汁,体液,油水,冷饮,精髓,硝化甘油,薪水,液,高利,地位,生命力,收入,活力",
"juicer":"n:榨汁机",
"jujitsu":"n:柔术",
"jujube":"n:枣树,枣,枣子",
"julep":"n:玫瑰露",
"julius caesar":"n:凯撒大帝",
"july":"n:七月,7月",
"jumble":"n:混乱,杂乱;v:乱",
"jumbled":"v:错杂,乱蓬蓬,拉杂;a:乱蓬蓬,拉杂",
"jumbo":"n:庞然大物;a:特大",
"jump":"v:跳;n:暴涨,中断",
"jump for joy":"n:欢跃",
"jump off":"v:开始",
"jump on":"v:责备,叱责",
"jump rope":"v:跳绳",
"jumper":"n:工作服,套衫,棘爪,雪橇",
"jumpiness":"n:跳动",
"jumping":"v:跳动",
"jumping-off place":"n:起点,天涯海角",
"jumping-off point":"n:出发点",
"junction":"n:接头,结,交叉点,连接,会合,接点,接合,连结;v:结,连结,会合,接合",
"juncture":"n:时候,关头,接缝,交界,结合;v:接合",
"june":"n:六月,6月",
"jungle":"n:丛林,密林",
"junior":"n:晚辈,后辈,小辈;a:初级,晚",
"junior college":"n:大专",
"juniors":"n:后辈,后进,子弟",
"juniper":"n:红松",
"junk":"n:破烂,旧货,旧物,帆船,废话,便宜货,哄骗",
"junket":"n:宴会,野餐,旅游,欢聚,游览;v:宴请",
"junta":"n:派系,军政府,私党,小集团",
"jupiter":"n:木星",
"jurisdiction":"n:裁判权,权限,审判权,司法权,司法",
"jurisprudence":"n:法学,法理学,法律学",
"jurist":"n:法学家,律师,法官",
"juror":"n:陪审员",
"jury":"n:陪审团",
"jury box":"n:陪审席",
"juryman":"n:陪审员",
"just":"d:就,刚,刚刚,刚才,正,不过,只不过,才,正好,请,只是,非常,仅仅,刚好,恰恰,真正;a:公道,顷;n:耳,高低,正义;c:但,只要;v:聊,持平",
"just about":"p:差不多",
"just as":"p:犹如,犹",
"just in case":"c:以防万一,万一",
"just in time":"p:正巧,可好,正好",
"just now":"n:方始,适才,顷,方,将才,此刻,刚刚",
"just right":"n:正好,适中,恰好,毫厘不爽,可好",
"just then":"n:方",
"justice":"n:正义,公正,审判,公道,公平,法官,司法,正确,正当,推事,妥当,天理,审判员,司法官,合法,义",
"justifiability":"n:情理",
"justifiable":"v:说得过去;a:入情入理",
"justifiably":"d:理所当然",
"justification":"n:理由,辩解,辩护,对齐,辩明",
"justified":"a:有理",
"justify":"v:是,圆,辩解,整版,声辩,装",
"justly":"d:秉公",
"justness":"n:公正,正确,正当",
"jut":"n:伸出,突出;v:突出,伸出",
"jute":"n:黄麻,麻,麻绳",
"juvenile":"n:青少年,雏鸟",
"juvenile delinquent":"n:少年犯",
"juxtapose":"v:并列",
"juxtaposition":"v:并列;n:并列",
"ka":"n:鬼魂,阴魂",
"kabul":"n:喀布尔",
"kaiser":"n:独裁者",
"kala-azar":"n:黑热病",
"kale":"n:蔬菜",
"kaleidoscope":"n:万花筒",
"kampala":"n:坎帕拉",
"kampuchea":"n:柬埔寨",
"kangaroo":"n:袋鼠,大袋鼠",
"kansas":"n:堪萨斯",
"kantian":"a:康德",
"kaolin":"n:瓷土,高岭土,陶土",
"kapok":"n:木棉,攀枝花",
"karachi":"n:卡拉奇",
"karat":"n:开",
"karma":"n:业,因果,因缘,因果报应",
"kashmir":"n:克什米尔",
"katydid":"n:蝈蝈儿,螽斯,纺织娘",
"kayak":"n:皮艇",
"kayo":"v:击倒;n:击倒",
"kazakh":"n:哈萨克族",
"kazakhstan":"n:哈萨克",
"kebab":"n:烤羊肉串",
"keel":"v:倾覆,翻身;n:船,龙骨",
"keen":"a:敏锐,激烈,灵敏,尖锐,锐利,锋利,锐敏,快,敏慧;v:入木三分;n:挽歌",
"keenly":"d:深深",
"keenness":"n:锐利",
"keep":"v:遮断,持,减缩,抵挡,遏抑,固守,逗留,压;n:保养,管理,监牢,监狱,生活资料,要塞,饲料,维,衣食",
"keep apart":"v:隔离",
"keep away":"v:避,辟,避开",
"keep back":"v:保留,留下,阻止,遗,敛,隐瞒",
"keep company":"v:交游,作伴",
"keep down":"v:躺下,压迫,减缩,镇,遏抑,控制,保留,沉,遏制",
"keep guard":"v:守卫",
"keep in":"v:控制",
"keep mum":"v:守口如瓶,默不作声,钳口结舌",
"keep off":"v:避开,防止,驱散",
"keep out":"v:抵挡,遮挡,阻止,遮断,搪,御",
"keep quiet":"v:默不作声,按兵不动,噤若寒蝉",
"keep up":"v:坚持,维持,撑,继续,维系",
"keeper":"n:饲养员,夹子,所有者,衔铁",
"keeping":"n:保管,保存,供养,保持,协调,饲养,管理,看守,保留,保有,一致;v:堆存,贮存,堆放",
"keepsake":"n:纪念,纪念品,信物",
"keg":"n:桶",
"kelly":"n:黄绿色",
"kelp":"n:海藻,海带,海草,昆布",
"kelvin":"n:开氏温标",
"ken":"n:肯,窝,见地,眼界,视域,景象;v:知道,看出",
"kennedy":"n:肯尼迪",
"kennel":"n:沟渠,阴沟,洞,明沟,下水道",
"kenning":"n:痕迹,微量",
"kent":"n:肯特",
"kentucky":"n:肯塔基",
"kenya":"n:肯尼亚",
"keratin":"n:角质",
"kerchief":"n:头巾,围巾,手帕,披巾",
"kerfuffle":"n:动乱,混乱,骚动",
"kern":"n:核,核心,颗粒;v:结",
"kernel":"n:核,核心,仁,果仁,种仁,子实,麦粒,子粒,原子核,中心,谷粒,要点,果核,果仁儿,核儿,核仁,内核",
"kerosene":"n:煤油,灯油,火油,洋油",
"kerosene lamp":"n:煤油灯",
"ketchup":"n:番茄酱",
"kettle":"n:水壶,壶,吊桶",
"kettledrum":"n:定音鼓,铜鼓",
"kewpie":"n:洋娃娃",
"key":"n:钥匙,键,键盘,关键;v:解答,激励,发,鼓舞,升调;a:关键",
"key out":"n:切断",
"key signature":"n:调号",
"key word":"n:主题词",
"keyboard":"n:键盘",
"keyboard instrument":"n:键盘乐器",
"keyhole":"n:钥匙孔,锁孔,锁眼",
"keying":"n:按键;v:按键",
"keynote":"n:基调,主旨,重点,要旨,基音,主音;v:强调",
"keypad":"n:键盘",
"keystone":"n:重点",
"keyword":"n:关键词",
"keywords":"n:关键字",
"kg":"n:公斤",
"kgb":"n:克格勃",
"khaki":"n:卡其,黄褐色,咔叽,土黄",
"khan":"n:汗,可汗,单于",
"khartoum":"n:喀土穆",
"khrushchev":"n:赫鲁晓夫",
"kibble":"n:吊桶",
"kibitz":"v:多嘴,多管闲事,管闲事",
"kibosh":"n:胡说",
"kick":"v:踢;n:刺激",
"kick back":"v:反转,坐,逆转,尥蹶子",
"kick off":"v:井喷",
"kick out":"v:逐出",
"kick the bucket":"v:伸腿,一命呜呼,上西天,死亡",
"kick up":"v:引起,骚动,骚乱,激起",
"kickback":"n:回扣,反冲,回程,贿赂,酬金",
"kickball":"n:踢球",
"kicking":"v:开钻",
"kickoff":"n:开球",
"kid":"v:愚弄,赚,哄;n:年轻人;a:冤",
"kiddie":"n:小孩",
"kiddo":"n:老兄",
"kidnap":"v:绑架,胁持,绑票,诱拐,拐走,架,劫持,拐",
"kidnapper":"n:绑匪,拐子",
"kidnapping":"v:绑架",
"kidney":"n:肾脏,肾,脾气,性格,腰子",
"kidney bean":"n:四季豆,云豆",
"kidney stone":"n:肾结石,软玉",
"kiev":"n:基辅",
"kigali":"n:公里",
"kill":"v:杀死,杀,杀害,打死,消磨,杀人,扼杀,宰,弄死,消灭,结果,否决,毁掉,要命,摧毁,删去,杀伤,害,中和,干掉,屠杀,诛,诛杀,虐杀,抵消,诛戮,抄斩;n:贼,杀伤,杀死;a:镇静",
"kill off":"v:除去,摧毁,消灭",
"killer":"n:凶手,杀手,鱼饵",
"killing":"n:屠杀,杀害",
"kiln":"n:窑,瓷窑,陶",
"kilo":"n:公斤,千克,公里",
"kilocycle":"n:千赫",
"kilogram":"n:公斤,千克",
"kilohertz":"n:千赫",
"kiloliter":"n:千升",
"kilolitre":"n:千升,公里",
"kilometer":"n:公里,千米",
"kilometre":"n:公里",
"kilos":"n:公里,公斤",
"kilowatt":"n:千瓦",
"kilt":"n:短裙;v:卷起",
"kimono":"n:和服",
"kin":"n:亲戚,亲属,家族,门第,家属",
"kind":"n:种;a:宽厚,温存;v:等,心慈",
"kindergarten":"n:幼儿园,幼稚园",
"kindhearted":"a:善良;n:善心,慈心;v:心慈",
"kindheartedness":"n:仁爱",
"kindle":"v:兴奋,点燃,发亮,燃烧,激动,点,照亮,激发,鼓舞,着火,放光,照耀;n:燃点",
"kindliness":"n:亲切",
"kindling":"n:火种,燃点,点火,劈柴,火捻,引火柴,燃烧,引柴",
"kindly":"a:友好,和悦;d:和蔼可亲",
"kindness":"n:好意,仁慈,善良,厚道,恩惠,好心,亲切,厚意,恩,恩情,恩典,美意,恩德,情,惠,慈爱,温暖,德,泽",
"kindred":"n:类似,宗族,骨肉",
"kine":"n:显像管",
"kinematics":"n:运动学",
"kinetics":"n:动力学",
"kinfolk":"n:家属,亲戚,亲属",
"kinfolks":"n:亲戚,亲属",
"king":"n:国王,王,金,大王,君王;v:统治",
"king cobra":"n:眼镜蛇",
"king crab":"n:鲎",
"kingdom":"n:王国,领域,界",
"kingfisher":"n:翠鸟,鱼狗,翠",
"kingpin":"n:领袖",
"kingston":"n:金斯敦",
"kink":"n:怪僻,缺陷,幻想,痉挛,乖僻;v:纠结,绞缠,妄想;a:怪僻",
"kinked":"a:屈曲",
"kinking":"a:屈曲",
"kinky":"a:绞缠",
"kinsfolk":"n:亲戚,亲人,家属,亲属,党",
"kinshasa":"n:金沙萨",
"kinsman":"n:亲戚",
"kinswoman":"n:亲戚",
"kiosk":"n:亭子,亭,凉亭",
"kip":"n:客栈,床;v:睡觉",
"kipper":"n:家伙",
"kirghizia":"n:吉尔吉斯",
"kiss":"v:吻,接吻,亲吻,亲,吻别,亲嘴,接触;n:接缝,唇吻",
"kisser":"n:脸,嘴唇,面孔",
"kissinger":"n:基辛格",
"kit":"n:配备,小提琴,工具箱,行装;v:装备",
"kitchen":"n:厨房,厨,庖厨,伙房,庖",
"kitchen range":"n:灶头",
"kitchen table":"n:餐桌",
"kitchener":"n:厨师",
"kitchenware":"n:炊具",
"kite":"n:风筝,飞机,空头支票,鹞鹰,流氓,骗子,信,纸鸢;v:上升",
"kith":"n:邻居,朋友,亲属,相识,熟人",
"kitten":"n:烦恼,兴奋;v:产",
"kitty":"n:头钱",
"kiwi":"n:罗汉果,无翼鸟,几维鸟",
"kiwi fruit":"n:猕猴桃",
"klutz":"n:傻瓜,笨蛋,木头人",
"km":"n:公里",
"knack":"n:窍门,诀窍,技巧,门道,花头,诀要,门路,诀,妙诀,玩具,妙法,三昧,习惯,花样",
"knapsack":"n:背包,背囊",
"knave":"n:流氓,仆人,无赖,小丑",
"knavery":"n:恶作剧,诈骗",
"knavish":"a:刁诈",
"knead":"v:揉,按摩,挼,挼搓,搋,和,锻炼,揉搓,和面,捏",
"knee":"n:膝盖,膝,膝关节,膝头,腕骨",
"knee joint":"n:关节,膝关节",
"kneecap":"v:膝盖骨,髌,护膝;n:髌骨,护膝,膝盖骨",
"kneel":"v:跪下,跪,下跪,跽",
"knell":"n:丧钟,钟声;v:敲丧钟",
"knesset":"n:议会",
"knickerbockers":"n:灯笼裤",
"knickers":"n:内裤,衬裤,灯笼裤",
"knife":"n:刀,小刀,菜刀;v:劈开,切",
"knight":"n:骑士,武士,爵士,马,会员,大家,社员,团员",
"knight-errant":"n:好汉,武侠,侠客,剑侠",
"knighthood":"n:爵士,骑士,侠义",
"knit":"v:织,编织,接合,结,结成,结合,粘合,针织,编结,织补,拼合,锁,蜂拥;n:编结,编织,针织,针织品;a:针织",
"knitter":"n:编织机",
"knitting":"n:编织,针织,联合,针织品,接合,结合;a:针织",
"knitting machine":"n:编织机",
"knitwear":"n:针织品,针织物",
"knives":"n:小刀",
"knob":"n:旋钮,把手,节,按钮,拉手,纽,调节器,山顶,线团,瘤,山峰,疙瘩;v:突出",
"knock":"v:敲,击倒;n:局",
"knock about":"v:漫游,碰撞",
"knock against":"v:碰撞,磕碰,碰到,撞上",
"knock down":"v:拆除,拆开,撂",
"knock off":"v:成交,中止,歇工,放工,住,下班,歇,减低",
"knock on":"v:敲",
"knock out":"v:击落,摧毁,打掉,打破,击倒",
"knock over":"v:打翻",
"knockabout":"n:帆船",
"knockdown":"n:成交,昏迷",
"knocker":"n:门环,兽环,门环子",
"knocking":"v:水锤",
"knockout":"n:击倒,拆卸,打倒,淘汰赛;v:拆卸",
"knockout drops":"n:蒙药",
"knoll":"n:圪垯,土,疙瘩,土墩",
"knot":"n:绳结,难题,节子,收缩;v:结,扣",
"knotty":"a:棘手,伤脑筋,疑难;v:绕脖子,伤脑筋",
"know":"v:知道,了,认识,了解,明白,知,懂得,懂,熟悉,晓得,经历,认得,相识,精通,识,明,通,认,知晓,体验,辨识,区别,知悉,接头,审,谂;n:知晓",
"know apart":"v:辨别",
"know the score":"v:心中有数",
"know what's what":"v:心中有数",
"know-how":"n:技术,秘诀",
"knowing":"n:认识,知道;v:会心,会意;a:知道;d:会心",
"knowledge":"n:知识,了解,认识,知,学问,学识,学科,学,理解,消息,智,见识;v:知",
"knowledgeable":"a:博学,博识",
"known":"a:有数",
"knuckle":"n:关节,指节;v:屈膝,投降",
"knuckle down":"v:屈膝",
"knuckle under":"v:屈服",
"knucklehead":"n:傻瓜,笨蛋",
"kobe":"n:神户",
"kohlrabi":"n:苤蓝,球茎甘蓝",
"kola":"n:可乐",
"kook":"n:傻子,怪人,狂人",
"koran":"n:古兰经",
"korea":"n:高丽,高句丽",
"korean":"n:朝鲜族",
"kotow":"v:拍马屁,磕头,奉承;n:低三下四,磕头",
"kowtow":"v:叩,叩拜,叩头,拍马屁,顿首,奉承,卑躬屈节,跪拜,磕头,叩首;n:磕头",
"kraal":"n:村庄,围栏",
"kraft":"n:牛皮纸",
"kraut":"n:泡菜",
"krill":"n:磷虾,鱼苗",
"krona":"n:克朗",
"krone":"n:克朗",
"kroner":"n:克朗",
"kronor":"n:克朗",
"krypton":"n:氪",
"kuala lumpur":"n:吉隆坡",
"kudos":"n:荣誉,光,光荣,赞扬,名誉",
"kudzu":"n:葛,葛藤",
"kudzu vine":"n:葛,葛藤",
"kulun":"n:库伦",
"kumquat":"n:金橘",
"kung fu":"n:功夫",
"kuomintang":"n:国民党",
"kuwait":"n:科威特",
"kvetch":"v:找岔子",
"kw":"n:千瓦",
"kyoto":"n:京都",
"kyushu":"n:九州",
"l":"n:湖",
"la":"n:装模作样",
"la paz":"n:拉巴斯",
"la-di-da":"a:矫揉造作,装腔作势",
"lab":"n:实验室",
"label":"n:标签,标号,标记,符号,帽子,签条,带子,标注,称号,邮票;v:标",
"labeling":"v:标号;n:标号",
"labial":"n:唇音",
"labium":"n:下唇,唇,阴唇",
"labor":"n:劳动,劳动力,工作,劳力;v:分娩,生产",
"labor force":"n:劳动力",
"labor movement":"n:工运",
"labor party":"n:工党",
"labor union":"n:工会",
"laboratory":"n:实验室,试验室,研究室,药厂,炉膛,化验室",
"labored":"a:吃力",
"laborer":"n:工人,劳工,劳动者,民工",
"laboring":"v:劳动者,劳苦",
"laborious":"a:辛苦,惨淡,吃力,辛",
"laboriousness":"n:千辛万苦",
"labour":"v:劳动;n:工,活计",
"labour pains":"v:阵痛",
"labour party":"n:工党",
"laboured":"a:吃力",
"labourer":"n:劳动者",
"labouring":"a:劳动者",
"labyrinth":"n:迷宫,错综复杂,迷路,曲折,难事,曲径",
"lac":"n:紫胶,虫胶,紫草茸",
"lace":"v:刺绣,混合,镶边,打,鞭打,镶,搀合,交织;n:丝带,缎带",
"lace into":"n:批评,攻击",
"lacerate":"v:划破,撕裂,割裂,撕碎,伤害",
"laceration":"n:伤,撕裂,划破,裂口;v:撕裂,划破",
"lacewing":"n:草蜻蛉",
"lacework":"n:花边",
"lachrymal gland":"n:泪腺",
"lacing":"n:殴打,猛击,条纹,鞋带,刺绣,鞭打,花边;v:镶边,缝合",
"lack":"v:缺乏,缺少;n:不够;a:乏,短,不够",
"lackadaisical":"a:没精打采,无精打采;d:懒洋洋;v:无精打采",
"lackey":"n:腿子,走狗,走卒,奴仆,狗腿子,仆人,仆从,奴才,喽罗;v:奉承,侍候,服侍",
"lackeys":"n:鹰犬,爪牙",
"lacking":"a:没有,贫乏;v:欠",
"lacquer":"n:漆;v:喷漆",
"lacquer tree":"n:漆树",
"lacquering":"v:漆工;n:漆工",
"lactate":"n:乳酸;v:喂奶",
"lactation":"n:哺乳,乳",
"lactose":"n:乳糖",
"lacuna":"n:洼地,空白,空隙,缺失,脱漏",
"lad":"n:小伙子,后生,少年,竖子,伙伴,老朋友,童子",
"ladder":"n:梯子,阶梯;v:抽丝,走红",
"laddie":"n:年青人,小伙子,少年",
"lade":"v:汲取,装载,装货",
"laden":"v:装载",
"lading":"n:货物,提单,重量,装载,汲取,压力",
"ladle":"v:舀,给与,灌输,淘,提供,赠送,盛;n:水瓢,舀子",
"lady":"n:女士,太太,夫人,女人,淑女,女郎,贵妇,妻子,情妇,嫂夫人,未婚妻",
"lady beetle":"n:瓢虫",
"lady palm":"n:棕竹",
"lady-in-waiting":"n:侍女,宫女",
"lady-slipper":"n:凤仙花",
"ladybird":"n:瓢虫,花大姐",
"ladybug":"n:瓢虫,花媳妇儿",
"ladyfinger":"n:拳头",
"ladylove":"n:情人",
"ladyship":"n:小姐,夫人",
"lafayette":"n:政治家",
"lag":"v:落,落后,滞后;n:减速,迟延,落后,逗留,外套",
"lagerstroemia indica":"n:紫薇",
"laggard":"n:缓慢;a:拖沓",
"lagging":"n:外套,迟延,落后;v:滞后",
"lagoon":"n:泻湖,咸水湖,水道",
"lagos":"n:拉各斯",
"laid up":"v:卧病",
"lair":"n:窝,巢穴,老巢,牛栏,牛棚,围栏;v:打滚",
"laird":"n:地主",
"laissez-faire":"n:自由",
"laity":"n:外行,门外汉",
"lake":"n:湖,湖泊,海子,池,淖尔,沟渠,泊",
"lake baikal":"n:贝加尔湖",
"lake erie":"n:伊利湖",
"lake huron":"n:休伦湖",
"lakefront":"n:湖边,湖畔",
"lakes":"n:湖泊",
"lakeside":"n:湖畔,湖滨",
"lam":"n:逃走,潜逃;v:鞭打",
"lama":"n:堪布,喇嘛",
"lamaism":"n:喇嘛教",
"lamb":"n:羔羊,羊羔;v:生",
"lambaste":"v:痛打",
"lambency":"n:巧妙,闪烁",
"lambkin":"n:乖乖",
"lambskin":"n:羊皮纸",
"lame":"n:薄板,瘸腿,薄片",
"lamebrain":"n:笨蛋",
"lameness":"n:瘸",
"lament":"v:悲伤,哀叹,哀悼,悲痛,悲叹;n:悼词,哀辞,悲叹,悲痛,哀歌",
"lamentable":"a:可悲",
"lamentation":"n:痛哭,哀悼,悲叹",
"lamina":"n:薄片,叶片,薄板",
"laminated glass":"n:夹层玻璃",
"lamination":"n:纹理",
"lamp":"n:灯,眼睛,灯泡,明灯,电子管,檠;v:看到,看",
"lampblack":"n:油烟,煤烟",
"lamplight":"n:灯光,灯火",
"lamplighter":"n:纸捻",
"lampoon":"v:讽刺",
"lampshade":"n:灯罩,灯罩子,灯伞",
"lan":"n:局域网",
"lanai":"n:凉台",
"lance":"v:刺,投,掷,戳;n:长矛,矛,标枪",
"land":"n:土地,地,陆地;v:到达",
"land mine":"v:地雷",
"land reform":"n:土改",
"land tax":"n:地价税,土地税,租,地税,钱粮",
"landau":"n:马车",
"landfall":"n:着陆,登陆;v:山崩",
"landforms":"n:地貌",
"landholder":"n:地主",
"landing":"n:着陆,登陆,降落,上岸,沉淀;v:接地,降落,登陆,着陆",
"landing craft":"n:登陆艇",
"landing field":"n:飞机场",
"landing place":"n:码头",
"landing stage":"n:栈桥",
"landing strip":"n:飞机场",
"landings":"n:降落",
"landlady":"n:房东,老板娘",
"landlocked":"a:内陆",
"landlord":"n:房东,地主,店主,房主,员外,老财,东家",
"landmark":"n:地标",
"landmass":"n:大陆",
"landmine":"n:地雷",
"landowner":"n:地主",
"landscape":"n:景色,风景,风景画,山水画;v:美化",
"landslide":"n:滑坡,山崩,塌方,坍方;v:山崩,坍方,塌方",
"landslip":"n:崩塌,塌方,坍方,山崩,滑坡;v:坍方,山崩,塌方",
"landsman":"n:同胞",
"lane":"n:车道,小路,小巷,跑道,胡同,巷子,弄堂,航道,巷,泳道,通路,坊,死胡同,巷道,航线,里巷",
"language":"n:语言,语,言语,术语,民族,态度,措词,立场,文,文词,语声,文句,语调,叫声,文风,文辞,文体",
"languid":"a:倦怠,没精打采,慵,懒洋洋,慢吞吞,懒",
"languish":"v:衰弱,渴望,烦恼,潦倒,减弱,减少,凋萎,疲倦",
"languishing":"v:脉脉含情,含情脉脉",
"languor":"n:倦怠,郁闷,疲倦,衰弱,乏力",
"lankiness":"n:瘦",
"lanky":"a:瘦长",
"lantern":"n:灯笼,提灯,灯,马灯,幻灯,街灯",
"lantern slide":"n:幻灯片",
"lanthanide series":"n:镧系元素",
"lanthanum":"n:镧",
"lanzhou":"n:兰州",
"laos":"n:老挝",
"lap":"n:耳朵,面;v:伸出,突出",
"lapdog":"n:巴儿狗,叭儿狗",
"lapel":"n:翻领;a:翻领",
"lapis lazuli":"n:天青石",
"laplace":"n:拉普拉斯",
"lapse":"v:失效,陷入;n:堕落,过失",
"larceny":"n:窃案,偷窃",
"larch":"n:落叶松",
"lard":"n:大油,猪油;v:点缀,调制",
"lard oil":"v:猪油",
"large":"a:大,大型,肥大,厚,博,硕;n:充分",
"large number":"n:大数",
"large-minded":"a:宽宏大量",
"large-scale":"a:大规模,大型",
"largely":"d:大",
"largeness":"n:广大,巨大,慷慨,广博",
"largess":"n:贺礼,慷慨",
"largo":"a:宽广",
"lariat":"n:套索",
"lark":"n:云雀,百灵鸟,玩笑,百灵;v:开玩笑,愚弄",
"larva":"n:幼虫,幼体,妖怪",
"larvae":"n:幼虫",
"laryngeal":"n:喉音",
"laryngitis":"n:喉炎",
"larynx":"n:喉头,喉,嗓,嗓子",
"lascivious":"a:淫荡,淫",
"laser":"n:激光,激光器,莱塞,雷射",
"lash":"v:冲击,抽打;n:冲击,眼睫毛,空隙,抽打",
"lash out":"v:痛打",
"lashing":"n:申斥,捆绑,大量,非难,鞭打;v:联接",
"lashings":"n:大量",
"lass":"n:情人,少女,妮子,小姑娘",
"lassie":"n:小姑娘,少女,情人",
"lassitude":"n:疲倦,无精打采,厌倦,疲乏",
"lasso":"n:套索",
"lassos":"n:套索",
"last":"n:最后;v:经久,支持;a:上届",
"last day":"n:头天",
"last judgment":"n:末日审判",
"last name":"n:姓",
"last out":"v:坚持,忍受,持续",
"last word":"n:定论",
"lasting":"a:持久,经久不息,长,恒久;n:耐久;v:经久不息",
"lastingly":"d:老是,经常",
"lastly":"d:最后,终于,末了",
"latch":"n:门闩,弹簧锁;v:获得,理解,闭锁",
"latch on":"v:理解",
"latching":"v:闭锁;n:锁式",
"late":"d:来不及,最近;a:已故,深;v:误点,已故,晚点",
"lately":"d:近来,最近,新近,一向;n:最近",
"latency":"n:潜伏性,潜伏,隐伏,潜在",
"latent":"a:潜在;v:隐",
"latent heat":"n:潜热",
"latent period":"n:潜伏期",
"later":"n:后来,后,过后,后面,之后;d:后来,回头,既而,以后,底下;a:后,以后,后面,之后,底下",
"later on":"p:他日,往后,以后,嗣后",
"lateral":"n:侧面,横向,边音,支线,巷道;a:侧面",
"lateral line":"n:侧线",
"latex":"n:乳胶,胶乳,乳汁,乳液",
"lathe":"n:车床,旋床,旋;v:车",
"lather":"n:焦躁,泡沫,肥皂泡;v:起泡",
"latin":"n:拉丁文",
"latin america":"n:拉美",
"latin cross":"n:十字架",
"latitude":"n:纬度,自由,地区,余地,幅度,纬,地方,地域",
"latitudes":"n:地区",
"latrine":"n:厕所,茅房,圊,茅厕",
"latter":"a:晚,下",
"latterly":"d:近来,最近,后来",
"lattice":"n:点阵,格子,网络",
"latvia":"n:拉脱维亚",
"laud":"n:赞美歌,赞美,称赞;v:赞美,称赞,颂扬",
"laugh":"v:笑,嘲笑,大笑;n:嘲笑",
"laugh at":"v:见笑,漠视,笑话,嗤笑,耻笑,笑",
"laugh away":"v:一笑置之",
"laughable":"a:可笑,好笑",
"laughably":"d:可笑",
"laughing":"v:笑",
"laughingly":"d:笑哈哈",
"laughingstock":"n:笑柄,笑料,笑谈",
"laughter":"n:笑声,笑,大笑,捧腹大笑,哑然失笑",
"laughton":"n:劳顿",
"launch":"v:发射,开始,发起,下水,提出,发动,开展;n:游艇,下水",
"launch pad":"n:发射台",
"launcher":"n:发射器,弹弓,运载火箭",
"launching":"n:发射,开办;v:发射",
"launching pad":"n:发射台",
"launder":"v:洗,烫,贪污,侵吞;n:导管,渡槽",
"laundering":"v:洗涤",
"laundry":"n:洗衣店,洗衣房,洗衣",
"laurel":"n:月桂,荣誉,桂冠,月桂树,胜利,殊荣,光荣,桂",
"laurel wreath":"n:桂冠",
"lav":"n:厕所,盥洗室",
"lava":"n:熔岩,火山岩",
"lavage":"n:灌肠,洗胃;v:洗胃",
"lavatory":"n:厕所,抽水马桶,洗脸盆,厕;v:洗涤",
"lave":"v:冲刷",
"lavish":"v:挥霍,浪费;a:大手大脚,阔气",
"law":"n:法律,定律,规律,法规,法令,警察,法则,律师,法学,法,国法,则,诉讼,定理,法典,律令,律;v:辟,控告",
"law officer":"n:检察长,司法官",
"law-abiding":"a:安分",
"lawbreaking":"n:犯法,违法",
"lawful":"a:合法,法定",
"lawless":"a:不法,暗无天日",
"lawlessness":"n:暗无天日",
"lawmaking":"n:立法",
"lawn":"n:草坪,草地,草场,细布,空地,平地",
"lawn mower":"n:剪草机",
"lawnmower":"n:放大器",
"lawrencium":"n:铹",
"lawsuit":"n:诉讼,官司,狱,辞讼",
"lawyer":"n:律师",
"lax":"a:松,松弛,涣散;v:腹泻",
"laxative":"n:泻药",
"laxity":"n:疏松,疏忽,松弛",
"lay":"v:放,下,铺设,安排,准备,解雇,铺,下蛋,产卵,献出,布置,打倒,搁,休息,砌砖,打赌,痛斥,贮存,安放,葬,搁置,摆,积蓄,停止,砍,设计,发现,涂,埋,搓,平息,编,划定,归罪,击倒,储存,敷设,展开,放置;n:层,方向,歌曲,方针,价格,职业,代价,民谣,外行;a:俗",
"lay aside":"v:闲置,积蓄,放置,贮,搁,搁置,贮备",
"lay away":"v:积蓄",
"lay down":"v:交出,献出,主张,规定,致,设计,卸,兴建,偃",
"lay eyes on":"v:看到",
"lay hands on":"v:抓住,袭击,占有",
"lay in":"v:储备,收藏,储存,贮藏",
"lay into":"v:痛斥,痛打",
"lay off":"v:停歇,停止,休息,关闭,解雇",
"lay out":"v:布置,陈设,划定,布局,敷,地形,事态,投资,编排,安排,陈列,花费,情况,部署,尸,展开,陈",
"lay over":"v:覆盖,胜过",
"lay up":"v:储备,贮存,储蓄,宴,储存,放置,卧床不起,积存",
"layer":"n:层,膜,地层,涂层,蛋鸡,阶层;v:压条,压枝",
"layered":"v:重重",
"layering":"v:压条;n:压条",
"layette":"n:套服",
"laying":"n:铺设,下蛋,瞄准,布置;v:瞄准,铺设",
"layman":"n:外行,门外汉,力巴,凡人",
"laymen":"n:外行",
"layoff":"n:解雇",
"layout":"n:布局,版面,布置,设计,电路图,安排,格式,形式,执行;v:设计,布置,实行,执行",
"laze":"v:偷懒,混日子;n:懒散",
"laziness":"n:懒惰,偷懒",
"lazy":"a:懒,懒惰,懒洋洋,怠惰;v:懒惰",
"lazybones":"n:懒汉,懒骨头",
"le":"n:乐",
"lea":"n:草地,牧场",
"leach":"v:溶解,滤,过滤,溶化",
"lead":"v:导致;n:矿脉,首位,引导,导言,枪弹,石墨,头部,引信;a:头",
"lead line":"v:铅垂线",
"lead off":"v:宣泄,开端,宣,开头",
"lead ore":"v:铅矿",
"lead up":"v:通向,升腾",
"leader":"n:领袖,领导人,领导,首领,领导者,长,导火线,主干,上级,首长,围墙,带头人,筋,头脑,主脑,引线,字幕,社论,头头儿,主机,长机,导管,魁首,首",
"leadership":"n:领导,领导权,指导",
"leading":"n:大家,铅条,主导,领导,指导,引导;a:超前",
"leading edge":"n:前缘,前沿",
"leading light":"n:主脑,台柱子",
"leaf":"n:树叶,叶子,叶,茶叶,花瓣,叶鞘,箔,天窗,贝叶树,簧片,扇,页,烟叶",
"leaf blade":"n:嫩叶,叶片",
"leaf lard":"n:板油",
"leaf mustard":"n:盖菜",
"leafage":"n:树叶",
"leafing":"v:漂浮",
"leaflet":"n:传单,活页,广告,小叶,嫩叶;a:活页",
"league":"n:联盟;v:结盟",
"league of nations":"n:国际联盟,国联",
"leak":"v:泄露;n:漏孔,罅漏",
"leak out":"v:泄露,透,漏光",
"leakage":"n:漏,漏电;v:泄露,泄漏",
"leakiness":"v:泄漏;n:泄漏",
"lean":"v:倚,倾斜;n:斜坡;a:清瘦,清癯",
"lean against":"v:靠,凭,把,倚靠",
"lean on":"v:倚,把,趴,凭,拄",
"leaning":"n:倾向,倾斜;v:偏",
"leanness":"n:贫瘠",
"leap":"v:跳;n:跃进",
"leap day":"n:闰日",
"leapfrog":"v:越过",
"leapfrogging":"v:勘探,间断",
"learn":"v:学会,学,学习,知道,记住,听到,获知,入门,悉,知悉,闻讯,探悉",
"learned":"a:博学,博雅,饱学;v:陆海潘江",
"learner":"n:初学者",
"learning":"n:学问,学习,学识,知识,学,学术,墨",
"lease":"v:租,出租;n:租契",
"leaseholder":"n:租户",
"leash":"n:束缚,控制;v:控制,束缚",
"leasing":"n:谎话,虚伪",
"least":"d:非常,最,很",
"least common multiple":"n:最小公倍数",
"leastwise":"d:至少",
"leather":"n:皮革,皮,皮子;v:抽打",
"leatherette":"n:人造革",
"leathery":"a:艮",
"leave":"v:离开,走,留下,去,留,剩下,离去,别,动身,离,留给,剩,下,落,遗留;n:同意;f:之",
"leave behind":"v:留下,贻,撂,闪,留,遗,抛,扔下,丢失",
"leave of absence":"n:假",
"leave off":"v:戒除,脱掉,宣泄,停止",
"leave office":"v:下台,离职",
"leave out":"v:删略,省,删除,省略,落,漏,略,删汰,删",
"leave-taking":"n:告别,告辞",
"leaven":"n:影响力;v:发酵",
"leaves":"v:离开;n:叶",
"leaving":"v:残余,剩余",
"leavings":"n:渣滓",
"lebanon":"n:黎巴嫩",
"lech":"n:淫欲,色鬼;v:贪求;a:好色",
"lechery":"n:好色,淫荡",
"lecithin":"n:卵磷脂",
"lecture":"v:讲,讲演,讲课;n:训斥",
"lecture room":"n:讲堂",
"lecturer":"n:讲师",
"ledge":"n:檐,暗礁,矿脉,突起",
"ledger":"n:总账,分类账,底账,底板",
"lee":"n:李,背风处,下风,庇护,庇护所",
"leech":"n:马鳖,吸血鬼,高利贷,水蛭,医师,蚂蟥",
"leek":"n:韭菜,葱绿;a:葱绿",
"leer":"v:暗送秋波;n:斜视",
"leery":"a:机敏",
"lees":"n:沉积物,渣滓,残渣",
"leeward":"n:下风;a:背风",
"leeway":"n:余地,余裕,落后,偏差,灵活性,退路,退步;v:退步",
"left":"a:极左",
"left hand":"n:左手,左侧",
"left-hand":"a:左边",
"left-hander":"n:左撇子",
"leftist":"n:左派,急进派",
"leftover":"n:剩饭",
"leftovers":"n:残羹,残羹剩饭,剩饭",
"lefty":"n:左撇子",
"leg":"n:腿,脚,大腿,足;v:奔走",
"leg-pull":"n:恶作剧",
"legacy":"n:遗产,遗赠,衣钵;v:遗赠",
"legal":"a:法律,合法,法定",
"legal action":"n:诉讼",
"legal holiday":"n:例假",
"legal power":"n:权限",
"legal principle":"n:法理",
"legal right":"n:权益",
"legalisation":"n:合法",
"legalise":"v:合法化",
"legalism":"n:形式主义,文牍主义",
"legality":"n:合法性,合法,法制",
"legalization":"n:批准,合法化,合法",
"legalize":"v:合法化,公认",
"legate":"v:遗赠;n:使节",
"legation":"n:公使馆,馆",
"legend":"n:传说,传奇,神话,铭文,题跋,图例",
"legendary":"a:传说",
"legerdemain":"n:花招,骗术,戏法,手法",
"legging":"n:护腿",
"leggings":"n:护腿,套裤,绑腿",
"leghorn":"n:来亨鸡",
"legibility":"n:清晰度",
"legible":"a:清楚",
"legion":"n:大批,军团,众多;a:众多",
"legislate":"v:立法",
"legislation":"n:立法,法律;v:立法",
"legislative":"n:立法权",
"legislator":"n:议员,立法委员",
"legislature":"n:议会",
"legitimacy":"n:合法性,正统,嫡系,合法",
"legitimate":"a:合法",
"legitimization":"n:合法化",
"legman":"n:外勤",
"legs":"n:下肢",
"legume":"n:豆类,豆,豆荚,荚果",
"legumes":"n:豆",
"legwork":"n:外勤",
"lei":"n:花环,雷",
"leigh":"n:利",
"leipzig":"n:莱比锡",
"leisure":"n:闲暇,空闲,闲工夫,闲,空暇,悠闲,暇,安逸,余暇,遑,余闲,嚣,工夫,闲空,逸,佚",
"leisure time":"n:余暇",
"leisureliness":"n:从容",
"leisurely":"a:悠悠,安闲,从容,慢条斯理,从容不迫,款,悠,优柔,逍遥,舒缓;d:慢慢,慢条斯理,从容不迫,悠然",
"lemma":"n:主题,题词,题目",
"lemna minor":"n:浮萍",
"lemon":"n:柠檬",
"lemon oil":"n:柠檬油",
"lemon yellow":"n:柠檬色",
"lemonade":"n:柠檬水",
"lemongrass":"n:香茅",
"lena":"n:勒拿河",
"lend":"v:借给,借,贷款,提供,出借,贷与,出租;n:贷款",
"lend-lease":"n:租借",
"lender":"n:贷方",
"lending":"v:附属物",
"length":"n:长度,长,长短,篇幅,范围,期间;v:截",
"lengthen":"v:伸长,延长,拉长,延伸",
"lengthiness":"n:冗长",
"lengthwise":"a:纵",
"lengthy":"a:冗长",
"lenience":"n:宽厚,宽大,怜悯",
"leniency":"n:宽大,宽厚;a:宽大",
"lenient":"a:宽大为怀,宽厚,宽,宽大,宽容",
"lenin":"n:列宁",
"leningrad":"n:列宁格勒",
"leninism":"n:列宁主义",
"lens":"n:透镜,镜头,晶状体,晶体,镜片,镜,隐形眼镜",
"lent":"n:斋期",
"lentil":"n:晶状体",
"leonine":"a:狮子",
"leopard":"n:豹,豹子,金钱豹",
"leopard cat":"n:狸,狸猫",
"leotard":"n:紧身衣",
"leprechaun":"n:妖精",
"leprosy":"n:麻风病,癞病,麻风,麻,疠",
"lesion":"n:病变,损害,损伤,缺陷;v:损害,损伤",
"lesotho":"n:莱索托",
"less":"a:不足,少;n:残渣;p:减去",
"lessee":"n:承租人,租户",
"lessen":"v:减少,轻视,缩小,看不起,贬低,掉",
"lessening":"v:降低,减少,缩减",
"lesser duckweed":"n:浮萍",
"lesser panda":"n:小猫熊",
"lesson":"n:课,教训,功课,课程,借鉴,训诫;v:训斥",
"lessons":"n:功课,课业",
"lessor":"n:出租人",
"lest":"c:免得,生怕,唯恐,以免;v:惟恐",
"let":"v:让,给,放,使,走,租,泄露,出租,放过,任,容许,假设,释放,听任,发泄,放掉,放出,泄漏,使得,辜负,松懈,熄灭,假定;n:假定,阻碍,障碍",
"let alone":"v:而况,俜,别说,放任",
"let down":"a:放下,松劲,对不住,辜负;v:辜负",
"let go":"v:纵,放走,撒,放,松手,脱落,放手,释放,释",
"let go of":"v:释放",
"let in":"v:插入,通",
"let loose":"n:放出",
"let off":"v:发泄,放掉,放过,阻断,免除,不问,排泄,熄灭",
"let on":"v:泄漏",
"let out":"v:捅,透,渫,出租,放出,释放,撒,泄,租,放,放大,散,泄露,走",
"let up":"v:停顿,松懈",
"letch":"n:泥塘",
"letdown":"n:失望,松劲,减少,减退,下降,减低,松弛",
"lethal":"v:致死,致命;a:致命,致死",
"lethality":"n:杀伤力",
"lethargic":"a:不死不活,慵,昏沉,暮气沉沉",
"lethargy":"n:懒散,麻木不仁,暮气,呆滞,没精打采,暮霭,昏睡",
"lethe":"n:遗忘",
"letter":"n:信,信件,字母,书信,书,函,字面,信函,件,文学,形式,信札,文字,札,学问,铅字,书函,来书,许可证,活字,简帖;v:笺,启",
"letter box":"n:信筒",
"letter of credit":"n:信用证",
"letter of intent":"n:意向书",
"letter writer":"n:尺牍",
"letterbox":"n:邮箱,信箱",
"lettering":"n:写字,刻字;v:刻字",
"letterpress":"n:活版",
"letters":"n:函件,信札,书牍,书简,书札",
"letting down":"n:回火,下滑",
"lettuce":"n:莴苣,生菜",
"letup":"n:休息,停止,中止",
"leukaemia":"n:白血病",
"leukemia":"n:白血病,血癌",
"leukocyte":"n:白细胞,白血球",
"levee":"n:防洪堤,接见,码头;v:筑堤",
"level":"n:水平,程度,能级,高度,等级,电平;v:推倒;a:水平;d:一直,准确",
"level crossing":"v:道口,岔口",
"leveling":"v:均衡,平整,矫正;n:平整",
"levelling":"v:平整,均衡",
"lever":"n:杆,手段,杠杆,杠",
"leverage":"n:影响,力量,势力",
"leviathan":"n:庞然大物",
"levitation":"n:轻浮,升空;v:升空",
"levity":"n:轻浮,变化无常,轻率",
"levy":"v:扣押,征税,征收,征集;n:课,募集,召集,征税",
"lewd":"a:淫荡,淫",
"lewdness":"n:淫荡",
"lewis":"n:刘易斯,地脚螺栓",
"lexeme":"n:词素",
"lexicography":"n:词典,词典学",
"lexicon":"n:简编,字汇,字书,词典,词库,辞典,概要",
"lhasa":"n:拉萨",
"li":"n:莉,黎",
"liabilities":"n:债务,负债",
"liability":"n:责任,债务,负债,义务",
"liable":"a:容易,大概,多半",
"liaison":"n:联络,私通,奸;a:奸",
"liana":"n:蔓生植物,藤本植物",
"liao":"n:廖",
"lib":"n:解放,千克",
"libation":"n:酒,饮料",
"libel":"v:诬蔑,诽谤,污蔑,控诉;n:侮辱",
"liberal":"a:开明,大方,优厚,慷慨,优,开通,宽大为怀",
"liberalism":"n:自由主义",
"liberality":"n:慷慨,磊落,丰满,公平,礼物,充足;a:宽阔,充足",
"liberalization":"n:自由化",
"liberate":"v:解放,释放,解除,放出",
"liberation":"n:解放,放出,释放,析出",
"liberator":"n:救星",
"liberia":"n:利比里亚",
"libertine":"n:浪子",
"liberty":"n:自由,冒昧,释放,自由权,无礼,范围;a:自由",
"libido":"n:性欲",
"libra":"n:天秤座",
"library":"n:图书馆,藏书,图书室,丛书,文库",
"librettist":"n:剧作者",
"libretto":"n:唱词,剧本",
"librium":"n:利眠宁",
"libya":"n:利比亚",
"lice":"n:虱子",
"licence":"n:破格,特许,放纵,凭照",
"license":"n:执照;v:照",
"licentiate":"n:硕士",
"licentious":"a:淫荡,淫乱,猖,淫,荒淫",
"lichen":"n:地衣,苔藓",
"licit":"a:合法",
"lick":"v:舔,舐,打败,吞没,一扫而光;n:些许,速度,少量",
"licorice":"n:甘草",
"lid":"n:盖子,盖,瓶盖,锅盖,眼睑,帽子,制止,取缔",
"lie":"v:在,躺,撒谎,有;n:状态,巢",
"lie about":"v:谎报,谎称",
"lie down":"v:倒头,倒卧,屈服,小憩,小睡,死亡,顺从,躺倒,趴下",
"lie in":"v:待产,在",
"lie in wait":"v:埋伏",
"lie low":"v:避风,埋伏,隐匿,敛迹,大败",
"lie with":"v:在于",
"lie-in":"n:坐月子",
"liechtenstein":"n:列支敦士登",
"lief":"d:欣然",
"liege":"n:君主,王侯",
"lien":"n:优先权",
"lies":"v:诳",
"lieu":"n:代替,场所,处所",
"lieutenant":"n:副官",
"lieutenant colonel":"n:中校",
"lieutenant commander":"n:少校",
"lieutenant general":"n:中将",
"life":"n:生活,生命,一生,人生,日子,命,性命,生,生物,寿命,生平,生气,传记,生命力,生机,身,春,尘世,活命,生计,世,弹性,精华,寿,日月,世面",
"life assurance":"n:人寿保险",
"life belt":"n:安全带,救生带",
"life insurance":"n:人寿保险",
"life jacket":"n:救生衣",
"life line":"n:安全线",
"life preserver":"n:救生衣,救生圈",
"life raft":"n:救生筏",
"life saver":"n:救生员",
"life sentence":"n:无期徒刑",
"life-and-death":"a:殊死",
"life-or-death":"a:你死我活",
"lifeblood":"n:生命线,命脉,命根子,命根,血液",
"lifeboat":"n:救生艇,救生船",
"lifeguard":"n:救生员,保镖",
"lifeless":"a:有气无力,暮气沉沉,呆滞,死气沉沉,不死不活",
"lifelessly":"d:有气无力",
"lifelike":"a:栩栩如生,传神,活灵活现,逼真",
"lifeline":"n:生命线,命脉",
"lifelong":"a:终身,毕生;n:终身",
"lifer":"n:无期徒刑",
"lifesaving":"n:救生",
"lifetime":"n:一生,寿命,毕生,终身,终生,辈,世,辈子",
"lift":"v:抬,举,举起,抬起,提,提起,解除,消散,掀起,剽窃,隆起,偷窃,提升,提高,升空,拎,掀动,水涨船高,起飞,抄;n:举起,吊车,抬高",
"lift off":"v:升空,升起,起飞",
"lift out":"v:举起",
"lift up":"v:祛,竖起,撩,跷,褰,抬,搴,挑,骞,擎",
"lifter":"n:起重机,升降机",
"lifting":"v:提升,隆起;n:举起,上升",
"liftoff":"n:发射,起飞;v:发射",
"ligament":"n:韧带,胸膜,带",
"ligate":"v:结扎,绑,绑扎",
"ligation":"n:绑扎,结扎;v:结扎",
"ligature":"n:结扎,带子;v:结扎,捆绑,绑扎",
"light":"n:光,灯,光线;a:微;v:点燃",
"light beam":"n:光束",
"light breeze":"n:微风,轻风",
"light brown":"v:棕黄",
"light bulb":"n:灯泡",
"light filter":"n:滤光器",
"light intensity":"n:亮度",
"light machine gun":"v:轻机枪",
"light up":"v:烛,点燃,照射,照亮,上灯,照",
"light upon":"n:碰见",
"light-year":"n:光年",
"lighten":"v:减轻,照亮,缓和,发亮,打闪,点火,减少",
"lightening":"v:发光,打闪;n:闪电",
"lighter":"n:打火机,驳船,点火器,自来火;v:驳运",
"lighthearted":"a:兴高采烈",
"lighthouse":"n:灯塔",
"lighting":"n:灯光,照明;v:点燃,采光",
"lightly":"d:轻轻,轻易,轻,清爽,翩然",
"lightness":"n:轻松,轻浮,明亮,轻,轻盈,愉快,敏捷,优美,轻率,机敏,清淡,精巧",
"lightning":"n:电闪,打闪;v:打闪",
"lightning arrester":"n:避雷器,避雷针",
"lights":"n:灯火",
"ligneous":"a:木本",
"lignite":"n:褐煤",
"likability":"n:可爱",
"likable":"a:可爱,讨人喜欢;v:讨人喜欢",
"like":"v:喜欢;p:不啻;d:简直,恰如,似乎,多半,宛如,犹如;a:简直;c:如同;n:爱好",
"like a shot":"p:立刻",
"like in":"p:同_一样,一样",
"like mad":"v:没命",
"likelihood":"n:可能,可能性,样子,希望,前途",
"likely":"a:容易;d:大概",
"liken":"v:比作,比拟",
"likeness":"n:像,相似,画像,相象,肖像,类似,形状,外表",
"likewise":"d:也,而且",
"liking":"n:喜欢,胃口,爱好,嗜好,欢心,趣味,兴趣",
"lilac":"n:紫丁香,丁香花,丁香",
"lilliputian":"n:矮子",
"lilongwe":"n:利隆圭",
"lilt":"n:韵律,节;v:欢唱",
"lily":"n:百合花,百合;a:洁白",
"lima":"n:利马",
"lima bean":"n:青豆,胡豆",
"limb":"n:四肢,肢体,手足,边缘,翼,枝干,肢,叶片,分支,支流,子句;v:肢解,插脚",
"limber":"n:拖车,车轴,前车",
"limberness":"n:可塑性",
"limbo":"n:拘禁,冷宫,监牢",
"limbs":"n:肢体,四肢",
"lime":"n:石灰,灰,白灰",
"lime tree":"n:椴树",
"limeade":"n:柠檬水",
"limekiln":"n:石灰窑",
"limes":"n:境界",
"limestone":"n:石灰石,石灰岩",
"limit":"n:限度,极限,范围,限制,界限;v:穷尽,拘囿,拘管;a:野",
"limitation":"n:限制,局限性,限度,局限,界限,时效,极限",
"limited":"a:有限,管,浅薄",
"limited company":"n:有限公司",
"limitless":"a:无限,无边无际,无疆,无际,漫无边际,漫天",
"limn":"v:描写,勾划,描画",
"limousine":"n:轿车,卧车,蹒跚",
"limp":"a:酥,酥软,松弛;v:拐,蹒跚",
"limpid":"a:清澈,清晰,浏,湛,盈盈,清亮,澈",
"limpidity":"n:清澈",
"limping":"v:磕磕绊绊",
"lin":"n:林",
"linchpin":"n:关键,辖;v:辖",
"lincoln":"n:林肯",
"linden":"n:菩提树,椴木,椴树,椴",
"lindsay":"n:林赛",
"line":"n:线,线路,行,直线,一行,线条,路线,排,钓丝,方法,队;v:交尾,溜,整顿,勾脸,站队",
"line feed":"n:换行符",
"line of business":"n:业,行,行当",
"line of reasoning":"n:立论",
"line of thought":"n:思路",
"line of vision":"n:视线",
"line up":"v:列队,站队,整顿,列",
"lineage":"n:血统,世系,门第",
"lineal":"a:子孙",
"lineament":"n:轮廓,面貌,特征",
"linear":"a:线性,线形;n:线性",
"linear equation":"n:线性方程",
"linear measure":"n:度",
"linear programming":"n:线性规划",
"linearity":"n:线性",
"lined":"v:夹",
"linen":"n:亚麻布,麻布",
"liner":"n:班轮,衬,衬套,邮船,班机,里,衬垫,衬里,瓶胆,套筒",
"lines":"n:纹,纹路,纹理,线条,皱纹",
"linesman":"n:养路工,列兵,司线员",
"lineup":"n:阵容",
"ling":"n:鳕鱼,菱,菱角",
"linger":"v:徘徊,逗留,拖延,萦绕,萦回,盘旋,流连,滞留,流连忘返,盘桓,袅袅",
"lingering":"v:滞留;a:缠绵",
"lingo":"n:方言,隐语",
"lingual":"n:舌音",
"linguistic":"a:语言",
"linguistics":"n:语言学",
"lining":"n:衬里,里,衬,衬垫,衬套,衬纸,隔板,套筒;v:衬",
"link":"v:联系,连接;n:衔接",
"link up":"v:连贯,连结,衔接,连接,联合,串联,联系,沟通,会合,贯通",
"linkage":"n:连接,连锁,联系;v:连接,连锁",
"linking":"v:耦合;n:结合",
"linking verb":"n:系词",
"linkman":"n:中间人,中介",
"links":"n:关节,球场",
"linkup":"n:连接,联系",
"linoleum":"n:油毡,漆布",
"linseed":"n:麻子",
"linsey-woolsey":"n:胡话",
"lint":"n:皮棉,绒布,棉绒,皮花",
"lintel":"n:楣",
"lion":"n:狮子,狮,名人,狻猊",
"lioness":"n:母狮",
"lionize":"v:奉承,树碑立传",
"lip":"n:嘴唇,唇,边,嘴皮子;v:冲刷",
"lip rouge":"n:口红",
"lip service":"n:空头支票,门面话,耍嘴皮子,空话",
"lipase":"n:脂肪酶",
"lips":"n:唇吻,嘴皮子;v:吻",
"lipstick":"n:口红,唇膏",
"liquefaction":"v:液化;n:液化",
"liquefy":"v:液化,融解",
"liquefying":"v:液化",
"liqueur":"n:甜酒",
"liquid":"n:液体;a:流质",
"liquid crystal":"n:液晶",
"liquidate":"v:清偿,杀掉,勾销,了结,清理,破产,清除,收盘,除掉,廓清,清算,结束,消灭",
"liquidation":"n:清算,清理,杀掉;v:液化",
"liquidise":"v:液化",
"liquidity":"n:流畅",
"liquor":"n:酒,溶液,液体,白酒,烧酒,白干儿,液",
"liquor store":"n:酒吧",
"liquorice":"n:甘草",
"lira":"n:里拉,条纹,皱纹",
"lire":"n:里拉",
"lisbon":"n:里斯本",
"lisp":"v:咬舌儿,咬舌;n:咬舌儿",
"lisper":"n:大舌头,咬舌儿",
"list":"n:名单,表,单子;v:入伍,历数",
"list price":"n:定价",
"listen":"v:听,听到;n:倾听",
"listen in":"v:听到,偷听",
"listener":"n:听众,接收者",
"listeners":"n:听众",
"listening":"v:倾听",
"listing":"n:列表,表册,编目,清单;v:列表",
"listless":"a:懒洋洋,蔫,颓丧,不得劲,委,委靡,没头没脑,萎靡,颓,蔫蔫;v:无精打采;n:懒洋洋",
"listlessly":"d:浑浑噩噩",
"litchi":"n:荔枝",
"liter":"n:升,公升",
"literacy":"n:文化,识字",
"literal":"n:精确,字面,实际;a:逐字",
"literalism":"n:直译,写实主义",
"literally":"d:确实,简直,真正,完全",
"literariness":"n:文学性,文艺性",
"literary composition":"n:构,文",
"literary work":"n:手笔",
"literate":"a:识字,识文断字",
"literati":"n:文人,知识界,文学家",
"literature":"n:文学,文献,著作,书籍,印刷品,学识,学问",
"lithe":"a:柔软,轻盈,绵",
"lithium":"n:锂",
"lithography":"n:石印",
"lithology":"n:岩石学",
"lithosphere":"n:地壳",
"lithuania":"n:立陶宛",
"litigant":"n:当事人",
"litigate":"v:打官司,诉讼,争论",
"litigation":"n:起诉,打官司,诉讼",
"litmus":"n:石蕊",
"litter":"n:废物,窝,杂乱,轿子,担架,垫圈,废纸",
"little":"a:小,少;n:些许,点儿,少许;d:稍",
"little brother":"n:小弟",
"little by little":"n:逐渐,渐渐,浸,缓缓",
"little finger":"n:小指",
"little girl":"n:毛丫头",
"little rock":"n:小石城",
"little short of":"p:差不多,近乎,几乎",
"littleness":"n:少量,吝啬,些许,小",
"littoral":"n:沿岸,沿海,海滨;a:沿岸",
"livability":"n:存活率",
"live":"v:住,生活,过,活,居住,吃,生存,过日子,生,度过,相处,处,过活,依靠,居,实践,存,处世,实行,住家,容忍,盼望,身体力行,生息,集居,寓居,住居,聚居,立;a:活活",
"live oak":"v:槲栎",
"live on":"v:吃,依靠",
"live out":"v:实践,身体力行",
"live together":"v:聚居,同居,集居,相处",
"live up to":"v:遵守,符合",
"live wire":"v:火线",
"live with":"v:容忍",
"livelihood":"n:生计,生活,日子,生,日月",
"liveliness":"n:活泼,生动,鲜明,快活,强烈,热闹",
"lively":"a:活泼,生动,活跃,精神,轻快,热闹,活,绘声绘色,眉飞色舞,欢快,火炽;d:绘声绘色",
"liven":"v:愉快",
"liven up":"v:热闹",
"liver":"n:肝脏,肝,赤褐色,肝部,肝儿",
"liver fluke":"n:肝吸虫,肝蛭",
"liver spot":"n:雀斑,褐黄斑",
"liverpool":"n:利物浦",
"liverwort":"n:地钱",
"livery":"n:制服,号衣,侍从,仆从",
"liveryman":"n:侍从,仆从",
"lives":"n:生命;v:住",
"livestock":"n:牲畜,家畜,畜",
"livid":"a:铁青",
"living":"a:活活;n:生存,财产;v:活活",
"living death":"n:人间地狱,活受罪",
"living quarters":"n:宿舍",
"living room":"n:起居室,居室",
"living thing":"n:生物",
"lizard":"n:蜥蜴,壁虎,四脚蛇",
"load":"n:载荷,负荷,荷载;v:负重,分装,负,装填,载重,担负,装满,上车,载,装料",
"load down":"v:满载",
"load up":"v:装满",
"loaded down":"a:重载",
"loading":"n:载荷,装货,荷重,重量,装载量;v:装运,装货,装载,装填",
"loaf":"v:闲荡;n:混日子",
"loafer":"n:浪子,无赖,流氓,二流子",
"loam":"n:壤土",
"loan":"n:贷款,借款,贷,债,出借;v:放款,借贷,借款,贷,借调",
"loan office":"n:当铺",
"loaner":"n:债权人",
"loanword":"n:借词,外来词,外来语",
"loath":"a:不愿,讨厌,厌恶",
"loathe":"v:讨厌,厌恶,憎恶,憎恨,憎厌,鄙弃,腻烦,嫌恶;a:恶",
"loathing":"n:厌恶,憎恨",
"loathsome":"a:作呕,丑,可恶;v:作呕",
"lobbing":"v:打滑",
"lobby":"n:门厅;v:游说",
"lobbyist":"n:说客",
"lobe":"n:叶,裂片,瓣,耳垂",
"lobster":"n:龙虾,傻子",
"local":"n:地方,当地人,当地,慢车,乡土;a:土,本埠;r:本埠",
"local time":"n:地方时",
"locale":"n:场所,地点",
"locality":"n:地区,地方,地点,位置,地,方,场所,环境,局部,方向",
"localization":"n:定位,局限,立体声,部位,地址;v:探测,局限",
"localize":"v:集中,局限,定位",
"locally":"d:就地",
"locate":"v:位于,定居,计划,住,出租,设计",
"located":"a:位于",
"locating":"v:定位;n:定位",
"location":"n:位置,单元,地址,设计,地点,定位,部位,测量,场所,位,处所,所在地,出租,址,所在;v:寻找",
"loch":"n:海湾,湖",
"loci":"n:位置,地点",
"lock":"v:锁,锁上,上锁,把,卡住;n:同步,缕,刹车,栓",
"lock in":"n:锁定",
"lock out":"v:闭锁,封锁",
"lock up":"v:关押,圈,关禁闭,封锁,钤,关,监禁,锁",
"locker":"n:橱柜,库房,抽屉",
"locker room":"n:更衣室",
"locking":"v:锁定",
"lockjaw":"n:破伤风",
"lockout":"n:锁定,闭门羹",
"locksmith":"n:锁匠",
"lockup":"n:拘留所,闭,锁,监狱",
"loco":"n:火车头,疯子,机车",
"locomotion":"n:运动,旅行,动作,移动,位移",
"locomotive":"n:机车,火车头;a:机动",
"locomotive engine":"n:火车头,机车",
"locus":"n:位置,所在地,轨迹,场所,地点,章节,座位,段落",
"locust":"n:蝗虫,蚂蚱,蝉,刺槐,蝗,蛩,洋槐,蚱蜢",
"locust bean":"n:槐豆",
"locust tree":"n:槐树",
"locution":"n:惯用语,语法,成语",
"lode":"n:矿脉",
"lodestar":"n:北极星",
"lodestone":"n:磁石,吸铁石",
"lodge":"v:提出,寄宿,住宿,住,留宿;n:旅店,窝,支部,理事,帐篷,客栈",
"lodger":"n:房客",
"lodging":"n:寄宿,住处;v:倒伏,住宿",
"lodgings":"n:住所,住房",
"loft":"n:阁楼;v:发射,抛掷",
"loftily":"d:傲然",
"loftiness":"n:高傲",
"lofty":"a:崇高,高,巍峨,巍巍,高耸,高尚,嵩,巍,傲然,崇,崔巍,岌,峨,阆,轩,高超,高大,嵬,岸,突兀;d:巍然;n:崔巍;v:突兀",
"log":"n:木头,原木;v:拖,采伐",
"log cabin":"n:木屋",
"log in":"v:登录",
"log off":"v:注销,退出",
"log out":"v:退出",
"logarithm":"n:对数",
"logarithmic scale":"n:计算尺",
"logarithms":"n:对数",
"logbook":"n:记录本",
"loge":"n:包厢,小屋",
"logger":"n:记录器",
"loggerhead":"n:傻瓜,傻子",
"logging":"n:存入,伐木,记录;v:存入,采伐",
"logic":"n:逻辑,推理,逻辑性,逻辑学,压力,眉目,理路,路,威力,事理,理,论理",
"logical":"a:顺理成章;v:顺理成章",
"logical thinking":"n:常理",
"logicality":"n:逻辑性",
"logistics":"n:后勤,逻辑学",
"logjam":"n:僵局",
"logo":"n:标语,图形,商标",
"logos":"n:道,理性,理念",
"logotype":"n:标识",
"logrolling":"n:支援,合作,互助;v:互助",
"loin":"n:腰,腰部",
"loins":"n:腰,腰部",
"loiter":"v:闲逛,游荡,耽搁,游手好闲,蹭,荡,混日子,浪荡,悠悠忽忽,漫步,逛荡",
"loitering":"v:悠悠忽忽,悠忽",
"loll":"v:闲荡,伸出,搭拉,下垂",
"lollipop":"n:糖果,棒棒糖,棒冰",
"lombard":"n:当铺,银行家",
"lome":"n:洛美",
"london":"n:伦敦",
"lone":"a:孤零零,孤独,匹,孤苦伶仃",
"loneliness":"n:孤寂,孤单",
"lonely":"a:寂寞,孤独,孤寂,僻静,孤单,冷清,只,岑寂,冷冷清清,孑,孤,落寞,孤身,寞,寂,孑然,落漠;n:寡人",
"lonesome":"a:寂寞,孤独,寂寥,寂然;n:自己",
"long":"v:渴望;a:悠然,悠悠,绵长;d:老;n:长裤,多头",
"long ago":"a:久已,早,悠远,早已",
"long bone":"n:长骨",
"long distance":"n:远距离",
"long haul":"n:长距离",
"long shot":"n:远景",
"long since":"v:就",
"long suit":"n:长处",
"long time":"n:年头,许久",
"long-distance":"a:长途",
"long-distance call":"n:长途电话",
"long-horned grasshopper":"n:蝈蝈,蝈蝈儿,螽斯",
"long-range":"a:远程",
"long-term":"a:长期,长远",
"longevity":"n:寿命,长寿,寿,资历,高寿",
"longing":"n:渴望,热望,欲",
"longitude":"n:经度;p:经",
"longitudinal":"a:纵向,纵;n:纵向",
"longsighted":"a:远视",
"look":"v:看,找,显得,瞧,寻找,好像;n:形,神采",
"look after":"v:陪,照,目送,照护,操劳,照拂,看管,照顾,照料,寻找,带,关照,看护,侍候",
"look around":"v:参观,瞿,查看,环顾,环视",
"look at":"v:瞅,顾,考察,睐,观览,考虑,呶,观,视",
"look back":"v:顾,追忆,眷,回首,回顾",
"look down on":"v:贱视,看不起",
"look for":"v:搜寻,淘换,物色,寻觅,寻摸,寻访,找,找寻",
"look forward":"v:期待",
"look into":"v:查看,查,窥视,找,检查,追,参观,追究",
"look like":"v:似,意思,随",
"look on":"v:旁观,隔岸观火,看待,观望,面向,看热闹",
"look out":"v:哎,留神,注意,仔细,挑选",
"look sharp":"v:当心,留神",
"look to":"v:指靠,期待,照顾,注意,面向,依赖,指望",
"look up":"v:检查,瞻,查阅,好转,仰视,查,看望,探望,查看",
"look up to":"v:瞧得起,仰慕,想望,仰望,企慕,慕,仰,尊敬",
"look upon":"v:看待,看,认为,视",
"look-over":"n:检查",
"looker":"n:检查员",
"looker-on":"n:旁观者",
"lookout":"n:监视哨,了望台,注意;v:眺望",
"looks":"n:面貌,相貌,相,貌,天资,形相,眉目,容貌,仪容,眉眼,姿容,长相,外貌,品貌,人品,容颜",
"loom":"n:织布机,织机,机杼,机子",
"loon":"n:疯子,废物,小伙子,妓女,愚人,狂人;v:闲荡",
"loony bin":"n:疯人院",
"loop":"n:环,回路,循环,匝,筋斗,圈,线圈,套,框,环路;v:循环,兜圈子,翻筋斗",
"loop-line":"n:铁路,环线",
"looped":"v:尺蠖",
"loophole":"n:漏洞,缺口,窥孔,枪眼,隙,漏子,借口",
"loose":"a:松,松散,疏松,松开,肥大,荒唐,活络,松软;v:放松,解,开枪,释放,开船,放射,松弛,放,松开,放掉;n:发射,放任,解放",
"loose woman":"n:破鞋",
"loosely":"d:松散",
"loosen":"v:松开,放松,松,解开,松动,疏松,松散,弛,宽松,释放",
"loosened":"v:松动",
"looseness":"n:松弛",
"loosening":"n:松动;v:松懈",
"loot":"v:抢劫,抢走,劫掠,洗劫,抢掠;n:不义之财",
"lop":"v:斩断,割断,砍伐,伐,低垂,割裂,剪枝,砍,删除,停止,修剪;n:修剪",
"lop off":"v:删除,割断,停止",
"lope":"n:飞奔",
"loping":"v:脉动",
"lopping":"v:摇摇晃晃",
"lopsided":"a:畸轻畸重,片面,畸;n:畸形",
"loquacious":"a:贫嘴,嘴碎,多嘴多舌,贫,贫气;v:多嘴多舌",
"loquaciousness":"n:贫嘴",
"loquacity":"n:吵闹,多嘴",
"lord":"n:上帝,主,贵族,阁下,领主,老爷;v:作威作福",
"lord it over":"v:横行霸道,霸,称王称霸",
"lord's day":"n:星期日",
"lord's supper":"n:圣餐",
"lord's table":"n:祭坛",
"lording":"n:大人",
"lordly":"d:骄奢淫逸",
"lordship":"n:支配,权力",
"lore":"n:知识,传说,学问,眼光,博学,传授",
"lorraine":"n:洛林",
"lorry":"n:卡车,货车,手车,矿车,槽车",
"los angeles":"n:洛杉矶",
"lose":"v:失去,丢,输,丧失,损失,丢失,丢掉,失败,失掉,迷路,掉,失,遗失,迷失,浪费,失落,忘记,脱离,败,少,错过,亏损,亏本,负,折,失却,蚀本,白费,破坏,坐失,蚀,败北,遗,耗损,丧,损,断送,夺,杀死,亡",
"lose one's temper":"v:闹脾气,发作,动火,发毛,动气,发脾气,发火,耍态度,动怒",
"lose sight of":"v:忽略,忘记",
"loser":"n:败者",
"losing":"n:失败",
"loss":"n:损失,亏损,丢失,丧失,减少,损耗,下降,失败,负,浪费,损伤,缺失,冤;v:损伤,折耗",
"lost":"v:走散",
"lot":"n:许多,大量,命运,抽签,一切,批,签,相当,家伙,一块,命,遭遇,运气;v:划分,分批;d:一块",
"lotion":"n:药水,洗涤",
"lottery":"n:奖券",
"lotus":"n:荷花,芙蓉,王莲,莲,莲花,睡莲,荷",
"lotus land":"n:安逸",
"loud":"a:大,响;d:高声",
"loudly":"d:嚎啕,放声",
"loudness":"n:响度,响亮;d:大声",
"loudspeaker":"n:扬声器,喇叭",
"lough":"n:湖泊,海湾",
"louis":"n:路易斯",
"louisiana":"n:路易斯安那",
"lounge":"n:休息室;v:闲逛,闲荡,躺",
"lounge chair":"n:躺椅",
"lounge suit":"n:西服",
"lour":"v:皱眉头",
"louse":"n:寄生虫,虱,虱子",
"lousy":"a:破",
"lout":"v:鞠躬,嘲弄,愚弄;n:蠢人,粗人",
"louver":"n:放气孔,百叶窗,天窗",
"lovable":"a:可爱,心爱",
"love":"n:爱,爱情;v:恋慕,称赞,恋",
"love affair":"n:恋爱",
"love child":"n:私生子",
"love song":"n:情诗",
"love story":"n:艳史",
"love-lies-bleeding":"n:千穗谷,鸡冠花",
"love-philter":"n:春药",
"lovelace":"n:色鬼",
"loveliness":"n:可爱",
"lovely":"a:可爱,妩媚,乖巧,胜,婉丽,乖,心爱;v:胜;n:美女",
"lovemaking":"n:调情",
"lover":"n:情人,情侣,恋人,爱人,爱好者,情夫,情郎,冤家,心上人,第三者,面首",
"lovers":"n:情侣",
"loving cup":"n:奖杯",
"loving-kindness":"n:慈爱,恩情",
"lovingly":"d:脉脉",
"low":"a:低;d:低矮,晚近;n:低气压区;v:说",
"low comedy":"n:滑稽戏",
"low frequency":"n:低频",
"low gear":"n:低速",
"low pitch":"n:低音,缓坡",
"low tide":"n:最低点",
"low-down":"a:贱",
"low-grade":"n:下品;a:低档",
"low-lying":"a:低洼",
"low-pitched":"a:低音",
"low-pressure":"a:悠然自得",
"low-water mark":"n:最低点",
"lower":"v:降低,放下,减少,压低,贬低,减低,降下;a:低级,沉;n:下铺",
"lower berth":"n:下铺",
"lower jaw":"n:下巴,下颚,下颌",
"lower oneself":"v:自轻自贱",
"lowercase":"n:小写",
"lowering":"n:低下,减损;v:减低;a:低沉",
"lowers":"v:降低",
"lowest":"a:最低",
"lowland":"n:低地",
"lowliness":"n:低下",
"lowly":"a:低微,低下,卑微,低三下四,微贱,贱,卑贱",
"lowness":"n:低下",
"loyal":"a:忠诚,忠实;v:忠实",
"loyalism":"n:效忠,忠诚",
"loyalist":"n:忠臣",
"loyalty":"n:忠诚,忠心,赤胆忠心,丹心,贞操;a:忠诚",
"lozenge":"n:含片,菱形",
"lp":"n:工党",
"lu":"n:卢",
"luanda":"n:罗安达",
"lube":"n:润滑油,润滑",
"lubricant":"n:润滑油,黄油;a:滑润",
"lubricate":"v:润滑,膏,润,润泽,收买,加油,行贿",
"lubricating":"v:润滑",
"lubricating oil":"n:润滑油",
"lubrication":"n:润滑",
"lubricity":"n:光滑,狡猾",
"luce":"n:狗鱼",
"lucid":"a:清楚",
"lucidity":"n:清楚,透明,洞察力,明朗,明白",
"lucifer":"n:金星",
"luck":"n:运气,幸运,侥幸,运;v:运",
"luckily":"d:幸亏,幸好,侥幸,幸而,幸,好在,亏,多亏;a:凑巧;v:亏",
"lucky":"a:幸运,侥幸,吉利;v:走运",
"lucre":"n:金钱,赚头,利益",
"lucubrate":"v:苦思冥想",
"lucubration":"n:苦思冥想",
"ludicrous":"a:可笑",
"lug":"v:拖;n:敲诈,拖",
"luge":"n:雪橇",
"luggage":"n:行李,红褐色,行装,皮箱,提包,箱笼",
"luggage van":"n:行李车",
"lugger":"n:帆船",
"lukewarm":"a:温,乌涂,温和",
"lull":"v:催眠,麻痹,缓和,镇静,哄骗;n:暂停,间歇",
"lullaby":"n:催眠曲,摇篮曲",
"lumbar":"n:腰椎",
"lumbar vertebra":"n:腰椎",
"lumber":"v:堆满,采伐,成材,阻碍;n:木料,废物,原木",
"lumbering":"v:伐木",
"luminance":"n:亮度,照度,发光,光亮,发光度",
"luminary":"n:天体,名人",
"luminescence":"n:发光,冷光;v:发光",
"luminosity":"n:光度,发光度,光辉,光明,亮度",
"luminous":"a:光亮,皓,灼",
"luminous energy":"n:光能",
"luminous flux":"n:光通量",
"lummox":"n:笨蛋",
"lump":"n:肿块,块,团;v:混为一谈,一概而论,总括,肿胀;a:总共,大量",
"lump sugar":"n:糖块",
"lumpish":"a:怯声怯气,块状",
"luna":"n:月亮",
"lunacy":"n:疯癫,疯病",
"lunar":"a:太阴;n:太阴",
"lunar calendar":"n:太阴历",
"lunar eclipse":"n:月蚀",
"lunar month":"n:朔望月",
"lunatic":"n:疯子,怪人,愚人,狂人;a:疯",
"lunch":"n:午饭,午餐,中饭,便餐,点心,晌饭",
"luncheon":"n:午餐,午宴",
"luncheonette":"n:饭馆",
"lung":"n:肺,肺脏,呼吸器官",
"lung-power":"n:声量",
"lunge":"n:突出,猛冲,刺,突进,戳;v:戳,推",
"lungfish":"n:肺鱼",
"lungs":"n:肺",
"lunkhead":"n:傻瓜",
"luo":"n:罗,骆",
"luoyang":"n:洛,洛阳",
"lupus":"n:狼毒,狼疮",
"lurch":"n:倾向,大败,倾侧,挫折;v:倾侧,埋伏",
"lure":"v:引诱,诱惑;n:诱惑,诱饵",
"lurid":"a:耀眼",
"lurk":"v:埋伏,潜伏,潜在,潜藏,匿伏;n:潜在",
"lurker":"n:划艇",
"lurking":"a:潜在;v:隐",
"lusaka":"n:卢萨卡",
"luscious":"a:甘美,甜美,香喷喷,香甜,妖娆,绚烂",
"lush":"a:茂盛,丰茂,芊芊;n:醉汉,酒",
"lusher":"a:酒鬼,醉汉",
"lust":"n:欲望;v:好色,贪求",
"lust after":"n:渴",
"luster":"n:光泽,光彩,光辉,光华,光;v:上光",
"lustful":"a:淫荡",
"lustiness":"n:精力充沛,活泼",
"lustre":"n:光彩,光华,光荣,荣誉,釉,光",
"lute":"n:琵琶,封泥",
"lutetium":"n:镥",
"luting":"n:油灰",
"luxembourg":"n:卢森堡",
"luxuriance":"n:奢华,繁茂",
"luxuriant":"a:繁茂,菁,莽莽,菀,蔼,懋,萋萋,森森,郁郁,蕃,菲,肥美,荣,丰茂,芾,茂,繇,郁,苞,楚楚,茂盛,萋,蔚,阴翳,蓁,蓊",
"luxuriate":"v:享受,繁茂",
"luxuries":"n:奢侈品",
"luxurious":"a:豪华,奢侈,华贵,阔气,阔绰,奢,奢华,精美",
"luxury":"n:奢侈,豪华,奢侈品,享受,摆设,美食;a:豪华",
"luzon":"n:吕宋",
"lyceum":"n:学会",
"lying":"v:虚伪,谎话,说谎",
"lying-in":"n:产期,分娩,临盆",
"lymph":"n:浆,淋巴液,淋巴,溪水,淋巴腺,疫苗,苗,泉水",
"lymph gland":"n:淋巴腺,淋巴结",
"lymph node":"n:淋巴结,淋巴腺",
"lymphatic":"a:淋巴腺;n:淋巴管",
"lymphocyte":"n:淋巴细胞,淋巴球",
"lymphoma":"n:淋巴瘤",
"lynch":"v:私刑",
"lynch law":"v:私刑",
"lynx":"n:猞猁,山猫",
"lyon":"n:里昂",
"lyons":"n:里昂",
"lyra":"n:里拉,天琴座",
"lyre":"n:里拉",
"lyrebird":"n:琴鸟",
"lyric":"n:抒情诗,歌词",
"lyrics":"n:唱词",
"lyssa":"n:狂犬病",
"ma":"n:妈妈,妈,马,大妈,娘",
"mac":"n:伙计",
"macadam":"n:碎石",
"macadamize":"v:筑",
"macao":"n:澳门",
"macaque":"n:短尾猴,猕猴,猢狲,狙",
"macaroni":"n:通心粉,花花公子",
"mace":"n:锤,锏",
"macedonia":"n:马其顿",
"macedonian":"n:马赫",
"macerate":"v:浸渍,沤,折磨",
"maceration":"n:浸渍,离析",
"machinate":"v:策划,图谋,阴谋",
"machination":"n:诡计,奸计,策划",
"machine":"n:机器,机械,机,缝纫机,汽车,打字机,机构,飞机,车,加速器,干部,机关;v:建造",
"machine gun":"n:机关枪,冲锋枪",
"machine tool":"n:工作母机",
"machine translation":"n:机器翻译",
"machinery":"n:机器,机械,机构,方法,机件,工具,组织,手段,机关",
"machining":"v:操作,加工",
"machinist":"n:机工,机械师",
"mack":"n:雨衣",
"mackerel":"n:马鲛鱼,鲐",
"mackintosh":"n:雨衣,胶布",
"macrame":"n:流苏",
"macro":"n:宏",
"macrocosm":"n:宏观世界,整体,宇宙",
"macroscopic":"a:宏观",
"macula lutea":"n:黄斑",
"mad":"a:疯,发疯,疯癫,狂,狂乱,癫狂,暴怒,痴;v:疯癫",
"madagascar":"n:马达加斯加",
"madam":"n:夫人,太太,女士,主妇,老鸨",
"madame":"n:太太,夫人,老鸨,女士",
"madcap":"a:鲁莽",
"mademoiselle":"n:小姐",
"madhouse":"n:疯人院",
"madly":"d:非常",
"madman":"n:疯子,狂人",
"madmen":"n:疯子,狂人",
"madness":"n:疯狂,狂乱,狂暴",
"madonna":"n:圣母",
"madrid":"n:马德里",
"madrigal":"n:牧歌,情歌,小曲",
"maelstrom":"n:灾害",
"mafia":"n:黑手党",
"magazine":"n:杂志,弹药库,宝库,暗盒,暗箱,仓库,弹匣",
"magenta":"n:品红",
"maggot":"n:蛆,蛆虫,空想,异想天开",
"magic":"n:魔法,魔力,魔术;a:神奇",
"magic square":"n:魔方",
"magical":"a:神奇,神,幻,神异;n:神",
"magical power":"n:神通",
"magician":"n:魔术师,术士,妖道",
"magistracy":"n:辖区",
"magistrate":"n:长官",
"magma":"n:岩浆",
"magnanimity":"n:宽宏大量,雅量,度,洪量,度量,肚量,高尚,海量,宽大为怀",
"magnanimous":"a:宽宏大量,宽大,坦荡,大量,厚,宽宏,宽厚,慷慨,落落大方;v:落落大方,容人",
"magnate":"n:大王,巨头,权贵,大亨,富豪,阔人",
"magnates":"n:达官贵人",
"magnesia":"n:镁砂",
"magnesium":"n:镁,镁光",
"magnesium sulfate":"n:泻盐",
"magnet":"n:磁铁,磁石,磁体,吸铁石",
"magnetic":"a:磁;n:磁性",
"magnetic core":"n:磁心",
"magnetic declination":"n:磁倾角,偏差",
"magnetic disc":"n:磁盘",
"magnetic field":"n:地磁场",
"magnetic head":"n:磁头,磁心",
"magnetic needle":"n:指南针",
"magnetic pole":"n:磁极,地磁极",
"magnetic recorder":"n:录影机",
"magnetic storm":"n:磁暴",
"magnetic tape":"n:磁带",
"magnetics":"n:磁学",
"magnetise":"v:吸引",
"magnetism":"n:磁,磁力,磁性,磁学,吸引力",
"magnetite":"n:磁铁矿,镁砂,磁石,菱镁矿",
"magnetization":"n:磁化;v:磁化",
"magnetize":"v:磁化,吸引,感动",
"magnetizing":"v:磁化",
"magnetometer":"n:磁强计",
"magnification":"n:放大,扩大,夸张,称赞,伸缩;v:放大",
"magnificence":"n:壮丽,豪华,宏伟,庄严,堂皇,宏大",
"magnificent":"a:宏伟,雄伟,壮丽,华丽,辉煌,瑰丽,灿烂,盛大,盛,堂皇,泱泱,靡丽,殷,壮美,皇,弘,雄壮,壮,浩荡,华,气壮山河,光辉,宏,华美,绚丽;v:盛,气壮山河",
"magnifier":"n:放大镜,放大器",
"magnify":"v:放大,夸大,赞美,扩大;a:张皇",
"magnifying":"v:放大",
"magniloquence":"n:华而不实,虚夸,大话",
"magniloquent":"a:华而不实",
"magnitude":"n:大小,数值,巨大,重大,震级,星等,重要性,广大,伟大,量度,强度,尺寸,数量",
"magnolia":"n:木兰",
"magnum opus":"n:大作,杰作",
"magpie":"n:喜鹊,碎嘴子,鹊",
"maharani":"n:大乘",
"mahatma":"n:伟人,圣贤",
"mahayana":"a:上乘;n:大乘",
"mahdi":"n:救世主",
"mahogany":"n:红木,餐桌,赤褐色",
"maid":"n:女仆,女佣,姑娘,少女,侍女,处女,青衣,闺女,使女",
"maiden":"n:少女,闺秀,女郎,处子,姑,闺女,处女,童女",
"maidenhair":"n:铁线蕨",
"maidenhair tree":"n:白果",
"maidenhead":"n:处女膜",
"maidservant":"n:使女,老妈子,娘姨,婢女,婢,侍女,女仆,女佣",
"mail":"n:邮件,信;v:邮递,邮",
"mail car":"n:邮车",
"mail carrier":"n:邮递员,绿衣使者",
"mail clerk":"n:收发员",
"mail order":"n:邮购",
"mailbag":"n:邮袋",
"mailbox":"n:信箱,邮筒,信筒,邮箱",
"mailer":"n:邮船",
"mailing":"n:邮寄,邮件;v:投递",
"maillot":"n:紧身衣",
"mailman":"n:邮递员,绿衣使者",
"maim":"v:伤残,残害",
"maimed":"v:残废,废;a:残废,废",
"main":"a:主要,主,大,基本,正,全,总;n:大洋",
"main course":"n:大菜,主航道",
"main drag":"n:大街",
"main line":"n:干路,大静脉,干道",
"main road":"n:大道,通衢",
"maine":"n:缅因",
"mainframe":"n:主机,大型机",
"mainland":"n:大陆,本土",
"mainline":"v:干线,主线,静脉注射",
"mainly":"d:主要,大部分,大抵,大概,基本上",
"mains":"n:电源,电力网",
"mainstay":"n:支柱,主心骨,主体,主干,骨干,台柱子,柱石,主将,主心骨儿",
"mainstream":"n:主流,干流",
"maintain":"v:保持,维持,维护,坚持,保养,主张,保存,维修,继续,认定,供养,养护,护养,持,扶养,养,安定,强调,养路,撑,维;n:维",
"maintenance":"n:维修,维护,维持,保持,保养,保管,生活,供给,保存,扶养,主张,继续,坚持,机务,拥护,生计,支持,保修",
"maitreya":"n:弥勒",
"maize":"n:玉米,玉蜀黍,老玉米,棒头,黄色,玉茭,包谷,棒子,粟米",
"majestic":"a:雄伟,威严,壮丽,磅礴;d:巍然,屹然",
"majesty":"n:陛下,雄伟,威严,庄严,主权,尊严,君主,威风,帝位,统治权",
"major":"a:主要,大;n:少校;v:搞,专修",
"major planet":"n:大行星",
"major-domo":"n:管家",
"majority":"n:大多数,多数,成年,大部分,过半;a:多数",
"make":"v:使,做,就,作,让,进行,作出,犯,制造,做出,使得,吃,赚,构成,制,表示,令,制作,造成,做成,搞,发出,赚钱,造,处理,赔偿,前进,变成,制定,理解,了解,当作,对待,打扮;n:制造,组织,脾性,产量,形状,样式",
"make a point":"v:立论",
"make as if":"n:假装",
"make believe":"v:假装,装,装假",
"make bold":"v:斗胆,敢,冒昧",
"make do":"v:对付,应付,凑合",
"make for":"v:袭击,有利于,走向",
"make fun":"v:打哈哈",
"make good":"v:成气候,抵偿,补偿,抵,兑现,履行,弥补",
"make headway":"v:进展",
"make love":"v:做爱",
"make merry":"v:寻欢作乐,行乐,闹腾",
"make noise":"v:噪,哗",
"make off":"v:逃跑",
"make out":"v:看出,辨认,起草,拼凑,表示,理解,开,认",
"make over":"v:改造,移交,毁,翻新",
"make peace":"v:调解,媾和,排解,议和",
"make sense":"v:言之成理",
"make sure":"v:查看,落实",
"make up":"v:缔结,构成,化装,起草,上装,收集,梳妆,调解,妆扮,赓,结算,捏,赔偿,整理,编,化妆,虚构,臆造,占,诌,包装,打扮,无中生有,编排,拼版,组合,扮,缝制,构,找补,补偿,靓,决定,捏合,拼缀,修理,妆",
"make water":"v:尿,漏水,小解",
"make way":"v:腾出,开道,让道,前进",
"make-peace":"n:调停人",
"make-up":"n:化妆品,化装,结构,特质,虚构,装扮,假装,打扮,体格,补偿,组织,补考,拼版,性格,补充,构造",
"makeover":"n:改头换面",
"maker":"n:上帝,制造商,诗人",
"makeshift":"n:凑合,将就;a:行",
"makeup":"n:构造;v:扮装,拼版",
"making":"n:素质,制作,生产,组织,材料,制造,利益,赚头,要素,所得",
"making love":"n:云雨",
"makings":"n:要素,料,气质,材料",
"malabo":"n:马拉博",
"malachite":"n:孔雀石",
"maladjustment":"n:失调",
"maladministration":"n:紊乱",
"malady":"n:病,弊病,疾病,病症",
"malaise":"n:不适",
"malar bone":"n:颧骨",
"malaria":"n:疟疾,瘴疠,瘴气,摆子,疟子,冷热病,疟",
"malarkey":"n:胡说",
"malathion":"n:主义,马拉松",
"malawi":"n:马拉维",
"malaya":"n:马来亚",
"malaysia":"n:马来西亚",
"malcontent":"a:不满;n:不满",
"maldive islands":"n:马尔代夫",
"maldives":"n:马尔代夫",
"male":"n:儿,男;a:公",
"male genital organ":"n:鸟",
"male genitals":"n:阳,势",
"male plug":"n:插头",
"malediction":"n:咒骂,诅咒,诽谤,诬蔑",
"malefaction":"n:罪恶,罪行,坏事",
"malefactor":"n:坏人",
"malefactors":"n:奸宄",
"maleficence":"n:坏事,罪行,毒害",
"maleficent":"a:心怀叵测",
"malevolence":"n:恶意,凶恶,黑心,恶毒;a:凶恶",
"malevolent":"a:凶狠;v:心怀叵测",
"malfeasance":"n:胡作非为,坏事,渎职",
"malformation":"n:畸形",
"malfunction":"n:故障,事故,出错,失灵;v:出错,失灵",
"mali":"n:马里,花匠",
"malice":"n:恶意,怨恨,恶感,恶念,歹毒,祸心,预谋,歹意;a:歹毒",
"malicious":"a:恶意,恶毒,奸险,毒,险恶,蓄意;d:蓄意",
"malign":"v:诽谤,中伤,诬蔑,诬害,毁谤;a:有害",
"malignancy":"n:恶性肿瘤,恶意,恶毒",
"malignant":"a:恶性,恶意,刻毒",
"malignant tumor":"n:恶性肿瘤,毒瘤",
"malignity":"n:恶意,狠毒,恶性,怨恨,敌意",
"malinger":"v:装病,诈病,开小差",
"mall":"n:商场,林荫道",
"mallard":"n:绿头鸭,野鸭",
"malleability":"n:展性,顺从",
"mallet":"n:槌,马球,锤骨",
"mallow":"n:蜀葵,锦葵",
"malpractice":"n:不正之风,弊端,玩忽职守,恶癖;v:营私舞弊,藏掖",
"malpractices":"n:歪风邪气,不正之风;v:营私舞弊,舞弊",
"malt":"n:麦芽;v:发芽",
"malta":"n:马耳他",
"malted milk":"n:麦乳精",
"malthus":"n:马尔萨斯",
"maltose":"n:麦芽糖,饴,饴糖",
"maltreat":"v:苛待,亏待,凌虐,滥用,凌辱,虐待;n:打骂",
"maltreatment":"n:打骂",
"mama":"n:妈妈",
"mammal":"n:哺乳动物",
"mammalian":"n:哺乳动物",
"mammon":"n:财富,财神,金钱",
"mammoth":"n:猛犸,毛象;a:巨大,庞大;v:声势浩大",
"mammy":"n:妈妈",
"man":"n:人,男人,男子,人类,士兵,谁,工人,男,汉子,男子汉,部下,丈夫,男性,男士,战士,仆人,学生,大人,汉,名人,大丈夫,喂,要人,老兄,对手,爷们;v:操纵",
"man of action":"n:活动家,实干家",
"man-at-arms":"n:兵士,士兵",
"man-made":"a:人为",
"man-made fiber":"n:人造纤维",
"man-made lake":"n:人工湖",
"man-of-war":"n:舰",
"manacle":"n:拘束,手铐,束缚;v:束缚",
"manacles":"n:手铐",
"manage":"v:管理,吃,经营,控制,做,处理,办到,对付,应付,弄,使用,驾驭,当,料理,办,理,处,支配,问,管,主持,经理,司,治理,办理,主,操纵,营,措,措置,敷衍,持,执,措手,打理,调度,经纪,开动,操办,训练,治,抓好,操持,处置;n:营,经理,司;p:经",
"manageable":"a:乖",
"management":"n:管理,资方,经营,处理,董事会,安排;v:管理,处理",
"management personnel":"n:厂方",
"manager":"n:经理,管事,管家,干事,理事,经纪,领袖,导演,总管,干才",
"managing":"n:管理,处理;a:社长",
"managing editor":"n:主编",
"manama":"n:麦纳麦",
"manatee":"n:海牛",
"manchester":"n:曼彻斯特",
"manchu":"n:满洲,清朝",
"manchuria":"n:满洲里,满洲国",
"mandala":"n:曼陀罗",
"mandamus":"n:训令",
"mandarin":"n:官吏,官话,橘子,要人,国语",
"mandarin orange":"n:柑,柑子,蜜柑",
"mandate":"n:命令,授权;v:托管",
"mandatory":"a:命令;n:代理人",
"mandible":"n:上颚,下颌,下颚",
"mandolin":"n:曼陀铃",
"mandrill":"n:山魈,魈",
"mane":"n:鬃毛,鬃",
"manes":"n:灵魂",
"maneuver":"n:演习,活动,手法,策略;v:演习,移动",
"maneuverability":"n:机动性,可操作性",
"maneuverable":"a:机动",
"manful":"a:演习,调动",
"manganese":"n:锰",
"manganese steel":"n:锰钢",
"mange":"n:疥癣",
"manger":"n:枥,槽子",
"mangle":"v:破坏,损坏",
"mangler":"n:绞肉机",
"mango":"n:芒果,蜂鸟",
"mangrove":"n:红树",
"manhandle":"v:虐待",
"manhole":"n:探井",
"manhood":"n:成年,成年期,成人,刚毅,大人",
"manhunt":"n:搜索",
"mania":"n:狂热,癫狂,狂躁,热衷",
"maniac":"n:疯子,迷,狂人",
"manicure":"v:修剪",
"manifest":"v:出现,表现,显示,证明,表,表明,现出,指明;a:显然,明白,显明,昭彰;n:宣言,货单,声明;d:显然",
"manifestation":"n:表现,显现,表示,表征,表明",
"manifesto":"n:宣言,声明,告示,布告",
"manifestos":"n:宣言,声明",
"manifold":"a:五花八门;v:复写;n:簇",
"manifold paper":"n:打字纸",
"manila":"n:马尼拉,马尼拉麻",
"manila hemp":"n:蕉麻",
"manipulate":"v:操纵,使用,处理,控制,摆弄,摆布,窜改,操作,拨弄,取巧,开动",
"manipulation":"n:操作,控制,操纵,推拿,手法;v:推拿,操作",
"manipulator":"n:控制器,电键,机械手",
"mankind":"n:人类,人,男人,男性,男子",
"manliness":"n:男子气,勇敢,雄伟,大胆,刚毅",
"manly":"a:雄纠纠",
"manna":"n:美味,甘露",
"manned":"a:载人",
"manner":"n:态度,举止,方式,礼貌,样子,方法,神态,习惯,气,规矩,风俗,风格,气派,派头,神气,做法,貌,种类,样式,惯例,声色,格局,劲,体,架式,架势,礼数",
"mannerism":"n:习气,守旧,怪癖",
"manners":"n:礼貌,礼",
"manoeuvre":"n:演习,花招;v:部署,耍手腕,回旋,耍花招",
"manometer":"n:压力计,血压计",
"manor":"n:庄园,采地,封地,领地",
"manpower":"n:人力,人工,人手,人",
"mansard":"n:阁楼",
"manservant":"n:童仆,听差,男仆,小厮",
"mansion":"n:大厦,府邸,公馆,大楼,宅第,府第,宫,府,宿,厦",
"mansion house":"n:府第,府邸",
"manslaughter":"n:杀人,杀人罪;v:误杀",
"manta":"n:苫布,乌贼,粗布,章鱼",
"mantel":"n:壁炉台,地幔",
"mantelpiece":"n:壁炉台",
"mantis":"n:刀螂,螳螂,髦,螳",
"mantissa":"n:尾数",
"mantle":"n:地幔,斗篷,衣钵,外表,罩衣,细胞膜,槽,披风,纱罩,水槽,外套,外罩,罩,罩袍;v:扩展,覆,隐蔽,展开",
"mantra":"n:颂歌",
"manual":"n:手册;a:手工,手",
"manual alphabet":"n:手指字母",
"manual labor":"n:劳作",
"manual labour":"n:活计,人力,劳动",
"manually":"d:实际,亲自",
"manufacture":"v:制造,生产;n:手工业",
"manufacturer":"n:制造商,厂商,厂主",
"manufactures":"n:制成品",
"manufacturing":"n:制造业",
"manufacturing business":"n:制造业",
"manumission":"n:解放",
"manumit":"v:解放",
"manure":"n:肥料,粪肥,坢,肥,牛粪",
"manuscript":"n:手稿,原稿,稿子,稿件,底稿,文稿,稿本,遗稿,来稿,草稿,抄本,初稿,手抄本,稿,书稿",
"many":"a:许多,多;n:群众;r:许多",
"many-sided":"a:多边",
"mao zedong":"n:毛泽东",
"map":"v:映射,测绘,制订,起草,筹划,勘测;n:舆图,面孔,图画,脸",
"map out":"v:筹划,起草,制订,部署,计划,规",
"maple":"n:枫树,槭,枫",
"mapping":"v:绘图,制图,映射,测绘;n:绘图",
"mar":"n:损伤,三月,3月,毁损,障碍;v:损坏,毁坏,弄坏,毁损",
"marathon":"n:马拉松",
"maraud":"v:劫掠,掠夺,掳掠,抢劫;n:掳掠",
"marble":"n:大理石,弹子,常识",
"marbles":"n:弹球",
"march":"v:前进,行进,游行;n:步调",
"marconi":"n:无线电报",
"mare":"n:骒马,海",
"margarine":"n:麦淇淋",
"marge":"n:边缘",
"margin":"n:边缘,余地,边,差额,范围,赚头,保证金,储备,空白,押金,边沿,差数,幅度,限界,余量,余额,余裕",
"margin of profit":"n:余利",
"marginal":"a:边缘,不毛之地",
"marginalia":"n:批注",
"marginalize":"v:忽视,排斥,忽略",
"marigold":"n:金盏花",
"marijuana":"n:大麻",
"marine":"n:海军,水兵;a:海",
"marine corps":"n:陆战队",
"marine law":"n:海洋法",
"mariner":"n:水手,海员,船长,船员",
"marionette":"n:木偶",
"maritime":"a:近海",
"mark":"n:马克,分数,符号;v:符,想,记录,区分,登记",
"mark out":"v:规划,指出,注明,设计",
"mark up":"v:涨价",
"marked":"a:显著,较,显明",
"marker":"n:标记,型号,纪念碑,指示器,标兵,记分员,墨斗,标志,书签,标竿,里程碑",
"market":"n:市场,需要,行情,销路,集市;v:卖,销",
"market place":"n:集市",
"market price":"n:牌价,时价,市价",
"market town":"n:集镇,市镇",
"market value":"n:市价",
"marketable":"v:适销对路,适销;a:适销对路",
"marketing":"n:营销;v:贩卖,销售",
"marketplace":"n:市场,市井",
"marking":"n:标志,记号,条纹,型号,记分,斑纹,印记,点;v:打分",
"markka":"n:马克",
"marksman":"n:射手,狙击手,神枪手,枪手",
"marksmanship":"n:枪法",
"marksmen":"n:射手,神枪手",
"markup":"n:赢利",
"marmalade":"n:果酱,果子酱",
"marmalade tree":"n:人心果",
"marmot":"n:旱獭,土拨鼠",
"maroon":"n:栗色,爆竹,鞭炮;v:闲荡",
"marooned":"v:孤立无援",
"marquess":"n:侯爵",
"marquis":"n:侯爵,侯",
"marquise":"n:帐幕,帐篷",
"marriage":"n:婚姻,结婚,婚礼,婚事,婚,亲事,亲,姻,姻缘,嫁娶,终身大事,婚嫁",
"marriage bed":"n:房事",
"marriage contract":"n:婚约",
"married":"a:已婚;v:已婚",
"married couple":"n:两口儿,伉俪",
"married woman":"n:妇人,妇",
"marrow":"n:骨髓,精髓,活力,敌手,生气,髓,精华,实质,对手",
"marrow squash":"n:南瓜",
"marry":"v:结婚,娶,嫁,完婚,匹配,结合,结亲,出阁,嫁娶,连接,讨,婚配",
"mars":"n:火星,荧惑,战争",
"marseillaise":"n:马赛曲",
"marseilles":"n:马赛",
"marsh":"n:沼泽地,沼泽,湿地,皋,衍,荡",
"marsh marigold":"n:金盏花",
"marshal":"v:编组,集合,排列,提挈;n:马歇尔,司仪",
"marshy":"a:湿地",
"mart":"n:貂皮,拍卖场,市场",
"marten":"n:貂,貂皮",
"martes zibellina":"n:紫貂",
"martial":"a:战争,武",
"martial law":"n:军法,军令,戒严令",
"martin":"n:马丁",
"martingale":"n:鞅",
"martyr":"v:杀害,殉节,殉难,折磨;n:烈士,先烈",
"martyrdom":"n:殉难,牺牲,殉教,苦恼,殉道,殉节,殉职,痛苦",
"marvel":"n:奇迹;v:诧异",
"marvellous":"a:不可思议,奇妙,瑰,入神",
"marvelous":"a:奇妙,精彩,神乎其神,纳罕,奇丽,神妙,不可思议",
"marx":"n:马克思",
"marxism-leninism":"n:马列主义",
"mary":"n:玛丽",
"maryland":"n:马里兰",
"mascot":"n:吉祥物,福星",
"masculine":"n:阳性;a:男性",
"masculinity":"n:男性,男子气",
"maseru":"n:马塞卢",
"mash":"v:捣碎,诱惑",
"mashed":"a:烂,烂糊;v:烂",
"mask":"v:化装,掩护,蒙蔽,遮蔽,隐,隐蔽,隐藏,覆;n:伪装,面罩",
"masked ball":"n:假面舞",
"masking":"n:化装,掩蔽,伪装",
"mason":"n:石匠,石工",
"masonite":"n:纤维板",
"masonry":"n:石工",
"masque":"n:面具",
"masquerade":"v:化装,乔装打扮,伪装,假托,假装,装扮;n:伪装,假托,掩饰",
"mass":"n:群众,质量;v:结集;a:大规模",
"mass spectrograph":"n:质谱仪",
"massachusetts":"n:马萨诸塞",
"massacre":"v:屠杀,残杀,杀戮,屠戮,损害;n:惨杀,惨案",
"massage":"v:按摩,推拿;n:按摩师,窜改,推拿",
"masses":"n:群众",
"masseur":"n:按摩师",
"massif":"n:地块,山岳,山丘",
"massing":"v:集中,总体,聚集;n:总体",
"massive":"a:块状,大规模,庞大",
"mast":"n:桅杆,桅,支柱,柱,坚果,船桅,竿;v:扯",
"master":"n:主人;v:熟练",
"master copy":"n:原稿,原本,原件,底本,原文",
"master key":"n:关子,关键",
"masterly":"a:高妙",
"mastermind":"n:智多星,诸葛亮;v:策划",
"masterpiece":"n:杰作,名作,名著,神品,佳作",
"masterpieces":"n:佳作",
"mastership":"n:胜利,统治,控制,练达,精通",
"masterwork":"n:杰作,名作,名著",
"mastery":"n:控制权,精通,首位,融会贯通,胜利,统治,修养,熟练,优势,控制,制服",
"masthead":"n:报头,刊头,桅顶",
"mastic":"n:膏剂,乳香",
"masticate":"v:噍,咀嚼,嚼",
"mastication":"n:咀嚼",
"mastiff":"n:獒",
"mastitis":"n:乳房炎,奶疮,乳腺炎",
"mastodon":"n:庞然大物",
"masturbate":"v:手淫",
"masturbation":"n:手淫",
"mat":"n:垫子,席子,衬垫;v:编织,垫",
"matai":"n:马蹄",
"match":"v:相配,配;n:伙伴,赛事;a:般配",
"matches":"n:洋火,自来火",
"matching":"v:配对,匹配,配合",
"matchless":"a:无比,无与伦比,独一无二,天下无双,盖世,旷代,无出其右;v:无双,无可比拟,盖世,天下无双,无与伦比",
"matchlock":"n:火绳",
"matchmaker":"n:介绍人,媒人,媒妁,月下老人,冰人,媒,月老",
"matchstick":"n:火柴",
"mate":"n:伴侣;v:交,配种,连接,联接,配对,交媾,匹配",
"mater":"n:母亲,脑膜",
"material":"n:材料,物质,料子,资料;a:物质",
"materialise":"v:实现",
"materialism":"n:唯物论,唯物主义,写实主义",
"materialistic":"a:唯物",
"materiality":"n:物质,物质性,有形,实体,重要性",
"materialization":"v:物化;n:物化",
"materialize":"v:实现,体现",
"materials":"n:原材料",
"materiel":"n:装备",
"maternity":"n:妊娠,母性,怀孕;v:妊娠",
"maternity hospital":"n:产院",
"math":"n:数学",
"mathematician":"n:数学家",
"mathematics":"n:数学,算学",
"maths":"n:数学",
"matinee":"n:日场",
"mating":"v:交配,配套,交尾,配种;n:交配",
"matriarchal":"a:母系",
"matriarchy":"n:母权制",
"matriculate":"v:录取",
"matrimony":"n:婚姻,结婚",
"matrimony vine":"n:枸杞",
"matrix":"n:矩阵,摇篮,铸型,铜模,字模,模子,范,模具,子宫,发源地,方阵,模,间架,母株,纸型,基层,模型,母体",
"matron":"n:妇女,主妇,护士长,保姆",
"matter":"n:事,问题,事情,物质;v:要紧,打紧;a:要紧,碍事",
"matting":"n:席子,草席",
"mattress":"n:床垫,垫子,褥垫,褥子,茵",
"mattress cover":"n:褥套",
"maturate":"v:化脓,成熟",
"maturation":"n:成熟,化脓,老化;v:化脓;a:成熟",
"mature":"v:成熟,熟,完成,长成,到期,羽毛丰满;a:壮年",
"maturing":"v:老化",
"maturity":"n:成熟,到期,完备,化脓;a:成熟",
"maudlin":"a:婆婆妈妈",
"maul":"v:伤害,打破,虐待",
"mauler":"n:拳头",
"maunder":"v:闲逛,咕哝",
"mauritania":"n:毛里塔尼亚",
"mauritius":"n:毛里求斯",
"mauser":"n:毛瑟枪",
"mausoleum":"n:陵墓,陵,墓,寝宫,纪念堂,陵寝",
"maven":"n:专家",
"maverick":"a:迷路",
"maw":"n:鱼肚,肚子,喉咙,咽喉,食道,食管",
"mawkish":"a:婆婆妈妈",
"max":"n:极大值",
"maxilla":"n:上颌,上颚,下颚",
"maxillary":"n:上颌",
"maxim":"n:格言,准则,箴言,座右铭,主义,谚语,原理",
"maximum":"n:极点,最高点",
"maxwell":"n:麦克斯韦",
"may":"n:五月,5月,梅,可以,可能,会,能,姑娘,尽管,无论,究竟,也许;v:可以,可,能",
"may bug":"v:金龟子",
"may day":"n:五一节,劳动节",
"maybe":"d:也许,或许,说不定,别,大概,或,兴许,备不住,兴,或者,多半,容或,作兴;v:别是,兴;c:或;n:可能",
"maybes":"n:可能性",
"mayflower":"n:山楂",
"mayfly":"n:蜉蝣",
"mayhem":"n:伤残,打倒;v:伤残",
"mayor":"n:市长",
"maze":"n:迷宫,困惑,迷魂阵,为难;v:迷惑",
"me":"r:鄙人,本人,咱,我,俺,在下",
"meadow":"n:草地,牧场,草原,草场,草甸,牧地",
"meadow mouse":"n:田鼠,野鼠",
"meadowland":"n:草地,牧地",
"meager":"a:微薄,贫乏,干瘪,可怜,浅陋,薄,辁,浅鲜",
"meagerly":"d:瘦",
"meagre":"a:微薄,薄,贫乏,浅薄,可怜",
"meal":"n:饭,饭菜,餐,膳食,进餐,食;v:进餐,吃饭",
"meal ticket":"n:饭票",
"mealiness":"n:粉状,甜言蜜语",
"meals":"n:饭菜,膳,伙食,膳食",
"mealy":"a:粉状",
"mean":"a:卑鄙;n:平均值,媒介;v:表示,打算,为",
"mean value":"v:均值,平均值,平均",
"meander":"n:河曲;v:漫谈",
"meandering":"a:弯曲,逶迤,迤逦;n:聊天,漫谈",
"meaning":"n:意思,意义,含义,词义,用意,涵义,内涵,语意,原意,真意,意味,命意,外延,意",
"meaningful":"a:隽永,意味深长,有意思;v:有意思,意味深长",
"meaningless":"a:淡,无谓,没头没脑",
"meanness":"n:卑鄙,卑贱,吝啬,小气,下贱,卑劣",
"means":"n:手段,着,工具,资产,筹,法子,路,法,资料;v:筹,入",
"meantime":"d:同时,一方面;n:中间,其间",
"meanwhile":"c:又,同时,与此同时;d:同时,其间;n:与此同时",
"meany":"n:小气鬼",
"measles":"n:麻疹,痧子,风疹,疹子,梅毒,斑点",
"measure":"n:措施;v:调节,检测",
"measure out":"v:配给",
"measured":"a:有板有眼",
"measureless":"a:无量;v:无量",
"measurement":"n:测量,尺寸,量度,计量,测试;v:测量,衡量",
"measurements":"n:度量衡",
"measures":"n:尺码",
"measuring":"n:测量;v:测量",
"measuring cup":"n:量杯",
"meat":"n:肉,肉类,内容,肉食,食物,实质,餐",
"meat grinder":"n:绞肉机",
"meat hooks":"n:拳头,手",
"meat pie":"n:肉饼,馅饼,馅儿饼",
"meat safe":"n:橱柜",
"meatball":"n:肉丸子",
"meaty":"a:肉",
"mecca":"n:圣地,发源地",
"mechanic":"n:技工,机工,技师,工匠",
"mechanical":"a:机械,刻板,板板六十四,生",
"mechanical press":"n:冲床",
"mechanics":"n:力学,技巧,结构,手艺",
"mechanisation":"n:机理",
"mechanise":"v:机械化",
"mechanism":"n:机制,机理,机构,机械,结构,历程,关,机能,手法,机关,机械论",
"mechanist":"n:机师,机工",
"mechanization":"n:机械化,机理",
"mechanize":"v:机械化",
"med":"n:地中海",
"medal":"n:奖章,奖牌,勋章,纪念章,徽章,章,证章",
"meddle":"v:干预,干涉,多事,参与,弄,插手,插一脚,摸弄,染指",
"meddlesome":"a:好事,多事",
"media":"n:介质,传媒,媒体,媒质",
"medial":"a:中间",
"median":"n:中线;a:中央",
"mediate":"v:斡旋,调处,调解,调停,调协,圆场,捏合,劝解,转达,传达,介于,劝和,排解,调,调和",
"mediation":"n:调解,调停,仲裁;v:调解",
"mediator":"n:介质,中人,调人,和事老",
"medic":"n:苜蓿,医生",
"medical":"n:医生",
"medical assistant":"n:医士",
"medical history":"n:病历",
"medical man":"n:医生",
"medical officer":"n:军医",
"medical record":"n:病案,病历",
"medical science":"n:医",
"medicament":"n:药物,药剂",
"medicate":"v:投药,下药",
"medication":"n:药物,药剂",
"medicinal":"a:药物;n:药物,药品",
"medicine":"n:药,医学,药物,医,医药,内科,内服药,良药,医术,魔术,成药,药饵,医科",
"medicine ball":"n:实心球",
"medicine chest":"n:药箱",
"medicine man":"n:医生",
"medicines":"n:药物",
"medico":"n:医师,医生",
"medieval":"a:中古",
"medina":"n:麦地那",
"mediocre":"a:平庸,碌,碌碌,平平,庸",
"mediocrity":"n:平凡,庸才,平庸,普通,下乘",
"meditate":"v:考虑,沉思,冥想,深思,企图,计划,反省,入定,策划,幽思",
"meditation":"n:沉思,默想,深思",
"mediterranean":"n:地中海",
"mediterranean sea":"n:地中海",
"medium":"n:媒体,介质,媒介,媒质,培养基,方法,工具;a:半大",
"medium frequency":"n:中频",
"medium-sized":"a:中型",
"medley":"n:混战,混杂,乌合之众,杂拌儿,杂烩,混合",
"medulla":"n:延髓,中心,骨髓,髓,脊髓",
"medusa":"n:水母",
"meed":"n:报酬,奖赏,称赞",
"meek":"a:温顺,柔顺,温柔,婉",
"meekly":"d:温顺,柔和",
"meekness":"n:卑躬屈节,柔和,温顺",
"meerschaum":"n:海泡石",
"meet":"v:见面,见,遇见,见到,满足,相遇,会,接,迎接,会见,会面,认识,相见,开会,碰见,聚会,应付,会晤,碰头,集会,相交,交,碰上,相会,会合,遭遇,谋面,偿还,碰,遭,面临,迎合,聚首,碰面,晤面,配合,逢;n:赛会,集合",
"meeting":"n:会议,会,大会,会见,集会,决斗,会合,集合,遭遇;v:遇见,聚会",
"meetinghouse":"n:礼拜堂",
"meetings":"n:会议",
"mega":"n:兆",
"megacycle":"n:兆赫,兆周",
"megacycle per second":"n:兆赫",
"megahertz":"n:兆赫,兆周",
"megalomania":"n:自大狂,妄自尊大",
"megaphone":"n:扩音器,话筒,传声筒,喇叭筒",
"megawatt":"n:兆瓦",
"mei":"n:梅",
"mekong":"n:湄公河",
"melancholy":"a:忧郁,惆怅;n:愁思,沉思",
"melanin":"n:黑色素",
"melbourne":"n:墨尔本",
"meld":"v:混合,合并,吞没,出示;n:混合",
"melee":"n:格斗,混战",
"meliorate":"v:改善,修正",
"melioration":"n:改善,改进;v:改进,改善",
"mellifluous":"a:甜蜜",
"mellow":"a:醇和,醇厚,醇香;v:香醇",
"melodious":"a:好听,和谐,悠扬",
"melody":"n:旋律,曲,曲调,曲子,歌曲,调,调调,调子",
"melon":"n:瓜,西瓜,甜瓜",
"melon vine":"n:瓜蔓",
"melt":"v:融化,熔化,化,软化,消失,熔,熔融,融,融解,溶入,熔炼,消融,涣然冰释,融合,浪费,熔解",
"meltdown":"n:暴跌,熔化,崩溃,熔解",
"melting":"v:熔解,熔化",
"melting pot":"n:软化,坩埚",
"member":"n:成员,会员,议员,委员,构件,分子,社员,部分,员,部件,节,阴茎,手足,属员,器官,肢体,分句,元,成分",
"membership":"n:籍",
"membrane":"n:膜,隔膜,膜片,羊皮纸",
"membranous":"a:膜",
"memento":"n:纪念,纪念品",
"memo":"n:备忘录,备考,便笺",
"memoir":"n:回忆录,自传,论文,实录,传略,传记",
"memoirs":"n:回忆录",
"memorabilia":"n:记录,大事记",
"memorable":"a:难忘",
"memorandum":"n:备忘录,记录,便笺,通知书,摘要,规章,照会,节略,会章",
"memorial":"n:纪念碑,纪念馆,纪念物,请愿书,编年史,呈,呈子,备忘录,呈文,纪念日;a:记忆",
"memorialize":"v:纪念,建议",
"memorise":"v:记住",
"memorization":"n:暗记,记忆,熟记",
"memorize":"v:记住,熟记,记忆,铭记,暗记,记牢,存储",
"memorizing":"v:存储",
"memory":"n:记忆,回忆,存储器,记忆力,存储,内存,纪念,记性,存贮器,主存储器,主存;v:回忆",
"memory device":"n:存储器",
"men":"n:人们,人,须眉,男士",
"menace":"v:威胁;n:胁迫,威吓",
"menacingly":"d:险恶",
"menagerie":"n:动物园",
"menarche":"n:初潮",
"mend":"v:修理,补,修,缝补,好转,修补,加快,改善,改进,改正,补缀,纠正,整,加,痊愈,收拾,织补,订正,改订,治愈;n:改进,改良,痊愈,修理",
"mendacious":"a:虚假",
"mendacity":"n:虚伪,谎话,虚假,捏造,撒谎",
"mendelevium":"n:钔",
"mendicancy":"n:行乞",
"mendicant":"n:乞丐",
"mending":"n:缝补,织补,修理;v:修补",
"menfolk":"n:男人,爷们",
"menial":"n:奴仆,仆人",
"meninges":"n:脑膜",
"meningitis":"n:脑膜炎",
"meninx":"n:脑膜",
"menopause":"n:更年期,绝经期",
"menses":"n:月经;p:经",
"menstrual flow":"n:月经",
"menstruate":"v:行经",
"menstruation":"n:月经,经血;p:经",
"mensuration":"n:测量,度量,测定,量度;v:测量",
"mental":"a:精神,脑力;n:文墨",
"mental ability":"n:神智",
"mental deficiency":"n:低能",
"mental disorder":"n:神经病,神经错乱",
"mental faculty":"n:智力",
"mental hospital":"n:精神病院",
"mental illness":"n:精神病,神经错乱",
"mental image":"n:幻像",
"mental state":"n:神思",
"mentality":"n:心理,智力,思想,智能,脑力,意识,思路,精神",
"menthol":"n:薄荷醇",
"mention":"v:提到,提,提及,提起;n:陈述,齿",
"mentor":"n:良师,良师益友;v:指导",
"menu":"n:菜单,餐,菜谱,菜肴,饭菜",
"meow":"n:怨言;v:发牢骚",
"mercantile":"a:商人",
"mercantile law":"n:商法",
"mercerized":"v:丝光",
"merchandise":"n:商品;v:买卖",
"merchandiser":"n:商人",
"merchant":"n:商人,商,私商,批发商,商贾,客商",
"merchant marine":"n:商船",
"merchantman":"n:商船",
"merchants":"n:商贾",
"merciful":"a:仁慈",
"mercifully":"d:从宽",
"merciless":"a:无情,残忍,狠心,心狠",
"mercilessly":"a:臭;d:臭",
"mercurial":"a:汞",
"mercurochrome":"n:汞溴红,红汞,红药水",
"mercury":"n:汞,水银,水星,精神,活泼,元气,温度表,信使",
"mercury chloride":"n:升汞,甘汞",
"mercury fulminate":"n:雷汞",
"mercy":"n:宽恕,仁慈,怜悯,慈悲,幸运,感谢,侥幸,善心",
"mere":"a:只,仅仅,不过;n:池塘",
"merely":"d:只,仅仅,只不过,不过,就,仅,只是,但,光,纯粹,单纯,只顾,净,单,聊,徒,只管;c:惟有,只要;v:聊;a:单纯",
"meretricious":"a:浮华,俗不可耐",
"merge":"v:合并,并,融合,混同;a:融和",
"merger":"n:合并,兼并,吞并;v:兼并,吞并",
"merging":"v:结合,连接",
"meridian":"n:子午线,经线,子午圈,顶点,正午,绝顶",
"merit":"n:优点;v:值得",
"merit badge":"n:勋章",
"merits":"n:功绩",
"mermaid":"n:美人鱼",
"merriment":"n:欢乐,欢心",
"merriness":"n:快活,愉快",
"merry":"a:欢乐,愉快,快活,熙,欢,兴高采烈",
"merry-go-round":"n:走马灯",
"merrymaking":"n:欢乐,欢宴,狂欢",
"merton":"n:默顿",
"mesa":"n:方山,台面,台地",
"mesh":"n:网眼,网,闭路,网络;v:落网,钩住,咬合",
"meshing":"v:啮合",
"mesmerism":"n:催眠术,催眠",
"mesmerize":"v:迷住,迷惑,催眠",
"meson":"n:介子",
"mesopotamia":"n:美索不达米亚",
"mesosphere":"n:中层",
"mess":"n:一团糟,混乱,食堂,困境,伙食;v:惹恼",
"mess about":"v:懒散,混日子",
"mess around":"v:混日子,懒散",
"mess hall":"n:餐厅,饭厅",
"mess up":"v:扰乱,搅和",
"mess-up":"n:混乱",
"message":"n:信息,通信,信,口信,消息,电报,情报,咨文,电文,口信儿,音讯,寓意,启示,文告;v:通告,消耗,通话,通知",
"messenger":"n:使者,信差,信使,投递员,邮递员,青鸟;v:使",
"messiah":"n:救世主,基督,弥赛亚",
"messiness":"n:杂乱",
"messy":"a:凌乱,拖泥带水,烂,不伦不类,邋里邋遢,邋遢;v:拖泥带水",
"mestizo":"n:混血儿",
"metabolise":"v:新陈代谢",
"metabolism":"n:新陈代谢",
"metabolize":"v:代谢,新陈代谢",
"metacarpal":"n:掌骨",
"metacarpal bone":"n:掌骨",
"metacarpus":"n:掌骨",
"metal":"n:金属,金,碱金属,合金,金色,银色,成分,装甲车,金属元素,勇气,成色,金属性,铁轨",
"metal saw":"v:钢锯",
"metallurgy":"n:冶金,冶金学,熔炼",
"metals":"n:钢轨,金属,金,五金",
"metalworking":"n:金工",
"metamorphism":"n:变质,变化,变形,变态",
"metamorphose":"v:变质,变幻,变形;n:变质",
"metamorphosis":"n:变态,变形,变异,变质",
"metaphor":"n:隐喻,比拟,譬喻,象征",
"metaphysics":"n:形而上学,空谈,玄学",
"metastasis":"n:转移,病变,新陈代谢,急变,变态;v:转移",
"metastasize":"v:转移",
"metastatic":"a:转移",
"metatarsus":"n:蹠,蹠骨",
"metathesis":"n:易位,换位,置换;v:置换",
"mete":"n:边界,界石,境界;v:评定",
"mete out":"v:给予",
"metempsychosis":"n:轮回,转生",
"meteor":"n:流星,陨星,贼星,星火",
"meteor shower":"n:流星雨",
"meteoric":"a:流星",
"meteorite":"n:陨石,陨星,陨铁",
"meteorology":"n:气象学,气象",
"meteors":"n:流星",
"meter":"n:仪表,米,节拍,公尺,计,表;v:测量",
"metering":"v:计量,测量",
"methane":"n:甲烷,沼气",
"methanol":"n:甲醇,木醇",
"method":"n:方法,办法,法,方式,手段,条理,条,途径,方,法子,规律,顺序,术,道道儿,分类法,路,路径,仑,道道,秩序,道,门,作法,点子",
"methodical":"a:井井有条,井然,有条有理",
"methodically":"a:有条不紊;d:有条不紊",
"methodicalness":"n:章法",
"methodism":"n:墨守成规",
"methodology":"n:方法论,分类法",
"methyl":"n:甲基,甲醇,木醇",
"methyl alcohol":"n:木醇",
"meticulous":"a:精细,细,细心,细致,细密;v:一丝不苟,致",
"meticulously":"d:无微不至,精心",
"metre":"n:格律,拍子",
"metric":"n:度量;a:公制",
"metric system":"n:公制,国际公制,米制",
"metrical":"a:诗,韵律",
"metrics":"n:韵律学",
"metro":"n:地铁,地下铁道",
"metronome":"n:节拍器",
"metropolis":"n:大都市,中心,都,首都,通都大邑,都会,都市,首府;d:都",
"metropolitan":"n:大主教,首都",
"mettle":"n:性格,气质,精神,勇气,脾性,气慨,气概",
"mettlesome":"a:活龙活现",
"mew":"n:海鸥,鸟笼",
"mews":"n:公寓,马厩",
"mexico":"n:墨西哥,墨",
"mezzanine":"n:夹层,底层",
"mezzo":"n:适中,半,一半",
"mezzo-soprano":"n:女中音",
"mi":"n:米",
"miami":"n:迈阿密",
"miao":"n:苗",
"miaow":"n:咪咪",
"miasma":"n:瘴气,瘴,毒气",
"mica":"n:云母",
"mice":"n:老鼠",
"mickey":"n:骄傲,傲慢,自夸",
"mickey mouse":"n:米老鼠,尝试",
"micro":"a:微量",
"microbe":"n:微生物,细菌",
"microbiology":"n:微生物学",
"microcomputer":"n:微电脑",
"microcosm":"n:缩影,微观世界",
"microcosmic":"a:微观",
"microelectronics":"n:微电子,微电子学",
"microfiche":"n:缩微胶片",
"micrometer":"n:测距器,千分尺,目镜",
"micron":"n:微米,微粒",
"micronesia":"n:密克罗尼西亚",
"microorganism":"n:微生物",
"microphone":"n:麦克风,话筒,扩音器,传声器,送话器,微音器",
"microprocessor":"n:微处理机,微处理器",
"microprocessors":"n:微处理器",
"microscope":"n:显微镜",
"microscope slide":"n:镜台",
"microscope stage":"n:镜台",
"microsecond":"n:微秒",
"microwave":"n:微波",
"microwave oven":"n:微波炉,微波灶",
"microwaves":"n:微波",
"mid":"p:在_之间,之间;n:中;a:中",
"midair":"n:空中,上空",
"midday":"n:中午,正午,晌午,亭午,午",
"midden":"n:堆肥",
"middle":"n:中间,中部,中央,中,腰部,中间人,就中,正当中,正中,中人,当央,将指;a:中间派",
"middle age":"n:中年",
"middle ages":"n:中古",
"middle class":"n:中班",
"middle distance":"n:中景",
"middle east":"n:中东",
"middle finger":"n:将指,中拇指",
"middle of the roader":"n:中间派",
"middle term":"n:中词",
"middle-level":"n:中层",
"middleman":"n:中间人,中人,牙行,掮客,牙侩,经纪人,侩,牙子",
"middling":"a:中等,中不溜儿;d:相当,中等",
"middy":"n:晌午",
"mideast":"n:中东",
"midge":"n:蠓,小个子",
"midget":"n:小个子,侏儒;a:小型",
"midland":"n:内地",
"midnight":"n:午夜,半夜,深夜,子夜,夜半,黑暗;a:黑暗",
"midpoint":"n:中点",
"midriff":"n:横膈膜,肚子",
"midst":"n:中央,中,中间,中部;p:在_之间,之间",
"midstream":"n:中流,中游",
"midsummer":"n:仲夏,盛夏,夏至",
"midterm":"n:期中",
"midway":"n:中途,半路,半道儿,半途;d:中途",
"midweek":"n:星期三",
"midwife":"n:产婆,老娘,接生员,助产士",
"midwifery":"n:收生,助产士",
"midwinter":"n:仲冬,冬至,隆冬,穷冬",
"midwives":"n:助产士",
"mien":"n:态度,样子,姿,风采,举止,风度,神采,神态",
"miff":"v:生气,发脾气,恼羞成怒;n:生气",
"miffed":"a:恼火",
"might":"n:能力,威力,力气,力量,智力,强权,势力;v:该,无论;a:威武;c:要",
"mightily":"d:极,非常",
"mightiness":"n:强烈,伟大,有力,高位",
"mighty":"a:强有力;d:趾高气扬,大",
"migraine":"n:偏头痛",
"migrant":"n:移民;a:移居",
"migrate":"v:迁徙,迁移,移居,移民",
"migration":"n:迁移,移居,迁徙,移动,洄游;v:回游,移动",
"migratory":"a:迁移",
"mikado":"n:天皇",
"mike":"n:传声器,扩音器,送话器,话筒,微音器,麦克风;v:鬼混",
"milady":"n:夫人",
"milan":"n:米兰",
"milch cow":"n:摇钱树",
"mild":"a:温和,轻度,和,柔和,和缓,和平,清淡,软,温;v:温和",
"mild steel":"n:低碳钢",
"mildew":"n:霉,霉病;v:霉变",
"mildewed":"v:霉;n:霉",
"mildewy":"a:白粉病",
"mildness":"n:柔和,温和",
"mile":"n:英里,哩,迈;v:迈",
"mileage":"n:里程,利润,好处,运费",
"mileometer":"n:计程表",
"milepost":"n:里程碑",
"milestone":"n:里程碑",
"milieu":"n:环境,背景",
"militancy":"n:好战,战斗性",
"militant":"v:战斗;a:战斗;n:斗士",
"militarisation":"n:军国主义",
"militarism":"n:军国主义,尚武",
"militarist":"n:军事家,军阀",
"militaristic":"a:黩武",
"militarization":"n:军事化",
"militarize":"v:武装,军事化",
"military":"n:军队,器械,军人;a:军用",
"military attache":"n:武官",
"military band":"n:军乐团",
"military campaign":"n:战役",
"military control":"n:军事管制",
"military force":"n:武力",
"military governor":"n:都督",
"military music":"n:军乐",
"military officer":"n:武将",
"military police":"n:宪兵队",
"military policeman":"n:军警",
"military science":"n:军事科学",
"military service":"n:兵役,役",
"military training":"n:军训",
"military uniform":"n:军装",
"militate":"v:影响,战斗,争,冲突",
"militia":"n:民兵,国民军",
"militiaman":"n:民兵",
"militiamen":"n:民兵",
"milk":"n:牛奶,奶;v:偷听",
"milk cow":"n:奶牛,乳牛",
"milk vetch":"n:紫云英",
"milker":"n:乳牛",
"milkiness":"n:柔弱,乳白色,温顺",
"milking":"v:挤奶",
"milksop":"n:懦夫",
"milky":"a:牛奶,乳白",
"milky way":"n:银河",
"milky way galaxy":"n:银河",
"milky way system":"n:银河系",
"mill":"n:工厂,磨坊,厂;v:锯,碾碎,粉碎,铣",
"millennium":"n:太平盛世",
"miller":"n:米勒,厂主,铣床,铣工",
"millet":"n:谷子,小米,谷,稷,芑,黍子,粟,黍,禾,粟子,黄米",
"millibar":"n:毫巴",
"milligram":"n:毫克",
"milliliter":"n:毫升",
"millimeter":"n:毫米,公厘",
"milling":"n:铣,碾碎,磨炼,磨,考验",
"million":"n:无数,许许多多,兆",
"millionaire":"n:百万富翁,富豪,巨富",
"millisecond":"n:毫秒",
"millstone":"n:磨盘,磨,石磨,碾盘,重担",
"millstones":"n:磨",
"milometer":"n:计程表",
"mils":"n:毫升",
"milt":"n:鱼白",
"miltown":"n:眠尔通",
"mime":"n:丑角,小丑,笑剧",
"mimeograph":"v:打印,油印;n:油印机;a:油印",
"mimic":"v:模仿,学,模写,摹拟;n:丑角,仿制品;a:迷你",
"mimicry":"n:模仿,摹拟,模写,拟态",
"mimosa":"n:含羞草",
"min":"n:分钟",
"minamata disease":"n:水俣病",
"mincer":"n:绞肉机",
"mincing":"n:肉末;a:慢条斯理",
"mind":"n:人,头脑,思想,脑子,脑海,想法,心;v:反对,照料,在乎,嫌,在心,照应,留心",
"mind's eye":"n:心目",
"mindedness":"n:心路",
"mindful":"a:经心,经意",
"mine":"n:矿,矿井;v:发射,开矿",
"mine detector":"n:探雷器",
"minefield":"n:雷区",
"miner":"n:矿工",
"mineral":"n:矿物;a:矿物",
"mineral jelly":"n:矿脂",
"mineral oil":"n:矿物油",
"mineral pitch":"n:柏油",
"mineral resources":"n:矿藏",
"mineral water":"n:矿泉",
"mineral wax":"n:石蜡",
"mineral wool":"n:玻璃棉,矿棉",
"mineralization":"n:矿化;v:矿化",
"mineralogy":"n:矿物学",
"minerals":"n:矿物,矿产",
"ming dynasty":"n:明代",
"mingle":"v:混,夹,混合,混杂,参加,掺,混淆,掺杂,交织,搅和,阑入,羼杂,糅;a:杂",
"mini":"n:超短裙,迷你裙",
"miniature":"n:缩影;v:具体而微,缩写;a:微型,小型;d:微型",
"miniaturise":"v:微型化",
"miniaturization":"n:微型化",
"miniaturize":"v:微型化",
"minibus":"n:公共汽车",
"minicomputer":"n:小型机",
"minimize":"v:轻视",
"minimum":"a:最低,起码;n:底限",
"mining":"n:采矿,矿业;v:采矿",
"minion":"n:宠臣,奴才,走狗,宠儿,宠物,僚属",
"miniskirt":"n:超短裙,迷你裙",
"minister":"n:部长,大臣,牧师,政府,首相,公使;v:侍奉,举行,供给",
"ministration":"n:救助,救济,服务,帮助,职务",
"ministry":"n:部,服务,侍奉",
"mink":"n:黄鼠狼,水貂",
"minneapolis":"n:明尼阿波利斯",
"minnesota":"n:明尼苏达",
"minnows":"n:鱼花",
"minor":"n:小前提,小调;a:小,次要",
"minor key":"n:小调",
"minor scale":"n:小调",
"minor term":"n:小词",
"minority":"n:少数,少数民族;a:少数",
"minsk":"n:明斯克",
"minstrel":"n:歌手,音乐家",
"minstrelsy":"n:吟唱,弹琴,诗歌",
"mint":"v:造,铸造,打算,创造;n:富源,巨额,尝试;a:崭新",
"mintage":"n:刻印,铸币,铸造",
"minuend":"n:被减数",
"minus":"p:减;n:欠缺;v:没有,减少,减去;a:负",
"minute":"n:一会儿,记录,分钟;a:微;v:记录",
"minute book":"n:记事簿",
"minuteman":"n:民兵",
"minuteness":"n:微小",
"minutes":"n:记录",
"minutia":"n:细节,细目,小节",
"minutiae":"n:细目,小节,细节,琐事",
"miracle":"n:奇迹,神异,怪事,奇事",
"miraculous":"a:神奇,出神入化,神异",
"mirage":"n:海市蜃楼,蜃景,幻想,妄想,幻像,幻景",
"mire":"n:泥坑,泥淖,泥潭,泥沼,污辱,侮辱;v:涂,一筹莫展",
"mirror":"n:镜子,反射镜;v:照,映,反射",
"mirror image":"n:镜象,镜像",
"mirth":"n:高兴,欢乐,欢笑",
"mirthful":"a:嘻嘻哈哈",
"mirthfully":"d:快快乐乐",
"miry":"a:泥泞",
"misadventure":"n:不幸,横祸,灾难",
"misanthropic":"a:愤世嫉俗",
"misanthropy":"n:愤世嫉俗,厌世",
"misapplication":"n:误用",
"misapply":"v:误用,滥用",
"misapprehend":"v:误解,误会",
"misapprehension":"n:误会,误解",
"misappropriate":"v:挪用,滥用,侵吞,霸占,吞没,侵占",
"misbegotten":"a:私生",
"misbehave":"v:失态,不成体统,作弊",
"misbehavior":"n:胡作非为",
"misbehaviour":"n:胡作非为",
"miscalculate":"v:失算,失策",
"miscalculation":"n:差池",
"miscarriage":"n:失败,流产,失策,早产,小月,小产;v:流产,小产",
"miscarry":"v:流产,失败,小产,失策,早产",
"miscegenation":"n:杂种,混血种",
"miscellanea":"n:杂记",
"miscellaneous":"a:五花八门,繁杂,各色,什,芜杂,杂,杂七杂八,冗杂;n:杂项",
"miscellanies":"n:杂记",
"miscellany":"n:杂烩,杂记,混合物,杂拌儿,杂物",
"mischance":"n:横祸,不幸,灾难,故障",
"mischief":"n:恶作剧,捣蛋,淘气,顽皮,危害,胡闹,损害,伤害,灾祸,病源,祸根,故障;v:捣蛋",
"mischievous":"a:淘气,顽皮,促狭;v:促狭",
"misconceive":"v:误解",
"misconception":"n:误解,错觉",
"misconduct":"n:通奸,过失,胡作非为,罪;v:胡作非为",
"misconstruction":"n:曲解,误解,误会",
"misconstrue":"v:误解,误会,曲解",
"miscreant":"n:恶棍,歹人;a:堕落",
"misdeed":"n:胡作非为,罪行,劣迹;v:胡作非为",
"misdemeanor":"n:坏事,过失",
"misdemeanour":"n:过失,坏事",
"misdiagnose":"v:误诊",
"misdo":"v:作恶",
"misdoing":"n:恶行,坏事",
"miser":"n:守财奴,吝啬鬼,小气鬼,铁公鸡,财迷",
"miserable":"a:可怜,悲惨,凄惨,凄凉,酸辛,惨淡,悲惨惨,辛酸,凄怆,惨苦,贫弱,凄楚,悲苦,惨,凄",
"miserably":"d:非常,极",
"miserliness":"n:吝啬",
"miserly":"a:吝啬,爱财如命,抠门儿,啬,贫气,吝,悭,抠搜;v:爱财如命",
"misery":"n:苦难,不幸,悲惨,贫穷,惨状,苦处,苦痛,忧患,苦水,苦楚,疼痛",
"misfeasance":"n:犯罪,违法",
"misfire":"v:熄火",
"misfortune":"n:不幸,厄运,祸,不测,灾祸,灾难,患难,倒霉,私生子,恶运,殃;a:不测,邪;v:劫",
"misgiving":"n:顾虑,忧虑,不安;v:顾忌",
"misgivings":"v:疑惧;n:疑虑",
"misguide":"v:误导",
"mishap":"n:事故,意外,不测,灾祸,灾难,毛病;a:意外,不测;v:失",
"mishmash":"n:杂烩,混杂",
"misinform":"v:误传",
"misinformation":"n:误传",
"misinterpret":"v:曲解",
"misjudge":"v:低估,轻视,失策,失算,误判",
"mislay":"v:丢,丢失",
"mislead":"v:误导,惑,淆惑,贻误,哄骗;n:荧惑",
"mismanage":"v:措置失当",
"mismanaged":"v:措置失当",
"mismatch":"v:不配",
"misplace":"v:错位",
"misplacement":"n:错位",
"misplay":"n:失误",
"misprint":"n:错字",
"misprision":"n:玩忽职守,误解",
"misread":"v:误解",
"misremember":"v:记错",
"misreport":"n:谎报;v:谎报",
"misrepresent":"v:歪曲,误传,曲解,诬告,虚报,篡改",
"misrepresentation":"n:误传,虚报",
"misrule":"n:混乱,苛政,虐政,紊乱",
"miss":"v:错过,误,想念,怀念,想,不见,缺,漏掉;n:失误,逃脱,密斯,女士,悬念",
"misshapen":"a:残缺",
"missile":"n:导弹,飞弹;a:导弹",
"missilery":"n:飞弹",
"missing":"v:短少,丢三落四,故障;a:失去;n:故障",
"mission":"n:任务,使命,天职,代表团,传教,使团,大使馆,传道,特使,派遣,专差;v:派遣",
"missionary":"n:传教士",
"missioner":"n:传教士",
"missive":"n:公函,公文,信件,书信",
"missouri":"n:密苏里",
"misspeak":"v:失言,说错",
"misspell":"v:拼错",
"misspelling":"n:拼错",
"misspend":"v:虚度,滥用,浪费",
"misstate":"v:谎报",
"misstep":"n:过失,失策,失足,错误",
"missus":"n:太太,妻子",
"missy":"n:少女,小姐",
"mist":"n:雾,薄雾,雾气,云雾,烟雾,暮霭,烟,迷糊",
"mistake":"n:错误,错,差错,误会;v:走眼,失",
"mistaken":"v:拧,讹,错;a:错误,错,走眼",
"mistakenly":"d:错,误",
"misted":"a:迷离;v:迷离",
"mister":"n:先生,丈夫,老百姓",
"mistiness":"n:模糊",
"mistletoe":"n:槲寄生",
"mistreat":"v:苛待,虐待",
"mistress":"n:女主人,情妇,主妇,老板娘,第三者,姘头",
"mistrust":"v:信不过;n:疑惑",
"misty":"a:飘渺,蒙蒙,漠漠,模,缥缈",
"misunderstand":"v:误解,误会,弄错,曲解,误",
"misunderstanding":"n:误会,误解,隔阂,争执;v:误会",
"misuse":"v:滥用,误用;n:误用",
"mite":"n:螨,小孩,一臂之力,小孩子",
"miter":"n:头饰",
"mitigate":"v:减轻,缓和,平息",
"mitigation":"n:缓和",
"mitt":"n:逮捕,拳头,手铐,掌",
"mitten":"n:手",
"mittens":"n:手套",
"mitts":"n:手套",
"mix":"v:和,混合,混;n:混和,混乱;a:杂",
"mix up":"v:乱,混同,混作",
"mix-up":"n:混乱,迷惑,混合物,混战",
"mixed":"a:混合,杂;v:什锦,错杂;n:什锦",
"mixer":"n:混合器,搅拌器",
"mixing":"v:转录,搅拌,循环,混合,配音;n:录音,混合",
"mixture":"n:混合物,混合,混杂,药水,杂烩,合剂,杂拌儿;v:混合",
"ml":"n:汽艇",
"mnemonic":"n:助记符",
"mo":"n:莫",
"moan":"v:呻吟;n:悲叹,号,啸",
"moat":"n:城壕,池,壕,护城河",
"mob":"n:暴徒,匪帮;v:聚众;a:民众",
"mobile":"a:流动,机动,活动,运动;v:流动,飘忽",
"mobile phone":"n:手机",
"mobilisation":"n:动员",
"mobilise":"v:动员",
"mobility":"n:机动性,迁移性,爬升,活动性,灵活性,能动性",
"mobilization":"n:动员;v:动员",
"mobilize":"v:动员,调动,发动,排出",
"mobster":"n:歹徒,暴徒,匪徒,盗匪",
"mock":"v:嘲笑,嘲弄,挫败;n:嘲笑;a:假",
"mock sun":"v:假日",
"mockery":"n:嘲笑,嘲弄,模仿,笑柄,徒劳,挖苦,愚弄",
"modal":"n:模态",
"modality":"n:形式,形态,样式,模态,程式,方式",
"mode":"n:方式,模式,方法,模,模态,调式,格式,时髦,习惯,款式,样式,程式,式,式样,风尚,体裁,型,样,音律,法",
"model":"n:模型,型号,模式,模特儿,模范,榜样,款式,式样,典范,典型,样式,样板,范例,楷模,机型,模特,型,原型,法,表率;a:仿造,仿照,建造,设计,制作;v:塑造,训",
"model t":"v:旧式",
"modeling":"n:靠模,造型",
"moderate":"v:节制,主持;a:和缓",
"moderately":"d:适度,普通,适中",
"moderation":"n:适度,温和,节制,减轻,减弱,稳定,中庸,镇定,缓和,中等,减速",
"moderator":"n:减速剂,主席,议长,减速运动",
"modern":"a:现代,新式,摩登;n:现代,近人,今人",
"modern dance":"n:现代舞",
"modern man":"n:近人",
"modern times":"n:近世",
"modernise":"v:现代化",
"modernity":"n:新式",
"modernization":"n:现代化,维新",
"modernize":"v:现代化",
"modest":"a:谦虚,谦,谦逊,客气,谦卑,虚心,逊,伪,稳重,虚,卑",
"modestly":"d:谦和",
"modesty":"n:谦虚,谦逊,虚心,羞怯,朴实,节制,中肯,谨慎,谦和",
"modicum":"n:少量",
"modification":"n:修改,改进,变化,变态,修正,修饰,改良,更改,限制,变质,缓和,变型;v:变更,变型,修改",
"modifier":"n:修饰语",
"modify":"v:修改,改变,修饰,改装,改善,改,缓和,限制,调节,规定,变更,改动,更动,改用,变动,减轻,限定,变质",
"modish":"a:时髦",
"modulate":"v:调制,调幅,调节,变调,减轻,转调,抑扬,调整,缓和",
"modulation":"n:调制,变化,调节,抑扬;v:调制,调节,调整",
"modulator":"n:调节器",
"module":"n:模块,组件,模,舱,系数",
"modulo":"p:以_为模,模",
"modulus":"n:系数,绝对值",
"mogadishu":"n:摩加迪沙",
"mogul":"n:权贵,大人物,火车头,贵族,货车",
"mohair":"n:马海毛",
"mohammedanism":"n:回教",
"moiety":"n:一半,一部分",
"moil":"n:苦工,瑕疵",
"moire":"n:龟纹",
"moist":"a:潮湿,湿润,润湿,潮,润泽,湿乎乎,津,润,沮;n:潮,津;v:润泽",
"moisten":"v:濡,沾,渥;a:湿润",
"moistness":"a:潮湿;n:潮湿",
"moisture":"n:湿度,湿气,潮湿,水汽,潮气;v:接墒;a:潮湿",
"moke":"n:驴",
"molar":"n:臼齿,大牙,磨牙;a:咬牙",
"molasses":"n:糖蜜,糖浆",
"mold":"n:模具,模子,模型,霉菌,类型,图样,线脚;v:改变",
"moldavia":"n:摩尔达维亚",
"molder":"v:崩溃,腐朽",
"moldiness":"n:发霉",
"molding":"n:造型,翻砂",
"moldova":"n:摩尔多瓦",
"mole":"n:鼹鼠,克分子,防波堤,黑痣,痣,色痣,痦,针鼹,痦子,鼹,人工港,田鼠",
"mole cricket":"n:蝲蝲蛄,蝼,蝼蛄",
"molecule":"n:分子,克分子",
"molest":"v:骚扰,调戏,干扰",
"molestation":"n:折磨,干扰;v:折磨,干扰",
"mollification":"n:缓和",
"mollify":"v:解劝,安慰,缓和,减轻",
"mollusk":"n:软体动物",
"molly":"n:花匠",
"mollycoddle":"v:溺爱,娇养",
"moloch":"n:四脚蛇",
"molt":"v:蜕皮,脱掉,脱毛;n:脱毛",
"molten":"a:熔融",
"molting":"v:蜕皮",
"molybdenum":"n:钼",
"mom":"n:妈妈",
"moment":"n:片刻,时机,力矩,关头,瞬间,会儿,刻,矩,契机,霎,场合,势头,须臾;a:片刻",
"momentarily":"d:暂时,一瞬间,时时刻刻,一会儿,瞬刻",
"momentary":"a:短暂,一时,瞬息间;d:刹那间,暂",
"momentous":"a:重大,重",
"momentum":"n:动量,势头,冲力,声势,冲量,气势,势,惰性,要素",
"monaco":"n:摩纳哥",
"monarch":"n:君主,君王,帝王,君,王,统治者,辟,国君",
"monarchic":"a:君主",
"monarchy":"n:君主制,帝制,君主国",
"monastery":"n:修道院,寺院,禅房",
"monastic":"n:和尚,尼姑,僧侣,修道士,修女;a:修道院",
"monasticism":"n:禁欲主义,出家",
"monday":"n:礼拜一,周一",
"money":"n:钱,金钱,货币,资金,钱财,金,货,银根,钱币,钞票,银钱,财,钱钞,赀,财帛,钿,资,币,孔方兄",
"money market":"n:头寸",
"money order":"n:汇票",
"money supply":"n:头寸",
"moneybag":"n:钱包",
"moneybags":"n:财东,财主,老财",
"moneyed":"a:有钱",
"monger":"n:商人,贩子,贩",
"mongol":"n:蒙古族",
"mongolia":"n:蒙古,内蒙古,蒙族",
"mongolian":"n:蒙古族",
"mongoloid":"n:蒙古族,蒙古人种",
"mongoose":"n:獴",
"mongrel":"n:杂种",
"moniker":"n:绰号",
"monism":"n:一元论",
"monition":"n:传票,警告,训诫,忠告",
"monitor":"v:监视,监测,监听,监控,调节,监察;n:监测器,控制器,监视器,气楼,显示器",
"monitoring":"v:监听,监督,监视",
"monitoring program":"n:监控程序",
"monk":"n:僧侣,修道士,和尚,僧,僧人,衲,释子,隐士",
"monkey":"n:猴子,猴;v:戏弄,干涉",
"monkey around":"v:戏弄,胡闹",
"monkey bridge":"n:天桥",
"monkey business":"n:胡闹,欺骗",
"monkey-wrench":"v:破坏,阻挠",
"monochromatic":"a:单色",
"monocotyledon":"n:单子叶植物",
"monody":"n:挽歌",
"monograph":"n:专著,专论,专刊",
"monolith":"n:磐石",
"monolithic":"a:千篇一律,坚如磐石",
"monologue":"n:独白",
"monomer":"n:单体",
"monopolisation":"n:独占",
"monopolise":"v:独占",
"monopolization":"n:独占,专利",
"monopolize":"v:垄断,独占,揽,把,把揽,独揽,专营,把持,专,独霸,一手包办",
"monopoly":"n:垄断,专利权,专营;v:专卖,垄断",
"monorail":"n:单轨,单轨铁路",
"monosyllable":"n:单音词",
"monotheism":"n:一神教",
"monotone":"a:单调;n:单调",
"monotonous":"a:单调,千篇一律,枯燥;v:一成不变",
"monotony":"n:单调;a:单调",
"monroe doctrine":"n:门罗主义",
"monrovia":"n:蒙罗维亚",
"monsieur":"n:先生,绅士",
"monsoon":"n:季风,季节风,雨季",
"monster":"n:怪物,妖怪,怪,庞然大物,妖物,畸形,畸胎,魔,精怪,巨人,魔鬼",
"monstrosity":"n:怪异,穷凶极恶,怪物,畸形",
"monstrous":"a:不像话,怪异,怪,滔天",
"mont blanc":"n:勃朗峰",
"montage":"v:剪接,拼接,剪辑;n:装配,蒙太奇",
"montana":"n:蒙大拿,山区",
"monte carlo":"n:蒙特卡洛",
"montenegro":"n:黑山",
"montevideo":"n:蒙得维的亚",
"montgomery":"n:蒙哥马利",
"month":"n:月,月份",
"monthlies":"n:月经",
"monthly":"n:月,月经,月度,月报,月刊",
"montreal":"n:蒙特利尔",
"monument":"n:纪念碑,丰碑,古迹,名胜,雕像,墓穴,遗物,纪念物,界石,遗址",
"monumental":"a:纪念",
"moo":"n:牛肉",
"mooch":"v:揩油,偷走",
"moocher":"n:乞丐,食客",
"mood":"n:情绪,心情,语气,心境,心思,基调,情态,式,心怀,魂,心肠,意境,思绪,意绪",
"moodiness":"n:喜怒无常,情绪",
"moody":"a:郁郁寡欢,郁郁不乐",
"moon":"n:月球,月亮,卫星;v:闲荡,虚度",
"moon about":"v:闲荡",
"moon around":"v:闲荡",
"moon blindness":"n:夜盲症",
"moonbeam":"n:月光",
"moonlight":"n:月光,月色,月华",
"moonrise":"n:月光",
"moonshine":"n:月光,空谈,烈酒",
"moor":"n:泊;v:碇泊",
"mooring":"v:停泊",
"moorland":"n:沼泽",
"moose":"n:驼鹿",
"moot":"v:提出,不切实际,讨论,争论;n:讨论会,讨论;a:不切实际",
"mop":"n:墩布,拖把,抹子;v:肃清,扑灭",
"mop up":"v:肃清,扑灭",
"mope":"v:忧郁,闷闷不乐,闲荡,郁郁不乐;n:忧郁",
"moped":"n:轻骑",
"moppet":"n:小孩,婴儿",
"moraine":"n:碛",
"moral":"n:道德,寓意,教训",
"moral principle":"n:道义",
"morale":"n:士气,情绪,气,志气,风纪",
"moralise":"v:说教",
"morality":"n:道德,美德,道,品德",
"moralization":"n:教化",
"moralize":"v:教化",
"morals":"n:道德,德,道",
"morass":"n:困境,泥淖,泥塘,泥沼,泥坑,沼泽,泥潭",
"moratorium":"n:暂停,暂缓,宽限",
"moravia":"n:摩拉维亚",
"moray":"n:海鳗",
"morbidity":"n:病态,发病率,发病,病状",
"morbidness":"v:患病;n:病态",
"mordancy":"n:辛辣",
"more":"d:反而,更,一发,较为,更加,愈,愈发,再;a:多,外加;v:外加",
"more or less":"d:或多或少",
"more than":"c:不止,甚,不只,余,多于,大于",
"morel":"n:龙葵,羊肚蕈",
"moreover":"d:此外,而且,何况,另外,再者,外,与此同时,同时,况,另,加以;c:此外,再者,并且,再则,况且,与此同时;v:加以",
"mores":"n:风俗",
"morgan":"n:摩根",
"moribund":"a:垂死,气息奄奄;v:奄奄一息",
"mormonism":"n:摩门教",
"morn":"n:早晨",
"morning":"n:早晨,上午,早上,晨,午前,早起,朝,前半晌,前晌,早期;a:早,清晨",
"morning glory":"n:牵牛花",
"morning sickness":"n:孕吐",
"morning star":"n:启明星",
"morocco":"n:摩洛哥",
"moron":"n:蠢人,白痴",
"moronic":"a:呆傻,痴愚",
"morose":"a:怏怏不乐,别扭",
"morpheme":"n:语素,词素",
"morphia":"n:吗啡",
"morphine":"n:吗啡",
"morphological":"a:形态学",
"morphology":"n:形态学,组织,形态,构词法,词法,词形",
"morrow":"n:次日,早晨,翌日",
"morse":"n:海象",
"morsel":"n:少量,佳肴",
"mortal":"n:凡人,人类;v:致命;a:致命",
"mortality":"n:死亡率,人类",
"mortality rate":"n:死亡率",
"mortally":"d:深深地",
"mortar":"n:灰浆,迫击炮,灰,砂浆;v:炮击",
"mortgage":"v:抵押;n:分期付款",
"mortification":"n:屈辱,耻辱",
"mortify":"v:伤害,抑制,腐败",
"mortise":"n:卯眼,榫眼,凿",
"mortuary":"n:太平间;a:丧葬",
"mosaic":"v:嵌镶,镶嵌;n:马赛克",
"moscow":"n:莫斯科",
"mosey":"v:漫步",
"mosque":"n:清真寺",
"mosquito":"n:蚊子,蚊虫,蚊",
"mosquito boat":"n:快艇",
"mosquito net":"n:帐子",
"mosquitoes":"n:蚊子",
"moss":"n:苔藓,地衣,青苔",
"mossback":"n:绿毛龟",
"most":"d:顶,至,最为,绝,太,最,极其;a:多数,多半,绝大多数;n:大部分",
"most-favored-nation":"a:最惠国",
"mostly":"d:大部分,大多,多半,大都",
"mot":"n:警句",
"mote":"n:尘埃",
"moth":"n:蛾子,飞蛾,蛀,蛾,蛀虫,蠹虫,蠹",
"mothball":"n:樟脑丸,卫生球",
"mother":"n:母亲,妈妈,母,妈,慈母,母本,母畜,母株,娘;a:母",
"mother country":"n:发祥地",
"mother tongue":"n:国语,本族语",
"mother wit":"n:常识",
"mother-in-law":"n:婆婆,岳母,丈母,丈母娘",
"motherhood":"n:母性",
"mothering":"n:省亲",
"motherland":"n:祖国",
"motherly":"a:母亲",
"motif":"n:主题",
"motility":"n:游动,机动性,能动性",
"motion":"n:运动,动议;v:示意",
"motion picture":"n:电影,影片,影",
"motionless":"a:静止,静",
"motivate":"v:激发",
"motivation":"n:动机,动力;v:推动",
"motive":"n:动机,目的,用意,题材,心气,用心,作用",
"motive power":"n:原动力",
"motley":"a:混杂,五颜六色,丛杂,斑驳,五光十色;n:杂色",
"motor":"n:马达,发动机,电动机,运动,摩托,原动力,助推器",
"motor neuron":"n:运动神经",
"motorbike":"n:摩托车,轻骑",
"motorboat":"n:汽艇,电船,快艇,摩托艇,摩托船,汽船",
"motorcade":"n:车队,车组",
"motorcar":"n:汽车",
"motorcycle":"n:摩托车,摩托",
"motorized":"a:机动;v:机动",
"mott":"n:丛林",
"mottle":"n:斑纹,斑点;v:杂色",
"mottled":"a:斑驳,杂色",
"motto":"n:座右铭,格言",
"mould":"n:模子;v:捏,塑,形成,发霉,陶冶",
"moulder":"v:腐朽;n:铸工",
"moulding":"n:造型,翻砂,浇铸",
"mouldy":"a:霉;n:霉",
"moult":"v:蜕皮,脱落,脱毛,脱换;n:脱毛",
"moulting":"v:蜕皮",
"mound":"n:土墩,丘,墩,冈陵,圪垯,坨,疙瘩,岗;v:筑堤",
"mount":"v:安装,上升,装置,上,镶,登,增高,装裱,跨上,骑马;n:支柱,骑马",
"mount mckinley":"n:麦金莱山",
"mount up":"v:变成",
"mountain":"n:山,高山,山脉,山岭,岭,崮,山野",
"mountain chain":"n:山脉",
"mountain climbing":"n:登山",
"mountain pass":"n:陉",
"mountain peak":"n:峦",
"mountain range":"n:山峦",
"mountaineer":"v:登山",
"mountaineering":"n:登山,登山运动;v:登山",
"mountains":"n:群山",
"mountainside":"n:山腰,山坡",
"mountaintop":"n:山顶",
"mountebank":"n:大话,江湖骗子",
"mountie":"n:骑警",
"mounting":"n:架设,装潢",
"mourn":"v:哀悼,悼念,悲悼,悲哀,戴孝,悼,哀痛,吊,哀,哀伤;a:哀伤",
"mournful":"a:悲哀,凄然,悲切,悲痛,怆,凄切,酸溜溜",
"mourning":"n:哀悼,追悼,悲痛,丧;a:悲哀",
"mouse":"n:老鼠,耗子,小鼠,鼠,鼠标器;v:撕裂",
"mousetrap":"n:捕鼠器",
"mousing":"v:捕鼠",
"moustache":"n:须,胡须,髭",
"mouth":"n:嘴,嘴巴,口,口腔,嘴边,嘴头;v:注入,嚼,吃,怒骂",
"mouthing":"n:说话",
"mouthpiece":"n:喉舌,代言人,发话器,接口,应声虫",
"movable":"a:活动,浮,活;n:动产,家具",
"movables":"n:动产",
"move":"v:移动,动,搬,走,搬家,感动,迁,搬进,移;n:班,一手,迁,行径,招数,招子",
"move around":"v:倒",
"move back":"v:后退,退走,退",
"move back and forth":"v:摆弄",
"move in":"v:搬进,迁入",
"move into":"v:迁入,迁居",
"move out":"v:搬走,搬迁",
"move over":"v:挪动",
"move up":"v:提前",
"moved":"v:动心",
"movement":"n:运动,动作,活动,乐章,动,举动,动静,举止,运转,排泄物;v:动",
"movie":"n:电影,影片,片子,影,影片儿",
"movie theater":"n:电影院",
"movie theatre":"n:影院",
"moving":"a:感人,动人,活,动听,缠绵",
"mow":"v:割,芟除;n:草堆",
"mow down":"v:杀死",
"mower":"n:割草机",
"moxie":"n:精力",
"mozambique":"n:莫桑比克",
"mozart":"n:莫扎特",
"mp":"n:议员",
"mph":"n:时速",
"mr":"n:先生,君",
"mrs":"n:太太",
"mrs.":"n:太太,夫人",
"ms":"n:女士,中景",
"mu":"n:慕,市亩,牟,穆",
"much":"a:诸多;n:许多;d:很",
"mucilage":"n:粘胶,粘液,胶水",
"muck":"n:渣土,坢,污秽,脏土,粪肥,粪土,矸石,泥肥,污物;v:鬼混,学习,清扫",
"muck about":"v:鬼混,懒散",
"muck around":"v:鬼混,懒散",
"muckraker":"n:探听",
"mucosa":"n:粘膜",
"mucous membrane":"n:粘膜,黏膜",
"mucus":"n:粘液,黏液",
"mud":"n:泥,烂泥,泥浆,泥巴,泥淖,泥子;v:涂",
"mud flat":"n:滩涂",
"mud puddle":"n:泥坑",
"muddily":"d:污浊",
"muddiness":"n:混乱,泥泞",
"muddle":"v:混,浪费,得过且过,出租,鬼混;n:杂乱",
"muddled":"v:糊涂,懵,懵懂,昏;a:背悔",
"muddleheaded":"a:昏庸,傻,稀里糊涂;v:懵懂",
"muddy":"a:浑浊,混浊,浑,灰蒙蒙,污浊,浊;v:混,拖泥带水",
"mudguard":"n:挡泥板,挡板",
"muff":"n:失误,套筒,保温套,手笼;v:错过",
"muffle":"v:包裹,覆,捂住,捂;n:上唇,套筒,头巾",
"muffled":"a:闷",
"muffler":"n:围巾,减速器,头巾,围脖儿,消声器,减声器",
"mufti":"n:便服,便衣",
"mug":"n:缸子,脸,暴徒,蠢才,茶缸,傻瓜,生手",
"mugginess":"n:闷热,湿热",
"mugging":"v:路劫;n:抢劫",
"muggins":"n:笨蛋,蠢人",
"muggy":"a:闷热,郁热",
"mugwump":"n:大人物",
"mulatto":"n:混血儿",
"mulberry":"n:桑树,桑葚儿,扶桑,桑葚",
"mulch":"v:覆盖",
"mulct":"n:罚金,惩罚,罚款;v:惩罚",
"mule":"n:骡子,骡,冻疮",
"mull":"v:磨,深思熟虑,搅和,研磨",
"mull over":"v:摩,咀嚼",
"mullet":"n:梭鱼,鲻",
"multicolor":"a:彩色",
"multicolored":"a:花,五颜六色,花花绿绿,五彩,斑斓;v:五彩缤纷",
"multicolour":"n:彩色;a:彩色",
"multicoloured":"a:五颜六色,花,花花绿绿,斑斓,五彩;v:五彩缤纷",
"multifarious":"a:五花八门,千差万别;v:千差万别",
"multifariously":"d:万端",
"multifunctional":"a:多功能",
"multilateral":"a:多边,多国",
"multilayer":"a:多层次",
"multilevel":"a:多层次",
"multimedia":"n:多媒体",
"multimeter":"n:万用电表,万用表",
"multinational":"a:多国,跨国",
"multiple":"a:多种;n:倍数",
"multiplex":"v:复工",
"multiplicand":"n:被乘数",
"multiplication":"n:乘法,增殖,倍增,增加;v:增生,增殖,倍增,放大",
"multiplicity":"n:大量,多样,复杂",
"multiplier":"n:乘数,乘法器",
"multiply":"v:繁殖,乘,相乘,增加,倍增,繁衍,生息,增殖,扩大,孳生,翻,滋生;d:倍加",
"multiprogramming":"n:多道程序",
"multistage":"a:多级",
"multistage rocket":"n:多级火箭",
"multitude":"n:大量,人群,黎,众,组,众多",
"multitudinous":"a:庶,洋,众多,苠,森",
"mum":"n:妈妈,妈,娘,沉默,老娘",
"mumble":"v:嘟囔,咕噜;n:咕哝",
"mummer":"n:演员",
"mummery":"n:哑剧",
"mummify":"v:干瘪",
"mummy":"n:木乃伊,妈妈,妈",
"mumps":"n:腮腺炎,痄腮",
"munch":"v:嚼",
"mundane":"a:世间",
"mung":"n:绿豆",
"munich":"n:慕尼黑",
"municipality":"n:市,市政府",
"munificence":"n:慷慨",
"munificent":"a:优厚",
"munition":"n:军需品",
"munitions":"n:军火,军需品",
"mural":"n:壁画,墙壁",
"murder":"v:谋杀,杀害;n:暗害,惨杀;a:凶",
"murder charge":"n:杀人罪",
"murderer":"n:凶手,杀人犯,凶犯,凶徒",
"murderous":"a:杀人,杀气腾腾;v:杀气腾腾",
"muriatic acid":"n:盐酸",
"murk":"n:黑暗,阴沉,暗",
"murky":"a:阴暗,涔涔,昏沉",
"murmur":"n:怨言;d:喃喃,咕噜;v:咕哝",
"murphy":"n:马铃薯",
"murrain":"n:瘟疫",
"murray":"n:墨累河",
"muscat":"n:马斯喀特",
"muscle":"n:肌肉,肌,筋,瘦肉",
"muscle fiber":"n:肌纤维",
"muscleman":"n:打手",
"muscles":"n:筋肉,肌肉",
"muscovy":"n:俄国",
"muscular":"a:强健,粗壮",
"muse":"v:沉思,默想,冥想,暗想",
"museum":"n:博物馆,美术馆,博物院",
"mush":"n:脸,泥煤;v:干扰",
"mushroom":"n:蘑菇,香菇,菌子,菌,香蕈",
"mushy":"a:烂",
"music":"n:音乐,乐曲,乐谱,乐,谱,谱子,曲,丝竹",
"music box":"n:八音匣子",
"music hall":"n:音乐厅",
"music stand":"n:乐谱架",
"musical":"n:歌舞片,音乐片,音乐会;a:音乐",
"musical interval":"n:音程",
"musical note":"n:音符",
"musical scale":"n:音阶",
"musicale":"n:音乐会",
"musician":"n:音乐家,乐师,作曲家",
"musk":"n:麝香,麝",
"musk deer":"n:香獐子,香獐",
"muskeg":"n:沼泽",
"musketeer":"n:步兵",
"muskiness":"n:麝香",
"muskmelon":"n:香瓜,甜瓜",
"muskrat":"n:麝鼠",
"muslim":"n:穆斯林,伊斯兰;a:清真",
"muslin":"n:洋纱,伊斯兰,棉布",
"muss":"n:混乱,一团糟,骚乱",
"mussel":"n:淡菜,壳菜,贻贝",
"mussolini":"n:墨索里尼",
"must":"v:必须,要,得,应该,须,不可,当,务必,总得,必,必得,须要;n:霉,必得,果汁;d:务必,务须,非得",
"mustache":"n:须",
"mustachio":"n:须",
"mustang":"n:野马",
"mustard":"n:芥末,芥,芥菜,榨菜",
"muster":"v:集合;n:集合,货样,检阅,样本",
"muster roll":"n:花名册",
"muster up":"v:集合",
"mustiness":"n:发霉,受潮,陈腐;v:发霉;a:陈腐",
"musty":"a:发霉",
"mutability":"n:可变性",
"mutable":"a:可变",
"mutant":"n:突变",
"mutate":"v:变异,变化,突变",
"mutation":"n:突变,盛衰;v:突变",
"mute":"a:默默,哑然无声,哑,缄默;n:弱音器,哑子,哑巴;v:哑,不声不响",
"mutely":"d:默默",
"muting":"v:叛变",
"mutiny":"v:叛变;n:叛变,兵变",
"mutt":"n:笨蛋",
"mutter":"v:叽咕,沉吟;d:喃喃;n:咕哝",
"mutton":"n:羊肉",
"mutton tallow":"n:羊脂",
"mutual":"a:相互,互相,互;n:交,双方;v:相关;d:互相",
"mutual induction":"n:互感应",
"mutuality":"n:依存,亲密,同感,双方",
"mutually":"d:互相,对,彼此,相,互",
"mutually beneficial":"a:互惠,互利",
"muzzle":"n:枪口;v:收,钳制",
"my":"a:我,我的,贱,舍,家;r:我,敝;n:家",
"myelitis":"n:脊髓炎,骨髓炎",
"myna":"n:八哥儿,鸲鹆,八哥",
"myopia":"n:近视,短视",
"myopic":"a:目光短浅",
"myriad":"a:无数,万,巨万,万千",
"myrmidon":"n:部下,跟班",
"myrrh":"n:末药",
"myself":"r:自己,本人,不才,亲自",
"mysterious":"a:神秘,不可思议,秘,魔,玄妙,神乎其神",
"mystery":"n:神秘,谜,奥秘,疑案,玄虚,行会,行业",
"mystical":"a:神秘;n:神异",
"mysticism":"n:玄想,玄妙,神秘",
"mystification":"n:迷惑,不可思议",
"mystify":"v:装神弄鬼",
"mystifying":"v:故弄玄虚;a:阴阳怪气",
"mystique":"n:神秘感,秘诀",
"myth":"n:神话",
"mythical":"a:神话",
"mythologize":"v:讲述",
"mythology":"n:神话",
"na":"n:钠,那",
"nab":"v:山嘴,拘捕,逮捕;n:山嘴",
"nadir":"n:最低点",
"nag":"v:困扰,纠缠,责骂,恼人;n:劣马",
"nagasaki":"n:长崎",
"nagger":"n:泼妇",
"nail":"n:钉子,指甲;v:约束",
"nail down":"v:约束",
"nail polish":"n:指甲油;v:指甲油",
"nailed":"v:抓住",
"naive":"a:天真,幼稚,老实",
"naivete":"n:朴素,天真",
"naivety":"n:天真,朴素",
"naked":"a:光,赤裸裸,裸体,无,一丝不挂,赤条条,光溜溜,光溜,赤光光,裸,裸袒,赤身露体;v:赤身露体",
"nakedness":"n:赤裸裸,坦白",
"name":"n:名字,名称,名;v:指名道姓,起名儿,指派",
"name tag":"n:名牌",
"nameless":"a:无名",
"namely":"d:即,换句话说,换言之;c:就是说",
"nameplate":"n:名牌,报头,铭牌",
"namibia":"n:纳米比亚",
"naming":"v:定名",
"nanchang":"n:南昌",
"nanjing":"n:南京",
"nanny":"n:保姆,乳母",
"nanometer":"n:毫微米",
"nanosecond":"n:毫微秒",
"nap":"n:小睡;v:起毛,打盹儿,睡觉",
"nape":"n:脖颈儿,脖颈,项,脖颈子",
"naphtha":"n:石油",
"naphthalene":"n:萘",
"napkin":"n:餐巾,尿布,头巾,月经带",
"naples":"n:那不勒斯",
"napoleon":"n:拿破仑",
"nappy":"n:尿布",
"nara":"n:奈良",
"narc":"n:密探",
"narcissism":"n:自我陶醉",
"narcissist":"n:孤芳自赏",
"narcissistic":"v:孤芳自赏,自我陶醉;a:自我陶醉,孤芳自赏",
"narcissus":"n:水仙花,水仙",
"narcosis":"n:麻醉;v:麻醉",
"narcotic":"n:麻醉剂,麻醉药,麻醉品,自我陶醉",
"narcotics":"n:毒品,毒",
"narcotize":"v:麻痹,麻醉",
"narrate":"v:讲,叙述,解说,讲述,叙说,诉说,描述,状,述评,述说,述,写,叙事,铺叙,叙,记叙;n:叙,述评,状",
"narration":"n:叙述,铺叙,讲述,故事",
"narrative":"n:叙事文",
"narrator":"n:讲解员",
"narrow":"a:狭窄,窄,狭隘;v:眯,缩减,逼;n:峡谷,隘",
"narrow down":"v:缩减",
"narrow escape":"n:九死一生",
"narrow-minded":"a:鸡肠鼠肚,小肚鸡肠;v:心窄",
"narrowly":"d:险些",
"narrowness":"n:狭小",
"nasal":"n:鼻音",
"nasal bone":"n:鼻骨",
"nasalize":"v:发",
"nascence":"n:起源",
"nastiness":"n:污秽",
"nasty":"a:讨厌;v:讨厌",
"nation":"n:国家,国,民族,国度,种族,邦",
"national":"n:国民,全国性,国",
"national flag":"n:国旗",
"nationalism":"n:民族主义,爱国心",
"nationality":"n:国籍,民族,族,家",
"nationalization":"n:国有化;v:国有化",
"nationalize":"v:国有化",
"nationwide":"a:全国,全国性;n:全国性",
"native":"a:祖国,本地,土,天然,本,素;n:特产;r:本地",
"native land":"n:本国",
"nativity":"n:诞生,圣诞节",
"natter":"v:瞎扯,发牢骚",
"natty":"a:整洁",
"natural":"a:天然,当然,大方,朴质;n:天",
"natural endowment":"n:禀赋",
"natural gas":"n:天燃气",
"natural law":"n:天道",
"natural resources":"n:资源,富源",
"naturalisation":"n:同化",
"naturalise":"v:归化",
"naturalism":"n:自然主义",
"naturalization":"n:入籍,归化",
"naturalize":"v:归化,入籍,驯化",
"naturally":"d:自然,生来,自,自然而然,本来,理所当然;a:自是",
"naturalness":"n:纯真,自然,逼真度,当然",
"nature":"n:性质,大自然,自然,自然界,本性,天性,本质,性格,天,秉性,造化,质,树液,先天性,性能,造物,真性,树脂,性,属性",
"naught":"n:零,泡影,无;a:毫无",
"naughtiness":"n:皮",
"naughty":"a:淘气,顽皮,调皮,淘,坏蛋;v:皮,淘;n:皮",
"nauru":"n:瑙鲁",
"nausea":"n:恶心,呕,晕船",
"nauseate":"v:作呕,厌",
"nauseating":"a:恶心,腻人;v:令人作呕",
"nauseous":"a:腻人",
"nautical mile":"n:吨海里,俚",
"nautilus":"n:鹦鹉螺",
"naval":"a:军舰",
"naval gun":"n:舰炮",
"nave":"n:套,毂",
"navel":"n:肚脐,肚脐眼儿,脐,中心",
"navigate":"v:横渡,航行,驾驶,导航,领航,横穿,行船,航空",
"navigating":"v:航渡",
"navigation":"n:导航,航行,航海,领航;v:导航,航海",
"navigator":"n:领航员,航海家,领航",
"navvy":"n:工人,挖土机,掘土机,挖掘机;v:掘",
"navy":"n:海军,水师;a:藏青",
"navy blue":"n:海军蓝,深蓝",
"nay":"d:不,而且,甚至,否;n:否定",
"nazarene":"n:基督教徒",
"nazi":"n:纳粹",
"near":"v:接近;a:侧,相近;p:靠近,接近;d:比邻,近旁,约略;n:比邻,近旁",
"near gale":"n:疾风",
"nearby":"d:跟前,就近,左近;n:近旁,左近,附近;a:附近,左近;p:在_附近",
"nearer":"p:离_较近",
"nearest":"n:最近;p:离_最近;d:最近",
"nearing":"v:垂",
"nearly":"d:几乎,差不多,险些,差点,差点儿,险,将近,几,仅,殆;a:差不多",
"nearness":"n:密切,靠近",
"nearsighted":"a:近视,近视眼,短视",
"nearsightedness":"n:短视,近视",
"neat":"a:整洁,整齐,平整,齐整,脆,齐楚,楚楚,匀实,利落,齐;v:整饬;n:井",
"neaten":"v:整理",
"neath":"p:在_之下,之下",
"neatness":"n:整洁",
"nebula":"n:星云,翳,云翳",
"necessaries":"n:需,必需品",
"necessarily":"d:必然,一定,必须,必,定然",
"necessary":"a:必要,必须;n:必需品,日用品;v:需",
"necessitate":"v:迫使",
"necessities":"n:必需品",
"necessity":"n:需要,必要,必要性,必然性,必然,危急,困难",
"neck":"n:脖子,颈部,颈;v:领,缩小",
"neckband":"n:领口;v:领",
"neckerchief":"n:领巾,围巾",
"necking":"n:搂抱",
"necklace":"n:项链,项圈,吊环",
"neckline":"n:领口,服饰",
"necktie":"n:领带,绞索",
"necrology":"n:讣告",
"necromancer":"n:方士,巫师",
"necromancy":"n:魔术",
"necropolis":"n:墓地",
"necropsy":"n:验尸",
"necrosis":"n:坏死,黑斑病,坏疽",
"nectar":"n:花蜜,蜜腺",
"nectarine":"n:蜜桃",
"need":"v:需要;n:贫穷",
"neediness":"n:贫穷,穷困",
"needle":"n:针,唱针,指针;v:穿过",
"needle bearing":"n:滚针轴承,球轴承",
"needlepoint":"n:针尖",
"needlework":"n:针线活,针线,刺绣,黹,女红,缝纫,针黹",
"needling":"v:针刺",
"needs":"n:需要,需求;v:需",
"needy":"a:贫穷,寒",
"negate":"v:否定,否认,否,抹杀;n:对立面,反面",
"negation":"n:否定,否认",
"negative":"v:否定,否决;n:负片,负数;a:阴性",
"negativeness":"n:否定性",
"negativity":"n:否定性",
"neglect":"v:忽略,忽视,忘,荒废,忘记,怠慢;n:忽略",
"neglected":"a:冷;v:冷",
"neglectful":"v:麻痹大意;a:麻痹大意",
"neglecting":"v:忽略",
"negligence":"n:疏忽,粗心大意,过失",
"negligent":"a:漫不经心,疲塌,苟;v:疏忽",
"negligible":"a:渺小;v:微不足道",
"negotiable instrument":"n:票据",
"negotiate":"v:谈判,商谈,协商,交涉,兑现,议定,妥协,打;n:打交道",
"negotiation":"n:商议,交易",
"negotiations":"n:谈判;v:谈判",
"negro":"n:黑人",
"negroid":"n:黑人",
"neigh":"n:咴儿咴儿,嘶,萧萧;v:嘶",
"neighbor":"n:邻居,邻座,街坊,比邻,邻人,邻舍,世人;v:邻接",
"neighborhood":"n:邻里,附近,街道,邻,里,里弄,方圆,闾",
"neighboring":"v:附近",
"neighborliness":"n:亲近",
"neighbors":"n:邻里",
"neighbour":"n:邻人,近邻,世人,街坊,邻座,邻舍",
"neighbourhood":"n:附近,邻里,街道;v:溜",
"neighbouring":"a:附近",
"neighbourliness":"n:亲近",
"neighbours":"n:邻里",
"nemesis":"n:报应,强手",
"neodymium":"n:钕",
"neologism":"n:新词",
"neon":"n:氖,霓虹灯",
"neon lamp":"n:氖管",
"neon tube":"n:氖管,霓虹灯",
"neonate":"n:新生儿",
"neophyte":"n:新手",
"neoplasm":"n:肿瘤",
"neoprene":"n:氯丁橡胶",
"nepal":"n:尼泊尔",
"nephew":"n:侄子,侄儿,外甥,阮,侄,内侄,表侄,甥",
"nephrite":"n:软玉",
"nephritis":"n:肾炎",
"nepotism":"n:裙带风,裙带关系",
"neptune":"n:海王星,海神",
"neptunium":"n:镎",
"nerd":"n:迷,蠢人",
"nerve":"n:神经,勇气,胆子;v:鼓舞",
"nerve cell":"n:神经元",
"nerve center":"n:神经中枢,中枢神经",
"nerve centre":"n:大本营",
"nerve ending":"n:末梢神经",
"nerve fiber":"n:神经纤维",
"nervous":"a:紧张,胆怯,张,战战兢兢,张皇失措,张皇,怯;v:神经过敏",
"nervous disorder":"n:神经错乱",
"nervous prostration":"n:神经衰弱",
"nervous tissue":"n:神经质",
"nervously":"d:战战兢兢",
"nervousness":"n:神经质,神经过敏,胆小,急躁",
"nest":"n:窝,巢;v:筑巢",
"nesting":"v:筑巢",
"nesting place":"n:发射场",
"nestle":"v:安居,安身",
"nestling":"n:婴儿,婴孩,幼儿,幼雏,雏鸟",
"nestor":"n:长老",
"net":"n:网;v:得到;a:纯净",
"net income":"n:净值",
"net profit":"n:纯利,余利",
"nether":"a:地下",
"netherlands":"n:荷兰",
"netherworld":"n:黄泉",
"nets":"n:网具",
"netting":"n:网",
"nettle":"v:激怒,惹;n:苦恼",
"nettle rash":"n:荨麻疹,风疹块",
"nettled":"v:急",
"network":"n:网络,网,电路,电视网,广播网",
"networking":"n:联网",
"neuralgia":"n:神经痛",
"neurasthenia":"n:神经衰弱",
"neurasthenic":"a:神经衰弱",
"neuritis":"n:神经炎",
"neuron":"n:神经原,神经细胞",
"neurone":"n:神经细胞",
"neurotic":"v:神经过敏;a:神经过敏",
"neuter":"n:工蜂,中性;a:无性",
"neutral":"a:中性,中立;n:中线;v:中立",
"neutralise":"v:中和",
"neutralism":"n:中立主义,中立",
"neutralist":"n:中立主义",
"neutrality":"n:中立,中性,中和,不偏不倚",
"neutralization":"n:中和;v:中和,对消",
"neutralize":"v:中和,抵消,抵销",
"neutrally":"d:中立",
"neutrino":"n:中微子",
"neutron":"n:中子",
"neutron bomb":"n:中子弹",
"never":"d:不,没有,从未,从不,决不,没,绝不,不要,不再,永不,从没,未曾,不曾,何尝",
"never mind":"c:没什么,没事,不要紧",
"never-ending":"a:川流不息",
"nevertheless":"d:仍然,不过,但,还是,虽然如此,可是,顾,然;c:然而,但是,不过,还是",
"nevus":"n:痣",
"new":"a:新,新奇,新式,新鲜,簇新;d:新近",
"new deal":"n:新政",
"new edition":"n:新版",
"new england":"n:新英格兰",
"new look":"n:新装,新貌",
"new mexico":"n:新墨西哥",
"new moon":"n:朔",
"new town":"n:卫星城",
"new year":"n:新年,元旦,年",
"new year's day":"n:元旦",
"new year's eve":"n:除夕",
"new york":"n:纽约市",
"new york city":"n:纽约市",
"new zealand":"n:纽芬兰",
"newbie":"n:新手",
"newborn":"n:新生儿,仔畜;a:新生",
"newborn baby":"n:赤子,产儿",
"newcastle disease":"n:鸡瘟",
"newcomer":"n:新手",
"newfangled":"a:新奇,新异",
"newfoundland":"n:纽芬兰",
"newly":"d:新,新近,重新,最近,再度,乍,又;a:新",
"newlywed":"n:新人",
"newness":"n:新,新奇,崭新",
"news":"n:消息,新闻,信息,音问,音信,息,音尘,风声,风,闻,音讯,音;v:闻",
"news report":"n:报道,新闻公报,通讯",
"newsboy":"n:报童",
"newsflash":"n:快报",
"newsletter":"n:通讯",
"newsman":"n:记者,新闻记者",
"newspaper":"n:报纸,报,白报纸,新闻纸",
"newspaperman":"n:报人,新闻记者",
"newspapers":"n:报章",
"newsprint":"n:报纸,白报纸,新闻纸",
"newsreel":"n:新闻片",
"newsroom":"n:报社,编辑部",
"newsstand":"n:报摊",
"newsweekly":"n:周报",
"newsy":"a:报童",
"newt":"n:蝾螈",
"newton":"n:牛顿",
"next":"n:下;d:下次;a:次;r:其二;c:其次",
"next door to":"p:相邻,与_相邻",
"next of kin":"n:亲,直系亲属",
"next to":"p:比,旁,在_旁,几乎,次于,接近,挨着,比邻",
"nexus":"n:关系,接合,联络,互连,联系,结合,连接;v:结合,接合",
"ni":"n:倪",
"niacin":"n:烟酸",
"niagara":"n:急流,瀑布",
"nib":"n:笔尖,尖头,尖端,嘴,字模,笔头",
"nibble":"v:咬,啃,吹毛求疵,蚕食,啮;n:啃",
"nibs":"n:头目",
"nicaragua":"n:尼加拉瓜",
"nice":"a:好,好吃,好看,良,可口",
"nicety":"n:精密,美好,考究,严密,优美",
"niche":"n:壁龛,适当的位置;v:放在适当的位置",
"nick":"n:缺口;v:摘记",
"nickel":"n:镍,镍币",
"nicker":"v:嘶叫,嘶",
"nicking":"n:刻痕,煤屑;v:刻痕",
"nickname":"n:绰号,诨名,外号,诨号",
"nicotine":"n:尼古丁,烟碱",
"niece":"n:侄女,外甥女,内侄女,甥女,表侄女",
"niff":"n:臭气",
"nigeria":"n:尼日利亚",
"niggard":"n:小气鬼",
"niggardly":"a:吝啬,小气;v:爱财如命",
"nigger":"n:黑人;v:耗尽",
"niggers":"n:灯花",
"niggling":"a:小手小脚",
"nigh":"p:接近,近于",
"night":"n:夜晚,夜间,夜,晚,黑夜,夜空,晚间,黄昏,黑暗;a:黑",
"night blindness":"n:夜盲,雀盲眼",
"night club":"n:夜总会",
"night owl":"n:夜游神,猫头鹰",
"night shift":"n:夜勤",
"night soil":"n:大粪,粪便",
"night watch":"n:守夜",
"night-blooming cereus":"n:昙花",
"nightcap":"n:睡帽,山颠",
"nightclothes":"n:睡衣",
"nightclub":"n:夜总会",
"nightfall":"n:黄昏,曛",
"nightgown":"n:睡衣,便装",
"nighthawk":"n:夜鹰",
"nightie":"n:睡衣",
"nightingale":"n:夜莺,歌鸲",
"nightlong":"d:通宵;a:彻夜",
"nightmare":"n:恶梦,噩梦,梦魇",
"nightshade":"n:龙葵",
"nighttime":"n:夜里,夜,夜间",
"nightwear":"n:睡衣",
"nihilism":"n:虚无主义,怀疑论",
"nil":"n:无,零;a:零,无",
"nile":"n:尼罗河",
"nile river":"n:尼罗河",
"nimble":"a:灵巧,灵活,敏捷,轻捷;v:眼明手快",
"nimbus":"n:光彩",
"nincompoop":"n:傻瓜,傻子",
"nine":"n:玖;a:九",
"ning":"n:宁",
"ninny":"n:憨子,傻子",
"niobium":"n:铌",
"nip":"v:夹,咬,掐,赶,阻止,扼杀,阻碍,偷,捏,逮捕,插嘴,夹住;n:讽刺,痛骂,虎钳,阻碍,严寒,霜害,寒气,少量",
"nipper":"n:吝啬鬼,镊子,小气鬼,钳子,手铐,脚镣",
"nipping":"v:夹住",
"nipple":"n:乳头,奶头,喷嘴,奶嘴",
"nirvana":"n:彼岸,极乐世界",
"nisi":"a:否则",
"nit":"n:虮,饭桶,卵,幼虫",
"niter":"n:硝,硝酸钾,硝石",
"nitpick":"v:挑毛拣刺,找岔子,挑,挑剔,求全责备,吹毛求疵",
"nitpicking":"v:求全责备",
"nitrate":"n:硝酸盐,硝酸钠,硝化,硝酸钾",
"nitric acid":"n:硝镪水",
"nitride":"n:氮化物",
"nitrification":"v:硝化;n:硝化",
"nitrogen":"n:氮,氮气",
"nitroglycerin":"n:硝化甘油",
"nitty-gritty":"n:事实,本质",
"nitwit":"n:笨蛋,傻子",
"nix":"n:没有,拒绝,无;v:禁止,拒绝,否决;i:不行;d:不",
"nixon":"n:尼克松",
"no":"d:不;n:否定,反对票,拒绝,否认;a:禁止,反对,不可;i:欸;c:不然",
"no doubt":"n:必定",
"no end":"n:无数",
"no longer":"d:不再",
"no man's land":"n:无人区",
"no matter":"p:不论,管,凭,任凭,随便,任;c:任凭",
"no more":"n:不再;d:不再",
"no one":"n:莫",
"nob":"v:打头;n:贵族",
"nobble":"v:逮捕,诈骗,收买",
"nobel":"n:诺贝尔",
"nobelium":"n:锘",
"nobility":"n:贵族,高尚,崇高,高贵,庄严;a:高尚",
"noble":"a:高贵,高尚;n:工头",
"nobleman":"n:贵族",
"nobleness":"n:高贵,高尚,崇高,宏大,庄严;a:高尚",
"nobly":"d:高贵,豪爽,宏伟,华美,壮丽,豁达,崇高",
"nobody":"n:小人物,无名小卒,小卒",
"nocturne":"n:夜曲",
"nod":"v:点头,打瞌睡;n:同意,诺言,打瞌睡",
"noddle":"v:点,点头;n:结核,头",
"node":"n:节点,结点,结,瘤,节,结节,结脉;v:结",
"nodule":"n:结核,根瘤,小结,瘤",
"noel":"n:圣诞节",
"noggin":"n:智力,脑筋,头",
"nohow":"d:绝不,毫不,决不",
"noise":"n:噪声,声音,噪音,响声,吵闹,声响,风声,闹,骚扰;v:响",
"noiseless":"v:无声;a:无声",
"noisily":"d:大声",
"noisiness":"n:吵闹",
"noisy":"a:嘈杂,响,闹,乱哄哄,闹哄哄,闹嚷嚷,闹热,喧,聒,嘈,聒噪;v:喧嚣,闹",
"nom de guerre":"n:化名",
"nom de plume":"n:笔名",
"nomad":"n:流浪者",
"nome":"n:省",
"nomenclature":"n:命名,名称;v:命名",
"nominal":"a:空头,虚设,徒有其名,徒有虚名,虚;v:挂名,虚设,徒有虚名,徒有其名;n:名义,体词",
"nominal value":"n:面值,票面",
"nominally":"d:有名无实",
"nominate":"v:提名,指定,任命,推荐,委任,命名,推选",
"nomination":"n:提名,任命,推荐,指定",
"nominative":"n:主格",
"non":"a:不是,甘紫菜",
"nonalignment":"n:不结盟",
"nonattendance":"n:缺席",
"nonce":"n:眼下,现时,当前",
"nonchalance":"n:冷淡",
"nonchalant":"a:漠不关心,淡漠,恬然",
"noncommissioned officer":"n:官佐,军士",
"noncommittal":"a:闪烁,活络;v:闪烁",
"noncompliance":"n:固执",
"nonconductor":"n:非导体,绝缘体,不良导体",
"nondescript":"a:不伦不类,不三不四;n:四不像",
"none":"d:决不,一个都,莫;a:没有",
"nonentities":"n:蝼蚁",
"nonentity":"n:无名小卒,小人物,虚构",
"nonesuch":"n:典型,典范",
"nonetheless":"d:不过,然而",
"nonexistent":"a:子虚乌有;v:子虚乌有",
"nonfat":"v:脱脂;a:脱脂",
"nongovernmental":"n:民间,草野",
"noninterference":"n:放任",
"nonlinear":"a:非线性",
"nonmetal":"a:非金属;n:非金属",
"nonobservance":"n:违反",
"nonpareil":"a:无比,无上",
"nonplus":"n:狼狈,窘境,迷惑,为难",
"nonpoisonous":"a:无毒",
"nonprofessional":"n:外行",
"nonresident":"n:走读生",
"nonresistance":"n:屈服",
"nonsense":"n:胡闹,胡说,废话,胡言,扯淡,狗屁,鬼话,乱弹,屁话,闲言闲语,梦话,屁;v:胡说",
"nonsensical":"a:不像话",
"nonspecific":"n:泛泛",
"nonstop":"a:直达,马不停蹄;v:直达",
"nonviolence":"n:非暴力",
"nonviolent":"a:非暴力",
"noodle":"n:面条,面;v:愚弄",
"noodles":"n:面条",
"nook":"n:角落,隅,背旮旯儿,旮旯儿,转角,岬角",
"noon":"n:中午,正午,午夜,晌午,午,顶点,晌,亭午,午间",
"noonday":"n:中午,全盛,正午",
"noontide":"n:中午",
"noontime":"n:中午",
"noose":"n:绞索,套,圈套,束缚,套索;v:绞死",
"nor":"c:和",
"norm":"n:准则,规范,指标,标准,艺,限额,定额,则,准,规格,模范,定量",
"normal":"n:垂直,当量;a:对头",
"normal distribution":"n:正态分布",
"normal school":"n:师范,师专",
"normalcy":"n:常态,当量",
"normality":"n:当量,常态,正规",
"normalization":"n:标准化,正常化,规范化;v:正规化",
"normalize":"v:正常化,标准化",
"normalizing":"v:标准化",
"normally":"d:通常,常,一般说来,按理,论理,论说,按说,照理,按理说;v:论说",
"normandy":"n:诺曼底,诺曼第",
"norms":"n:规格;d:常",
"north":"n:北方,北,北部,北风,北边,朔",
"north america":"n:北美洲",
"north pole":"n:北极",
"north sea":"n:北海",
"north temperate zone":"n:北温带",
"north-east":"n:东北",
"north-west":"n:西北",
"northeast":"n:东北",
"northeaster":"n:东北风",
"northeastern":"a:东北方",
"northeastward":"n:东北",
"norther":"n:北风",
"northern":"a:北方;n:北风",
"northern europe":"n:北欧",
"northern hemisphere":"n:北半球",
"northern ireland":"n:北爱尔兰",
"northwest":"n:西北,西北部",
"northwest wind":"n:西北风",
"norway":"n:挪威",
"nose":"n:鼻子,鼻,嗅觉,气味,机头,枪口,船头;v:险胜,探索,反对",
"nose cone":"n:头部,弹头",
"nose dive":"n:暴跌",
"nose out":"v:险胜",
"nosebag":"n:防毒面具",
"nosebleed":"n:衄,鼻衄,鼻出血,鼻血",
"nosecone":"n:头部",
"nosedive":"v:俯冲",
"nosegay":"n:花束",
"nosh":"n:食物,小吃;v:吃",
"nosing":"n:头部,机头",
"nostalgia":"n:怀旧,乡思,乡愁",
"nostalgic":"a:狐死首丘",
"nostril":"n:鼻孔,鼻子眼儿",
"nostrum":"n:秘方",
"not":"d:不,并不,没,别,未,非,毫不,莫,毋",
"not bad":"a:不赖,不错,可以,差不多",
"not guilty":"a:无罪",
"not only":"c:不仅,不但,不光,不止,岂但,不单,非但,不独,不只;a:岂止,不单,不只,非徒,何止",
"notability":"n:名人,显著",
"notable":"a:显著;n:名人,要人",
"notarization":"n:公证",
"notarize":"v:确认",
"notary":"n:公证人,书记,秘书",
"notary public":"n:公证人",
"notation":"n:符号,记号,标记,注释,乐谱,标志",
"notch":"n:切口,缺口,等,凹槽,峡谷,分数,级,山峡;v:切,搭,得,砍,开槽",
"notching":"v:多级;a:多级",
"note":"n:笔记,音符,记,便条,记录,条子,字条,注意,纸币,口气;v:启,注目,笔录,批点",
"notebook":"n:笔记本,笔记簿,簿子,作文簿,本子",
"noted":"a:著名,知名",
"notepad":"n:记事本",
"notepaper":"n:信纸,便笺",
"notes":"n:笔记,笔录,记,记录,杂记,杂志;v:注",
"nothing":"n:没有;d:莫;r:什么,什麽,无;a:空空",
"nothing short of":"p:完全",
"nothingness":"n:虚无,无,无关紧要,无聊;a:虚无",
"notice":"n:通知,注意,布告;v:提及,听到,介绍",
"notice board":"n:布告牌",
"noticeable":"a:引人注目;v:引人注目",
"noticeably":"d:显著,显然",
"notification":"n:通知,通知单,布告,告白,通告",
"notify":"v:通知,报告,公告,示,招呼,告知,通,布告,打招呼,晓示,报信,知,通告,照,知照,告,申报,宣告",
"notion":"n:概念,想法,观念,看法,见解,观点,想,打算,意图,观,意见,心头,意向,意志,理解",
"notoriety":"n:恶名,有名,臭名昭著;a:臭",
"notorious":"a:臭名昭彰;v:臭名远扬,臭名昭著",
"notwithstanding":"d:虽然,还是;p:虽然;c:尽管,虽然",
"nought":"n:毫无,零;a:零",
"noun":"n:名词",
"nourish":"v:滋养,养育,滋补,补,怀抱,教养,抱,助长,抚养",
"nourishing":"v:滋补",
"nourishment":"n:营养,养料,营养品,滋补品,助长,滋养品,培养,滋养,食物",
"nous":"n:常识,理性,理智,智力,精神",
"nov":"n:11月,十一月",
"nova":"n:新星,新秀,暂星",
"novel":"a:新奇,新,新颖,新鲜,新异;n:小说,长篇小说",
"novelette":"a:中篇;n:中篇小说",
"novelist":"n:小说家,作家",
"novella":"n:短篇小说",
"novellas":"n:中篇小说",
"novelty":"n:新奇,新颖,珍奇;a:新奇",
"november":"n:十一月,11月",
"novice":"n:初学者,生手,新手",
"novitiate":"n:见习期,生手",
"now":"d:现在,这,现,这时,目前,此刻,那么;n:当今,此刻,此时,今朝,今天,今日,目前,现时,现下,目下,眼前;r:这会儿,这,此,这儿,咱;c:既,由于",
"now that":"c:一旦,既,鉴于",
"nowadays":"d:现在,现今,现时,今儿;n:当今,时下,目今,如今,现今,现在",
"nowise":"d:决不",
"nowt":"n:公牛",
"noxious":"a:毒",
"nozzle":"n:喷嘴,管,喷头,漏孔,套管,接口",
"nuance":"n:神韵",
"nub":"n:要点,瘤,节,核心,瘤子",
"nubby":"a:块状",
"nuclear":"a:核扩散",
"nuclear energy":"n:原子能",
"nuclear engineering":"n:核工程",
"nuclear fission":"n:裂变",
"nuclear fusion":"n:聚变",
"nuclear magnetic resonance":"n:核磁共振",
"nuclear power":"n:核能",
"nuclear rocket":"n:核火箭",
"nuclear submarine":"n:核潜艇",
"nuclear warhead":"n:核弹头",
"nucleation":"n:集结",
"nuclei":"n:中心,核心",
"nucleolus":"n:核仁,细胞核",
"nucleon":"n:核子,单子",
"nucleus":"n:核,原子核,细胞核,核心,中心,蜂房,中坚,环",
"nude":"a:裸体,光",
"nudge":"v:接近",
"nudity":"n:裸体,赤裸,裸露",
"nugget":"n:金钱",
"nuisance":"n:讨厌,损害,妨害;a:累赘;v:讨厌",
"nuke":"n:核电站,核武器",
"nukes":"n:核武器",
"null":"n:零,零位,空行,空;a:零",
"nullification":"n:作废,取消,废弃,无效",
"nullify":"v:毁弃,作废,废弃,抹杀,注销,取消",
"nullity":"n:无效,零度,无",
"numb":"a:麻木,麻木不仁,僵;v:发麻",
"numbed":"v:麻木不仁",
"number":"n:数,许多,号码,数字,数目,数量,若干,号,多少;v:为数;a:多少",
"number one":"n:状元",
"numbness":"n:麻木;a:麻木",
"numeral":"n:数字,数码,字码,字码儿,数词,码子",
"numerate":"v:读,读出,计算,数",
"numeration":"n:读数,计算",
"numerator":"n:分子,计数器,计算器",
"numeric":"n:数,数字,分数",
"numerical":"a:数值",
"numerous":"a:许多,众多,繁多,诜,百,列,诸多,繁,广大,庶,洋洋,黎,猥,莘,殷,众,奂,瑟,上万,芸芸,纷,九,广,林林总总,不一而足",
"numskull":"n:笨蛋",
"nun":"n:修女,尼姑,姑",
"nuncio":"n:使者",
"nunnery":"n:尼姑庵,庵",
"nuptial":"n:婚礼,婚姻",
"nuremberg":"n:纽伦堡",
"nurse":"v:护理,照料,喂奶,培养,养成,抱,哺乳,看护;n:乳母",
"nurser":"n:奶瓶,奶妈",
"nursery":"n:苗圃,托儿所,苗床",
"nursery rhyme":"n:儿歌,歌谣",
"nursery school":"n:托儿所,保育院",
"nursing":"v:护理,调护;n:保育",
"nursing care":"n:护理",
"nursing home":"n:敬老院",
"nursling":"n:婴儿",
"nurture":"v:养育,培育;n:养育,教养,食物,训练",
"nut":"n:坚果,疯子,螺帽,螺母,怪人,笨蛋,傻瓜,果仁儿,仁果,难题,脑袋,果核",
"nut grass":"n:香附子",
"nut tree":"n:榛",
"nutation":"n:点头,垂头,下垂",
"nutcracker":"n:钳子",
"nutmeg":"n:肉豆蔻,肉果",
"nutria":"n:海狸鼠",
"nutrient":"n:养分,养料,营养元素,营养品",
"nutriment":"n:滋养,养料,营养品,营养素,粮,食物",
"nutrition":"n:营养,营养学,食物,滋养",
"nutritious":"a:滋补;v:滋补",
"nuts":"i:呸",
"nutshell":"n:大要",
"nuzzle":"v:掘",
"nylon":"n:尼龙,锦纶,玻璃",
"nymph":"n:若虫,美女",
"nympholepsy":"n:狂喜,狂乱",
"nymphomania":"n:色情狂",
"o":"a:可以,好,行,零,圆;i:啊",
"o'":"p:在_上",
"o'er":"p:之上,在_之上",
"oaf":"n:白痴,呆子",
"oak":"n:橡树,柞树,橡,柞",
"oak tree":"n:柞树",
"oar":"n:桨,船",
"oasis":"n:绿洲",
"oat":"n:燕麦,牧笛",
"oath":"n:宣誓,誓言,誓词,诅咒,誓,誓约",
"oatmeal":"n:麦片,燕麦,燕麦片",
"oats":"n:燕麦",
"ob":"n:鄂毕河",
"obduracy":"n:顽固,执拗,倔强,冷酷",
"obedience":"n:服从,遵守;v:服从",
"obedient":"a:服贴,忠顺,乖,贴;v:听话;n:帖",
"obeisance":"n:服从,敬意,尊敬,敬礼",
"obesity":"n:肥胖;a:肥胖",
"obey":"v:服从,遵守,听话,听,听从,照,从,遵从,遵照,遵办,随顺,服,顺,遵;p:由",
"obfuscation":"n:昏迷",
"obit":"n:祭奠,葬礼",
"obituary":"n:讣,讣告,讣闻",
"object":"n:物体;v:抗议,讨厌",
"object glass":"n:物镜",
"object lens":"n:接物镜",
"object lesson":"n:鉴戒",
"objectify":"v:体现",
"objection":"n:反对,意见,异议,缺点,妨碍,障碍,异同,缺陷,嫌恶,二话",
"objective":"n:目标,目的,物镜,任务,客,宾格,旨趣,出发点,接物镜",
"objective lens":"n:物镜,接物镜",
"objectiveness":"n:客观,客观性",
"objectivity":"n:客观,客观性",
"objurgate":"v:骂,谴责,斥责",
"oblate":"n:扁圆",
"oblation":"n:捐献,祭品,供献,供奉",
"obligate":"v:强迫,强制",
"obligation":"n:义务,责任,债务,职责,恩惠,契约,证券,负担,合约,本分",
"obligations":"n:义务",
"oblige":"v:效劳,给,借,迫使,责成",
"obliging":"a:婉顺,随和",
"oblique":"a:斜;v:倾斜,歪;d:颇",
"obliquely":"d:颇",
"obliqueness":"n:倾斜",
"obliquity":"n:倾斜,歪斜,斜度,转弯抹角,斜,斜面",
"obliterate":"v:抹杀,磨灭,涂改,清除,一笔抹煞,抹煞,涂抹,删去,除去,磨",
"obliteration":"n:消灭,灭迹,淹没,清除,删除",
"oblivion":"n:忘却,淹没,大赦;v:忘却",
"oblivious":"a:忘却,忘记",
"oblong":"n:长方形,椭圆形",
"obloquy":"n:耻辱,斥责",
"oboe":"n:双簧管",
"obscene":"a:下流,淫秽,猥亵,淫猥;n:黄色",
"obscenity":"n:脏话,猥亵",
"obscurantism":"n:蒙昧主义,愚民政策",
"obscure":"a:晦涩,暗,隐晦,朦胧;v:混淆,遮蔽,含糊其词,掩蔽,隐藏;n:黑夜,灰色",
"obscured":"v:相形见绌",
"obscurely":"d:暗暗,暗",
"obscurity":"n:含糊,阴暗,暗,不明",
"obsequies":"n:丧礼,葬礼",
"obsequious":"a:低三下四",
"obsequiousness":"n:媚骨,拍马,奴才相",
"observance":"n:仪式,遵守,教规,习惯,纪念,戒律,观察,庆祝,典礼,恭顺,惯例",
"observant":"a:注意,留心",
"observation":"n:观察,观测,注意,观察力,监视,意见,侦察,谈话,观望,发言,经验;v:观测,观察",
"observation post":"n:观察哨",
"observation station":"n:观象台,观察站,气象台,观察所",
"observatory":"n:天文台,气象台,观象台,望楼",
"observe":"v:观察,说,看到,注意,遵守,观测,看,评论,监视,恪守,知道,察看,讲,举行,观,评述,守,奉行,纪念,丕,庆祝,觇,察,陈述",
"observer":"n:观察家,观察员,旁观者,观测员,目击者,见证人",
"obsessed":"v:痴迷",
"obsession":"n:困扰,着魔,执意",
"obsolescence":"n:过时,陈旧,废弃,淘汰",
"obsolescent":"a:过时",
"obsolete":"a:过时,陈旧;v:老掉牙",
"obstacle":"n:障碍,障碍物,阻碍,妨碍,妨害,干扰;v:干扰",
"obstetrics":"n:产科",
"obstinacy":"n:固执,顽固,顽强,牛脾气,顽梗,牛劲",
"obstinate":"a:固执,倔强,顽固,拗,犟,硬,顽,梗,泥,执拗,刁蛮,顽梗",
"obstruct":"v:堵塞,挡住,妨碍,阻挡,挡,阻挠,干扰,梗,作梗,阻,隔断,遮,阻难,梗阻,拦,拦挡,拦阻,壅,障碍,阻滞,格,梗塞,障,碍,闭,妨,障蔽,遮蔽,阻拦,阻塞;n:障碍",
"obstructed":"a:不通",
"obstruction":"n:梗阻,障碍物,障碍,阻碍,遮断,堵塞;v:梗阻,阻塞",
"obstructive":"n:障碍,障碍物;a:障碍物",
"obtain":"v:得到,获得,取得,得,求得,得出,获,获取,流行,达到,赢得,牟取,收到,通行,谋取,博得",
"obtainment":"n:达成,获得",
"obtrude":"v:强迫,闯入,挤出,强加于人,伸出,打扰,强行",
"obtuse":"a:迟钝,迟,鲁钝",
"obtuse angle":"n:锐角",
"obtuseness":"n:愚钝,钝角",
"obverse":"a:正;n:表面",
"obviate":"v:防止,预防,除去,排除,避免",
"obviation":"n:除去",
"obvious":"a:明显,显然,显而易见,明摆着,较,明白,分明,明朗;v:显见;d:显然",
"obviously":"d:显而易见,明明,由此可见,显见,可见",
"occasion":"n:场合,机会,时刻,场面,事;v:引起",
"occasional":"a:偶尔,偶然",
"occasionally":"d:偶尔,偶,偶然,间或,不时,偶或",
"occident":"n:西方,西洋",
"occidental":"n:西方人,西;a:西",
"occipital":"n:枕骨",
"occipital bone":"n:枕骨",
"occlude":"v:堵塞,遮蔽,关闭,咬合,闭塞,封锁",
"occlusion":"n:闭塞,闭合,堵塞;v:闭合,堵塞",
"occult":"v:掩,隐藏",
"occultism":"n:占星术",
"occupancy":"n:居住,占用,占有,占领,据有;v:占用",
"occupation":"n:职业,占领,工作,消遣,居住,行业,事情,业;v:占用",
"occupational disease":"n:职业病",
"occupied":"v:有事",
"occupy":"v:占据,占领,占,占有,占用,担任,据有,挤占,据,居,侵占",
"occur":"v:发生,出现,存在,出,出来,想起,萌,浮现",
"occurrence":"n:发生,事件,有,出现,事故,遭遇;v:发生",
"occurring":"v:事件,事故,事变",
"ocean":"n:海洋,大洋,洋,大海,远洋,许许多多,无量,瀛,无限",
"ocean liner":"n:轮船,邮船",
"ocean sunfish":"n:翻车鱼",
"oceangoing":"a:远洋",
"oceania":"n:澳洲,大洋洲",
"oceanic":"a:远洋",
"oceanic bonito":"n:鲣",
"oceanography":"n:海洋学",
"oceanology":"n:海洋学",
"oceans":"n:许多,广阔,大洋",
"ocelot":"n:豹猫",
"ocher":"n:赭石",
"ochre":"n:赭色,金钱,黄褐色,赭石",
"oct":"n:10月,十月",
"octagonal":"n:八角;a:八角",
"octave":"n:八度",
"octet":"n:八角",
"october":"n:十月,10月",
"october revolution":"n:十月革命",
"octopus":"n:章鱼,蛸,八带鱼",
"ocular":"n:目镜,眼镜,接目镜,眼睛;a:直观",
"oculomotor nerve":"n:动眼神经",
"odd":"a:古怪,奇怪,多,单,怪;n:有零,一零儿,零头,邪门儿;d:有零;v:有余",
"odd-job man":"n:零工,勤务员,勤杂工,勤务兵",
"oddball":"n:古里古怪;a:古里古怪",
"oddity":"n:古怪,怪物,怪事,怪人,奇特,怪癖",
"oddly":"d:失常",
"oddment":"n:残余,零碎,残品,零头",
"oddness":"n:奇怪,邪门儿,失常",
"odds":"n:遭遇,差额,恩惠,不等,不等式,差距,可能性,不和,差异,希望",
"ode":"n:颂诗,颂,颂歌",
"odessa":"n:敖德萨",
"odious":"a:恶劣",
"odiousness":"n:讨厌",
"odium":"n:公愤,反感,厌恶,耻辱,憎恨",
"odobenus rosmarus":"n:海马",
"odometer":"n:里程表,行程表,计程表,计步器",
"odor":"n:气味,香味,臭味,味道,痕迹,气,臭,味,迹象",
"odoriferous":"a:香",
"odour":"n:味道,香气,香味,气,味,香,香水,声望,迹象,名誉,香料,臭气;a:臭",
"oedema":"n:浮肿;v:浮肿",
"oesophagus":"n:食道,食管",
"oestrogen":"n:雌激素",
"oestrus":"n:发情,动情,狂热",
"of":"p:的,从,于,之,向,对于,关于",
"of a sudden":"p:突如其来",
"of course":"p:自是,自,本来,理当,固然,敢情",
"of late":"d:最近,日来",
"of the order of":"p:大约",
"off":"p:从,离开,离,由,脱离,从_离开,从_脱离;d:离开,脱掉,隔开;v:跑,离开;a:落",
"off the cuff":"p:即席",
"off year":"n:小年,凶年",
"off-key":"a:左嗓子",
"off-season":"n:淡季",
"offal":"n:下水,次品,垃圾,废料,废物,糠",
"offence":"n:罪行,冒犯,罪,犯罪,侮辱,罪过,绊脚石,无礼,罪愆;v:犯规",
"offend":"v:得罪,冒犯,触犯,触怒,惹,激怒,伤害,冲撞,犯规,开罪,来劲,冲犯,犯,伤风败俗,违犯,惹火,侮辱,犯罪,干,逆耳,干犯;a:来劲",
"offender":"n:罪犯,犯人,罪人",
"offense":"n:冒犯,触怒,罪行,罪过,过失",
"offensive":"a:进攻,唐突,难听;n:攻势,进攻;v:进攻,唐突",
"offer":"v:提供,提出;n:报价",
"offering":"n:礼物,提供,捐款,提议,贡献,供品,股票,课程,祭品",
"offerings":"v:供;n:供品",
"offertory":"n:捐款",
"offhand":"d:随便,立即,当下,不假思索,即席,唐突",
"office":"n:办公室,公司,办事处,职务,职员,事务所,诊所,机关,公职,职,任,职责,室,任务,厅子,诊室,祷告,科,司,厅,仪式,祭礼,圣餐,署,号,厕所,处,斡旋,部,店,厨房,局;v:警告",
"office building":"n:办公楼",
"officeholder":"n:官,职员",
"officer":"n:军官,官员,警官,官,职员,长官,船长,武官,法警;v:指挥,管理,统率",
"official":"n:官员;a:正式",
"official document":"n:状,公牍,公函,文翰",
"officialdom":"n:宦海,官场",
"officialese":"n:官样文章",
"officially":"d:正式",
"officials":"n:有司",
"officiant":"n:主祭",
"officiate":"v:主持,执行,做",
"officious":"a:好事",
"offing":"n:海面,海上,近海",
"offload":"v:卸,解除,抒发,卸货,处理,发泄",
"offprint":"n:单行本;v:抽印",
"offset":"v:补偿,抵消,弥补,相抵,抵销;n:弥补,侧枝,抵销,补偿,分支,偏差,支脉",
"offset lithography":"v:胶印",
"offshoot":"n:分枝,分支,支流,侧枝,支派,支脉,支,衍生物",
"offshore":"a:近海,沿岸",
"offside":"n:右侧,越位;v:越位",
"offspring":"n:后代,子女,产物,子孙,后,后嗣,幼苗,仔,根苗,后裔,昆,下辈,胄,胤,子代,结果,儿女,苗裔",
"oft":"d:再三",
"often":"d:常,常常,往往,经常,时常,长,每,不时,每每,频繁,屡次,勤,雅,时时;r:每",
"oftentimes":"d:常常,屡次",
"ogle":"n:秋波",
"oh":"i:啊,哦,呀,哎呀,唉,啊呀,嗳,哟,呵,哦呀,喔,吁,嗐,嚄;f:呕,哟,呀;a:恶",
"ohm":"n:欧姆",
"ohmmeter":"n:欧姆计",
"oil":"n:石油,油,油脂,油类;v:行贿,加油,收买",
"oil cake":"n:油枯",
"oil color":"n:油漆,油画",
"oil colour":"n:油画",
"oil lamp":"n:灯盏",
"oil of turpentine":"n:松节油",
"oil paint":"n:油漆",
"oil palm":"n:油棕,油椰子",
"oil refinery":"n:炼油厂",
"oil shale":"n:油母页岩,油页岩",
"oil stain":"n:油渍",
"oil tanker":"n:油轮,油船",
"oilcan":"n:无赖,加油器,油罐",
"oilcloth":"n:漆布,油布",
"oilfield":"n:油田",
"oiliness":"n:奉承,油性,油腻",
"oiling":"v:加油",
"oilskin":"n:油布",
"oily":"a:油腻,油腻腻,腻,油,油头滑脑;v:腻",
"ointment":"n:药膏,软膏,油膏,膏剂,膏",
"ok":"n:许可;a:妙,不错;v:承认",
"okay":"n:认可,赞同",
"okinawa":"n:冲绳",
"old":"a:旧,老,大,年老,亲爱的,年迈,苍老,陈年,上年纪,老迈,老气;n:老大;c:故;v:迈",
"old age":"n:年老,暮年,白头,古老,老境,老年期,耋,老龄",
"old boy":"a:毕业生",
"old hand":"n:老手,熟手,惯犯,精通,里手",
"old lady":"n:母亲,老妈子,妻子",
"old maid":"n:老处女,老姑娘",
"old man":"n:老头,老先生,老者,父亲,长官,老夫,叟,翁,老前辈,船长",
"old nick":"n:魔鬼,魔王,撒旦,恶魔",
"old school":"n:守旧派",
"old stager":"n:识途老马,过来人",
"old style":"n:旧历,旧式",
"old style calendar":"n:旧历",
"old woman":"n:姥,婆娘,媪,老太婆,老妪,妪",
"old-age pension":"n:退休金",
"old-timer":"n:老手,老朋友,老前辈",
"olden":"a:古时",
"older":"a:长",
"oldest":"a:长",
"oldster":"n:老人",
"oleander":"n:夹竹桃",
"olefin":"n:烯烃,石蜡",
"oleo oil":"n:油",
"olfactory":"a:鼻",
"olfactory nerve":"n:嗅神经",
"olfactory sensation":"n:嗅觉",
"oligarch":"n:寡头",
"oligarchic":"a:寡头政治",
"oligarchy":"n:寡头政治",
"olive":"n:橄榄树,橄榄,油橄榄,齐墩果,洋橄榄",
"olive branch":"n:橄榄枝",
"olive drab":"n:草绿色",
"olive oil":"n:橄榄油",
"olive tree":"n:橄榄树",
"olivine":"n:橄榄石",
"olympiad":"n:奥运会",
"olympic":"n:奥林匹克",
"olympic games":"n:奥运会",
"olympics":"n:奥林匹克",
"olympus":"n:天",
"oman":"n:阿曼",
"omega":"n:结局,终止",
"omen":"n:预兆,兆头;v:预告",
"ominous":"a:不祥,险恶,凶",
"omission":"n:疏忽,遗漏,省略,罅漏,删节,失职",
"omit":"v:略去,遗漏,省略,省去,删去,忽略,略,省,疏忽,落,遗,怠慢;n:删略;d:略",
"omnibus":"n:统括,公共汽车",
"omnipotence":"n:全能,万能",
"omnipotent":"a:万能;n:神;v:神通广大",
"omnipresence":"n:普遍,无所不在",
"omnipresent":"a:无所不在;v:无所不在",
"omniscience":"n:上帝,无所不知",
"omniscient":"n:神;a:无所不知;v:无所不知",
"omnium-gatherum":"n:杂凑",
"omnivore":"n:杂食",
"omnivorous":"a:杂食",
"on":"p:在,就,到,用,于,上,靠,关于,下去,按,对于;d:向上,向着;a:熟悉,开;v:下去,接通",
"on account":"c:赊帐",
"on account of":"p:由于,因为,为了,基于",
"on behalf of":"p:代表,替",
"on board":"p:在船上",
"on earth":"p:究竟,天底下,世间",
"on fire":"p:着火,失火",
"on grounds of":"p:为由,以_为由",
"on guard":"p:值班",
"on hand":"p:手边,现",
"on one hand":"d:一来",
"on order of":"p:按照",
"on pain of":"p:代价,以_为代价",
"on par with":"p:相等,与_相等",
"on purpose":"p:成心,特意,存心",
"on tap":"p:零售",
"on the average":"p:平均",
"on the basis of":"p:在_基础上",
"on the contrary":"p:顾,相反,倒,倒是,反而,反过来说,适得其反,倒反,反是,反,故;d:顾;c:相对而言",
"on the grounds of":"p:为由,以_为由",
"on the loose":"p:寻欢作乐",
"on the nose":"p:正好",
"on the occasion of":"p:时,在_时",
"on the offensive":"p:先手",
"on the one hand":"d:一方面,一则",
"on the order of":"p:大约,一样,同_一样",
"on the other hand":"d:另一方面",
"on the part of":"p:就_而言,一边,而言,在_一边",
"on the point of":"p:在_之时,之时",
"on the side of":"p:在_一边,一边",
"on the sly":"p:背地,暗中,潜,偷偷,偷偷摸摸,暗地",
"on the spot":"p:好看,在场;d:当场",
"on the strength of":"p:凭借,依赖",
"on the top of":"p:之上,在_之上",
"on the way":"p:半道儿,半路,顺路,沿路,途中,顺脚;d:路上",
"on the whole":"p:简言之,总算,大体上,大抵,总而言之,大体,大致,大致说来,基本;d:大体上",
"on the wing":"p:忙于",
"on time":"p:正点,按期",
"on top of":"p:上面,紧接着,在_之上,之上,除外,另外",
"on trial":"p:试用",
"on-the-spot":"a:即席",
"once":"d:一;c:一经;v:尝",
"once again":"d:再次,再度,从头",
"once more":"n:再度,重,重新,再,重整旗鼓",
"oncoming":"n:来临,接近",
"one":"r:人,之一,你;n:单,单位;a:壹;d:一道",
"one after another":"n:纷纷,挨,逐个,连,先后,逐一,相率,挨个儿,挨次",
"one another":"n:相,互相",
"one by one":"n:各个,逐,逐渐,挨,挨个,历;d:挨次",
"one time":"n:一下",
"one-sided":"a:单方面,单方",
"one-step":"n:一步舞",
"one-way":"a:单程",
"one-way street":"n:单行道",
"oneness":"n:一致,同一,统一,独特,一体,单一,完整",
"onerous":"a:艰巨,繁重",
"oneself":"r:其,自我,身,自个儿,亲手,自身,亲自,自己,己,自各儿,本人,本身,自,自家;d:亲手,亲自;n:身",
"onetime":"a:旧",
"ongoing":"a:处置,事务,行为,工作,发展,行动",
"onion":"n:洋葱,葱头,葱,脑袋,芤,头,脸",
"online":"a:联机",
"onlooker":"n:旁观者,目击者,观潮派",
"onlooking":"a:旁观",
"only":"d:只,才;a:徒,唯独,惟有,第,耳;c:但是,但;v:惟有,唯有;n:耳",
"only too":"d:非常",
"onomatopoeia":"n:象声词,拟声,拟声词",
"onomatopoeic":"a:拟声",
"onomatopoetic":"a:拟声",
"onrush":"n:奔流,突击,冲锋,猛冲,冲击;v:猛冲",
"onset":"n:开始,发作,袭击,攻击,突击,动手",
"onslaught":"n:猛攻,突击;v:猛进,猛攻",
"onto":"p:到,上,按,在_上",
"ontogeny":"n:胎生学",
"ontology":"n:本体论",
"onus":"n:责任,重担,负担",
"onward":"d:向前,前进;a:向前",
"onwards":"d:向前,前进",
"oodles":"n:许多,大量",
"oomph":"n:性感,精力",
"ooze":"n:软泥,分泌物;v:沁,溜走,分泌",
"opacity":"n:愚钝",
"opal":"n:蛋白石;a:乳白",
"opaque":"n:晦暗",
"opec":"n:欧佩克",
"open":"v:打开,开,开始,向,开放,张开,开辟;a:明目张胆,阳;n:户外,公开",
"open air":"n:户外",
"open circuit":"n:断路",
"open fire":"n:活火",
"open letter":"n:公开信",
"open sesame":"n:护照",
"open university":"n:电大",
"open up":"v:展开,顿开茅塞,拓,斥,开,展,打通,开设,辟,打天下,发,开拓",
"open-minded":"a:旷达,明达,开诚布公",
"opencast":"a:露天矿",
"opener":"n:开瓶器,起子,泻药,开具",
"openhanded":"a:手松",
"openhearted":"a:光明,爽,襟怀坦白,宽大为怀",
"opening":"n:孔,开始,开,开放,空缺,口,通道,洞,空隙,开端,空地,口子,缝,开头,通路,战幕,空子,着手,豁口,开盘,缺,豁子;v:断开,开拓",
"openly":"d:公然,明目张胆,正面,直率,当众,坦白",
"openness":"n:宽阔,明目张胆,松脆,开放,宽大,公开,坦白",
"opera":"n:歌剧,歌剧院,剧,砌",
"operand":"n:操作数",
"operate":"v:操作,工作,操纵,运转,经营,动手术,开,管理,开刀,决定,开动,实行,动作,引起,操,导致,开工,生效,营,完成,聚赌;n:营",
"operate on":"v:开刀",
"operating":"v:工作,运算",
"operating expense":"n:事业费",
"operating room":"n:手术室",
"operating system":"n:操作系统",
"operating table":"n:手术台",
"operating theatre":"n:手术室",
"operation":"n:操作,手术,运算,工作,行动,运行,作业,活动,运转,经营,作用,实施,动作,作战,业务,交易,运用,开动,施行,效力,效果;v:操作,运行",
"operations research":"n:运筹学",
"operative":"n:职工,工人,刑警",
"operator":"n:操作员,话务员,接线员,算子,操作符,运算符,报务员,资方,司机,驾驶员,操纵员,骗子,经纪人,量词",
"operetta":"n:小戏,轻歌剧",
"ophthalmology":"n:眼科学,眼科",
"opiate":"n:麻醉剂",
"opine":"v:认为",
"opinion":"n:意见,看法,舆论,见解,主张,想法,评价,见,意思,判断,鉴定,议,观念,讲法,判定,浅见,论,主;v:见",
"opinionated":"v:固执己见,自用,刚愎自用,自以为是;a:自用",
"opinions":"n:口碑",
"opium":"n:鸦片,烟,大烟,阿片,麻醉剂,土,罂粟",
"opium addict":"n:烟鬼",
"opponent":"n:对手,敌手,对头,冤家",
"opportune":"a:恰好,凑巧,巧,适",
"opportunely":"d:适时,恰好",
"opportunism":"n:机会主义",
"opportunity":"n:机会,会,时机,机遇,机,遇,方便,隙;v:遇",
"oppose":"v:抗争,持,反,妨碍,抗议;a:敌对",
"opposed":"a:相反",
"opposing":"v:对;a:对",
"opposite":"a:左;n:对立面;p:对面,在_对面;v:相反",
"opposition":"n:反对,反对党,抵抗,对立,敌对,面对,相对,对偶,对抗,对照,冲,妨害,在野党",
"oppress":"v:压迫,压制,欺侮,虐待,压倒",
"oppressed":"v:堵",
"oppression":"n:压迫,虐待,苦闷,压制,镇压,沉闷,苦恼,抑制,忧郁",
"oppressive":"a:压抑,酷,残,沉闷",
"oppressiveness":"n:压抑",
"oppressor":"n:暴君",
"opprobrious":"a:辱骂",
"opprobrium":"n:耻辱,责骂,轻蔑",
"opt":"v:选择,抉择",
"optic":"n:镜片",
"optic axis":"n:光轴",
"optic nerve":"n:视神经",
"optical fiber":"n:光纤",
"optical fibre":"n:光导纤维",
"optical lens":"n:透镜",
"optical prism":"n:棱镜",
"optics":"n:光学",
"optimism":"n:乐观",
"optimistic":"a:乐观,达观,开朗",
"optimization":"n:优化,优选法",
"optimize":"v:优化",
"optimum":"a:最佳",
"option":"n:选择,取舍",
"optional":"a:自选",
"optionally":"d:自由,随意",
"optometry":"n:验光",
"opulence":"n:丰富,丰饶,富裕",
"opus":"n:著作,电影,广播剧,作品",
"or":"c:或,或者,还是,或是,某,要么,也好,不然,否则,要不,就是,要不然,大概,抑或,即或;d:也罢,再不;n:黑色",
"or else":"a:不然,要不然;c:要不",
"or so":"c:约摸,约莫,把,大约,那么,上下;p:上下",
"oracle":"n:先知,哲人,神殿,预言",
"oral":"n:口头;a:口头",
"oral cavity":"n:口腔",
"oral examination":"n:口试",
"orange":"n:橙子,桔子,柑桔,橙色,橙,橘柑,福橘,桔,甜橙,香橙",
"orange juice":"n:橘汁,橙汁",
"orange red":"n:缇,橙红色",
"orange tree":"n:桔树",
"orangeade":"n:橙汁",
"orangutan":"n:猩,猩猩",
"orate":"v:演讲",
"oration":"n:演说,演讲,引语",
"orator":"n:辩护人,原告",
"oratorio":"n:清唱剧",
"oratory":"n:演讲,修辞,雄辩",
"orb":"n:天体,球体,眼球,地球;v:卷,包围,围",
"orbit":"n:轨道;v:环行",
"orchard":"n:果园,果木园,棒球场",
"orchestra":"n:管弦乐队,乐队,管弦乐,乐池",
"orchestra pit":"n:乐池",
"orchestrate":"v:配器",
"orchid":"n:兰花,兰,恭维话,感谢,兰草,贺词,祝贺",
"ordain":"v:注定,任命,规定,制定,命令",
"ordeal":"n:考验,折磨;v:考验",
"order":"n:命令;v:饬令,驱迫,支,注定,定制;d:先后",
"order form":"n:订单",
"order of magnitude":"n:数量级",
"orderliness":"n:条理,整洁,整齐,理路,板眼,秩序井然",
"orderly":"a:整齐,井然有序;n:公务员,井,通讯员",
"orders":"n:军命",
"ordinal":"n:序数",
"ordinance":"n:法令,条例,仪式,天意,条令,训令,布告",
"ordinances":"n:条例",
"ordinarily":"d:通常,一般,常,平常,按说,大抵,大概,普通;v:照说",
"ordinary":"a:普通,一般,平常,常,平凡,寻常,便,平庸,庸庸碌碌,凡庸,凡,简单,如常,等闲;n:常例,法官,庸夫,客店;v:如常",
"ordinary shares":"n:普通股",
"ordinate":"n:纵坐标",
"ordination":"n:规则,整理,分数,委任",
"ordnance":"n:军械,军用品,武器,军器,军需品,大炮",
"ordovician":"n:奥陶纪",
"ordure":"n:下流话,粪便,肥料,排泄物,粪",
"ore":"n:矿石,矿砂,矿,矿车,矿层,贫矿",
"ore bed":"n:矿层",
"organ":"n:器官,风琴,机构,机关,喉舌,管风琴,机器,口琴,元件,机件,官,器,报刊,工具,机关报",
"organdy":"n:玻璃纱",
"organelle":"n:细胞器",
"organic":"a:有机,机;n:机",
"organisation":"n:组织,团体",
"organise":"v:组织",
"organism":"n:生物,有机体,生物体,微生物,机体,组织,肌体,构造,结构",
"organisms":"n:生物",
"organization":"n:组织,机构,结构,构成,编制,团体,委员会,协会,公会,团,会党,生物体,体制,组织性",
"organize":"v:组织,组建,整理,搞,发起,编,创办,创立;n:组",
"organizing":"v:组织",
"orgy":"n:狂欢,放荡",
"orient":"n:东方,亚洲;a:定向,光彩夺目;v:修正",
"oriental":"a:特等",
"oriental arborvitae":"n:侧柏",
"oriental cherry":"n:樱",
"orientate":"v:定位,调整,辅导,定向",
"orientation":"n:方向,取向,定向,方针,倾向性,定位,适应",
"orientations":"v:朝向",
"orifice":"n:孔,口,喷嘴,开口",
"origin":"n:起源,出身,起因,成因,原点,来源,血统,来历,由来,根源,源,渊源,起始,根本,本源,开始,母,起点,出发点,根,震源,根子,焦点,根由,缘起,本原,来路,因由,元,发端",
"original":"n:底本,原型,雏型,底片,模型;a:本,母,初;v:原有",
"original sin":"n:原罪",
"originality":"n:独创性,新颖,创见,创造力,独出心裁,创意,匠心,创举,怪人,原物;a:新颖",
"originally":"d:最初,原来,起初,本来,原本;n:当初",
"originate":"v:引起,发源,首创,发生,开始,创始,发起,源于,发自,发明,来源,创办,创作,肇,创设,滥觞,起头;n:来源",
"originate in":"v:来源于,起源",
"origination":"n:发源,起始,起点,创作",
"originator":"n:开山祖师",
"oriole":"n:黄莺,莺,黄鹂,黄鸟",
"orion":"n:猎户",
"ornament":"n:装饰;v:美化,点缀",
"ornamental":"n:观赏植物,装饰品",
"ornamentation":"n:装饰,装饰品,修饰",
"ornaments":"n:饰物,摆设",
"ornery":"a:古怪",
"ornithology":"n:鸟类学",
"orphan":"n:孤儿,孤子,遗孤",
"orphanage":"n:孤儿院",
"orthoboric acid":"n:硼酸",
"orthodox":"a:正统",
"orthodoxy":"n:正统,正教",
"orthography":"n:正字法,正字",
"orthopaedics":"n:骨科",
"orthopedic":"a:矫形",
"orthopedics":"n:整形,骨科",
"orthophosphoric acid":"n:磷酸",
"os":"n:操作系统,孔穴,通路",
"osaka":"n:大阪",
"oscar":"n:奥斯卡,左轮,现款",
"oscillate":"v:振荡,摆动,变动,浮沉,晃荡,振动",
"oscillating":"v:振荡",
"oscillation":"n:振荡,振动,摆动,震荡,变动,振幅;v:震荡,摆动,震动,振荡",
"oscillator":"n:振荡器",
"oscilloscope":"n:示波器,示波管",
"osculate":"v:密切,接触",
"osculation":"n:接吻,密切",
"osier":"n:柳树,柳枝,柳条",
"oslo":"n:奥斯陆",
"osmium":"n:锇",
"osmosis":"n:渗透;v:渗透",
"osprey":"n:鱼鹰,鹗",
"ossification":"n:硬化,僵化,骨化;v:硬化,骨化",
"ossified":"v:僵死",
"ossify":"v:僵化,硬化,骨化",
"ostentation":"n:卖弄,摆阔,表面文章,排场,夸示,夸耀",
"ostentatious":"a:浮华,浮艳,阔绰;n:浮华",
"ostler":"n:马夫",
"ostracism":"n:排斥,放逐,流放",
"ostracize":"v:排斥,流放,放逐",
"ostrich":"n:鸵鸟,鸵",
"othello":"n:奥赛罗",
"other":"r:他;a:外;n:旁;d:另外",
"other than":"p:不同,除外,之外,与_不同,除了_之外",
"otherness":"n:他,相异",
"others":"r:他人,旁人,别的,别人",
"otherwise":"c:反之,要不,不然,否则,要不然;d:否则;a:一",
"otitis media":"n:中耳炎",
"ottawa":"n:渥太华",
"otter":"n:水獭,獭,水獭皮",
"ought":"v:应该,应当,当;n:零",
"ounce":"n:盎司,少量,英两",
"our":"r:我,敝,我们;a:我",
"ourselves":"r:吾人",
"oust":"v:取代,斥,代替,剥夺,轧,撵,驱逐,逐出",
"ouster":"n:剥夺,驱逐,放逐,逐出",
"out":"d:出去;n:印象;v:逐出;p:外面;a:结束;i:出去,滚蛋",
"out of":"p:离开,外,由于,里,来自,从中,缺乏,从_里,在_外",
"out of all proportion to":"p:超过",
"out of bounds":"p:越轨",
"out of bounds to":"p:禁区,对_的禁区",
"out of gear":"p:失常",
"out of hand":"n:立刻",
"out of keeping with":"p:不符,与_不符",
"out of play":"p:出局",
"out of practice":"p:生疏,荒疏",
"out of proportion to":"p:不成比例,与_不成比例",
"out of reach":"p:鞭长莫及",
"out of stock":"p:抢购一空",
"out of the way of":"p:给_让路,让路",
"out of touch with":"p:陌生,与_失去联系,对_陌生,失去联系",
"out of true":"p:出毛病",
"out-and-out":"a:完全",
"out-of-bounds":"d:界外球",
"outage":"n:出口,停车,停止,停电,损耗;v:断电",
"outback":"n:内地",
"outbalance":"v:胜过,优于",
"outbid":"v:抢先",
"outbreak":"n:爆发,暴动,暴发,反抗,骚扰,发作;v:暴动,暴发,爆发",
"outburst":"n:爆发,迸发;v:爆发",
"outcast":"n:流氓,流浪者,丧家之犬,无赖,废物",
"outclass":"v:超过",
"outcome":"n:结果,结局,后果,成果,产物,分晓,胜负,输出,终局;v:输出",
"outcrop":"n:露头;v:露头",
"outcropping":"n:矿苗;v:露头",
"outcry":"n:喊叫,喧嚷,叫卖,怒号,吆喝",
"outdated":"a:老,老式",
"outdistance":"v:胜过",
"outdo":"v:优于,超越,胜过,凌驾,超过,制服,打败",
"outdone":"v:烦恼,激怒",
"outdoor":"n:野外,室外;a:野外",
"outdoors":"n:户外,野外,外头,自然界,世间,露天",
"outer":"a:外,套;n:外面,外壳",
"outer garment":"n:风衣,外衣,外套",
"outer mongolia":"n:外蒙古",
"outer planet":"n:外行星",
"outer space":"n:太空,宇宙空间",
"outerwear":"n:外套,外衣",
"outface":"v:恐吓,挑,反抗,冒,蔑视",
"outfall":"n:出口,河口,吵架,突击,袭击",
"outfield":"n:边境,外场,郊外,边地",
"outfight":"v:击败,打败,战胜",
"outfit":"n:准备,素养,用品,工具,装置,旅费;v:供给,装",
"outfitting":"v:准备,装束",
"outflank":"v:包抄,迂回,阻挠",
"outflow":"n:流出,泛滥,爆发;v:流出,外流",
"outgo":"n:支出,出发;v:胜过,超过,优于",
"outgoing":"v:外出,出去,出发,开支,声明",
"outgrow":"v:出生",
"outgrowth":"n:结果,枝条,成果,长大,副产物,瘤",
"outguess":"v:看透",
"outgun":"v:超越,胜过",
"outing":"n:远足,出游,外出,游览,散步,旅行",
"outlandish":"a:稀奇古怪",
"outlaw":"n:歹徒,逃犯,亡命徒;v:取缔",
"outlawry":"n:放逐",
"outlay":"n:开支,经费,费用,花费,用度,支出,用,用费;v:花费",
"outlet":"n:出口,出路,插座,销路,输出,通路;v:输出",
"outlier":"n:局外人,门外汉",
"outline":"n:轮廓,梗概,提纲,要点,大纲,纲,架子,略图,概略,概要,纲要,草稿,崖略;v:勾勒,领,剪影,简述;d:略;a:凡",
"outlook":"n:观点,眼界,景色,前景,人生观,展望,望楼,观,了望,见解,见地,看守,形势,景致,风光",
"outlying":"a:边远",
"outmatch":"v:优于,胜过",
"outmoded":"a:陈旧,过时",
"outnumber":"v:超过",
"outpace":"v:超过,胜过",
"outperform":"v:胜过",
"outplay":"v:击败,胜过",
"outpost":"n:前哨",
"outpouring":"n:迸发,流露,洋溢,流出",
"output":"n:产量;v:出力",
"outrage":"v:犯,驳倒,凌辱,伤害,违反;n:暴行,残暴,凌辱,痛恨,义愤",
"outrageous":"a:妄,不像话,残暴",
"outrageously":"d:悍然",
"outreach":"v:伸长,胜过,超过;n:展开,伸出",
"outrigger":"n:支架",
"outright":"d:彻底,坦白,马上,完全,公然,公开,即刻;a:爽快,地地道道",
"outrun":"v:脱离,超过,胜过,逃走",
"outset":"n:开始,开头,最初,开端",
"outshine":"v:解放,胜过,优于",
"outside":"n:外面,外表;a:出界;d:外面;p:在_外;v:在外",
"outsider":"n:外人,局外人,门外汉,外行",
"outsize":"n:特大号",
"outskirt":"n:市郊,郊区,外边",
"outskirts":"n:郊外,市郊,四郊,郊区,城郊,远郊",
"outspoken":"a:坦率,直言,爽直,直肠子;v:直肠子",
"outspread":"v:展开,传播,扩张,散布",
"outstanding":"a:杰出,出色,优秀,突出,显著,卓越,卓著,拔尖,出类拔萃,俊,旷代,旷世,了不得,了得,著,卓异,特出,优,不凡,非凡,杰,优异,尤,峥嵘,卓然,卓跞,响当当;v:超拔,出类拔萃,数得着,出众,未了,冒尖儿,头角峥嵘,未决",
"outstretch":"v:伸出,展开,扩张,张开,伸展",
"outstrip":"v:超过,胜过,越过,优于,超前,逃脱",
"outta":"p:由于,从_里,缺乏,里,外,在_外",
"outtake":"n:烟道",
"outward":"n:外观,外形,外表;a:外,外貌;d:表面化",
"outwardly":"d:在外",
"outwards":"d:在外",
"outweigh":"v:胜过",
"outwit":"v:智取,哄骗",
"outworn":"a:陈腐",
"ova":"n:卵细胞,卵",
"oval":"n:椭圆,椭圆形",
"ovary":"n:卵巢,子房",
"ovation":"n:欢呼",
"oven":"n:烤箱,烤炉,炉子,炉灶,烘炉,灶火,灶,炭窑,烘箱,炉",
"over":"p:过;d:出,剩余,过于,倒;n:上面,剩余,套,以上,余额,上边,上头;a:逾分,多,余,过度;f:开外,过",
"over again":"p:再次",
"over against":"p:比较,在_对面,与_比较,对面",
"over and above":"p:此外,除_之外,之外",
"overabundance":"n:奢侈品",
"overage":"n:超额,过多,过量,过剩;a:超龄",
"overall":"n:工装裤;a:罩;d:全盘,通盘",
"overalls":"n:工作服,套裤",
"overarm":"a:横杆",
"overawe":"v:威吓,威慑",
"overbalance":"v:压倒,优于,胜过",
"overbear":"v:压倒,超过,超生,压服,制服",
"overbearing":"a:傲慢,盛气凌人;v:气势汹汹,咄咄逼人,不可一世",
"overbearingly":"d:气势汹汹",
"overbid":"n:谎价",
"overburden":"v:过载;n:重担",
"overcast":"a:阴沉,阴,低沉,灰蒙蒙;n:覆盖",
"overcautious":"a:拘谨,狷",
"overcharge":"v:加码,敲,敲竹杠,夸张,压倒",
"overcloud":"v:阴暗,悲伤",
"overcoat":"n:大衣,外套,大氅",
"overcome":"v:克服,战胜,克,征服,制胜,排除,制服,打败;n:克",
"overconfidence":"n:自负",
"overconfident":"a:不自量",
"overcrowd":"v:挤满,拥塞",
"overdo":"v:过分,夸张,过火,过头;a:过头",
"overdose":"v:过量",
"overdraft":"v:透支;n:透支",
"overdraw":"v:透支,夸大,夸张",
"overdrawn":"v:夸张,透支",
"overdress":"n:外衣",
"overdue":"v:过期,误点;a:过期",
"overeat":"v:暴食",
"overestimate":"v:看重",
"overflight":"n:飞越",
"overflow":"v:溢,泛滥,淹没,充满,溢出,漫溢,满,漫;n:过多,泛滥",
"overflowing":"n:过剩,充沛,溢出;a:盎然,潋滟;v:横溢",
"overfly":"n:飞越;v:飞越",
"overground":"a:地上",
"overgrow":"v:丛生,疯长",
"overgrown":"a:老",
"overgrowth":"n:繁茂,蔓延,生长,增生,疯长,共生;v:生长",
"overhand":"n:优势,上风,胜利",
"overhang":"v:伸出,威胁;n:悬垂",
"overhaul":"v:检修,追上;n:检查",
"overhead":"a:架空,空中,高架;n:上空,天,空中,天花板;v:开销",
"overhear":"v:偷听",
"overindulgence":"n:放纵",
"overjoy":"v:大喜,狂喜",
"overjoyed":"v:欢天喜地,欢跃;a:欢天喜地",
"overkill":"n:过多",
"overlap":"v:交叠,一致,覆盖,叠加,套,交叉;n:重复",
"overlapping":"v:重叠,交叠,交叉",
"overlay":"v:涂,铺,压倒,盖,重叠,叠置,压制,叠加,覆,敷",
"overleaf":"n:反面;d:反面",
"overload":"v:过载;n:超载",
"overloading":"v:过载,超载",
"overlook":"v:忽略,俯瞰,忽视,俯视,眺望,监视,漠视,观察,忘记,读,疏忽,临,监督,检阅,检查,视察,忘,忽",
"overlord":"n:霸王,霸,太岁,霸主,太上皇",
"overlying":"v:叠加",
"overmaster":"v:征服,克服,压服,压倒",
"overmuch":"n:过量,剩余",
"overnight":"d:过夜,整夜,昨晚,通宵;n:一朝一夕",
"overpass":"v:翻过,忽视,通过,优于,越过,超过,违背,渡,超出,过;n:过街桥,天桥,高架道路,旱桥",
"overpower":"v:制服,压倒,打败,压服",
"overpraise":"n:谬奖,过奖;v:过誉,过奖",
"overprint":"v:叠印",
"overproduce":"v:生产过剩",
"overproduction":"n:生产过剩",
"overreach":"v:越过,赶上,超越,追上,过火,夸张",
"override":"v:不顾,压倒,推翻,藐视,蔑视,废弃,凌驾,制服,超过",
"overriding":"v:过载",
"overrule":"v:否决,驳回,推翻,压倒,压制,统治,克服,废弃",
"overrun":"v:超过,超出,泛滥,猖獗,越过,侵占,侵略,蔓延,蚕食;n:猖獗,余额,跋扈,泛滥成灾,蔓延",
"overrunning":"v:凌驾",
"overseas":"n:国外;a:海外;d:海外",
"oversee":"v:监督,管理,视察,监视,了望,照料,错过,俯瞰;n:监工",
"overseer":"n:监工,工头,监督,管理员",
"oversensitive":"a:神经过敏;v:过敏,多愁善感,神经过敏;n:斗筲",
"overshadow":"v:庇护,相形见绌,遮蔽",
"overshadowed":"v:相形见绌",
"overshoe":"n:套鞋",
"overshoes":"n:套鞋",
"overshoot":"v:越过,镶边,超出,飞过,夸张;n:尖峰",
"overshot":"v:抓取",
"oversight":"n:疏忽,监督,监视,看管,疏漏",
"oversimplified":"a:简单;v:简单",
"oversimplify":"v:简单化",
"oversize":"n:特大号,大号;a:特大",
"overspend":"v:超支",
"overspending":"v:超支",
"overspread":"v:布满,铺天盖地,罩,扩张,遮掩,覆盖,铺盖,蒙,遮盖,蔓延",
"overstaffed":"v:臃肿;a:臃肿",
"overstate":"v:夸大,夸张,走火,夸,过甚,过甚其词",
"overstatement":"n:夸张,大话,言过其实",
"overstep":"v:超越,超拔,越过,犯,违犯,越,超出",
"overstock":"v:积压",
"overstress":"v:过载",
"overt":"a:公开,明,阳",
"overtake":"v:超过,赶上,追上,超,超车,赶,打垮,赶超,压倒",
"overthrow":"v:推翻,颠覆;n:失败,瓦解,征服,倾覆,灭亡,垮台",
"overtime":"n:加班,加班费",
"overtly":"d:公然,公开",
"overtone":"n:泛音,意味,联想,暗示,言外之意",
"overtones":"n:弦外之音",
"overture":"n:序曲,建议,提议,开端,序幕,前奏曲,提案",
"overturn":"v:打翻,推翻,倾覆,翻转,毁灭,打倒;n:垮台,灭亡,推翻,毁灭,瓦解,倾覆",
"overuse":"v:滥用;n:滥用",
"overview":"n:概观",
"overweening":"a:自负,惟我独尊;v:惟我独尊,唯我独尊",
"overweight":"n:超重,优势;v:超重",
"overwhelm":"v:淹没,压倒,覆盖,制服,压垮,倾覆,推翻,压服",
"overwinter":"v:过冬",
"overwork":"n:加班",
"overworked":"v:劳累,劳乏",
"oviduct":"n:输卵管",
"oviparous":"a:卵生",
"ovulate":"v:排卵",
"ovulation":"n:排卵",
"ovule":"n:胚珠,卵细胞",
"ovum":"n:卵,卵子,卵细胞",
"owe":"v:欠,短欠,短",
"owen":"n:欧文",
"owing":"a:由于",
"owing to":"p:多亏,因为,由于",
"owl":"n:猫头鹰,夜猫子,鸱;v:走私",
"owlet":"n:鸺鹠,枭,猫头鹰",
"own":"v:有,承认,拥有,所有,占有;a:负",
"own up":"v:供,坦白,招",
"owner":"n:主人,业主,所有者,物主,主,失主,货主,东",
"owner-occupier":"n:业主",
"ownership":"n:所有权,所有制,所有",
"ox":"n:牛,公牛,黄牛",
"oxalate":"n:草酸",
"oxalic acid":"n:乙二酸",
"oxbow":"n:河套",
"oxcart":"n:牛车",
"oxen":"n:牛,公牛",
"oxford":"n:牛津",
"oxidant":"n:氧化剂",
"oxidation":"n:氧化",
"oxide":"n:氧化物,氧化;v:氧化",
"oxidize":"v:氧化,生锈",
"oxidizer":"n:氧化剂",
"oxidizing agent":"n:氧化剂",
"oxygen":"n:氧,氧气",
"oxygen deficit":"n:缺氧",
"oxygenation":"n:氧化",
"oyster":"n:牡蛎,海蛎子,蚝,蚝油",
"ozone":"n:臭氧",
"pa":"n:爸,爹,爹爹;d:啪",
"pa system":"n:有线广播",
"pabulum":"n:养料,柴,食品,食物,营养,食粮",
"pace":"n:脚步,步伐,速度,步子;v:引导,步测",
"pacemaker":"n:样板,标兵",
"pacesetter":"n:标兵,标杆,带头人",
"pacific":"n:太平洋",
"pacific herring":"n:鲱,鲱鱼",
"pacific ocean":"n:太平洋",
"pacification":"n:平定,媾和,和约,绥靖",
"pacifism":"n:绥靖主义",
"pacify":"v:安抚,平息,绥靖,靖,抚慰,平,绥,平定",
"pacing":"v:步测",
"pack":"v:收拾,包装,行李,包,装;n:打,填充物,容器,塞子,驮子,组合",
"pack animal":"n:驮子",
"pack ice":"n:积冰",
"pack rat":"n:侍应生,小偷,陌生人",
"package":"n:包裹,包,一揽子,包装,件,部件,捆;v:组装;a:一揽子,整套",
"packaging":"v:组装,封装;n:装潢,打包",
"packed":"a:满满当当,满",
"packer":"n:打包机",
"packet":"n:包,束,邮船,盒,包裹,袋,班轮,组;v:包装",
"packhorse":"n:驮马",
"packing":"n:包装,填料;v:封装,结块,堆集,堆积,填充",
"packing plant":"n:加工厂",
"pact":"n:条约,公约,约,契约,合同,盟约",
"pad":"n:捆,房间,束,缓冲器,毛刺,垫片,公寓,篓子,篮子,掌,拍纸簿;v:漫步,垫,浮报,虚报,装填",
"padding":"n:贴边,芯,装填,补白,填料,铺张,填充;v:填充",
"paddle":"n:叶片,桨;v:抚弄",
"paddock":"n:蛙,围场",
"paddy":"n:稻子,谷子,稻,谷,水稻,稻谷",
"paddy field":"n:水田,皋",
"paddy wagon":"n:囚车,警车,巡逻车",
"padlock":"n:挂锁",
"padre":"n:神父,教士",
"paean":"n:赞美歌,赞歌,凯歌",
"pagan":"n:异教徒",
"pagan religion":"n:异教",
"paganism":"n:异教",
"page":"n:页,书,书页,专栏,篇页,事件,服务员,网页,叶,插话;v:侍候",
"pageant":"n:盛会,赛会",
"pageantry":"n:赛会,壮观,夸耀",
"pager":"n:呼叫器",
"pagination":"n:页码",
"pagoda":"n:宝塔,佛塔,浮屠,塔",
"pagoda tree":"n:榕树,槐树",
"pah":"i:呸",
"paid":"v:收讫,付讫;a:受雇",
"pail":"n:桶,水桶,容器",
"pain":"n:痛苦,疼痛,痛;a:痛,疼痛,痛苦;v:痛,疼",
"pained":"a:痛心,苦涩",
"painful":"a:痛苦,痛,苦,惨痛;v:钻心",
"painfulness":"n:痛苦",
"pains":"n:辛劳,苦功,苦心",
"painstaking":"a:刻苦,苦干;n:刻苦,辛苦,苦干,煞费苦心;v:煞费苦心",
"painstakingly":"d:刻意,煞费苦心,竭力,极力,精心,苦",
"paint":"v:画;n:油彩,香粉,口红,绘画",
"paint the lily":"v:徒劳无功,锦上添花",
"paintbrush":"n:画笔",
"painter":"n:画家,油漆匠,画师,画工,漆匠,漆工,油匠,美洲狮",
"painting":"n:画,绘画,油画,图画,画法,水彩画,油漆,美术,上色,漆工,着色,工笔画,丹青,画幅,颜料,涂料",
"pair":"n:对,双;v:成对",
"pairing":"v:交尾,配对,成对,并行,对偶;n:对偶",
"pajama":"n:睡衣",
"pajamas":"n:睡衣",
"pakistan":"n:巴基斯坦",
"pal":"n:同伙,同谋,伙伴",
"palace":"n:宫殿,王宫,皇宫,宫廷,宫,大厦,殿堂,龙宫,派力司,殿,宫室,廷",
"paladin":"n:干将,武士,勇士,游侠,骑士",
"palaeontology":"n:古生物学",
"palanquin":"n:肩舆,轿子",
"palatable":"a:对胃口,好吃,可口;v:对胃口",
"palate":"n:味觉,嗜好,上膛,腭",
"palaver":"n:笼络,谈判,废话,奉承,诱骗,交涉,空谈;v:交涉,空谈,闲谈,笼络,侈谈,哄骗",
"pale":"a:苍白,淡,灰白,惨白,土色,刷白,熹微,青白,弱;n:境界,桩,栅栏,范围,土色,界线",
"pale blue":"n:鸭蛋青",
"pale yellow":"n:鹅黄,缃,昏黄",
"paleface":"n:白人",
"paleness":"n:苍白",
"paleontology":"n:古生物学",
"palestine":"n:巴勒斯坦",
"palestine liberation organization":"n:巴解组织",
"palette":"n:调色板,画板;v:调色板",
"palette knife":"n:刮刀",
"palimpsest":"n:羊皮纸",
"paling":"n:栅,围,栅栏",
"palisade":"n:栅栏,桩,木栅,栅",
"pall":"n:走味,棺材,棘爪,外套;v:覆盖,厌倦",
"palladium":"n:钯",
"pallet":"n:草荐,调色板,棘爪,衔铁,托盘,地铺",
"palliate":"v:掩饰,缓和,减轻",
"palliation":"n:减轻",
"palliative":"n:辩解,减轻",
"pallid":"a:苍白,煞白",
"pallor":"n:苍白,灰白;a:苍白",
"palm":"n:手掌,手心,棕榈,巴掌,手掌心,胜利,光荣,掌,奖赏,优越,荣誉,棕树;v:以假乱真,握手,假冒,哄骗",
"palm off":"v:假冒,以假乱真",
"palm oil":"n:棕榈油",
"palm tree":"n:棕榈",
"palmy":"a:兴旺",
"palpate":"v:触,摸",
"palpitate":"v:悸动,跳,跳动,扑腾,颤抖,发抖,悸,心慌,心悸",
"palpitation":"n:心悸,心跳,跳动,颤抖;v:心跳,心悸",
"pals":"n:哥儿们",
"palsy":"n:痉挛,无力,无能,麻痹,中风,颤抖;v:瘫痪,震颤,瘫",
"palsy-walsy":"a:伙伴",
"paltry":"a:藐小,破,渺小,微不足道;v:微不足道",
"pamper":"v:姑息,纵容,娇惯,宠,娇,惯纵,娇养,娇纵",
"pampered":"v:娇贵,娇养",
"pamphlet":"n:小册子",
"pan":"n:平底锅,盘子;v:淘金",
"pan out":"v:结果,成功",
"panacea":"n:妙药",
"panache":"n:摆架子",
"panama":"n:巴拿马",
"pancake":"n:薄饼,煎饼,烙饼,大饼,饼子",
"panchromatic film":"n:全色片",
"pancreas":"n:胰腺,胰,胰脏,膵脏,膵",
"pancreatic juice":"n:胰液",
"panda":"n:熊猫,猫熊,大猫熊,大熊猫",
"pandemic":"n:传染病,世界性",
"pandemonium":"n:混乱,大吵大闹,魔窟,无法无天,乌烟瘴气,地狱,喧嚣",
"pander":"v:迎合,拉皮条,勾引,煽动,怂恿",
"pane":"n:边,面",
"panegyric":"n:颂词,称赞",
"panel":"n:面板,板,镶板;v:选定",
"panel discussion":"n:座谈会",
"pang":"n:剧痛,苦痛;v:剧痛,折磨;a:苦闷",
"pangolin":"n:穿山甲,鲮鲤",
"panhandle":"v:行乞",
"panhandler":"n:叫化子,乞丐",
"panic":"a:恐慌,惊惧;n:惊慌",
"panic-stricken":"a:惊惶,惊慌失措,惊骇",
"panicky":"a:人心惶惶",
"panjandrum":"n:大亨",
"panning":"v:淘金",
"panoply":"n:华服,礼服,盛装",
"panorama":"n:全景,概论,概观",
"pansy":"n:三色堇;v:打扮",
"pant":"v:气喘吁吁,喘,喘气,喘息,想,渴望,气短,发喘,气喘,热望,心跳;n:心跳,气喘,喘息",
"pantaloon":"n:裤子,马裤,傻瓜,丑角",
"pantheism":"n:泛神论,多神教",
"panther":"n:豹,豹子,黑豹,美洲豹",
"panthera tigris":"n:虎",
"panties":"n:内裤",
"panting":"a:气吁吁,气喘吁吁,气短;v:脉动,裤料;n:裤料",
"pantograph":"n:放大器,缩放仪",
"pantomime":"n:哑剧,姿势,手势",
"pantry":"n:胃",
"pants":"n:裤,长裤,衬裤,裤子",
"pantyhose":"n:袜裤",
"panzer":"n:战车,装甲车,坦克",
"pap":"n:软食,津贴,果肉",
"papa":"n:爸爸,情人,丈夫",
"papal":"a:罗马教皇",
"papaya":"n:番木瓜,木瓜",
"paper":"n:纸,报纸,文件,论文,报,纸张;v:掩盖",
"paper bag":"n:纸袋",
"paper clip":"n:回形针",
"paper currency":"n:纸币",
"paper cutter":"n:裁纸机",
"paper knife":"n:裁纸机",
"paper mill":"n:槽坊",
"paper money":"n:钱票,纸票,票子,钞,钱钞",
"paper mulberry":"n:构,楮",
"paper tape":"n:纸带,纸条",
"paper towel":"n:纸巾",
"paperback":"a:平装;n:平装本",
"paperback book":"n:平装本",
"paperboard":"n:纸板",
"paperboy":"n:报童",
"paperclip":"n:曲别针",
"papers":"n:证件,文章,文件",
"paperweight":"n:镇纸",
"papilla":"n:乳头,棘",
"papist":"n:教宗",
"paprika":"n:辣椒粉,辣椒",
"papyrus":"n:草纸",
"par":"n:同等,标准,平价,常态,定额",
"par value":"n:票面,面值",
"parable":"n:寓言,比喻,格言,大话,讽喻",
"parabola":"n:抛物线,抛物面",
"parabolic":"a:比喻,寓言",
"paraboloid":"n:抛物面",
"paracetamol":"n:扑热息痛",
"parachute":"n:降落伞;v:跳伞",
"parachutist":"n:伞兵",
"paraclete":"n:辩护人",
"parade":"n:游行,检阅;v:夸耀,卖弄,标榜,散步",
"paradigm":"n:范例,示例",
"paradise":"n:天堂,乐园,伊甸园,天国,宫,福地,彼岸,乐土,公园,仙境",
"paradox":"n:悖论,怪事,谬论,怪论",
"paradoxical":"a:反常",
"paraffin":"n:石蜡,煤油,烷烃",
"paraffin oil":"n:煤油,灯油",
"paragon":"n:完人;v:胜过",
"paragraph":"n:款;v:分段",
"paraguay":"n:巴拉圭",
"parallax":"n:视差",
"parallel":"n:类似,纬线,对比,比较,垫片,平行线;v:并联,并行;a:平行",
"parallel port":"n:并行接口",
"parallel processing":"v:平行作业",
"paralleling":"v:并联",
"parallelism":"n:平行,对联,比较,对应,相同,接近,类似;v:接近",
"paralyse":"v:麻痹",
"paralysed":"v:瘫,瘫痪",
"paralysis":"n:瘫痪,麻痹,疯瘫,痪,停顿,截止;v:截止,停顿",
"paralytic":"n:瘫子",
"paralyze":"v:麻木不仁,关闭",
"paralyzed":"v:瘫痪,麻木不仁",
"paramecium":"n:草履虫",
"parameter":"n:参数,参量,变数,参变量",
"paramount":"n:首长,至上,元首,主要;a:至高无上,无上;v:至高无上",
"paramountcy":"n:主权",
"paramour":"n:外遇,情妇,姘头,奸夫,情夫,奸妇",
"parapet":"n:栏杆,胸墙,矮墙,陴,围墙",
"paraphernalia":"n:行头,装饰品,附件",
"paraphrase":"n:释义,意译;v:释义,意译",
"paraplegia":"n:截瘫",
"parasite":"n:寄生虫,寄生物,食客",
"parasitic":"a:寄生",
"parasitism":"n:奉承,寄生",
"parasol":"n:阳伞,旱伞",
"parathyroid":"a:甲状腺;n:甲状旁腺",
"paratrooper":"n:伞兵",
"paratroops":"n:伞兵",
"paratyphoid":"n:副伤寒",
"parcel":"n:包裹,包,邮包,分部,一块,一部分;v:分派,打包,区分,分;d:一部分",
"parcel out":"v:打包",
"parcel post":"n:邮包",
"parceling":"v:打包",
"parch":"v:焦,烤,烘",
"parched":"a:焦渴;v:焦渴",
"parchment":"n:羊皮纸",
"pardon":"v:包容,饶,讨饶,贷,原;n:大赦",
"pardonable":"a:情有可原;v:情有可原",
"pardonably":"d:难怪",
"pare":"v:削减,削,修,剪,推,片,减少,剥,缩减,旋,刮削",
"paregoric":"n:止痛药",
"parent":"n:父母,双亲,母,父亲,母亲,根源,母体,老人家,祖先,本源;v:亲;a:母",
"parentage":"n:出身,血统,门第,起始,来源",
"parentheses":"n:括号,括弧",
"parenthesis":"n:圆括号,插入语,插话,括弧,插曲",
"parenthood":"n:生育",
"parents":"n:父母,家长,堂上,双亲,二老",
"pariah":"n:流浪者,贱民",
"parietal":"a:顶骨",
"parietal lobe":"n:顶叶",
"paring":"n:刨花",
"paris":"n:巴黎",
"parish":"n:教区,县",
"parity":"n:宇称,同等,类似,平价,等价,平等,均等,比价,同样,一致,均势",
"park":"n:公园;v:停,停车,停放",
"parka":"n:棉猴儿",
"parking":"n:停车",
"parking area":"n:停车场",
"parking lot":"n:停车场,车场",
"parking space":"n:停车场",
"parlance":"n:辩论,谈判,腔调,用语,说法",
"parley":"v:谈判,会谈,讲;n:会谈",
"parliament":"n:议会,国会,议院",
"parliamentarian":"n:议员",
"parlor":"n:客厅,休息室,接待室,办公室,诊室,会客室,花厅,起居室,摄影室,电影院",
"parlour":"n:花厅,办公室,摄影室,休息室,接待室,诊室",
"parlous":"a:极",
"parnassus":"n:诗,文学",
"parochial":"a:狭隘",
"parole":"n:宣誓",
"parotid gland":"n:腮腺",
"paroxysm":"n:激发,终极,发病,发作,努力,活动;v:发病",
"paroxysmal":"a:阵发性;n:阵发性",
"parrot":"v:人云亦云,学舌,随声附和,鹦鹉学舌;n:鹦哥,应声虫",
"parry":"n:闪避,躲开,帕里;v:闪开,回避",
"parse":"v:分析,解析",
"parsimonious":"a:小气",
"parsimony":"n:小气,吝啬",
"parson":"n:牧师",
"part":"n:部分,一部分,角色,地方,零件,作用;v:斩断,断绝,区别,分配;a:零",
"part-time":"a:兼任",
"part-timer":"n:零工",
"partake":"v:参加,分享,分担,分得,参与,吃光,共享",
"partake in":"v:分享,参加",
"partaker":"n:参与者",
"parterre":"n:花坛,宅地,花台,花圃",
"parthenogenesis":"n:孤雌生殖",
"partial":"n:片,倚,偏,偏流;a:偏心,一点,偏颇;v:倚,偏",
"partial eclipse":"n:偏食",
"partial tone":"n:泛音,谐音",
"partiality":"n:偏爱,偏心",
"partially":"d:一部分",
"partials":"n:谐音",
"participant":"n:参加者,参与者,一把手",
"participate":"v:参加,参与,分担,参予,插足,分享,共享,插脚,参",
"participation":"n:参加,参与,关系,分享;v:参与",
"participator":"n:参与者",
"participle":"n:分词",
"particle":"n:粒子,颗粒,微粒,质点,词缀,星,星子,虚词,条,项,微量",
"particular":"n:细节;a:考究;r:各;d:特",
"particularity":"n:特殊性,挑剔,特性,细致,特别,特殊,特征,精确,私事,详细,个性",
"particularization":"n:列举",
"particularize":"v:大书特书,缕述,列举,详述",
"particularly":"d:特别,尤其,格外,特,分外,异常,尤,分别",
"particulars":"n:细节,详情",
"particulate":"n:粒子,颗粒,微粒",
"parting":"n:分离,十字路口,离别,死亡,岔口,分裂;v:张开,分割",
"partisan":"n:党徒,同类",
"partisanship":"n:同类,同党",
"partition":"n:分区;v:分段,分类,隔,瓜分,垒;d:隔墙",
"partitive":"a:区分",
"partly":"d:半,几分;a:半",
"partner":"n:合伙人,伙伴,舞伴,伴侣,搭档,配偶,同伙,一把手,伴;v:配合",
"partnership":"n:合伙,伙,配合",
"partridge":"n:鹧鸪,松鸡",
"parts":"n:零部件,部件,机件,配件",
"parturition":"n:分娩,临盆,生产;v:生产",
"party":"n:聚会,党,宴会,政党,会,党派,一方,当事人,方,集会,一行,招待会,伙伴,用户,同类,会党,特遣部队,部队",
"party boss":"n:党魁",
"party line":"n:党纲,分界线",
"party spirit":"n:党性",
"party wall":"n:界墙",
"parvenu":"n:暴发户",
"pas":"n:优先权,舞,舞步,跳舞",
"pas de deux":"n:双人舞",
"pass":"v:通过,过去,及格,经过,过,穿过,给,递给,下;n:隘口",
"pass across":"v:交叉",
"pass along":"v:传递",
"pass away":"v:崩,过世,圆寂,断气,物故,与世长辞,长逝,辞世,死亡,去世,见背,弃养,撒手归西,下世,仙游,弃市,亡,消灭,永眠",
"pass by":"v:路过,过去,行经,经过",
"pass judgment":"v:臧否,明断",
"pass off":"v:停止,终止",
"pass on":"v:传来,传授,转,宣告,传达,转达,递给,传,转递,转手",
"pass out":"v:晕倒,昏倒",
"pass over":"v:浏览,忽略,躐",
"pass through":"v:阅,由,走,穿,历,穿透,经历,经,透,穿过",
"pass up":"v:放过,拒绝,错过",
"pass water":"v:小便,尿,小解",
"passable":"a:可以,说得过去;v:说得过去",
"passably":"d:过得去,还",
"passage":"n:段,通道,通过,段落,走廊,过道,旅行,通路,通行,道路,航道,航行,经过,推移,水路,孔道,死亡,细部,转变,迁移,事件,逝世,讨论,航线,争论,交流,进气道,片段,商量;v:前进,穿过,通过,航海,透射,争论",
"passages":"n:经脉",
"passageway":"n:通道,小道,楼道,通路,小路,过道,走廊,夹道",
"passbook":"n:存折",
"passee":"n:纬纱",
"passenger":"n:乘客,旅客,行人,过路人,客人,客",
"passenger ship":"n:客轮",
"passenger train":"n:客车",
"passer":"n:旅客,过路人,过客",
"passer-by":"n:过路人,过客",
"passerby":"n:过路人,路人",
"passim":"d:处处",
"passing":"n:通过;v:穿过,透射;d:非常,极其;a:现代,及格",
"passing game":"n:及格赛",
"passingly":"d:顺便,很;a:仓卒",
"passion":"n:激情,热情,爱好,热爱,痛苦,情,热恋,激怒,殉教,热心,性爱,热望",
"passionate":"a:多情,炽热",
"passionflower":"n:西番莲",
"passive":"a:被动,消极;n:被动式",
"passive immunity":"n:被动免疫",
"passivity":"n:忍受,消极怠工,被动",
"passover":"n:耶稣",
"passport":"n:护照,通行证,手段,保障,入场券,执照",
"password":"n:口令,密码",
"past":"p:走过,过,过去;a:往,旧;n:往事;v:往;f:过;d:过",
"past tense":"n:过去时",
"pasta":"n:面团",
"paste":"n:浆糊,面团,软膏,糊,糨糊;v:粘贴,溜",
"pasteboard":"n:纸板,门票",
"pastel":"n:小品文",
"pastern":"n:骨胶,胶",
"pastime":"n:消遣,娱乐,游戏",
"pasting":"v:胶合",
"pastor":"n:牧师",
"pastoral":"n:牧歌,田园诗",
"pastry":"n:点心,糕点,糕,糕饼,饽饽,饵",
"pasturage":"n:放牧,牧场,畜牧;v:放牧",
"pasture":"n:牧场,牧草;v:放牧",
"pastureland":"n:牧场",
"pasty":"n:馅饼;a:苍白",
"pat":"v:拍,拍打,爱抚,抚,摩,扑打;d:合适,恰好,适当,正好;n:抚摩,抚;a:滚瓜烂熟",
"patch":"v:补缀,东拼西凑,弥缝,靪,插入,调处,弥补,制止;n:斑点,斑纹,修补",
"patch up":"v:东拼西凑,平息,弥补,调处,补缀,弥缝,衲,修理,修补",
"pate":"n:头,前额,家伙,头脑,脑袋",
"patella":"n:髌骨,髌,膝盖",
"patent":"n:专利,专利权,特权",
"patent leather":"n:漆皮",
"patent office":"n:专利局",
"patently":"d:显然,公然,一清二楚",
"pater":"n:父亲",
"paternity":"n:作者,出处,父系,来源,父权",
"paternoster":"n:符咒",
"path":"n:小路,路,路径,小径,道路,小道,路线,轨迹,途径,轨道,人行道,弹道,途,带,路程,蹊径,路途,跑道,轨,道,走道,山径,方式,徼,径",
"pathetic":"a:可怜;v:泄气,荡气回肠",
"pathogen":"n:病原体,邪气,病因",
"pathogenesis":"n:发病",
"pathology":"n:病理学,病理,变态,病状,反常,病变",
"pathos":"n:哀婉,悲怆,凄楚,怜悯,同情",
"pathway":"n:途径,轨道,弹道,小路,航线,轨迹",
"patience":"n:耐心,耐性,忍耐,忍受,容忍,坚韧",
"patient":"n:病人,患者;a:耐烦,坚苦",
"patina":"n:神情,铜锈,铜绿,外貌",
"patio":"n:院子,庭院",
"patois":"n:方言,行话,土话,隐语,土语",
"patriarch":"n:族长,创始人,罗马教皇,元老,鼻祖,家长",
"patriarchal":"a:父系",
"patriarchy":"n:家长制,父权制",
"patrimony":"n:遗产,传统",
"patriot":"n:爱国者,爱国人士",
"patriotism":"n:爱国主义,爱国,爱国心",
"patrol":"n:斥候,囚车;v:梭巡",
"patrol wagon":"n:警车",
"patron":"n:靠山,保护人,老病号,顾主",
"patronage":"n:赞助,惠顾,保护,顾,光顾,支援,奖励",
"patronize":"v:光顾,赞助,庇护,惠顾,顾,栽培,支援,保护",
"patronymic":"n:姓",
"patsy":"n:替罪羊,懦夫",
"patter":"n:行话,隐语,黑话;v:祷告",
"pattern":"n:模式,图案,形式,图样,方式,结构,样板,模型,纸样,格局,式样;v:仿造",
"patterning":"n:图形",
"paucity":"n:贫乏,缺乏,少量,少许",
"paul":"n:保罗,棘爪",
"paunch":"n:肚子,大肚子,腹",
"paunchy":"v:大腹便便;a:大腹便便",
"pauper":"n:穷人,贫民,穷光蛋,穷棒子,乞丐",
"pause":"v:停,停顿;n:断句,中止",
"pave":"v:铺,铺路,铺设,筑,设,铺砌",
"pavement":"n:人行道,便道,路面,走道,铺面",
"pavilion":"n:亭子,外耳,耳廓,凉亭,天空,亭,分馆,楼阁,阁,看台",
"paving":"n:铺砌,铺面,铺路;v:铺路",
"pavlov":"n:巴甫洛夫",
"paw":"v:抓;n:爪,脚爪",
"pawl":"n:爪,卡子,千斤,棘爪",
"pawn":"n:当;v:答应",
"pawn ticket":"n:当票",
"pawnshop":"n:当铺",
"pay":"v:付;n:支付,偿还,报答;a:划算",
"pay back":"v:还清,偿付,偿还,报答",
"pay cash":"v:兑现,付现",
"pay for":"v:赔,偿付,赔偿,赔钱",
"pay off":"v:还清,付清",
"pay out":"v:付出,支,出,放松",
"pay packet":"n:工资袋",
"payable":"a:应付;v:应付",
"paycheck":"n:薪水",
"payer":"n:付款人",
"paying":"a:合算,划算,上算",
"paymaster":"n:出纳员",
"payment":"n:支付,报酬,缴纳,赔偿,酬,补偿,报偿;v:支付",
"payoff":"n:分赃,结束,发薪,高潮,支付,盈利,报仇,报复,了结,算清;v:支付",
"payola":"n:贿赂",
"payout":"n:花费,支出",
"pea":"n:豌豆",
"pea bean":"n:菜豆",
"pea family":"n:豆科",
"pea green":"n:豆青,豆绿,黄绿色",
"peace":"n:和平,和,讲和,平静,安静,安宁,平安,太平,和睦,安,安心,平和,寂静,升平,悠闲,和好,沉默",
"peace of mind":"n:心平气和",
"peace officer":"n:警官",
"peace treaty":"n:和约",
"peaceful":"a:宁静,恬静,安静,幽静,安谧,睦,泰;v:安生",
"peacefully":"d:安然",
"peacemaker":"n:和事老,调人",
"peacemaking":"n:调停,调解;v:调解",
"peacetime":"a:平时",
"peach":"n:桃子,桃;v:告密",
"peacock":"v:招摇过市,炫耀;n:孔雀",
"peacock ore":"n:黄铜矿",
"peafowl":"n:孔雀",
"peahen":"n:孔雀",
"peak":"n:高峰,山峰,峰,峰值,山顶,顶峰,波峰,尖峰,顶,帽舌,顶点,尖端,尖头,海角,最高点;v:竖起,高耸,缩小,憔悴,消瘦,减少",
"peak season":"n:旺季",
"peaked cap":"n:鸭舌帽",
"peal":"v:鸣响;n:钟声,编钟,响声",
"peanut":"n:花生,花生米,长生果,落花生,小人物",
"peanut oil":"n:生油",
"pear":"n:梨,梨树,梨子",
"pearl":"n:珍珠,珠子,珠,精华,赛珍珠,微粒,真珠,珍品,珠玑",
"pearl harbor":"n:珍珠港",
"pearl oyster":"n:珠蚌",
"pearl river":"n:珠江",
"pearly nautilus":"n:鹦鹉螺",
"peas":"n:豆,豌豆,豆子",
"peasant":"n:农民,农夫,庄稼人,乡下人,农人,农,泥腿子",
"peasantry":"n:农民",
"peat":"n:泥炭,泥煤,草炭",
"pebble":"n:卵石,石子,鹅卵石,石头子儿,水晶,河卵石,皱纹,石子儿,砾",
"pebbles":"n:雨花石,沙砾",
"pecan":"n:山核桃",
"peck":"v:啄;n:大量,找岔子",
"peck at":"v:啄食",
"pecker":"n:啄木鸟,啄,精神,簧片",
"pectin":"n:果胶",
"pectoral":"n:胸肌,胸鳍",
"pectoral fin":"n:胸鳍",
"pectoralis major":"n:胸大肌",
"peculate":"v:侵吞,盗用,挪用",
"peculiar":"a:特殊,怪,奇特,特有,异样,各别,别具一格,怪里怪气,神奇,各,特异;n:犹太人,特权,异样;v:别具一格;r:各",
"peculiarity":"n:怪癖,特点,特色,特性,特质,奇形怪状,特殊性",
"pedagogical":"a:师范",
"pedagogics":"n:教学法,教育学",
"pedagogue":"n:教员,老师,教师",
"pedagogy":"n:教育学,师范,教学法",
"pedal":"n:踏板;v:登",
"pedant":"n:书呆子,腐儒,学究,空谈家,夫子,迂夫子,书痴",
"pedantic":"a:酸溜溜,酸,迂",
"pedantry":"n:迂腐,穷酸气;a:迂腐",
"peddle":"v:兜售,叫卖,贩卖,推销,零卖,斥卖,传播,兜销",
"peddler":"n:小贩,商贩",
"peddling":"v:商贩",
"pederasty":"v:鸡奸;n:鸡奸",
"pedestal":"n:底座,支座;v:支持",
"pedestrian":"n:行人;a:平淡,平淡无奇",
"pediatric":"a:儿科",
"pediatrics":"n:小儿科,儿科",
"pedicab":"n:三轮儿,三轮车",
"pedicure":"v:修,修脚;n:修脚",
"pedigree":"n:出身,纯种,谱系,血统,词源,世系,身家,种,家谱,种子,门第,起源",
"pediment":"n:山墙,山,山头",
"pedology":"n:土壤学,小儿科",
"pedometer":"n:计步器",
"peduncle":"n:花梗",
"pee":"v:撒尿,小便;n:小便,尿",
"peek":"v:窥视,偷看;n:一瞥",
"peel":"v:剥落,剥,脱皮,削;n:果皮,皮,嫩芽",
"peel off":"v:剥落,剥离",
"peeling":"n:蜕皮",
"peen":"n:锤头",
"peep":"v:窥视,偷看,出现,张望,吱;n:窥探,露出,一瞥,出现;d:吱",
"peep sight":"v:准星",
"peeper":"n:眼睛,望远镜,镜子,眼镜",
"peephole":"n:窥孔",
"peer":"v:隐约可见;n:伙伴",
"peerage":"n:贵族,爵",
"peeress":"n:贵妇",
"peerless":"a:绝代,无双,天下第一,无出其右,举世无双,绝伦,盖世,无比,绝世无匹,无可比拟;v:盖世,无可比拟,天下第一,无双",
"peeve":"n:怨恨,气恼,生气;v:怨恨",
"peewee":"n:矮子",
"peg":"n:借口,衣夹,挂;v:分清,稳住,鉴定,识别",
"peg down":"v:约束",
"pei":"n:裴",
"peignoir":"n:浴衣",
"peking":"n:北京",
"peking man":"n:北京,北京猿人,北京人",
"pekingese":"n:北京人,巴儿狗,叭儿狗;a:北京",
"pelf":"n:赃物",
"pelican":"n:鹈鹕",
"pell-mell":"d:混乱,乱七八糟,匆促,鲁莽;n:混乱,混战,杂乱,纷乱",
"pellet":"n:粒,药丸,球,炮弹,颗粒,丸;v:弹",
"pellets":"n:沙子,铁砂",
"pelt":"n:开足马力,皮货,皮张,毛皮,投掷,打击,皮衣,速度;v:投,攻击,投掷",
"pelvic girdle":"n:腰带",
"pelvis":"n:骨盆,肾盂",
"pemmican":"n:提要,摘要",
"pen":"n:钢笔,笔;v:作",
"pen nib":"n:笔尖",
"pen pal":"n:笔友",
"penal":"a:刑事",
"penalize":"v:惩罚,处罚,罚,惩处,惩",
"penalty":"n:惩罚,罚款,处罚,刑罚,报应,赔偿;v:罚",
"penance":"n:苦行,悔过;v:悔过,处罚",
"pence":"n:便士",
"penchant":"n:爱好,嗜好",
"pencil":"n:铅笔,笔,光束,束,石笔,蜡笔,画笔,电子束",
"pencil box":"n:铅笔盒",
"pencil case":"n:铅笔盒",
"pencil sharpener":"n:卷笔刀",
"penciling":"v:铅笔画",
"pend":"v:悬而未决,倒置,悬挂",
"pendant":"n:附属物,缆索,吊灯,耳环,坠子,对手,附录",
"pendent":"n:缆索,吊灯",
"pending":"p:在_之前,之前;v:听候;a:听候",
"pendulum":"n:摆,钟摆;v:摆",
"penetrate":"v:深入,穿透,透,渗透,弥漫,进入,透过,洞察,渗入,穿,识破,钻,看穿,击穿,深入人心,贯穿,扩散,辟,突入,打动,看透,侵入",
"penetrating":"a:尖锐,透彻;v:入木三分,辟,刻",
"penetratingly":"d:一针见血",
"penetration":"n:穿透,突破,贯穿,眼光;v:突破,穿透",
"penguin":"n:企鹅",
"penicillin":"n:青霉素,盘尼西林",
"peninsula":"n:半岛",
"penis":"n:阴茎,小便",
"penitence":"n:忏悔,悔罪,悔悟,悔过,后悔",
"penitentiary":"n:监狱,感化院",
"penknife":"n:小刀",
"penman":"n:笔者,文人,作家,书法家",
"penmanship":"n:书法,习字,写作,书体,笔法,笔迹",
"pennant":"n:旗子",
"penniless":"a:一文不名,家贫如洗,不名一文,囊空如洗",
"penny":"n:钱,便士,小钱",
"penny-pinching":"a:一毛不拔",
"pennyworth":"n:便宜货,少量,交易",
"penology":"n:刑罚学",
"pension":"n:养老金,退休金,抚恤金,恤金,年金,公寓,补助费,补助金,退休费",
"pensioner":"n:随员,跟班,随从",
"pentagon":"n:五边形",
"pentecost":"n:圣灵降临节",
"penthouse":"n:阁楼",
"penumbra":"n:阴影",
"penury":"n:吝啬,赤贫,缺乏,贫穷",
"peon":"n:跟班,巡警,日工,卒",
"peony":"n:牡丹,芍药",
"people":"n:人,人们,人民,别人,民族,老百姓,家,人类,百姓,民,亲属,国民,家属,祖先,黎民百姓,随从,黎民;r:别人,人们;v:占据",
"peoples":"n:民族",
"pep":"n:锐气,活力,劲头;v:刺激,鼓励",
"pepper":"n:胡椒,胡椒粉,急性子,精力,勇气,胡椒面,劲头,活力;v:撒,痛骂",
"pepper sauce":"n:辣椒酱",
"peppermint":"n:薄荷,薄荷油,薄荷糖",
"peppery":"a:辣",
"pepsin":"n:胃蛋白酶",
"peptide":"n:肽,胜;v:胜",
"per":"p:每,一,以,由,经,根据;r:每",
"per se":"p:本身",
"per year":"p:年均",
"peradventure":"d:恐怕;n:疑问,疑惑",
"perambulate":"v:穿过,走过,巡视,勘查,徘徊,闲荡,闲逛,巡行,漫步",
"perambulation":"n:漫步,巡视,徘徊,闲荡",
"percale":"n:细布",
"perceive":"v:发觉,看见,察觉,觉察,看出,感觉,了解,理解,领悟,直观,领会,听见;n:镜",
"percent":"n:百分率;a:百分",
"percentage":"n:百分比,百分数,比例,部分,百分率,佣金,用处,手续费,好处,开,成数,可能性",
"percentage point":"n:百分点",
"perceptibly":"d:显然",
"perception":"n:感觉,感知,洞察力,直觉,知觉,感受,观念,感性认识,理解力,征收,概念,收获",
"perceptive":"v:感知;a:知觉",
"perceptual":"a:感性",
"perch":"n:高位,连杆,虚荣心,鲈鱼,没落,自负,竿,架,主轴;v:歇,休息,验",
"perchance":"d:偶然,可能,或许",
"percipient":"a:鉴别力,鉴赏力;n:洞察",
"percolate":"v:煮,渗滤,滤,穿过,刺穿,渗出,渗漏,渗透",
"percolation":"n:渗滤;v:渗透",
"percolator":"n:过滤器",
"percuss":"v:敲,击,敲打",
"percussion":"n:叩诊,敲打,碰撞,打击,打击乐器,撞击;v:撞击,击发",
"percussion cap":"n:雷管",
"perdition":"n:灭亡,沉沦,地狱,毁灭",
"peregrinate":"v:旅程,游历,旅行,步行",
"peregrination":"n:游历,旅程",
"peregrine":"n:外侨",
"peremptory":"a:专横,蛮横无理,蛮横",
"perennial":"a:多年生;n:多年生植物",
"perfect":"a:完全,完美,绝妙,尽善尽美;v:改良,完成,改善,贯彻;n:健全",
"perfection":"n:完美,标本,完成,改进,改善,完全,完整性,典型,圆满,熟习,无缺;v:改进,改善",
"perfectly":"d:绝对,满",
"perfectness":"n:完美",
"perfidy":"n:背信弃义,出卖,叛变",
"perforate":"v:穿孔,穿,穿过,刺穿,钻孔,贯穿,打眼,打孔",
"perforation":"n:穿孔,射孔,打孔;v:穿孔",
"perforce":"d:不得已",
"perform":"v:执行,完成,进行,表演,演出,履行,干,演,实行,演奏,上演,施行,行使,行,奏",
"performance":"n:演出,表演,性能,成绩,工作,演奏,特性,执行,行为,履行,实行,完成,绩效,行动,实现,动作,偿还,把戏,功绩,弹奏,素质;v:执行",
"performer":"n:演员,乐师,歌手,执行者,能手,选手",
"performing":"v:执行",
"perfume":"n:香水,香味,香料,香气,芳香,香",
"perfumery":"n:香水,香料",
"perfunctorily":"d:苟且,不力",
"perfunctory":"a:不痛不痒,草率,肤皮潦草,马虎,含糊,不力",
"perfusion":"n:灌注",
"pergola":"n:凉棚,凉亭,花架",
"perhaps":"d:也许,可能,或许,大概,或,恐怕,或者,说不定,许,怕,多半,兴许,指不定,敢,作兴,兴,大半,慨,容或,容许,备不住;v:脱,敢,兴;n:假定,设想;c:或",
"peri":"n:仙女,美人",
"pericardium":"n:心包",
"perihelion":"n:最高点,极点",
"peril":"n:危险,冒险;v:患;a:危险",
"perilla frutescens crispa":"n:紫苏",
"perilous":"a:危险,险,险恶,艰险,危",
"perimeter":"n:周围,周长,周边,周",
"perineum":"n:会阴",
"period":"n:时期,周期,时代,阶段,过程,句号,期间,月经,纪,期,例假,学时,循环,课时,终结,乐段;v:循环",
"period of time":"n:时段",
"periodical":"n:期刊,杂志;a:定期",
"periodically":"d:定期,按时,分期",
"periodicity":"n:周期性,周率,周波,频率",
"periodontal disease":"n:牙周病",
"peripatetic":"n:小贩,游历",
"peripheral":"n:外围",
"periphery":"n:周围,边界,外面,外围,周边,边缘,周,外部,圆周",
"periscope":"n:潜望镜",
"perish":"v:毁坏,腐烂,枯萎,死去,灭亡,灭,腐败,殒命,堕落,沦丧,消亡,陨灭,亡,殒灭,泯,消灭,殒,暴卒,毁灭",
"perisher":"n:混蛋",
"perishing":"d:极,非常",
"peristalsis":"v:蠕动;n:蠕动",
"peritoneum":"n:腹膜",
"peritonitis":"n:腹膜炎",
"periwig":"n:假发",
"periwinkle":"n:海螺",
"perjury":"n:伪证",
"perk":"v:打扮,昂首;n:赏钱",
"perk up":"v:装腔作势,提神",
"perm":"v:烫,烫发",
"permanence":"n:永久,永久性,持久",
"permanency":"n:永久性",
"permanent":"a:永久,持久,常任,常设,久长,融,常驻;v:融",
"permanent magnet":"n:永久磁铁",
"permanent tooth":"n:恒齿",
"permanent wave":"n:电烫,烫发",
"permanently":"a:长久;d:长久",
"permeability":"n:磁导率,渗透",
"permeate":"v:弥漫,渗,充满,渗透,渗入,透过,穿过,贯通,渗出,贯串,磅礴,普及,融为一体",
"permeation":"n:渗透,浸透;v:渗透",
"permissibility":"n:允许",
"permission":"n:允许,许可,同意,准许,答应,许;v:允许,许可",
"permit":"v:允许;n:准许,凭照",
"permutation":"v:排列,交换,互换,置换;n:互换",
"permute":"v:置换,变更,交换,软化,排列,取代",
"pernicious":"a:有害,恶性",
"perniciousness":"n:危害性",
"peroxide":"n:过氧化物,过氧化氢",
"perpendicular":"n:垂线,直立,垂直面,绝壁;a:垂直;v:垂直,竖",
"perpendicularity":"n:垂直",
"perpetrate":"v:做,犯,胡说,施",
"perpetration":"n:行凶,为非作歹",
"perpetual":"a:永久性,永恒,永久",
"perpetually":"d:永",
"perpetuate":"v:不朽",
"perpetuity":"n:永久,永远,不朽,永恒",
"perplex":"v:困惑,迷惑,困扰,迷",
"perplexed":"a:困惑,迷茫,手足无措",
"perplexing":"v:错综复杂",
"perplexity":"n:困惑,为难,混乱",
"perquisite":"n:津贴,酒钱,奖金,赏钱",
"persecute":"v:迫害,困扰,摧残,强求",
"persecution":"n:迫害,困扰,残害",
"perseverance":"n:不屈不挠,恒心,坚持,坚忍不拔,坚定,恒",
"persevere":"v:坚持,忍耐,不屈不挠,支持,鼓舞,支撑,持之以恒",
"persevering":"a:有恒,坚持不渝;v:坚持不渝",
"persia":"n:波斯",
"persian gulf":"n:波斯湾",
"persiflage":"n:挖苦,戏弄,嘲弄",
"persimmon":"n:柿子,柿",
"persist":"v:坚持,固执,存留,力持,保留",
"persist in":"v:固执,力持,执",
"persistence":"n:持久,固执,存留,坚持,持之以恒,余辉,顽固,恒心,坚持不渝",
"persistent":"a:持久,一贯,坚持不渝,持之以恒",
"persistently":"d:一个劲儿",
"person":"n:人,个人,人物,人称,身体,人身,人格,容貌,位,法人,个体,徒,自身,士,子",
"persona":"n:人,角色,人物",
"personable":"a:风度翩翩",
"personage":"n:人物,显贵,人,角色,个人,名流,人士,名士,要人",
"personages":"n:显贵",
"personal":"a:切身,贴身,己,亲身;n:动产,个人,私人;v:自用;r:己",
"personal equation":"n:个性",
"personal estate":"n:动产",
"personal foul":"n:侵人犯规",
"personal letter":"n:手书,私信",
"personality":"n:个性,人,性格,人格,人物,品格,个体,为人,地势,容貌,做人",
"personally":"d:亲自,亲眼,面,私下,亲口,手,躬,私自,亲,亲手;n:面,身,手",
"personalty":"n:动产",
"personification":"n:典型,化身,拟人,人格化,表演,体现",
"personify":"v:象征,体现",
"personnel":"n:人员,人事,职员,员工,班底,勤杂人员",
"perspective":"n:透视,观点,看法,眼界,远景,眼力;a:透视;v:透视",
"perspicacity":"n:慧眼,聪明,敏锐,颖悟",
"perspicuity":"n:明白,明晰,清楚",
"perspiration":"n:汗水,出汗,汗,发汗,汗液",
"perspire":"v:排,出,发,出汗",
"persuade":"v:说服,劝说,相劝",
"persuader":"n:手枪",
"persuasion":"n:说服,信仰,说服力,劝告,确信,疏导,唇舌,动员,国籍,劝导,信条,阶级,信念,性别,教派,种类",
"persuasive":"n:动机,诱因;a:动听",
"persuasiveness":"n:说服力",
"pertain":"v:有关,属于,适合,附属,关于,相配",
"pertinacious":"a:牛脾气",
"pertinacity":"n:顽固,执拗,顽强",
"pertinence":"n:相关,恰当,相关性,针对性,适当",
"pertinent":"a:中肯,贴题;n:参考",
"pertness":"n:无礼",
"perturb":"v:烦扰,扰乱,搅乱",
"perturbation":"n:不安,烦扰,狼狈,慌张,干扰,扰乱,焦虑;v:干扰",
"perturbed":"a:忧烦,乱糟糟,忐忑;v:心猿意马",
"pertussis":"n:百日咳",
"peru":"n:秘鲁",
"peruke":"n:假发;v:装",
"perusal":"n:熟读,目测,研讨,精读;v:精读",
"peruse":"v:精读,研讨,读,熟读,披览,披阅",
"pervade":"v:充满,遍及,弥漫,渗透,蔓延,扩大,普及",
"perverse":"a:拗,刚愎,乖戾,顽梗,聱,横,剌,戾,丧心病狂,悖,乖,横蛮,反常",
"perversion":"n:歪曲,堕落,曲解,恶化,误用,坠落,败坏,颠倒,滥用",
"perversity":"n:反常,刚愎,乖僻,坠落,邪恶,堕落",
"pervert":"v:堕落,误用,误解,颠倒;a:反常",
"perverted":"a:昏天黑地",
"peso":"n:比索",
"pessimism":"n:悲观",
"pessimistic":"a:悲观;n:灰色",
"pest":"n:害虫,虫害,害人虫,鸟害,蟊贼,瘟疫",
"pester":"v:缠,纠缠,蘑菇,泡蘑菇,磨蹭,缠绕,磨,折磨,胡缠,烦恼",
"pesticide":"n:农药,杀虫剂",
"pestilence":"n:瘟疫,疫病,鼠疫,祸害,疠,疫疠,时疫,疫,流行病",
"pestle":"v:擂,捣,研磨;n:杵",
"pet":"v:宠爱,爱,生气,拥抱,娇养,钟爱,爱抚;n:烦恼,爱子",
"pet name":"n:奶名,乳名",
"petal":"n:花瓣,瓣,腕足",
"petard":"n:作法自毙",
"peter":"n:彼得,麻醉品",
"peter the great":"n:彼得大帝",
"pethidine":"n:度冷丁",
"petiole":"n:叶柄,柄",
"petition":"n:请愿书;v:禀,祈求",
"petitioner":"n:原告",
"petrel":"n:海燕",
"petri dish":"n:培养皿",
"petrifaction":"n:顽固,僵化,石化,化石;v:僵化",
"petrify":"v:石化,僵化",
"petrifying":"v:僵化",
"petrol":"n:汽油,石油",
"petrol station":"n:加油站",
"petrolatum":"n:凡士林,矿脂",
"petroleum":"n:石油",
"petroleum jelly":"n:矿脂",
"petrology":"n:岩石学",
"petted":"v:乖戾",
"petticoat":"n:衬裙,裙子,套裙,少女,童装,女装",
"pettifog":"v:诡辩,挑剔",
"pettifogger":"n:讼棍",
"pettifoggery":"n:刀笔,狡诈",
"pettiness":"n:卑劣,小家子气,琐碎",
"petting":"n:爱抚,拥抱",
"petty":"a:小,窄,藐,琐;n:厕所,小心眼;v:小心眼儿",
"petty cash":"n:零用钱",
"petty officer":"n:下士,军士",
"petulance":"n:使性子,无礼,别扭,暴躁",
"pew":"n:座位,讲台,椅子",
"pewter":"n:奖杯,奖金",
"phage":"n:噬菌体",
"phagocyte":"n:吞噬细胞",
"phalanx":"n:指骨,趾骨,集结,结社,集团,方阵",
"phallus":"n:阴茎,鬼笔",
"phantasm":"n:错觉,幻影,空想,幻像,幻想,幽灵,幻觉",
"phantom":"n:幽灵,幻影,错觉,鬼怪,妄想,影像,假想;a:仿真",
"pharaoh":"n:法老",
"pharisee":"n:伪君子",
"pharmaceutical":"n:药品,药物;v:制药;a:药物",
"pharmaceuticals":"n:药物",
"pharmaceutics":"n:药物学,制药学",
"pharmacist":"n:药剂师,司药",
"pharmacology":"n:药理学,药学,药理,药物学",
"pharmacopoeia":"n:药典",
"pharmacy":"n:制药,药店,药房,药学",
"pharyngitis":"n:咽炎",
"pharynx":"n:咽,咽头;v:咽",
"phase":"n:相,阶段,相位,方面,状态,局面,月相,期,段落,变相,阶级,盈亏;v:变相",
"phase angle":"n:相位角",
"phasing":"v:变相",
"pheasant":"n:野鸡,翟,山鸡,雉",
"phenacetin":"n:乙酰",
"phenobarbital":"n:苯巴比妥",
"phenol":"n:酚,苯酚,石炭酸",
"phenolphthalein":"n:酚酞",
"phenomena":"n:现象",
"phenomenon":"n:现象,神物,珍奇,珍品,奇迹,症候",
"phenotype":"n:表现型",
"phial":"n:药瓶",
"philadelphia":"n:费城",
"philander":"v:调情,玩弄",
"philanthropic":"a:慈善",
"philanthropist":"n:慈善家,善人",
"philanthropy":"n:慈善,博爱,善心",
"philatelic":"a:集邮",
"philatelist":"n:集邮者",
"philately":"n:集邮",
"philharmonic":"n:管弦乐队,音乐会",
"philippic":"n:痛骂",
"philippines":"n:菲律宾",
"philistine":"n:市侩,市井小人,门外汉;a:庸俗,鄙俗",
"philistinism":"n:庸俗",
"philology":"n:文字学,语言学",
"philosopher":"n:哲学家,哲人,思想家,学者,贤人",
"philosopher's stone":"n:哲理",
"philosophical":"a:达观",
"philosophize":"v:思索",
"philosophy":"n:哲学,哲理,达观,人生观,宗旨,世界观",
"philter":"n:春药",
"phlebitis":"n:静脉炎",
"phlebotomy":"n:放血",
"phlegm":"n:痰,冷淡,粘液,迟钝",
"phloem":"n:韧皮部",
"phnom penh":"n:金边",
"phobia":"n:恐惧症,憎恶,恐惧",
"phoenix":"n:凤,海枣,绝代佳人,凤凰",
"phone":"n:电话;v:挂",
"phone book":"n:电话簿",
"phone booth":"n:电话亭",
"phoneme":"n:音素,音位,音",
"phonetic alphabet":"n:拼音字母,音标",
"phonetic symbol":"n:音标",
"phonetic transcription":"n:拼音,音标",
"phonetics":"n:语音学",
"phonics":"n:声学,语音学",
"phoniness":"n:虚假",
"phonograph":"n:留声机,唱机,电唱机",
"phonograph needle":"n:唱针",
"phonology":"n:声韵学,音位学,音韵学",
"phony":"n:骗子,假货;a:空头",
"phosphate":"n:磷酸盐",
"phosphor":"n:金星,黄磷",
"phosphorescence":"n:磷光,鬼火",
"phosphoric":"a:磷",
"phosphorus":"n:磷",
"photo":"n:照片,相片,像片",
"photocell":"n:光电管,光电池,电眼",
"photochemical":"a:光化",
"photochemistry":"n:光化学",
"photocopy":"v:影印;n:影印本",
"photoelectric":"a:光电",
"photoelectric cell":"n:光电管,光电池",
"photograph":"n:照片,照,相片;v:照",
"photograph album":"v:影集",
"photographer":"n:摄影师,摄影家",
"photographic film":"n:胶片",
"photographic paper":"n:相纸,印相纸,照相纸",
"photographic plate":"n:底版",
"photographic print":"n:影印",
"photographs":"n:照片",
"photography":"n:照相;v:照相",
"photometer":"n:光度计,曝光表",
"photon":"n:光子,光量子",
"photosensitive":"v:感光;a:感光",
"photosphere":"n:光球",
"photosynthesis":"n:光合作用",
"phrase":"n:短语,词组,用语,成语,措辞,名言,短句,警句,名词;v:恭维",
"phraseology":"n:措词,熟语,术语,辞,用语",
"phrasing":"n:措词,语法",
"phylactery":"n:护符",
"phyllostachys bambusoides":"n:桂竹",
"phylogeny":"n:发展史",
"phylum":"n:门",
"physic":"n:医药,医学,泻药,药品,医术;v:处罚,治愈",
"physical ability":"n:体能",
"physical change":"n:物理变化",
"physical education":"n:体育,体育运动",
"physical exercise":"n:运动",
"physical geography":"n:地学",
"physical pendulum":"n:复摆",
"physical property":"n:物理性质",
"physical science":"n:自然科学",
"physical therapy":"n:物理疗法",
"physicals":"n:现货",
"physician":"n:医生,医师,大夫,医",
"physicians":"n:世医",
"physics":"n:物理学,物理",
"physiognomy":"n:相貌,面貌,外观,特征,形状,脸,特色",
"physiography":"n:地形学,地学",
"physiologic":"a:生理",
"physiology":"n:生理学,生理",
"physiotherapy":"n:理疗",
"physique":"n:体格,体质,地形,形体,筋骨,体魄;a:健康",
"pi":"n:皮,圆周率",
"pianist":"n:钢琴家,钢琴师",
"piano":"n:钢琴",
"pianoforte":"n:钢琴",
"piao":"n:朴",
"piazza":"n:广场,市场,游廊",
"pic":"n:照片,电影",
"picaresque":"n:歹徒",
"picasso":"n:毕加索",
"picayune":"n:小人物",
"piccolo":"n:短笛",
"pick":"v:摘,挑,挑选,拿,选,采摘,挖,找到,吃,采,啄食,择,得到;n:拨子,牙签",
"pick off":"v:采取,拾取",
"pick out":"v:选拔,拣,抉",
"pick over":"v:精选",
"pick up":"v:拣,搂,拈,提取,掇,回升,摭,搛",
"pick-off":"n:传感器",
"pickax":"n:镐,洋镐;v:掘",
"pickaxes":"n:镐头",
"picked":"a:精锐,精选,精",
"picker":"n:扒手,窃贼",
"picket":"n:纠察,桩,支柱;v:放哨",
"picket line":"v:警戒线",
"picking":"n:采摘,偷窃,掘",
"pickle":"n:泡菜,困境;v:腌制",
"pickles":"n:泡菜,咸菜,腌菜,小菜,酱菜",
"pickpocket":"n:扒手,掱手,三只手",
"pickup":"n:传感器,消息,电唱头,改进,加快,复兴,拾音器;v:摄像",
"picnic":"n:野餐,郊游",
"picric acid":"n:苦味酸",
"pictogram":"n:象形文字,图表",
"pictograph":"n:象形字,图表,象形文字",
"pictorial":"n:画报,图解,画刊,画页",
"picture":"n:画,照片,图,图画,图片,图像,照,图象,画像,影片,像,景象,相片;v:描画,写",
"picture book":"n:连环画",
"picture frame":"n:画架,绞刑架",
"picture gallery":"n:美术馆",
"picture palace":"n:电影院",
"picture postcard":"n:画片",
"picture show":"n:画展,电影院,电影",
"picture tube":"n:显像管",
"picturesque":"a:入画",
"piddle":"v:鬼混,浪费,撒尿",
"pie":"n:馅饼,糕饼,杂乱,喜鹊,混乱,排",
"piebald":"a:花斑;n:花斑",
"piece":"n:块,一块,碎片,工作,部分,棋子,片,件;v:修补,接,结合,修理",
"piecemeal":"a:零星,零零星星,零碎;v:粉碎;n:块",
"pieces":"n:碎片",
"pied":"a:杂色",
"piedmont":"n:山麓",
"pier":"n:码头,桥墩,墩,防波堤,柱,埠头,墩子,埠,丁坝",
"pierce":"v:穿,突破,穿透,刺穿,看穿,贯,戳穿,钻,凿孔,贯穿,洞察;n:凿孔",
"piercer":"n:钻,锥",
"piercing":"v:穿透,交叉,刺骨,穿孔;a:刺骨,尖利,尖,尖锐",
"piety":"n:孝顺,虔敬,恭敬,爱国,孝敬,忠顺",
"piezoelectric effect":"n:压电效应",
"piffle":"n:傻事,梦话,废话,傻话;v:砍大山",
"pig":"n:猪,生猪,仔猪,野猪,生铁,猪肉,猪猡,铸铁;v:狼吞虎咽,下",
"pig farm":"n:猪场",
"pig out":"v:狼吞虎咽",
"pigeon":"n:鸽子,鸽,家鸽,少女,姑娘,傻子,生手,白鸽",
"pigeon pea":"n:木豆",
"pigeonhole":"v:置诸高阁,扣压,压,搁置,束之高阁",
"piggery":"n:养猪场,猪圈,猪场",
"pigging":"v:生铁;n:生铁",
"pigheaded":"a:拧,执拗;v:拧",
"pigheadedness":"n:牛性,牛脾气",
"piglet":"n:仔猪,猪娃,猪崽,猪仔,猪苗",
"pigment":"n:颜料,色素,颜色",
"pigmentation":"n:染色",
"pigpen":"n:猪圈,猪舍",
"pigskin":"n:猪皮,马鞍",
"pigsty":"n:猪圈,框架",
"pigtail":"n:辫子,小辫,小辫儿,辫,发辫",
"pike":"n:狗鱼,矛,梭子鱼,尖头,长枪,关卡,尖峰,大路,长矛,矛头;v:死,走",
"piker":"n:胆小鬼,小气鬼,流浪者",
"pilchard":"n:沙丁鱼",
"pile":"n:堆,大量;v:码,积累,堆叠,挤,摞,打",
"pile up":"v:簇,堆,堆叠,累,积聚,码,叠,丛集,摞",
"piles":"n:痔,痔疮",
"pilfer":"v:偷,小偷小摸,扒,偷窃;n:小偷小摸",
"pilferage":"n:小偷小摸,盗窃;v:盗窃,偷窃",
"pilferer":"n:偷,窃贼,小偷",
"pilfering":"v:小偷小摸",
"pilgrim":"n:香客,旅客,流浪者;v:朝圣,流浪",
"pilgrimage":"n:朝圣;v:朝圣",
"piling":"n:桩;v:打桩",
"pill":"n:药丸,医生,球,丸剂,丸药,丸,药剂,果皮,香烟;v:掠夺",
"pillage":"v:掠夺,掳掠,洗劫;n:抢劫",
"pillar":"n:柱子,台柱,矿柱,栋梁,柱头,台柱子,支柱,柱,墩,主心骨,柱石,顶梁柱",
"pillar box":"n:邮筒",
"pillbox":"n:碉,地堡,碉堡,小汽车",
"pillion":"n:后座,后坐",
"pillory":"n:笑柄",
"pillow":"n:枕头;v:枕,垫",
"pillow fight":"n:打闹",
"pillowcase":"n:枕套,枕头套",
"pills":"n:丸剂",
"pilot":"n:飞行员,驾驶员;v:引水",
"pilot light":"n:指示灯",
"pilothouse":"n:驾驶室",
"piloting":"n:引水,领航",
"pilotless aircraft":"n:无人驾驶飞机",
"pimiento":"n:辣椒",
"pimp":"n:老鸨,烟卷儿;v:拉皮条",
"pimple":"n:脓包,丘疹,粉刺,癍,疙瘩",
"pimples":"n:面疱",
"pin":"n:别针,销钉,插头,腿,销,钉,大头针;v:围困,绷,插脚,销",
"pin down":"v:掎,困,牵制,犄,围困",
"pin money":"n:零用钱",
"pin up":"n:别",
"pinafore":"n:围裙",
"pincers":"n:钳子,螯,铗,夹子,钳",
"pinch":"v:掐,捏,夹,抓住,拧;n:困苦,收缩,捕捉,危急",
"pinch hitter":"v:代理人",
"pine":"v:憔悴,渴望;n:凤梨",
"pine away":"v:憔悴",
"pine marten":"n:松貂",
"pine nut":"n:松仁,松果",
"pineal body":"n:脑上体",
"pineapple":"n:菠萝,凤梨,手榴弹",
"ping":"n:砰,平",
"ping-pong":"n:乒乓球",
"ping-pong ball":"n:乒乓球",
"ping-pong table":"n:台子",
"pinhead":"n:针头,傻子,店员",
"pinhole":"n:针孔",
"pinion":"n:臂膀,翅膀,羽毛;v:束缚",
"pink":"n:粉红色;v:桃红,扎,戳,刺,粉红色;a:桃红,粉",
"pink bollworm":"n:红铃虫",
"pinkeye":"n:红眼病,红眼,火眼",
"pinnacle":"n:尖顶,顶峰,极点,尖端,顶点;v:举起",
"pinny":"n:围巾",
"pinpoint":"v:指出,查明;a:详尽,一针见血;n:针尖",
"pinprick":"n:针孔,针眼,针刺",
"pins and needles":"n:发麻",
"pinstripe":"n:线条",
"pint":"n:品脱",
"pinto":"n:斑马",
"pinwheel":"n:风车",
"pioneer":"n:先驱,先驱者,拓荒者;v:提倡,开,开垦",
"pious":"a:虔诚,虔;v:孝敬",
"pip":"n:脉冲,点,果仁,标准,根茎,星,针头,种子;v:妨碍,挫败,死,打败,打破,射击,击伤",
"pipe":"n:管子,烟斗,管道,管;v:看,透露",
"pipe bowl":"n:烟袋锅",
"pipe dream":"n:黄梁美梦",
"pipe fitter":"n:管工",
"pipe rack":"n:烟斗架",
"pipe wrench":"n:管钳子",
"pipeline":"n:管道,管线,管路,流水线",
"pipette":"n:吸管",
"piping":"n:管道,滚边,花边;v:收缩",
"pipit":"n:鹨",
"pippin":"n:美人,种子",
"pipsqueak":"n:小人",
"piquancy":"n:调皮,辣味,活泼,痛快,辛辣,尖刻,开胃",
"pique":"v:夸耀;n:生气,呕气,探井",
"piracy":"n:剽窃",
"pirate":"n:海盗,强盗;v:掠夺",
"pisa":"n:比萨",
"pismire":"n:蚂蚁",
"piss":"v:小便,尿,撒尿;n:尿,小便",
"pistil":"n:雌蕊,花蕊,花须,蕊,蕤",
"pistol":"n:手枪,盒子枪,马枪",
"piston":"n:活塞",
"piston ring":"n:活塞环",
"piston rod":"n:活塞杆",
"pit":"n:坑,坑道,凹坑,核,掩体;v:凹陷,抵抗",
"pitch":"n:高度,音调;v:说大话,扎,选择",
"pitch into":"n:狼吞虎咽",
"pitch-black":"a:乌黑",
"pitch-dark":"a:黑咕隆咚,黑漆漆,黑森森,黑洞洞,黑黢黢,黑沉沉,漆黑",
"pitchblende":"n:沥青",
"pitched battle":"n:激战",
"pitcher":"n:投手,罐子,摊贩",
"pitchfork":"n:杈,音叉;v:推进",
"pitching":"n:投球;v:俯仰",
"pitchman":"n:摊贩",
"pitfall":"n:陷阱,阱,堑,诱惑,陷,陷坑,圈套",
"pith":"n:力气,髓,精髓,体力,瓤子,要点,骨髓,精力,要义,力,精神",
"pithead":"n:井口",
"pithy":"a:精粹,简练,简洁",
"pitiable":"a:可怜,可悲",
"pitiful":"a:可怜,惨,悲惨",
"pitiless":"a:狠心,忍心;v:忍心",
"piton":"n:尖峰",
"pitted":"a:麻",
"pitter-patter":"n:雨声",
"pitting":"v:腐蚀;n:锈斑",
"pittsburgh":"n:匹兹堡",
"pituitary":"n:垂体",
"pituitary gland":"n:垂体,脑下垂体",
"pity":"v:可怜;n:憾事,慈悲;a:遗憾",
"pivot":"n:支点,枢轴,要点;v:旋转",
"pix":"n:图像,相片,影片",
"pizazz":"n:精力",
"pizza":"n:比萨饼,薄饼",
"placard":"n:牌,标语,招贴画,名牌,行李牌,招牌,招贴,告示,布告;v:张贴,公布,悬挂",
"placate":"v:安抚,柔,敉,怀柔,抚慰",
"place":"n:地方,地;v:订,摆列,认出,装入,整顿,措,置,想起,停放,置放",
"place name":"n:地名",
"place of origin":"n:策源地,发源地",
"placement":"n:安排,定位,安置,放置,放,布置,方位",
"placenta":"n:胎盘,胎座,紫河车,胞衣",
"placer":"n:砂矿",
"placid":"a:平缓,沉静,平和",
"placidity":"n:宁静,温和,平静",
"placing":"n:出售,名次,出盘;v:名次",
"placket":"n:衣袋,开口",
"plagiarism":"n:抄袭,剽窃",
"plagiarist":"n:文抄公",
"plagiarize":"v:剽窃,抄袭,抄,剿",
"plague":"n:瘟疫,鼠疫,时疫;v:麻烦",
"plague spot":"n:疹子",
"plaid":"n:方格呢",
"plain":"a:明摆着;n:平地;v:悲歌,叹惜,痛哭,悲伤,诉苦;d:明白,平,便,坦白",
"plain clothes":"n:便衣,便装",
"plain sailing":"n:顺利,一帆顺风,平顺",
"plainclothesman":"n:便衣,侦探",
"plainly":"d:明明,分明,明了,平易",
"plainspoken":"a:快",
"plaint":"n:控诉,状纸,抗议,悲叹,委屈,诉状,状,状子",
"plaintiff":"n:原告",
"plaintive":"a:凄切,哀怨",
"plait":"n:辫子,辫;v:编,编制,编织",
"plan":"n:计划;v:谋,谋算,筹,运筹,打主意;d:略",
"plane":"n:飞机,平面,面,机,水平;v:参加,滑行,刮",
"plane figure":"n:平面图",
"plane table":"n:平板仪",
"plane tree":"n:悬铃木",
"planer":"n:刨,刨工,刨床",
"planet":"n:行星,星,星体",
"planetarium":"n:天象仪,天文馆",
"plank":"n:木板,板,板子,基础;v:打",
"planking":"n:地板,板材",
"plankton":"n:浮游生物",
"planner":"n:设计者",
"planning":"v:计算,心计,规划;n:规划,心计,计划",
"planning commission":"n:计委",
"plant":"v:种;n:生育,苗木,内线,草本",
"plant food":"n:肥料",
"plant life":"n:植物",
"plantain":"n:芭蕉",
"plantation":"n:种植园,殖民,殖民地,建设,移民,创设",
"planter":"n:花盆,播种机",
"planting":"n:种植,撒种,栽培,种植业;v:定植",
"plaque":"n:徽章,匾,牌匾,胸章,血小板",
"plash":"n:闪动",
"plasma":"n:等离子体,血浆,等离子,原生质,淋巴液",
"plaster":"v:抹,粉刷,敷药,涂抹,糊;n:胶泥,熟石膏",
"plasterer":"n:泥水匠,泥瓦匠,瓦工,瓦匠",
"plastering":"n:瓦工;v:抹灰",
"plastic":"n:塑胶,玻璃,电木,信用卡;v:整形",
"plastic art":"n:造型艺术",
"plastic film":"n:地膜",
"plasticine":"n:橡皮泥",
"plasticity":"n:可塑性,适应性,塑性,范性,粘性",
"plasticize":"v:塑化",
"plastics":"n:塑料",
"plat":"n:地图",
"plate":"n:盘子,板,板块,极板,钢板,盘,底片;v:喷镀",
"plate armour":"n:装甲",
"plate iron":"n:铁皮,铁板",
"plateau":"n:高原,坪,高地,平顶,台地",
"platelet":"n:血小板",
"plates":"n:板材",
"platform":"n:讲台,平台,站台,月台,政纲,台,讲坛,台地,演说,车厢,主席台,台子,工作台,坛,讨论会,转盘;v:演讲",
"plating":"n:镀层,镀,镀金,喷镀;v:电镀",
"platinum":"n:白金,铂",
"platitude":"n:老生常谈,滥调,陈腐,单调,老调,平凡",
"platitudes":"n:滥套子,老生常谈",
"plato":"n:柏拉图",
"platonic year":"n:大年",
"platoon":"n:排,小队",
"platter":"n:唱片,铁饼",
"platypus":"n:鸭嘴兽",
"plaudit":"n:喝彩,喝采,赞美,称赞",
"plausible":"a:头头是道",
"play":"v:玩,打,演奏;n:方法",
"play around":"v:玩弄",
"play down":"v:冲淡,贬低",
"play false":"v:欺骗,背信弃义",
"play hooky":"v:偷",
"play off":"v:竞赛",
"play possum":"v:假死",
"play tricks":"v:耍把戏,弄虚作假,做鬼,弄鬼,调皮,耍手腕,作假,玩花招",
"play up":"v:用劲,鼓吹,加油",
"playact":"v:做戏,假装,装腔作势,演戏,装扮",
"playacting":"n:演戏,装扮",
"playback":"n:放音,读数,再现,播放,读出;v:放音,再现",
"playbill":"n:海报",
"playbook":"n:剧本",
"playboy":"n:花花公子,纨绔子弟",
"played out":"v:筋疲力尽",
"player":"n:运动员,选手,球员,演员,播放器,唱机,赌徒",
"playfellow":"n:游伴",
"playful":"a:嬉笑",
"playfulness":"n:童心",
"playgoer":"n:戏迷",
"playground":"n:操场,运动场",
"playhouse":"n:戏院",
"playing area":"n:赛场",
"playing card":"n:纸牌",
"playmate":"n:玩伴",
"plaything":"n:玩物,玩具,玩意儿",
"playwright":"n:剧作家,编剧",
"plaza":"n:广场",
"plea":"n:请求,辩解,恳求,抗辩,答辩,托词;v:推托,抗辩",
"plead":"v:辩护,恳求,央求,求情,解释,主张,托,吁请,抗辩,答辩,辩论,吁",
"pleader":"n:辩护人,律师",
"pleading":"n:答辩,调停,辩论,辩护,说项,诉状",
"pleasant":"a:愉快,宜人,心旷神怡;v:心旷神怡",
"pleasantry":"n:幽默,笑话,玩笑,谐谑;a:谐谑",
"please":"v:讨好,讨人喜欢,请问,中意,有趣,敬请;d:请",
"pleased":"a:高兴,乐意,快,乐滋滋,快慰;v:快意,乐意;n:快意",
"pleasure":"n:乐趣,高兴,快乐,愉快,欢乐,娱乐,享受,乐事;v:喜欢,游荡,满意,游览",
"pleat":"n:褶子,褶",
"pleb":"n:老百姓,平民",
"plebeian":"n:庶民,平民",
"plectrum":"n:拨子,悬雍垂,距",
"pledge":"n:保证;v:押,当",
"plenipotentiary":"n:全权代表,全权",
"plenitude":"n:完全,充实,多,绝顶,茂盛,充分,丰富,充满;a:茂盛",
"plentiful":"a:丰富,富足,充裕,充畅,丰,丰盈,车载斗量,丰满,丰足;v:饶,盛,车载斗量",
"plenty":"a:宽裕,充足,宽余;n:充分,多,丰富;d:十分,充分",
"plenum":"n:充实,充满,全会",
"pleonasm":"n:烦冗",
"plethora":"n:过多,过剩",
"pleura":"n:肋膜,胸膜",
"pleurisy":"n:肋膜炎,胸膜炎",
"plexus":"n:编织,丛;v:编织",
"pliability":"n:柔韧",
"pliable":"a:软",
"pliers":"n:手钳,老虎钳,克丝钳子,钳,钳子",
"plight":"n:困境,处境,苦境,境况,窘境;v:发誓",
"plimsoll":"n:胶鞋",
"plinth":"n:磉,础,底座",
"plod":"n:辛苦",
"plosive":"n:塞音,爆破音,爆发音,破裂音",
"plot":"n:阴谋,情节,故事;v:绘,计划,作图,计,画,图谋",
"plot of land":"n:畦",
"plotter":"n:绘图仪,策划者",
"plotting":"v:绘图;n:测绘",
"plough":"v:犁,犁地,耕,开,耕田,作,开槽,开路,深耕,耕地;n:耕作,犁铧,耕地",
"ploughing":"v:耕翻",
"ploughman":"n:庄稼汉",
"ploughshare":"n:犁铧,铧,犁头",
"plover":"n:鸻",
"plow":"v:开,开路,作;n:耕作",
"plowman":"n:农夫,庄稼汉",
"plowshare":"n:犁头,犁铧",
"ploy":"n:策略,花招,手法",
"pluck":"v:摘,拔,扯,采摘,拉,弹奏,采撷,拖,采,弹,抖擞;n:拔,扯,胆魄,胆量,胆子",
"plug":"v:堵塞,堵住,埋头苦干,入,堵;n:废物",
"plug away":"v:埋头苦干",
"plug into":"v:入",
"plugging":"v:堵塞",
"plughole":"n:插孔",
"plum":"n:李子,梅子,糖果,肥缺,黄梅,精华;d:完全,充分",
"plumb":"v:测量,查明,看出,铅直,焊,看穿;n:垂直,铅锤;a:铅直;d:完全",
"plumb line":"v:标准",
"plumbago":"n:石墨",
"plumber":"n:管工,管道工,水暖工",
"plumbing":"n:波导管",
"plume":"n:羽毛,翎毛,烟柱,热点;v:整理,自夸",
"plummet":"n:铅锤,坠子,钟摆,准绳;v:下跌",
"plump":"a:胖;v:肿胀,膨胀,肥胖;d:咕咚;n:队",
"plumper":"a:猛跌",
"plumping":"v:肿胀",
"plums":"n:填料",
"plunder":"v:掠夺,抢劫,洗劫;n:利益,行李,赚头,家具",
"plunge":"n:冒险;v:插入,投",
"plunger":"n:活塞,搅拌器",
"plunk":"v:支持,猛打,猛击",
"plural":"n:复数;a:多数",
"pluralism":"n:兼职,多种,复数,多元论",
"pluralistic":"a:兼职",
"plurality":"n:大多数,多数,复数,兼职",
"plus":"a:正,正号,强,阳;n:加号,利益,多余,剩余;p:加,加上;v:加",
"plus sign":"n:加号,正号",
"plush":"n:丝绒,长毛绒",
"pluto":"n:冥王星",
"plutocrat":"n:富豪,财阀",
"plutonium":"n:钚",
"ply":"v:行驶,来往,出力,赶;n:股,厚,薄板,厚度,层",
"plying":"v:合股",
"plywood":"n:胶合板,三合板;v:逮捕",
"pm":"n:首相,午后",
"pneumatic":"a:气动;n:管",
"pneumatic hammer":"n:风锤",
"pneumonia":"n:肺炎",
"po":"n:邮局",
"poach":"v:偷猎,侵入,卧",
"poached egg":"n:荷包蛋",
"pock":"n:痘疱,痘疮",
"pocket":"n:口袋,衣袋,腰包,兜,衣兜,兜儿,钱袋,袋,腰,兜子,金钱,穴;v:包藏,阻挠,操纵,搁置,抑制,克扣;a:小型,袖珍",
"pocket book":"n:金钱,皮夹子,笔记簿",
"pocket knife":"n:折刀",
"pocket money":"n:零用钱,零用,零花,零钱",
"pocket watch":"n:挂表",
"pocket-handkerchief":"n:手帕",
"pocket-size":"a:袖珍",
"pocketbook":"n:皮夹子,袖珍本,小册子,笔记本,皮夹",
"pocketknife":"n:刀子",
"pockmark":"n:麻子,痘疮",
"pockmarked":"a:麻",
"pockmarks":"n:麻子",
"pod":"n:荚,豆荚;v:结荚",
"podium":"n:叶柄,足",
"poem":"n:诗,诗歌,诗篇,诗章,律诗",
"poesy":"n:诗歌,韵文",
"poet":"n:诗人,骚客,空想家",
"poetic":"n:诗情画意;a:诗",
"poetry":"n:诗歌,诗,诗意,诗词,诗集,韵文",
"pogrom":"n:大屠杀;v:大屠杀",
"poignancy":"n:辛辣,强烈,刻薄,尖锐,深刻,尖利",
"poignant":"a:锋利,诱人",
"poinsettia":"n:一品红",
"point":"n:点;v:表明;a:尖",
"point duty":"n:站岗,值勤",
"point of view":"n:角度",
"point out":"v:点破,点,点明,提示,指,指明",
"point up":"v:强调",
"point-blank":"d:立即,平射,直射",
"pointed":"a:尖;d:显然;v:显然",
"pointedness":"n:棱角",
"pointer":"n:指针,指示器,点子,教鞭,线索,暗示",
"pointing":"n:标点,瞄准,指示;v:指示,标定",
"pointless":"a:无谓,不痛不痒,秃",
"points":"n:道岔;v:点数",
"poise":"n:沉着,平静,平衡,自信,秤锤,犹豫不决;v:踌躇,均衡",
"poison":"v:毒死;n:毒害",
"poisoned":"v:毒;a:毒",
"poisoning":"v:中毒,毒害",
"poisonous":"a:有毒;v:有毒",
"poisonous substance":"n:毒物,毒药",
"poke":"v:拨,戳,拨动,捅,插入,探听,闲逛,伸出,刺,打,打听,通,挑,鼓励,激励;n:刺,懒汉,戳",
"poke into":"v:干涉,参与",
"poker":"n:扑克,扑克牌,火钳,拨火棍,通条",
"poky":"a:慢吞吞,古板",
"poland":"n:波兰",
"polar":"a:相反",
"polaris":"n:北辰",
"polarity":"n:极性,极化",
"polarization":"n:极化,偏振,两极,偏光",
"polarize":"v:两极,偏振,极化",
"pole":"n:极,磁极,杆,杆子,电线杆,极点,天空,极地,木桩,桩,棒,桅杆,电极,地极,顶点,撑杆,竿",
"pole jump":"n:撑竿跳高",
"pole star":"n:北极星",
"pole vault":"n:撑杆跳,撑竿跳,撑竿跳高,撑杆跳高",
"polecat":"n:妓女",
"polemic":"n:驳斥,争论,论战,攻击;a:辩论",
"polemical":"a:争论",
"polemicist":"n:说客",
"polemics":"n:论战",
"polestar":"n:北极星",
"police":"n:警察,治安;v:管辖",
"police car":"n:警车",
"police commissioner":"n:捕头",
"police detective":"n:警探",
"police force":"n:警力",
"police station":"n:警察局,巡捕房,捕房,局子,警署",
"policeman":"n:警察,巡警,警士,干警",
"policemen":"n:治安警",
"policy":"n:政策,方针,策略,方向,保险单,行政,方法,权谋,政纲,智慧",
"policy maker":"n:决策人,决策者",
"policyholder":"n:投保人",
"poling":"v:还原,吹气,支撑",
"polio":"n:小儿麻痹症,脊髓灰质炎",
"poliomyelitis":"n:脊髓灰质炎,小儿麻痹症",
"polish":"v:点窜;n:优美,推敲;a:波兰",
"polish off":"v:狼吞虎咽",
"polish up":"v:改善,装饰",
"polished":"a:文雅",
"polished rice":"n:粲",
"polisher":"n:磨光机",
"polishing":"v:上光,抛光",
"polite":"a:客气,客客气气,和气,婉,恭",
"politeness":"n:礼貌,彬彬有礼,殷勤,客气,套话",
"politesse":"n:斯文",
"political commissar":"n:政治委员",
"political party":"n:党",
"political prisoner":"n:政治犯",
"political program":"n:政纲",
"politically":"d:巧妙",
"politician":"n:政治家,政客",
"politico":"n:政客",
"politics":"n:政治,政见,政治学,政策,管理,战略,政治课,政,动机",
"polity":"n:国家,行政,国体,政体,制度,政府",
"polka":"n:波尔卡",
"poll":"v:查询,投票,探询,剪,得,剪短,投,查;n:投票",
"poll tax":"n:口算",
"pollard":"n:糠",
"pollen":"n:花粉",
"pollinate":"v:授粉,传粉",
"pollination":"n:授粉,传粉",
"polling":"v:探询,查询",
"polling booth":"n:投票站",
"polling station":"n:投票站",
"polliwog":"n:蝌蚪",
"pollute":"v:污染,玷污,亵渎,败坏",
"pollution":"n:污染,公害,腐败,堕落",
"polo":"n:马球,水球",
"polonium":"n:钋",
"poltroon":"n:胆小鬼",
"polyester":"n:聚酯",
"polyethylene":"n:聚乙烯",
"polygamy":"n:雌雄同株",
"polygon":"n:多边形,多角形",
"polyhedral":"n:多面体;a:多面体",
"polyhedral angle":"n:多面角",
"polyhedron":"n:多面体",
"polymer":"n:聚合物",
"polymerise":"v:聚合",
"polymerization":"n:聚合,多项式;v:聚合",
"polymerize":"v:聚合",
"polymethyl methacrylate":"n:有机玻璃",
"polynesia":"n:波利尼西亚",
"polynomial":"n:多项式",
"polyp":"n:息肉,珊瑚虫,鼻息肉",
"polypropylene":"n:聚丙烯",
"polystyrene":"n:聚苯乙烯",
"polytheism":"n:多神教",
"polythene":"n:聚乙烯",
"polyurethane":"n:聚氨酯",
"polyvinyl chloride":"n:聚氯乙烯",
"pomade":"n:香油,发蜡,头油",
"pomegranate":"n:石榴",
"pommel":"n:头;v:打",
"pommel horse":"v:鞍马;n:鞍马",
"pomp":"n:浮华,虚荣,壮观,华丽",
"pomposity":"n:自负,自大,傲慢,豪华,华丽,夸大,摆架子",
"pompously":"d:大模大样",
"poncho":"n:雨披,雨衣",
"pond":"n:池塘,池,水池,水塘,塘,鱼塘,池沼,河塘,泽,湫,池子,潭,汪,游泳池",
"ponder":"v:思索,琢磨,思忖,沉思,深思,想,默想,玩味,暗想,虑,缅,忖,忖量,估量,幽思,衡量,自忖",
"ponderousness":"n:沉重",
"pone":"n:肿块",
"pong":"n:恶臭",
"pongee":"n:柞丝绸,茧绸,府绸",
"poniard":"n:短剑",
"pontiff":"n:教皇,权威,主教,泰斗",
"pontifical":"a:教皇;n:徽章",
"pontificate":"n:教宗",
"pontoon":"n:浮筒,浮桥,趸船,驳船,沉箱",
"pontoon bridge":"n:啐,藐视,嘲笑",
"pony":"n:幼驹,马驹",
"pooch":"n:狗",
"pooh-pooh":"v:藐视,瞧不起,轻视;i:呸",
"pool":"n:游泳池,池塘,水坑,水池,池,水潭,水塘;v:开",
"poop":"n:船尾,消息,傻子;v:拉屎",
"poop deck":"v:船尾",
"poor":"a:可怜,穷,差,贫穷,贫困,贫苦,弱,贫乏,蹩脚,贫寒,少,贫瘠,不行,菲薄,乏,清寒,劣等,薄,破,稀松,瘦,不够,穷乏,单寒,家无担石,贫弱,清苦,瘦瘠,赖;v:菲薄",
"poorly":"d:拙劣,下贱,不足,贫弱,不够,贫穷",
"poorness":"n:贫乏,不够,贫穷,粗劣,缺乏",
"pop":"n:砰;v:射击,死亡,抵押,枪击;d:突然",
"pop off":"v:死亡",
"popcorn":"n:玉米花,爆米花,玉米花儿",
"pope":"n:教皇,罗马教皇",
"popinjay":"n:花花公子",
"poplar":"n:白杨,杨树,杨",
"poplin":"n:府绸",
"popper":"n:枪,炮手,射手",
"poppet":"n:支架",
"poppy":"n:鸦片",
"poppycock":"n:胡扯,废话",
"popsicle":"n:冰棍,冰棍儿,雪糕,棒冰,冰糕",
"populace":"n:人民,老百姓,平民,大众,群氓",
"popular":"a:流行,通俗,得人心,普及,香,时兴,热门,盛,土,热,俗,舆;v:盛,大众化,盛行,时兴;n:民间",
"popularity":"n:声望,普及,流行,名气,知名度,名望,人缘儿,大众性,通俗性,人望",
"popularization":"n:推广,通俗化,普及,简单化",
"popularize":"v:普及,推广",
"populate":"v:增加,繁殖",
"population":"n:人口,种群,总体,群体,密度,组,族,人丁,丁",
"populism":"n:民粹派",
"porcelain":"n:瓷器,瓷,磁",
"porcelain clay":"n:高岭土",
"porch":"n:门廊,走廊,游廊,门口,廊",
"porcupine":"n:箭猪,豪猪",
"pore":"v:凝视,钻研,细看,沉思,注视,默想;n:孔隙,毛孔,气孔",
"porgy":"n:鲷",
"pork":"n:猪肉,猪",
"pornographic":"a:淫秽,黄色,淫;n:黄色",
"pornography":"n:色情",
"porosity":"n:多孔结构,孔",
"porous":"a:多孔",
"porphyry":"n:斑岩",
"porpoise":"n:海豚,波动",
"porridge":"n:粥,稀饭,肉汤,米粥,汤,稀粥",
"port":"n:港口,港,端口,码头,炮眼,舷窗,举止,口岸,入口,样子,舱门,枪眼,态度,埠,风采,含意,水门,避难所,意义,舱口,城门,机场,商埠;v:搬运,持",
"port wine":"n:葡萄酒",
"portability":"n:轻便",
"portable":"a:便携式,轻便,手提",
"portage":"n:运输,运费,搬运,货物",
"portal":"n:正门,门,入门,入口,门静脉,井口",
"portal vein":"n:门静脉",
"portend":"v:预示,兆,警告,预兆;n:兆",
"portent":"n:预兆,兆,奇迹,凶兆,怪物,先兆,朕兆,征兆,兆头,征;v:征",
"porter":"n:脚夫,门房,搬运工,服务员,清洁工,脚力,挑夫,脚行",
"porterage":"n:搬运,搬运费",
"porterhouse":"n:饭馆",
"portfolio":"n:文件夹,业务量,公事包,皮包,公文包",
"porthole":"n:舷窗,舱口,炮眼",
"portico":"n:门廊",
"portiere":"n:门帘",
"portion":"n:部分,一部分,妆奁;v:停",
"portliness":"n:肥胖,魁伟",
"portly":"a:大肚子",
"portrait":"n:肖像,画像,像,相片,人像,雕像,影象,影像,写真,半身像,肖像画,照,模型,类型",
"portraiture":"n:肖像,照相,描写,传真,肖像画,写照",
"portray":"v:描绘,描写,描述,塑造,画,刻画,画像,描摹,饰演,摹绘;n:画像",
"portrayal":"n:肖像,写照,画像,画,叙述,描写",
"portsmouth":"n:朴次茅斯",
"portugal":"n:葡萄牙",
"pose":"v:提出,造成;n:姿态",
"poseidon":"n:海神",
"poser":"n:难题",
"posit":"v:安排,布置,假定,安置,论断,断定;n:论断",
"position":"n:位置,地位,职位,立场,地,阵地,职务,处境,位;v:驻扎,立论,配置",
"position paper":"n:意见书",
"positioning":"v:定位,布置;n:定位",
"positive":"a:积极,肯定,阳性,阳,确信;n:正数,阳极,正面,正片",
"positively":"d:确实,积极,断然,必定,绝对,断断",
"positivism":"n:实证主义",
"positivity":"n:确信,确实,积极性",
"positron":"n:正电子,阳电子",
"posse":"n:民兵,乌合之众,民团,可能性",
"possess":"v:有,具有,拥有,占有,迷住,支配,所有,具,有着,掌握,保持,据有,缠,具备,维持,抑制,拥,附,赋有,克制,领,领有",
"possessing":"a:万贯",
"possession":"n:财产,有,拥有,所有权,所有,占有,殖民地,属地,泰然自若,着魔,领土,着迷",
"possessions":"n:所有",
"possessive":"n:所有格",
"possessive case":"n:所有格",
"possessor":"n:主人,主",
"possibility":"n:可能性,可能,希望",
"possible":"n:金钱,可能",
"possibly":"d:也许,无论如何,容许,万万,作兴,或者,容或,许",
"post":"n:柱子,职位,邮件;v:付邮,誊,注册",
"post card":"n:明信片",
"post house":"n:驿站,邮亭",
"post office":"n:邮局,邮政局",
"post road":"n:驿道",
"post-mortem":"n:验尸",
"post-office box":"n:信箱",
"postage":"n:邮费,邮资",
"postal":"n:明信片;v:邮;a:邮",
"postal card":"n:明信片",
"postal order":"n:汇票",
"postbag":"n:邮袋",
"postbox":"n:信箱,邮筒,邮箱",
"postcard":"n:明信片",
"postcode":"n:邮政编码",
"poster":"n:海报,招贴画,广告,招贴,招子,标语,广告画,大字报;v:贴",
"posterior":"n:后部,屁股",
"posterity":"n:后世,子孙,后代,子孙后代,后,后人,后裔,胤,裔,儿孙,根,后辈",
"postgraduate":"n:研究生",
"posthaste":"n:赶紧,特快,火急,火速;d:火速,急如星火;a:快马加鞭,急如星火;v:十万火急",
"posthumously":"d:身后",
"postman":"n:邮递员,邮差,信差,绿衣使者",
"postmark":"n:邮戳",
"postmortem":"a:验尸",
"postnatal":"a:后天",
"postpartum":"a:产后",
"postpone":"v:推迟,延期,延迟,延,搁置,顺延,展期,延缓,缓,纾,误期,延宕,迟延,暂缓,缓期,慢,展,展缓,推宕,推延,推",
"postponement":"n:延期,延迟,搁置;v:延期",
"postscript":"n:附言,再者,补遗,附笔,书后,跋,附录,跋文,后记",
"postulate":"n:假设,公设;v:假设,公设,主张",
"postulation":"n:公设,假设,要求,假定",
"posture":"n:姿态,姿势,态度,心情,架子,式子,身段,体态,心境,形势,相,架式,架势,情形,态势,身姿;v:故作姿态",
"postwar":"a:战后",
"posy":"n:花束,诗句",
"pot":"n:锅,花盆,罐,罐子,壶,盆,瓶;v:封装,删节,煮,喝酒",
"pot metal":"n:铸铁",
"potable":"n:酒,饮料",
"potassium":"n:钾,碘化钾",
"potassium bromide":"n:溴化钾",
"potassium nitrate":"n:火硝",
"potassium permanganate":"n:灰锰氧",
"potato":"n:马铃薯,土豆,洋芋,薯,白薯,山药蛋,甘薯,头",
"potbellied":"a:大腹便便;v:大腹便便",
"potbelly":"n:大肚子",
"potency":"n:效能,能力,性子,力量,神力,基数,权势,效验,权威,效力,浓度,权力,势",
"potentate":"n:君主,统治者,当权者",
"potential":"n:电位,潜力,势,电势,可能,潜能,位;a:潜在",
"potential difference":"n:电势差",
"potentiality":"n:潜力,可能性,潜能",
"potentiometer":"n:电位器",
"pother":"n:烦恼,喧闹,忙乱;v:忙乱",
"potherb":"n:野菜",
"pothole":"n:竖井",
"pothook":"n:挂钩",
"potion":"n:药水",
"potluck":"n:便饭,家常便饭,聚餐",
"potpie":"n:锅贴",
"potpourri":"n:杂烩",
"potshot":"n:射击",
"pottage":"n:浓汤",
"potted":"v:封闭式;a:封闭式",
"potter":"v:浪费,混,闲逛,闲荡;n:陶工",
"potter's clay":"n:陶土",
"potter's earth":"n:陶土",
"potter's wheel":"n:钧",
"pottery":"n:陶器,陶,泥胎儿",
"potting":"v:浇灌,盆栽,封装;n:盆栽",
"potty":"n:便壶;a:琐碎",
"pouch":"n:袋,荷包,酒钱,邮袋,育儿袋,囊;v:吞食",
"poultry":"n:家禽,家畜,禽",
"pounce":"v:猛扑,突袭,掩杀;n:猛扑,突袭,抓",
"pound":"v:猛击,冲击,捶,抨击,拘留,擂,灌输,砸,捣碎,苦干;n:夯",
"poundage":"n:监禁,佣钱,拘留",
"pounding":"v:打碎",
"pour":"v:倒,涌,斟,倾诉,注,涌出,倾泻,源源而来,流,倾注,倾吐,泻,发泄,浇注;n:大雨",
"pour down":"v:倾注",
"pour forth":"v:倾吐,诉说",
"pour out":"v:涌出,倾倒,倾诉,诉说,倾吐,泻,酌",
"pouring":"v:浇注,浇铸;a:滂沱",
"pout":"v:噘嘴,撅嘴,张开,板脸,噘,鼓;n:板脸",
"poverty":"n:贫穷,贫困,缺乏,贫乏,贫瘠,虚弱,低劣,缺少",
"poverty-stricken":"a:窘促",
"pow camp":"n:战俘营",
"powder":"n:粉末,粉,火药,药粉;v:抹粉",
"powder room":"n:化妆室,化装室",
"powdered":"v:沙",
"powdered milk":"n:奶粉",
"powdering":"n:粉碎;v:粉碎",
"powdery":"a:齑,粉状,白粉病",
"powdery mildew":"n:白粉病",
"power":"n:权力,力量,能力,功率,权,动力,电力,势力,政权,电源,强国,力,大国,体力,威力,幂,本领,方,功,精力,大量,能量,乘方,势,权限,机能;v:建政;a:威武",
"power drill":"n:电钻",
"power failure":"n:停电",
"power grid":"n:电网",
"power line":"n:火线",
"power meter":"n:功率表",
"power pack":"n:电源,电池组",
"power plant":"n:发电厂,发动机",
"power shovel":"n:掘土机,挖土机",
"power-driven":"a:电动",
"powerboat":"n:摩托艇,汽艇",
"powerful":"a:强大,有力,强有力,强,强劲,威武,雄健,劲,雄,大气磅礴,遒劲,有劲,冲;d:非常,很;v:大气磅礴,气势磅礴;n:劲",
"powerhouse":"n:发电站,强者",
"powerless":"v:无能为力,无权,无力;a:无力",
"powers":"n:职权",
"powwow":"n:仪式,会谈,讨论,祭司,巫师;v:开会,商量",
"pox":"n:痘,天花,疹,瘟疫",
"pr":"n:公关",
"practicability":"n:可行性",
"practicable":"a:可行,落实;v:行得通,落实",
"practical":"a:实际,切实;v:务实;n:恶作剧",
"practical joke":"n:恶作剧",
"practicality":"n:实际,实践性,实例,实物,实用",
"practically":"d:实际上,几乎,简直,事实上,差不多,几",
"practice":"n:实践,练习;v:操练",
"practiced":"a:熟练,熟,纯熟",
"practise":"v:实行,开业,练,搞,练功,训练,演,实施;n:教练",
"practised":"a:老手,熟练,熟,纯熟,纯",
"practitioner":"n:老手",
"pragmatism":"n:实用主义,自负",
"prague":"n:布拉格",
"prairie":"n:草原",
"praise":"v:称赞,表扬;n:赞词",
"praiseworthy":"a:可贵",
"pram":"n:手推车",
"prance":"v:龙骧虎步,腾,欢跃,高视阔步,腾跃;n:腾跃,昂首阔步,腾越,欢跃",
"prang":"v:轰炸,坠毁,碰撞,击,撞;n:坠毁",
"prank":"n:鬼把戏,恶作剧,胡闹;v:打扮,装饰",
"praseodymium":"n:镨",
"prate":"n:碎嘴子,唠叨,多嘴;v:瞎说,空谈,多嘴",
"pratfall":"n:丢脸",
"prattle":"v:咿呀,空谈,胡说;n:空谈,废话",
"prawn":"n:大虾,明虾,对虾,龙虾",
"pray":"v:祈祷,祈求,祷告,恳求,请求,祝祷,乞求,祈",
"prayer":"n:祈祷,祷文,祷词,恳求,祝福,祈求",
"praying mantis":"n:螳螂",
"prc":"n:中华人民共和国",
"preach":"v:讲道,鼓吹,布道,讲,宣讲,说教,宣传,宣扬,说,教,传道,提倡,劝告",
"preacher":"n:传道士,鼓吹者",
"preaching":"v:传教,说教,讲道,训诫",
"preachment":"n:说教,传教,讲道,长篇大论",
"preamble":"n:前言,序,端倪,导言,绪言,开端",
"prearrange":"v:预定",
"precarious":"a:风雨飘摇;v:风雨飘摇",
"precast":"v:预制",
"precaution":"n:预防,小心,谨防,警惕",
"precede":"v:领先,高于,优于,前导",
"precedence":"n:在先,位次,领先",
"precedent":"n:先例,判例,惯例,例,前例;v:领先;a:在先",
"precedents":"n:成例",
"preceding":"v:前面,前边,上;a:前",
"precept":"n:言教,训导,戒律,方案,格言,规程,信条,告诫,格式,教训",
"preceptor":"n:教师,导师,校长",
"precession":"n:岁差,行列,先行,前行",
"precinct":"n:郊区,分界,附近,周围,境界,管界,分区,管区,区,选区",
"preciosity":"n:矫揉造作",
"precious":"a:宝贵,珍贵,非常,极,贵重,可贵,贵;d:极;n:宝",
"precipice":"n:悬崖,绝壁,石壁,峭壁,崖壁,崖,削壁",
"precipitant":"n:沉淀物;a:急",
"precipitate":"v:加速;n:沉淀物",
"precipitation":"n:沉淀,降水,降水量,降雨,降雨量,降落,沉积,鲁莽,猛冲,仓促,急躁",
"precipitous":"a:险峻,陡峭,陡,陡峻,峭,危,巉,萃",
"precise":"a:精确,确切,准确,精密,精,准",
"precisely":"d:恰恰,精确,就,准确,正,正好,就是",
"preciseness":"n:确切,准确,精确",
"precision":"n:精度,精确,精确性,精密度,精密,精确度,确切,严格;a:精密",
"preclude":"v:排除,杜绝,消灭,预防,阻断,阻止",
"preclusion":"n:预防,排除",
"precocious":"a:早熟",
"precocity":"n:早熟",
"precognition":"n:预知,预见;v:预知",
"preconceive":"v:预见,预想",
"preconception":"n:偏见,预想,预见",
"precondition":"n:前提,先决条件;v:预处理",
"precursor":"n:前兆,预兆,前驱,前身,前辈,先导,先兆,前任,先锋,先驱,嚆矢,母体",
"predation":"n:捕食",
"predecessor":"n:前任,前辈,前身,先驱,祖先",
"predecessors":"n:前人",
"predestination":"n:命运,宿命论,天命,预定",
"predestine":"v:注定",
"predetermination":"n:预测,预定;v:预测",
"predetermine":"v:预定,注定",
"predicament":"n:困境,窘境,窘况,苦境,种类,境遇,状况,困处",
"predicate":"v:断言,声明,宣布,断定;n:语词,谓语,属性,宾词,谓词",
"predication":"n:断定,谓语",
"predicative":"n:表语",
"predict":"v:预言,预料,预报,预示,预见,推算,预告,卜,料",
"prediction":"n:预言,预测,预报,预告,超前,虞;v:预报",
"predilection":"n:偏爱,爱好,偏好,嗜好",
"predisposition":"n:天性,倾向,素质,诱因,资质",
"predominance":"n:优势,卓越,出众,突出,优越,显著",
"predominate":"v:占优势,支配,统治,一边倒",
"preemie":"n:早产儿",
"preeminence":"n:卓越,杰出",
"preeminent":"a:卓尔不群,卓跞;v:超群,逸散",
"preemption":"n:优先权",
"preen":"v:打扮,自负",
"preexistence":"n:前世",
"prefab":"n:活动房屋",
"prefabricate":"v:预制",
"preface":"n:序言,前言,序文,自序,开端,叙文,弁言,前沿,绪言,引语;v:导致",
"prefect":"n:总督,长官,班长,县长,司令官",
"prefecture":"n:郡,县,地区,省,府,专区",
"prefer":"v:喜欢,情愿,提出,提升,倾向,提起,推荐,介绍,录用,提拔,看中,申请,建议,拈轻怕重",
"preferably":"d:最好,宁可,宁愿",
"preference":"n:偏爱,优先权,特惠,优先,趣味",
"preferential":"a:优先,优惠;v:优先;n:优先权",
"preferment":"n:提升,提拔,提出;v:提拔",
"prefigure":"v:预示,预兆,预言,预见,预想",
"prefix":"n:前缀,词头",
"prefixing":"v:前缀",
"preform":"n:雏形",
"pregnancy":"n:妊娠,怀孕,怀孕期,孕期,丰满,怀胎;v:妊娠",
"pregnant":"a:怀孕,大肚子,有喜",
"preheat":"v:预热",
"prehistoric":"n:史前;a:史前",
"prehistory":"n:背景",
"prejudgment":"n:偏见",
"prejudice":"n:偏见,成见,不利,歧视;v:伤害",
"prejudiced":"v:偏",
"prelate":"n:教士,主教,牧师",
"preliminary":"n:淘汰赛,准备,开端;d:预先;a:初步",
"preliminary examination":"n:初审,初试",
"prelude":"n:前奏,序曲,序幕,序言,前兆,开场戏,前奏曲,预兆;v:开头",
"premarital":"a:婚前",
"premature":"v:为时过早,早泄,早熟;a:早产儿;n:早产儿",
"premature baby":"n:早产儿",
"premature ejaculation":"n:早泄",
"premature infant":"n:早产儿",
"premature labour":"n:早产",
"prematurity":"n:早熟",
"premeditate":"v:盘算,预谋,蓄谋",
"premeditated":"v:蓄意;d:蓄意",
"premeditation":"n:预谋,预想",
"premier":"n:总理,首相",
"premise":"n:前提,房屋;v:假定,引导,引述",
"premises":"n:前提,房产",
"premium":"n:保险费,奖励,佣金,贴水;v:升水",
"premolar":"n:前臼齿",
"premonition":"n:预感,前兆,征兆",
"prentice":"n:学徒",
"preoccupation":"n:全神贯注,出神,急务,偏见,专心,成见",
"preoccupied":"v:心不在焉",
"preoccupy":"v:出神",
"prep":"v:准备,自修,预备",
"preparation":"n:准备,制备,制剂,配制,预备,试液,预习;v:制备,筛选",
"preparative":"n:筹备,预备,准备",
"preparatory school":"n:预科",
"prepare":"v:准备,做,预备,配制,制订,备,布置,作出,制造,筹备,配备,编写,温习,训练,筹办,调制,锻炼,装备,预习,研制,办,筹",
"prepare for":"v:备",
"preparedness":"n:预备",
"prepay":"v:预付,预支",
"preponderance":"n:优势,优越",
"preponderate":"v:压倒,超过,胜过",
"preposition":"n:介词,前置词",
"prepossess":"v:充满",
"prepossession":"n:偏见,着迷,全神贯注,偏爱",
"preposterous":"a:荒谬,荒唐;v:见鬼,岂有此理",
"prepuce":"n:包皮",
"prerequisite":"n:先决条件,前提,条件,必要条件;a:先决",
"prerogative":"n:特权,特性,君权,特点",
"presage":"n:前兆,预知,预言,预示,预感,预兆;v:主,预感,预知",
"presbyopia":"n:花眼,老花眼,远视眼,老视眼,远视",
"presbyter":"n:长老",
"presbytery":"n:祭坛,住宅",
"preschool":"n:幼儿园",
"prescience":"n:预知",
"prescribe":"v:规定,开,处方,处,嘱咐,建议,指示,指令,命令,指挥,配药;n:处方",
"prescript":"n:药方,旨意,规定,训令,法令,命令",
"prescription":"n:处方,药方,规定,时效,训令,法规,方药,方,药单,指示,命令,方子,方剂",
"presence":"n:在,存在,出席,在场,风度,眼前,鬼,相貌,临场,妖怪,实在,接近,列席,面前,滞留,姿容,见面,风采,态度",
"present":"v:介绍,提出;n:礼,仪,瞄准,赠品,赠礼,今日;a:目前",
"presentable":"a:像样",
"presentation":"n:表示,显示,介绍,礼物,授予,陈述,提出,图像,上演,描述,展示,指示;v:提示",
"presentiment":"n:预感",
"presently":"d:不久,一会儿,马上,目前,随即,立刻,俄顷,俄;a:一会儿",
"presentment":"n:出示,陈诉,呈现,描写,上演,提出,叙述,表象,陈述,画,演出,展示,肖像",
"preservation":"n:保存,维护,保持;v:堆放",
"preservative":"n:防腐剂",
"preserve":"v:保存,保持,维护,保留,保藏,维持,保全;n:果酱,蜜饯,罐头,护目镜,猎物,禁区,维",
"preserves":"n:蜜饯",
"preset":"v:调整,给定",
"preside":"v:主持,统辖,指挥,负责,管理,柄",
"presidency":"n:支配,统辖",
"president":"n:总统,总裁,主席,校长,总经理,董事长,会长,长官,院长,社长,州长,行长,总督,庭长,议长",
"presidium":"n:主席团",
"press":"v:按;n:混战,人丛,繁忙,书局,挤,压力机,印刷术",
"press agency":"n:通讯社",
"press agent":"n:宣传员",
"press box":"n:记者席",
"press clipping":"n:简报",
"press down":"n:捺,镇",
"press gallery":"n:记者席",
"press gang":"n:抽丁,抽壮丁",
"pressing":"a:迫切,紧急,紧迫;n:唱片,压,按,压榨,冲压;v:冲压,压制,迫在眉睫",
"pressman":"n:新闻记者",
"pressure":"n:压力,压,压强,气压,压迫,按,电压,繁忙,紧急,挤,强制,为难,困苦;v:密封,压,迫使;a:紧急",
"pressure gage":"n:压强计,气压计,压力计,压力表",
"pressure gauge":"n:压力计,压力表,压强计,气压计",
"pressure sore":"v:褥疮",
"pressurization":"n:加压,增压,挤压,密封",
"pressurize":"v:增压,加压,密封",
"prestidigitation":"n:变戏法,魔术",
"prestidigitator":"n:魔术师",
"prestige":"n:威信,声望,威望,声威,声誉,望,颜,威名,显赫,颜面,信誉,老脸,威严,信望,人望,盛名;a:威严",
"presto":"d:快,立刻,赶快;a:急速,快",
"presumably":"d:大概,可能,想必,大抵,假定;v:想来",
"presume":"v:认为,以为,假定,擅自,设想,竟敢,相信,推测,猜想,忖度,意味着,当作,想像,胆敢,料想,假设",
"presumption":"n:设想,推测,假定,自以为是,傲慢,猜测,臆断,想像,自大,无礼,假说,跋扈",
"presumptuous":"a:狂妄,自作聪明,妄,非分",
"presuppose":"v:猜想,预料,推测,含有,预想",
"presupposition":"n:猜测,假说,前提,先决条件,预想",
"pretence":"n:借口,假装,自命,口实,虚伪,托词,企图,托辞,假托,自称,要求",
"pretend":"v:假装,装,装作,装模作样,自称,佯装,作,装做,借口,假托,演戏,自封,妄想,伪装,要求,诈,装假,装扮,诡称,假意",
"pretender":"n:骗子",
"pretense":"n:假装,虚伪,幌子",
"pretension":"n:自负,借口,要求,做作;v:假装",
"pretentious":"a:捏腔拿调",
"preterit":"n:过去时",
"pretext":"n:借口,假象;v:假托,借口",
"pretreatment":"n:预处理",
"prettify":"v:美化,雕琢,涂脂抹粉,贴金,美",
"prettiness":"n:漂亮,秀色,优美,好,机灵,可爱,妙",
"pretty":"a:漂亮;d:蛮,颇;n:隋,心肝",
"prevail":"v:流行,盛行,说服,普遍,压倒,成功,占上风,奏效,普及,占优势,劝说,胜过,行,传开,胜,兴,得逞",
"prevailing":"v:占优势;a:占优势",
"prevalence":"n:普遍,盛行,流行,卓越",
"prevalent":"a:流行",
"prevaricate":"v:推诿,支支吾吾,支吾,搪塞",
"prevent":"v:防止,阻止,预防,妨碍,制止,阻挡,消弭,阻拦,杜,迎合,沮,免除,避",
"prevention":"n:预防,防止,阻碍,妨碍,制止,阻止",
"preventive":"n:预防药",
"preview":"n:试映,预习,试演,预演;v:试映,预展,预习,预演",
"previous":"a:头;n:以往;d:在先",
"previously":"d:以前,先前,过去,先是,在先,预先;n:已往",
"prevision":"n:预见,预知",
"prevue":"n:试演",
"prewar":"a:战前",
"prey":"n:猎物;v:掠夺",
"price":"n:价格,物价,价钱,价,代价,费用,钱,售价,行情,价值,牺牲,悬赏,价目,牌价,实价,值,价码,市价,贵重,报酬",
"price cutting":"n:减价",
"price list":"n:价目表",
"price tag":"n:标签",
"priced":"v:价廉物美",
"priceless":"a:无价,价值连城,金不换,珍",
"prices":"n:行情,物价,行市",
"prick":"v:扎,刺痛;n:刺痛",
"prick up":"v:竖起",
"pricker":"n:刺针,冲子,锥子",
"pricking":"v:刺痛;a:刺棱;n:刺",
"prickle":"n:棘,刺痛,刺",
"prickling":"v:刺痛",
"prickly heat":"n:痱,汗疹,痱子",
"prickly pear":"n:仙人球",
"pride":"n:骄傲,自豪,傲慢,得意,自豪感,自尊,自大,全盛,装饰,开屏,群,顶点,血气,精力,自满;a:骄傲",
"priest":"n:牧师,神父,教士,祭司,大师,神甫,术士,僧人",
"priestess":"n:尼姑",
"prig":"v:讨价还价",
"prim":"a:整洁;v:装饰",
"primacy":"n:首位,首先,首要,卓越",
"primarily":"d:原来,最初,首先,根本上,起初",
"primary":"n:主星,原色,底子,元,初级线圈,行星;a:低级",
"primary coil":"n:原线圈",
"primary color":"n:原色",
"primary election":"n:初选,预选",
"primary school":"n:完小",
"primate":"n:灵长目,大主教,首领",
"prime":"n:壮年,年富力强,素数,青春,基音,春,最初;v:采摘,引燃,灌注,装填;a:总",
"prime meridian":"n:本初子午线",
"prime minister":"n:丞相,宰相,相",
"prime mover":"n:驱动,原动力,倡议者",
"prime of life":"n:盛年",
"prime time":"n:黄金时间",
"primer":"n:入门,雷管,导火线,始爆器,底火",
"primeval":"a:原始",
"priming":"v:打底,起爆,装填,灌注,点火,引爆;n:底子,发火,起爆,点火",
"primitive":"n:原人,洪荒;a:洪荒",
"primitively":"d:最初",
"primogenitor":"n:先祖,始祖,祖先",
"primp":"v:装饰,打扮",
"primrose":"n:报春花,樱草",
"prince":"n:王子,亲王,君主,大家,大王,公爵,巨头,王爷,名家,千岁,王孙,诸侯,侯爵",
"prince albert":"n:便鞋",
"princess":"n:公主,王妃,女王",
"princeton":"n:普林斯顿",
"principal":"n:长,老本,首长,元,主角;a:主角",
"principal axis":"n:光轴,主轴",
"principal sum":"n:资金",
"principality":"n:公国",
"principally":"d:主要,大抵,首要",
"principle":"n:原则,原理,节操,政策,主义,道理,道,原则性,源泉,本原,要素,本体,根源,物情,动因,本性,揆,总纲,本质,素",
"principled":"a:刚正",
"print":"n:印刷;v:刊印,刊行,印染,晒图,现出,制版",
"print shop":"v:印刷所",
"printer":"n:打印机,印刷机",
"printing":"n:印刷,复制,印数,印花,印刷业;v:印刷,打印,复印",
"printing press":"n:印刷厂",
"prior":"a:预先,先验;v:优先;n:先验;d:事先",
"prior to":"p:以前,头,在_之前,之前",
"priority":"n:优先权,优先,重点,先后,先,前,上位,主动权;d:先后",
"prise":"n:杠杆",
"prism":"n:棱镜,三棱镜,棱柱,棱柱体,柱",
"prison":"n:监狱,监禁,狱,监牢,牢;v:关押",
"prison cell":"n:囚室",
"prison guard":"n:禁子",
"prison house":"n:牢房",
"prisoner":"n:囚犯,犯人,俘虏,监犯,囚徒,阶下囚,囚,人犯",
"prisoner of war":"n:战俘,俘虏,虏,俘",
"prissy":"a:谨言慎行",
"pristine":"a:古时",
"privacy":"n:秘密,私事,隐居,阴私,私下,隐君子,隐退,机密",
"private":"n:士兵,兵,列兵,个人,小卒,私人,阴部,兵卒,生殖器;a:普通",
"private citizen":"n:平民",
"private parts":"n:下身,阴,下体",
"private property":"n:私藏,私",
"private school":"n:塾",
"privately":"d:私下,私自,背地,秘密,背地里",
"privates":"n:士兵,兵卒,阴部,士卒",
"privation":"n:匮乏,缺乏,丧失,艰难,困难,贫穷,剥夺,没收,穷困",
"privet":"n:女贞",
"privilege":"n:特权,优惠;v:特许",
"privileges":"n:特权",
"privily":"d:暗中,私下",
"privy":"n:厕所",
"prize":"v:珍视;n:彩",
"pro":"n:内行,专家;a:依违两可",
"probability":"n:概率,可能性,几率,或然性,盖然性,或然率",
"probability theory":"n:概率论",
"probable":"a:或然;n:可能",
"probably":"d:可能,也许,大概,或许,或,恐怕,大约,多半,谅必,备不住;v:敢;c:或",
"probate":"v:检验",
"probation":"n:见习,缓刑,考验,预备期,鉴定,检验,察看;v:鉴定",
"probational":"a:察看",
"probationary":"a:察看",
"probationer":"n:练习生,试读生,见习生",
"probe":"v:探查,调查;n:探子",
"probing":"v:钻探,探测,试探性;n:试探性",
"probity":"n:正直,诚实",
"problem":"n:问题,题,课题,疑问",
"proboscis":"n:鼻子,吻",
"procaine":"n:普鲁卡因",
"procedure":"n:过程,程序,方法,手续,步骤,工序,行动,礼节,礼仪,程,流程,行为",
"procedures":"n:程序,条贯,手续",
"proceed":"v:进行,继续,开始,着手,前进,起诉,发出,接着,发生,出发,动手,控诉,出自,入手,出于,处置,前往,赴;n:收益,收入",
"proceeding":"n:程序,进程,学报,记录,进行,做法,行为,论文集,处理,汇编,手段,行动,项目,会刊,事项,活动",
"proceeds":"n:收入;v:收入",
"process":"n:过程;v:储藏",
"processed":"a:熟",
"processing":"v:处理,洗印,操作;n:处理",
"procession":"n:队伍,游行,行列,行进,发出,前进,队列,先行,进行",
"processor":"n:处理机,处理器,计算机",
"proclaim":"v:宣布,显示,宣告,声明,公布,赞扬,布,宣,歌颂,表示,揭示;n:布",
"proclamation":"n:公告,宣布,文告,声明,布告,宣言,榜文,自白,公布,声明书",
"proclivity":"n:脾气,倾向,癖性,敏捷",
"procrastinate":"v:因循,拖延,拖,延宕,迟误,推宕,延搁,迁延,耽搁",
"procrastinating":"v:拖拉;a:拖拉",
"procrastination":"n:拖延,因循;a:拖拖拉拉",
"procreate":"v:生育,产生,生,制造,滋,生殖",
"procreation":"n:生殖,生产,生育",
"proctor":"n:学监,代理人",
"procurator":"n:检察官,代理人",
"procure":"v:获得,取得,达成,引起,实现,拉皮条,采购,介绍",
"procurement":"n:获得,取得,成就,获,达成,采购,征购;v:征购",
"prod":"n:戳;v:促使,将,戳,激励,针刺,拨动",
"prodigal":"n:浪子,逛荡,败家子",
"prodigality":"n:大量,丰富,奢侈,挥霍,慷慨,浪费",
"prodigy":"n:奇才,天才,奇迹,神童,神物,预兆,壮观,怪人,怪物,怪事",
"produce":"v:产生,生产,引起,出,提出,制造,产,生成,生,出示,演出,做,创作,创造;n:成果,制品,手法",
"producer":"n:生产者,制片人,振荡器,发生器",
"product":"n:产品,产物,乘积,制品,积,成果,制成品,结果,生成物,品,作品,创作,结晶,产量,积数,生产物,活,出产,出品;v:产",
"product line":"n:生产线",
"production":"n:生产,产生,产品,制造,生产量,演出,提出,作品,提供,总产量,摄制,生成,制作,成果,形成,作业,小题大做,延长,制品,著作;v:产生,形成,生产",
"production line":"n:生产线",
"productiveness":"n:效率,生产力",
"productivity":"n:生产率,生产力,生产能力,多产,效率,丰饶",
"products":"n:货物,物产,制品",
"prof":"n:教授",
"profanation":"n:滥用,误用",
"profane":"v:亵渎,误用",
"profanity":"n:脏话",
"profess":"v:自称,表示,声称,表白,宣称,宣布,教授,承认,假装,声言,佯装,宣言,明言",
"profession":"n:职业,行业,同行,表白,行当,生涯,行,业,行道,生业,宣言,声明,自白,自称,自由职业,工种",
"professional":"n:内行,专家,知识分子",
"professionalization":"n:专业化",
"professionals":"n:内行",
"professor":"n:教授,老师,先生",
"proffer":"v:提出,送礼,贡献,赠送,奉送,提供;n:提议,贡献",
"proficiency":"n:潜能,精练,熟练,一手,精通",
"proficient":"n:专家,老手,能手,内行;a:圆熟,熟练",
"proficiently":"d:得心应手",
"profile":"n:剖面,侧面,简介,曲线,轮廓,形象,侧影,传略,简况,外形,纵剖面,小传,外观,型,翼型,断面,素描,侧面图",
"profiling":"v:成形,造型,靠模,切削,整形;n:造型,靠模",
"profit":"n:利润,赢利,利,好处,收益,利益;v:有用,谋利,赚钱,有利于,利用",
"profit margin":"n:利润率",
"profitable":"a:有利可图;v:有利可图",
"profiteer":"n:奸商;v:捞一把,牟取暴利,谋利",
"profitless":"v:无利可图;a:无利可图",
"profligacy":"n:荒淫,堕落,放荡",
"profligate":"n:浪子;a:糜烂;v:糜烂",
"profound":"a:深刻,深,深奥,深切,深邃,渊深,沉稳,厚,隆,玄,赜,沉,入木三分,深长,奥妙,奥博,深厚,湛;n:大洋,深渊,深处,洞;v:入木三分",
"profoundly":"d:深深地,深深",
"profundities":"n:堂奥",
"profundity":"n:深刻,深奥,深度,深,天高地厚,深渊,深处,深厚,深刻性,深切",
"profuse":"a:茂,芾,苞,纷",
"profusely":"d:不迭",
"profusion":"n:大量,丰富,奢侈,豪爽,浪费,充沛,挥霍,慷慨;v:浪费",
"progenitor":"n:先驱,祖先,前辈,前驱,老祖宗",
"progeny":"n:后代,子孙,胄,后裔,苗裔,成果,结果",
"progesterone":"n:黄体酮,孕激素",
"prognosis":"n:预后,预测,预知;v:预测",
"prognostic":"n:预兆,先兆,征兆;a:预兆",
"prognosticate":"v:预测,预示,预兆,预言",
"prognostication":"n:预言,征兆,前兆",
"program":"n:程序,计划,节目,方案,纲领;v:规划",
"programme":"n:节目,节目单,大纲,规划,日程,工程,要目,拟,时间表;v:规划",
"programmer":"n:程序员,计算机",
"programming":"n:设计;v:规划",
"progress":"n:进步,进展,发展,进行;v:长进,发达;c:进步",
"progression":"n:发展,前进,进行,级数,改进,算术级数,进步,数列,累进",
"progressive":"a:进步,左,左倾",
"progressive party":"n:改革派",
"progressive tense":"n:进行式",
"progressively":"d:逐渐,逐步",
"prohibit":"v:禁止,禁,阻止,取缔,不许,防止,不准,查禁",
"prohibited":"v:不许",
"prohibition":"n:禁止,禁酒,禁令",
"prohibitions":"n:禁例",
"prohibitory":"a:禁例",
"project":"v:投射,突出;n:企业",
"projectile":"n:弹丸,导弹,火箭,飞弹",
"projecting":"a:突出",
"projection":"n:投影,预测,计划,射影,推测,估计,放映,规划,投射,设计,想像;v:发射",
"projective":"a:投影",
"projector":"n:放映机,投影仪,发射机,发射器,探照灯,幻灯,骗子,设计者",
"prolapse":"v:脱出,下垂;n:脱出",
"prole":"n:无产阶级",
"proles":"n:后代",
"proletarian":"n:无产者",
"proletariat":"n:无产阶级",
"proliferate":"v:增殖,增生,激增,蕃,扩散",
"proliferation":"v:出芽,增生,增殖;n:增生,增殖",
"prolix":"a:冗长,烦冗,繁冗",
"prolixity":"n:罗嗦,冗长",
"prologue":"n:序,开场白,序幕,序言",
"prolong":"v:延长,拖延,拖,延,拉长,延期,展缓",
"prolongation":"n:延长,伸长,延期;v:伸长",
"prolonged":"a:旷日持久,经久,经久不息;v:经久不息,经久",
"prom":"n:舞会",
"promenade":"n:散步",
"promethium":"n:钷",
"prominence":"n:日珥,显著,著名,突起",
"prominent":"a:杰出,突出,特出,出类拔萃,杰;v:出众",
"promiscuity":"n:混乱,混杂,混淆,乱,杂乱",
"promiscuous":"a:淫乱",
"promise":"v:答应;n:允许",
"promises":"n:承诺",
"promising":"v:有为,大有作为;a:大有可为",
"promo":"n:推广,宣传",
"promontory":"n:海角,角,岬,岬角",
"promote":"v:提升,促进,提拔,升级,增进,提倡,获得,推动,升,升高,助长,推广,升迁,发起,奖励,开展,引起,擢升,宣传,创立,升格,提,兴,拔,倡,擢,筹划,发扬,弘,振兴,陟,促,晋,伸张,推,掖,鼓动,拉扯,超拔",
"promotion":"n:提升,升迁,促进,宣传,升级,产品,增进,奖励,举办,推广,发起,振兴,助长,发扬;v:升级",
"prompt":"v:促使,驱使;a:捷;n:提醒,提示符;d:正好",
"prompting":"n:提示,驱使,煽动,刺激,唤起,激励,鼓励,暗示;v:提醒,提示",
"promptitude":"n:迅速,机敏,果断,敏捷",
"promptly":"d:立即,马上,及时,立刻,连忙;v:毫不迟疑",
"promptness":"n:敏捷",
"promulgate":"v:颁布,公布,揭示,颁,颁发,传播,发表,宣传",
"promulgation":"n:发布",
"prone":"a:容易",
"proneness":"n:俯伏,倾向,嗜好,脾性,屈",
"prong":"n:叉子,插脚,股,角,树枝,尖头,射线,叉;v:刺,插脚",
"pronoun":"n:代词,代名词",
"pronounce":"v:宣布,发音,宣告,宣称,断定,宣判,表态,断言,咬,讲述,演讲",
"pronounced":"a:显著,浓厚",
"pronouncement":"n:公告,表示,判决,声明,决定,宣告",
"pronto":"d:马上,立刻",
"pronunciation":"n:发音,读法,语音,字,字音,读,读音;v:读",
"proof":"n:证明,证据,校样,证件,检验,考验,凭据;v:校验,论证,经得起,征",
"proofing":"v:防护",
"proofread":"v:校,校对,勘正",
"proofreader":"n:校对",
"prop":"v:撑;n:后盾",
"prop up":"v:犁,扶植,撑,撑持,掎,戗,支",
"propaganda":"n:宣传,宣传部,传播",
"propagandist":"n:宣传员",
"propagandize":"v:宣传,传播",
"propagate":"v:繁殖,传播,宣传,增殖,普及,弘扬,蔓延,宣扬,传种,孳,阐扬,传达,遗传,繁,滋生,传染,摅,生息",
"propagation":"n:传播,宣传,传送;v:传播,传送",
"propane":"n:丙烷",
"propel":"v:推进,推动,推,逐出,驱使",
"propeller":"n:螺旋桨,推进器,桨",
"propenoic acid":"n:丙烯酸",
"propensity":"n:倾向,嗜好,癖性,脾性",
"proper":"a:适当,恰当,正确,正当,一定,应有,正经,当,适度,端正,合宜,特有,妥当,相称;v:合,得,端,像话,应有,当;d:恰,非常,很",
"proper fraction":"n:真分式",
"proper name":"n:专名",
"proper noun":"n:专名",
"properly":"d:适当,完全,非常,整整齐齐,好生,恰,相当;a:妥贴,得宜",
"properties":"n:特征,性质,性状,道具,特性",
"property":"n:财产,性质,特性,性能,所有,地产,特征,产业,属性,财物,所有权,财,资产,道具,性,服装,产,家业,玉帛,家当,业;v:产",
"property owner":"n:业主,地主",
"property right":"n:财产权",
"property tax":"n:财产税",
"prophecy":"n:预言,谶",
"prophesy":"v:预言,预示",
"prophet":"n:先知,预言家",
"prophylactic":"n:预防药",
"prophylaxis":"n:预防",
"propinquity":"n:接近,近亲,类似,近似,邻近;v:近似",
"propitiate":"v:抚慰,调解,调和,劝解",
"propitiation":"n:和解",
"propitious":"a:吉利,祥,祯,吉,吉庆,吉祥",
"proportion":"n:比例,部分,相称,比,比重,比率,份,率,比例式,配合,调和,平衡;v:摊派,分配",
"proportional":"a:比例,均衡;n:比例式",
"proportionality":"n:相称,比例",
"proportionate":"a:均衡",
"proposal":"n:建议,提议,提案,求婚,方案,议案,主张,案,拟议,申请,投标",
"propose":"v:建议,提出,提议,求婚,打算,计划,推荐,提名,动议,求,建,倡言,倡首,申请,倡导;n:动议",
"proposer":"n:申请人",
"proposition":"n:命题,建议,家伙,陈述,主张,事情,事业,提议,主题,工作,论题,企业,定理,商品;v:提议,建议,构想",
"propound":"v:提出,提议,建议",
"proprietary":"n:所有者,成药,领主,所有权;a:专有权",
"proprietor":"n:老板,主人,业主,地主,领主",
"proprietorship":"n:所有权",
"propriety":"n:得体,恰当,礼节,适当,体统,适宜,规矩,正当,妥当,轻重,体面",
"propulsion":"n:推进,推进器;v:推进",
"propylene":"n:丙烯,丙稀",
"prorate":"v:摊派",
"prorogation":"n:休会,闭会",
"prorogue":"v:休会,闭会",
"prosaic":"a:平淡,平淡无奇",
"proscenium":"n:舞台,前台",
"proscribe":"v:禁止,排斥,放逐",
"proscription":"n:禁止,排斥,放逐",
"prose":"n:散文,散体,平凡,单调",
"prose poem":"n:散文诗",
"prosecute":"v:起诉,告发,控告,做,从事,经营,执行,推行",
"prosecution":"n:起诉,控告,执行,贯彻,检举,实行,告发",
"prosecutor":"n:原告,举报人",
"proselyte":"v:改变,搜罗",
"proselytism":"n:改变",
"proselytize":"v:变节",
"prosody":"n:韵律学",
"prospect":"n:前景,前途,希望;v:找,查勘,探矿,展望",
"prospecting":"v:勘探,勘察,似乎,勘查;n:勘查",
"prospects":"n:出息,局面",
"prospectus":"n:说明书,简介,意见书,样本,大纲",
"prosper":"v:兴隆,繁荣,庇佑,兴,勃发,昌盛",
"prosperity":"n:繁荣,繁荣昌盛,昌盛,兴盛,繁华,嘏;a:景气",
"prosperous":"a:昌,红火,穰,熙攘,熙,华,隆,兴隆,旺,隆盛,盛;v:盛,欣欣向荣,兴旺",
"prostate":"n:前列腺",
"prostate gland":"n:前列腺",
"prosthesis":"n:取代,置换",
"prostitute":"n:妓女,娼妓;v:卖身,出卖,卖淫,滥用,卖,卖春",
"prostitution":"n:卖淫,滥用;v:卖淫",
"prostrate":"v:衰竭,推翻,顶礼,虚脱;a:俯伏",
"prostration":"n:虚脱,衰竭,俯卧,衰弱,拜倒,屈服",
"protactinium":"n:镤",
"protagonist":"n:主人公,头面人物,主角,主人翁,领导者",
"protease":"n:蛋白酶",
"protect":"v:保护,防止,护,包庇,防护,捍卫,护卫,庇护,警戒,卫护,抚,佑,卫,荫庇,庇荫,保,庇,守护,庇佑",
"protection":"n:保护,防护,保卫,防御;v:保护,警戒",
"protector":"n:避雷器,保安器,保险丝,摄政",
"protectorate":"n:保护国",
"protege":"n:门徒",
"protein":"n:蛋白质,蛋白,朊",
"proterozoic":"n:元古界,元古代",
"protest":"v:抗议,说,坚持,声明,讲,主张,断言,拒付;n:不服,声明,断言",
"protestantism":"n:新教,耶稣教",
"protestation":"n:反对,声明,拒绝,异议,断言,主张,抗议",
"protocol":"n:协议,礼仪,议定书,礼节,草案,草约,拟;v:打",
"proton":"n:质子",
"protoplasm":"n:细胞质,原生质;v:靠",
"prototype":"n:原型,样机,标准,典型,模范,本色,样板,样品",
"protozoan":"n:原生动物",
"protozoic":"n:原生动物",
"protract":"v:延长,伸出,推迟,画,绘制,突出,延",
"protracted":"a:持久,旷日持久",
"protraction":"n:伸长,制图,延长,拖延",
"protractor":"n:量角器",
"protrude":"v:伸出,突出,凸出,支,出,努,凸,突,腆",
"protruding":"v:突出;a:突出",
"protrusion":"n:突出,突起,隆起,伸出,凸出",
"protuberance":"n:包,疙瘩,突出,突起,瘤,隆起",
"proud":"a:自豪,傲,光荣,满;d:傲然;v:自豪",
"proudly":"d:傲然,踌躇满志,大模大样,扬扬得意",
"prove":"v:证明,证实,试验,表明,验证,体验,显示,检验;n:证",
"provenance":"n:起源,原产地,产地,出处",
"provender":"n:粮秣,粮草,饲料",
"proverb":"n:谚语,俗话,格言,笑柄,谚,古语,语,话柄",
"proverbial":"a:有口皆碑",
"provide":"v:提供,给,规定,准备,供给,供养,供,预备,配备,赡养,管,备,考虑,预防,发放,庀,养,酌量,防,具,任命,龚,资",
"provided":"c:只要,假如,设若",
"provided that":"c:只要,只有,假若,倘或,倘若",
"providence":"n:上天,天意,上帝,深谋远虑,先见之明,节约,准备,天命,天道",
"providing":"c:假如",
"province":"n:省,范围,省份,职责,乡间,地方",
"provincial":"n:乡下人,大主教",
"provincial capital":"n:省治,省垣,省城",
"provincialism":"n:方言,地区性,地方主义",
"proving":"v:验证",
"provision":"n:规定,条款,粮食,食品,粮;v:准备",
"provisional":"a:临时,暂定;v:暂定",
"provisioned":"v:给养",
"provisions":"n:口粮,给养,供应,食品,粮",
"proviso":"n:条件,但书",
"provocateur":"n:奸细",
"provocation":"n:发脾气,挑衅,发怒,愤怒,挑拨,刺激,触怒,诱发,煽动",
"provocative":"a:挑衅;n:兴奋剂",
"provoke":"v:激怒,引起,招惹,挑起,惹,刺激,挑逗,挑衅,挑拨,招,煽动,沾惹,触怒,激发,惹火,惹事,滋生,撩拨,逼使,撩,寻衅,撩逗,讨,挑动,驱使,拨弄,调",
"provost":"n:教务长,院长",
"prow":"n:船头,机头",
"prowess":"n:本事,威力,英勇,勇猛,神威",
"prowler":"n:小偷",
"proxima centauri":"n:比邻星",
"proximity":"n:邻近,亲近,接近,距离;v:接近",
"proxy":"n:代表,代用品,委托书,代理人,代理",
"prudence":"n:谨慎,慎重,小心,节俭,精明",
"prudent":"a:谨慎,审慎,慎重,持重;v:谦虚谨慎",
"prudential":"a:慎重",
"prune":"v:修剪,整枝,剪除,剪裁,修整,删节,修,修理,省去,删除,除去,修枝;n:蠢货",
"pruning":"v:整枝,修枝,打杈;n:修剪",
"prurience":"n:好色,渴望",
"prussia":"n:普鲁士",
"prussic acid":"n:氢氰酸,氰化氢",
"pry":"v:窥探,打听,盯,撬;n:杆子,杠杆,窥视,窥探",
"ps":"n:附言",
"psalm":"n:赞美诗",
"psalmist":"n:王",
"psalter":"n:诗篇",
"pseudo":"a:假,伪",
"pseudonym":"n:笔名,假名,化名",
"pseudopod":"n:伪足",
"pseudoscience":"n:伪科学",
"psoriasis":"n:牛皮癣",
"psyche":"n:心灵,精神,灵魂,魂魄",
"psychic":"n:巫师,巫婆,心理",
"psychics":"n:心理学",
"psychology":"n:心理学,心理,心态",
"psychopathy":"n:精神病",
"psychosis":"n:精神病",
"ptarmigan":"n:雷鸟",
"pterodactyl":"n:翼手龙",
"pteroylglutamic acid":"n:叶酸",
"pu":"n:蒲",
"pub":"n:酒馆",
"puberty":"n:青春期,青春,发情期,妙龄",
"pubes":"n:阴毛,阴阜",
"pubescence":"n:绒毛,发情期",
"pubic bone":"n:耻骨",
"pubis":"n:耻骨",
"public":"n:公众;a:公立,公有,公营;v:公用",
"public debt":"n:公债",
"public discussion":"n:公议",
"public holiday":"n:节日,公休",
"public house":"n:酒肆,客栈,酒吧",
"public law":"n:公法",
"public lecture":"n:报告会",
"public nuisance":"n:公害",
"public opinion":"n:民意",
"public property":"n:公物",
"public prosecutor":"n:检察官",
"public relations":"n:公关",
"public servant":"n:官,公务员",
"public utility":"n:公用事业",
"public-spirited":"a:急公好义",
"publication":"n:出版,出版物,发表,公布,发行,刊物,刊,颁布,发布",
"publicity":"n:宣传,公开,出名,舆论界,宣扬,传开,广告",
"publicize":"v:公布,宣扬,张扬,发表,公,宣传",
"publicly":"d:公开,当众,公然",
"publish":"v:出版,发表,公布,刊登,披露,印行,刊载,宣布,登,出,揭晓,刊印,刊,使用,刊布,编印,发刊,公开,颁布,布,发布,发行,付梓,登载;n:布,发布",
"publisher":"n:出版社,发行人,出版者",
"publishing":"a:出版",
"publishing house":"n:书局",
"puck":"n:冰球,顽童",
"pucker":"v:皱;n:皱纹",
"puckering":"n:皱纹;v:皱纹",
"pud":"n:前脚,手",
"pudding":"n:布丁,糕,香肠",
"pudding head":"n:蠢货",
"puddle":"n:水坑,洼,水潭;v:搅拌,撒尿",
"puddling":"n:精炼",
"pudendum":"n:阴部",
"pudgy":"a:胖乎乎,矮墩墩",
"pueblo":"n:村庄",
"puerile":"a:幼稚,侗",
"puerility":"n:幼稚,孩子气,愚蠢",
"puerperal":"a:产妇",
"puerperal fever":"n:产褥热",
"puff":"v:喷,喘,吹,喘息,吹气,疏松,喘气,肿胀,吹风,膨胀,扑;n:垫片,团,广告,阵,褥子;d:噗",
"puff out":"v:吹风,吹气",
"puff up":"v:膨胀",
"puffed rice":"n:爆米花",
"puffer":"n:河豚,火车头",
"puffiness":"n:肿大,自满,膨胀,自夸,夸张,虚胖",
"puffing":"v:夸奖",
"puffy":"a:蓬松",
"pug":"n:巴儿狗,猴子,拳师,兔子,管家;v:拌,捣",
"pugilism":"n:拳击,拳",
"pugilist":"n:拳师",
"pugnacity":"n:好斗",
"puke":"n:催吐剂,呕吐,绰号;v:呕",
"puking":"v:冒顶",
"pulchritude":"n:漂亮,美丽",
"pule":"v:抽咽",
"pull":"v:拉;n:把柄,牵引",
"pull at":"v:吧嗒",
"pull away":"v:脱身",
"pull down":"v:拉倒,扒,拆除,推翻",
"pull in":"v:抵达,靠岸",
"pull off":"v:脱,赢得,成功,捣鬼",
"pull out":"v:扎,抻,撤离,拔掉,擢,撤退,发车,掏",
"pull strings":"v:走后门,牵线",
"pull through":"v:渡过,渡",
"pull together":"v:戮,通力合作",
"pull up":"v:薅,扯,揠,停车",
"pull wires":"v:牵线,牵线搭桥",
"pull-up":"n:停车处,停止,休息",
"pullback":"n:挂钩,阻力",
"pullet":"n:小姑娘",
"pulley":"n:滑轮,皮带轮,滑车",
"pulley block":"n:滑轮组",
"pulling":"v:拉力,拖带;n:拉力",
"pullout":"n:撤退",
"pullover":"n:套衫",
"pulmonary":"a:肺活量",
"pulmonary artery":"n:肺动脉",
"pulmonary emphysema":"n:肺气肿,肺吸虫",
"pulmonary vein":"n:肺脓肿,肺静脉",
"pulp":"n:果肉,肉,纸浆,矿浆,髓,木浆,瓤子,牙髓",
"pulpiness":"n:虚胖,稀烂",
"pulpit":"n:讲坛,操纵台",
"pulpy":"a:稀烂",
"pulsar":"n:脉冲星",
"pulsate":"v:搏动,脉动,跳动,震动,搏,筛选,脉冲,波动,悸动",
"pulsating":"v:脉动",
"pulsation":"n:脉动,颤动,震动,悸动,间断;v:脉动",
"pulse":"n:意向;v:搏动,震动",
"pulses":"n:豆",
"pulsing":"v:脉动",
"pulverization":"n:粉碎",
"pulverize":"v:粉碎,碎,碾碎,研磨",
"pulverizing":"v:粉碎;n:粉碎",
"puma":"n:美洲狮",
"pumice":"n:浮石,浮岩",
"pumice stone":"n:浮石",
"pump":"n:泵,打气筒;v:排出,抽动,绞",
"pump room":"v:泵房",
"pumper":"n:消防车",
"pumping":"v:抽动",
"pumping station":"n:扬水站,抽水站",
"pumpkin":"n:南瓜,西葫芦,番瓜,大亨,倭瓜,脑袋瓜",
"pun":"n:双关语;v:一语双关",
"punch":"n:穿孔,穿孔机;v:推,凿孔,冲,捅",
"punch line":"v:警句,妙语",
"punch-up":"n:吵闹,打群架",
"puncher":"n:冲床,穿孔机",
"punching":"v:打孔,冲,冲压,钻孔,穿孔,凿孔",
"punctilio":"n:拘束,拘板,细节",
"punctilious":"a:执著",
"punctual":"a:准时,按时",
"punctuality":"n:守信用,敏捷",
"punctually":"d:准时,按时,正点,如期",
"punctuate":"v:加重,强调,断句,圈点,标点,间断",
"punctuation":"n:标点",
"puncture":"n:刺,针刺,穿孔,戳,扎,刺伤;v:穿孔,击穿,穿刺,揭穿",
"pundit":"n:学者",
"pungency":"n:刺激性,辛辣,苦痛,辣味",
"pungent":"a:刺激性,泼辣,辛辣,辣,辛,辛酸",
"puniness":"n:不足道,微小",
"punish":"v:惩罚,处罚,惩处,罚,处,惩治,收拾,处分,痛击,办,治,整治,制裁,诛,惩办,打棍子,治罪,惩,咎,艾,责罚,开刀,论处,处置,处治,大吃大喝,责,整",
"punishment":"n:惩罚,处罚,罚,刑罚,处分,惩办,痛击,刑;v:罚,惩罚,惩办",
"punk":"n:妓女,废话,小伙子,废物,面包,朽木;a:腐朽",
"punt":"v:赌,踢",
"punter":"n:船夫",
"pup":"n:狗崽子,幼畜;v:生,下",
"pupa":"n:蛹",
"pupil":"n:学生,小学生,瞳孔,生,弟子,徒弟,瞳人,门生,徒",
"puppet":"n:木偶,傀儡,伪;a:伪",
"puppet show":"n:木偶戏",
"puppetry":"n:假装,傀儡,木偶戏,虚假",
"puppy":"n:脚,狗崽子",
"purchase":"n:购买,买;v:采买,置,购,收购,采办",
"purchaser":"n:买方,买主,采购员",
"purchasers":"n:用户",
"purdah":"n:帷幔",
"pure":"a:纯,纯粹,纯洁,纯净,纯正,单纯,地道,正,白,清,地地道道,清白,纯朴,淳,粹,贞,清醇;n:玉",
"pure gold":"n:纯金",
"purebred":"n:纯种",
"puree":"n:浓汤",
"purely":"d:纯粹,完全,单纯,单,全然;a:单纯",
"pureness":"n:纯度,清白,纯粹,洁净,纯净",
"purgative":"n:打药,泻药",
"purgatory":"n:炼狱",
"purge":"v:清洗,清除,净化;n:清洗,清除,泻药",
"purging":"v:腹泻",
"purification":"n:净化,提纯,斋戒,精制;v:提纯,净化,精制",
"purifier":"n:净化器",
"purify":"v:净化,提纯,清除,精炼,纯洁,纯净,涤,洁净,精制,洁,澄清,澄",
"puritan":"n:清教徒",
"purity":"n:纯洁,纯度,纯正,贞洁,纯净,清白,清洁,清廉,纯粹",
"purl":"n:流苏,潺潺,花边",
"purlieu":"n:郊外,范围,界限,近郊",
"purloin":"v:偷窃",
"purple":"n:紫色,紫红色,暗紫色,高位,贵族;a:紫",
"purplish blue":"n:藏蓝",
"purplish red":"n:紫红色",
"purport":"n:大意;v:意味着,声称",
"purportedly":"d:据称",
"purpose":"n:目的,用途;v:企图",
"purposefully":"d:有意",
"purposely":"d:故意,有意,特意,有心,故;c:故",
"purr":"d:呜呜;n:呜呜",
"purse":"n:钱包,手提包,钱袋,奖金,荷包,金钱,囊,腰包,资财,资力,国库",
"purser":"n:事务长,出纳员",
"pursuance":"n:贯彻,履行,尾追,追踪,追,追赶,奉行,追求,实行,推行",
"pursuant to":"p:根据,按照",
"pursue":"v:追求,追捕,继续,追赶,采取,从事,纠缠,追,奉行,追逐,推行,走,乘,实行,寻求,追随,经营,猎取,穷追,追踪,求,探求,适,图,追寻,逐,贯彻",
"pursuer":"n:原告,研究者",
"pursuit":"n:追求,研究,追捕,追踪,工作,追赶,追击,职业,实行,事务,穷追,经营,驱逐",
"purulence":"n:化脓;v:化脓",
"purvey":"v:供给,供应",
"purveyance":"n:食物,伙食",
"purview":"n:范围,眼界,界限,权限",
"pus":"n:脓",
"push":"v:推,挤;n:毅力,精力",
"push around":"v:欺侮",
"push aside":"v:推开,排挤,拨,拨开,扒,扒开",
"push away":"v:推,推开",
"push button":"n:按钮,开关",
"push down":"v:按,推倒,压",
"push forward":"v:督促,挺进,推动,推,推进",
"push on":"v:推动,推进",
"push out":"v:轧,排挤,凌轹",
"push through":"v:促成",
"push up":"v:顶,俯卧撑",
"pushcart":"n:手推车,小车",
"pusher":"n:推杆",
"pushiness":"n:精神,精力,冲力,毅力",
"pushing":"v:爱出风头",
"pushpin":"n:图钉",
"pusillanimity":"n:怯懦,胆怯",
"puss":"n:老虎,脸色,少女,嘴,脸,兔子,小姑娘",
"pussly":"n:马齿苋",
"pussy":"n:猫,阴户,少女,小姑娘",
"pussyfoot":"v:谨言慎行",
"pustule":"n:脓包",
"put":"v:放,着,穿上,提出,加,建议,认为,放下,穿,提,连缀;n:戳,刺,扔,投,推,掷",
"put across":"v:做成,表达,解释",
"put aside":"v:积蓄,搁置,搁,撇开,丢,扔下",
"put away":"v:储存,收,放弃,整理",
"put back":"v:降级,返航,推迟",
"put behind bars":"v:关押",
"put down":"v:记录,剿,放下,撂,讨平,平,镇压,笔录,贬低,降落,平息,弭",
"put forward":"v:生长,发挥,出头,提",
"put in":"v:加入,投入,下,加,提出,投,置于",
"put off":"v:推延,暂缓,辩解,搁置,推,推宕,延缓,缓,顺延,推诿,熄灭,延迟",
"put on":"v:摆,穿,哄骗,演,抹,使用,擐,穿上,假话,擦,假意,上演,献,戴",
"put on airs":"v:摆架子,故作姿态,装腔作势,扬眉吐气,耀武扬威",
"put out":"v:熄,出版,灭火,出产,灭,放出,取出,伸出",
"put over":"v:渡过,搭,拖延,完成",
"put right":"v:纠正",
"put through":"v:完成,打通,接通",
"put to death":"v:诛戮,处决,诛,弄死",
"put together":"v:并拢,连缀,接,整理,综,总,汇总,装配,缀合,揖,集中,归总",
"put under":"v:杀死,划归",
"put up":"v:设置,修筑,茇,架,住宿,支撑,挂,落脚,下榻,增设,张贴,支,出,竖,寄宿,举起,预谋",
"putrefaction":"n:腐烂,腐败,腐化",
"putrefy":"v:腐烂,腐败,发霉,堕落,化脓",
"putrescence":"n:堕落,腐败,腐化",
"putrid":"a:腐败;v:腐臭",
"putridity":"n:霉烂,腐败,堕落",
"putsch":"n:暴动,民变",
"puttee":"n:裹腿,绑腿",
"putter":"v:磨蹭,拖拉,偷懒,闲荡",
"putting":"v:投掷",
"putty":"n:油灰,泥,泥子",
"puzzle":"n:难题,谜;v:不解,苦思冥想,冥思苦索,困扰",
"puzzle over":"v:苦思冥想,冥思苦索",
"puzzled":"a:困惑;v:不解",
"puzzlement":"n:迷惑,谜,难题,为难",
"puzzler":"n:难题",
"pvc":"n:聚氯乙烯",
"pygmy":"n:侏儒",
"pyjama":"n:睡衣",
"pylon":"n:挂架,标杆,支架,悬臂,铁塔",
"pylorus":"n:幽门",
"pyongyang":"n:平壤",
"pyramid":"n:金字塔,锥体,凌锥;v:叠罗汉",
"pyramiding":"v:叠罗汉",
"pyridine":"n:吡啶",
"pyrimidine":"n:嘧啶",
"pyrite":"n:黄铁矿",
"pyrotechnics":"n:烟火,天花乱坠,火花",
"pyroxene":"n:辉石",
"python":"n:蟒,巴,蚺蛇,巨蟒,蟒蛇,蚺",
"pyx":"n:检查",
"qatar":"n:卡塔尔",
"qi":"n:戚,祁,气",
"qiang":"n:羌,强",
"qin":"n:秦",
"qua":"c:作为;n:作为;p:作为",
"quack":"v:吹牛,聊天,卖,呷呷,大言不惭;d:呱呱,嘎,嘎嘎;n:庸医,骗子",
"quack-quack":"n:嘎嘎",
"quackery":"n:大话",
"quadrangle":"n:四边形,四合院",
"quadrant":"n:象限",
"quadratic equation":"n:二次方程",
"quadrature":"n:矩",
"quadrilateral":"n:四边形,四边",
"quadruped":"n:走兽",
"quaff":"v:痛饮",
"quagmire":"n:泥潭,泥沼,泥坑,沼泽",
"quail":"v:畏缩,胆怯,沮丧,指挥;n:鹌鹑",
"quaint":"a:古怪,古色古香;r:各",
"quake":"v:震动,发抖,颤动,颤抖,震,摇动,摇晃,抖;n:摇动,战栗",
"qualification":"n:资格,条件,批准,限制,斟酌,称作,执照,授权,形容,评定,限定,称呼",
"qualifications":"n:资格",
"qualified":"v:合格",
"qualify":"v:修饰,限制,斟酌,准予,缓和,限定",
"qualitative":"a:定性;v:定性",
"qualities":"n:气质",
"quality":"n:质量,品质,性质,优质,素质,质,能力,特质,品德,才能,身份,地位,音色,质地,品种,成色,相,属性,音值,音品,优点,品,素养,品位,优劣,品第,技能,鲜明,性",
"qualm":"n:不安,恶心,顾忌,疑虑,责备,疑惧;v:顾忌",
"quandary":"n:窘境,左右为难,困惑,窘",
"quantification":"n:量化,定量",
"quantifier":"n:数量词,量词",
"quantify":"v:定量",
"quantity":"n:量,数量,大量,值,大批,许多,数字,音量,大宗,额,分量,定量,参量,定额,期限",
"quantization":"n:量化",
"quantize":"v:量化",
"quantum":"n:量子,量,定量,额,份,数量,定额,份额",
"quantum theory":"n:量子论",
"quarantine":"n:隔离,检疫,封锁;v:检疫,隔离,封锁",
"quarrel":"v:争吵;n:口舌,碴儿",
"quarry":"n:采石场,猎物;v:采,挖掘",
"quarrying":"v:采石",
"quart":"n:夸脱",
"quarter":"n:季度,地方,方向;v:宿营,扎营,屯扎,扎,屯",
"quarterfinal":"n:复赛",
"quarterly":"n:季刊",
"quartermaster":"n:军需,舵手",
"quarters":"n:营盘,住处",
"quartile":"n:弦",
"quarts":"n:金矿",
"quartz":"n:石英,晶,水晶",
"quartz crystal":"n:水晶",
"quartz glass":"n:石英玻璃",
"quasar":"n:类星体",
"quash":"v:撤销,平息,捣碎,废除,取消,压制,镇压",
"quasi":"a:几乎,有点,即,宛如,就是说",
"quaternary":"n:四",
"quaver":"v:颤抖,颤动,震动;n:颤音",
"quay":"n:码头,船埠,埠头",
"queen":"n:女王,王后,皇后,后,女皇,尤物,情人,女神,上品",
"queen bee":"n:雌蜂",
"queen consort":"n:皇后,王妃",
"queer":"a:奇怪,古怪,怪,奇特,不对,奇,怪里怪气,莫名其妙,奇异,不是味儿,刁钻古怪,蹊跷,阴阳怪气,左",
"queerness":"n:奇妙",
"quell":"v:镇压,平息,压,弹压,减轻,平定,消除,弭;n:屠杀",
"quench":"v:熄灭,淬火,解,抑制,遏制,结束,压制",
"quencher":"n:灭火器,饮料,冷却器",
"quenching":"v:蘸火,淬火;n:淬火",
"querulous":"a:满腹牢骚;v:满腹牢骚",
"query":"v:质询,征询,查询;n:质问,怀疑",
"quest":"n:寻找,搜索,追求,找,探求;v:寻找,追求,追逐,探索",
"question":"n:问题,问;v:发问,探究",
"questionable":"a:可疑",
"questioner":"n:审问者",
"questionnaire":"n:问卷,调查表",
"questions":"v:问答",
"queue":"n:队列;v:站队",
"quibble":"v:狡辩,推诿,推托;n:支吾,狡辩,遁词",
"quibbling":"v:诡辩;n:诡辩",
"quick":"a:快;n:核心,要害,本质,活物,生物;d:快",
"quick fix":"n:权宜之计",
"quick march":"n:齐步走",
"quick temper":"n:火气",
"quick-freeze":"v:速冻",
"quicken":"v:加快,加速,快速,鼓舞,苏醒,刺激",
"quickening":"v:胎动",
"quicklime":"n:生石灰",
"quickly":"d:快,赶快,快速,快快,忽忽,霍然;v:赶",
"quickness":"n:迅速,神速",
"quicksand":"n:流沙",
"quicksilver":"n:水银",
"quickstep":"n:快步",
"quid pro quo":"n:报复,赔偿,报酬",
"quiescence":"n:寂静,休眠,沉默,沉寂,静止",
"quiet":"a:安静,静;n:太平,和平,休养,清净,平稳,沉着,肃静,安定,静养;v:安慰",
"quiet down":"v:平息",
"quietly":"d:悄悄,默默,悄然,悄,闷头儿,悄声",
"quietness":"n:静悄悄",
"quietude":"n:沉着,寂静,平静,宁静",
"quietus":"n:解除,死,休眠,灭亡,制止,偿清",
"quiff":"n:姑娘",
"quill":"n:写字,导火线,浮漂;v:刺穿",
"quilt":"n:被子,被,棉被;v:缝",
"quilted":"a:棉",
"quinine":"n:奎宁,金鸡纳霜",
"quintessence":"n:精髓,精华,结晶,精英,本体,本质,菁华,典范,实质,实体",
"quip":"n:妙语;v:嘲弄",
"quirk":"n:怪癖,奇想,口实;v:弯曲",
"quisling":"n:卖国贼",
"quit":"v:离开,辞职,停止,放弃,少,告别,还清,偿还,酬答,免除,偿清,退,退出,作罢,认输,解除,尽;n:离开,辞职,退出",
"quite":"d:很,完全,相当,十分,挺,颇,极,真正,够,差不多,事实上,的确,较,满,怪,颇为,彻底,好生,蛮,较比,比较",
"quite a little":"a:许多",
"quittance":"n:解除,报答,免除,收据",
"quitter":"n:懦夫",
"quiver":"v:颤动,抖动,发抖,颤抖;n:抖动,震动",
"quiz":"n:测验;v:盘问,嘲弄,考试,提问,挖苦",
"quizzical":"a:古怪",
"quoin":"n:角落,榫子,楔子",
"quoit":"n:铁环;v:掷",
"quorum":"n:法定人数",
"quota":"n:定额,配额,限额,指标,数额,份",
"quotas":"v:摊派",
"quotation":"n:引文,引用,引语,语录,行情,估价单,行市;v:引证",
"quote":"v:引用,引证;n:估价表",
"quoth":"v:说",
"quotient":"n:商,商数,份额,系数",
"quoting":"v:引用",
"rabbet":"n:插孔,插座,榫头",
"rabbi":"n:法师,先生",
"rabbit":"n:兔子,野兔,兔,兔皮,家兔;v:诅咒",
"rabbit food":"n:生菜",
"rabble":"n:贱民,乌合之众,狐朋狗友,耙子;v:搅拌",
"rabid":"a:狂热",
"rabidness":"n:猛烈,狂犬病,顽固",
"rabies":"n:狂犬病,恐水病",
"raccoon":"n:浣熊",
"raccoon dog":"n:貉,貉子,貔",
"race":"n:比赛,赛跑,种族,赛马,民族,竞赛,种;v:飞跑,疾行",
"race car":"n:赛车",
"race horse":"n:螳螂",
"racecourse":"n:赛马场,沟,跑道",
"racehorse":"n:赛马",
"raceme":"n:总状花序",
"racer":"n:快艇",
"racetrack":"n:跑道",
"raceway":"n:水道,水沟",
"rachel":"n:犹太人",
"racialism":"n:种族主义",
"racily":"d:痛快",
"raciness":"n:活泼,痛快,挑逗性",
"racing":"n:赛马,赛艇,赛跑,空转,竞赛;v:空转,赛马",
"racing car":"n:赛车",
"racing yacht":"n:赛艇",
"racism":"n:种族歧视,种族主义",
"rack":"n:架子,行李架;v:剥削",
"racket":"n:网球拍,球拍,吵闹,球拍子,考验,骗局,敲诈,狂欢,职业,工作,讹诈,拍子,事情,喧嚷;v:喧闹,喧嚷,吵闹,拍",
"racketeer":"v:敲诈,恐吓,讹诈;n:骗子",
"radar":"n:雷达",
"radial":"n:径向,射线;a:光线",
"radial artery":"n:桡动脉",
"radian":"n:弧度,弪",
"radiance":"n:光辉,光彩,光芒,容光焕发,照射,发光,泽,光焰,发光度,辐射",
"radiant":"a:满面春风,云蒸霞蔚;v:云蒸霞蔚;n:光源",
"radiant energy":"n:辐射能",
"radiate":"v:辐射,放射,发射,照射,发光,发散,散热,闪耀",
"radiation":"n:辐射,发射,放射,照射,发光,放热,散热器;v:发射,发光,照射,放射",
"radiation sickness":"n:放射病",
"radiator":"n:散热器,冷却器,水箱,振荡器",
"radical":"n:基,根式,根;a:急进",
"radicalization":"n:激进",
"radically":"d:根本",
"radicals":"n:部首",
"radii":"n:半径",
"radio":"n:收音机,无线电,无线电台;v:广播",
"radio frequency":"n:射频",
"radio operator":"n:报务员",
"radio receiver":"n:收音机",
"radio set":"n:电台,收音机,接收机",
"radio station":"n:广播电台",
"radio wave":"n:电波",
"radioactivity":"n:放射性",
"radiogram":"n:无线电报",
"radiography":"v:造影;n:造影",
"radiology":"n:放射科,辐射学",
"radiometer":"n:辐射计",
"radiophone":"n:无线电话",
"radiotelegraph":"n:无线电报",
"radiotelegraphy":"n:无线电报",
"radiotelephone":"n:无线电话,报话机",
"radiotherapy":"n:放疗",
"radish":"n:萝卜,小萝卜,莱菔",
"radium":"n:镭",
"radius":"n:半径,桡骨,辐,针",
"radius vector":"n:辐",
"radix":"n:基数,根,底数,词根,根本,根源",
"radon":"n:氡",
"raffle":"n:垃圾,废物,杂物",
"raft":"n:木筏,筏子,木排,大量,筏,排,橡皮船,救生筏,排筏",
"rafter":"n:椽子,榱,椽",
"rafting":"n:合金;v:合金",
"rag":"v:开玩笑;n:帐篷,恶作剧,开玩笑,少量,毛刺",
"ragamuffin":"n:山雀",
"rage":"n:愤怒,怒火,怒气,狂怒,热情,激烈,狂热,暴怒;v:激荡,发狂,流行,汹涌,气愤,风行,发怒,狂怒,盛怒;a:愤怒,汹涌",
"ragged":"a:破烂,褴褛,参差不齐,破破烂烂,参差",
"ragging":"v:开玩笑,恶作剧,胡闹,欺负",
"raging":"v:狂怒,熊熊",
"ragtag":"a:乌合之众,贱民",
"raid":"v:袭击;n:急袭,围捕,游击,抄查,侵入",
"rail":"n:横杆,扶手,路轨;v:责骂",
"rail fence":"n:篱墙,栅栏",
"railing":"n:栏杆,栅栏,围栏,栏,扶手,责备,咒骂",
"railings":"n:栅栏",
"raillery":"n:讥笑,挖苦,取笑,逗弄",
"railroad":"n:铁路,铁道",
"railroad car":"n:车厢",
"railroad train":"n:列车",
"railway":"n:铁路,铁道,轨道",
"raiment":"n:衣服",
"rain":"n:雨;v:消除,中断,降雨,提出,冲洗",
"rain check":"n:顺延",
"rain out":"v:消除,冲洗,中断,暂停",
"rainbow":"n:彩虹,虹,幻影,鲎,幻想",
"raincoat":"n:雨衣",
"raindrop":"n:雨点",
"rainfall":"n:降雨量,雨量,雨水,降雨,降水量,降水,下雨",
"rainproof":"a:雨衣",
"rainstorm":"n:暴风雨,暴雨,风暴,瀑",
"rainwater":"n:雨水",
"raise":"v:提高,提出,举起,引起,抬起,增加,提,养,筹集,饲养;n:筹款,登高,上升,加价,升起,抬起",
"raise hell":"v:闹翻天,撒赖,沸反盈天",
"raise the roof":"v:大发雷霆",
"raise up":"v:举起",
"raiser":"n:酵母",
"raises":"n:加薪",
"raisin":"n:葡萄干",
"raising":"v:养育,提高,饲养",
"raj":"n:统治,支配",
"rajah":"n:王公,柞丝绸,酋长",
"rake":"v:耙,扫射;n:倾斜度,钉耙",
"rake off":"v:油水,佣金,利益,回扣,手续费,扫除",
"rake up":"v:搜集,扒,激起",
"rake-off":"n:回扣",
"rally":"v:振奋;n:集结,挖苦,嘲笑",
"rallying cry":"n:呐喊",
"rallying point":"n:号召力",
"ram":"v:撞,撞击;n:夯",
"ram's horn":"n:羊角",
"ramadan":"n:封斋,斋月",
"ramble":"v:漫步,东拉西扯,漫谈;n:漫游,漫步,浪,闲谈,漫笔,散步",
"rambler":"n:蔓生植物",
"rambling":"a:拉杂;n:天南海北;v:漫无边际",
"ramie":"n:苎麻,苎",
"ramification":"n:分歧,分支,分枝,后果,门类,结果,衍生物,支派;v:分叉",
"ramified":"v:丫杈;n:丫杈",
"ramify":"v:分叉,分枝,分派,交错",
"ramming":"v:打夯",
"ramp":"n:斜坡,坡道,舷梯,斜路,愤怒,诈骗;v:诈取,诈骗,张牙舞爪,降低,减少",
"rampage":"v:暴怒,发怒",
"rampant":"a:猖獗,嚣张",
"rampart":"n:城墙,壁垒,垒;v:垒",
"ramrod":"n:通条",
"ran":"v:泛滥,溢出;n:冉",
"rancid":"a:哈喇,腐臭;v:腐臭",
"rancidity":"n:哈喇,腐臭",
"rancor":"n:怼,冤仇,怨恨",
"rancour":"n:憎恨,怨恨,冤仇",
"rand":"n:地头,边缘,田埂",
"random":"a:随机,乱,随便,漫;v:漫",
"randomness":"n:随机性",
"ranee":"n:王妃,王后",
"range":"n:范围,射程,距离,幅度,种类;v:到达,瞄准,巡逻,开列,连绵,蔓延,整理,对准",
"range finder":"n:测距器",
"range pole":"n:标杆",
"ranging":"v:测距",
"rangoon":"n:仰光",
"rani":"n:公主,王妃",
"rank":"n:地位,队伍,士兵,军阶;v:定级;a:莽莽",
"ranker":"n:兵",
"ranking":"n:顺序,名次",
"rankle":"n:怨尤,怨望;v:激怒,红肿",
"ranks":"n:队伍,阵线,行列",
"ransack":"v:洗劫,掳,掠,搜,搜查,劫掠,掠夺",
"ransom":"n:赎金;v:赎回",
"ransom money":"n:赎金",
"rant":"n:叫喊,叫声,妄语,大话,怒骂,咆哮,怒吼,妄言;v:咆哮,说大话,怒吼,怒骂",
"rap":"n:一点儿;v:抢走",
"rapacious":"a:贪婪;v:强取豪夺",
"rapacity":"n:掠夺,贪婪,抢夺,贪心;a:贪心",
"rape":"v:强奸;n:抢夺",
"rape oil":"n:菜油,菜籽油,菜子油",
"raper":"n:强奸犯",
"rapeseed":"n:油菜子,油菜籽,菜子",
"raphael":"n:拉斐尔",
"rapid":"a:迅速,快,急,湍急,急促,狂暴,急遽,骤;n:急湍,湍流;d:骤",
"rapidity":"n:速度,迅速,敏捷,快速,急速",
"rapidly":"d:迅速,快,急速,立刻,疾速,急匆匆,霍然,敏捷",
"rapids":"n:滩,险滩,激流,急流,湍流",
"rapine":"n:劫掠,滥伐,掠夺",
"rapist":"n:强奸犯",
"rapper":"n:证人",
"rapport":"n:关系,和睦,配合,亲善,和好,联系",
"rapporteur":"n:书记",
"rapprochement":"n:和解,和睦",
"rapscallion":"n:无赖,流氓,恶棍",
"raptor":"n:猛禽,猛兽",
"rapture":"n:狂喜,欣喜若狂,着迷;v:欢天喜地",
"rare":"a:罕见,稀有,难得,少有,珍贵,稀薄,个别,稀少,罕有,珍奇,名贵,鲜,冷,不可多得,稀罕,傀,珍,瑰,罕,希奇,稀,生僻,稀奇,珍异;d:很,极",
"rare earth":"n:稀土",
"rare-earth element":"n:稀土元素",
"rarefied":"a:稀薄",
"rarefy":"v:稀释",
"rarely":"d:难得,极,不大,罕有",
"rareness":"n:稀罕,稀奇",
"rarity":"n:珍品,异物,稀薄,瑰宝,奇事,稀有",
"rascal":"n:坏蛋,恶棍,无赖,流氓,地痞",
"rascally":"a:流里流气,流氓,赖皮,无赖;d:赖皮",
"rascals":"n:地痞",
"rash":"a:鲁莽;n:疹;v:造次",
"rashly":"d:率然,贸然,轻易,愣,冒",
"rashness":"n:轻率,轻举妄动",
"rasp":"n:木锉,焦急;v:磨擦",
"raspberry":"n:讥笑",
"raster":"n:光栅,屏面",
"rat":"n:老鼠,叛徒,耗子,鼠,工贼;v:责骂,变节,叛变,告密,捕鼠",
"ratchet":"n:棘轮,棘爪",
"ratchet wheel":"n:棘轮,闸轮",
"ratcheting":"n:离合器;v:离合器",
"rate":"n:速率,速度;v:骂,评级",
"rate of exchange":"n:兑换率,汇费",
"rate of growth":"n:增产率",
"rate of interest":"n:分,利率,利润率",
"rated":"a:额定",
"rather":"d:相当,有些,有点,颇,颇为,宁愿,宁可,未免,比较,挺,够,怪,较,当然,反而,几分,稍微,满,毋宁,无宁,聊;c:宁,宁愿;r:有些;i:当然;v:聊;a:几分",
"rather than":"c:与其,毋宁;p:宁愿",
"rathskeller":"n:酒吧间",
"ratification":"n:批准,认可,追认",
"ratify":"v:批准,认可,追认,核定,核准",
"rating":"n:斥责,等级,分摊,估计,测定,规格,估价,参量,级别,定额,分配,计算",
"ratings":"n:分级",
"ratio":"n:比,比率,比值,比例,系数,关系;v:对比",
"ratiocinate":"v:推断,推理,推论",
"ratiocination":"v:推理,推论;n:推理,推论",
"ration":"n:配给;v:配售,限定",
"rational":"a:合理,有理;n:有理数,理性",
"rational number":"n:有理数",
"rationale":"n:理论",
"rationalism":"n:唯理论",
"rationality":"n:合理性,理由",
"rationalization":"n:合理化;v:合理化",
"rationalize":"v:合理化,理顺,文饰,文过饰非",
"rations":"n:给养",
"rattan":"n:藤,白藤,藤条",
"ratter":"n:告密者,工贼,叛徒",
"rattle":"n:发生器,乒乓,咕隆,响度;v:叨叨,咕隆",
"rattler":"n:倾盆大雨,滚筒,响尾蛇",
"rattlesnake":"n:响尾蛇",
"rattling":"d:极,非常,很",
"rattrap":"n:困境",
"raucous":"a:沙哑",
"raucously":"d:沙哑",
"ravage":"v:毁坏,蹂躏,糟蹋,劫掠,摧残,破坏;n:暴力,荒废,破坏,灾害,损害,毁坏",
"rave":"v:嚷,说胡话,咆哮,胡言乱语,叫嚣,叫喊,狂喜,激赏,狂暴;n:怒吼,围栏",
"ravel":"v:拆开,缠绕,解除,解开,纠结,纠缠,纷乱,错综,解决;n:缠绕,纠结,混乱,错杂",
"ravel out":"v:解开",
"raveling":"n:拆",
"ravelling":"n:解,解开",
"raven":"v:狼吞虎咽,掠夺;n:劫掠,渡鸦",
"ravenous":"v:强取豪夺;a:强取豪夺",
"ravine":"n:深谷,峡谷,沟,山谷,山沟,涧,峪,赃物,沟壑,谷",
"raving":"a:狂;n:狂言",
"ravings":"n:狂言,呓语,谵语,胡话",
"ravioli":"n:馄饨",
"ravish":"v:强奸,抢夺",
"ravishing":"v:引人入胜",
"raw":"a:生,阴冷,原,潮湿;n:痛处,触犯",
"raw meat":"n:生肉",
"raw recruit":"n:新兵,新手",
"rawness":"n:生硬",
"ray":"n:光线,射线,光,雷;v:放射,投射,闪现",
"ray of light":"n:光线,光束",
"rayon":"n:人造丝,粘胶",
"raze":"v:消除,摧毁,擦伤,毁灭,毁坏,拆毁,磨灭",
"razon":"n:飞弹",
"razor":"v:剃;n:剃刀",
"razor clam":"n:蛏干,蛏",
"razor edge":"n:刀口",
"razorback":"n:长须鲸",
"razz":"n:嘲弄,嘲笑,责备,讥笑;v:嘲弄",
"razzle-dazzle":"n:混乱,烂醉;v:欺骗",
"razzmatazz":"n:活力,精力,兴奋",
"re":"p:关于",
"re-create":"v:改造",
"re-echo":"v:轰传,哄动;n:反响",
"re-enter":"v:收回,加深",
"re-examine":"v:复查,再审,复试",
"re-formation":"n:再造",
"reach":"v:到,达到,到达,达成,抵达,伸出,达,取得;n:智力,力量,地段,到达,宽窄,理解力,领域,伸出,游",
"reach out":"v:伸展,伸出",
"react":"v:反应,反抗,反动,反作用,重演,倒退",
"reactant":"n:成分,反应器",
"reacting":"v:反作用;n:反作用",
"reaction":"n:反应,反作用,反动,反作用力,倒退;a:反动",
"reactionaries":"n:反",
"reactionary":"n:反动派,守旧派,反;a:黑暗,黑",
"reactive":"a:活泼",
"reactor":"n:反应器,反应堆",
"read":"v:读,看,阅读,读书,念,了解,读出,宣读,朗读,识字,攻读,学习,研究,审阅,写作,读取,默读,念书,辨认,翻阅,专攻,批阅,阅,诵读,念诵,阅览,察觉,用功,解答;n:读书,阅读",
"read-out":"n:读出",
"readability":"n:可读性",
"reader":"n:读者,标签,读本,讲师,文选,助教,读物",
"readily":"d:欣然,轻易,甘心,甘愿,爽快,不假思索",
"readiness":"n:准备,愿意,乐意,迅速,敏捷;v:准备",
"reading":"n:阅读,读数,读书,读物,朗读,学识,指示;v:读出",
"reading desk":"n:书桌",
"reading lamp":"n:台灯",
"reading room":"n:阅览室",
"readings":"n:度数",
"readjust":"v:调整,微调,整顿,饬",
"readjustment":"v:调整;n:调整",
"readout":"n:读出,宣读",
"ready":"a:就绪;v:就绪;n:现金;d:欣然",
"ready cash":"n:头寸",
"ready money":"n:现金,现",
"ready-made":"a:现成",
"reaffirm":"v:重申",
"reagent":"n:试剂,试药",
"real":"a:的,真,真正,实际,真实;n:真格的,实物,实情,实数;d:真正",
"real estate":"n:房地契",
"real estate broker":"n:纤手",
"real property":"n:不动产",
"realise":"v:体认",
"realism":"n:现实主义,写实主义,现实性,实在论",
"realistic":"a:实际,切实",
"reality":"n:现实,实际,事实,真实,实体,真实性,实在,现实性,本体,逼真;a:实",
"realization":"n:实现,变卖,成就,赚头",
"realize":"v:了,意识,实现,知道,了解,发觉,体会,变卖,领悟,知,变为,兑现,写实,领略,酬,实行,悟",
"really":"d:真,真正,确实,实在,的确,非常,其实,够,果真,当真,着实,正经,硬是,委实,端的,确乎,真个,果然,诚,殊,敢情,究,果,委",
"realm":"n:领域,王国,国土,界,圈,独立王国,境域,带,境界,部门",
"realness":"n:真实性",
"realty":"n:房地产,不动产",
"ream":"v:绞,铰,榨取;n:令,条纹",
"reamer":"n:绞刀",
"reanimate":"v:鼓舞,激励",
"reanimation":"n:鼓舞",
"reap":"v:收割,得到,获得,收获,穑,获,艾",
"reaper":"n:收割机",
"reaping hook":"n:镰刀",
"reappear":"v:重现,再,再现;d:再",
"reappearance":"n:再现",
"rear":"v:出现,建立,竖起,栽培,牧畜,培育,蓄养,高耸,举起,培养,养育;n:屁股,背后,后部,后边,背面;a:后边",
"rear admiral":"n:少将",
"rear-end":"v:撞入",
"rearguard":"n:殿军",
"rearrange":"v:重排,改编",
"rearrangement":"n:改编;v:改编",
"rearview mirror":"n:后视镜",
"rearward":"n:后方,后面,背后,后部;d:背后;a:背后",
"reason":"n:原因,理由,道理,理性,理智,缘故;v:论断,推究,推论,端;p:由,因;c:故",
"reason out":"v:作出",
"reasonable":"a:合理,公道,通情达理,明白,有理;v:通情达理,知情达理,像话",
"reasonableness":"n:理性",
"reasoning":"n:推理,推论,论证,理论,论断;v:推理",
"reassemble":"v:调整",
"reassert":"v:重申",
"reassign":"v:交还",
"reassurance":"n:安心,再保险,自信",
"rebate":"n:回扣,折头,折扣,减少;v:减少,折,削弱,打折扣",
"rebel":"v:反抗,造反;n:叛逆",
"rebellion":"n:叛乱,反抗,造反,起义,反,暴乱;v:暴动,暴乱",
"rebirth":"n:再生,转生,复活,轮回,新生",
"rebound":"v:弹回,回响;n:反应,篮板球,弹回",
"rebroadcast":"n:重播,转播;v:转播,重播",
"rebuff":"v:驳斥,挫折,阻碍,击退,拒绝;n:拒绝",
"rebuild":"v:重建,翻修,改建,改造,整修,返修,改变",
"rebuke":"v:指责,责骂,斥责;n:熊",
"rebus":"n:谜,字谜",
"rebut":"v:驳斥,反驳,驳回,驳,置辩,揭露,阻止,戳穿,批驳",
"rebuttal":"n:反驳,反证",
"rec":"n:运动场",
"recalcitrance":"n:固执,顽抗,顽固,抗拒,顽强",
"recall":"v:回忆,记得,回想,想起,召回,唤起,收回;n:撤回",
"recant":"v:改变,取消",
"recantation":"n:撤消,取消",
"recap":"v:翻新",
"recapitulate":"v:概括",
"recapitulation":"v:重演;n:重演",
"recapture":"v:收复,征收;n:恢复,征收",
"recast":"v:改作,改造",
"recede":"v:退,后退,退缩,归还,退出,倒退,低落,退却,跌落,交还",
"receding":"n:逆流;v:逆流",
"receipt":"n:收据,接收,发票,收条,接受,进款,收益,票据,字,回条,契据,回单,回执,借据,发单,疗法,文契;v:接收,收到",
"receipts":"n:进款,入款,收入,进项;v:收",
"receive":"v:收到,得到,接收,接到,接受,欢迎,接待,受,接见,接,领到,迎接,承受,收听,款待,收,容纳,招待,蒙,进,奉,领取,纳,领,听从,收买,承认,支撑,领受,签收,迎,接防,领悟,收容,支,落,膺,遇,信任",
"receiver":"n:接收机,听筒,接收器,受话器,收音机,窝家,耳机,容器,收报机,收件人,电视机",
"receiving":"n:接收;v:接收",
"receiving set":"n:接收机",
"recension":"n:修订",
"recent":"n:近期;a:近期",
"recently":"d:最近,近来,新,新近,比,迩来,日来;n:近日,最近;a:新",
"recentness":"n:前不久",
"receptacle":"n:插座,容器,盛器,花托,仓库,插孔",
"reception":"n:招待会,接待,接收,欢迎,欢迎会,招待,收音,迎接,酒会,承认,反响,领悟;v:迎接,取回,接收,接受",
"reception room":"n:会客室,接待室,客堂,客厅",
"receptionist":"n:接待员,招待员,传达;v:传达",
"receptivity":"n:理解力",
"receptor":"n:感受器,接收器",
"recess":"n:深处,凹槽,休会;v:开槽,隐藏,后退",
"recesses":"n:深处",
"recession":"n:衰退,不景气,交还,退出;v:衰退,退缩,后撤,后退",
"recessional":"n:赞美歌",
"recharge":"n:补给",
"recharger":"n:充电器",
"recidivist":"n:惯犯",
"recipe":"n:食谱,配方,方法,处方,秘诀,方剂",
"recipes":"n:食谱",
"recipient":"n:得主,容器",
"recipients":"n:收件人",
"reciprocal":"a:交;v:对等,有来有往,互惠;n:反比",
"reciprocate":"v:报答,回报,交换,往复,报,酬答,来回,互换,答",
"reciprocation":"n:报答,来回,交换",
"reciprocity":"n:对等,可逆性,相关性,互换",
"recital":"n:故事,叙事,吟诵,朗诵,细说,详述,背诵,独奏,叙述",
"recitation":"n:背诵,朗诵,叙述,宣叙调,详述,课堂",
"recitative":"n:道白,宣叙调",
"recite":"v:背诵,朗诵,列举,吟诵,呻,吟,念诵,诵,叹,细说,讲,陈述,念经,陈诉,籀",
"reckless":"a:鲁莽,妄,猖,胆大妄为,愣头愣脑,风风火火;v:胆大妄为",
"recklessly":"d:恣意妄为,没命,不管三七二十一,混,大肆,肆意;v:混",
"recklessness":"n:鲁莽",
"reckon":"v:认为,估计,计算,想,算,指望,合计,依赖,估摸,算计,揣,总计,列入,想见,支付,依靠,料想,揣度,打量,揣测,掂掇,加入,推算,推想",
"reckoning":"n:估计,算账,计算;v:推测,推算",
"reclaim":"v:开垦,改造,改正,改邪归正,收回,再生;n:悔改,矫正,改造,改邪归正,开垦",
"reclamation":"n:回收,开垦,矫正,收复;v:开垦",
"recline":"v:躺,靠,信赖",
"recluse":"n:隐士,隐君子,逸民",
"reclusive":"a:孤独",
"recognise":"v:认识,认出",
"recognition":"n:识别,承认,认识,公认,认可,认得,表扬,感谢,招呼,酬劳,褒奖;v:识别",
"recognizance":"n:保证金,承认,具结,保证书,保释金;v:具结",
"recognize":"v:认出,承认,认识,识别,认,公认,认得,看出,赏识,确认,辨认,辨,具结,酬劳,感谢,表扬,认清,招呼",
"recoil":"v:缩,退缩,倒退,畏缩;n:坐力",
"recollect":"v:回忆,想起,回想,记忆,追忆,想到,追念,忆,追思",
"recollection":"n:回忆,记性,记忆力,回想,感怀",
"recollections":"v:感怀",
"recombination":"n:复合,重组",
"recombine":"v:重组",
"recommend":"v:推荐,建议,介绍,劝,保举,举荐,引进,委托,绍介,引荐,保荐,荐举,劝告,荐,荐引,提倡,引用,托",
"recommendable":"a:可取",
"recommendation":"n:建议,推荐,劝告,介绍,举荐,介绍信,特长,议案;v:推荐",
"recompense":"n:报酬,回报,酬报,酬劳,偿还,报;v:偿还,酬答,回报,酬报,报偿,报",
"recompose":"v:改组,重排,改写",
"recon":"n:侦察",
"reconcile":"v:调和,调解,融合,排解,调停",
"reconciliation":"n:和解,调解,调和,服从,一致,调停;v:和解",
"recondite":"a:深奥,高深,深邃,玄",
"recondition":"v:翻新,修理,整修,改革,恢复,修复,修好,重建,还原,检修,修整,修改,调整",
"reconnaissance":"n:侦察,勘探,搜索,调查,勘察,勘测,探测,勘查;v:探测,搜索,勘探",
"reconnoiter":"v:侦察,斥,斥候,踏勘",
"reconnoitre":"v:调查;n:斥候",
"reconquer":"v:克复",
"reconsider":"v:复议",
"reconstruct":"v:重建,改建,设想,推想,修复,改造,复兴",
"reconstruction":"n:重建,改造,复兴;v:建设,重建",
"reconversion":"v:复原;n:复原",
"record":"n:记录;v:登",
"recorder":"n:录音机,记录器,记录",
"recording":"n:记录,录音,唱片;v:引出",
"recording studio":"n:录音棚",
"records":"n:案卷,志,杂志",
"recount":"v:讲述,叙述,列举,述说,诉说,叙事;n:叙",
"recoup":"v:补偿,收回,赔偿,扣除,偿还",
"recourse":"n:求助,依靠,求援,依赖;v:求援",
"recover":"v:恢复,痊愈,康复,复元,回收,清醒,收复,找到,复原,追回,复,怀柔,安抚,光复,赔偿,开采,提取,愈,取回,围垦,挽回,光,克复,取得,胜诉,收回",
"recovered":"a:康复;v:康复",
"recovering":"v:再现",
"recovery":"n:恢复,回收,康复,痊愈,收回,矫正,复苏,复原,再生;v:复苏,回收,复原,再生",
"recreant":"a:不义;n:胆小鬼",
"recreate":"v:休养,静养,消遣",
"recreation":"n:娱乐,消遣,康乐,休养,游戏,游艺",
"recreation room":"n:游艺室",
"recriminate":"v:反诉,倒打一耙;n:反唇相讥",
"recrudesce":"v:复发",
"recrudescence":"n:复发",
"recruit":"v:招收,吸收,补充,录用,征募,招聘,征集,招募,招,保养,补养,招纳,招工,征,录取,征求,发展,收录,搜罗,征收;n:新兵",
"rectangle":"n:矩形,长方形",
"rectangular":"a:长方",
"rectification":"n:整流,调整,整顿,矫正,净化,修正,改正,校正;v:修正,整流,调整,净化,校正",
"rectifier":"n:整流器,整流,检波器,解调器",
"rectify":"v:调整,纠正,正,改正,纠,端正,矫正,整顿,匡正,检波,更正,厘,提纯,整流,订正,矫,匡,整,整饬,改,校正",
"rectifying":"v:检波,整流",
"rectitude":"n:正直,公正,诚实,正确,笔直;a:笔直",
"recto":"n:封一",
"rector":"n:校长",
"rectum":"n:直肠",
"recuperate":"v:恢复,疗养,休养,养病,回收,起色,痊愈,调理,调养,将息,复原,将养,缓,疗",
"recuperation":"n:反馈,弥补,复原,起色,回收,痊愈,恢复,挽回;v:复原,回收",
"recur":"v:复发,重演,回想,回到,想起,循环,翻来覆去,递归",
"recurred":"v:治愈",
"recurrence":"n:复发,递归,反复;v:循环,返回",
"recurrent fever":"n:回归热",
"recurring":"v:再现",
"recursion":"n:递归,循环;v:循环",
"recycle":"v:改建,整修",
"red":"n:红,红色,亏空,赤字,共产党;a:红不棱登",
"red blood cell":"n:红血球",
"red clay":"n:红土",
"red cross":"n:红十字会,吗啡,十字军",
"red deer":"n:马鹿,水鹿",
"red fox":"n:赤狐,火狐",
"red guard":"n:红卫兵",
"red heat":"n:赤热",
"red indian":"n:印第安人",
"red ink":"n:损失",
"red porgy":"n:真鲷",
"red sandalwood":"n:红木",
"red sanders":"n:红木",
"red sea":"n:红海",
"red spider":"n:红蜘蛛,麦蜘蛛",
"red tape":"n:繁文缛节",
"red tide":"n:红潮",
"red water":"n:红潮,血尿",
"red-eye":"n:夜班",
"red-hot":"a:炽燥",
"red-letter day":"n:节",
"redact":"v:拟订,编写,编纂,编辑",
"redaction":"n:编写,编辑,校订,改订",
"redbreast":"n:知更鸟",
"redcap":"n:红帽子,金翅雀,宪兵,搬运员,搬运工,魔鬼",
"redden":"v:脸红",
"reddish":"a:潮红,红不棱登,红殷殷",
"reddish brown":"n:栗色,棕红,赭色,赭",
"reddish orange":"n:橘红",
"redeem":"v:赎回,赎,取回,弥补,补救,履行,偿还,超度,拯救,挽回,赎买,恢复,还清,收回,缓冲",
"redemption":"n:赎回,履行;v:缓冲,兑换,兑现",
"redeploy":"v:调动,转移",
"redeployment":"n:转移",
"redirection":"n:折回,归还",
"redneck":"n:乡下人",
"redness":"n:红色,红",
"redolence":"n:芬芳,芳香",
"redouble":"v:加倍,倍增,加强,激增;d:加倍",
"redound":"v:促进,发生,抬高,增加",
"redress":"v:革除;n:善后",
"reduce":"v:减少,降低,削减,减小,缩小,减低,缩减,还原,减轻,压缩,简化,约,化为,提炼,压低,克服,降,精简,缩短,减,贬,杀,裁减,减杀,归并,裒,征服,煞,约分,节减,减缩,紧缩,精炼,弱化,裁,分解,减免",
"reducer":"n:减速器,还原剂,减压阀,减压器",
"reducing":"v:缩减,简化,降低,减低,还原;n:还原,减低",
"reducing agent":"n:还原剂",
"reduction":"n:降低,减少,还原,缩小,简化,压缩,减低,还原法,弱化,订正,提炼,陷落,缩减,整理,投降,约分;v:订正,缩小,减低,降低,还原,衰减,简化,压缩,缩减",
"reduction gear":"n:减速器",
"reductive":"a:还原剂",
"redundancy":"n:冗余,多余,冗词赘句;v:过剩",
"redundant":"a:冗,衍,冗词赘句,赘",
"reduplicate":"v:重复",
"reduplication":"n:加倍,重叠,重复;v:重叠",
"redwood":"n:红树,红杉",
"reed":"n:芦苇,簧片,苇,簧,芦,苇丛,筘,牧笛,杼,箭,衔铁,萑,苇子",
"reed pipe":"n:胡笳",
"reef":"n:暗礁,礁石,礁;v:收缩",
"reef knot":"n:死结",
"reefer":"n:冷藏船,冰箱,冷藏室",
"reek":"n:臭气;v:冒烟",
"reel":"v:摇摇晃晃,摇摆,眩晕,摇动,桄,纺;n:眩晕,卷轴,摇摆,卷筒,纺车,线轴",
"reelect":"v:改选",
"reeling":"v:头晕眼花,缫丝",
"reentry":"n:重返",
"reequip":"v:改装",
"reestablish":"v:重建",
"reestablishment":"v:重建",
"reeve":"v:穿,穿过",
"reexamine":"v:复审,复查",
"refashion":"v:毁,改制,改变",
"refection":"n:消遣,茶点,休养,饮食",
"refectory":"n:食堂,饭厅",
"refer":"v:提到,涉及,提交,提,参考,参阅,参看,引用,查阅,委托,认为,属于,打听,借助,参见,翻阅,交付,指点,查看,谈及,指示,引证,参照,付托,见于,参,见",
"referee":"n:裁判,裁判员",
"reference":"n:参考,基准,提到,证明书,提及,依据,引证,委托,出处,介绍人,咨询,鉴定书,关系;v:引证,参考,交付",
"reference book":"n:参考书,工具书",
"reference frame":"n:参考系",
"reference point":"n:控制点,控制符",
"referendum":"n:投票",
"referential":"a:参考系",
"referral":"n:介绍,提名,指示,指引",
"refill":"n:笔芯",
"refine":"v:提炼,改进,推敲,锤炼,精益求精,改善,精制,炼,澄清,精炼,斟酌,提纯,琢磨,炼制,美化",
"refined":"a:文雅,风雅,精;v:脱俗",
"refinement":"n:优雅,提炼,高尚,精密,精致,纯净,精制,精炼,改善,净化,精制品,提纯,微妙,大雅,精美;v:精制,提纯",
"refinery":"n:炼油厂",
"refining":"v:精炼,精练;n:精炼;a:精练",
"refinishing":"v:精制",
"refit":"v:整修,改装;n:整修,改装",
"reflect":"v:反映,反射,考虑,带来,思考,反应,回想,体现,映,弹回,非难,照,表现,辉映,招致,博得,转移,反响,反照,返照,诽谤,中伤",
"reflectance":"n:反射率,反射",
"reflection":"n:反射,反省,反映,影子,翻转,影像,弹回,倒影,丢脸,影,耻辱,感怀,非难;v:反射",
"reflections":"n:感想;v:感怀",
"reflectivity":"n:反射率",
"reflector":"n:反射镜,反射面,反光镜,反射层,回光镜",
"reflex":"n:反映,影像,倒影,显现;v:回复,反映,反射",
"reflexion":"n:反射",
"reflux":"n:回流,退潮,倒流",
"reform":"v:改革,改造,改过自新,改良;n:改进,改正,悔改,维新",
"reformation":"n:改革,改造,修正;v:革新,改革,修正",
"reforming":"v:变换,整形",
"reformist":"n:改良派",
"reformists":"n:改良派",
"reformulate":"v:修订,改订",
"refract":"v:折射,分析",
"refracting":"n:折射;v:折射",
"refraction":"n:折射",
"refractory":"n:耐火材料;a:耐火",
"refrain":"v:自制,抑制,避开,戒除,忍,避免,制止",
"refresh":"v:恢复,翻新",
"refreshed":"a:爽快;v:爽快",
"refresher":"n:食物,饮料,复习,酒;v:复习",
"refreshing":"a:清爽;v:沁人心脾,清香",
"refreshingly":"d:爽口",
"refreshment":"n:点心,心旷神怡,振作,提神,饮食",
"refreshments":"n:茶点,小吃",
"refrigerant":"n:冷冻剂,清凉剂,冷却剂",
"refrigerate":"v:冷藏,冷冻,解热,冰镇",
"refrigeration":"v:制冷,冷却,冷冻,冷藏;n:冰冻,冷冻",
"refrigerator":"n:冰箱,电冰箱,制冷机,冷冻机,冷藏库,冷冻箱",
"refrigerator car":"n:冷藏车",
"refuel":"v:加油",
"refuge":"n:避难所,避难,庇护;v:躲避,避难,庇护",
"refugee":"n:难民,逃亡者,流民",
"refulgence":"n:辉煌,光辉,灿烂",
"refund":"v:归还;n:归还",
"refurbish":"v:刷新,翻新,整修",
"refusal":"n:拒绝,谢绝",
"refuse":"v:拒绝,拒,却,不予;n:糟粕,秽土,渣滓,废料",
"refutation":"n:反驳;v:反驳",
"refute":"v:驳斥,驳倒,驳,批驳,辩驳,辟,抗辩,置辩,驳难;n:团",
"regain":"v:恢复,收回,收复,回到;n:收回,收复,恢复,回潮",
"regale":"v:款待,吃喝,欢娱;n:佳肴,盛宴;a:欢娱",
"regalia":"n:徽章,标记,勋章",
"regard":"n:关心;v:顾虑",
"regard as":"v:当,当作,算,作,当做,看成,作为,看做,认为,把",
"regarding":"p:关于,对于,论",
"regardless":"a:不拘,不顾,不管;d:无论如何",
"regards":"n:敬意",
"regency":"n:政权,统治,摄政",
"regenerate":"v:再生,恢复,革新,更生,悔悟,回收,改造;a:更生",
"regeneration":"n:再生,新生,更生;v:更新,还原,再生;a:更生",
"regent":"n:学监,摄政王",
"regicide":"n:弑君",
"regime":"n:政权,状态,制度,统治,管理,方法,政柄,格律,政体,社会制度",
"regimen":"n:养生之道,政权,摄生,统治,支配,水情,政体",
"regiment":"n:团,支配,大量;v:编入",
"regimental":"a:军服",
"regimentation":"n:编制,类别,统治",
"region":"n:地区,区域,区,范围,地方,地带,层,域,邻近,地面,领域,区间,部位,局部,部,方,路,间隔,界,境,行政区,地域,地段",
"regionalism":"n:地方主义",
"register":"n:寄存器;v:对齐,注,登录,录",
"registrar":"n:记录员",
"registration":"n:登记,注册,记录,读数,签到,定位,对齐,挂号,报到,对准;v:对准",
"registry":"n:国籍,记录簿,登记,籍,注册处,登记簿,登记处,注册,记录",
"regress":"v:退化,倒退,复归;n:回顾,回归,退化,退步,退回",
"regression":"n:回归,复归;v:后退,退化",
"regression line":"n:回归线",
"regret":"v:遗憾,后悔,抱歉;n:痛惜;a:抱歉,遗憾",
"regretful":"a:遗憾,懊,不过意",
"regular":"a:规则,固定,定期,正规,正式,一定,正常,端正,正,板正,整齐,均匀,周正,健全,专任;n:修道士,例,班;d:完全,非常;p:经",
"regular army":"n:正规军",
"regular polygon":"n:正多角形",
"regular polyhedron":"n:正多面体",
"regularity":"n:规律性,定期,经常性,经常,匀称,整齐,正规,调和,规格",
"regularization":"n:整理,正规化,合法化,调整;v:正规化",
"regularize":"v:调整,整理,固定",
"regularly":"d:经常",
"regulate":"v:控制,调节,管理,规定,调整,厘,调剂,检束,对准,校准,管制,治,整顿",
"regulation":"n:规则,规章,条例,调节,管理,控制,限制,节制;v:调整,管理,调节",
"regulations":"n:规程,规章,条规,条例,例,清规,章程,清规戒律,守则,条令,章",
"regulator":"n:调节器,标准钟,标准,控制器,原则",
"regurgitate":"v:反刍,回流,翻胃,吐,反胃",
"regurgitation":"v:反胃,反刍;n:翻胃,反刍",
"rehabilitate":"v:重建,恢复,修理,复兴,复原,休养生息,平反,改善,善后,修复,昭雪",
"rehabilitation":"n:恢复,复原,康复,善后,平反,休养生息;v:复原,康复",
"rehash":"v:炒冷饭,改作;n:改作",
"rehear":"v:重审,复审,再审",
"rehearsal":"n:排练,详述,排演,复述,练习,背诵",
"rehearse":"v:排练,排演,练习,讲述,朗诵,列举,总计,背诵,详述,预演,排",
"reheat":"v:温",
"reich":"n:帝国,德国,国",
"reign":"v:统治,在位,当政;n:势力",
"reign of terror":"n:腥风血雨",
"reimburse":"v:补偿,赔偿,偿付,偿还,赔还,退款",
"rein":"v:控制,勒;n:统治,牵制",
"rein in":"v:勒",
"reincarnate":"v:投胎",
"reincarnation":"n:再生,转生,超生,化身,投胎",
"reindeer":"n:驯鹿,鹿",
"reindeer moss":"n:石蕊",
"reinforce":"v:增援,加强,增强,加固,补充,接应,求援,救应,充实,添加;n:援军",
"reinforced":"v:加料",
"reinforced concrete":"n:钢骨水泥",
"reinforcement":"n:增援,增强,援军,加固,支援,援兵,后援,构架",
"reinforcements":"n:生力军,后援,救兵,援军",
"reinforcing":"v:补足",
"reins":"n:腰部,激情,爱情,感情,肾脏",
"reinstate":"v:恢复,复原,修理,起用,修补",
"reinstatement":"n:复原",
"reinsurance":"n:分保,再保险",
"reintegrate":"v:恢复,重建,复兴",
"reinvigorate":"v:搞活",
"reissue":"v:补发,重排;n:改版",
"reiterate":"v:重申,反复",
"reiteration":"n:重申,重复,反复;v:重复",
"reject":"v:拒绝,否决,剔除,排斥,拒收;n:下脚料",
"rejection":"n:拒绝,否决,抛弃,否定,驳回,排除,闭塞,阻碍,截止,废弃,舍去,抵制,丢弃,拒收,衰减,退回;v:截止,衰减,拒收",
"rejects":"n:等外品",
"rejoice":"v:高兴,有,庆祝,欢乐,庆幸,快乐,欢呼,欢喜,欢庆,开心,享有,欢腾,幸",
"rejoicing":"n:庆祝,欢呼,高兴,喜悦,欢声,欢庆,欢喜",
"rejoin":"v:回答,重返,抗辩,答辩,答应,答复,重逢",
"rejoinder":"n:答辩,反驳,回答,回嘴",
"rejuvenate":"v:返老还童,再生,回春,翻身,复原,死灰复燃,复壮;n:返老还童",
"rejuvenation":"n:返老还童,更新,回春;v:回春,复壮",
"relapse":"v:故态复萌,沉陷,堕落,回复,复发,退步,恶化;n:复旧,退步",
"relapsing fever":"n:回归热",
"relate":"v:联系,讲述,涉及,讲,关联,叙述,符合,追叙,诉说,叙,述,关乎,诉;n:叙",
"related":"v:连带",
"relation":"n:关系,亲戚,联系,关系式,亲属,叙述,讲述,故事,告发,比率;v:讲述",
"relationship":"n:关系,联系,关系式,亲缘,交,义,亲戚",
"relative":"n:亲戚,亲属,亲人;a:亲;p:关于",
"relative humidity":"n:相对湿度",
"relatively":"d:相对,较,比较,较比,相互",
"relatives":"n:党,亲戚,亲属,六亲",
"relativism":"n:相对主义,相对论,相对性",
"relativity":"n:相对论,相对性,相关",
"relativity theory":"n:相对论",
"relax":"v:放松,松弛,松懈,缓和,休息,松驰,弛缓,放宽,松,松快,和缓,缓解,松散,削弱,宽绰,休养,减少,娱乐;a:弛缓,宽绰,弛懈,和缓,宽",
"relaxation":"n:缓和,放松,松弛,松驰,舒张,休息,解闷,弛缓,娱乐,削弱,宽舒,松懈,放宽,减轻,衰弱,休养;v:削弱;a:弛缓",
"relaxed":"a:轻松,松快,轻,松动,缓,宽心,清爽,轻快,松散",
"relay":"n:继电器;v:转播,传达,接替,转发,中继,接力,替班",
"relaying":"v:中继;a:中继",
"release":"n:释放;v:发布",
"releasing":"v:脱扣",
"relegate":"v:委托,贬谪,丢弃,谪,贬,谴,贬黜,束之高阁,指示,驱逐,移交,充军,降职",
"relegation":"n:贬黜,移交,归属,降职,委托,驱逐,充军",
"relent":"v:缓和,发慈悲,松口,心平气和,转租",
"relentless":"a:毫不留情,恶狠狠,狠",
"relevance":"n:关系,贴切,中肯,关联,相关",
"relevancy":"n:关联",
"relevant":"v:相应,相关;a:贴题",
"reliability":"n:可靠性,安全性,确实,守信用",
"reliable":"a:可靠,靠得住,确切,稳当,牢靠,牢稳,确实,稳妥,准,确,忠实,可信,妥靠,稳,信实",
"reliably":"d:确",
"reliance":"n:信赖,信任;v:信任",
"relic":"n:遗物,残余,遗风,遗迹,遗念,遗俗,故迹,纪念物",
"relics":"n:陈迹,废墟,遗骸,遗址",
"relict":"n:寡妇,残余,遗孀",
"relief":"n:救济,减轻,起伏,安慰,缓解,地形,地势,救援,援救,释放,地貌,慰藉,安心,卸载,救济品,救助,解围,替班,显著;v:替班,释放,援救,换班",
"relief printing":"n:铅印",
"relief valve":"n:安全阀",
"relieve":"v:减轻,解除,缓解,缓和,宽,周济,免除,救济,减少,接班,纾,换防,济,接防;a:宽,宽绰",
"relieve oneself":"v:解,大小便,便,净手",
"relieved":"a:宽心,清爽,放心",
"relieving":"v:显露",
"religion":"n:宗教,信仰,教;v:教",
"religious":"n:修士,修女",
"religious leader":"n:教主",
"relinquish":"v:放弃,捐,停止,让出,作罢,废除,捐弃,放松,撤回,放开",
"relish":"n:味,佐料,滋味,劲,美味;v:品味",
"relive":"v:苏醒,再生,复活",
"relocate":"v:搬迁",
"reluctance":"n:不愿,勉强,嫌厌",
"reluctant":"a:不愿",
"reluctantly":"d:勉强",
"rely":"v:依靠,依赖,信赖,赖,信任,挟,仰赖,倚赖,倚仗,依托,倚,有赖于,仗恃,仰,赖以,依傍,聊",
"rely on":"v:凭,凭借,仰赖,依托,倚,冯,挟,仗恃,负,据,赖以,仰,依,仗,指,靠,聊,信赖,依傍,怙,赖,倚靠,倚仗,托,有赖于",
"rely upon":"v:依靠,信赖",
"remain":"v:在,仍,保持,留,依然,剩,剩下,停,留下,有待,停留,残留,搁置,遗留,逗留,残存,留存,余,遗址,归于,现存,留成,剩余;n:化石,遗迹,遗体,遗址,遗风,遗物,遗嘱,余额",
"remain firm":"v:岿然不动",
"remainder":"n:余数,剩余,余额,残余,废墟,遗物;v:余存,余剩",
"remaining":"v:残存,余下;a:余,残",
"remains":"n:遗体,遗骸,残骸,残余,遗迹,遗物,尸体,头,遗骨,遗容,尸身",
"remake":"v:改造,改作,翻新,修改;n:翻新,改造,修改",
"remand":"v:检查,检阅,召回,送还;n:召回,退押",
"remark":"n:话;v:议论,表示,留意,陈述",
"remarkable":"a:显著,杰出,出色,卓越,不同凡响,了不得,漂亮,殊,炳,卓异,倬;v:不同凡响",
"remarks":"n:用语,备注",
"remarriage":"n:再嫁,再婚;v:再婚",
"remarry":"v:复婚,再婚,再嫁,后续,转嫁,续弦,走步,改嫁",
"rematch":"n:复赛",
"remediation":"n:辅导,补习,补救",
"remedy":"v:纠正,挽救;n:公差,纠正",
"remember":"v:记得,记住,记,想起,回忆,记忆,问候,牢记,致意,追想,记取,谂,识,忆及,追",
"remembrance":"n:纪念,回忆,纪念品,记忆,回想,问候,追忆,记忆力,纪念碑,致意,耳性",
"remind":"v:提醒,指出,打招呼",
"reminder":"n:通知,提示,信号",
"reminisce":"v:话旧,追怀,追,追想",
"reminiscence":"n:回忆,回忆录,记忆力,追忆;v:回忆",
"remiss":"a:粗心大意;v:怠",
"remission":"n:缓解,汇款,延期,平息,宽恕,减轻,免除,松弛,减退,交付,缓和",
"remissness":"n:疏失",
"remit":"v:免除,汇款,豁免,汇,释放,宽恕,减轻,延期,展期,和缓,付款,放弃,付,缓和,汇寄,开发,送交,停止,汇兑,豁,减退",
"remittance":"n:汇款,汇兑,支付,开发",
"remnant":"n:残余,零头,残存,残部,剩,剩余,遗迹,底子,余烬,残,头,尾,遗风,幸存者;a:残",
"remnants":"n:残余",
"remodel":"v:改造,重建,装修,改编,改作,改变",
"remold":"v:改造",
"remonstrance":"n:劝告,规劝,抗议,责备,抗辩,规谏,忠告",
"remonstrate":"v:抗议,规劝,责备",
"remonstration":"n:抗议",
"remorse":"n:悔恨,后悔,疚,沉痛,自责,同情心,怜悯,痛悔,慈悲",
"remorseful":"a:懊,愧恨",
"remote":"a:远程,遥远,偏僻,远,偏远,久远,边远,远距离,悠悠,辽远,悠远,迢迢",
"remoteness":"n:偏僻,远离",
"remotest":"d:太;a:太",
"remould":"v:改型",
"remount":"v:回到,回溯",
"removal":"n:除去,迁移,切除,移动,排除,去掉,杀害;v:移动,转移,移植",
"remove":"v:除去,消除,去掉,去,清除,除掉,排除,搬走,摘除,取消,除,脱掉,撤职,拿走,迁移,移,搬,解除,起,收拾,消失,搬家,拆卸,撤除;n:间隔,移动,阶段",
"remover":"n:搬运工",
"remunerate":"v:报酬,酬报,酬劳",
"remuneration":"n:酬金,工资,待遇,补偿,报酬,赔偿,酬劳",
"renaissance":"n:文艺复兴,复兴,复活,新生",
"renal calculus":"n:肾结石",
"rename":"v:改名",
"renascence":"n:复活,再生,复兴,更生",
"rend":"v:割裂,响彻,劈开,裂开,撕裂,分裂,撕碎",
"render":"v:翻译,演奏,表现,给予,使得,归还,表示,打底,放出,粉刷,反映,放松,报答,炼,抹灰,提出,放弃,交付,交纳,提取,托付,移交,描写,让出,反响,让给,演出,致使;n:打底,粉刷",
"rendering":"n:演奏,翻译,描绘,抹灰,提炼,译文,打底,译本;v:粉刷,炼油",
"rendezvous":"v:集合,聚会,会见,聚集,相遇;n:集合",
"rending":"v:断裂,裂开",
"rendition":"n:再现,给予,施行,翻译,放弃,演奏;v:给予,复制,引渡",
"renegade":"v:背叛,变节;n:叛匪",
"renege":"v:背信,拒绝,违约,否认,食言",
"renew":"v:恢复,新,继续,展期,续借,更新,更换,补充,更生,更新换代,换取,重建,更改;a:新,更生",
"renewal":"n:恢复,延期,更新,展期;v:复原,更新,修补,更换",
"renminbi":"n:人民币",
"renounce":"v:放弃,背弃,抛弃,弃权,摒除,否认",
"renouncement":"n:放弃,否认",
"renovate":"v:整修,修复,更新,修缮,革新,刷新,整治,整,改善,修理,修补,翻新,恢复,修葺,翻改",
"renovation":"n:翻新,更新,革新,修补;v:革新,翻新,回复,修复",
"renown":"n:名望,声威,声誉,威名,传闻,名人,声望,传说,名声",
"renowned":"a:著名,闻名;v:驰名,闻名",
"rent":"n:分裂,谷,断口,裂缝,租子,裂隙,分歧,实物地租,峡谷,租价;v:租借,佃",
"rent out":"v:出租,租",
"rental":"n:租金,租钱,收入",
"renter":"n:出租人,佃户,承租人,房客,租户",
"renunciation":"n:放弃,自制,拒绝,废弃,出家,断念,否认,弃权,抛弃",
"reoccupy":"v:收复",
"reorganization":"v:改组,改编;n:改组,改编",
"reorganize":"v:改组,整,改造,改编,整编,整备,整顿,整理,改革",
"reorientation":"n:改变",
"rep":"n:名气,名声,代表,名誉",
"repack":"v:改装",
"repackage":"v:改装",
"repair":"v:修理,修,去,修好,修复,修缮,修补;n:依靠,矫正,赔偿,订正,依赖,补偿",
"repair shop":"n:修理厂,机修厂",
"repairman":"n:修理工",
"reparation":"n:赔偿,补偿,修补;v:赔偿,弥补,修补",
"reparations":"n:赔款",
"repartition":"v:分配,分割,划分;n:划分,分配",
"repast":"n:饮食,饭菜,膳食,食物,饭;v:就餐,设宴",
"repatriate":"v:遣返,回国,遣送",
"repatriation":"n:遣返",
"repay":"v:还,偿还,报答,回报,报复,报,报偿,偿,回敬,酢,酬报,酬",
"repayment":"n:偿还,偿",
"repeal":"v:取消,废除,撤消,作废,撤回,召回,撤销;n:废除,取消,撤销,撤回,作废",
"repeat":"v:重复,反复,背诵,复述,重演;n:复制,再说,重播,拷贝",
"repeatability":"n:重复性",
"repeated":"a:累,频仍",
"repeatedly":"d:一再,反复,多次,屡次,再三,亟,接二连三,屡屡;a:两次三番",
"repeater":"n:循环小数,惯犯,围盘,中继器",
"repeating":"a:中继;v:中继",
"repel":"v:排斥,拒绝,击退,抵制,推却,抵抗,弹回,反驳,斥,拒",
"repellent":"n:驱虫剂,防水布",
"repelling":"v:挡板;n:挡板",
"repent":"v:后悔,忏悔,悔恨,悔改,悔悟,追悔;n:后悔",
"repentance":"n:后悔,悔改,悔悟;v:悔改",
"repentant":"a:遗憾",
"repercussion":"n:影响,余波,反响,击退,返回;v:弹回",
"repercussions":"n:余波",
"repertoire":"n:清单,剧目,目录",
"repertory":"n:库存,目录,宝库,索引,积贮,搜集,仓库,保留剧目,贮藏",
"repetition":"n:重复,反复,背诵,拷贝,重读,留级;v:重复",
"repetitiveness":"n:重复性",
"repine":"v:不满,发牢骚,向往",
"replace":"v:代替,取代,替代,替换,更换,撤换,更,接替,接任,置换,还,更新,赔偿,倒换,顶替,替,代换,更替,换位,倒替,交替,替补,调换,送还;d:更",
"replaceable":"a:移位,置换,归还,交代,替换,替代,代换",
"replacement":"n:取代,更换,置换,替换,交代,替代;v:替代,置换,交代,更换",
"replacing":"v:复位,代换,置换",
"replant":"v:移植,补种,再植",
"replay":"v:重演,重播;n:重演",
"replenish":"v:补充,装满,填,添补,追加,充实,加强",
"replenishment":"n:补充,充实,补给,供给,充满",
"repletion":"n:充分,充满,满足,充实",
"replica":"n:复制品,拷贝,复印,反复,摹本",
"replicate":"v:复制,重复",
"replication":"n:复制,重复,复印;v:复制,重复",
"reply":"v:回答;n:反响,报复",
"report":"v:报告,报道;n:炮声,速记,意见书,名气",
"report card":"n:成绩单",
"reportage":"n:报告文学,报道",
"reportedly":"d:据报道",
"reporter":"n:记者,通讯员,指示器",
"repose":"n:长逝;v:长逝,信赖,基于,休憩,倚靠",
"repose on":"v:安睡,基于",
"reposition":"n:贮存,安置,保藏,保存;v:换位",
"repository":"n:仓库,宝库,容器,心腹,墓室,店铺,博物馆,知识库",
"repossess":"v:取回",
"repossession":"n:取回",
"reprehend":"v:申斥,责难,指摘,非难,谴责",
"reprehension":"n:非难,谴责,指摘,申斥",
"represent":"v:代表,表示,表现,描述,象征,扮演,描写,代理,描画,上演,意味,比拟",
"representation":"n:表示,代表,抗议,模型,陈述,表达式,表象,建议,代理,画像,演出;v:再现",
"representative":"n:代表,议员,典型,继承人;a:典型",
"representativeness":"n:代表性,典型性",
"repress":"v:镇压,压抑,抑制,制止,压制,压迫,抑,约束",
"repression":"n:阻遏,镇压,压制,抑制,制止;v:阻遏",
"reprieve":"n:缓刑,暂缓;v:缓刑,暂缓",
"reprimand":"v:斥责,训斥,谴责;n:惩戒",
"reprint":"v:重印,转载,再版,翻本;n:翻版,再版,单行本",
"reprisal":"n:报复,赔款",
"reprise":"v:重复,重演",
"reprises":"n:租金",
"reproach":"v:责备;n:污辱",
"reprobate":"v:谴责,非难,痛斥,拒绝,罚;n:恶棍",
"reprocess":"v:再生,回收",
"reproduce":"v:繁殖,复制,再现,重现,生殖,转载,传种,仿造,孳,演示,复写,再版,再生产,增殖,翻印",
"reproducer":"n:扬声器",
"reproduction":"n:繁殖,复制,复制品,生殖,再现;v:再现,生殖,再生产,复制,放映,复写",
"reproductive organ":"n:生殖器",
"reprogram":"v:改编",
"reproof":"n:谴责,责备,责骂",
"reprove":"v:责备,训斥,数落,指斥,谴责,责骂,责,斥骂",
"reptile":"n:爬行动物,爬虫",
"reptilian":"a:爬虫;n:爬行动物",
"republic":"n:共和国,共和,国家",
"republic of china":"n:中华民国",
"republican":"n:共和党",
"republican party":"n:共和党",
"republicanism":"n:共和",
"republication":"n:重版,再版",
"republish":"v:重版",
"repudiate":"v:拒绝,遗弃,否认,否定,推倒,批判,辟,推翻,驳斥,驳倒,拒付,赖",
"repudiation":"n:批判,拒绝,拒付,推翻,驳斥,撤销;v:撤销,拒付",
"repugnance":"n:厌恶,冲突,憎恶",
"repugnant":"a:反感,讨厌;v:讨厌",
"repulse":"v:拒绝,击退,驳倒,挫败,反击,击败,谢绝,却,排斥,推开;n:反击",
"repulsion":"n:排斥,斥力,厌恶,反驳,嫌恶,拒绝,反击,消散",
"repulsive":"a:丑恶",
"repulsive force":"n:斥力,推斥力",
"reputation":"n:名声,名誉,声誉,声望,信誉,名气,声名,名,名望;v:闻",
"repute":"v:看做,名誉,称为,评价,闻;n:名声,信用,名誉,名望",
"reputedly":"d:据说",
"request":"v:要求,请求,请,恳请,求;n:需要;a:烦",
"requiem":"n:安魂曲,挽歌",
"require":"v:需要,要求,需,命令,责,请求",
"requirement":"n:要求,需要,需求,条件,需要量,规格,资格,必需品,必要条件",
"requirements":"n:口径",
"requisite":"n:要素,必需品,要件;a:必要",
"requisition":"n:需要,要求,通知书,必要条件,命令,征调,征发,索取;v:征用,要求,征购,召集,征调",
"requital":"n:罚,报酬,还礼,复仇,报答,补偿",
"requite":"v:回报,报,报酬,报答,还礼,偿,酬谢,补偿,酬报",
"reread":"v:重读",
"rerecording":"v:配音,转录",
"rerun":"v:重复",
"res":"n:事件,事,物件,实体",
"resale":"n:转卖",
"rescind":"v:撤消,废除,撤销,解除,退,删除,作废,取消",
"rescission":"n:废除,解除,取消,撤销,解约;v:撤销",
"rescue":"v:救,抢救;n:援救",
"rescuer":"n:救兵,救星",
"research":"v:研究;n:调查,探测,追究",
"researcher":"n:研究者,研究员,研修生",
"reseau":"n:网格",
"reseed":"v:补种",
"resell":"v:转卖,转手",
"resemblance":"n:相似,像,神似,肖像,样子,外观,外表,外形",
"resemble":"v:像,类似,相似,象,宛如,相像,肖,摹写,仿;a:相似,相像;n:类",
"resent":"v:憎恨,愤恨,怨望,恼恨,望",
"resentful":"a:不满,愤懑,不平,反感,悻然,冯,悻悻",
"resentment":"n:怨恨,愤慨,愤怒,憎恨,怨气,愤,怨望,怼,恩怨,嫌,嫌怨;v:怨尤,怨恨,怨艾,怨",
"reserpine":"n:利血平",
"reservation":"n:保留,预订,预定,但书,限制,条件,先决条件,预约,声名",
"reserve":"n:储备;v:贮藏;a:后备",
"reserve fund":"n:公积金",
"reserved":"a:矜持,含蓄,拘谨;v:不苟言笑,沉默寡言",
"reserves":"n:后备军,储藏量,储量",
"reservoir":"n:水库,容器,油箱,贮藏,水槽,蓄积;v:贮藏",
"reset":"v:复位,复原,清除,重排,转接,移栽",
"resetting":"v:还原,复位",
"reshape":"v:改造",
"reshaping":"v:整形",
"reshipment":"n:转载",
"reshuffle":"v:改组",
"reshuffling":"v:改组",
"reside":"v:属于,住,居住,存在,居,住家,住居,居留,归于,寓",
"residence":"n:住宅,居住,住所,落,寓所,宅,住家,窝巢,宅子,宅邸,居所,寓,居,留存,住处;v:落",
"residency":"n:居住",
"resident":"n:居民;a:常驻",
"residential area":"n:居民区,住宅区,居民点",
"residential district":"n:街道",
"residual":"n:上演税,残渣,后遗症;a:残留,剩余;v:残留",
"residuary":"a:剩余",
"residue":"n:残渣,余数,残余,剩余,渣,渣滓,余款,脚,木屑,废渣",
"residuum":"n:残渣,残余,副产品,剩余",
"resign":"v:辞职,辞去,放弃,退出,退职,委托,引退,离职,下台,听从,让出,隐退;n:辞去",
"resignation":"n:辞职,辞呈,服从,听从,听任,退职,断念,抛弃,忍受,让位",
"resilience":"n:弹性;v:弹回",
"resin":"n:树脂,松香,松脂",
"resist":"v:抵抗,抵制,抗拒,抗,抗击,阻止,反对,抵挡,抵御,反抗,阻碍,御,违背,敌对,击退,抗争;n:防腐剂,防染剂",
"resistance":"n:抵抗,阻力,电阻,反抗,电阻器,抗拒,敌对,抵御,阻抗;v:抵抗",
"resistant":"a:防腐剂",
"resisting":"v:抗拒",
"resisting arrest":"n:拒捕",
"resistivity":"n:电阻率,抵抗",
"resistor":"n:电阻,电阻器",
"resolute":"a:坚决,果断,毅,果;v:决绝",
"resolutely":"d:毅然,决然,狠狠,雷厉风行",
"resolution":"n:决议,决心,决定,分辨率,分辨,坚决,解决,分解,果断,清晰度,决断,离析,解答,归结,变形,转化,刚毅;v:分辨,解析",
"resolve":"v:决定,解决;n:决断,议决,铁",
"resolved":"a:坚决",
"resolvent":"n:溶剂",
"resolver":"n:分解器",
"resolving":"v:溶解,解析",
"resonance":"n:共振,共鸣,同步,调谐,谐振,反响;v:共鸣",
"resonant":"a:洪亮,响亮,嘹亮,豁亮",
"resonate":"v:共鸣,共振,回响;n:共振,共鸣",
"resonating":"v:调谐",
"resonator":"n:共鸣器,共振器",
"resort":"v:求助,诉诸,采用,玩弄,玩,倚靠,动用,会集;n:手段",
"resound":"v:回荡,回响,响彻,传遍,赞扬,传播,反响,共振,亮",
"resounding":"v:共振,回声,反响,亮;a:高亢,响亮,亮;n:反响,回声",
"resource":"n:资源,方法,物力,手段,消遣,能力,娱乐,机智,智谋,才略",
"resourceful":"a:机智,智",
"resourcefulness":"n:智谋",
"resources":"n:财力,资源,财源,利,家底",
"resow":"v:补种",
"respect":"n:方面;v:戴,奉,关心,敬;a:贵",
"respectability":"n:体面,礼仪,尊严,威望,习俗,可敬",
"respectable":"a:体面,可敬,尊贵,高尚,正经",
"respected":"a:可敬,尊贵;v:有头有脸",
"respectful":"a:恭敬,谨,穆,肃,寅;d:谨;v:肃然",
"respectfully":"d:肃然;v:敬",
"respectfulness":"n:敬意",
"respecting":"p:关于,鉴于,由于",
"respective":"a:各自",
"respectively":"d:分别,各自,各别",
"respiration":"v:呼吸;n:呼吸",
"respirator":"n:口罩,防毒面具",
"respiratory organ":"n:呼吸器官",
"respiratory system":"n:呼吸系统",
"respiratory tract":"n:呼吸道",
"respire":"v:呼吸,休息,生活",
"respite":"n:休息,休养,延期,缓刑;v:喘息,延期,缓期",
"resplendence":"n:辉煌,灿烂",
"resplendent":"a:华丽,华,靡丽;v:鲜艳夺目",
"respond":"v:反应,回答,响应,应,应答,答腔,应付,符合,答理,感应,唱和,履行,答,答应,一致,搭腔,报,搭理,负责;n:对称",
"respondent":"n:反射,应答,被告,反应;v:应答",
"response":"n:反应,响应,回答,特性,答复,回音,反响,感应,灵敏度;v:应答,回答,响应",
"responsibility":"n:责任,职责,事,责任感,负担,责任心,言责,干系,荷,责,可靠性",
"responsible":"a:负责",
"responsible for":"a:担负,负责",
"rest":"v:休息,靠;n:架,托",
"rest day":"n:假日",
"rest home":"v:休养院,休养所",
"rest house":"n:客栈,休养所,监狱",
"rest on":"n:有赖,依靠,依赖",
"restate":"v:重述,重申",
"restatement":"n:重述",
"restaurant":"n:餐馆,饭馆,饭店,餐厅,馆子,酒家,饭庄,菜馆",
"restful":"a:安生;v:安生",
"restitution":"n:赔偿,复职,归还,恢复,复原,偿还,解调",
"restless":"a:不安,躁;d:忽忽",
"restoration":"n:恢复,修复,复辟,复兴,痊愈,复原,归还,再造,复职,光复;v:复位,回复,复原,更新",
"restorative":"n:补药,补品;a:滋补",
"restoratives":"n:补药",
"restore":"v:恢复,修复,归还,重建,复兴,修补,修理,还原,复活,复辟,补正,复,复原,翻修,痊愈,整修,再造,复旧",
"restrain":"v:克制,约束,抑制,制止,限制,防止,收敛,束,抑,律,钤,制,敛,管束,捺,绳,收,辖制,抑遏,约,拘束,牵制,限定,戢,拘,束缚;n:克,束;a:拘束",
"restrained":"a:矜持",
"restraint":"n:克制,约束,限制,拘束,抑制,禁止,束缚,监禁;v:约束,制约,阻止,抑制;a:拘泥",
"restrict":"v:限制,拘束;a:拘束",
"restricted":"a:有限,管;v:限制性",
"restriction":"n:限制,限制性,约束,自制,樊篱,框框,拘束;v:约束",
"restrictive":"a:限制性",
"restroom":"n:厕",
"restructure":"v:调整,改组",
"result":"n:结果;v:导致",
"resultant":"n:结果,合力,生成物,后果,合成,组合,产物",
"results":"n:收获",
"resume":"v:继续,恢复;n:概要,履历表,概略",
"resumption":"n:取回,概要,收回,继续",
"resurgence":"n:苏醒,复活,中兴,复苏;v:复苏,复活,回潮",
"resurgent":"a:中兴,恢复,复兴;v:恢复",
"resurrect":"v:复活,复苏,复兴,死而复生",
"resurrection":"n:复活,复兴,恢复",
"resurvey":"v:复查;n:复查",
"resuscitate":"v:救活,复活,复苏,复兴",
"resuscitation":"n:复苏,复兴,复活,回生;v:复苏",
"retail":"v:零售,转述,传播;n:零售;d:零卖",
"retailer":"n:零售商,零售店",
"retain":"v:保留,保持,记住,维持,保有,拦蓄,维系,存,雇用,聘用",
"retainer":"n:仆从,随从,挡板,定位器,侍从,门客",
"retaining":"v:制动",
"retake":"v:克复",
"retaliate":"v:报复,回报,倒算,还击",
"retaliation":"n:报复,反击,倒算",
"retard":"v:延迟,妨碍,延缓,推迟,阻滞,阻止,减速,迟延,放慢,迟到,耽误,减缓;n:耽误,迟延,阻止,迟滞,妨碍",
"retardation":"n:阻碍,迟延,留级,推迟,阻滞,迟钝,迟滞,制动,延迟;v:制动",
"retarder":"n:减速器",
"retch":"v:干呕,反胃,呕吐,作呕,恶心",
"retell":"v:复述,重述,再说",
"retention":"n:保持,滞留,保留,记忆力,潴留,拘押,监禁;v:滞留",
"reticence":"n:保留,沉默,含蓄,缄默",
"reticent":"a:沉默,沉默寡言,默默无言,不苟言笑;v:沉默寡言",
"reticently":"d:默默无言",
"reticulation":"n:网状",
"reticulum":"n:蜂巢胃",
"retina":"n:视网膜,网膜",
"retinue":"n:左右,随员,侍从,扈,随从",
"retire":"v:退休,就寝,退居,撤退,退役,退隐,收回,离开,退职,离职,后退,辞退,告退,退却,离休;n:退隐",
"retired":"v:离休,退休",
"retirement":"n:退休,退职,退役;v:辞退",
"retirement pension":"n:退休金",
"retort":"n:反驳;v:反击",
"retouch":"v:修改,修饰,润色,润饰,描",
"retrace":"v:回溯,回想,折返,回顾,退回,回忆,折回;n:回程",
"retract":"v:缩回,撤消,食言,取消,收回,撤回,翻,收起",
"retraction":"n:撤回,取消,撤消,收回,缩回",
"retransmission":"v:转发",
"retransmit":"v:重播,转播",
"retread":"v:翻新",
"retreat":"v:撤退;n:默想,收容所",
"retrench":"v:紧缩,节省,缩减,俭约,减缩,精简,撙节,减少",
"retrenchment":"n:节约,缩减,紧缩,省略,删除;v:紧缩",
"retrial":"n:复审,再审;v:复审,再审",
"retribution":"n:报复,惩罚,报酬,报应,报,报答",
"retrieval":"n:检索,弥补,取回,挽回,修补,补偿;v:复原,检索,补救",
"retrieve":"v:检索,挽回,取回,恢复,回收,想起,追回,收复,收回,找回,补偿;n:恢复,找回,挽回",
"retro":"n:复旧,怀旧",
"retrofit":"v:翻新,改型",
"retrograde":"v:堕落,后退,退步,退化,逆行,倒退;a:后退",
"retrogress":"v:衰退,退步,退化,倒退",
"retrogression":"n:逆行,衰微,退化,退步,倒退,堕落,后退,衰退,消退;v:后退,减退,退化,衰退,倒退",
"retrospect":"n:回想;v:回顾,回想,追忆,追溯",
"retrospection":"n:回想,回顾,对证",
"retry":"v:重审,再审",
"return":"v:回来,回到,返回,回,恢复,再,还,还给,回答;n:回答,汇报;d:再",
"return ticket":"v:来回票",
"reunion":"n:团聚,团圆,和解,复合,聚会",
"reunite":"v:团聚,完聚",
"rev":"n:旋转;v:变速",
"revalue":"v:升值",
"revamp":"v:补钉,修补,翻新,改装,修改,修理,补缀,改制",
"reveal":"v:透露,显示,暴露,揭示,泄露,显露,揭露,露出,现,展现,给,披露,吐露,看,亮,展示,告诉,现出,表露,流露,点化,揭发,露,透漏,启示,走,默示,说穿,道破;n:窗框,显露",
"revel":"v:狂欢,沉迷,作乐,陶醉,狂喜;n:欢乐",
"revelation":"n:启示,透露,泄露,揭发,暴露,显示,默示,圣经",
"revelry":"n:狂欢;v:狂欢",
"revenge":"n:报复,报仇;v:报仇,报复",
"revenue":"n:收入,税收,总收入,岁入,收益,所得,钱粮",
"revenue stamp":"n:印花",
"reverberate":"v:回荡,回响,回音,反射,弹回,反响;n:回响",
"reverberation":"n:回声,反响;v:反射",
"revere":"v:敬重,尊敬,尊,尊崇,钦仰,宠,敬畏,敬仰,敬慕,崇敬",
"reverence":"n:崇敬;v:崇敬,敬畏",
"reverend":"n:牧师;a:大师",
"reverent":"a:穆,恭,虔敬",
"reverie":"n:梦幻,沉思,遐想,白日梦,幻想,空想,妄想,梦想,幻想曲",
"revers":"n:翻领",
"reversal":"n:颠倒,反转,倒转,换向,逆转,撤消,反向,逆向,反复;v:反转",
"reverse":"v:倒置,掉换,推倒,倒退,翻转,换向,扭转,摧折,逆转,交换,可逆;n:逆向,反向,倒转,反对,背面,失败,左转,不幸,挫折,颠倒,倒刺;a:逆向",
"reversed":"v:颠倒,反;a:反",
"reversibility":"n:可逆性,可逆",
"reversible":"a:可逆,双面",
"reversing":"v:换向",
"reversion":"n:逆转,继承权,颠倒,复归;v:回潮,回复",
"revert":"v:回想,回复,恢复,归还,返回,复归,归属,复辟,继承,犯,还原;n:归属,继承",
"revetment":"n:驳岸,被覆,护坡",
"review":"v:回顾,复习,评论,检阅,复审;n:反省,习题,复审,回忆",
"reviewer":"n:评论员",
"revile":"v:诽谤,勾当,辱骂,诟骂,漫骂,唾骂,咒骂",
"revise":"v:修改,复习,改变,修订,校正,改编,修正,订正,删改,校阅,校订,改,订,温习;n:订正,校订",
"reviser":"n:检查员",
"revision":"n:修正,修改,修订,校对,修订本,复审,校订,订正,上诉,审校;v:校订",
"revisionism":"n:修正主义;v:修",
"revisit":"v:回到",
"revitalization":"n:新生",
"revitalize":"v:复兴,休养生息",
"revival":"n:复兴,复活,苏醒,苏,再生,更生",
"revive":"v:恢复,苏醒,复活,复兴,死灰复燃,振奋,复原,缓,死而复生,更新,苏,稣,还魂,再生,更生;a:更生",
"reviver":"n:酒,兴奋剂",
"revivification":"n:苏醒,再生,复原,还原,复活;v:还原,苏醒",
"reviving":"v:返青",
"revocation":"n:撤销,废除,取消,撤回,解除",
"revoke":"v:吊销,取消,废除,撤销,作废,撤消,解除,吊,收回;n:废弃",
"revolt":"v:反感;n:暴乱",
"revolting":"v:不堪入耳,令人作呕;a:不堪入耳",
"revolution":"n:革命,转,旋转,公转,运行,转速,回转,周转;v:旋转,公转,回转",
"revolutionary":"n:革命,革命家,红色;a:左,红",
"revolutionist":"n:革命者,革命家",
"revolutionize":"v:革新",
"revolve":"v:绕,旋转,转动,转,公转,围绕,运行,考虑,思索,运转,环绕,周转,旋绕,打转,运,循环,旋",
"revolve around":"v:旋绕,环绕",
"revolver":"n:左轮,转炉,转轮手枪",
"revue":"n:活报剧,滑稽剧",
"revulsion":"n:反感,突变,嫌恶,诱导;v:突变",
"reward":"n:奖金,劳金,劳务费,惩罚;v:奖",
"reword":"v:改写",
"rewrite":"v:改写,修改,改订",
"rex":"n:王",
"rhapsody":"n:狂想曲,狂热,狂喜",
"rhea":"n:苎麻",
"rhenium":"n:铼",
"rheostat":"n:变阻器",
"rhesus":"n:猕猴,狙",
"rhesus monkey":"n:猕猴",
"rhetoric":"n:修辞,辩才,修辞学,辞藻;a:花言巧语",
"rhetorical question":"n:反问",
"rheum":"n:感冒",
"rheumatic":"a:风湿痛",
"rheumatism":"n:风湿病,风湿痛,风湿,痹",
"rhine":"n:莱茵",
"rhinestone":"n:水晶",
"rhinitis":"n:鼻炎",
"rhino":"n:犀牛",
"rhinoceros":"n:犀牛,犀",
"rhizome":"n:根茎",
"rhodesia":"n:罗得西亚",
"rhodium":"n:铑",
"rhododendron":"n:杜鹃花",
"rhombus":"n:菱形",
"rhubarb":"n:大黄,争吵",
"rhyme":"n:诗,韵,韵脚;v:叠韵;a:压韵",
"rhymes":"n:词韵",
"rhythm":"n:节奏,节律,节拍,韵律,配合,抑扬,拍子,匀称,周期性,调和",
"rhythmical":"a:抑扬顿挫,有板有眼",
"rib":"n:肋骨,肋,肋条,少女;v:戏弄",
"ribaldry":"n:下流话,下流",
"ribbing":"n:垄,开玩笑,翅脉,田垄,挖苦;v:扩大",
"ribbon":"n:丝带,缎带,碎片,带,绶带,色带,飘带,带子,帽带,发条",
"riboflavin":"n:核黄素,维生素",
"ribs":"n:骨子,排骨",
"rice":"n:大米,米饭,米,水稻,稻子,稻,稻米,稻谷,白米",
"rice grass":"n:稻草",
"rice paper":"n:卷烟纸",
"rice weevil":"n:蛘",
"rich":"a:富,丰富,富有,有钱,肥沃,阔气,阔,富饶,浓郁,富足,丰盛,醇厚,肥美,殷实,充实,肥;v:腆,饶",
"rich man":"n:财主,阔佬,大款",
"rich people":"n:富民,富人",
"riches":"n:财富,丰富,钱财,财帛,钱",
"richness":"n:富有,富丽,财富",
"rickets":"n:佝偻病",
"rickety":"v:东倒西歪;a:东倒西歪",
"rickshaw":"n:胶皮,人力车,黄包车,洋车",
"rid":"v:摆脱,去掉,释放,免除,清扫,救,扫除",
"riddance":"n:除去,驱除,摆脱,去除",
"riddle":"v:穿孔,解谜,解;n:哑谜",
"riddling":"v:过筛",
"ride":"v:骑,骑马,坐,乘;n:乘坐",
"ride horseback":"v:骑马",
"rider":"n:骑士,接穗,马贼,武士,附笔,夹层,系,行商",
"ridge":"n:山脊,山梁,脊,山岭,屋脊,分水岭,岗,书脊,鼻梁,顶部,埂子,地塄,栋梁,波峰,上部,梁,垄,脊梁,山脉,沟,棱,岭,垄坎,脊背,岗子,山嘴,田埂;v:培土",
"ridgepole":"n:栋,栋梁,脊檩",
"ridging":"v:培土",
"ridicule":"v:嘲笑,揶揄,讥笑,取笑;n:笑话,笑柄,愚弄",
"ridiculous":"a:可笑,不成体统,好笑;v:不成体统",
"riding":"n:骑马;v:乘车",
"riding breeches":"n:马裤",
"riff":"n:涟漪,礁石",
"riffle":"n:涟漪,波纹,急流,沟槽,微波,成功,胜利;v:翻,流过",
"riffraff":"n:痞,流氓,痞子,群氓,废物,渣滓,地痞",
"rifle":"v:洗劫;n:来复线",
"rifle range":"n:靶场",
"rifleman":"n:步兵,枪手",
"rifling":"n:膛线",
"rift":"n:裂痕,裂谷,裂缝,断裂,分裂,罅隙;v:断裂,裂开",
"rift valley":"n:裂谷",
"rig":"n:钻塔;v:控制",
"rig up":"v:拼凑,囤积居奇",
"rigger":"n:脚手架,骗子",
"rigging":"n:衣服,机构,服装,设备,屋脊,装置;v:装配",
"right":"n:权利;v:改善,救济,竖立,拯救;d:很;a:真的;i:唉",
"right angle":"n:直角",
"right away":"v:当时,跟着,当儿,就",
"right field":"n:右翼",
"right hand":"n:右手",
"right of privacy":"p:隐私权",
"right of way":"n:主动权",
"right to life":"p:生存权",
"right to vote":"v:表决权",
"right wing":"n:右翼",
"right-hand man":"n:左右手,膀臂",
"righteous":"a:公正,正人君子;v:雅正;n:正义",
"righteousness":"n:正义",
"rightful":"a:合法,正当",
"rightists":"n:右派",
"rightly":"d:当然",
"rightness":"n:正确,公正,恰当,正直,无误,正义;v:适合",
"rights":"n:权限",
"rigid":"a:严格,僵,呆板,死,刚,硬性,生硬,机械,死板,板板六十四,死硬,划一不二,呆滞,硬挺,执著;v:划一不二,硬挺;d:刚",
"rigidify":"v:固定,僵化",
"rigidity":"n:刚性,刚度,顽固,刚直,坚硬,精密,严峻,僵直,严格,严厉;a:坚硬,僵直",
"rigmarole":"n:废话,梦呓,鬼话",
"rigor":"n:苛刻,寒冷,苛求,严寒,发冷,严厉,生硬,寒战,僵硬",
"rigorous":"a:严格,严,严谨,严峻,厉",
"rigour":"n:严格,困苦,严密;a:寒冷,生硬",
"rile":"v:激怒",
"rill":"n:溪流,沟纹,谷",
"rim":"n:边框,缘,边沿,海面,眼镜框,边;v:镶",
"rime":"n:树挂,雾凇,结晶,霜,韵律",
"rimless":"a:无边",
"rind":"n:皮子,外表,外层,外观,外皮,树皮,表面,果皮",
"ring":"n:戒指,环;v:登录,收下,鸣;a:卷绕",
"ring out":"v:响起",
"ring road":"n:环路",
"ring up":"v:登录,挂,收下",
"ringer":"n:电铃,骗子,铁环,成功",
"ringing":"a:清朗",
"ringleader":"n:头头儿,罪魁,罪魁祸首,头目",
"ringlet":"n:卷发",
"ringlike":"n:环状;a:环形",
"rings":"n:吊环",
"ringworm":"n:金钱癣,体癣,癣,癞癣",
"rink":"v:溜冰;n:溜冰场",
"rinse":"v:冲洗;n:清洗",
"rinsing":"n:冲洗,渣滓,残渣,漂洗;v:冲洗;a:水洗",
"rio de janeiro":"n:里约热内卢",
"riot":"n:骚乱,暴乱,暴动;v:挥霍,骚动,乱,防暴,暴动",
"rioter":"n:暴徒",
"rip":"v:撕开;n:激流,浪子,废物",
"rip up":"v:撕碎",
"rip-off":"n:偷窃,骗取",
"ripe":"a:成熟,熟",
"ripen":"v:成熟,长成,催熟",
"ripeness":"n:成熟",
"ripening":"a:成熟",
"riposte":"v:还击",
"ripper":"n:派性",
"ripping":"v:开裂",
"ripple":"v:荡漾,卷,漾,浮动;n:水波,波动",
"ripples":"n:涟漪",
"rippling":"v:涟漪;n:涟漪",
"rips":"n:涟漪",
"riptide":"n:激流",
"rise":"v:起来,升起,上涨;n:复活,苏醒,出头;a:高涨",
"rise up":"v:升起",
"risen":"v:涨,上升",
"risibility":"n:可笑",
"rising":"n:反抗,起义,上升,苏醒,出现,起床,起立,复活,高地,疙瘩,起来;v:蒸腾",
"rising tide":"n:涨潮",
"risk":"n:风险,危险;v:冒险;a:危险",
"risky":"a:险",
"rite":"n:仪式,惯例,礼仪,习惯,仪,典礼,礼",
"ritual":"n:仪式,典礼,式",
"rival":"v:比美,匹敌,竞争,抗衡,媲美,对抗,伦比;n:对手,敌手,竞争者",
"rivalry":"n:竞争,对抗,竞赛",
"rive":"v:分裂,扯裂,撕开,劈开,折断,裂开,撕裂,撕碎;n:碎片",
"river":"n:河,河流,水,江,江河,河面,河川,川",
"river boat":"n:江轮",
"riverbank":"n:河边",
"riverbed":"n:河床,河槽",
"rivers":"n:河流,江河,水流",
"riverside":"n:河边,浦,江干,河沿,河岸",
"rivet":"v:铆接,铆,加深;n:铆,铆钉",
"riveter":"n:铆工,铆钉枪,铆机",
"riveting":"v:铆接;n:铆工",
"rivulet":"n:小溪,溪,溪流",
"rna":"n:核糖核酸",
"roach":"n:蟑螂,蜚蠊,岩石",
"road":"n:路,道路,公路,马路,铁路,道,路途,车行道,干道,办法,街道,路程,手段,隧,涂,行程,方法,行车道,途径,路道,途,锚地,陌,途程;v:涂",
"road map":"n:路线图",
"road roller":"n:压路机",
"road show":"n:巡回演出",
"roadbed":"n:路基,路面,行车道,道床",
"roadblock":"n:路障,障碍,困难",
"roadhouse":"n:客店,客栈",
"roadside":"a:路边,路旁;n:路边",
"roadster":"n:马车夫,跑车,流浪者",
"roadway":"n:车行道,道路,路,铁路,车道,巷道",
"roam":"v:漫游,漫步,逛,闲逛,云游,浮游,流荡;n:漫游,闲逛,游荡,游历",
"roamer":"n:流民",
"roar":"v:吼,呼啸,吼叫,咆哮,怒吼;n:鼓噪",
"roaring":"n:咆哮,吼声,怒号;v:呼啸;a:兴旺",
"roast":"v:责备,炙,炒,焙烧,烧;n:烧肉,炒,焙烧,烘",
"roaster":"n:烤箱",
"rob":"v:抢劫,抢,盗,掠夺,打劫,抢夺,盗窃,劫掠,偷走,剽,盗劫,劫,掠,打家劫舍,盗掘,行劫",
"robber":"n:强盗,抢劫犯,盗贼,盗寇,强人,盗犯,暴客,响马",
"robbers":"n:盗贼,盗匪",
"robbery":"n:抢劫,盗窃,劫夺,盗案,抢夺",
"robe":"n:长袍,礼服,浴衣,衣服,袍子,罩袍,法衣,官服,袍,制服,衣柜;v:装扮,穿上",
"robe-de-chambre":"n:晨衣",
"robert":"n:罗伯特",
"robin":"n:知更鸟,歌鸲",
"robot":"n:机器人,机械手,机械人",
"robust":"a:强壮,健壮,结实,茁壮,雄健,壮,粗壮,壮实,矫健,奘;n:壮健",
"robustly":"d:强健",
"rock":"n:岩石,石头,礁石,岩,石块,暗礁;v:摇荡",
"rock crystal":"n:石英",
"rock dove":"n:野鸽",
"rock pigeon":"n:原鸽",
"rock salt":"n:石盐,氯化钠",
"rock-and-roll":"n:摇滚乐",
"rocker":"n:摇椅,振荡器",
"rockery":"n:假山",
"rocket":"n:火箭,火箭弹;v:猛涨",
"rocket launcher":"n:火箭筒",
"rocket scientist":"n:高人,能人",
"rocking":"a:摇摇晃晃",
"rocking chair":"n:摇椅",
"rocking horse":"n:木马",
"rocky":"v:头晕目眩;a:头晕目眩",
"rococo":"a:俗不可耐",
"rod":"n:杆,拉杆,连杆,魔杖,棍,体罚,竿,威力,棍子,枝条,棍棒,避雷针,枝,标尺,血统,子孙,手枪,推杆,杖",
"roe":"n:狍子,卵,鲕,狍,鱼子",
"roe deer":"n:獐",
"roebuck":"n:獐",
"roentgen":"n:伦琴,伦琴射线",
"roentgen ray":"n:爱克斯光",
"rogue":"n:流氓,恶棍,无赖,小淘气;v:流浪,欺诈,淘汰,行骗,游荡",
"roguery":"n:淘气,欺骗,捣鬼;v:行骗",
"roil":"v:搅乱,搅动",
"roister":"v:喧闹,摆架子",
"role":"n:作用,角色,责任,任务,角,正角儿,脚,男角",
"roll":"v:滚,卷,转动,滚滚,卷起,滚动;n:轧辊,鼓鼓囊囊,目录,团,滚滚,卷轴,旋转;a:鼓鼓囊囊;d:咕噜",
"roll call":"v:点名",
"roll down":"v:轧制",
"roll film":"v:胶卷",
"roll in":"v:卷进,蜂拥而上,纷至沓来",
"roll over":"v:滚动,折",
"roll up":"v:卷,蜷缩",
"rollback":"n:击退",
"roller":"n:滚筒,卷轴,压路机,辊,轴,转子,警察,辊子,磙子,碾子,轧辊,轴子,碾,碾盘,轧道机,磙,滑轮",
"roller bearing":"n:滚柱轴承",
"rollick":"n:说笑,高兴",
"rolling":"v:轧制,滚动,镇压,滚,轰鸣,压延,滚压;n:旋转,轧,轰鸣,轧制,滚动;a:滚滚",
"rolling mill":"n:轧钢厂",
"rolling pin":"n:擀面杖",
"rolling stock":"n:车辆",
"rollover":"n:翻转",
"roly-poly":"n:扳不倒儿",
"roma":"n:罗马",
"romaine lettuce":"n:生菜",
"roman":"n:拉丁语,天主教徒",
"roman numeral":"n:罗马数字",
"romance":"v:谈情说爱,妄想,吹牛;n:风月,浪漫史",
"romances":"n:稗官野史",
"romania":"n:罗马尼亚",
"romantic":"a:浪漫,罗曼蒂克",
"romanticism":"n:浪漫主义,虚构,传奇性,空想",
"romany":"n:吉普赛",
"rome":"n:古罗马",
"romp":"n:欢蹦乱跳,顽皮,顽童;v:调情",
"rompers":"n:背心",
"rood":"n:路德,十字架",
"roof":"n:屋顶,房顶,顶部,屋面,车顶,顶板,顶子,上颌,上颚,房屋,顶针;v:庇护",
"roofer":"n:屋主",
"roofing":"n:屋顶,屋面,覆盖",
"rooftop":"n:屋顶",
"rook":"n:车,骗子,军;v:诈骗,敲竹杠",
"rookery":"n:公寓",
"rookie":"n:新兵,新手",
"room":"n:房间,屋子,屋,房,地方,房子,室,空间,余地,间,机会,位置,堂,地位,场所,席位,余裕,房室;v:投宿,留住,住宿,寓居",
"room temperature":"n:室温",
"roomer":"n:房客",
"roomful":"n:满座",
"roominess":"n:广阔",
"roommate":"n:室友",
"roomy":"a:宽敞,宽阔,宽绰,宽大,庞大",
"roosevelt":"n:罗斯福",
"roost":"v:安歇,就座,过夜,投宿;n:鸡栅,床,卧室,鸡舍,鸡窝",
"rooster":"n:雄鸡,公鸡",
"root":"n:根,树根,根源,根本;v:铲除,欢呼,搜寻,除根,肃清,赞助,斩草除根,固定,声援",
"root for":"n:声援",
"root out":"v:铲除,肃清,斩草除根,除根",
"rooter":"n:挖土机",
"rooters":"n:拉拉队,啦啦队",
"rooting":"v:加固",
"rootstock":"n:根茎",
"rope":"n:绳子,绳索,绳,缆绳;v:笼络,引诱,拉扯",
"rope bridge":"n:索桥",
"rope in":"v:笼络,拉拢,拉扯",
"rosary":"n:念珠,玫瑰园",
"rose":"n:玫瑰,玫瑰花,蔷薇,愉快",
"rose bay":"n:夹竹桃",
"rose of sharon":"n:槿",
"rose water":"n:奉承话",
"rosebush":"n:蔷薇",
"rosette":"n:插座",
"rosewood":"n:红木,紫檀",
"rosin":"n:树脂,松香,松脂",
"rosiness":"n:玫瑰色",
"roster":"n:登记簿,花名册,名单,名册",
"rostrum":"n:主席台,讲坛,讲台,检阅台,嘴",
"rosy":"a:红润",
"rot":"v:腐烂;n:堕落",
"rota":"n:轮唱,轮班,值班",
"rotate":"v:旋转,转动,轮流,自转,转,轮作,轮换,循环,打转,轮回,轮转,转圈,交替,倒茬,轮替,倒换",
"rotation":"n:旋转,自转,轮流,轮作,公转,循环,轮换,交替,轮转;v:旋转,循环,回转",
"rote":"n:死记硬背,死记",
"rotor":"n:转子",
"rotten":"a:烂,腐败,腐朽,腐,腐臭,糟朽,烂乎乎,糜烂;v:糟,腐臭,朽",
"rotter":"n:贱骨头,无赖,废物",
"rotundity":"n:肥胖,圆形,洪亮,球状,华丽",
"rouble":"n:卢布",
"rouge":"n:胭脂,口红,唇膏,粉红,铁丹",
"rough":"a:粗糙,粗野,崎岖,粗鲁,粗略,粗,粗暴,毛,干;n:要略,大纲,村野,废料,梗概;v:搅乱,虐待,驯,敷设;d:粗,大概,约略",
"rough in":"v:敷设,草拟",
"rough-and-tumble":"n:战斗,混战",
"roughage":"n:原料,粗粮,粗饲料,素材",
"roughcast":"v:打底子",
"roughhouse":"v:大吵大闹",
"roughing":"v:粗加工",
"roughly":"d:大致,粗,大略,约摸,约莫;a:粗",
"roughneck":"n:暴徒",
"roughness":"n:粗糙,粗暴;v:近似",
"round":"v:环绕;n:轮,一系列,环,周期;d:周围;a:滚瓜溜圆;p:附近",
"round angle":"p:周角",
"round file":"p:圆锉",
"round of drinks":"n:巡",
"round off":"v:成功,煞尾,扫尾",
"round out":"v:成功",
"round robin":"n:轮转",
"round table":"n:圆桌会议",
"round the clock":"p:日夜,昼夜,夜以继日",
"round trip":"n:周游",
"round up":"v:综述,围捕,兜捕,兜抄",
"roundabout":"a:迂;n:迂回;v:迂回",
"roundabout way":"n:弯路",
"rounded":"a:圆形",
"roundel":"n:圆盘,环",
"roundelay":"n:回旋曲,小曲儿",
"rounder":"n:酒鬼",
"rounding":"v:舍去,四舍五入",
"roundly":"d:完全,充分,大略",
"roundness":"n:圆,率直,坦率,圆形,严厉,圆满,完整,丰富,球形,完满",
"roundup":"n:逮捕,围捕,综述,摘要,兜捕",
"roundworm":"n:蛔虫,圆形动物,蛔",
"rouse":"v:惊醒,叫醒,醒来,唤醒,激发,激励,唤起,奋起,愤激,抖擞,拨弄,鼓励,鼓,鼓舞,抖;n:奋起,觉醒,干杯",
"roused":"v:激昂;a:激昂",
"roust":"v:激动,驱逐,唤醒,鼓舞",
"rout":"n:溃败;v:搜,翻,唤起,打垮",
"route":"n:路线,路,航线,线路,通路,路径,路程,线,辙,航路,旅程,途,道,信道",
"routine":"n:程序,例行,例,常规,事务,例行公事,手续,惯例,家常便饭,定例,舞步;a:常务",
"rove":"v:环视;n:垫圈",
"rover":"n:海盗,流浪者,童子军",
"roving":"n:粗纱,粗纺;v:游",
"row":"n:行;v:溜,申斥,责骂,责备",
"rowboat":"n:划艇,划子",
"rowdy":"n:无赖",
"rowel":"n:齿轮",
"rowing":"n:划船,赛艇;v:赛艇",
"rowing boat":"n:划子",
"royal blue":"n:品蓝",
"royal court":"n:宫廷,王室,王朝",
"royal family":"n:王室,皇族",
"royal house":"n:王室",
"royal jelly":"n:蜂王浆,蜂王精",
"royalist":"n:保皇派",
"royalists":"n:保皇党",
"royalty":"n:版税,高贵,王位,上演税,庄严,王道,堂皇,王国,王族",
"rub":"v:擦,擦掉,摩擦,揉,磨;n:挖苦,障碍;a:困难",
"rub up":"v:擦亮,激起",
"rub-a-dub":"n:鼓声",
"rubber":"n:橡胶,橡皮,胶,皮,讥讽,挖苦,毛巾,不幸,阻碍,橡皮擦子,凶手,胶皮,困难,按摩师",
"rubber band":"n:猴皮筋,猴皮筋儿,橡皮圈",
"rubber boot":"n:胶靴,雨鞋",
"rubber plant":"n:橡胶树",
"rubber stamp":"n:橡皮图章",
"rubber tree":"n:橡树,橡",
"rubberneck":"v:游览;n:包打听",
"rubbers":"n:胶鞋,雨鞋",
"rubbing":"v:擦亮;n:拓片",
"rubbings":"n:拓片",
"rubbish":"n:垃圾,废话,废物,货色,秽土,脏土,屁话,狗屁;v:蔑视",
"rubble":"n:瓦砾,碎石,卵石,废料,石碴,碎砖",
"rubdown":"n:按摩",
"rube":"n:乡巴佬;a:土里土气",
"rubella":"n:风疹",
"rubicund":"a:红润",
"rubidium":"n:铷",
"ruble":"n:卢布",
"rubric":"n:标题,规程",
"ruby":"n:红宝石,宝石,鲜红色,血,嘴",
"ruby-red":"n:鲜红色",
"ruck":"n:废物,褶,皱,大量",
"rucksack":"n:背包",
"ruckus":"n:骚动,吵闹,吵嚷,乱动,喧闹",
"ruction":"n:骚动,吵闹",
"rudder":"n:方向舵,舵,船舵,指针,领导人;v:跺脚",
"ruddiness":"n:红色,红",
"ruddy":"d:非常,很;a:红润",
"rude":"a:伧,粗,愣;v:唐突",
"rudeness":"n:无礼",
"rudiment":"n:初步,基本,入门,基础;v:萌芽",
"rudimentary":"a:起码,基本,初,素朴,初等,低级",
"rue":"v:后悔,悔恨,驾驶,悲叹;n:芸香,后悔",
"rueful":"a:悲戚",
"ruffian":"n:恶棍,歹徒,流氓,光棍,亡命之徒,泼皮,青皮,痞子,痞,暴徒",
"ruffianly":"a:凶恶",
"ruffle":"v:发脾气,搅乱,激怒,生气,洗,着急,扰乱;n:波纹,激怒,微波,皱纹",
"rug":"n:地毯,毯子,毯,毡子",
"rugby":"n:橄榄球",
"rugged":"a:崎岖,粗犷,坎坷,嶙峋",
"ruggedness":"n:崎",
"ruin":"v:毁;n:灭亡,崩溃,祸害,败落,旧址,没落,瓦解,损失,祸,破坏",
"ruination":"n:没落,祸根,毁灭,毁坏,破产,灭亡",
"ruined":"a:残败;v:破败",
"ruins":"n:废墟,遗址,基址",
"rule":"n:规则,规定;v:宰,稳定",
"rule out":"v:排除,拒绝",
"ruler":"n:统治者,尺,尺子,直尺,辟,横线,后,元首",
"rules":"n:矩,条例,条规,规程,章,守则,规章,例,章程,章则",
"ruling":"n:判决,刻度,支配;v:裁决,裁定,划线",
"rum":"n:酒,甜酒",
"rumba":"n:伦巴",
"rumble":"v:隆隆;n:咕隆;d:咕噜",
"ruminant":"n:反刍动物",
"ruminate":"v:沉思,玩味,左思右想,咀嚼,寻味,反刍,深思,倒噍,倒嚼,默想",
"rumination":"n:默想,反刍,沉思,思索;v:反刍",
"rummage":"v:翻,翻腾,翻箱倒柜,搜查,检查,抄查;n:搜查,杂物,检查",
"rummy":"n:酒徒,无赖;a:古怪",
"rumor":"n:谣言,传闻,流言;v:谣传",
"rumored":"a:风",
"rumors":"n:谣诼",
"rumour":"n:传言,风传,道听途说,风声,风谣",
"rumoured":"v:风",
"rump":"n:屁股,臀尖,臀部,尾部,渣滓",
"rumple":"v:蓬乱,起皱",
"rumpus":"n:吵闹,喧嚷,口角",
"run":"v:跑,开,经营,奔跑,运行,跑步,运转,流,管理,行驶,走,撞;n:作业,打猎,倾向,事件;d:赶紧",
"run a risk":"v:出生入死",
"run across":"v:撞见,穿过,碰见",
"run around":"v:寻花问柳",
"run away":"v:脱逃,出奔,溜之乎也,亡,逃,逃窜,奔,跑,出走,奔逃,出逃,私奔,逃逸,脱缰,溜走,逃走",
"run down":"v:扫视,精疲力尽,追寻",
"run dry":"v:干枯,涸竭",
"run into":"v:碰到,碰,邂逅,遇到,丁,赶上,碰撞",
"run low":"v:缺乏",
"run off":"v:离题,偷走",
"run on":"v:继续",
"run out":"v:殆尽,耗尽,期满,欺瞒,完,流出,抽出,精疲力尽",
"run over":"v:浏览,轧,溢出",
"run short":"v:缺乏",
"run through":"v:贯穿,用尽,贯串",
"run up":"v:升起",
"run-down":"n:裁员;v:破败",
"run-in":"n:争吵,争论,口角",
"run-through":"n:贯通",
"run-up":"n:抬高",
"runabout":"n:游民,幼儿,流浪者,敞篷车,幼童",
"runaround":"n:躲闪,回避,逃避,藐视,借口",
"runaway":"n:私奔,逃亡者,亡命;a:失控;v:失控",
"rundown":"n:裁减",
"rune":"n:神秘",
"rung":"n:梯级,一级,棍子",
"rungs":"n:条",
"runnel":"n:水沟",
"runner":"n:秧鸡,交通员,使者,司机,推销员,滑道,转子,蔓,通讯员,叶轮,警察,收款员,走私者,巡捕,情报员",
"runner-up":"n:亚军",
"running":"n:管理;d:接连,一连;a:连续;v:工作",
"running hand":"n:草写,草体,行书,草书",
"running mate":"n:密友",
"runoff":"n:径流,决赛;v:溢出,流出",
"runway":"n:跑道,河槽,河道,轨道,滑道,斜坡",
"rupee":"n:卢比",
"rupiah":"n:卢比",
"rupture":"v:破裂;n:闹翻,裂缝",
"rural":"a:乡下人",
"rural area":"n:乡,乡村",
"ruse":"n:计,计策,谋略,骗术,阴谋诡计,诡计,局,花头",
"rush":"v:冲,赶,闯;n:猛进,抢购,突击,突破,急进,灯心草,莽撞,突进,殷勤",
"rushing":"v:滚",
"rusk":"n:面包干",
"russet":"n:黄褐色,土布,赤褐色",
"russia":"n:俄国,沙俄",
"russian":"n:俄文;a:俄语",
"russian olive":"n:沙枣",
"rust":"n:锈,锈病,铁锈;v:锈蚀,衰退,氧化",
"rustic":"a:土里土气;n:乡巴佬,乡间,庄稼人,村夫",
"rusticate":"v:勒令,下乡",
"rustication":"n:下乡",
"rusticity":"n:质朴,礼貌,朴实,朴素,撒野",
"rustiness":"n:荒疏,生锈,衰退,锈蚀;v:锈蚀,衰退,生锈",
"rusting":"v:生锈",
"rustle":"v:飒飒,刷,觅食;d:刷,簌簌",
"rustler":"n:活动分子",
"rusty":"a:生锈,生疏,荒疏;v:荒疏",
"rut":"n:车辙,沟,惯例,辙,成规,沟槽,轨辙;v:动情,发情",
"rutabaga":"n:大头菜",
"ruth":"n:同情,悔恨,怜悯",
"ruthenium":"n:钌",
"rutherford":"n:卢瑟福",
"ruthless":"a:无情,残酷,残忍,狠,狠心,豺狼成性,严酷,辣手,暴虐,残暴,毫不留情,辣",
"ruthlessness":"n:残酷,残暴",
"rwanda":"n:卢旺达",
"rye":"n:黑麦,裸麦,绅士",
"sabbath":"n:静寂",
"sabbatical":"a:休假",
"saber":"n:马刀,军刀,军法,剑",
"saber rattling":"v:磨刀霍霍,刀光剑影",
"saber saw":"n:手锯",
"sable":"n:黑貂,黑色,紫貂",
"sabotage":"v:破坏;n:破坏,怠工",
"sabre":"n:劈刺,剑,战刀",
"sac":"n:囊,袋,上衣",
"saccharin":"n:糖精",
"saccharine":"a:糖精",
"sachem":"n:首领,酋长,巨头,大亨",
"sachet":"n:香粉",
"sack":"v:解雇;n:麻包,邮袋,掠夺,革职",
"sackcloth":"n:丧服,粗麻布,麻布",
"sacking":"n:粗麻布",
"sacrament":"n:神秘",
"sacred":"a:神圣,圣",
"sacrifice":"n:牺牲;v:豁",
"sacrilege":"n:亵渎",
"sacrum":"n:骶骨,骶,荐骨",
"sad":"a:悲伤,伤心,不幸,悲哀,可悲,愁,哀,凄惨,凄,痛苦,哀愁,悲愁,忧愁,怅,怆,肝肠寸断,酸溜溜,惕,恻,凄迷,痛,辛酸,盱,惨然,感伤,哀戚,忡,悯,凄恻,凄清,悄,悒,哀伤,哀怨,怊,惆,凄然,悲,搔;v:感伤",
"sad sack":"n:冒失鬼",
"sadden":"v:悲伤,凄惨,阴郁,悲惨",
"saddened":"v:惨然",
"saddle":"n:马鞍,鞍子,座子,鞍,车座;v:承受",
"saddlebag":"n:捎马子",
"saddlery":"n:马具",
"sadhu":"n:圣人,哲人",
"sadly":"d:悄然",
"sadness":"n:悲伤,悲哀,忧伤,愁眉苦脸,认真,哀怨,伤痛,忧愁;a:痛",
"safari":"n:旅行,出猎",
"safe":"a:安全;n:冷藏室;v:安",
"safe and sound":"a:安然无恙",
"safe period":"n:安全期",
"safe-conduct":"n:护照,通行证;v:护送,保卫",
"safe-deposit box":"n:保险箱",
"safeguard":"n:通行证,卫兵,保管,护照,守护,维,装置;v:卫护",
"safekeeping":"n:保护,保管;v:保管",
"safely":"d:牢牢,安然",
"safety":"n:安全,保险,安全性,安危,安,平安,保险装置",
"safety belt":"n:救生带",
"safety deposit box":"n:保险箱",
"safety device":"n:保险装置",
"safety fuse":"n:保险丝",
"safety glass":"n:安全玻璃",
"safety island":"n:安全岛",
"safety lamp":"n:安全灯,矿灯",
"safety net":"n:安全网,保险",
"safety razor":"n:保险刀",
"safety valve":"n:安全阀",
"safflower":"n:红花",
"saffron":"n:桔黄色,藏红花",
"saffron crocus":"n:藏红花",
"sag":"v:下坠,凹陷,松弛,下陷,下垂,弯曲;n:下沉",
"sagacious":"a:精明,贤明,哲;n:贤明",
"sagacity":"n:聪明,敏锐,卓识,卓见,才略,明智,精明",
"sage":"n:圣人,圣贤,贤人,哲人,尧舜,先哲,智者",
"sagebrush":"n:一串红",
"sagely":"d:贤明",
"sagging":"v:松弛",
"sago":"n:铁树",
"saguaro":"n:仙人掌",
"sahara":"n:荒野",
"sahara desert":"n:撒哈拉沙漠",
"sahib":"n:绅士,先生,大人",
"saigon":"n:西贡",
"sail":"v:航行;n:船篷,触手",
"sailboard":"n:帆板",
"sailboat":"n:帆船",
"sailcloth":"n:苫布,帆布",
"sailfish":"n:旗鱼",
"sailing":"n:航行,滑翔,开船",
"sailing boat":"n:帆船,樯",
"sailing vessel":"n:帆船",
"sailor":"n:水手,水兵,海员,船员,老兄",
"sailplane":"n:翱翔机,滑翔机",
"saint":"n:圣人,死者,基督教徒,教徒;a:神圣",
"saith":"v:说",
"sake":"n:缘故,目的,关系,理由",
"sal ammoniac":"n:氯化铵,硇砂",
"salaam":"n:敬礼,敬意",
"salable":"a:走俏",
"salacious":"a:淫秽,猥,猥亵",
"salacity":"n:色情",
"salad":"n:色拉,沙拉,生菜",
"salad oil":"n:色拉油",
"salamander":"n:蝾螈,鲵",
"salary":"n:薪水,薪金,工资,待遇,薪俸,工薪,薪资,薪给,俸,工钱,薪",
"sale":"n:出售,销售,销售额,销路,拍卖,卖,贱卖,出卖;v:放盘",
"sales":"n:销货,销售额;a:销货",
"sales promotion":"n:促销,推销",
"sales resistance":"n:滞销",
"salesclerk":"n:店员,伙计,售货员",
"salesman":"n:推销员,售货员,店员,伙计,跑街,屠户",
"salesmen":"n:推销员",
"salespeople":"n:售货员,店员",
"salesperson":"n:推销员,售货员,营业员,店员",
"salience":"n:突出,显著",
"salina":"n:盐滩,盐田",
"saline":"n:盐场,盐水",
"salinity":"n:盐度,盐分",
"saliva":"n:唾液,唾沫;v:唾",
"salivary gland":"n:唾液腺,唾腺,颌下腺",
"salivate":"v:流口水",
"sallow":"a:蜡黄,焦黄;n:柳条,柳枝",
"sally":"n:突围,出击,旅行,外出,戏谑,开玩笑,钝角,恶作剧,警句,远足,迸发;v:动身",
"salmon":"n:鲑鱼,大麻哈鱼,鲑",
"salmon pink":"n:橙红色",
"salmon trout":"n:鳟",
"salmonella":"n:沙门氏菌",
"salon":"n:沙龙,厅,客厅,招待会,画廊,院",
"saloon":"n:客厅,餐厅,大厅,茶座",
"salt":"n:盐;v:储蓄",
"salt away":"v:积蓄",
"salt marsh":"n:盐沼",
"salt merchant":"n:盐商",
"salt mine":"v:盐矿,盐井",
"salt pork":"n:盐水,海产,咸肉",
"salted":"a:咸;v:咸",
"salter":"n:盐商",
"saltpeter":"n:硝,硝石,火硝,硝酸钾",
"saltpetre":"n:火硝",
"salts":"n:盐类,泻盐",
"salty":"a:咸,口重,鹾",
"salutation":"n:致意,招呼,称呼,寒喧,祝贺,问候,道别",
"salutatory":"n:开幕词,祝词,祝辞;a:施礼",
"salute":"v:行礼,欢迎,敬礼;n:喝彩",
"salvadoran":"a:萨尔瓦多",
"salvage":"v:打捞,抢救;n:救助,偷,抢救,救济",
"salvation":"n:拯救,救星,得救,超度,救助,救济品,获救,救济",
"salve":"v:安慰;n:软膏",
"salver":"n:托盘,盘子",
"salvo":"n:托词,遁词,排炮,口实,保留,齐鸣,礼炮",
"sam":"n:萨姆",
"samara":"n:翅果",
"samarium":"n:钐",
"same":"a:同一,同样,一,同,一样,该;d:可是,还是,一样,一律",
"sameness":"n:相同",
"samovar":"n:茶炊,茶汤壶",
"sampan":"n:舢板",
"sample":"n:样品,试样,样本,标本,样;v:选样,提供,抽验",
"sampler":"n:范本",
"sampling":"n:取样;v:选样,抽样,取样,采样",
"samurai":"n:武士",
"san diego":"n:圣地亚哥",
"san francisco":"n:旧金山",
"san juan":"n:圣胡安",
"san marino":"n:圣马力诺",
"sanatorium":"n:疗养院,休养院",
"sanctification":"n:净化,圣洁,奉献",
"sanctify":"v:认可,批准,崇奉,道貌岸然",
"sanctimony":"n:伪善,伪装",
"sanction":"n:承认,法令,准许;v:制裁,裁,赞许,承认",
"sanctions":"n:制裁",
"sanctity":"n:圣洁,神圣,尊严;a:圣洁",
"sanctuary":"n:庇护所,避难所,圣殿,殿堂,神殿,礼拜堂",
"sanctum":"n:书房",
"sand":"n:沙子,砂,沙,沙滩,砂子,沙地,砂土,砂粒,细沙,时间,勇气,寿命,沙堤,矿渣,胆量,毅力,光阴",
"sand badger":"n:猪獾,沙獾",
"sand bar":"n:沙洲,沙堤",
"sand fly":"n:白蛉",
"sandal":"n:凉鞋,草鞋,便鞋",
"sandals":"n:凉鞋",
"sandalwood":"n:紫檀,檀香木,檀香",
"sandbag":"n:沙袋;v:拈轻怕重",
"sandbank":"n:沙洲,坝",
"sandbar":"n:坝,坻,洲,沙洲",
"sandblast":"v:磨蚀;n:喷沙",
"sandiness":"n:流沙",
"sanding":"v:打磨",
"sandlot":"n:沙地",
"sandpaper":"n:砂纸",
"sandpiper":"n:鹬",
"sandpit":"n:沙坑",
"sands":"n:砂子,滩",
"sandstone":"n:砂岩",
"sandstorm":"n:沙暴",
"sandwich":"n:三明治",
"sandwiching":"v:夹层",
"sane":"a:健全",
"saneness":"n:理智",
"sang":"n:桑",
"sang-froid":"n:镇定,沉着",
"sangfroid":"n:冷静",
"sanguinary":"a:嗜杀成性,血腥;v:嗜杀成性",
"sanguine":"a:乐观,豁达;n:自信",
"sanitarium":"n:干休所",
"sanitary napkin":"n:卫生巾",
"sanitation":"n:卫生,卫生设备",
"sanitize":"v:卫生",
"sanitized":"v:卫生",
"sanity":"n:发狂,稳健",
"sans":"p:没有,无",
"sanskrit":"n:梵语,梵文",
"santiago":"n:圣地亚哥",
"sap":"n:树液,活力,元气,体液,棍子;v:耗竭",
"sapience":"n:精明,智慧",
"sapling":"n:树苗,年轻人,幼苗",
"sapphire":"n:蓝宝石,天蓝色,蔚蓝色",
"sappy":"a:傻",
"sapraemia":"n:败血病",
"saprophytic":"a:腐生",
"sapsucker":"n:啄木鸟",
"sapwood":"n:边材",
"sarcasm":"n:讽刺,讥讽,挖苦,挖苦话,反话;v:讽刺",
"sarcoma":"n:肉瘤",
"sardine":"n:沙丁鱼",
"sardinia":"n:撒丁岛",
"sarong":"n:纱笼,围裙",
"sartorial":"a:服装",
"sash":"n:腰带,彩带,窗框,框架,窗扇,门框",
"sash window":"n:吊窗",
"sasquatch":"n:野人",
"sass":"n:唐突,顶嘴,蔬菜",
"sassafras":"n:檫",
"sassy":"a:莽撞",
"satan":"n:撒旦,魔王",
"satanism":"n:穷凶极恶",
"satchel":"n:书包,挂包,褚,挎包",
"satellite":"n:卫星,人造卫星,随从,卫星国,食客,郊区",
"satiation":"n:饱满",
"satiety":"n:过多,许多",
"satin":"n:缎子,缎",
"satire":"n:讽刺;v:讽刺",
"satiric":"a:俳谐",
"satirize":"v:讥讽,违反,讥,讽刺,讽,讽诵,讥刺,挖苦",
"satisfaction":"n:满意,满足,赔偿,决斗,偿还,舒服,快事",
"satisfactorily":"d:妥贴;a:妥贴",
"satisfactory":"a:圆满,完满,合意,喜人,可意,可人,善,顺心,圆,中意,美",
"satisfied":"a:满足,满,中意;n:快意;v:得",
"satisfy":"v:满足,满意,符合,消除,达到,赔偿,履行,答应,饱,赎,餍,偿清;d:遂",
"satisfying":"v:可人;a:可心",
"satrap":"n:总督,州长",
"saturate":"v:浸,浸透",
"saturated":"v:饱和",
"saturation":"n:饱和,饱和度,浓度,浸透,充满,浸润",
"saturation point":"n:饱和点",
"saturday":"n:礼拜六,周六",
"saturn":"n:土星,镇星",
"sauce":"n:酱;v:顶撞",
"saucepan":"n:锅子",
"saucer":"n:茶碟,茶托,碟子,盆地,盘子,碟",
"sauciness":"n:傲慢",
"saucy":"a:莽撞",
"sauerkraut":"n:泡菜,酸菜",
"sauna":"n:蒸汽浴,蒸气浴",
"saunter":"v:闲逛,转悠,逛,溜达,漫步,闲荡,遛;n:漫步,闲荡,混日子",
"sausage":"n:香肠,腊肠;v:灌肠",
"saute":"v:炒",
"savage":"a:野蛮,残暴,狰狞,残,猖狂,惨;n:雇员,野兽;v:痛打,灭绝人性,痛骂",
"savagery":"n:野蛮,残暴,凶猛,野兽,荒野",
"savant":"n:学者",
"save":"v:救,节省,拯救,挽救,存,节约,储蓄,省,抢救,积蓄,保全,留,营救,存储,搭救,保留;p:除_外;c:除了,只是,除去;n:节",
"save up":"v:储藏,蓄积,蓄",
"save-all":"n:围裙,罩衫",
"saver":"n:救星",
"saving":"n:存款,储蓄,救济,救助,省却,除外,搭救;p:除_之外,之外",
"savings":"n:积蓄,储蓄",
"savings bank":"n:储蓄所",
"savior":"n:救星",
"saviour":"n:重生父母",
"savoir-faire":"n:手腕,圆滑",
"savor":"n:风味,名气,味,滋味,趣味,兴味,味道,一点儿;v:鉴赏,品尝,体味,玩味",
"savory":"a:香喷喷;n:香草",
"savour":"n:趣味,一点儿,滋味,风味,名气,香味,兴味,香,意味;v:品味,玩味,鉴赏,体味",
"savoury":"a:香喷喷,香",
"savvy":"n:本领,机智,理解力,精明;v:懂得,领悟,理解",
"saw":"n:锯,锯子;v:锯,拉锯",
"sawdust":"n:木屑,锯末",
"sawfly":"n:叶蜂",
"sawing machine":"n:锯床,电锯",
"sawmill":"n:锯木厂,锯床",
"sawtooth":"a:锯齿",
"saxifraga stolonifera":"n:虎耳草",
"saxifrage":"n:虎耳草",
"saxophone":"n:萨克管",
"say":"v:说,说道,讲,说话,道,称,表明,表达,念,开口,语,大约,声明;n:说法,谚语",
"say-so":"n:道听途说,谣传",
"saying":"n:话,谚语,格言,老话,言语,常言,言论,语",
"scab":"n:痂,孔,无赖,工贼,疥癣,疮痂,结疤;v:结疤,结痂",
"scabbard":"n:鞘,刀鞘",
"scabies":"n:疥疮,疥,疥癣,瘙,瘙痒,疥螨病",
"scad":"n:大量,许多",
"scaffold":"n:脚手架,绞刑架,工作台,支架,骨骼,断头台,看台,骨架,绞架",
"scaffolding":"n:脚手架,骨骼,骨架",
"scag":"n:海洛因",
"scalar":"n:标量,数量",
"scalawag":"n:流氓,饭桶,无赖",
"scald":"v:烫,烫伤;n:烫伤",
"scalding":"v:烫",
"scale":"n:刻度,比例,尺度,标,规模,天平,秤,比例尺,尺;v:设计,缩减",
"scale down":"v:缩减,降低",
"scale insect":"n:蚧",
"scale up":"v:扩大,增加",
"scales":"n:天平,尺度,磅",
"scaling":"n:攀登,测量,绘制,升高,比例;v:斑纹,比例",
"scallion":"n:大葱,青葱,葱,芤",
"scallop":"n:扇贝,海扇;v:烤",
"scalp":"n:头皮,浅滩,筛子;v:倒卖,夺取,击败",
"scalpel":"n:手术刀",
"scalper":"n:雕刻刀,黄牛",
"scaly":"a:鳞鳞",
"scam":"n:诡计,诈骗",
"scamp":"n:流氓,无赖,饭桶,恶棍",
"scamper":"n:疾走,奔跑;v:炸",
"scan":"v:扫描;n:视野,细看,眼界,扫视",
"scandal":"n:丑闻,丑事,耻辱,流言蜚语,诽谤,反感,物议,丑话",
"scandalize":"v:中伤,诽谤",
"scandalous":"a:丢脸,不像话,说不得;v:臭名远扬,说不得",
"scandinavia":"n:斯堪的纳维亚,北欧",
"scandium":"n:钪",
"scanner":"n:扫描器",
"scanning":"n:扫描,搜索;v:扫描",
"scant":"v:缩减,吝惜,克扣;a:寡",
"scanties":"n:短裤,衬裤",
"scantiness":"n:缺乏",
"scantly":"d:仅仅",
"scanty":"a:浅鲜,陋,微薄,疏,寥",
"scape":"n:花茎,花梗",
"scapegoat":"n:替罪羊,替死鬼,替身",
"scapegrace":"n:淘气鬼,顽童,无赖,恶棍",
"scapula":"n:肩胛,肩胛骨,琵琶骨",
"scapular":"n:肩胛,肩章",
"scar":"n:伤疤,疤痕,创伤,创痕;v:结疤",
"scarab":"n:金龟子,金壳郎",
"scaramouch":"n:无赖",
"scarce":"a:稀,不足,稀少,少见",
"scarcely":"d:不大,决不,刚刚,勉强,才,不至于,好容易,将近,仅仅",
"scarcity":"n:缺乏,不足,稀罕,荒,缺少,少见",
"scare":"v:吓;n:吓唬,恐怖;a:恐慌",
"scarecrow":"n:稻草人",
"scared":"a:恐慌,惊慌,张皇,惊惶,毛",
"scarf":"n:围巾,头巾,披巾,槽,围脖,斜面,领带;v:盖,围,打",
"scarification":"v:划破;n:划破",
"scarify":"v:折磨",
"scarlatina":"n:猩红热",
"scarlet":"a:鲜红;n:猩红,鲜红",
"scarp":"n:悬崖,陡坡",
"scarper":"v:撤退,溜掉",
"scarring":"n:伤疤;v:伤疤",
"scary":"a:险峻",
"scathe":"v:损害,损伤;n:损害,损伤",
"scatter":"v:散射,分布,分散,流散,击溃,扩散,浪费,散落,传播,挥,溃散,撒,冲散,打散,弥散,四散,摧毁,驱散,散播,散开,消除,挥霍;n:散播",
"scatterbrain":"n:马大哈",
"scatterbrained":"v:丢三落四;a:丢三落四",
"scattered":"a:零星,疏落,零散,散,零落,稀疏,散漫,稀,哩哩啦啦;v:疏散",
"scattering":"n:散射;v:分散",
"scavenge":"v:吃,清除,打扫,寻觅",
"scavenger":"n:清道夫",
"scavenging":"v:吹气",
"scenario":"n:方案,情况,戏剧,脚本,电影剧本,剧本",
"scenarist":"n:编剧",
"scene":"n:现场,场面,景色,景象,情景,场景,镜头,风景,景,事件,风光,光景,吵闹,实况,景致,幕,场,发脾气,风貌,风,插话,色,风月,风景区,气象",
"scenery":"n:风景,景色,布景,风光,景致,景物,风月,色,风物,背景,光,景",
"scenic":"a:风景如画",
"scent":"n:气味,香味,香,香气;v:看破",
"scented":"a:香;v:香",
"scepter":"n:王位",
"sceptical":"a:怀疑",
"scepticism":"n:怀疑,怀疑论",
"sceptre":"n:君权,王位",
"schedule":"n:时间表,日程;v:排定",
"scheduled":"v:班",
"scheduling":"v:调度;n:制表",
"schema":"n:模式,图解,要略,纲要,图表,摘要,大要,大意,法衣,略图,一览,格",
"scheme":"n:计划,方案,诡计,阴谋,计谋,系统;v:安排,策动,谋,图解,谋划;d:略",
"schemer":"n:阴谋家,野心家;v:阴谋家",
"scheming":"v:心计,心机,心数",
"schiller":"n:闪光",
"schilling":"n:铜币,先令",
"schism":"n:分立,分派;v:分裂",
"schist":"n:页岩,板岩",
"schizophrenia":"n:精神分裂症",
"schlep":"v:携带,运,带,拖",
"schlock":"n:贱货,次品",
"schmaltz":"n:伤感,油腻,脂肪",
"schmo":"n:愚人,傻瓜",
"schmooze":"v:闲谈,搬弄是非,扯皮,说闲话,聊天;n:闲谈,闲话,流言蜚语",
"schmuck":"n:笨蛋,愚人",
"schnapps":"n:烈酒,烧酒",
"schnitzel":"n:肉片",
"schnook":"n:可怜虫",
"schnozzle":"n:鼻子",
"scholar":"n:学者,学生,秀才,士,儒,生,士人,大方,文人,读书人,学士,门徒,光身汉,进士,公费生",
"scholarly":"a:饱学,儒",
"scholarship":"n:奖学金,学识,学问,才学",
"scholasticism":"n:烦琐哲学,墨守成规",
"school":"n:学校,校,学,功课,上课,学派,学期,小学,校舍,家,教室,学业,学院,派,流派,学会;v:教导,教授,训戒,克制,教",
"school assignment":"n:作业",
"school of medicine":"n:医科",
"school system":"n:学制",
"schoolbag":"n:书包",
"schoolbook":"n:教科书,课本",
"schoolboy":"n:男生",
"schoolchild":"n:小学生,学童",
"schoolfellow":"n:同学,同窗,校友",
"schoolgirl":"n:女生",
"schoolhouse":"n:校舍",
"schooling":"n:教育,学费,训练,文化,锻炼",
"schoolmaster":"n:教师,校长,老师,教练,教员",
"schoolmate":"n:同学,学友,同窗",
"schoolroom":"n:教室,课堂",
"schoolteacher":"n:教师,教士",
"schoolwork":"n:功课,课业",
"schoolyard":"n:校园",
"schooner":"n:大篷车",
"science":"n:科学,技术,理科,知识,学,自然科学,学科,学问,理,学术",
"science fiction":"n:科幻",
"science museum":"n:科学馆",
"scientific knowledge":"n:科学",
"scientist":"n:科学家",
"scintilla":"n:火花,闪烁",
"scintillate":"v:闪烁,闪耀,发出,发,焕发",
"scintillation":"n:闪烁,闪光;v:闪烁",
"scion":"n:接穗,后裔,小孩,幼芽",
"scissor":"v:剪,删除,削减",
"scissoring":"v:剪",
"scissors":"n:剪刀,剪子;v:剪",
"sclerosis":"n:硬化;v:硬化",
"sclerotic":"n:巩膜",
"scoff":"v:嘲笑;n:冷笑",
"scold":"v:责骂,骂,斥责,说,斥骂,斥,干,呵斥,数说;n:勾当,熊",
"scolding":"n:斥责,责骂",
"sconce":"n:盔,灯台,头,智慧,智力,烛台,才智",
"scone":"n:烤饼",
"scoop":"n:舀;v:掏,淘,撮",
"scoop out":"v:汲取,剜,掏",
"scoop up":"v:撮,捞,舀,挹",
"scoot":"n:疾走,溜走;v:溜走",
"scope":"n:范围,余地,机会,规模,力量,范畴,广度,眼界,射程,能力,面,园地,见识,界,地域,视野,分野,幅度,显示器,指示器",
"scorch":"v:焦,枯,灼热,灼伤,燎,烧灼,焦化,挖苦",
"scorched":"v:焦;a:焦",
"scorcher":"n:热门货,痛骂",
"scorching":"a:炎热,热辣辣,灼伤;v:炎,烤,灼伤;n:炎",
"score":"v:得分;n:计算,缘故,记号",
"score out":"v:删去",
"scoreboard":"n:记分牌",
"scorer":"n:记分员,记录员",
"scoring":"n:得分,擦痕,刻痕;v:擦痕",
"scorn":"v:看不起,鄙视;n:笑柄,侮弄",
"scornful":"a:轻蔑;v:轻蔑",
"scorpio":"n:天蝎座",
"scorpion":"n:蝎子,蝎,蜥蜴",
"scot":"n:税金",
"scotch":"v:擦伤,粉碎,弹压,镇压,打破,刻痕,抓,消除;n:擦伤,刻痕",
"scotland":"n:苏格兰",
"scoundrel":"n:恶棍,无赖,坏蛋,歹徒,坏人,鼠辈,混账,棍,坏东西",
"scoundrels":"n:鼠辈",
"scour":"v:搜寻,冲刷,疏浚,洗刷,肃清,洗涤,擦亮,扫荡,搜索,奔跑,查找,打,冲洗,磨擦,侵蚀;n:疏浚,洗涤剂",
"scourge":"n:灾难;v:洗劫,磨难",
"scourging":"v:鞭挞",
"scouring":"n:侵蚀,扫荡,扫除;v:疏浚",
"scout":"n:侦察员,侦察兵,童子军,侦察;v:斥候,讥笑,踏勘,探,侦察,搜索,守候,巡哨,嘲弄",
"scouting":"v:踏勘",
"scouts":"n:斥候",
"scow":"n:渡船",
"scowl":"n:阴沉;v:绷脸,横眉,怒目而视,皱眉头",
"scrabble":"n:奋斗,争夺,挣扎,扒;v:挣扎",
"scrag":"n:脖子,糟粕,碎片,碎块;v:卡脖子,绞死",
"scraggy":"v:骨瘦如柴;a:骨瘦如柴",
"scram":"v:滚蛋,滚开;n:故障",
"scramble":"v:爬,炒;n:攀登,攀缘",
"scrap":"n:破烂;v:停办,废弃,吵架,口角,撕毁,丢弃,毁弃",
"scrap iron":"n:废铁",
"scrape":"v:刮,擦,擦伤,刮去,蹭;n:摩,擦伤",
"scrape along":"v:活命",
"scraper":"n:刮刀,财迷,挖掘机,小气鬼,叉车,橡皮擦,铲土机",
"scraping":"v:擦,削,挖,刮",
"scrapper":"n:刮刀,守财奴,铲运机,吝啬鬼",
"scrappy":"a:零七八碎,零碎,零零碎碎",
"scraps":"n:屑,渣",
"scratch":"v:搔;n:拙笔,刮痕,平局;a:抠搜",
"scratch line":"v:起跑线",
"scratching":"a:刮痕",
"scrawl":"v:涂,涂抹,涂鸦,划拉",
"scream":"v:尖叫,呼啸,叫喊,惊叫;n:笑柄,伙伴,夸张",
"scree":"n:卵石",
"screech":"n:尖叫;v:惨叫",
"screed":"n:裂口,裂缝,样板,布条;v:裂开",
"screen":"n:屏幕,荧光屏,银幕,屏,屏风;v:屏蔽,遮,甄别,挡住,筛分,筛选,藏匿",
"screen door":"n:屏门",
"screening":"n:审查,甄别,放映,关卡;v:过滤,筛分,过筛",
"screenplay":"n:电影剧本",
"screenwriter":"n:编剧",
"screw":"v:拧,勒索;n:螺旋桨,驽马",
"screw jack":"n:绞盘",
"screw propeller":"n:螺旋桨",
"screw up":"v:强迫",
"screwball":"n:怪事,怪人",
"screwdriver":"n:改锥,螺丝刀,螺丝起子,起子",
"screwy":"a:疯颠颠",
"scribble":"v:涂,涂抹",
"scribe":"n:书记,新闻记者,作家,书法家",
"scrimmage":"n:扭打,前锋,混战;v:交火,扭打",
"scrimp":"v:吝啬,折皱,克扣",
"scrip":"n:股票,辅币,收条,证券,药方,纸条",
"script":"n:剧本,脚本,字体,底稿,文字,考卷,戏本,原件,手写体,书,手迹,笔迹,原本,戏剧",
"scripts":"n:字",
"scripture":"n:经典,经文,文稿,手稿,著作;p:经",
"scriptwriter":"n:编剧",
"scrivener":"n:公证人,掮客",
"scrod":"n:鱼片",
"scrofula":"n:瘰疬",
"scroll":"n:画卷,画轴,书卷,条幅,名册,目录,表,花押,卷轴,文稿",
"scroll saw":"n:钢丝锯",
"scrooge":"n:小气鬼",
"scrotum":"n:阴囊,肾囊",
"scrounge":"v:揩油",
"scrub":"v:擦洗,擦,刷,取消,刷洗;n:擦,刷子,丛林,杂种",
"scrubber":"n:洗涤器",
"scrubbing":"v:擦洗",
"scrubbing brush":"n:板刷",
"scrubby":"a:寒酸",
"scruff":"n:废渣,废物",
"scrunch":"v:踩",
"scruple":"n:顾忌;v:迟疑,忌惮;a:微量",
"scrupulosity":"n:小心谨慎,犹豫,踌躇,顾虑,拘泥",
"scrupulous":"a:心细",
"scrutineer":"n:监票人",
"scrutinize":"v:审查,细看,察,端详,鉴",
"scrutiny":"n:细看",
"scud":"v:掠过,疾行;n:阵雨,飞跑",
"scuff":"v:损伤,擦伤,磨损,攻击;n:疤痕,拖鞋",
"scuffing":"v:擦伤,咬住",
"scuffle":"v:混战,打架,扭打,剋架;n:混战,扭打",
"scull":"v:划",
"sculpt":"v:刻,塑,雕,雕塑,做",
"sculptor":"n:雕刻家,雕塑家",
"sculpture":"n:雕塑,雕刻,圆雕,雕像;v:雕刻,雕琢",
"scum":"n:渣滓,泡沫,沫子",
"scupper":"v:击溃;n:水沟",
"scurf":"n:头皮,头皮屑",
"scurrility":"n:粗话,粗俗,下流,漫骂",
"scurry":"v:催促,疾趋,窜;n:疾走",
"scurvy":"a:下流;n:坏血病",
"scuttle":"n:煤斗;v:放弃,毁坏",
"sea":"n:大海,海,海面,海洋,波涛,浪,航海,大量,潮流,内海,瀛,海事,溟",
"sea boat":"n:海船,救生艇",
"sea bream":"n:鲷",
"sea breeze":"n:海风",
"sea captain":"n:船长,舰长",
"sea cow":"n:海象",
"sea dog":"n:海狮",
"sea eagle":"n:鹗,鱼鹰",
"sea elephant":"n:海象",
"sea horse":"n:海象",
"sea lane":"n:航路",
"sea level":"n:海拔,海水面,潮位",
"sea lily":"n:海百合",
"sea lion":"n:海狮",
"sea mew":"n:海鸥",
"sea mile":"n:俚",
"sea power":"n:制海权",
"sea serpent":"n:海蛇",
"sea slug":"n:海牛",
"sea swallow":"n:海鸥",
"sea tangle":"n:海带",
"sea turtle":"n:海龟",
"sea wrack":"n:海藻",
"sea-ear":"n:鲍鱼",
"sea-level":"n:海面",
"seabed":"n:海底",
"seabird":"n:海鸟",
"seaboard":"n:海岸",
"seaborne":"n:海上",
"seacoast":"n:海岸,海滨",
"seafarer":"n:水手",
"seafloor":"n:海底",
"seafood":"n:海鲜,海味,鱼鲜",
"seagull":"n:海鸥",
"seal":"v:封,密封,封闭;n:戳子",
"seal off":"v:拆封,密封,封锁,封闭",
"sealant":"n:火漆",
"sealed":"a:闷",
"sealer":"n:封口机",
"sealing":"v:焊接,密封;n:焊缝,封",
"sealing wax":"n:火漆",
"seam":"n:缝,矿层,裂缝,接缝,节理,缝隙,罅漏;v:裂开,合拢,接合,缝合",
"seaman":"n:海员,水手,船员,水兵",
"seamen":"n:海员",
"seaming":"v:缝合,接合",
"seamy":"a:阴暗面",
"seance":"n:会议",
"seaplane":"n:水上飞机",
"seaport":"n:海港,口岸,海口,港",
"sear":"v:枯萎,烧灼,灼伤,烧伤,凋谢;n:烙印",
"search":"v:寻找,搜查;n:追求,检查",
"searcher":"n:探针",
"searching":"n:搜查,探索,搜索,搜寻,调查,探究;v:寻找,检索,探索",
"searchlight":"n:探照灯",
"searing iron":"n:烙铁",
"seascape":"n:海景",
"seashell":"n:贝类,蠡",
"seashore":"n:海岸,海滨,海滩",
"seasick":"a:晕船",
"seasickness":"n:晕船",
"seaside":"n:海滨,海边",
"season":"n:季节,季;v:熟练,习惯,候,千锤百炼,调和,缓和",
"season ticket":"n:月票",
"seasonable":"a:及时,应时",
"seasonal":"a:季节性;d:季节性;n:季节性",
"seasonal worker":"n:短工,零工",
"seasonality":"n:季节性",
"seasoned":"a:老练,老辣",
"seasoning":"n:调料,调和,调味品,干燥,缓和,时效,作料,处理,老化,佐料;v:干燥,上光,齐,风干;a:干燥",
"seat":"n:座位;v:装填,安置",
"seat belt":"n:安全带",
"seating":"n:底板,座位,席次",
"seattle":"n:西雅图",
"seawall":"n:海堤",
"seawater":"n:海水,海流",
"seaway":"n:海路,航路,航行,航线,航道,大海,公海;v:航行",
"seaweed":"n:海草,海藻,昆布",
"sebum":"n:脂肪",
"secant":"n:割线,正割",
"secede":"v:退出,脱离",
"secession":"n:退出,分裂,脱离",
"seclude":"v:与世隔绝,孤立,隔绝,隔离",
"secluded":"a:僻静,冷,窈窕,清静",
"seclusion":"n:闭塞,隔离,孤立,隐退,隔绝",
"second":"n:秒,片刻;v:附和,辅助,借调,支援;a:别的,次",
"second half":"n:后半;v:下半场",
"second hand":"n:二手货",
"second lieutenant":"n:少尉",
"second nature":"n:习与性成",
"second sight":"n:预见,千里眼,卓见",
"second-guess":"v:猜测,预言",
"secondarily":"d:其次",
"secondary":"n:旋风,副手,卫星,代理人,次重音,助手,帮手;a:次要,次级,中等;d:从;v:预制",
"secondary school":"n:完全中学",
"seconded":"v:附议",
"secondhand":"a:间接,二手",
"secondly":"d:其次,其二;r:其二",
"secrecy":"n:秘密,保密,隐蔽",
"secret":"n:秘密,机密,秘诀,奥秘,诀窍,神秘,隐私;a:阴,暗;v:隐",
"secret agent":"n:特务,内线,细作",
"secret code":"n:暗码",
"secret service":"n:特工",
"secret society":"n:帮",
"secretaire":"n:书桌",
"secretariat":"n:秘书处,书记处",
"secretary":"n:秘书,书记,干事,大臣,秘,支书,文书",
"secretary general":"n:秘书长",
"secretary of defense":"n:国防部长",
"secretary of state":"n:国务卿",
"secrete":"v:分泌,隐藏,藏,泌,藏匿",
"secretion":"n:分泌,分泌物,隐匿;v:分泌",
"secretive":"a:诡秘,鬼头鬼脑,嘴紧",
"secretly":"d:秘密,暗自,偷偷,暗暗,暗地里,暗中,背地里,偷,背地,暗地;a:密,暗",
"sect":"n:派别,派,学派,党派,团体,宗,支派,宗派,门户,道门,门,流派",
"sectarianism":"n:宗派主义,门户之见",
"section":"n:部分,节,段,剖面,截面,部件,阶层,科,组,断面,区域,口,部门,段落,切片,章节,部,处,小队,地段,条,章,剖面图,切面,切断,区段,股,界,零件,边,区间,室,小分队,工段,款,分区,课,排,派,切开,项,党,切割,片段;v:切开,切片,分段,解,拆,截,区分",
"sectionalism":"n:地方主义,本位主义",
"sectioning":"v:分割",
"sector":"n:部门,扇形,部分,区域,两脚规,阵线",
"secular":"a:长期,俗,世事;n:世俗",
"secularization":"n:世俗化,还俗",
"secure":"v:搞,安,保卫,防护,绑住,保险;a:稳当,安稳",
"securities":"n:有价证券,证券",
"security":"n:安全,证券,保证,抵押,治安,把握,疏忽,保证金,稳妥,担保,保密性,债券,可靠性,确实,平安,安,防护,确信,担保人,股票,大意,保证人,押金,质,安全性,抵押品",
"security council":"n:安全理事会",
"security deposit":"n:押金",
"sedan":"n:轿车,小车,小轿车,小汽车,轿子,轿,卧车",
"sedan chair":"n:舆",
"sedate":"a:稳重,不苟言笑,端庄,沉稳,安稳,稳;v:不苟言笑",
"sedation":"n:镇静;a:镇静",
"sedative":"n:镇静剂,止痛药",
"sedge":"n:蓑衣草,苔,莎草,筛,薹草;v:筛",
"sediment":"n:沉积物,泥沙,沉积,沉渣,沉淀,渣,渣滓,滓",
"sedimentary rock":"n:沉积岩",
"sedimentation":"n:沉积,沉淀,沉降;v:沉降,淤积",
"sediments":"n:沉淀物",
"sedition":"n:暴动,骚动",
"seduce":"v:勾引,诱奸,引诱,诱,吸引,引逗,迷惑,勾搭,诱惑,勾,蛊,挑唆,奸污,奸淫",
"seduction":"n:勾引,引诱,诱惑,吸引力,诱奸",
"sedulously":"d:刻意",
"see":"v:看到,看,看见,见,见到,会,看出,知道,认为,明白,见面,注意,瞧,喜欢,观察,参观,目睹,观看,考虑,看望,拜访,懂,经历,送,看透,瞧见,送行,检查,遇见,理解,照料,查看,负责,照顾,设法,领会,瞅见,见于,参看,视,睹,探,同意,允许,访问,视察,领悟,会见,监督,出发,细看,欢送,拆穿,小心,看破,罗列,参阅,查考,听凭,解,体验,晤面,赠别,看管,览,留神",
"see red":"v:生气,红眼",
"see through":"v:拆穿,看破",
"seed":"n:种子,种,籽;v:成熟,下种,播,萌芽,催化;a:结实,实,精",
"seed coat":"n:种皮",
"seed money":"n:股金",
"seedbed":"n:温床,苗床,种子田",
"seedcase":"n:果皮",
"seeded player":"n:种子选手",
"seeder":"n:播种机",
"seeding":"v:下种,播种",
"seedling":"n:幼苗,秧苗,苗,树苗,栽,禾苗,栽子,幼株,苗子,秧;v:栽",
"seeds":"n:菜籽",
"seeing":"n:视力,看,视觉,能见度;c:鉴于,因为,既然",
"seek":"v:寻求,去,寻找,找,企图,追求,查找,谋求,探索,试图,请求,要求,搜查,研究,征求,追逐,探求,求,追,追寻,干,邀,调查,寻觅,贪图,谋取,图谋,营,访求,觅,赴,探寻,寻,搜求,淘换,寻索,投,尝试,牟,谋,取,猎取,牟取,搜索,搜寻,贪,踅摸,打主意,图,寻摸;n:营",
"seek out":"v:寻求",
"seeker":"n:探测器",
"seeking":"v:牟",
"seem":"v:似乎,看来,好像,好象,显得,仿佛,似,像,象是,看样子,意思,好似,恰似,恰如,若,恍若;d:似乎",
"seeming":"n:表面,外表,外观",
"seemingly":"d:似乎,貌似;v:貌似;a:恍惚",
"seemliness":"n:适当",
"seen":"a:懂得",
"seep":"v:渗出,渗入,渗透,渗,渗漏,沁润,沁",
"seepage":"n:渗出,渗透,渗漏,油苗,漏水;v:渗透",
"seer":"n:先知,预言家",
"seersucker":"n:泡泡纱",
"seesaw":"v:交替,动摇,升降,涨落;n:跷跷板,杠杆",
"seethe":"v:沸腾,翻腾,浸,煮沸,激昂,煮",
"seething":"v:热火,腾腾;a:腾腾",
"segment":"n:段,部分,线段,片段,节,环节,碎片;v:分割,分段,分裂",
"segmentation":"n:分割,分裂,分段,断裂,切断;v:分段,分割,断裂",
"segregate":"v:分开,隔开,分离,分异,隔离",
"segregation":"n:隔离,分离,分开,分散,分异;v:隔离,分离",
"segue":"v:延续,连续",
"seigneur":"n:贵族,诸侯",
"seignior":"n:贵族,君主,乡绅",
"seine":"n:塞纳河,拉网",
"seismograph":"n:地震仪,地动仪",
"seismography":"n:地震学,测震学",
"seismology":"n:地震学",
"seize":"v:抓住,占领,没收,夺取,抓,夺,抢,明白,把握,捕获,卡住,扣押,利用,占有,篡夺,抓获,拿,知道,捉,缴获,窃据,取得,攘,占,捽,强占,侵夺,擒,围捕,缉捕,逮捕,略,侵占,霸占,捕,查封,劫掠,篡,缉,了解,抢夺,抢占,晓得,咬住,充公,拿下,扭,攘夺,拔,捕捉,攫取,夺得,缉拿,揪,攫,掠取,据,掠夺;d:略",
"seize on":"v:利用,采用",
"seizing":"n:捆绑,捆扎,强占,查封,没收,捕捉,所有,占有,扣押;v:卡住,捆扎",
"seizure":"n:占领,充公,捉拿,卡住,没收;v:扣留",
"seldom":"d:罕有;a:少有,难得",
"select":"v:选择,选,挑选,选定,选取,挑,精选,拣,遴选,选拔,甄选,拔取,拣选,录,摘,拔,抡,推,拣择,差,选派,择,采,点,甄拔",
"selected":"v:选定",
"selection":"n:选择,选拔,淘汰,分离,拨号,选择性,文选",
"selections":"n:选集,选辑;v:录,选",
"selectivity":"n:选择性,选择,专一性,精选",
"selenium":"n:硒",
"self":"n:自己,我;r:自,本人,自身;a:这",
"self-abasement":"n:自卑",
"self-abnegation":"n:克己,自我牺牲,自制",
"self-absorption":"n:自私自利",
"self-abuse":"n:手淫,自责,自暴自弃",
"self-accusation":"n:自责",
"self-annihilation":"n:自杀",
"self-assertion":"n:任性,一意孤行,自负,自作主张,逞能,自做主张",
"self-assurance":"n:自信,自恃,自满",
"self-assured":"a:旁若无人",
"self-command":"n:自制,镇定自若,沉着,克己",
"self-complacency":"n:自满,自我陶醉,自得",
"self-conceited":"a:自满",
"self-concern":"n:自私自利",
"self-confidence":"n:自信,自恃",
"self-consistent":"a:一贯",
"self-contradiction":"n:自相矛盾",
"self-contradictory":"a:自相矛盾",
"self-control":"n:自制,克己",
"self-criticism":"n:自我批评,检讨",
"self-deception":"n:自欺",
"self-defence":"n:正当防卫",
"self-defense":"n:自卫,正当防卫",
"self-denial":"n:自我牺牲,无私",
"self-destruction":"n:自杀",
"self-determination":"n:自决,民族自决",
"self-discipline":"n:自律",
"self-effacement":"n:谦逊,谦让",
"self-esteem":"n:自尊,自重,自负,自大,自满",
"self-evident":"n:公理;a:不言而喻",
"self-evident truth":"n:公理",
"self-examination":"n:反省,内省",
"self-governing":"a:自制",
"self-government":"n:自治,自制,自治机关",
"self-heal":"n:夏枯草",
"self-help":"n:自助,自立",
"self-importance":"n:妄自尊大",
"self-important":"a:骄矜",
"self-induction":"n:自感应",
"self-indulgence":"n:任性",
"self-interest":"n:私心,自私自利,私利",
"self-knowledge":"n:自知之明,自觉",
"self-love":"n:自爱,自大,自私,利己主义,自负",
"self-mortification":"n:禁欲",
"self-pity":"n:自怜",
"self-pollination":"n:自花传粉",
"self-portrait":"n:自画像",
"self-possession":"n:沉着,冷静,自制,泰然自若",
"self-pride":"n:自负",
"self-protection":"n:自卫",
"self-regard":"n:自尊,自尊心,利己,自爱",
"self-reliance":"n:自力更生",
"self-renewal":"v:自强",
"self-renunciation":"n:大公无私,献身",
"self-reproach":"n:后悔,自责",
"self-respect":"n:自尊心,自尊,面子,自重",
"self-restraint":"n:涵养",
"self-rule":"n:自治",
"self-sacrifice":"n:自我牺牲",
"self-satisfaction":"n:自满,自鸣得意",
"self-satisfied":"a:自鸣得意,自满,飘飘然",
"self-sufficient":"a:自给",
"self-torture":"n:苦行",
"self-will":"n:固执己见,任性",
"self-willed":"a:刚愎自用",
"selfish":"a:自私;v:自私自利",
"selfishness":"n:自私,自私自利,私心,私欲",
"selfless":"a:无私,大公无私,忘我,公而忘私;v:公而忘私,大公无私",
"sell":"v:卖,出售,销售,售出,出卖,售,脱手,经销,拍卖,变卖,销,说服,背叛;n:失望,市",
"sell off":"v:变卖",
"sell up":"v:变卖,拍卖",
"seller":"n:卖方,卖主",
"selling":"v:出售,销售,卖",
"selling price":"n:售价",
"sellout":"n:背叛,客满,出卖,告密,售完,脱销",
"selvage":"n:边缘,边,布",
"semantics":"n:语义学,语义,语义哲学,语意",
"semaphore":"n:信号,旗语,信号机",
"semblance":"n:外表,相似,外衣,假装,外观,样子,肖像,类似,伪装,外貌",
"semen":"n:精液,精子,精,种子;a:精",
"semester":"n:学期,半年",
"semi":"n:半",
"semibreve":"n:全音符",
"semicircle":"n:半圆",
"semicolon":"n:分号",
"semiconductor":"n:半导体",
"semifinal":"n:半决赛",
"semifinals":"n:半决赛",
"semimonthly":"n:半月刊",
"seminar":"n:研究会,讨论会,讲习会,专题讨论,研讨会",
"seminary":"n:发源地,苗床,温床",
"semiotic":"a:符号学",
"semis":"n:半成品",
"semitone":"n:半音",
"semitrailer":"n:挂车",
"semivowel":"n:半元音",
"senate":"n:参议院,上议院,上院,理事会",
"senator":"n:参议员,理事",
"send":"v:去,送,派,寄,发出,使,送给,打发,发,着,派遣,发射,拍,散发,下,输送,寄信,放出,吩咐,订购,射,放,投,提出,发信,支使,转寄,遣,退学,赐,递送,赶走,欢送,降,前进,延请,延展,掷,逐出,出动,上升,差使,调派,拍发,致,延,传导,放送;n:支派,原动力",
"send away":"v:放,支,打发,支使,逐出,赶走",
"send back":"v:归还,遣送,发还",
"send down":"v:吩咐,下达,退学,命令",
"send for":"v:延,延请,订购",
"send in":"v:上,提出",
"send off":"v:逐出,欢送,发出",
"send on":"v:转寄,转送",
"send out":"v:发,放送,射,出动,调派,放出,派遣,冒",
"send word":"v:通知,寄语,送信儿,转告",
"send-off":"n:欢送,送葬,葬礼,介绍,起动,发动,鼓励,送别,送行,推荐",
"sender":"n:寄件人,发报机,发射机,发射器,发送机,电键,送话器",
"sending":"n:信件,发射,发送,派遣;v:发送,发射",
"seneca":"n:哲学家",
"senegal":"n:塞内加尔",
"senescence":"n:老年期,老朽",
"senile":"a:龙钟,耄,朽,朽迈,老迈,衰老;v:朽",
"senility":"n:高龄,衰老,老迈,老态龙钟;a:衰老",
"senior":"n:前辈,长辈,上级,长者,上司,尊,长上,老资格,优先;a:高级;v:优先",
"senior citizen":"n:老人",
"senior high school":"n:高中",
"seniority":"n:年长,资历,上级,前辈,排行,资格,辈数,辈数儿,工龄,老资格",
"seniors":"n:先进",
"senor":"n:绅士",
"senora":"n:女士,太太",
"senorita":"n:女士",
"sensation":"n:感觉,轰动,知觉,印象,激动;a:激动",
"sensational":"v:耸人听闻;a:耸人听闻",
"sense":"n:意义,感觉,意识,感官;v:明白,理会,意会,了解",
"sense of humor":"n:幽默感",
"sense of responsibility":"n:责任心",
"sense of shame":"n:廉耻,面目",
"sense of smell":"n:嗅觉",
"sense of taste":"n:味觉",
"sense of touch":"n:触觉",
"sense organ":"n:感觉器官",
"senseless":"a:无谓,无聊,蒙,痴",
"senses":"n:神志",
"sensibilities":"n:情面,人情,情,脸,情感",
"sensibility":"n:敏感,感性,感光度,感觉,灵敏度,明智",
"sensible":"a:明智,感知,发觉,知道,明白,懂事,觉悟,知情达理;v:知情达理",
"sensibleness":"n:见识,懂事",
"sensing":"v:读出,指向,检测;n:感觉",
"sensing element":"n:传感器",
"sensitive":"a:敏感,灵敏,感官,感光,锐敏",
"sensitiveness":"n:灵性,灵敏度",
"sensitivity":"n:灵敏度,响度,过敏性,感光度,敏感",
"sensitization":"n:感光,激活,敏感;v:激活",
"sensitize":"v:敏感,感,激活",
"sensor":"n:传感器,感受器",
"sensory":"a:直观",
"sensory nerve":"n:感觉神经",
"sensual":"a:肉感",
"sensuality":"n:肉感,好色,淫荡",
"sentence":"n:句子,句,判决;v:判刑,处,处刑,宣判",
"sentence structure":"n:句法",
"sentencing":"n:判刑",
"sentience":"n:感觉",
"sentient":"a:意识,心",
"sentiment":"n:感情,情感,情绪,情操,观点,情调,感想,情,情趣,情愫,感伤,情味",
"sentimental":"a:感伤,伤感,多愁善感;v:多愁善感,感伤",
"sentimentalism":"n:多愁善感,牢骚",
"sentimentality":"n:多愁善感,柔情",
"sentimentalize":"v:伤感",
"sentiments":"n:情绪",
"sentinel":"n:哨兵,卫兵,步哨,符号,岗哨;v:警戒,守卫",
"sentry":"n:哨兵,岗哨,卫兵,看守,岗位,岗,望楼,步哨,警卫;v:站岗",
"sentry box":"n:岗亭",
"seoul":"n:汉城",
"sepal":"n:萼片",
"separate":"v:分开,分离,分居,隔,分手,分,隔开,分隔,区分,分别,隔离,离,割裂,割断,离析,离开,区别;n:单行本,抽印本,间;a:各别",
"separate out":"v:析出",
"separately":"d:分别,另,分头,另行,一一,个别,各个;r:各个",
"separateness":"n:分开",
"separation":"n:分离,分开,距离,间距,分居,间隙,空隙,间隔,脱离,析出,分类,离析;v:隔开,分离,离析",
"separatism":"n:分裂,脱离,分离,隔离",
"separator":"n:分离器,隔板,垫圈",
"sepia":"n:乌贼",
"sepsis":"a:腐败;n:腐败",
"sept":"n:9月,九月,氏族",
"september":"n:九月,9月",
"septicaemia":"n:败血症",
"septicemia":"n:败血症,败血病",
"septum":"n:隔膜,隔壁;d:隔墙",
"sepulcher":"n:坟墓",
"sepulchre":"n:墓穴;v:埋葬",
"sequel":"n:续集,后果,结局,续篇,继续,下文,续编,结果,遗患,后遗症",
"sequence":"n:序列,顺序,程序,序,连续,数列,结果,次序,关系,顺,地层,连贯性,条贯,次,连续性,路,次第,插曲,片断,秩序,关联,后果,时序,继续,接续",
"sequencing":"n:程序",
"sequent":"n:后果,结果",
"sequential":"a:时序;n:时序",
"sequester":"v:没收,查封,接收,扣押,弃权",
"sequestrate":"v:查封,分离,没收,隔离,扣押",
"sequestration":"n:扣押,没收,隐居,隐退,分隔,分开",
"sequoia":"n:红杉",
"seraglio":"n:后宫,闺房",
"serbia":"n:塞尔维亚",
"sere":"a:干枯",
"serenade":"n:小夜曲",
"serene":"a:安详,晴空,沉静,幽;n:晴空;v:宁静",
"serenity":"n:安详,宁静,平静,晴朗,从容",
"serf":"n:农奴,奴隶",
"serfdom":"n:奴役",
"serge":"n:哔叽",
"sergeant":"n:中士,军士,警官",
"sergeant first class":"n:上士",
"serial":"a:串行;n:系列片",
"serialize":"v:连载,系列化",
"serially":"d:连续,顺次",
"series":"n:一系列,系列,级数,连续剧,连续,数列,串联,丛书,组,列,区,段,系,层,轮,辑,族,套,丛刊,统;a:连续;v:串联",
"serious":"a:严重,严肃,认真,重大,重,厉害,正经八百,庄重,正经,重度,沉重,打紧,庄;d:正经八百",
"seriously":"d:认真,严重,严肃",
"seriousness":"n:严重性,严肃,严重,认真,重大",
"sermon":"n:讲道,布道,说教,训诫,鬼蜮,训导;v:说教",
"sermonize":"v:说教,布道,训导,训诫,讲道",
"sermons":"v:讲道",
"serous membrane":"n:浆膜",
"serpent":"n:蛇,毒蛇,爬行;v:爬行",
"serpentine":"n:蛇纹石;v:缠绕",
"serration":"n:锯齿",
"serum":"n:血清,树液,羊脂,浆液,血浆",
"serum sickness":"n:血清病",
"servant":"n:仆人,佣人,奴仆,用人,服务员,仆,勤务员,佣工,追随者,雇员,奴隶,侍者,雇工,卒,随员,仆役,丫鬟,伴当,童仆,下人,信徒,马快,役,佣",
"servant girl":"n:丫鬟,女仆",
"servants":"n:童仆,苍头",
"serve":"v:服务,供应,招待,用作,上,服役,发球,服,侍候,发,伺候,供,有用,担任,侍奉,处理;n:事,开球",
"server":"n:工作者,服务员,服务器",
"service":"n:服务,业务,工作,仪式,服役,帮助,发球,事业;v:效劳;a:勤",
"service charge":"n:服务费",
"service station":"n:加油站",
"serviceability":"n:适用性",
"serviceable":"a:有用;v:得心应手",
"serviceman":"n:军人",
"services":"n:劳务",
"servicing":"v:维修",
"serviette":"n:餐巾",
"servile":"a:奴颜婢膝,奴隶;v:唯唯诺诺",
"servility":"n:奴性,屈从,隶属,奴颜婢膝",
"serving":"n:上菜,伺候,服务,服侍",
"servitor":"n:跟班,侍从",
"servitude":"n:奴役,劳役,使用权",
"servo":"n:伺服;v:伺服",
"sesame":"n:麻,芝麻",
"sesame oil":"n:芝麻油,麻油",
"sesame seed":"n:芝麻",
"session":"n:会议,会话,开庭,会期,开会,市,盘",
"set":"v:调整,煽动,拿粗挟细,竖立,闲置,安置,架设,贴,分割,划定,激发,拨,卷,抢,种植,安上,盼望,创办,从事,校正,挑唆,掀起,分设;n:丛书,堂;a:既定",
"set about":"v:下手,开始",
"set apart":"v:突出",
"set aside":"v:拨,闲置",
"set back":"v:阻碍",
"set down":"v:放下,轻视,卸下",
"set forth":"v:发布,阐述,启程",
"set free":"v:放走,放,释,纵",
"set in":"v:固定,来到,交,进来,开始,涨潮,停当",
"set in motion":"v:掀动,开动",
"set off":"v:发射,出发,对照,分,烘,扣除,映带,表扬,衬,衬托,抵销,陪衬,抵,动身,对比,掀起,映衬,激发,分割,托,掩映",
"set on":"v:调节,定位,嗾使,挑唆,拿粗挟细,置放,攻击,开始,前进,埋头,袭击,专心,鼓动,煽动",
"set on fire":"n:放火,燃烧,焚烧,燔",
"set out":"v:开拔,胪,陈设,动身,开始,种植,陈列,开,起身,上路,张,罗列",
"set phrase":"n:语",
"set square":"n:三角板",
"set theory":"n:集合论",
"set to music":"v:谱",
"set up":"v:建立,成立,开,设立,设置,起,设,创办,树立,安装,架设,陷害,准备,办,开业,竖起,竖立,置,分设,开辟,搞,树,植,建,创建,创立,张,安设,开设,创设,安上",
"set upon":"v:挑拨",
"set-to":"n:拳赛,争论,较量",
"setback":"n:挫折,逆转;v:摧折",
"setbacks":"n:周折",
"settee":"n:沙发",
"setter":"n:二传手,调节器",
"setting":"n:背景,环境,底座,布景,镶嵌,安装,装置,调整,谱曲,安置,凝固,装配,硬化;v:安置,定形",
"settings":"n:设定",
"settle":"v:了,解决,定居,决定,安顿,平静,处理,沉降,和解,澄清,稳定,沉淀,安排,下沉,结算,确定,清偿,落户,下陷,安家,固定,了结,清算,偿付,成家,排解,结,清,收拾,安家落户,设定,侨居,私了,看上,立脚,了却,说定,栖息,相中,安家立业,安居,安置,调停,顿,奠定,平安",
"settle down":"v:安家立业,安顿,安家落户,立脚",
"settle on":"v:相中,看上,决定",
"settled":"a:安定,定当,停当,利落;v:停,定",
"settlement":"n:解决,殖民地,村落,和解,沉降,定居,处理,清算,定居点,沉陷,结账,沉淀,殖民,落,清理,镇定,整理,固定,沉淀物,决算,租界,决定,安定,调停,清偿,澄清,了局,支付,住宅区;v:沉陷,沉降,落",
"settler":"n:移民",
"settling":"v:渣滓,安置,沉淀,沉淀物,决算,清算,镇静,解决,固定,结账,决定",
"setup":"n:机构,格局,摊子,体系,组织,体制",
"seven":"a:七;n:七",
"seventeen":"n:妙龄",
"seventh heaven":"n:极乐世界",
"sever":"v:分离,断绝,断,切断,割断,分开,截,裂开,殊,分裂,分割,绝,掰,区别,割切,离间,切除",
"several":"a:几,好几,数,三,俩;n:俩",
"severally":"d:分别,分头,各自,个别",
"severance":"n:中断,隔离,差别,分离,隔断,切断,断绝,分隔;v:分隔,隔离,分离,中断",
"severe":"a:严厉,严峻,厉害,苛刻,严酷,重度,森严,严,剧,凛,峭,峻,苛,厉,懔",
"severely":"d:重;a:臭,痛",
"severity":"n:严厉,严重,严肃,苛刻,猛烈,厉害,严正,刚度,严格,硬度,纯洁",
"sew":"v:缝,缝纫,缝制,解决,缝补,确定,缝缝补补,缝合,连,纫,缀",
"sewage":"n:污水,下水道,污物,污",
"sewed":"v:线装",
"sewer":"n:下水道,阴沟,排水管,缝纫机,渗沟",
"sewer rat":"n:褐家鼠",
"sewerage":"n:污水,污物",
"sewing":"n:缝纫,针线活,线,装订",
"sewing kit":"n:针头线脑",
"sewn":"a:线装;v:线装",
"sex":"n:性别,性,女性,色情,性欲,性交",
"sex appeal":"n:性感",
"sex change":"n:变性",
"sexiness":"n:性感",
"sextant":"n:六分仪",
"sexual intercourse":"n:性交,性关系,云雨,房事,交媾",
"sexual love":"n:性爱",
"sexual perversion":"n:性变态",
"sexuality":"n:性别,性生活,性欲,性感",
"sexy":"a:性感,香艳,色情;n:色情",
"seychelles":"n:塞舌尔",
"sh":"i:嘘;v:嘘",
"shabby":"a:寒酸,褴褛,破,破陋,损;r:敝",
"shack":"n:房间,棚,窝棚,游民,落实,棚子,马架",
"shackle":"n:束缚;v:禁锢,阻碍,妨碍,拘束",
"shackles":"n:脚镣,铁链,锁链,枷锁,桎梏",
"shade":"n:树荫,荫凉;v:渐变,隐藏",
"shades":"n:太阳眼镜,百叶窗",
"shadiness":"n:可疑,阴暗",
"shading":"v:荫蔽,遮蔽,遮光;n:浓淡,阴影",
"shadow":"n:影子,阴影,阴暗,黑暗,暮色,庇护,暗影,幽灵,鬼;v:尾随,预示,渐变,庇护;a:投影,微量",
"shadow cabinet":"n:智囊团",
"shadow play":"n:皮影戏,影戏",
"shadow show":"n:影戏",
"shadowboxing":"v:打拳;n:太极拳",
"shadowing":"v:荫蔽,遮蔽",
"shadowy":"a:影影绰绰",
"shady":"a:阴凉,背阴,荫,不三不四,暧昧,黑,阴",
"shaft":"n:轴,箭,矿井,竖井,矛,车杠,烟囱,棍棒,柄;v:撑",
"shafting":"n:传动轴",
"shag":"v:追赶,追回",
"shaggy":"a:毛烘烘,芜,邋遢",
"shake":"v:动摇,发抖,震动,摇,摇晃,颤抖,抖动,抖,摇动,震,挥,撼;n:震动",
"shake hands":"v:拉手",
"shake off":"v:抖动,抖搂,抛弃,摇,脱卸,抖落,挣脱",
"shake up":"v:摇动",
"shake-up":"n:震动,搅动,激励,激动,摇动,动乱,骚动",
"shakeable":"a:撼天动地",
"shakedown":"n:地铺,勒索,敲诈",
"shakeout":"n:暴跌",
"shaker":"n:筛,搅拌器",
"shakes":"n:寒战",
"shakespeare":"n:莎士比亚",
"shakeup":"n:振动",
"shakiness":"n:震动",
"shaking":"v:振动;a:摇摇晃晃",
"shaky":"a:活动,颤悠悠",
"shale":"n:页岩",
"shall":"v:应该,要,会,将,得,必须,给,将要",
"shallot":"n:小葱",
"shallow":"a:浅,浅薄,肤浅;n:草野,托盘",
"shallows":"n:滩涂,海涂,浅滩",
"shalt":"v:将",
"sham":"n:虚伪;a:假,虚假,虚伪;v:诳,冒充",
"shaman":"n:僧人",
"shamanism":"n:萨满教",
"shamble":"v:蹒跚",
"shambles":"n:废墟,残骸,肉市",
"shame":"n:羞愧,耻辱,惭愧,羞耻,羞耻心,勾当,侮辱;v:恬不知耻,羞辱,凌辱,侮辱",
"shamed":"v:羞",
"shameful":"a:可耻,难看;n:德行",
"shameless":"a:无耻,厚颜无耻,赖皮,不要脸,丑,没羞,皮脸,厚颜,厚脸皮,寡廉鲜耻;v:恬不知耻",
"shampoo":"n:洗发剂,洗发,洗发膏;v:洗发",
"shampooing":"v:洗",
"shamrock":"n:三叶草",
"shamus":"n:警察",
"shang":"n:尚",
"shanghai":"v:诱拐,拐骗,胁迫;n:沪",
"shangri-la":"n:世外桃源",
"shank":"n:秆,花梗,叶柄,小腿,杆",
"shantung":"n:山东",
"shanty":"n:窝棚",
"shantytown":"n:棚户区,贫民窟",
"shape":"n:形状;v:定形,刨,设想,想像,说明",
"shape up":"v:整理",
"shapeliness":"n:美,漂亮,相称",
"shaping":"v:成型,整形,成形;a:成形",
"shard":"n:牛粪,砸碎,碎片",
"share":"v:分担,分享,共享;n:股子,配给品,犁铧,犁头",
"share-out":"n:均分,分摊",
"shareholder":"n:股东",
"shareholding":"n:股权",
"sharing":"v:均分,共享;n:分享",
"shark":"n:鲨鱼,骗子,专家;v:骗,狼吞虎咽,诈欺",
"sharp":"a:锋利,尖,快,尖锐,明显,锐利,敏锐,尖利,机灵,敏捷,厉害,激烈,利,犀利,准,精,辣,酸,锐,尖溜溜,急遽;d:整,直线;n:升号,夏普;v:激,磨",
"sharpen":"v:磨刀,加强,加剧,钢,鐾,砺,激化,磨练,加重;n:钢",
"sharpener":"n:磨床",
"sharpening":"v:加强",
"sharpie":"n:帆船",
"sharply":"d:准,截然",
"sharpness":"n:尖锐,清晰度,严厉,剧烈,锐利,机灵,敏捷,严酷",
"sharps":"n:麦麸",
"sharpshooter":"n:神枪手",
"shatter":"v:粉碎,破坏,破碎;n:碎片,落花",
"shattering":"v:脱粒",
"shave":"v:刮,刮脸,掠过;n:幸免,刮刀,掠过",
"shaver":"n:小伙子,刮刀,刮胡刀,理发师,剃须刀,家伙,年轻人,剃刀",
"shaving":"n:刨花,剃,修面;v:刮削,修整",
"shavings":"n:刨花",
"shaw":"n:丛林,肖",
"shawl":"n:披肩,披巾,围巾",
"she":"r:她,其,人家,伊人;n:渠",
"sheaf":"n:扎,捆,束;v:捆扎",
"shear":"v:剪;n:切变",
"sheared":"v:剪切",
"shearing":"v:切变,剪切;n:切变",
"shears":"n:剪刀,剪子,剪床;v:剪",
"sheath":"n:鞘,套,叶鞘,护套,套子,避孕套,刀鞘,兜,翅鞘,结缔组织,外壳,外皮,阳极",
"sheathe":"v:套,包,藏,覆盖;n:鞘",
"sheathing":"n:外壳,护套,盖板",
"sheave":"n:滑轮,滑车;v:束,捆",
"shebang":"n:小屋,东西,房屋,事情,赌场,店铺,妓院",
"shed":"v:舍,蜕,溢出,放弃,挥洒,减少,落,蝉蜕,散发;n:栈",
"shed blood":"v:流血",
"shed light on":"v:解释",
"shedding":"v:放射,开口",
"sheen":"n:光泽,光辉,光彩;v:发亮,照耀",
"sheep":"n:羊,绵羊,羊皮,蠢人,教友,胆小鬼",
"sheepfold":"n:羊圈",
"sheepherder":"n:牧羊人",
"sheepish":"a:羞怯",
"sheepskin":"n:羊皮,羊皮纸",
"sheer":"d:完全,彻底,绝对,十足;v:避开,脱落,打喷嚏,转向;n:纱,转向,避开;a:纯粹",
"sheet":"n:床单,被单,单,片,文件,纸张,薄片,单子,薄板,层,表格,炕单儿,皮,铁板,褥单,印张,空位,书页,图表,篇,叶;v:覆盖,扩展,展开,包",
"sheet iron":"n:铁皮",
"sheet metal":"n:薄板",
"sheeting":"n:薄膜,覆盖,薄片,挡板",
"sheets":"n:床单",
"sheik":"n:酋长,教长,家长,族长,村长",
"shelf":"n:架子,架,陆棚,层,暗礁,阁,隔板,沙洲,格,高阁",
"shell":"n:贝壳,壳,炮弹,外壳,蛋壳;v:剥落,炮轰",
"shell out":"v:付款",
"shellac":"n:虫胶,紫胶;v:打,揍",
"shellacking":"n:鞭笞,殴打",
"sheller":"n:脱壳机",
"shellfire":"n:炮火,炮轰",
"shellfish":"n:贝类",
"shelling":"n:炮击,谷壳;v:脱粒",
"shelter":"v:隐匿,庇护,躲避;n:掩蔽部,百叶箱,建筑物,屏障,工事",
"shelve":"v:搁置,压,按,辞退,搁,罢免,束之高阁,解雇",
"shelves":"n:档,架子",
"shelving":"n:搁置,解职,免职,延误,斜面,倾斜度",
"shenanigan":"n:恶作剧,胡说,诡计,胡闹,鬼把戏,欺骗",
"shenyang":"n:沈阳,沈",
"shepherd":"v:看守,牧,照看,放牧,牧羊,指导,领导;n:羊工",
"shepherd's purse":"n:荠",
"sherbet":"n:果子露,冰糕",
"sherry":"n:白葡萄酒",
"shibboleth":"n:口号,黑话,口令,切口,口头禅,服装,习惯",
"shield":"v:保护;n:挡箭牌,卵翼,屏",
"shielding":"v:防护",
"shift":"v:移动,转移;n:办法,衬衣,替换",
"shifter":"n:开关,领班,筛子",
"shifting":"n:位移,移位,转变,变化,狡赖,转移,偏移,移动;v:位移,移动,转移,偏移,变速,漂移",
"shifty":"a:翻云覆雨,滑头",
"shill":"n:代理人,代言人",
"shilling":"n:先令",
"shim":"n:垫片,衬垫",
"shimmer":"v:闪烁,发光,闪光;n:微光",
"shimmy":"n:振动,摆动,震动;v:摆动,震颤,震动",
"shin":"n:胫骨,胫;v:爬",
"shin bone":"n:胫骨",
"shine":"v:照,照耀,照射,光,发光,闪烁,发亮,擦亮,亮,闪耀,闪,光亮;n:光辉,晴天,诡计",
"shiner":"n:眼睛",
"shingle":"n:短发,鹅卵石,砂石,盖板;v:锻,压",
"shininess":"n:光彩,闪光,光泽",
"shining":"a:明亮,炯炯,亮铮铮;v:辉耀,照射,发光",
"shinny":"v:击球",
"shinto":"n:神道",
"shiny":"a:光亮,油汪汪,油光,油光光,油亮,铮,精光,雪亮",
"ship":"v:送,船运,装货,雇,解雇,卸货;n:飞船,艘",
"ship building":"n:造船业",
"shipboard":"n:船帮,船",
"shipbuilding":"v:抵达;n:造船",
"shipbuilding industry":"n:造船业",
"shipment":"n:装运,装船,装货;v:装运,装货",
"shipowner":"n:船主,船东",
"shipper":"n:货主",
"shipping":"n:航运,船舶,船只,航行,运送,海运,装货,船运,运输;v:航渡,装载",
"shipping clerk":"n:理货员",
"ships":"n:舟楫",
"shipshape":"a:井井有条,整洁,整齐,井然",
"shipwreck":"n:海难,挫折,失败,毁灭,灭亡",
"shipwrecks":"n:沉船",
"shipyard":"n:船坞",
"shire":"n:郡",
"shirk":"v:逃避,推卸,偷懒,推脱,贷,躲避,卸,辞,逃,规避,躲懒",
"shirr":"v:橡皮筋",
"shirt":"n:衬衫,衬衣,内衣,汗衫,上身",
"shit":"n:伪装;v:大便;i:狗屁",
"shiv":"n:剃刀",
"shiver":"v:发抖,哆嗦,颤抖;n:寒噤,页岩,寒战,碎片,发抖,裂片,碎块,冷战",
"shoal":"n:浅滩,鱼群,大量,群;v:成群",
"shoat":"n:猪仔,懒鬼",
"shock":"n:震惊,打击,冲击,休克,震动,地震;v:震,震撼,撞击,震荡,震骇,休克",
"shock absorber":"n:缓冲器",
"shocked":"a:骇异,骇怪",
"shocker":"n:减震器",
"shocking":"a:不像话,极度,触目惊心;v:动魄惊心,震撼人心",
"shockingly":"d:骇然",
"shockproof":"v:防震;a:防震",
"shoddy":"a:粗劣,蹩脚,滥",
"shoe":"n:鞋,鞋子,闸瓦,靴,制动器,轮胎,马蹄银,插座,底板,煞车,外胎",
"shoe leather":"n:鞋",
"shoe polish":"n:鞋油,皮鞋油",
"shoehorn":"n:鞋拔子",
"shoelace":"n:鞋带,綦",
"shoemaker":"n:鞋匠,皮匠",
"shoes":"n:鞋子,鞋",
"shoestring":"n:电线,鞋带",
"shogunate":"n:幕府",
"shoo":"i:滚开,嘘",
"shoo away":"v:轰",
"shoot":"v:射击,开枪,射,击落,枪毙,拍摄,放,发射,枪杀,拍,放枪,上;n:发射,光线,放炮,幼株,枝条",
"shoot down":"v:打下,击落",
"shoot the breeze":"v:言之无物",
"shoot up":"v:欣欣向荣,腾贵",
"shooter":"n:枪,手枪,火器,射手,炮手,流星",
"shooting":"n:射击,打猎,猎场,摄影,兴奋,乱子,枪杀,射杀;v:放射,射击,发射",
"shooting gallery":"n:射击场,打靶场",
"shooting range":"n:彀,打靶场,彀中",
"shooting star":"n:星火",
"shootout":"n:枪战",
"shoots":"n:青苗,苗",
"shop":"n:商店,店,店铺,铺子,车间,家;v:解雇,选购,出卖,挑选;a:肆",
"shop assistant":"n:售货员,伙计",
"shop clerk":"n:伙计",
"shop window":"n:橱窗",
"shopkeeper":"n:店主,老板,掌柜,店家,坐商",
"shoplifter":"n:扒手",
"shopper":"n:顾客",
"shopping":"n:购物;v:购物",
"shopping bag":"n:提包",
"shopping basket":"n:提篮",
"shopping center":"n:商业区",
"shops":"n:馆",
"shoptalk":"n:行话",
"shore":"n:海岸,岸边,岸,陆地,海滨,滨,海岸线,支柱,滨海,分界线;v:支护,撑持",
"shore bird":"n:水鸟,涉禽",
"shore up":"v:戗,撑持",
"shoreline":"n:海岸线,水线",
"short":"a:短,简短,矮;n:短裤;d:缺乏,暂,不足,忽然;v:欺骗,短路,短少",
"short bone":"n:短骨",
"short circuit":"n:漏电",
"short letter":"n:柬帖",
"short of":"p:缺少,缺乏,差,欠,除_以外,除外,短少,窄,以外,不够",
"short shrift":"n:不耐烦,漠不关心",
"short-circuit":"v:短路,简化",
"short-tempered":"a:毛躁",
"short-term":"a:短期",
"short-winded":"a:气喘",
"shortage":"n:短缺,不足,缺少,荒,缺陷,缺点",
"shortbread":"n:酥",
"shortcoming":"n:缺点,短处,不足,欠缺,罅漏,瑕,缺乏,毛病,歉收,忽略,缺欠",
"shortcomings":"n:短处",
"shortcut":"n:抄道,捷径,近路,便路,便道",
"shortcutting":"v:简化",
"shorten":"v:缩短,缩,弱化,诎,收,减少,缩小",
"shortening":"n:缩短;v:弱化,缩短",
"shortfall":"n:不足,亏空,缺少,短缺",
"shorthand":"v:速记;n:速记",
"shorthorn":"n:生手",
"shortly":"d:不久,马上,简单,简短,在即,立刻",
"shortness":"n:脆性,不足,缺少,短,简单,缺乏",
"shorts":"n:短裤",
"shortsighted":"a:近视眼,目光短浅,目光如豆",
"shortsightedness":"n:近视",
"shortwave":"a:短波",
"shot":"n:子弹,枪声,射门,照片,射击,镜头,炮弹,铅球;v:投篮",
"shot hole":"n:弹痕",
"shot tower":"n:厕所",
"shotgun":"n:猎枪",
"should":"v:当,要,该当,应当,务,应该,必须,倒,该,会,好,理当,应,可能,理应,宜;d:谅必",
"shoulder":"v:承担,担负,扛;n:逮捕,管",
"shoulder blade":"n:胛,胛骨",
"shoulder pad":"n:垫肩",
"shoulder strap":"n:背带,吊带",
"shoulders":"n:双肩",
"shout":"v:喊,喊叫,叫喊,嚷,叫,呼喊,呼叫,高呼;n:呼喊",
"shouting":"n:喊叫",
"shove":"v:推;n:铲子,推开",
"shovel":"n:铁锨,铲,铲子,铁锹,锹,挖掘机,犁铧;v:铲",
"show":"v:显示,表现,表示;n:外貌,装扮,团体,壮观,铺张,外观,陈列品,征象,表面文章,痕迹,机关,景象,迹象,假装,夸示,事件,小事,粉饰,盛装",
"show bill":"n:传单,广告,海报,招贴",
"show card":"v:广告牌",
"show off":"v:夸示,咋呼,摆弄,出风头,谝,显耀,摆,卖弄,炫,招摇过市,逞,卖,炫示,露头角,表现",
"show up":"v:揭,揭穿,照面,照面儿",
"show-off":"n:卖弄",
"showcase":"n:陈列柜,橱窗,柜橱,影戏院",
"showdown":"n:摊牌,暴露,公布",
"shower":"n:阵雨,淋浴,流星雨,淋洗;v:洒落",
"shower room":"n:浴室",
"showiness":"n:华丽",
"showing":"n:外观,表现,放映,外表,主张,展览",
"showings":"n:油花",
"showpiece":"n:样品,窗口,展品,展览品,陈列品",
"showroom":"n:陈列室",
"showy":"a:浮华,花,显眼;v:漂浮,飘浮;n:浮华",
"shrapnel":"n:榴霰弹,弹片,子母弹,霰弹",
"shred":"n:碎片;v:粉碎",
"shredder":"n:粉碎机",
"shrew":"n:悍妇,泼妇,母老虎",
"shrewd":"a:精明,慧黠,精,乖",
"shrewdness":"n:城府",
"shrewish":"a:泼;v:泼",
"shriek":"n:尖叫;v:尖叫",
"shrift":"n:忏悔,招认",
"shrike":"n:伯劳,百舌鸟,虎不拉",
"shrill":"a:尖锐,尖利,尖,凄厉",
"shrilling":"v:凄厉",
"shrimp":"n:虾,毛虾",
"shrimp sauce":"n:虾油,虾酱,卤虾油",
"shrine":"n:神殿,神龛,圣地,庙",
"shrink":"v:缩水,收缩,缩,畏缩,缩小,害怕,萎缩,退缩,抽,抽缩,缩短,搐缩,退避;n:收缩,畏缩,缩水,退缩",
"shrink back":"v:缩回,退却",
"shrink from":"v:憷",
"shrinkage":"n:收缩,跌价,减少,缩短,减缩,缩水,抽缩;v:缩短,收缩,抽缩",
"shrinking":"v:缩短",
"shrivel":"v:枯萎,萎缩,干枯,失效;a:干瘪",
"shrivel up":"v:蔫",
"shriveled":"a:干瘪;v:焦枯,皱皱巴巴,秕",
"shrivelled":"v:干枯,皱皱巴巴,焦枯,干巴",
"shroud":"n:寿衣;v:覆盖",
"shrouding":"v:遮蔽",
"shrub":"n:灌木,灌木丛;v:灌",
"shrubbery":"n:灌木",
"shrug":"v:耸肩,耸;n:耸肩",
"shrunken":"a:瘪",
"shtick":"n:特色",
"shuck":"n:外皮,壳,皮,荚,贝壳",
"shucks":"i:什么",
"shudder":"v:发抖,不寒而栗,打哆嗦,战栗,打颤,打战,颤栗,战抖,颤;n:震颤,发抖",
"shuffle":"v:拖,洗,混合,推诿,推托,移动,含糊其词,混和,搅局,蒙混,推开;n:混合,搅乱,敷衍,推托,洗牌",
"shui":"n:水",
"shun":"v:避开,躲开,避免,忌;n:舜,孙",
"shunt":"v:并联,搁置,分流,逃避,拖延,闪开,躲开;n:岔道",
"shunting":"v:分流,并联",
"shush":"i:嘘",
"shut":"v:关上,关,关闭,闭,排斥,压制,堵塞,合,合拢,阻止,中断,闭合,退关,关机,拢,中止,憋,封锁,停下,嗡,遮断,拦网,封闭,掩,隐藏,障蔽,闭锁;n:闭锁,终止,完结,焊缝;d:嗡",
"shut down":"v:关机,停下",
"shut in":"v:关,围住",
"shut off":"v:堵塞,关闭,中断,中止,遮断",
"shut out":"v:退关,杜,障蔽",
"shut up":"v:憋",
"shutdown":"n:停工,停车,停业",
"shutoff":"n:遮断,停止;v:停止",
"shutout":"n:停工",
"shutter":"n:百叶窗,快门,板,光盘,门板,快门儿,闸门,闸",
"shuttering":"v:模板",
"shutting":"v:闭合",
"shuttle":"n:梭子,梭,宇宙船,宇宙飞船",
"shuttlecock":"n:毽子,板羽球,羽毛球",
"shy":"a:腼腆,害羞,怕羞,羞怯,不好意思,怯生生;v:投掷,含羞;n:投掷",
"shyness":"n:羞涩,羞怯",
"shyster":"n:讼棍",
"si":"n:斯",
"siam":"n:暹罗,泰国",
"siamese":"n:结合,连接",
"sib":"n:同胞,血亲,氏族",
"siberia":"n:西伯利亚",
"sibilance":"n:齿音",
"sibling":"n:同胞,兄弟",
"sichuan":"n:四川",
"sicily":"n:西西里岛",
"sick":"v:攻击,呕吐,追击;n:患者",
"sickbed":"n:卧病,病床,病榻",
"sicken":"v:作呕;n:患病",
"sickening":"a:肉麻",
"sickle":"n:镰刀",
"sickness":"n:疾病,病,呕吐,瘅,疾",
"sickroom":"n:病房",
"side":"n:侧,一方,方面,面,路,方,山坡,队,边,头,侧面,船舷,旁边;v:附和,偏袒;a:旁,横",
"side by side":"a:并,并排",
"side by side with":"p:与_并肩,并肩",
"side dish":"n:小菜",
"side entrance":"n:侧门",
"side road":"n:岔子,岔道",
"side street":"n:小街",
"side view":"n:侧面图,侧面",
"sideboard":"n:餐具柜,橱柜",
"sideburns":"n:连鬓胡子,鬓",
"sidekick":"n:伙伴,朋友,死党",
"sidelight":"n:舷窗,拾零",
"sidelights":"n:侧记,散记",
"sideline":"n:副业,边线,界线,横线,兼职",
"sideshow":"n:杂耍,余兴",
"sidesplitting":"a:捧腹大笑",
"sidestep":"v:闪避,闪身;n:台阶",
"sidestroke":"n:侧泳,侧击",
"sideswipe":"v:掠过",
"sidetrack":"v:避让,扣压,转变,拖延;n:侧线",
"sidewalk":"n:人行道,便道,走道,人行路",
"sidewards":"d:横,斜",
"sideways":"d:横,侧身;a:横;v:侧身;n:侧面",
"sidewinder":"n:响尾蛇,侧击",
"siding":"n:侧线,支线,偏袒,壁板,挡板,附和,岔道,支持",
"siege":"n:围攻,包围,强求,排泄物,说服;v:围攻,包围",
"sienna":"n:赭色",
"sierra":"n:岭,山区,马鲛",
"sierra leone":"n:狮子山,塞拉利昂",
"siesta":"n:午休,午睡;v:午睡",
"sieve":"n:筛,筛子;v:筛选,筛",
"sieving":"v:过筛,筛分;n:过筛",
"sift":"v:筛,筛选,精选,筛分,过筛,淘汰,罗",
"sifter":"n:罗,筛网,筛子,罗圈,筛,滤器;v:筛",
"sifting":"n:过筛,筛分;v:过筛",
"sigh":"v:叹;n:叹气",
"sight":"n:景象,情景,视力,视觉,景色;v:出示,观测",
"sighting":"n:目睹",
"sightless":"a:瞎,盲",
"sightseeing":"n:游览,出游,观光",
"sightseer":"n:观光客,观光者,游人,游客",
"sigmoid":"a:乙状结肠",
"sigmoid flexure":"n:乙状结肠",
"sign":"n:迹象;v:使眼色",
"sign in":"v:签到",
"sign language":"n:亚当,哑语",
"sign manual":"n:特征,特性",
"sign on":"v:签字,签名",
"sign up":"v:报名",
"signal":"n:信号,讯号;v:预示",
"signal fire":"n:烽火,烽烟",
"signal light":"n:信号弹",
"signaler":"n:信号机",
"signalize":"v:显示,表明",
"signally":"d:突出,显著,非常",
"signalman":"n:通信兵,司号员",
"signature":"n:签名,特征,象征,署名,押;v:押",
"signboard":"n:幌子,招牌,市招,布告板,广告牌",
"signet":"n:印记,私章,印章,印,手戳,图章,影像",
"significance":"n:意义,重要,重要性,重大,意味深长,意味,旨趣,紧要,谛,义,关系,味",
"significant":"a:重要,重大,有意思;v:有意思",
"signification":"n:意义,含义,含意",
"signify":"v:表示,意味着,意味,要紧,预示,装腔作势,代表,示,象征,装模作样",
"signor":"n:绅士,贵族",
"signora":"n:夫人",
"signore":"n:贵族,绅士",
"signorina":"n:姑娘,少女",
"signpost":"n:路标,指路牌,路牌",
"sikkim":"n:锡金",
"silence":"n:沉默,寂静,肃静,无声,沉静,停止,忘却;i:嘘,喂",
"silencer":"n:消音器,消声器,灭音器",
"silent":"a:沉默,无声,寂静,静,寂然,默然,蔫不出溜,哑然,蔫不唧,蔫不溜;v:无声",
"silently":"d:默默,不声不响,默默无言,默然,闷头儿,哑然,寂然",
"silesia":"n:亚麻布",
"silhouette":"n:侧影,轮廓,黑影,剪影,影像",
"silica":"n:硅石,二氧化硅",
"silicate":"n:硅酸盐",
"silicon":"n:硅,矽",
"silicon carbide":"n:金刚砂",
"silicon valley":"n:硅谷",
"silicone":"n:硅酮",
"silicone rubber":"n:硅橡胶",
"silicosis":"n:矽肺,硅肺",
"silk":"n:丝绸,丝,降落伞,绸料,真丝,生丝,蚕丝,缎,丝织品,绸,绢,柞绢,绸缎,柞绸,绢花,柞丝绸",
"silk cotton":"n:攀枝花",
"silk road":"n:丝绸之路",
"silk tree":"n:合欢",
"silks":"n:帛",
"silkworm":"n:蚕,桑蚕,家蚕",
"silkworm seed":"n:蚕子",
"sill":"n:窗台,门槛,梁,岩层,槛,踏板,基石",
"silliness":"n:愚蠢",
"silly":"a:傻,愚蠢,无聊,蠢,傻头傻脑,痴;n:蠢货,蠢驴",
"silo":"n:地窖,竖井",
"silt":"n:淤泥,泥沙;v:淤积",
"silurian":"n:志留纪,志留人,志留系",
"silva":"n:林区,丛林",
"silver":"n:银,银器,银币,白银,银子,钱,银两;v:镀银",
"silver dollar":"n:大头,现大洋,光洋,大洋,现洋钱,献辞",
"silver fir":"n:银杉",
"silver fox":"n:玄狐",
"silver gray":"n:银灰色,银灰",
"silver nitrate":"n:硝酸银",
"silver perch":"n:石首鱼",
"silver screen":"n:银幕,电影界",
"silver standard":"n:银本位",
"silver storm":"n:冰雹",
"silver-grey":"n:银灰色",
"silverfish":"n:蠹鱼,衣鱼,银鱼",
"silvering":"n:包银,镀银;v:镀银;a:镀银",
"silversmith":"n:银匠",
"silverware":"n:银器",
"silvery":"a:银白",
"simian":"n:类人猿,猿",
"similar":"a:类似,同样,差不多,同,同类,近似,齐;v:相仿,近似",
"similarity":"n:相似,相像,相似性,类似,共性;a:相似",
"simile":"n:明喻,譬喻",
"similitude":"n:相似性,外表,样子;a:相似",
"simmer":"v:炖,煨;n:分离器",
"simmer down":"v:镇静,冷却",
"simon":"n:西蒙",
"simper":"v:傻笑;n:傻笑",
"simple":"a:约,轻巧;n:散体,单体;d:略",
"simple eye":"n:单眼",
"simple fraction":"n:简分数",
"simple harmonic motion":"n:简谐运动",
"simple interest":"n:单利",
"simple leaf":"n:单叶",
"simple machine":"n:简单机械",
"simple sentence":"n:简单句",
"simple sugar":"n:单糖",
"simple-minded":"a:傻乎乎",
"simpleminded":"a:老实,傻呵呵",
"simpleton":"n:傻瓜,憨子,呆子,傻子,痴子",
"simplex":"a:单向",
"simplicity":"n:简单,单纯,朴素,天真,质朴,简易,轻便,无知,诚实,愚钝,卑贱;a:简单",
"simplification":"n:简化;v:简化",
"simplify":"v:简化,删繁就简,简缩;d:略",
"simplifying":"v:简化",
"simply":"d:简单,简直,极,仅仅,干脆,非常,只是,便,索性,无非,的确,单单,活,绝对,死活,硬是,高低,直,只顾;n:高低",
"simulacrum":"n:幻影,影像,影,像",
"simulate":"v:模拟,假装,模仿;a:仿真",
"simulation":"n:模拟,仿真,拟态,假装;a:仿真",
"simulator":"n:模拟器,仿真器",
"simulcast":"v:联播",
"simultaneity":"n:同时",
"simultaneous":"a:带,平行,一齐;n:同声;v:平行",
"simultaneously":"d:同时,并,一齐,不约而同,兼,交,一边,一面,齐",
"sin":"n:罪过,罪,罪孽,过失,罪戾;v:犯",
"since":"p:自从,自;c:打,既,既是,打从;d:于今,以来;n:以来",
"sincere":"a:真诚,诚恳,真心实意,真心,诚实,衷心,诚挚,恳切,诚心诚意,由衷,真挚,赤,惇,至诚,款,悫,纯真,敦,浑厚,悃诚,亲切,肫,诚,笃,谨,真率,挚,诚笃,恳,恳挚,拳拳,实心;d:谨",
"sincerely":"d:真心诚意,由衷,真心实意;a:真心诚意",
"sincerity":"n:诚意,真诚,诚实,真心实意,真实,诚心,真挚,诚,纯粹,肝胆,笃实,襟怀坦白,情愫,真心,愫",
"sine":"n:正弦,正弦曲线",
"sine qua non":"n:必要条件",
"sinecure":"n:闲职",
"sinew":"n:筋,肌肉,体力,主力,资源,腱;v:支持",
"sinful":"v:罪孽深重;a:罪孽深重",
"sing":"v:唱,唱歌,歌唱,演唱,歌颂,称赞,吟诵,歌吟,鸣唱,吟唱,赞美,卖唱;n:歌",
"singapore":"n:新加坡",
"singe":"v:燎,损害,烧灼",
"singer":"n:歌手,诗人,鸣禽",
"singing":"n:歌声,鸟鸣,唱歌,声乐,唱功,歌咏,唱工;v:耳鸣",
"singing voice":"n:乐声,歌声",
"single":"n:单,只,单打;a:纯一,孤独;v:单一;d:独",
"single entry":"n:单式",
"single file":"n:单行,一路",
"single out":"v:抉,挑选",
"single-handed":"a:单人独马,单枪匹马",
"single-minded":"a:专一",
"singleness":"n:单一,专一性;a:单一",
"singles":"n:单打",
"singlet":"n:背心,汗衫,汗背心,单线;a:单一",
"singly":"d:单",
"singsong":"n:单调",
"singular":"a:奇特;n:单数",
"singularity":"n:非凡,奇特,特性,特别,异常,单一,怪癖",
"singularly":"d:格外,异常,个别,单独",
"sinister":"a:阴险,险恶,毒辣,阴谋,阴,阴毒,黑,险",
"sinistral":"a:左撇子",
"sink":"v:沉没,沉,下沉,坐;n:海洋,阴沟,洼地;a:凹",
"sink in":"v:陷落,眍",
"sinker":"n:坠子",
"sinkiang":"n:新疆",
"sinking":"n:孔,沉没,衰弱,投资;v:没落,淹没",
"sinner":"n:罪人,无赖",
"sinology":"n:汉学",
"sinuosity":"n:弯曲,曲折,起伏",
"sinus":"n:窦,弯曲,穴,湾,凹,弯",
"sinusoid":"n:正弦曲线",
"sip":"v:呷,啜饮,抿",
"siphon":"n:虹吸;v:虹吸,吮吸;a:虹吸",
"sir":"n:先生,阁下,爵士,各位,君,客官,早",
"sire":"v:生殖,产生,创作;n:祖先,作者",
"siren":"n:警报器,警笛,汽笛,妖女",
"sirius":"n:天狼星",
"sirloin":"n:牛腩,腩",
"sirrah":"n:小子",
"sirs":"r:诸位",
"sissy":"n:娘娘腔,少女,胆小鬼",
"sister":"n:妹妹,姐姐,姐妹,姊,妹,修女,护士,姐,老姐儿,护士长,妹子",
"sister-in-law":"n:嫂子,弟媳,弟妇,弟妹,堂姐妹,大姨子,小姑子",
"sisters":"n:姊妹,姐妹,姐儿,姐儿们",
"sit":"v:坐,起来,开会,孵,袖手旁观,骑,就座,坐落,栖息,出席,卧,适合,听讲,位于,照料,折磨,应试,逆来顺受,扎营",
"sit by":"v:袖手旁观",
"sit down":"v:逆来顺受,扎营",
"sit tight":"v:固执己见",
"sit up":"v:起来",
"sit-down":"n:坐下",
"sitcom":"n:连续剧",
"site":"n:地点,现场,地,位置,场地,遗址,地基,场所,场,网站,去处;v:安放",
"sitting":"n:坐,开会,一口气,一气,一股劲儿;a:一下子;v:孵卵",
"sitting room":"n:起居室,客厅",
"situate":"v:位于,处于",
"situated":"a:位于",
"situation":"n:情况,形势,局势,局面,处境,地,情形,地位,工作,情势,境地,位置,场合,职位,事态,情境,关系,地步,景,职业,景况,场所,情,时势,气候,时局,情事,势,态势,阵势,境遇,步,地点,事机,况,涨落,阵脚,状,局,境",
"six":"a:六",
"sizable":"a:可观",
"size":"n:大小,大,尺寸,规模,尺码,体积,粒度,长度,质量,号,能力,个头,个儿,特性,巨大,个头儿;v:上浆,估量",
"size up":"v:判断,估量,量",
"sizing":"v:上浆,分级;d:分级;n:填料",
"skate":"n:溜冰鞋,滑冰,溜冰;v:飞跑,掠过",
"skateboard":"n:滑板",
"skates":"n:冰鞋",
"skating":"v:溜冰,滑冰;n:溜冰,滑冰",
"skating rink":"n:冰场",
"skedaddle":"n:溃逃,逃走;v:逃走",
"skein":"n:绞,束,混乱,纠缠;v:绞",
"skeletal muscle":"n:骨骼肌",
"skeleton":"n:骨骼,骨架,骷髅,尸骨,骨头架子,架子,骨架子,骸骨,骨干,骨殖,枯骨,骸,基干,脉络,尸骸",
"skeleton shrimp":"n:麦秆虫",
"skepticism":"n:怀疑论",
"sketch":"n:草图,素描;v:概述,勾画,简述",
"sketchbook":"n:小品文",
"sketching":"v:草图;n:草图",
"sketchy":"a:粗略,简略,简约;d:略",
"skew":"v:偏移,歪斜;a:斜",
"skewer":"n:扦子,刀",
"skewing":"v:偏移",
"skewness":"n:畸变,偏斜",
"ski":"v:滑雪;n:滑雪板",
"skid":"n:滑道,刹车,垫板,制动器,导轨,溜滑,煞车;v:打滑,煞车;a:溜滑",
"skies":"n:天气",
"skiff":"n:小艇,扁舟,轻舟",
"skiing":"v:滑雪",
"skill":"n:技术,技巧,技能,熟练,能,巧妙,技艺,本领,知识,本事,手艺,功夫,圆熟,解数,能耐,身手,手法,艺,艺术,把式,伎,技,技工,球技,术,工力,理解力,道,工,把势,道行,功,技法,一手;v:能",
"skilled":"a:熟练,精,烂熟,目无全牛,娴,熟,娴熟",
"skilled workman":"n:巧匠",
"skillful":"a:练,圆熟,纯熟,巧,灵巧,拿手;v:练",
"skim":"v:掠过,撇,略读,逃税,点",
"skim over":"v:掠过,掠",
"skimmer":"n:蜻蜓,帽子",
"skimp":"v:节省,敷衍,克扣",
"skin":"n:皮肤,皮;v:覆盖,夹带,作弊",
"skin diving":"n:潜水,潜泳",
"skinflint":"n:守财奴,吝啬鬼,小气鬼",
"skinner":"n:皮货商",
"skinny":"a:皮包骨,皮包骨头,枯瘦;n:柴",
"skip":"v:空行,逃亡;n:遗漏,省略,跳跃",
"skip distance":"v:跨度",
"skip over":"v:跳,躐",
"skipper":"n:船长,飞鱼,机长",
"skipping":"a:跑跑跳跳",
"skirmish":"v:搜索,侦察;n:前哨战",
"skirmisher":"n:哨兵,散兵",
"skirt":"n:裙子,裙,长裙;v:抹",
"skirting":"v:边缘",
"skit":"n:活报剧",
"skittish":"a:轻佻,佻",
"skittle":"n:锥体,胡说;v:耽误,失误",
"skive":"v:磨",
"skivvy":"n:汗衫,内衣",
"skulduggery":"n:欺骗,诡计,欺诈",
"skulk":"v:偷偷摸摸,躲避,偷懒,躲藏,鬼鬼祟祟",
"skull":"n:颅骨,头骨,头颅,脑壳,脑颅,头盖骨,头顶,颅,头脑,智能",
"skullcap":"n:便帽,瓜皮帽,小帽,帽盔儿,帽盔",
"skunk":"n:黄鼠狼;v:欺骗",
"sky":"n:天空,天,天气,空,星空,霄汉,天蓝色,云天",
"skyjack":"v:劫机",
"skyjacking":"n:劫机",
"skylark":"n:云雀",
"skylight":"n:天窗,天光,天井",
"skyline":"n:轮廓,地平线,天边,天涯",
"skyrocket":"v:飞涨,猛增,扶摇直上,盲动,猛涨;n:焰火",
"skyscraper":"n:摩天楼,摩天大厦",
"slab":"n:石板,平板,铁块,土块,片,板材",
"slack":"v:放松,偷懒,放慢,休息;a:呆滞,淡;n:煤渣,淡季,空隙,休息,工装,静止,松弛",
"slack off":"v:放松,减慢,泄劲,衰弱",
"slack suit":"n:便装",
"slack up":"v:减慢",
"slacken":"v:放慢,放松,减弱,松,减少,松劲,怠惰,弛,松懈,休息,松弛,削弱",
"slacker":"n:逃兵,懒鬼,懒虫",
"slackness":"n:闲散",
"slacks":"n:女裤",
"slag":"n:炉渣,釉料,残渣,矿渣",
"slake":"v:满足,消除,扑灭,消化,消散,缓和,停,解,平息",
"slaked lime":"n:熟石灰",
"slam":"n:侮辱;v:猛攻",
"slam dunk":"n:扣篮",
"slammer":"n:监狱",
"slander":"v:诋毁,诽谤;n:污蔑,毁谤,口语;a:谗",
"slang":"n:俚语,行话,口头语,黑话,隐语,切口",
"slant":"n:斜面,斜坡,意见,态度;v:偏斜,斜视,歪斜,打斜;a:歪",
"slanted":"v:偏斜",
"slanting":"a:斜;v:偏,坡",
"slap":"v:拍,打,拍打;n:峡谷,侮辱;d:迎面",
"slapdash":"a:粗线条,粗枝大叶;n:草率,鲁莽;v:草拟",
"slaphappy":"a:头昏眼花",
"slapstick":"n:闹剧",
"slash":"v:削减,鞭打;n:斜线号,伤痕,斜线,减少,枝桠,刀痕",
"slat":"v:打,敲打,击",
"slate":"n:石板,板岩,记录;v:责骂,鞭打,痛打",
"slate pencil":"n:石笔",
"slather":"v:挥霍;n:大量",
"slating":"n:责骂;v:训斥",
"slattern":"n:荡妇,盐场,妓女",
"slatternly":"a:邋遢",
"slaughter":"v:杀害,杀戮,惨杀,诛戮,残害,残杀,屠戮;n:杀戮",
"slaughterer":"n:刽子手,屠夫",
"slaughterhouse":"n:屠宰场,屠场,汤锅",
"slav":"n:斯拉夫",
"slave":"n:奴隶,从动,奴,家奴;a:从动",
"slaveholder":"n:奴隶主",
"slaver":"n:口水,唾液,奉承,吐沫;v:奉承,流口水,垂涎",
"slavery":"n:奴隶制,奴役,束缚,服从;v:服从",
"slavishness":"n:奴性",
"slay":"v:杀死,杀害,谋杀,戮,毁灭",
"slayer":"n:凶手",
"sled":"n:雪橇;v:橇",
"sledge":"n:雪橇,扒犁,爬犁,冰橇",
"sleek":"a:光滑,润泽,溜光;v:溜,滑动",
"sleep":"v:睡,睡觉;n:静寂,麻痹",
"sleeper":"n:卧车,卧铺,枕木,寝车,道木,轨枕,木枕,死人",
"sleepers":"n:枕木",
"sleepiness":"n:睡意,倦意,困倦,瞌睡",
"sleeping":"v:静止,睡眠,休止",
"sleeping bag":"n:睡袋",
"sleeping car":"n:卧车,寝车",
"sleeping draught":"n:安眠药",
"sleeping pill":"n:催眠药",
"sleepwalking":"v:梦游",
"sleepy":"a:困,困倦,瞌睡,蒙胧",
"sleepyhead":"n:懒鬼",
"sleet":"n:冻雨",
"sleeve":"n:袖子,衣袖,套,袖,套管,套筒,袖管,袖套,袖筒,书套,套子,外壳,轴套",
"sleeveless":"a:坎肩",
"sleeves":"n:袖子",
"sleigh":"n:雪橇,冰橇,扒犁,爬犁",
"sleight":"n:诡计,奸诈,策略,技巧,手法",
"sleight of hand":"n:魔术",
"slender":"a:苗条,细,修长,纤细,细挑,窄,狭,纤纤,细条",
"sleuth":"n:足迹,猎犬,警犬,侦探",
"slew":"n:旋转,回转,大量;v:旋转,回旋,回转",
"slewing":"n:固定;v:固定",
"slice":"n:片;v:切开",
"slicing":"v:切割",
"slick":"a:光滑;v:滑溜,整顿;d:正面",
"slicker":"n:刮刀",
"slide":"v:滑,滑动;n:滑行",
"slide fastener":"v:拉链,拉锁",
"slide projector":"v:幻灯",
"slide rule":"v:算尺",
"sliding":"v:滑动;n:滑动",
"slight":"a:轻微,微微,微;v:轻慢,怠慢,侮慢;n:轻侮,怠慢,忽视,侮辱,轻蔑;d:微微",
"slighting":"v:亵渎",
"slightly":"d:稍,稍微,稍稍,略,略带,略微,略为,稍为,略略,差,薄,粗,些微;a:粗,薄;v:聊",
"slightness":"n:稍微,些微",
"slim":"a:苗条;v:减肥",
"slime":"n:矿浆,粘土,烂泥,软泥,稀泥,沥青,堕落;v:糊,涂",
"sliminess":"n:滑溜",
"slimming":"n:减肥",
"sling":"n:吊带,吊索,弹弓;v:扔,投掷,吊环,吊索",
"slinger ring":"n:吊环",
"slingshot":"n:弹弓",
"slink":"v:溜走,流产,潜逃,潜行,早产",
"slinky":"a:贼溜溜",
"slip":"v:滑,溜,溜走,失足;n:山崩,条,过失,木条,纰漏,外衣,枕套,传票",
"slip away":"v:溜,溜之大吉,逃之夭夭,逃跑;n:溜掉",
"slip by":"v:蒙混过关,荏苒",
"slip off":"v:摆脱",
"slip ring":"n:集流环",
"slip up":"v:失败,失误,跌交",
"slip-on":"n:套衫",
"slipcase":"n:书套",
"slipcover":"n:套子,书套,椅套",
"slipknot":"n:活结,活扣",
"slippage":"n:滑动,滑溜;v:滑动",
"slipper":"n:拖鞋,便鞋;v:打",
"slippers":"n:便鞋,拖鞋",
"slippery":"a:滑,狡猾,滑头,溜滑,油滑,滑溜,光溜溜,光溜",
"slipping":"v:滑动;n:转移",
"slipshod":"a:随便",
"slipway":"n:船台",
"slit":"v:扯裂,剐,切开,拉,剖开,豁;n:裂口",
"slither":"v:扭动,滑行;n:滑动,滑行",
"slithery":"a:滑溜",
"slitter":"n:切割机",
"sliver":"n:棉条,条子,裂片,薄片;v:切开,裂开",
"slob":"n:烂泥,懒汉,笨蛋",
"slobber":"v:垂涎,哭诉;n:口水,哭诉",
"slog":"n:猛击,苦干;v:猛击,苦干",
"slogan":"n:口号,短语,标语,呐喊",
"slop":"n:废油,外衣,卧具,稀泥,警察,泥浆,水坑,罩衣;v:溢出",
"slope":"n:大陆架,倾斜度;v:来,溜之大吉",
"sloping":"v:侧,坡",
"sloppily":"d:拖泥带水",
"sloppiness":"n:潮湿,懒散,泥泞",
"sloppy":"a:潦草,稀松,拖泥带水,邋里邋遢,马马虎虎,粗枝大叶;v:拖泥带水",
"slops":"n:废水,污水,泔水",
"slosh":"n:烂泥,泥泞;v:搅动,扰动",
"slot":"n:沟槽,切口,职位,足迹,空隙,位置,轨迹,狭缝",
"sloth":"n:懒惰,懒散,树懒,怠惰",
"slothful":"a:疏懒,懒",
"slothfulness":"n:怠惰",
"slouch":"v:懒散,耷拉,搭拉;n:帽檐,下垂",
"slouching":"a:懒洋洋,没精打采",
"slough":"n:泥沼,腐肉;v:结痂,蜕皮,逮捕,坍塌",
"slough off":"v:删除,蜕化,蜕",
"slovak":"n:斯洛伐克",
"slovakia":"n:斯洛伐克",
"sloven":"n:懒鬼",
"slovenia":"n:斯洛文尼亚",
"slovenly":"a:邋遢,不修边幅,潦草;v:拖泥带水;d:苟且",
"slow":"a:慢,缓慢;v:减却;d:缓慢",
"slow down":"v:减速,减却,怠工,减缓",
"slow match":"n:导火线",
"slow motion":"n:慢动作",
"slow up":"v:减速",
"slow-witted":"a:愚钝",
"slowdown":"n:减速,减退,减缓",
"slower":"a:减慢",
"slowly":"d:慢慢,缓缓,慢吞吞,徐徐,慢悠悠,冉冉,迟迟",
"slowness":"n:缓慢",
"slowpoke":"n:慢性子,笨伯",
"sludge":"n:泥,烂泥,泥肥,泥浆,渍,淤泥,胡说,软泥;v:渍",
"slue":"n:大量,许多,回转;v:回转",
"slug":"n:蛞蝓,子弹,鼻涕虫,刮痕,毛坯,铅条,芯子,芯片,懒汉,蜒蚰;v:铁心",
"sluggard":"n:懒汉",
"sluggish":"a:迟缓,懒散,呆滞,慢腾腾,懒,慢慢腾腾,拖拉,懈怠,拖沓,滞,迟滞",
"sluggishly":"d:慢腾腾,慢慢腾腾",
"sluggishness":"n:惰性,惯性",
"sluice":"n:渡槽,源泉,水门,闸口,蓄水;v:流出,奔流,排放",
"sluicing":"v:冲刷",
"slum":"n:贫民窟,贫民区",
"slum area":"n:贫民区",
"slumber":"v:睡眠,睡觉;n:睡梦,熟睡,安眠",
"slump":"v:萧条,狂跌,暴跌,不景气,衰败;n:消沉,萎靡",
"slumped":"v:疲软",
"slumping":"v:萧条",
"slur":"v:藐视,轻视,诽谤,诬蔑,隐瞒,掩饰,中伤,忽略;n:诬蔑,污点,耻辱,毁谤,污辱,模糊不清",
"slur over":"v:含糊其词,藐视,忽略",
"slurry":"n:泥浆,溏,膏剂,水泥浆",
"slush":"n:雪水,贿赂,淤泥,脂膏;v:冲洗",
"slushy":"a:泥泞",
"slut":"n:妓女,荡妇,蜡烛",
"sly":"a:狡猾,刁滑,猾,狡滑,刁,狡黠,诡",
"smack":"n:味,风味,气味,些微,海洛因,滋味,少量,鼓舌,接吻,渔船;d:猛地;v:掴;a:少量",
"smacker":"n:一元,嘴巴,嘴唇",
"small":"a:小,微小,管,毛,薄,子,窄小,次要,窄巴;n:儿童,寸",
"small change":"n:零钱,找头,零头,琐事",
"small intestine":"n:小肠",
"small talk":"n:闲话,聊天儿,胡扯",
"small town":"n:鄙,市集",
"smallness":"n:小",
"smallpox":"n:天花,花,痘,痘疮",
"smart":"a:漂亮,聪明,机灵,帅,时髦;n:苦痛,愤慨,悲痛,聪敏,神;v:杀,刺痛",
"smart aleck":"n:自作聪明,刚愎自用",
"smarten":"v:打扮",
"smash":"v:粉碎,打碎,猛击,打破,摧毁;n:破碎",
"smashup":"n:惨败,破碎,破灭,粉碎,失败,崩溃",
"smattering":"n:一知半解,少量,少数,皮毛",
"smear":"v:诽谤,抹;n:污迹,涂料,污渍",
"smear word":"v:绰号",
"smell":"n:气味;v:发觉,查出,领略;a:臭",
"smell out":"v:查出",
"smelling":"n:嗅觉;v:嗅觉",
"smelly":"a:臭",
"smelt":"v:熔化,熔炼,精炼,炼,冶炼,提炼",
"smelter":"n:熔炉,熔铸工",
"smelting":"v:熔化,熔炼",
"smidgen":"n:一丁点儿",
"smile":"v:笑,微笑;n:喜气",
"smiling":"a:笑呵呵,笑盈盈",
"smilingly":"d:带笑,咪咪,含笑;a:笑眯眯",
"smirch":"v:沾污,损坏;n:污点",
"smirk":"v:傻笑",
"smite":"v:侵袭,袭击,打,击败,杀死,遭殃,撞,破坏;n:一点儿,猛击,尝试,打,打击",
"smith":"n:史密斯,铁匠,锻工,小炉匠",
"smithereens":"n:碎片",
"smithy":"n:锻工,铁匠",
"smock":"n:罩衣,罩衫,工作服",
"smog":"n:烟雾,浓雾",
"smoke":"v:吸烟;n:浮尘,空谈",
"smoke bomb":"n:烟幕弹",
"smoke out":"v:查出",
"smoke tree":"n:栌",
"smoker":"n:吸烟室",
"smokescreen":"n:烟幕",
"smokestack":"n:烟筒",
"smoking":"n:吸烟,抽烟,冒烟;v:冒烟,抽烟",
"smoking gun":"n:铁证",
"smoking room":"n:吸烟室",
"smoky":"a:冒烟",
"smoky quartz":"n:墨晶",
"smolder":"v:燃烧,郁积",
"smooch":"v:爱抚,接吻,拥抱;n:污迹",
"smooth":"a:光滑,平坦,顺利,平滑;v:抿,溜,舒展,粉饰;n:抚平,草原",
"smooth muscle":"n:平滑肌",
"smooth out":"v:铺平,舒展",
"smooth over":"v:克服",
"smooth-tongued":"a:油嘴滑舌",
"smoothing":"v:滤波",
"smoothing iron":"n:烙铁",
"smoothly":"d:顺利,自如,顺顺当当,顺手,流利;a:顺顺当当,自如",
"smorgasbord":"n:大杂烩",
"smother":"v:窒息,覆盖,掩盖,透不过气,扼杀,熏,冒烟,蒸,憋;n:冒烟,制止,抑制",
"smoulder":"v:郁积",
"smouldering":"v:郁积",
"smudge":"n:污迹,污点",
"smug":"a:沾沾自喜;v:衣冠楚楚,沾沾自喜;n:书呆子",
"smuggle":"v:走私,偷运,夹带",
"smuggler":"n:走私者,走私犯,走私船",
"smuggling":"n:走私",
"smut":"n:污物,黑粉病,黑穗病,煤尘,污点,煤灰",
"smuttiness":"n:脏污",
"snack":"n:点心,小吃,快餐,分派",
"snack bar":"n:小吃店",
"snack counter":"v:快餐部",
"snacks":"n:零食,小卖;v:中不溜儿",
"snaffle":"v:偷;n:嚼子",
"snafu":"v:搅乱",
"snag":"v:阻挠,分叉,抽丝,妨碍,阻碍;n:钉子",
"snagging":"v:打磨",
"snail":"n:蜗牛,田螺,蜗,螺",
"snails":"n:钉螺",
"snake":"v:扭转,拖,弯曲,拉;n:蛇,长虫,威士忌酒",
"snake pit":"n:精神病院",
"snake venom":"n:蛇毒",
"snakelike":"n:蛇形",
"snakeskin":"n:蛇皮",
"snap":"v:咬,断;n:快照,精力,弹指,急变,劲头,猛扑,按扣,气力,元气;d:突然,嘎,喀嚓;a:少量",
"snap at":"v:责骂,咬",
"snap bean":"n:菜豆,豆荚,云豆",
"snap fastener":"v:摁扣儿",
"snapdragon":"n:火钳,金鱼藻",
"snapper":"n:车钩,红鱼,牙齿",
"snappers":"n:烧酒",
"snaps":"n:烧酒",
"snapshot":"n:快照",
"snare":"n:圈套,陷阱;v:陷害",
"snarl":"n:咆哮,混乱,纠纷,谩骂;v:骂,扭结",
"snarl-up":"n:阻塞",
"snarls":"v:扭结,卷曲",
"snatch":"v:抓住;n:抓举,诱拐",
"snatch up":"v:抢夺",
"sneak":"v:告发,潜行,隐藏,潜逃,偷窃;n:溜走,小偷",
"sneak away":"v:潜逃,溜号",
"sneak in":"v:潜入",
"sneak off":"v:开小差,溜",
"sneak thief":"n:小偷",
"sneakers":"n:球鞋,胶鞋",
"sneaking":"a:鬼鬼祟祟,鬼祟,偷偷摸摸",
"sneer":"v:嘲笑;n:冷语,鄙视",
"sneeze":"n:喷嚏,打喷嚏,轻视,嚏喷;v:打喷嚏",
"sneezing":"v:喷嚏;n:喷嚏",
"snick":"v:削,猛击;n:刻痕,削球",
"snicker":"v:暗笑,窃笑,嘶叫",
"snicks":"n:细节",
"sniff":"v:嗅,闻;n:吸,嗅",
"snifter":"n:吸,闻,暴风;v:闻,吸气,嗅",
"snip":"n:片断,分摊;v:剪",
"snipe":"n:烟头,沙锥,烟蒂,鹬,狙击;v:中伤",
"sniper":"n:狙击手",
"snippet":"n:摘录",
"snipping":"v:碎片",
"snitch":"v:偷窃,偷,小偷小摸,扒,告密;n:贼,小报告",
"snivel":"n:假话,哭鼻子,哭诉,鼻涕;v:哭诉,哭鼻子",
"snob":"n:势利眼,势利小人,工贼",
"snobbery":"n:势利,附庸风雅",
"snobbish":"a:势利",
"snobbishness":"n:势利眼,炎凉",
"snood":"n:发网",
"snooker":"n:台球",
"snoop":"v:探听,管闲事,窥探,偷窃;n:管闲事",
"snoot":"n:脸,前缘,鼻,鬼脸,鼻子;v:讥笑",
"snooty":"a:骄傲",
"snooze":"n:午睡,打瞌睡;v:打瞌睡",
"snore":"v:打呼噜;n:呼噜",
"snort":"v:哼哼,哼唧,吸入;n:响鼻,鼻息;i:哼",
"snorter":"n:申斥",
"snot":"n:鼻涕",
"snout":"n:嘴,鼻子,吸盘,口吻",
"snow":"n:雪,积雪,下雪;v:降雪",
"snow-white":"a:雪白",
"snowball":"n:雪球;v:打雪仗",
"snowdrift":"n:雪堆",
"snowfall":"n:降雪",
"snowfield":"n:雪原,雪地",
"snowflake":"n:雪花,雪片",
"snowman":"n:雪人",
"snows":"n:积雪",
"snowstorm":"n:暴风雪,雪暴",
"snowsuit":"n:冬装",
"snowy":"a:白皑皑",
"snub":"v:冷落,怠慢,责骂;n:斥责",
"snuff":"n:鼻烟,烛花;v:愤怒",
"snuffbox":"n:鼻烟盒",
"snuffer":"n:海豚",
"snuffle":"v:嗅,闻;n:鼻音",
"snuffling":"v:齉",
"snug":"a:舒适;v:隐藏;n:小康",
"snuggle":"v:依偎,挨近",
"so":"d:这样,这么,那么,很,如此,非常,那样,十分;c:故,故而,于是乎;r:这个,这么,约;i:好;n:底",
"so as to":"p:以,以便,为了,好,用以,以致,庶",
"so far":"a:迄今,迄今为止,至今,迄",
"so far from":"p:与其,绝非",
"so long":"i:再见,再会",
"so much":"n:多少,那么些,这么些;a:如许",
"so that":"c:好,因此,以致,以至于,甚至于,为着,庶",
"so to speak":"v:如同,好比",
"so-and-so":"n:相当",
"so-called":"a:所谓",
"so-so":"a:了了",
"soak":"v:泡,浸;n:浸渍,浸,浸泡;d:渐",
"soak through":"v:浸透",
"soak up":"v:吃",
"soap":"n:肥皂,皂;v:奉承",
"soap powder":"n:肥皂粉",
"soapbox":"v:煽动",
"soapstone":"n:滑石",
"soar":"v:飞涨,翱翔,高耸,暴涨,滑翔,猛增,耸立,向上,腾飞,屹立,飞腾,激增,腾,腾空;n:翱翔;a:腾贵",
"soaring":"v:翱翔,滑翔;a:高耸入云,冲天",
"sob":"v:哭,啜泣,呜咽;n:抽噎,畜生",
"sober":"a:清醒,稳重;v:醒,不苟言笑",
"sober up":"v:醒,醒酒",
"sobriety":"n:节制,清醒,沉着,认真,稳健,谨严,冷静",
"sobriquet":"n:绰号",
"soccer":"n:足球",
"sociability":"n:和气",
"sociable":"n:联谊会",
"social":"n:联谊会;v:群居",
"social dancing":"n:交谊舞,交际舞",
"social disease":"n:花柳病",
"social gathering":"n:联欢会",
"social insurance":"n:社会保险",
"social intercourse":"n:酬应,社交",
"social relation":"n:社会关系",
"social status":"n:身份",
"social system":"n:社会制度",
"socialism":"n:社会主义",
"socialite":"n:社会名流",
"socialization":"v:公有化,社会化;n:公有化",
"socialize":"v:社会化,周旋",
"society":"n:社会,协会,会,社交,团体,学会,社团,交际,社,团,群居,世面,公会",
"sociology":"n:社会学",
"sock":"n:袜子,短袜,拖鞋,零食;v:吃嘴,殴打,储蓄,吃零食;d:迎面,正好,对准",
"socket":"n:插座,插口,座,轴承,凿,槽,窝,插孔,洞,腔,穴,孔",
"socks":"n:袜,袜子,短袜,袜套",
"socrates":"n:苏格拉底",
"sod":"n:草皮,草地,土地,小苏打,故乡",
"soda":"n:苏打,汽水,小苏打,碳酸氢钠,碱,钠,碳酸钠",
"soda pop":"n:汽水",
"sodden":"v:腐败,浸,泡,浸透;a:烂,湿润",
"sodium":"n:钠,小苏打",
"sodium bicarbonate":"n:碳酸氢钠",
"sodium chloride":"n:食盐",
"sodium nitrate":"n:智利硝石",
"sodium salicylate":"n:水杨酸钠",
"sodium sulfate":"n:硫酸钠",
"sodium thiosulphate":"n:硫代硫酸钠",
"sodomy":"n:鸡奸;v:鸡奸",
"sofa":"n:沙发,沙发椅",
"sofia":"n:索非亚",
"soft":"a:软,柔软,柔和,轻柔,轻,松软,软绵绵,柔,软和,娇气,绵软,酥,绵,软乎乎,松;v:柔软;n:傻子",
"soft coal":"n:烟煤",
"soft drink":"n:软饮料",
"soft money":"n:纸币",
"soft soap":"n:奉承,奉承话,拍马屁",
"soft spot":"n:好感",
"soft water":"n:软水",
"soft-shelled turtle":"n:鼋,鳖",
"soft-soap":"v:奉承,阿谀",
"softball":"n:垒球",
"softball game":"n:垒球",
"soften":"v:软化,减轻,减弱,融和,松口,柔",
"softening":"v:精炼",
"softhearted":"a:心慈,心慈手软,心软;v:心慈,心慈手软",
"softly":"d:轻轻,轻,轻声,轻手轻脚,悄然",
"softness":"n:温柔,柔和,柔软,轻声",
"software":"n:软件,程序,软设备,方案",
"software package":"n:程序包",
"softwood":"n:针叶树",
"soil":"n:土壤,土,土地,地,泥土,国土,肥料,温床,土质,可耕地,国家;v:污损,染,污辱",
"soil horizon":"n:土层",
"sojourn":"v:寄居,逗留,旅居,栖身,作客,侨居,栖止;n:旅居",
"sol":"n:溶胶,太阳",
"solace":"v:安慰,抚慰,减轻,缓和;n:安慰",
"solar":"a:太阳",
"solar calendar":"n:太阳历",
"solar day":"n:太阳日",
"solar flare":"n:耀斑",
"solar furnace":"n:太阳炉,太阳灶",
"solar halo":"n:日晕,风圈",
"solar plexus":"n:心窝儿",
"solar power":"n:太阳能",
"solar prominence":"n:日珥",
"solar year":"n:太阳年",
"solder":"v:焊,焊接,接合,结合;n:焊剂,焊料,焊药,焊锡",
"soldering":"n:焊工;v:焊接",
"soldering flux":"n:焊料,焊剂",
"soldier":"n:士兵,战士,军人,兵,兵士,勇士;v:当兵,规避,逃避,偷懒,装病",
"soldier of fortune":"n:兵痞",
"soldiered":"v:当兵",
"soldiering":"v:当兵",
"soldiers":"n:士卒,兵员,兵卒",
"soldiery":"n:军人,军队",
"sole":"n:鞋底,掌;a:唯一,惟一;d:独;v:掌",
"solecism":"n:失礼,背理,无礼",
"solely":"d:完全,仅仅,单,独自,单独,纯粹,惟独",
"solemn":"a:严肃,庄严,郑重,庄重,一本正经,肃静,隆重,庄,谨;d:谨",
"solemnity":"n:隆重,一本正经,严肃,庄重,庄严,装腔作势",
"solenoid":"n:螺线管",
"solicit":"v:征求,请求,拉,兜揽,恳求,引发,要求,征稿,告,徕,诱惑,乞求,提起,诱发,求告,延揽,邀,招徕,征,教唆,招揽,兜",
"solicitation":"n:请求,恳求,引发,恳请,诱发,诱惑,征求,教唆",
"solicitor":"n:律师,推销员",
"solicitous":"a:殷勤",
"solicitude":"n:关心,焦虑,热心,挂念,担心,渴望",
"solid":"a:坚固,实心,结实,坚实,牢固;n:立体;d:一致",
"solid food":"n:糗,干粮",
"solid geometry":"n:立体几何",
"solidarity":"n:团结,休戚相关",
"solidification":"n:固化,团结,凝固;v:固化",
"solidify":"v:凝固,固化,结晶,团结,巩固,固",
"solidifying":"v:固化",
"solidity":"n:固态,固体,牢靠,充实,完整性,稠度,稳固,坚牢,体积,坚固,强度,确实,殷实,连续性,硬度",
"solidly":"d:扎扎实实",
"soliloquize":"v:独白,自言自语",
"soliloquy":"n:独白,自言自语",
"solipsism":"n:唯我主义",
"solitary":"a:孤独,孤零零,孤僻,寂寥,孤立,隔离,寂然;v:隔离;n:隐士",
"solitude":"n:孤独,幽静,寂寞,荒野,独居",
"solo":"n:独奏,独唱;v:独奏,独唱;a:单独;d:独",
"solomon":"n:圣人,贤人,聪明人",
"solon":"n:贤人,议员",
"solstice":"n:至,最高点",
"solubility":"n:溶解度,可溶性,溶度",
"soluble glass":"n:水玻璃",
"solute":"n:溶质,溶化",
"solution":"n:解决,溶液,解,溶解,解法,解答,溶剂,答案,真溶液,解释,分晓,免除,了局,消散,溶体,解除,药水,答数;v:解",
"solve":"v:解决,解,解答,解释,解开,说明,松开,调停,了却,清偿",
"solvent":"n:溶剂,溶媒,解释,说明",
"solving":"v:溶解",
"somali":"n:索马里",
"somalia":"n:索马里",
"somber":"a:阴沉,黯淡无光,阴冷",
"sombre":"a:阴沉,阴冷",
"some":"a:一些,些;r:几分;d:很,稍,相当,非常,稍微,大约,有点;n:俩,些",
"some other":"n:另外,别",
"some what":"n:有些",
"somebody":"r:有人,某人,某个;n:大人物,张三李四",
"someday":"d:有朝一日,有一天,改天,改日",
"somehow":"d:设法",
"someone":"r:有人,某人,谁,某某;c:或",
"somersault":"n:空翻,跟头,筋斗,翻筋斗;v:翻滚,翻筋斗,翻斤斗,空翻",
"somerset":"n:筋斗;v:翻筋斗",
"something":"r:名人,若干,要人;d:相当,有点",
"sometime":"d:曾经,从前,有朝一日,改天,往昔;c:多会儿",
"sometimes":"d:有时,有时候,常常,往往,间或,时而",
"someway":"d:设法",
"someways":"d:设法",
"somewhat":"d:有点,有些,多少,略微,稍微,几分,有所,略带,略;n:稍微,少量,有点,多少;a:几分",
"somewhere":"n:某地;d:某地",
"somnambulism":"n:梦游症,梦行症,梦游;v:梦游",
"somnolence":"n:困倦,嗜睡,瞌睡",
"somnolent":"a:蒙胧;v:嗜睡",
"son":"n:儿子,子,后裔,女婿,子孙,养子,子嗣,儿,男,子弟,国民,囝,崽,居民,会员",
"son-in-law":"n:女婿,东床,娇客,子婿,姑老爷,赘婿,姑爷,半子",
"sonar":"n:声纳",
"sonata":"n:奏鸣曲",
"song":"n:歌,歌曲,唱歌,曲,曲子,声乐,颂歌,抒情诗,韵文,颂,诗歌,歌子,宋",
"song thrush":"n:画眉",
"songbird":"n:告密者,歌女,鸣禽",
"songbook":"n:歌本",
"songster":"n:歌唱家,鸣禽,歌女,歌手,诗人",
"sonic barrier":"n:声障",
"sonnet":"n:十四行诗,商籁体",
"sonny":"n:孩子,年轻人",
"sonority":"n:洪亮,响亮",
"sonorous":"a:洪亮,响亮,豁亮",
"soon":"d:很快,不久,快,早,马上,一会儿,即将,立刻,快要,早日,行,旋即,即刻,最近,眼看,欣然;a:一会儿,不久;n:不日,最近",
"soot":"n:煤烟,烟灰,幼芽,油烟,滑道,纬纱,烟子,推力",
"sooth":"n:实际,事实",
"soothe":"v:安慰,减轻,抚慰,减少,缓和,劝慰,解劝,宽慰,奉承",
"soothsaying":"n:占卜",
"sop":"n:酒鬼,面包片,东西,贿赂;v:渗透,泡",
"sophism":"n:诡辩",
"sophisticate":"v:窜改,掺杂,掺假,诡辩,伪造",
"sophisticated":"a:复杂,尖端,老于世故,圆滑",
"sophistication":"n:诡辩;v:混杂",
"sophistry":"n:诡辩",
"soporific":"a:安眠",
"soprano":"n:女高音",
"sorcerer":"n:巫师,术士,神汉,神巫,巫神",
"sorceress":"n:女巫,神婆,巫,巫婆,仙姑",
"sorcery":"n:魔法,巫术,妖术,魔术",
"sordid":"a:肮脏,卑鄙",
"sore":"n:痛处,疮疤,疮,溃疡,疤痕;a:痛,痛苦;v:疼",
"sorely":"d:非常,很",
"soreness":"n:痛苦,疼痛;a:疼痛",
"sorghum":"n:高粱,蜀黍,秫",
"sorrel":"n:栗色,红褐色",
"sorriness":"n:悲哀",
"sorrow":"n:悲痛,悲哀,忧伤,不幸,伤心,忧愁,遗憾,愁,抱歉,痛;v:悲痛,悲叹,愁,惋惜;a:痛",
"sorrowful":"a:怆,凄恻,哀愁,悲怆,愁,感伤,哀戚,悲哀,怊,悲痛,悲酸,哀,悲凄,悲伤,轸,悲,悴;v:感伤",
"sorrowfully":"d:哀,悄然,恸",
"sorry":"a:对不起,抱歉,遗憾;v:对不起,失敬;n:歉意",
"sort":"n:种;v:清理;a:一般",
"sort out":"v:分类,清理,绎,疏理",
"sorter":"n:分析器",
"sortie":"n:突围,架次,出击;v:出击,出港",
"sorting":"v:分类,拣选,分级;n:整理;d:分级",
"sot":"n:醉鬼,酒鬼",
"sottish":"a:醉醺醺",
"souffle":"n:杂音",
"sough":"v:萧萧;n:排水沟",
"soughing":"v:飒然",
"soul":"n:灵魂,人,心灵,精神,化身,精髓,热情,气魄,魂,精华,本原,灵台,典型,魂灵,首脑,要素,心魄,阴魂,魂魄,领袖",
"soul kiss":"n:接吻",
"soul-searching":"n:反省",
"soul-stirring":"a:惊心动魄,回肠荡气",
"sound":"n:声音,声;v:召唤,调查,发声,鼓,夸夸其谈;a:健康",
"sound effect":"n:音响效果,音效",
"sound film":"n:有声片",
"sound off":"v:夸夸其谈",
"sound out":"v:摸,打听",
"sound recording":"v:录音",
"sound reproduction":"n:放声,放音",
"sounder":"n:探针,探测器",
"sounding":"v:发声,探测;n:发声;a:有声",
"sounding rocket":"n:探空火箭",
"soundless":"a:哑然无声",
"soundly":"d:香甜;a:香",
"soundness":"n:稳固,健全,完好,公正,正当,坚固",
"soundproof":"v:隔音",
"soundtrack":"n:音带,声带",
"soup":"n:汤,菜汤,困境,浪花,电,硝化甘油,马力",
"soupcon":"n:少量,痕迹,嫌疑",
"sour":"n:鸡尾酒,酸味,苦恼,痛苦;a:酸溜溜,酸臭;v:憎恶",
"sour milk":"n:酸牛奶",
"source":"n:来源,源,光源,根源,源泉,电源,源头,出处,原因,水源,发源地,泉源,策源地,来路,根子,渊源,母,血统;a:母;v:滥觞",
"source language":"n:源语言",
"sourdough":"n:老手,酵母,面肥,老资格",
"sourness":"n:酸味",
"souse":"v:腌,腌制,狂饮,喝醉,浸,泼;n:酒鬼,浸透",
"south":"n:南方,南,南部,南边,南风",
"south africa":"n:南非",
"south america":"n:南美",
"south frigid zone":"n:南寒带",
"south korea":"n:南韩",
"south pole":"n:南极",
"south sea":"n:南海",
"south vietnam":"n:南越",
"south west africa":"n:西南非洲",
"southeast":"n:东南,东南部",
"southeaster":"n:东南风",
"southeastern":"a:东南",
"southerly":"n:南风;a:南",
"southern hemisphere":"n:南半球",
"southern lights":"n:南极光",
"southpaw":"a:左撇子;n:左撇子",
"southward":"n:南;a:南方",
"southwest":"n:西南,西南部",
"southwester":"n:西南风",
"southwestern":"a:西南",
"souvenir":"n:纪念品,纪念,追忆,回忆,表记",
"sovereign":"n:君主,统治者,皇,辟,元首,后,主权国,君",
"sovereignty":"n:主权,统治权,君权,宗主权",
"soviet":"n:苏维埃,苏;a:苏",
"soviet union":"n:苏联",
"sow":"v:播种,种,播,撒,撤,散播,传播",
"sower":"n:播种机",
"sowing":"v:播种,撒播",
"soy":"n:大豆,酱油,黄豆",
"soybean":"n:大豆,黄豆",
"soybean oil":"n:豆油",
"spa":"n:温泉,矿泉",
"space":"n:空间,时间,地方,太空,间隔,篇幅,距离,间隙,空地,场地,空隙,行距;v:拉开,岔开",
"space lattice":"n:点阵",
"space platform":"n:太空站",
"space rocket":"n:宇宙火箭",
"space shuttle":"n:航天飞机",
"space station":"n:空间站,航天站",
"space vehicle":"n:航天器",
"spacecraft":"n:宇宙飞船,航天器",
"spaceflight":"n:航天",
"spaceman":"n:宇航员,太空人",
"spaceport":"n:航天站",
"spacer":"n:垫圈,隔板,衬垫,垫片",
"spaceship":"n:宇宙飞船",
"spacing":"n:间隔,间距,距离,行距,空白行,疏密,空隙",
"spacious":"a:宽敞,广阔,宽绰,宽大,绰,空廓,空阔,阆;v:敞",
"spade":"n:黑桃,铁锹,铲子,锹,铲,铁锨,锄,铲刀",
"spain":"n:西班牙,西",
"span":"n:跨度;v:到,看到,观测,及",
"spangle":"v:闪耀",
"spaniel":"n:走狗,马屁精",
"spanish mackerel":"n:鲅",
"spank":"v:打,飞跑,击败",
"spanking":"n:拍打",
"spanner":"n:扳手,扳子",
"spar":"n:桅杆,圆材;v:战斗,争吵",
"spare":"v:省掉,割爱;n:准备金,零件,剩余;a:多余",
"spare part":"n:零件",
"spare time":"n:闲工夫,空闲,闲空,余闲,余,工余,闲,空,空暇",
"spareness":"n:缺乏",
"spareribs":"n:排骨",
"spares":"n:备品,零件",
"sparing":"a:俭约,俭省,爱惜,贫乏",
"spark":"n:火星,火花,电火花,闪光;v:走火",
"spark gap":"n:避雷器",
"spark off":"v:引爆",
"spark plug":"n:中坚,火花塞,带头人",
"sparking":"v:点火,走火",
"sparking plug":"n:火花塞",
"sparkle":"v:闪闪,发光,闪耀;n:活力,火星,闪光",
"sparkler":"n:花炮,宝石",
"sparkling":"a:闪闪,烁烁,亮晶晶",
"sparring":"v:争论,辩论,拳击",
"sparrow":"n:麻雀,家雀儿,雀",
"sparrow hawk":"n:鹞,鹞鹰,鹞子",
"sparse":"a:稀疏,稀稀拉拉,疏落,寥寥无几,疏散;v:疏散",
"sparsity":"n:稀疏",
"spasm":"n:痉挛,抽搐,抽风;v:抽搐,抽动,转筋",
"spasms":"v:抽风",
"spat":"v:争吵,口角,产卵;n:口角,争论",
"spate":"n:大量,洪水,猛涨",
"spatter":"v:溅,喷溅,洒落,溅射,泼,洒,飞溅,诽谤;n:溅,少量,点滴",
"spattering":"v:飞溅,喷溅;n:泼",
"spatula":"n:胸骨",
"spawn":"n:产物,丝,小鬼,结果,卵,子,菌;v:产卵,酿成,引起",
"spawning":"v:放散,产卵",
"speak":"v:说,说话,讲话,讲,谈,发言,谈话,语,开口,谈论,交谈,演说,演讲,表示,证明,言语,吐,道,响,表现,辩解,表达,嘴,表明,言,出口,传言,声明,定购,陈述,出声,朗诵,吭气,吭声,宣告,招呼,吠;n:嘴",
"speak for":"v:定购",
"speak out":"v:开口,吐",
"speaker":"n:发言人,议长,主席,扬声器,喇叭,音箱,话筒,扩音器,广播员",
"speaking":"v:传说,谈话,雄辩,演说,语言",
"speaking trumpet":"n:扩音器,话筒",
"spear":"n:矛;v:得到",
"spearhead":"n:前锋,尖端,矛头,先锋,锋芒;v:带头",
"spearmint":"n:留兰香",
"special":"a:特殊,特别,特,专,非常,独特;n:特稿,特刊,特派员,特使,特约稿;d:特",
"special education":"n:特殊教育",
"special forces":"n:特种部队",
"specialism":"n:专业",
"specialist":"n:专家,内行",
"speciality":"n:专业,特产,特性,专长,特殊性,一技之长,特长,专",
"specialization":"n:专业化",
"specialize":"v:专攻,专修,分化,攻读,列举,限定,攻,主修,专业化,指定",
"specialized":"a:专门;v:专门",
"specially":"d:特别,专门,特地,特意,专,特,尤为,特为,专诚,特此",
"specialness":"n:特殊,专门",
"specialty":"n:专业,专门,特点,专长,专科,特质,特性",
"specie":"n:硬币,铸币",
"species":"n:种,物种,种类,形式,金币",
"specific":"a:特定,具体,比,特有,一定,个别;n:细节",
"specifically":"d:尤其",
"specification":"n:说明,规格,规范,详述,明细表",
"specifications":"n:口径,说明书,规格",
"specificity":"n:专一性,特效,特征,特性",
"specified":"a:特定,额定;v:特定",
"specify":"v:规定,指定,详述,注明,分类",
"specimen":"n:标本,试样,样品,怪人,例子,实例,典型,样本,雏形,样册,抽样,样机",
"specious":"a:似是而非",
"speck":"n:微粒,点,斑点,污点,斑,点子,脂肪,肥肉,缺点",
"speckle":"n:斑,污迹,斑点;v:点缀",
"specks":"n:眼镜",
"specs":"n:规范,规格,眼镜",
"spectacle":"n:眼镜,景象,场面,奇观,壮观,表演,展览,状况,光景",
"spectacles":"n:镜子,眼镜",
"spectacular":"v:洋洋大观,引人注目,气象万千;a:气象万千;n:壮观",
"spectator":"n:观众,旁观者",
"specter":"n:幽灵,鬼魂,亡魂,亡灵",
"spectral":"a:分光;v:分光",
"spectre":"n:亡魂,鬼魂,亡灵,鬼怪",
"spectrograph":"n:摄谱仪,光谱仪",
"spectrographic analysis":"n:光谱分析",
"spectrometer":"n:分光计",
"spectroscope":"n:分光镜",
"spectroscopic analysis":"n:光谱分析",
"spectroscopy":"n:光谱学",
"spectrum":"n:光谱,谱,频谱,范围,波谱,分光,系列,幅度",
"spectrum analysis":"n:光谱分析",
"spectrum line":"n:光谱线",
"speculate":"v:猜测,推测,思索,投机,投机倒把,忖度,炒买炒卖,买空卖空,设想,忖,自忖,猜,沉思,倒把",
"speculation":"n:投机,推测,考虑,思索,沉思,空谈,炒买炒卖,投机倒把",
"speculum":"n:反射镜",
"speech":"n:讲话,演讲,演说,发言,说话,讲演,言语,语音,言论,词,报告,话语,音,谈话,用语,方言,引语,口白,音色;v:讲演,演讲",
"speechify":"v:高谈阔论",
"speechless":"a:默然,无言以对;v:无言以对",
"speed":"v:超速;n:快慢;a:快",
"speed indicator":"n:速度计",
"speed of light":"n:光速",
"speed up":"v:加快,加紧,加速,催",
"speedboat":"n:快艇",
"speeder":"n:加速器",
"speedily":"d:迅速,赶紧,飞,赶快,快;v:飞",
"speediness":"n:迅速",
"speedometer":"n:速度计,速度表",
"speedster":"n:快艇",
"speedup":"n:加速",
"speedy":"a:迅速,快,戾,迅急,快速,速",
"spell":"v:拼写,拼,招致;n:魔力",
"spellbind":"v:迷住,迷惑",
"spellbound":"v:发呆",
"spelling":"n:拼写,拼字,拼写法",
"spencer":"n:短大衣",
"spend":"v:花,度过,用,开支,过,花钱,花费,消磨,消耗,度,费,浪费,化,失去,献出,破,过日子,产卵,销,用尽",
"spending":"n:开销,花费,经费;v:开支",
"spendthrift":"n:浪子,大少爷,败家子",
"sperm":"n:精子,精液,微生物,抹香鲸;a:精",
"spermatozoon":"n:精子,精虫",
"spew":"v:涌出,渗出,呕吐",
"sphere":"n:球,球体,球面,范围,领域,球形,职分,地位,天体,行星,地球仪,身分,天球,天空,星",
"spherical":"a:球形,圆",
"spherical angle":"n:球面角",
"spheroid":"n:球体",
"sphincter":"n:括约肌",
"sphincter muscle":"n:括约肌",
"sphinx":"n:怪人,天蛾",
"spic-and-span":"a:崭新",
"spice":"n:香料,调味品,情趣,香气,调味料,香味,风味",
"spices":"n:五香",
"spiciness":"n:香味",
"spicule":"n:骨针,穗状花序",
"spider":"n:蜘蛛,蛛,三脚架,蛛蛛",
"spider web":"n:蛛网",
"spiel":"n:演说",
"spigot":"n:栓,套管,插口,插销,龙头,塞子",
"spike":"n:钉鞋;v:挫败,扣球,阻挡,抑制",
"spikes":"n:钉鞋",
"spill":"v:泼,洒,溢,撒,溢出,倾覆,涌流,漏风,抛洒,喷溅,飞溅,浪费,涌出;n:引柴,纸捻,捻子,纸捻儿,销子,溢出,溢洪道,涌出",
"spill over":"v:溢出",
"spill the beans":"v:露馅儿",
"spillage":"n:溢出",
"spillover":"n:溢出,过多",
"spillway":"n:溢洪道",
"spin":"v:旋转,纺纱,结,讲,跳舞,编造,吐丝,纺,自转;n:螺旋,眩晕,飞过",
"spin out":"v:拉长",
"spin-off":"n:副产品",
"spinach":"n:菠菜",
"spinal column":"n:脊柱",
"spinal nerve":"n:脊神经",
"spindle":"n:主轴,轴,纺锤,疯枝,纱锭,梭,络子;a:疯;v:徒长",
"spindle tree":"n:桫椤",
"spindling":"v:徒长,疯长;n:徒长",
"spindrift":"n:浪花,浪沫,灰尘",
"spine":"n:脊骨,刺,书脊,脊柱,脊椎骨,棘,脊梁骨,书背,背,毅力,勇气,针,骨针,脊",
"spineless":"v:优柔寡断;a:优柔寡断",
"spinner":"n:挡车工",
"spinney":"n:灌木丛,树丛",
"spinning":"n:旋转,纺线;v:纺纱",
"spinning frame":"n:细纱机",
"spinning machine":"n:纺纱机,纺丝机",
"spinning wheel":"n:纺机",
"spinster":"n:老处女",
"spinsterhood":"n:独身",
"spiny anteater":"n:针鼹",
"spiracle":"n:气门,通气孔",
"spiral":"n:盘旋,螺旋,螺线,徊,螺蛳,螺纹;v:盘旋;a:螺旋",
"spiral galaxy":"n:旋涡星云",
"spiral spring":"n:发条",
"spire":"n:尖顶,螺旋,螺线,尖峰;v:发芽",
"spirit":"n:白干儿,醇,劲头,情态,志气,潮流,心魄,阴魂,气,生命力,鬼怪,鬼物,精,老白干儿,醑剂,魂,灵台,妖精,药酒;v:鼓励,采,诱拐,拐带;a:精",
"spirit lamp":"n:酒精灯",
"spirit up":"n:激励",
"spirited":"a:精神,烈性,神气",
"spiritless":"a:没精打采,死气沉沉,蔫",
"spirits":"n:情绪,神志,鬼神,酒",
"spiritual":"n:心灵",
"spirituality":"n:精神,灵性",
"spirochete":"n:螺旋体",
"spit":"v:吐,说,点燃,蔑视,唾;n:唾液,涎,吐沫,岬",
"spit out":"v:唾",
"spite":"n:恶意,怨恨;v:欺负,妨碍,泄愤",
"spiteful":"a:刻毒",
"spitting":"v:分散;n:分散",
"spittle":"n:吐沫,唾,唾沫,唾液;v:唾",
"spittoon":"n:痰桶,痰盂",
"spiv":"n:懒汉",
"splash":"v:溅;n:污迹,色斑,游泳,斑点;d:扑通,咕咚",
"splatter":"v:溅,喷溅",
"splay":"n:斜面,展开;v:脱臼,张开",
"spleen":"n:脾脏,脾,发脾气,颓丧,忧郁,愤怒,发怒,消沉",
"splendid":"a:辉煌,漂亮,出色,光辉灿烂,灿烂,优秀,豪华,富丽堂皇,华,精彩,懋,绚烂,光彩,锦绣,美妙,韶,优,炳;n:锦绣,华;v:韶",
"splendor":"n:光辉,光彩,辉,光华,彩",
"splendour":"n:光辉,光耀,辉,豪华,显赫,壮丽,杰出,彩,光华,显著",
"splenic fever":"n:炭疽",
"splice":"v:拼接,拼合,移植,重组,接头;n:接头",
"spline":"n:键槽,齿槽,齿条",
"splint":"n:夹板,藤条,碎片,裂片",
"splinter":"v:分裂,劈开,裂开,碎裂;n:裂片",
"splintering":"v:碎裂",
"split":"v:分裂,分成,裂开;n:裂片,碎片,分化,裂口,柳条,奸细,派别",
"split up":"v:分化,离婚,四分五裂,吵架,分离",
"splits":"n:劈叉",
"splitter":"n:分离器,分解器",
"splitting":"n:分裂,裂解;v:裂解",
"splodge":"n:污迹,污点,斑点",
"splosh":"v:溅,泼",
"splotch":"n:斑点,污点,污迹;v:沾污",
"splurge":"n:摆阔,炫耀;v:挥霍,炫耀,卖弄,夸示",
"splutter":"n:分离器,劈里啪啦,分解器;d:劈里啪啦",
"spoil":"v:宠坏,破坏,坏,宠,弄坏,糟蹋,败,溺爱,惯,损坏,抢劫,奉承,娇惯,妨碍,糟踏,腐败,惯纵,娇,娇纵,糟践,伤害,掠夺,作践,残损,搅和,毒化;n:残,娇,职位,次品,废品,掠夺",
"spoilage":"n:废品,损坏,损耗;v:损坏",
"spoiled":"v:残损",
"spoils":"n:赃物,贼赃;v:渔利",
"spoke":"n:轮辐,辐,车条,辐条",
"spoken language":"n:言语",
"spokesman":"n:发言人,代言人",
"spokesperson":"n:发言人,代言人",
"spoliation":"n:掠夺,销毁,窜改,腐败,冒领,抢劫",
"sponge":"v:吸收,消除,敲诈,乞讨,揩油;n:海绵",
"sponge cake":"n:蜂糕,发糕",
"sponge gourd":"n:丝瓜",
"sponge on":"n:揩油",
"sponger":"n:吸血鬼,寄生虫",
"spongy":"a:肉,松软,泡,糠;n:糠,肉",
"sponsor":"n:介绍人,保证人,策划者,倡议者,召集人,主办者,担保人,教父;v:创办,担保",
"spontaneity":"n:自发",
"spontaneous":"a:自发,自动,圆浑;d:自发",
"spontaneously":"d:自然而然,不禁",
"spoof":"v:哄骗,开玩笑;n:戏弄",
"spoofing":"v:哄骗",
"spook":"n:鬼;v:惊吓",
"spool":"n:卷轴,轴线,卷,轴,管,卷筒",
"spoon":"n:匙;v:迷恋,动手动脚",
"spoonful":"n:匙",
"spoor":"n:脚迹,足迹",
"sporadic":"a:零落,哩哩啦啦,零星",
"spore":"n:孢子,芽孢,原因,根源",
"spore case":"n:孢子囊",
"sport":"n:运动,体育,运动会,娱乐,游泳,消遣,运动员,钓鱼;v:开玩笑,浪费,游戏,打猎,运动",
"sport car":"n:跑车",
"sporting":"v:运动,打猎,比赛",
"sports":"n:竞技,体育运动,体育,运动",
"sports meeting":"n:运动会",
"sportsman":"n:运动员,赌徒",
"sportswear":"n:运动衣,运动服",
"sportswoman":"n:运动员",
"spot":"n:点,斑点,地点,现场,找到,夜总会,斑,发现,场,污点,疤痕,点缀,黑子,看出,现货,阴影,场所,点子,布置,处境,缺点,污辱,少量,少许,疵点,认出;v:点缀,识别",
"spot check":"n:抽查,抽样调查",
"spot welding":"n:点焊",
"spot-check":"v:抽查,抽样",
"spotless":"a:一尘不染,洁净;v:一尘不染",
"spotlight":"n:聚光灯,注意",
"spots":"n:现货",
"spotted":"a:麻,斑;v:斑",
"spotter":"v:溅射;n:侦察机",
"spousal":"n:结婚",
"spouse":"n:配偶,爱人,偶,夫,妻,特;v:嫁,配;d:特",
"spout":"n:喷嘴,倾盆大雨,瀑布,筒子,喷管,导管,水柱;v:喷,喷水,喷射,高谈阔论,朗诵,迸,吟诵",
"sprain":"v:扭伤,扭,戳,扭动;n:扭伤",
"sprang":"v:网眼;n:网眼",
"sprat":"n:瘦子,小个子,小孩子,灯心草,年轻人,年青人,小人物",
"sprawl":"n:散乱,毅力,蔓延;v:铺展",
"spray":"v:喷,喷洒,喷射;n:水珠",
"spray paint":"v:喷漆",
"spray painting":"n:喷涂,喷漆",
"sprayer":"n:喷雾器,喷油器,喷子",
"spraying":"v:喷镀;n:喷雾",
"spread":"v:蔓延,传播,涂;n:伸展,扩张,牧群,床罩,分布,宴会,流行,延伸,桌布;a:广",
"spread out":"v:铺设,伸张,罗,发,铺开,披,展,摊,衍,展开,褰",
"spread over":"v:蔽,遍布,传遍",
"spreader":"n:扩张器",
"spreading":"v:伸展",
"spree":"n:狂欢,狂饮;v:狂欢",
"sprig":"n:少年,小家伙",
"sprightliness":"n:活泼,生气勃勃,愉快",
"sprightly":"a:活泼,明快",
"spring":"n:春天,弹簧,春季;v:发芽,升起,耸立,跳跃,跳出,绷",
"spring balance":"n:磅秤",
"spring beauty":"n:马齿苋",
"spring chicken":"v:年轻人",
"spring mattress":"n:弹簧床",
"spring onion":"n:小葱",
"spring roll":"n:春卷",
"spring up":"v:出现,发出,崛起,兴起,发芽",
"spring-clean":"v:清扫,大扫除",
"springboard":"n:跳板,出发点",
"springbok":"n:羚羊",
"springiness":"n:湿润,弹性,轻快",
"springing":"v:弹跳",
"springs":"n:弹簧,弓子",
"springtime":"n:春天,初期,春季,早期,青春",
"sprinkle":"v:撒,洒;n:少量",
"sprinkler":"n:洒水车,喷壶",
"sprinkling":"n:零星,洒,少量,点滴,撒,许多,撒布,喷雾",
"sprint":"v:冲刺;n:短跑",
"sprite":"n:妖怪,鬼怪,鬼魂",
"spritz":"n:水花;v:喷水",
"sprocket":"n:链轮",
"sprocket wheel":"n:链轮",
"sprog":"n:新手",
"sprout":"v:发芽;n:苗,年轻人,出芽生殖,秧",
"sprouting":"v:发芽,分枝;n:分枝",
"spruce":"n:云杉;v:整洁;a:整洁",
"spry":"a:轻快",
"spume":"n:泡沫",
"spun yarn":"n:麻纱",
"spunk":"n:愤怒,急躁,火星,种,胆量,生气,火绒,精神,勇气",
"spur":"n:刺激;v:教唆,驱赶,驱迫",
"spurious":"a:乱真,赝",
"spurn":"v:唾弃;n:拒绝,唾弃,藐视",
"spurt":"v:冲刺,喷,蹿,喷射,突发,迸,喷薄欲出,发芽,一鼓作气,喷溅,生长;n:迸发,冲刺,突发",
"spurting":"v:分散,溅射;n:分散",
"sputter":"n:吵闹,争论;v:飞溅,停息",
"sputtering":"v:溅射,雾化",
"sputum":"n:痰,唾液,唾沫",
"spy":"n:间谍;v:特;d:特",
"squab":"n:雏,雏鸟,小鸟,小姑娘,少女",
"squabble":"v:争吵,吵;n:吵架",
"squad":"n:班,小分队,小组,警车,小队",
"squad car":"n:巡逻车",
"squadron":"n:中队,方阵,连,团体,舰队",
"squall":"n:暴风,麻烦,尖叫,暴雨,困难;v:嚎哭",
"squalor":"n:肮脏,贫困,悲惨,卑劣",
"squander":"v:浪费,挥霍,四散,抖搂;n:浪费,挥霍",
"square":"n:广场,正方形;v:抗议;a:见方",
"square away":"v:备齐",
"square bracket":"n:方括号",
"square foot":"n:平方尺",
"square matrix":"n:方阵",
"square measure":"n:面积",
"square meter":"n:平米,平方,平方米",
"square up":"v:抗议,责备",
"squareness":"n:一丝不苟,方正,正直,公正,矩形",
"squarer":"n:石匠;v:改造",
"squaring":"n:自乘;v:自乘",
"squash":"n:南瓜;v:压制,镇压,压服",
"squashing":"v:捣碎",
"squat":"v:蹲,蹲伏,坐,大便",
"squawk":"v:发牢骚,诉苦,告密,抗议;n:抗议",
"squawk box":"n:扬声器",
"squeak":"d:吱,咿呀;n:机会;v:吱",
"squeal":"v:号叫,告密;n:抗议",
"squealing":"v:号叫",
"squeamish":"a:吹毛求疵,娇,娇气;v:吹毛求疵",
"squeeze":"v:挤,挤压,挤出,榨,塞,榨取;n:佣金,拥挤",
"squeeze out":"v:轧,排挤,挤出,凌轹",
"squeezer":"n:剥削者",
"squeezing":"v:挤压",
"squelch":"v:咕唧,镇压;n:镇压,压制;i:吧唧",
"squib":"n:补白,讲话,爆竹",
"squid":"n:鱿鱼,鱿,枪乌贼",
"squint":"v:乜斜,斜视;n:斜视;d:斜视",
"squire":"n:乡绅;v:侍从",
"squirm":"v:蠢动,蠕,折腾,蠕动;n:蠢动,蠕动",
"squirming":"v:蠕蠕",
"squirrel":"n:松鼠,威士忌酒,怪人,疯子,灰鼠",
"squirt":"n:喷,水枪,注射器;v:注射",
"squirt gun":"n:喷射器",
"squish":"n:果酱",
"stab":"v:刺,刺伤,捅,扎,刺痛,戳;n:刺,戳,刺痛,刺伤,试图,努力,中伤",
"stabber":"n:刺客",
"stabilise":"v:稳定,稳固",
"stability":"n:稳定性,稳定,坚定,巩固",
"stabilization":"n:稳定,固定,坚定",
"stabilize":"v:稳定,安定,平服,稳;a:稳",
"stabilizer":"n:稳定剂",
"stable":"a:稳定;n:妓院",
"stable companion":"n:同学",
"stableman":"n:马倌,马夫",
"stables":"n:牢",
"stabling":"n:马厩,牛棚",
"stabs":"n:赌注",
"stack":"n:烟囱,堆栈;v:竖起,堆叠;a:大量",
"stack up":"v:摞",
"stacking":"v:堆垛",
"stadium":"n:体育场",
"staff":"n:人员,职员,员工,拐杖,手杖,参谋部,五线谱,人马,僚属,标尺,同事,干部,标竿,竿,教职工,谱表,棒,棍棒,杖,杆,路签,指挥棒,支柱",
"staff member":"n:属员",
"staff officer":"n:参谋",
"staff sergeant":"n:上士",
"staffer":"n:职员",
"stag":"v:监视,告发",
"stage":"n:阶段,舞台,台,站,级;v:筹办,发起",
"stage fright":"n:怯场",
"stage name":"n:艺名",
"stagecraft":"n:经纶",
"stagger":"v:摇摇晃晃,踉跄,错开,动摇,蹒跚,趔趄,犹豫;n:摇晃,眩晕;a:参差",
"staggered":"v:交错",
"staggering":"a:参差",
"staggeringly":"d:大模大样",
"staggers":"v:眩晕",
"staging":"n:构架,上演,工作台,脚手架",
"stagnancy":"n:不景气,萧条,停滞,呆滞,迟钝",
"stagnant":"a:滞,死气沉沉,沉滞,淤,呆滞",
"stagnate":"v:停滞,停滞不前,停顿,迟钝,滞,沉滞,墨守成规,瘀,呆,凝滞,淤",
"stagnation":"n:停滞,不景气,萧条,迟钝;v:停滞",
"staid":"a:稳重,沉稳,稳",
"staidness":"n:认真",
"stain":"n:污迹,污点;v:生锈,渍,沾染",
"stained":"v:染污",
"stainer":"n:染料",
"staining":"n:染色;v:锈蚀",
"stainless":"a:无瑕,清白",
"stair":"n:楼梯,一级,阶梯,梯级",
"staircase":"n:楼梯,阶梯,梯子,梯,扶梯",
"stairs":"n:阶梯,楼梯,梯",
"stairway":"n:楼梯",
"stake":"n:桩,赌注;v:赌,压宝",
"stakes":"v:注",
"staking":"v:绑架",
"stalactite":"n:钟乳石,石钟乳",
"stalactites":"n:石钟乳",
"stalagmite":"n:石笋",
"stale":"a:腐,陈腐,滥;n:笑柄,尿;v:走味",
"stalemate":"n:僵局,相持,僵持,困境",
"stalemated":"v:胶着",
"staleness":"n:泄气",
"stalin":"n:斯大林",
"stalk":"n:花梗;v:高视阔步,搜索",
"stalking-horse":"n:托词,假托,借口,掩饰",
"stalks":"n:秸",
"stall":"n:借口,拖延,床子,口实,推托,牛棚,售货摊;v:挨,逃避,停止,阻挡,迟延,授予,停顿",
"stallion":"n:种马,儿马",
"stalls":"n:正厅",
"stalwart":"a:魁梧,魁岸,五大三粗,伟岸",
"stamen":"n:雄蕊,花蕊,花须,绢丝",
"stamens":"n:雄蕊",
"stamina":"n:耐力,体力,精力,毅力,持久力,后劲",
"stammer":"n:口吃;v:磕巴",
"stammering":"a:结结巴巴;n:口吃",
"stamp":"n:邮票;v:戳,捣碎,盖戳,打印,印刷,跌足,跺",
"stamp album":"n:集邮簿",
"stamp collecting":"n:集邮",
"stamp out":"v:平息",
"stamp pad":"n:印台",
"stamp tax":"n:印花税",
"stampede":"v:惊,溃散,一哄而散;n:溃逃",
"stamper":"n:靴子,印章",
"stamping":"v:冲压,捣碎;n:冲压",
"stamping ground":"n:落脚处",
"stance":"n:姿态,态度,架式,架势,架子",
"stanch":"v:止血",
"stanchion":"n:支柱,柱子",
"stand":"v:在,站,起来,要,站立,立,忍受,坚持,坐落,离开,位于,容忍,准备,站住,经受,屹立,受,监督,参加;n:台,停止;p:经",
"stand by":"v:信守,在场,靠近,援助,准备",
"stand fast":"v:坚持,固守",
"stand firm":"v:巍然屹立",
"stand for":"v:主持,代替,竞选,象征,主,主张,为",
"stand guard":"v:放哨,守望",
"stand in":"v:处于,参加,加入",
"stand out":"v:暴,冒尖儿,显著,突出,醒目,显眼",
"stand still":"v:站住,停滞不前,伫立,停顿",
"stand up":"v:起来,起,翻身,作,谡",
"stand watch":"v:警戒",
"stand-in":"n:替身,门路,照顾,偏袒,线索",
"standard":"n:标准;a:标准;v:训,雅正",
"standard time":"n:标准时",
"standard-bearer":"n:旗手,领袖",
"standardization":"n:标准化,正规化,标定,规范化;v:正规化",
"standardize":"v:标准化,正规化,标定",
"standardized":"v:划一,正;a:正",
"standardizing":"v:标准化,校准",
"standards":"n:规程,规格",
"standby":"n:备用,备品,靠山,备用品,党羽;v:备用",
"standing":"n:地位;a:直立",
"standing committee":"n:常务委员会,常委会",
"standing order":"n:规程",
"standoff":"n:离开,抵消,隔开,和局,停工,孤立,疏远",
"standoffish":"a:落落寡合",
"standpipe":"n:水鹤",
"standpoint":"n:观点,立场,立足点",
"standstill":"n:停顿,停止,搁浅,整顿",
"stanford":"n:斯坦福",
"stank":"v:坝,池塘,堰,水沟",
"stanza":"n:节,章",
"stapes":"n:镫骨",
"staphylococcus":"n:葡萄球菌",
"staple":"n:主题;v:分级,分拣,分类;a:大宗",
"staple fiber":"n:人造纤维",
"stapler":"n:钉书机,订书机",
"stapling machine":"n:订书机",
"star":"n:恒星,星星,星,明星;v:主演",
"star anise":"n:八角,大茴香",
"star shell":"n:照明弹",
"starch":"n:淀粉,浆,严格,精力;v:上浆",
"starchiness":"n:拘泥",
"starching":"v:上浆",
"starchy":"a:拘执",
"stardust":"n:宇宙尘,星团",
"stare":"v:盯,瞪,凝视,注视,瞪眼,凝望;n:凝视;a:睽睽",
"starfish":"n:海星",
"stargaze":"v:想入非非,凝视",
"stargazer":"n:空想家",
"stargazing":"n:心不在焉,空想,凝视",
"staring":"v:显然",
"stark":"a:僵",
"starkly":"d:完全,全然,简直",
"starlight":"n:星光",
"starred":"a:元帅",
"stars":"n:星辰,星星,星斗",
"start":"v:开始,动身,出发,发动;n:着手,努力,冲动,发作,起程,弯曲",
"start out":"v:着手,开始",
"start up":"v:开动",
"starter":"n:酵母,诱因,原因,起动机,发令员,启动器",
"starting":"n:开始,出发,起动,开车,开动;v:投产,加速,加快,起步",
"starting line":"n:起跑线",
"starting point":"n:着眼点,出发地,起点,出发点",
"starting post":"n:出发点,起点",
"startle":"v:震惊,大吃一惊,惊动;n:吃惊,震惊",
"startling":"a:触目惊心;v:触目惊心",
"starvation":"n:饥饿,绝食,粮荒",
"starve":"v:饿,挨饿,饥饿,渴望,绝食,饿饭,揭不开锅",
"stash":"v:停止,贮藏,藏匿,隐藏",
"stasis":"n:停滞;v:阻塞,停滞",
"state":"n:状态,国家,州,政府,状况,情况,态,国,情形;v:陈说,申明,申述,陈诉,称,指定,候,述说,启,白,开宗明义",
"state of affairs":"n:情形,情况,局,势,情状,状态",
"state of mind":"n:心怀,心思,兴致,神魂,心情,心肠",
"statecraft":"n:经纶",
"stateliness":"n:庄严,堂皇,华贵,雄壮",
"stately":"a:庄严,威严,厚重,堂皇;d:堂而皇之",
"statement":"n:语句,声明,说法,命题,陈述,谈话;v:陈述,谈话",
"stateroom":"n:大厅",
"statesman":"n:政治家",
"statesmanship":"n:经纶",
"statesmen":"n:政治家",
"static":"n:静电,天电,杂音,口角,争吵;a:静止",
"static electricity":"n:静电",
"statics":"n:静力学,静态,静电",
"station":"n:车站,站,电台,所,地位,台;v:配置,扎,安置,屯,设置",
"station house":"n:车站,派出所",
"station wagon":"n:旅行车",
"stationary":"n:稳定,驻军",
"stationer":"n:文具店,书商",
"stationery":"n:文具,信纸,笔札,文房四宝",
"stationmaster":"n:站长",
"statistics":"n:统计,样本,统计表,统计学",
"stator":"n:定子",
"statuary":"n:雕像,塑像,雕刻家",
"statue":"n:雕像,塑像,法律",
"stature":"n:身材,身段,个儿,身高,身长,身量,身躯,个子,才干",
"statures":"n:个子",
"status":"n:状态,地位,状况,身份,体质,现状,资格,位,身价,情形",
"status quo":"n:现状,原状",
"statute":"n:法令,章程,法律,法规,规则,律,条例,宪",
"statute book":"n:法典",
"statute law":"n:成文法",
"statutes":"n:章程,法令,例",
"statutory":"a:法定",
"staunch":"a:坚定,坚强,忠诚,烈,忠贞,顽强;v:停止,制止,止血",
"stave":"v:击穿,延缓,赶走,避开,猛冲,突进,拆散;n:木棒,诗句,辐,谱表,棒,棍,五线谱",
"stave in":"v:击穿,穿孔,凿孔,穿透",
"stave off":"v:躲开,赶走",
"stay":"v:在,呆,住,留,待,留下,坚持,保持,停留,逗留;n:撑杆,持久,中止,妨碍,延期",
"stay away":"v:外出,躲开",
"stay of execution":"n:死缓",
"stay off":"v:远离",
"stay put":"v:站住脚,居",
"stay up":"v:熬夜",
"staying power":"n:耐力,后劲",
"std":"n:标准",
"stead":"n:好处,替代,代替,用处",
"steadfast":"a:坚,坚定;v:始终不渝",
"steadier":"n:支座",
"steadily":"d:稳步",
"steadiness":"n:坚定,始终如一,均匀,稳当,稳固",
"steady":"a:平稳,稳;v:沉着;n:未婚夫,情人,承,台",
"steak":"n:牛排,肉排",
"steal":"v:偷,偷窃,偷走,盗窃,偷盗,溜,窃取,窃,侵占,扒窃,笼络,盗取;n:偷窃,赃物",
"steal away":"v:蒙混过关",
"stealing":"v:盗窃,偷窃,欺骗,赃物",
"stealth":"n:隐形,鬼祟",
"stealthily":"d:偷偷,潜,偷,偷偷摸摸,暗中",
"stealthy":"a:鬼鬼祟祟,偷偷摸摸,贼头贼脑,鬼,鬼祟,鬼头鬼脑,悄悄的",
"steam":"n:蒸汽,蒸气,水蒸气,水汽,轮船;v:煮,炒,喝酒,喝醉,馏,出汗,鼓励,蒸发",
"steam bath":"n:蒸汽浴,蒸气浴",
"steam turbine":"n:气轮机,汽机",
"steam whistle":"n:汽笛",
"steamboat":"n:汽船,轮船,汽艇,轮",
"steamer":"n:轮船,汽船,蒸汽机,轮,蒸锅,蒸笼,航船,笼,气锅",
"steaming":"v:蒸;a:腾腾",
"steamship":"n:轮船,航船,汽船",
"stearic acid":"n:硬脂酸",
"steed":"n:马,骏马,骏",
"steel":"n:钢,钢铁,钢材,坚硬,刀,钢骨,小刀,剑;v:锻炼,锤炼,刺杀",
"steeliness":"n:冷酷",
"steels":"n:钢材",
"steelyard":"n:杆秤,秤,铨",
"steep":"v:浸泡,精通,泡,浸透,沉浸;n:泡,绝壁,悬崖,陡坡,浸,峭壁;a:直线;d:直线",
"steeple":"n:高耸,尖顶",
"steeplechase":"n:赛马",
"steeplejack":"n:烟囱",
"steepness":"n:险峻",
"steer":"v:驾驶;n:公牛,忠告,建议",
"steerage":"n:统舱,操纵,驾驶,船尾,领导",
"steering":"n:导向,驾驶,控制,劝告,操纵,领导,掌舵,转向,指导;v:导向,引导",
"steering wheel":"n:方向盘,舵机",
"steersman":"n:舵手,司机",
"stem":"n:茎,杆,柄,把;v:阻遏,抵抗,发生",
"stench":"n:臭气,腥臭;a:腥臭",
"stencil":"n:模板,蜡纸",
"stenographer":"n:速记员",
"stenography":"n:速记",
"step":"n:台阶,步骤;v:砌,伸腿,介入,跨入,走步,升压",
"step by step":"a:渐渐,循序渐进,缓缓,按部就班,浸",
"step down":"v:降压",
"step forward":"v:进步,开步",
"step in":"v:步入,跨入,伸腿,介入",
"step on":"n:跋,蹑,蹋,跐,踏,履,登",
"step up":"v:升压,加紧",
"stepchild":"n:继子",
"stepfather":"n:继父,后爹",
"stepladder":"n:梯子",
"stepmother":"n:继母,阿姨,后妈,后娘,后母,晚娘",
"steppe":"n:草原",
"stepping":"v:分级",
"stepping stone":"n:敲门砖",
"steps":"n:阶梯,阶,梯",
"stepson":"n:继子",
"stereo":"n:立体声,立体",
"stereophonic":"a:立体声;n:立体声",
"stereoscopic":"a:立体",
"stereotype":"n:陈规,定型,旧框框,成规,铅版,常规,旧习",
"stereotyped":"v:公式化,陈规,划一不二,千篇一律;a:呆板",
"sterility":"n:无效,不孕,贫乏,中性;v:不孕",
"sterilization":"n:灭菌,消毒,绝育",
"sterilize":"v:绝育,消毒,灭菌,杀菌",
"sterling":"n:英磅",
"stern":"a:严厉;n:尾巴",
"sternness":"n:严格",
"sternum":"n:胸骨",
"stethoscope":"n:听诊器,听筒",
"stevedore":"v:装,装货,卸货",
"stew":"v:炖,煮,着急,熬汤,扒,焦虑,熬,发昏;n:混合物,酒鬼,硝化甘油,噪声,妓院,忧虑",
"steward":"n:服务员,干事,乘务员,管家,管事,茶房,理事,招待员,审判长",
"stewardship":"n:经营,处理,管理",
"stick":"v:支,排字,粘着,坚守,撑持,直立,巴,顾忌;n:郊区,木棒,哨棒,梗,手柄",
"stick by":"n:忠于",
"stick in":"n:别,栽,扦",
"stick insect":"n:竹节虫",
"stick out":"v:暴,竖起,探,挺",
"stick to":"n:执,复活,执著,救活,附着,巴,执着;v:巴",
"stick together":"v:粘着,坨",
"stick up":"v:翘,噘,直立,突出",
"stick with":"n:紧追不舍",
"sticker":"n:滞销品,尖刀,滞销货,邮票,陈货,签,屠夫",
"stickiness":"n:粘性,黏性",
"sticking":"v:粘附,附着",
"sticking out":"n:突出",
"stickpin":"n:领带夹",
"stickup":"n:抢劫",
"sticky":"a:粘,黏;v:粘",
"stiff":"a:板,死硬,硬性,板滞,生;n:笨蛋,钞票,死尸;v:挺,硬挺",
"stiffen":"v:硬,加强,僵直,上涨,硬化",
"stiffened":"v:紧绷绷",
"stiffener":"n:补药",
"stiffening":"v:硬化,加固",
"stiffness":"n:刚度,刚性,硬度,坚硬;a:坚硬",
"stifle":"v:窒息,压制,打垮,镇压,藏匿,埋没,熏蒸,隐蔽,阻止,憋闷",
"stifled":"a:堵;v:堵",
"stifling":"a:压抑;n:强压;v:熏蒸",
"stigma":"n:柱头,烙印,耻辱,符号;v:压制",
"stigmatic":"v:同心;a:同心",
"stigmatization":"n:描绘",
"stigmatize":"v:戴帽子,诬蔑",
"stiletto":"n:短剑,匕首",
"still":"d:还,仍,仍然,还是,依然,更,仍旧,尚,再,依旧,尽管如此;a:静谧,但;v:安生,遏制,烧,蒸馏,镇静;n:剧照,无声,蒸馏器,寂静;c:但,但是,然而",
"still life":"n:静物画",
"still room":"v:酒窖",
"stillbirth":"n:死胎",
"stillness":"n:寂静,平静",
"stilt":"n:脚,高跷,腿",
"stilts":"n:高跷",
"stimulant":"n:兴奋剂,酒",
"stimulant drug":"n:兴奋剂",
"stimulate":"v:刺激,促进,激发,鼓励,激励,激,振奋,鼓舞,喝酒,增强,发动,刺",
"stimulated":"v:亢奋",
"stimulation":"n:刺激,激励,兴奋,鼓励;v:刺激",
"stimulative":"a:兴奋剂",
"stimuli":"n:刺激",
"stimulus":"n:刺激,激励,针,刺;v:刺激",
"sting":"n:刺;v:激励,抢;a:辣",
"stinger":"n:螫针,针,刺,痛击",
"stinginess":"n:吝啬,不足",
"stingy":"a:吝啬,小气,悭,啬,贫气,小手小脚,吝,悭吝,抠搜,抠,抠门儿,薄",
"stink":"n:臭,臭味,臭气,丑事,自然科学,恶臭,丑闻;v:腐臭,回嘴,恶臭,反驳;a:臭",
"stink out":"v:发臭",
"stink up":"v:发臭",
"stinkbug":"n:蝽,臭虫",
"stinker":"n:难题",
"stinking":"a:臭,卑鄙,腐臭,腥气;d:极,非常;v:腐臭,腥气",
"stinky":"a:臭乎乎",
"stint":"v:节省,限制;n:定量,限制",
"stipend":"n:退休金,薪水,助学金",
"stipulate":"v:规定,要求,约定,保证",
"stipulation":"n:规定,条款,订约,项目",
"stir":"v:动,引起,激动,起床,激起,搅拌;n:感动,活动,冲,刺激,激动,运动;a:激动",
"stir up":"v:拨弄,鼓,搅扰,挑,撩,转播,激起,捅,搅拌,挑起,引起,抖,掇弄,煽,扇动,扇,调弄,激发,挑拨,挑动,重播",
"stirrer":"n:搅拌器",
"stirring":"v:搅动,搅和,震撼人心,搅拌;a:热烘烘",
"stirrup":"n:马镫,镫",
"stitch":"v:缀;n:一点儿,线脚",
"stitching":"v:滚压,缝纫;n:缝纫",
"stoat":"n:鼬",
"stochastic":"a:随机",
"stock":"n:股票,存货,贮存,股份,进货,相信,原种,血统,砧木,枪托,估量,资本;v:堆集,放养,找回,贮备,屯,蓄积;a:繁殖",
"stock company":"n:股份公司",
"stock up":"v:储藏,找回,储存",
"stock-in-trade":"n:存货",
"stockade":"n:栅栏,寨",
"stockholder":"n:股东",
"stockholm":"n:斯德哥尔摩",
"stockily":"d:矮胖",
"stocking":"v:聚集,堆集,放养,配种;n:长统袜,长袜",
"stockings":"n:袜,袜子,长袜",
"stockpile":"n:核武器,资源;v:积存,积贮",
"stockpiling":"n:贮存,堆存,积存;v:堆积",
"stockpot":"n:汤锅",
"stocktaking":"n:估量,盘货",
"stocky":"a:敦实,壮实",
"stodge":"n:狼吞虎咽,搅拌,暴食",
"stoke":"v:司炉",
"stoker":"n:司炉,火夫",
"stolid":"a:麻木不仁",
"stoma":"n:气孔,口,气门",
"stomach":"n:胃,肚子,腹部,胃口,肠胃,腹,食欲,欲望,肚,志趣,嗜好;v:忍耐,消化",
"stomacher":"n:腰带",
"stomp":"v:跺脚;n:跺脚",
"stone":"n:石头,石块,石,宝石,石料,纪念碑,核,结石,核儿,石碑,雹,英石,磐石,里程碑,砧,短距离",
"stone fruit":"n:核果",
"stone pit":"n:采石场",
"stone-broke":"a:不名一文",
"stonemason":"n:石匠",
"stonewalling":"v:石墙",
"stonework":"n:工程,石方",
"stonily":"d:木呆呆;a:木呆呆",
"stoning":"v:磨刀",
"stooge":"n:密探,走狗,走卒,奸细,特务,傀儡,帮闲",
"stool":"n:凳子,凳,大便,粪便;v:分蘖",
"stoop":"v:堕落,俯身,弯腰,弯;n:游廊,门廊",
"stop":"v:停,停止,停下,阻止,已,制止,拦住,停车;n:光圈,停泊,妨碍;f:为止;d:已",
"stop over":"v:落脚,耽搁,勾留,羁留,落,淹",
"stop up":"v:窒,犁,壅,闭塞,阻碍,闭,堵",
"stop watch":"n:跑表",
"stopcock":"n:活塞,水龙头",
"stopgap":"n:权宜之计,搪塞,敷衍,填补,充数",
"stoplight":"n:红灯",
"stopover":"n:次,途次",
"stoppage":"n:扣除,停工,停止,阻塞,罢工,中止,阻止,便秘,堵塞;v:截止,停止",
"stopper":"n:塞子,制动器,掣,耳塞;v:塞",
"stopping":"n:阻止,隔墙,停止,回采;v:制动,回采,阻止",
"stopple":"n:塞子",
"stopwatch":"n:停表,秒表,跑表,马表",
"storage":"n:存储,存储器,贮藏,仓库,记忆,装载,保管,库藏,堆存;v:蓄积,堆放,装载",
"storage cell":"n:蓄电池",
"storage room":"n:库房",
"storage tank":"n:油罐",
"store":"v:存储;n:货栈",
"storefront":"n:店面,铺面",
"storehouse":"n:仓库,宝库,堆栈,库房,粮栈,府,栈,仓房,堆房,栈房,仓,库",
"storekeeper":"n:店主,保管员,经理,滞销货,店家",
"storeroom":"n:储藏室,堆房,库房",
"storey":"n:层,楼层",
"storing":"v:聚集,堆积",
"stork":"n:鹳,白鹳",
"storm":"n:暴风雨,风暴,暴风雪;v:怒骂,强击",
"storm lamp":"n:风灯",
"storminess":"n:吵闹,猛烈,急性子,骚乱",
"stormy":"a:暴风雨,风急浪大,风狂雨骤",
"stormy petrel":"n:海燕",
"story":"n:故事,小说,报道,经历,情节,情况,传说,叙述,历史,楼,传记,谎话,真情,假话,传奇,内情,来历,沿革,阅历,原作;v:闻",
"storytelling":"n:评书",
"stoup":"n:酒壶",
"stout":"a:结实,胖,强健,粗壮,肥实,虎背熊腰;n:胖子",
"stoutness":"n:坚固",
"stove":"n:炉子,火炉,电炉,加热炉,烟斗,窑,温室,加热器",
"stovepipe":"n:闲谈,烟筒,火炉,裤子,囱",
"stow":"v:收藏,装,堆垛,卷起,装载,停止,隐藏,贮藏",
"stowage":"n:贮藏,仓库,食量,装载,食欲",
"stowing":"v:充填",
"straddle":"v:跨,骑墙,骑,加倍;n:立柱,大踏步",
"straddling":"v:骑墙",
"strafe":"v:扫射,轰炸,惩罚;n:惩罚",
"strafing":"v:扫射",
"straggle":"v:蔓延,迷路,迷途,蓬乱,离散,零落,零乱,掉队,流离,落后,落伍,四散",
"straggling":"v:离散",
"straight":"d:直,一直;a:直撅撅,直挺挺,端端正正,直溜,端,直溜溜,挺;v:端,挺;n:直线",
"straight line":"n:直线",
"straight off":"v:痛痛快快,立刻,马上",
"straightaway":"d:径直",
"straightedge":"n:直尺,标尺",
"straighten":"v:直,挺直,整理,伸直,端正,矫正,理顺,纠正,梗,整饬,整顿",
"straighten out":"v:矫,整饬,矫正,理顺,整理",
"straighten up":"v:挺",
"straightener":"n:整流器",
"straightforward":"a:直截了当,直率,明快,直性子;d:干脆,脆;n:直性子,粗线条;v:直通",
"straightness":"n:率直,直",
"straightway":"d:马上,径直,径,立刻",
"strain":"n:应变,应力,紧张,种;v:强制,曲解,淋,强迫,劳损,渗出,扭伤",
"strained":"a:紧张,勉强,紧绷绷,牵强",
"strainer":"n:滤器,粗滤器,漏勺",
"straining":"v:过滤,下坠",
"strait":"n:海峡,口,地峡,穷困;a:艰难,窄",
"straiten":"v:收紧,限制",
"straits":"n:困境,海峡,困处",
"strand":"n:纤维,线,根,绞;v:围困",
"stranded":"v:搁浅",
"stranding":"v:触礁,搁浅;n:搁浅",
"strange":"a:奇怪,陌生,怪,古怪,奇异,新奇,反常,希奇,怪异,新鲜,冷,蹊跷,邪门儿,诡怪,古里古怪,诡异,生,怪诞,陆离,奇",
"strangeness":"n:奇妙,邪门儿",
"stranger":"n:陌生人,生人,外人,生客,客人,外国人,异乡人,新生儿,路人,门外汉,局外人,第三者",
"strangle":"v:勒死,扼杀,扼死,绞死,绞杀",
"stranglehold":"n:压制,束缚",
"strangulate":"v:勒死,绞死,压缩",
"strangulation":"n:窒息",
"strap":"n:皮带,带,带子,肩章,鞭子,赊;v:压缩",
"strapping":"v:捆扎,联接;n:滚边",
"straps":"n:提梁,背带",
"strata":"n:地层",
"stratagem":"n:计谋,策略,计,谋略,智术,诡计,花头,手腕,战略,胜算,机关,筹,机谋,疑阵,计策",
"strategics":"n:兵法,战略学,军事学,战略",
"strategist":"n:战略家,策士",
"strategy":"n:战略,策略,计谋,谋,谋略,策,略,权数;d:略",
"stratosphere":"n:同温层",
"stratum":"n:地层,岩层,阶层,层,大气层",
"straw":"n:稻草,吸管,草,麦草,头子,东西,垫脚,秸杆,助理,荞麦",
"straw mushroom":"n:草菇",
"strawberry":"n:草莓",
"stray":"v:走失,迷路,迷惘,游荡,漂泊,堕落,披散;n:流浪者,植物",
"strays":"n:天电",
"streak":"n:条纹,一连串,矿脉,一系列,划线,倾向,斑纹,矿层,纹理,暂时",
"stream":"n:河流,流,溪水,溪流;v:展开,招展,倾注",
"streamer":"n:流光,飘带,横幅,旒,幡",
"streamers":"n:帷幔",
"streaming":"v:涔涔,滂沱,环流;n:流动,环流",
"streamline":"n:现代化;v:流线型",
"streamline flow":"v:层流",
"streamlined":"a:流线型",
"streamlining":"v:流线型;a:流线型",
"streams":"n:水流",
"street":"n:街道,街,大街,马路,街头,街区,自由",
"street corner":"n:街头,转角",
"street girl":"n:妓女,娼妓",
"street sweeper":"n:清道夫",
"street theater":"n:活报剧",
"streetcar":"n:电车",
"streetlight":"n:路灯",
"streets ahead of":"p:胜过",
"streetwalker":"n:娼妓,妓女",
"strength":"n:力量,强度,体力,力气,实力,气力,力,浓度,全力,兵力,编制,长处,人数,劲,劲头,强项,骨力,威,笔力,底气,流速,利润,性子",
"strengthen":"v:加强,增强,坚强,充实,坚定,扩充,固,坚挺,强化,巩固,勉励,壮,壮大,健,健全,激励,上涨",
"strengthening":"v:加固",
"strenuous":"a:繁重,强烈,费力,吃力,吃重,粗重",
"strenuously":"d:力,强烈;n:力",
"streptococcus":"n:链球菌",
"streptomycin":"n:链霉素",
"stress":"n:应力;v:着重,突出,压;a:厚;d:着重",
"stretch":"v:伸,伸出,伸展,拉长,伸手,延伸,伸懒腰,绷,伸长;n:音段",
"stretch out":"v:伸出",
"stretchability":"n:拉长,铺开,曲解,紧张,夸大,伸张,延性",
"stretcher":"n:担架,谎话",
"stretching":"v:展开,扩展,拉伸,延伸",
"strew":"v:撒,播,点缀,散播",
"stria":"n:纹,线条,擦痕,条纹",
"striated muscle":"n:横纹肌",
"striation":"n:条纹,擦痕",
"strict":"a:严格,严,严谨,厉,凛,严刻,懔,森严,紧",
"strictly":"d:全然,的确,从严,断然,确实",
"strictness":"n:严格",
"stricture":"n:狭窄,限制,谴责,光束,非难,弹劾,束缚;a:狭窄",
"stride":"n:大步;v:跨,迈步,骑,放步",
"strife":"n:冲突,战争,倾轧,斗争,争吵,竞争,争斗;v:格斗,争斗",
"strike":"v:打翻,打垮,抵,勾,打劫,打落,伐,殴,闪击,一蹴而就,刺穿,击打,勾除,突袭,筛,结算,抹,鼓,取道,删除,摽,破灭,激怒,披荆斩棘,搁浅,空袭,碰,触发,到达,抓;n:罢课,钟声,打击,恐吓,铸模,殴打,讹诈,烈度,发现,报时,勒索,强度",
"strike back":"v:反击",
"strike down":"v:破灭,打垮,打翻",
"strike dumb":"v:哑口无言",
"strike home":"v:击中要害,一语道破",
"strike off":"v:披荆斩棘,勾销,一蹴而就",
"strike out":"v:勾销,删去,抹,勾,勾除,删除",
"strike up":"v:开始,结交",
"striker":"n:鱼叉,撞针,打手,锤",
"striking":"a:醒目,显著,奇特;v:点火,引人注目",
"string":"n:绳子,弦,线;v:拉长,扩张",
"string along":"v:愚弄",
"string bean":"n:豆荚",
"string out":"v:拉长",
"stringed instrument":"n:弦乐器",
"stringency":"n:紧缩,严重,逼迫,紧迫,严格,强度,说服力,迫切,严厉,紧急",
"stringent":"a:严格,紧",
"stringiness":"n:延性",
"strip":"v:扒,剥,剥落,拆除,劈,洗涤,摘,剥离,采,褫夺,挤出;n:条子,跑道",
"strip mine":"n:露天矿",
"stripe":"n:条纹,条子,鞭打,类型,类别,斑纹,条纹布,斑",
"striped":"a:斑",
"striping":"n:条纹",
"stripling":"n:年轻人,小伙子",
"stripping":"v:剥离,剥落;n:拆开",
"strips":"n:袖章",
"striptease":"n:脱衣舞",
"strive":"v:努力,奋斗,竞争,力求,钊,勉,强,争",
"strobe":"n:闪光灯,闸门",
"stroboscope":"n:万花筒,闪光灯",
"strode":"v:沼泽",
"stroke":"n:冲程,中风,击;v:摩,抚,摩挲,打,发作,抚弄",
"strokes":"n:中风",
"stroll":"v:逛,闲逛,散步,漫步,溜达,闲荡,遛,转悠,转;n:浪,流浪,闲逛,漫步",
"stroller":"n:流浪者,流氓",
"strong":"a:强烈,强,坚强,强壮,有力,坚固,结实,强有力,浓,坚挺,强硬,烈性,坚实,冲,铁,硬,浓厚,牢靠,巩固,壮,劲,烈,扎实,浓郁,有劲,坚,强固,精壮,够劲儿,硬棒,浓重,酷烈,强项,硬实;n:铁,劲,茁壮;d:刚",
"strong point":"n:强项,长",
"strong suit":"n:长处,优点",
"strong-arm":"n:暴力;v:殴打",
"strongbox":"n:保险箱",
"stronghold":"n:堡垒,据点,要塞,支撑点,根据地,大本营,碉堡;a:坚",
"strongly":"d:强烈,使劲",
"strongman":"n:红人,独裁者,强人,大力士",
"strontium":"n:锶",
"strop":"n:钢",
"strophe":"n:节",
"structural":"a:构造",
"structural member":"n:构件",
"structural steel":"n:型钢,结构钢",
"structure":"n:结构,构造,建筑物,组织,建筑,体,体制,格局",
"structures":"n:构筑物",
"struggle":"v:搏,干,打斗;n:拚命",
"strum":"v:乱弹",
"strumpet":"n:婊子,妓女",
"strut":"v:高视阔步,大摇大摆,支持,撑住,支撑,扭搭;n:撑杆,高视阔步",
"strutting":"v:大摇大摆",
"stub":"n:存根,根,票根;v:除根",
"stubble":"n:茬,短发,麦茬,楂",
"stubborn":"a:固执,顽固,倔强,执拗,拧,顽,愎,强,倔犟,泥,偏执,拗,梗;v:拧,固执己见",
"stubbornly":"d:一个心眼",
"stubbornness":"n:牛性,牛劲,死心眼儿,犟劲,牛脾气",
"stucco":"v:粉刷",
"stud":"n:马,销子,键钮,种马,立柱,轴,公畜,枢轴;v:竞争",
"student":"n:学生,学者,研究生,学员,研究者,生,学子,门下,门人,初学者",
"student union":"n:学生会",
"studio":"n:画室,工作室,播音室,演播室",
"studio couch":"n:躺椅",
"studious":"a:好学,热心,用功,笃学,专心",
"studiously":"d:努力",
"studiousness":"n:热心,认真,用功",
"study":"v:研究;n:习作,研究室,书斋,工作室,摩,书屋",
"stuff":"n:材料;v:狼吞虎咽",
"stuffer":"n:填充物",
"stuffiness":"n:闷气,窒息,闷热;a:闷热;v:窒息",
"stuffing":"n:馅儿,填料,馅,填充物;v:填充,装填",
"stuffy":"a:闷,自以为是,窒闷,闷气,齆",
"stultification":"n:愚弄",
"stultify":"v:愚弄",
"stumble":"v:绊倒,蹒跚,踌躇,结巴,弄错,撕裂,失足,磕磕绊绊,磕磕撞撞;n:结巴,失足,绊倒,差错,失误,过失,失败",
"stumbling":"a:磕磕绊绊,跌跌撞撞;n:绊脚石,障碍",
"stumbling block":"n:绊脚石,拦路虎",
"stump":"n:树桩,树墩,烟蒂,脚,考验,矿柱;v:挑衅,绊,抵抗,砍伐,绊倒,阻碍,蹒跚",
"stumpy":"a:矮墩墩",
"stun":"n:胡桃,震惊;v:惊愕",
"stunned":"v:发呆,愕然,惊愕,目瞪口呆;a:目瞪口呆",
"stunt":"n:特技,绝技;v:阻碍",
"stunting":"v:阻碍;n:阻碍",
"stupefaction":"n:麻木,茫然;a:麻木",
"stupefied":"v:愣,发呆,惊愕;a:木呆呆,木然",
"stupefy":"v:惊愕",
"stupid":"a:愚蠢,笨,蠢,无聊,傻,笨拙,呆头呆脑,胡涂,昏庸,冥顽不灵,愚笨,痴呆,混,愚,呆笨,钝,呆气,鲁钝,顽钝;n:笨蛋,傻瓜;v:一窍不通,混",
"stupid person":"n:二百五",
"stupidity":"n:愚蠢,愚笨,笨,愚钝,糊涂,傻劲儿",
"stupor":"n:麻木,昏迷,不省人事,昏呆",
"sturdily":"d:扎扎实实",
"sturdiness":"n:坚固",
"sturdy":"a:壮实,强壮,结实,皮实,粗壮,牢靠,硬棒,坚固,茁实,扎实,茁壮,刚劲,强健,壮健;n:劲",
"sturgeon":"n:鲔,鲟,鲟鱼",
"stutter":"n:口吃;v:磕巴",
"sty":"n:妓院,圈,针眼,栏,猪圈,麦粒肿;v:舍",
"style":"n:风格,文体,作风,式样,气派,笔调,款式,态度,派,花柱,样式,式,格调,体例,体,模样,样子,语调;v:称",
"styling":"n:式样;v:设计",
"stylish":"a:时髦,时新",
"stylishly":"d:时髦",
"stylist":"n:设计师",
"stylus":"n:笔,唱针,花柱,铁笔",
"stymie":"v:阻碍,从中作梗;n:阻碍",
"styrene":"n:苯乙烯",
"styrofoam":"n:泡沫塑料",
"styx":"n:冥河",
"su":"n:苏",
"suasion":"n:说服,劝告",
"suave":"a:飘洒,文质彬彬",
"suavity":"n:柔和,愉快,和蔼,温和",
"sub":"a:附属;n:潜水艇",
"subaltern":"n:部下,僚属;a:副,下,次",
"subbasement":"n:基础",
"subbranch":"n:支行,支店",
"subclass":"n:子集",
"subconscious":"n:下意识",
"subconsciousness":"n:下意识,潜意识",
"subcontinent":"n:次大陆",
"subdivide":"v:细分,区",
"subdivision":"n:细分,区",
"subduction":"n:减去,俯冲,扣除;v:俯冲",
"subdue":"v:征服,克制,镇压,制服,减轻,开拓,制胜,弹压,降,降伏,收服,驯养,压制,伏,折服,根除,减弱,制伏,摧折;n:克",
"subgroup":"n:簇,族,分组,小组;v:分组",
"subhead":"n:小标题,副标题",
"subheading":"n:细目,副标题,小标题",
"subject":"n:问题,我,题目,学科,主题,科目,话题,主体,主语,课,对象,臣民,国民,本题,原因,论题,题;v:提出,加,提供,交给,委托",
"subject matter":"n:内容,题目,论题,话题",
"subjection":"n:征服,屈从,服从,镇压",
"subjective":"a:主观,主;n:主格",
"subjectively":"d:臆",
"subjectivity":"n:主观,主观主义",
"subjects":"n:臣民",
"subjoin":"v:附加,增补,添加,追加",
"subjugate":"v:制服,亡,镇压,征服",
"subjugation":"n:克制,征服,镇压",
"sublease":"v:转租",
"sublet":"n:转租;v:转租",
"sublimate":"v:升华,提高,提纯;a:高尚;n:升汞",
"sublimation":"n:升华,提纯;v:升华",
"sublime":"v:升华,至高无上;n:宏伟;a:至高无上",
"subliminal":"a:下意识",
"sublimity":"n:崇高,精华,庄严,极点,化境,雄伟",
"sublingual gland":"n:舌下腺",
"submachine gun":"n:冲锋枪",
"submarine":"n:潜艇,潜水艇;v:袭击",
"submarine earthquake":"n:海震",
"submerge":"v:潜入,淹没,浸沉,沦陷,潜水,淹,灭,沉没,没,下沉,汨,消失,溺",
"submergence":"n:浸入,淹没,沉入,泛滥,潜水,下沉,沉没;v:沉没,淹没",
"submerse":"v:淹没,浸没",
"submersion":"n:淹没,下沉;v:淹没",
"submission":"n:屈服,投降,服从,提交,自白,谦逊,意见,建议,看法,呈递,柔顺;v:服从",
"submissive":"a:伏帖,柔顺,帖,贴,低三下四,伏贴,服贴;n:帖",
"submissively":"d:俯首听命,拱手",
"submit":"v:提交,屈服,提出,服从,认为,递交,提供,顺从,低头,投降,呈交,呈,上,上交,报请,顺服,委托,屈,呈递,进,就范",
"submitting":"v:顺服",
"subordinate":"n:下属,部属,下级;v:从属,轻视,属;a:次要",
"subordinates":"n:僚属,属下",
"subordination":"n:从属,服从,下属,次级,次要,次等,手底下;v:统属",
"suborn":"v:收买,唆使",
"subornation":"n:唆使",
"subplot":"n:穿插;v:穿插",
"subpoena":"v:传讯,传唤;n:传票",
"subprogram":"n:子程序",
"subroutine":"n:子程序",
"subscribe":"v:订阅,捐,同意,预订,捐助,捐款,认购,订,赞成,认捐,签名,签署,署名,预定,订购,定阅,预约",
"subscribe to":"v:定阅,订,订阅,定",
"subscriber":"n:用户,订户,定户,订购者",
"subscript":"n:下标,注脚,指标,索引",
"subscription":"n:订阅,捐款,预定,预约,订购,署名",
"subsection":"n:小节,小组,分部,条款,分段,分队,细目",
"subsequently":"d:随后,接着,嗣后;n:嗣后",
"subservience":"n:媚态",
"subservient":"a:奴颜婢膝,马屁精,看人眉睫",
"subset":"n:子集,小集团",
"subside":"v:平息,下陷,消退,减退,沉淀,下沉,沉降,伏,凹陷,平复,跪下,陷落,坐,塌陷,躺下,退烧",
"subsidence":"n:沉陷,平息;v:沉陷",
"subsidiary":"a:附属,辅助,附带,补给品,附属品,副;v:辅助,附属;n:子公司",
"subsidiary company":"n:子公司",
"subsidiary ledger":"n:明细账",
"subsidies":"n:贴",
"subsidization":"n:津贴,补助",
"subsidize":"v:补助,津贴,搭补,帮补,收买,贴补,资助,贴,资",
"subsidy":"n:补贴,津贴,补助,奖金,补助金,助学金;v:贴补",
"subsist":"v:生存,存在,供养",
"subsistence":"n:生存,生活费,实体,给养,生计,存在",
"subsoil":"n:底土,心土",
"substance":"n:物质,内容,材料,实质,资产,体,大意,实体,本质,物,物体,财产,要旨,主旨,资力,要领,质地,灵,梗概,质,本体,精神",
"substandard":"a:等外",
"substantial":"a:殷实,本质,老鼻子,瓷实,大笔,坚实,实惠,充实;n:大意",
"substantially":"d:大体上,大幅度",
"substantiate":"v:证实,充实",
"substantiation":"n:证实",
"substantive":"n:实词,名词",
"substation":"n:变电站,分析,支局,分局,派出所,变电所,分站",
"substitute":"v:代替,取代,代换;n:替身,代用品,收入",
"substituting":"v:代换",
"substitution":"n:取代,代替,代换,换人,代,置换,替代,更替,代用;v:置换,替代",
"substrate":"n:底层,基层,地层",
"substratum":"n:心土,下层,底层,底土",
"substructure":"n:基础,路基",
"subsume":"v:包括,包含,包孕",
"subsurface":"a:土壤",
"subsystem":"n:子系统,部件,分系统,分部",
"subtenancy":"n:转租,转借",
"subtend":"v:对,衬托",
"subterfuge":"n:托词,口实,遁词,欺骗,托辞,规避,诡计",
"subterranean":"a:地下;n:地下",
"subtext":"n:言外之意,潜台词",
"subtitle":"n:小标题,副题,子目,副标题",
"subtitles":"n:字幕",
"subtle":"a:微妙,细微,微,不可捉摸,奥妙,啧,赜;v:不可捉摸",
"subtlety":"n:微妙,巧妙,狡猾,精妙,纤巧,敏感,精细,稀薄,城府,敏锐",
"subtract":"v:减,减去,扣除,去掉",
"subtracting":"v:减去",
"subtraction":"n:减,减法;v:减去",
"subtrahend":"n:减数",
"subtropics":"n:亚热带",
"suburb":"n:郊区,城郊,郊外,近郊,市郊,附近,周围,甸",
"suburban":"n:郊外",
"suburbia":"n:郊区",
"suburbs":"n:郊,四郊,郊区,近郊",
"subvention":"n:补助金,援助,津贴",
"subversion":"n:颠覆,破坏,覆灭,瓦解",
"subvert":"v:破坏,搅乱,腐蚀,颠覆,推翻",
"subway":"n:地铁,地下铁道,地道",
"subzero":"n:零下;a:严寒",
"succade":"n:蜜饯",
"succeed":"v:成功,继承,继,接替,继任,得逞,继续,接连,成,随后,接班,接任,嗣,得势,成事,得手,遂;p:继;d:遂;a:成功",
"success":"n:成功,成就,成绩,发迹;a:成功;v:胜",
"successful":"a:成功,顺利,完满",
"successfully":"d:胜利,顺利",
"succession":"n:连续,继承,接连,继承权,顺序,序列,继任,系统,世系,继承性;a:连续;v:继任",
"successive":"a:连续,逐次,历任,续",
"successively":"d:先后,依次,逐次;v:递",
"successor":"n:继承人,接班人,后任,传人",
"succinct":"a:简练,简洁,精粹,紧身,紧身儿,要言不烦,精炼,精练,不蔓不枝",
"succinctness":"n:精粹",
"succor":"v:救助,救,帮助,营救,支援,救济;n:救援,掩体,援助",
"succour":"v:帮助,救,营救,支援;n:救助,救援,援助,援军",
"succubus":"n:妖魔",
"succulence":"n:青饲料",
"succumb":"v:屈服,死,服从,屈从,慑服,屈膝",
"such":"a:这样,这么,如此,非常;r:他们,那,这个,该,其;n:底",
"such as":"p:如,例如,像,比如,譬如",
"suchlike":"r:之类,之流",
"suck":"v:吸,吮吸;n:吸入,吸力,失败,失望",
"suck in":"v:吸收,嗡",
"suck out":"v:拔",
"suck up":"v:吸取,吸",
"sucker":"n:傻瓜,笨蛋,吸盘,仔猪,吸管,棒棒糖,寄生虫,食客,生手",
"suckle":"v:哺乳,喂奶,养育,吸吮,奶,抚育,吮吸,吸取",
"suckling":"n:乳儿,生手",
"suckling pig":"n:豚",
"sucrose":"n:蔗糖",
"suction":"n:吸力,吸入,吸引;v:吸取,吸气",
"suction cup":"n:吸盘",
"suction pump":"n:真空泵,抽水机",
"sudan":"n:苏丹",
"sudden":"a:突然,忽然,突发,突兀,急遽,急剧,猝;v:突兀",
"suddenly":"d:突然,忽然,一下子,猛然,冷不防,蓦地,骤然,忽,忽地,顿然,陡然,霍然,蓦然,猛,猝然,顿,遽然,冷不丁;a:陡",
"suddenness":"n:突然,意外",
"suds":"n:肥皂泡,泡沫",
"sue":"v:控告,起诉,诉讼,请求,告,求和,求婚,告状,控诉;n:休",
"suet":"n:板油",
"suez":"n:苏伊士",
"suffer":"v:受,患,遭受,受苦,被,吃,忍受,害,苦于,受难,蒙受,罪,遭,煎熬,吃苦头,患病,经受,容许,遭殃,吃亏,磨难,害病,闹,受害,惨遭,中,挨,忍耐,受罚,遭罪,负",
"sufferance":"n:容许,苦难,忍耐,忍受,默许,宽容,耐性",
"sufferer":"n:受难者,患者,受害者,病人",
"suffering":"n:痛苦,苦难,苦,苦痛;v:熬煎,煎熬;a:熬心",
"sufferings":"n:疾苦,痛痒",
"suffice":"v:够,足以,够用,满足,足够",
"sufficiency":"n:自满,满足,能力,自负,充足,资格",
"sufficient":"a:足够,足以,充分,够,充足,足,从容,够用,赡;v:充,足够",
"sufficiently":"d:足",
"suffix":"n:词尾,下标,后缀",
"suffocate":"v:窒息,透不过气,受阻,熏蒸,憋,窒",
"suffocated":"v:堵;a:堵",
"suffocating":"v:熏蒸",
"suffocation":"n:窒息;v:窒息",
"suffrage":"n:投票,同意,投票权,赞成",
"suffuse":"v:弥漫,充满",
"suffusion":"n:充溢,弥漫",
"sugar":"n:糖,食糖,甜言蜜语,麻醉品,糖食,绵白糖,糖块,蔗糖;v:糖化",
"sugar candy":"n:甜品,冰糖",
"sugarcane":"n:甘蔗,蔗",
"sugarcoating":"n:糖衣;v:糖衣",
"sugared":"a:甜蜜;v:糖;n:糖",
"sugarplum":"n:糖果,甜言蜜语",
"sugary":"a:甜蜜",
"suggest":"v:建议,提出,提议,表明,暗示,启发,提醒,介绍,指点,授意",
"suggestion":"n:建议,意见,提议,暗示,启发,联想,意,气味,迹象,发言,样子;v:暗示",
"suicide":"n:自杀,自取灭亡,短见;v:自杀",
"suing":"v:控诉",
"suit":"n:套;v:合用,相配;a:可,对,般配,合意",
"suitability":"n:适合,适当,合宜,相配",
"suitable":"a:合适,适当,适宜,恰当,配合,贴切,相当,侻,相宜,得当,合宜,相称,切当;v:配合",
"suitcase":"n:手提箱,箱子,衣箱,提箱,皮箱",
"suite":"n:套间,套,组曲,组,随从,套件,随员,序列",
"suiting":"n:衣料",
"suitor":"n:原告",
"sulfate":"n:硫酸盐",
"sulfide":"n:硫化物",
"sulfur":"n:硫磺",
"sulk":"v:生气;n:生气,愠怒",
"sulks":"n:情绪",
"sullen":"a:阴沉,紧绷绷,发愁;n:忧郁,绷脸",
"sully":"v:玷污,污染,毁损,诬蔑,糟蹋,污蔑,污辱,沾染;n:污点",
"sulphate":"n:硫酸盐",
"sulphide":"n:硫化物",
"sulphonic acid":"n:磺酸",
"sulphur":"n:硫,硫磺,黄绿色,磺",
"sulphur dioxide":"n:二氧化硫",
"sultan":"n:苏丹",
"sultana":"n:王妃",
"sultanate":"n:职位",
"sultriness":"a:闷热;n:闷热",
"sultry":"a:闷热",
"sum":"n:钱,和,算术;v:归总,拢,共计",
"sum of money":"n:金额",
"sum total":"n:总计,合计,总和,总数",
"sum up":"v:综述,归结,归纳,归总,总,简言之,综,拢",
"sum-up":"n:总结",
"sumac":"n:黄栌,漆树",
"sumatra":"n:苏门答腊",
"summarily":"d:立刻,马上",
"summarize":"v:概括,总结,概述,综述,撮;n:综",
"summarizing":"v:列表",
"summary":"n:摘要,总结,概括,扼要,提要,概述,要略,概要,纪要,一览,案由,记要;a:略,概述;d:略",
"summation":"n:求和,总结,积聚;v:积聚,合计",
"summer":"n:夏天,夏季,暑假;v:避暑",
"summer house":"n:凉亭",
"summer solstice":"n:夏至,夏至点",
"summer squash":"v:西葫芦",
"summerhouse":"n:凉亭",
"summering":"v:避暑",
"summertime":"n:夏季,夏天,夏令,夏日",
"summing up":"n:总结",
"summit":"n:顶峰,峰,顶,高峰,顶点,极点,峰值,绝顶,颠,高潮;a:颠",
"summon":"v:召集,传唤,召唤,传,号召,招降,召",
"summons":"n:传票;v:传唤",
"sumo":"n:相扑",
"sump":"n:池,坑,水坑",
"sumptuous":"a:豪华,奢华,讲究,酒池肉林,腆,丰盛,富丽堂皇;v:腆",
"sumptuousness":"n:奢侈",
"sun":"n:太阳,阳光,日,恒星,日出;v:晾",
"sun plant":"n:半支莲,阳性植物,喜光植物",
"sun yat-sen":"n:孙中山",
"sunbath":"n:日光浴",
"sunbeam":"n:阳光,日光,金币",
"sunburn":"v:晒斑,暴晒;n:晒斑",
"sunday":"n:星期,礼拜天,周日,礼拜",
"sunder":"v:分离,分开,切断,切开",
"sundial":"n:日晷,晷",
"sundown":"n:日落,暮",
"sundries":"n:杂费,杂货,杂品,什物,杂事,杂项",
"sundry":"a:杂;n:杂项",
"sunfish":"n:翻车鱼",
"sunflower":"n:葵花,向日葵,向阳花,朝阳花",
"sunflower seed":"n:葵花籽,葵花子",
"sunglasses":"n:太阳眼镜,墨镜,太阳镜",
"sunk fence":"n:矮墙",
"sunken":"v:凹陷;a:凹",
"sunlamp":"n:太阳灯",
"sunlight":"n:阳光,太阳,日光,曜,炅,昱,晖",
"sunned":"v:晒",
"sunniness":"n:光明",
"sunning":"v:晒",
"sunny":"a:晴朗,向阳,朝阳,风和日暖,熙",
"sunrise":"n:日出,黎明,东方,昕;v:日出",
"sunset":"n:日落,晚霞,晚年,傍晚,末路,末尾,西方;v:日落",
"sunshade":"n:旱伞,遮阳,天棚,阳伞",
"sunshine":"n:阳光,太阳,日光,晴天,日照,黄金",
"sunspot":"n:日斑,雀斑,黑子",
"sunstroke":"n:中暑;v:中暑",
"sunup":"n:日出",
"sup":"v:经验,尝,啜",
"super":"a:超级,超等,顶刮刮;v:装订;d:非常",
"superabundance":"n:过度,过剩",
"superannuation":"n:废弃,退休金",
"superb":"a:高超,绝,高级,入神,胜,出神入化,超等,超绝;v:胜",
"supercharge":"v:用尽,增压",
"supercilious":"a:高傲,目无余子,慢,目无全牛",
"superconductive":"a:超导",
"superconductivity":"n:超导电性,超导,超导体",
"superconductor":"n:超导体,超导",
"superficial":"a:浅薄,肤浅,浅,浮泛,虚浮,鄙薄,不求甚解,粗浅,泛泛,浮,浮浅,草野,谫,辁,不痛不痒,浮皮潦草,飘浮,皮相,鄙陋,肤泛,浅学;v:不求甚解,漂浮,飘浮;n:草野,面",
"superficiality":"n:肤浅,表面性,皮相",
"superficially":"d:大面儿上,干,泛泛",
"superfine":"a:特异,特级,超等",
"superfluity":"n:过剩,奢侈,多余",
"superfluous":"a:多余,赘,冗,骈枝,画蛇添足,衍",
"superhero":"n:奇才",
"superhighway":"n:高速公路",
"superhuman":"a:超人",
"superimpose":"v:重叠,加上,附加,添加",
"superimposing":"v:叠加",
"superimposition":"n:被覆,叠置,叠加,叠印",
"superintend":"v:监督,管理,指挥,督察,董",
"superintendence":"n:监督,指挥,管理",
"superintendency":"n:监督,管理",
"superintendent":"n:负责人,校长,主管,所长",
"superior":"n:上级,上司;a:精良;v:优先,优胜",
"superiority":"n:优势,优越,优越性,优胜者,超越,胜过,优秀",
"superman":"n:超人",
"supermarket":"n:超级市场,自选市场",
"supernatural":"n:神;a:神乎其神",
"supernatural being":"n:神物",
"supernova":"n:超新星",
"supernumerary":"n:冗员",
"superpose":"v:重叠,迭加,叠置",
"superposition":"n:叠加,重合,重叠;v:重合,叠加",
"superpower":"n:超级大国,大功率;a:大功率",
"superscription":"n:刻,题写,题名,题字,标题",
"supersede":"v:取代,代替,废弃,废除,继任,交替,接替,替代,置换,更替",
"supersonic":"n:超声波;a:超声波",
"superstar":"n:大员",
"superstition":"n:迷信,异教,邪教,异端;v:迷信",
"superstructure":"n:上层建筑,楼,楼盖",
"supervene":"v:附加,并发,添加,接踵而来",
"supervention":"n:附加,接踵而来",
"supervise":"v:监督,管理,监察,董,管,监,督办,听,督察",
"supervision":"n:管理,监督,督导;v:监督",
"supervisor":"n:监工,督察;v:董,监督",
"supper":"n:晚饭,晚餐,夜宵,宵夜,夜饭,飧",
"supplant":"v:取代,代替",
"supple":"a:柔,软;v:驯",
"supplement":"n:增刊,副刊,追加,补码,附录,增补,补足,添加剂;v:补足,配搭",
"supplementary":"a:辅助,补充;v:辅助,补充",
"suppleness":"n:柔顺",
"supplicate":"v:乞求,哀求,祈祷,祈求,恳请,乞,求告,哀告,恳求",
"supplication":"n:恳求,祈求",
"supplier":"n:厂商",
"supplies":"n:供应品,补给品",
"supply":"v:提供,供应;n:经费",
"supplying":"v:补足",
"support":"v:支持;n:衣食,援助,后盾,台,赡养,腰杆子,预备队;d:将",
"supporter":"n:载体,后盾,后台老板,支架,绷带",
"supportive":"a:支持",
"suppose":"v:想,假定,假设,猜想,如果,想象,设想,推测,料想,意味着,算,设;c:设若,比如,要是;a:假",
"supposed":"v:虚拟;a:虚悬",
"supposedly":"d:大概,恐怕,想必",
"supposing":"c:假如,倘使,假若,倘,若是;v:使",
"supposition":"n:假定,推测,臆说,假想,虞,想像,假设",
"suppository":"n:栓剂,坐药",
"suppress":"v:镇压,平息,压制,取缔,清剿,窝,平,扑灭,扫平,镇,憋,戡,遏抑,遏制,平定,钳制,压,弹压",
"suppression":"n:抑制,镇压,扑灭,删除,禁止,压抑,萎缩,压制,隐匿,制止;v:抑制",
"suppressor":"n:消声器",
"suppurate":"v:化脓",
"suppuration":"n:化脓;v:化脓",
"suprarenal gland":"n:肾上腺",
"supremacy":"n:霸权,优越性,无上",
"supreme":"a:至尊,首,无上,至上;v:至高无上,至上",
"supreme headquarters":"n:大本营",
"supremo":"n:总裁,首脑",
"surcease":"v:中止,停止;n:停止,终止",
"surcharge":"n:超载,附加费;v:过载",
"surcingle":"n:腰带",
"surd":"n:根式",
"sure":"a:肯定,一定,确信;d:一准,必定;n:准儿",
"sure enough":"a:千真万确,实在,毫无疑问",
"sure thing":"n:必定",
"surefire":"a:万安,万全,万无一失;v:万无一失;n:万全",
"surely":"d:肯定,一定,无疑,当然,确实,好,必定,稳,的确,保管,准,管教,管保,必,是的,一准;v:管保;a:稳",
"sureness":"n:确实",
"surety":"n:担保,准谱儿,保释金,确实,牢靠;v:担保",
"surf":"v:冲浪",
"surface":"n:表面,面,水面,地面,表,外表,皮;v:铺",
"surface soil":"n:表土",
"surfeit":"n:不适,放纵,恶心,过量,过度;v:过量",
"surfing":"v:冲浪",
"surge":"v:滚滚,冲击,汹涌,涌;n:起伏,洋溢,波动",
"surgeon":"n:医师,军医",
"surgeon general":"n:军医",
"surgery":"n:外科,医院,诊所",
"surgical dressing":"n:敷料",
"surgical operation":"n:手术",
"surging":"v:汹涌澎湃;a:滔滔;n:冲击",
"surly":"a:倔,倔巴",
"surmise":"v:推测;n:推测,猜度,猜疑",
"surmount":"v:克服,超越,越过,打破,超高,突破",
"surname":"n:姓,姓氏,别名,别号,绰号,氏",
"surpass":"v:超过,胜过,赛,过,超越,盖,超前,倾,优于,越过,超,胜,拔,超拔,胜似,过人",
"surplus":"n:顺差,过剩,剩余,盈余;a:多余,浮,余,剩;v:余剩,过剩",
"surprise":"n:惊奇,吃惊;v:诧异;a:吃惊",
"surprise attack":"n:奇袭,偷袭",
"surprised":"a:惊讶,惊诧;v:惊异",
"surprising":"a:奇怪,奇异,奇",
"surrender":"v:投降;n:交出,解约",
"surreptitious":"a:偷偷摸摸,鬼,诡秘,鬼鬼祟祟",
"surreptitiously":"d:暗中,偷偷摸摸",
"surrogate":"n:代表,代理人,代用品,委员,代替;v:代理,代替",
"surround":"v:包围,围绕,环绕,围,环,包,遮蔽,围猎,合围,困,拱抱,拱,环抱,共;n:匝",
"surrounding":"v:附近,环境,围猎",
"surroundings":"n:环境,四下里;v:溜",
"surtax":"n:附加税",
"surveillance":"n:监视,监督;v:监视",
"survey":"v:概述,测量,调查;n:鉴定书,通论,综述,环顾",
"surveying":"n:测量,测量学,概观,勘测,环视;v:丈量,测量",
"surveyor":"n:检查员",
"survival":"n:生存,存活,残余,幸存,遗物,遗风,生死存亡,残存,成活;v:生存",
"survivals":"n:残余",
"survive":"v:幸存,存活,死里逃生,生还,成活,残存,存",
"surviving":"v:残存",
"survivor":"n:幸存者,残生",
"susceptibility":"n:感情,灵敏度",
"susceptible":"a:敏感",
"sushi":"n:寿司",
"suspect":"v:怀疑;n:疑犯",
"suspend":"v:悬浮,悬挂,吊,暂停,停止,中断,悬,挂,中止,终止,缓期,停办,保留,开除,停职,悬空,除名",
"suspender":"n:挂钩,吊袜带,背带,吊索",
"suspenders":"n:袜带,吊带,吊袜带,背带",
"suspense":"n:悬念,悬而未决,悬挂,中止,暂停,停止,悬吊,未定",
"suspension":"n:悬浮,悬挂,停职,悬,停止,悬吊,停学,吊,悬垂,保留,中止;v:悬浮,悬挂",
"suspension point":"n:省略号",
"suspicion":"n:怀疑,猜疑,疑心,嫌疑,一点儿;v:狐疑,怀疑,嫌",
"suspicious":"a:多心;v:狐疑",
"sustain":"v:维持,持续,支撑,支持,确认,证明,准许,顶,抵挡,证实,中,鼓舞,经得起,忍耐,蒙受,认可,掎,补养,犁,撑持,遭受,承认,加强,忍受,养,支,抵",
"sustained":"v:持续",
"sustenance":"n:营养,食物,维持,耐久,生计,支持,给养,持久,粮食",
"suture":"n:缝合,缝;v:连接,缝合",
"suzerain":"n:封建主,领主,宗主国",
"suzerainty":"n:宗主权",
"swab":"n:水手,蠢货,墩布,拖把",
"swaddle":"v:限制,包裹,束缚;n:襁褓",
"swaddling clothes":"n:裤,襁,襁褓,裼",
"swag":"n:水潭,摇晃,洼地,赃物,倾侧",
"swagger":"v:大摇大摆;n:大摇大摆,摆架子",
"swaggering":"v:大摇大摆",
"swallow":"v:吞服;n:食道,喉咙",
"swallow up":"v:吞并,吞没,耗尽,侵吞",
"swallow-tailed coat":"n:燕尾服",
"swallowtail":"n:凤蝶,燕尾服;v:分叉",
"swami":"n:专家",
"swamp":"v:淹没,沉没,满,糟蹋,吃苦头;n:草泽,湿地,泥沼",
"swan":"n:天鹅;v:闲逛",
"swan song":"n:绝笔",
"swank":"n:虚张声势,吹牛,出风头,优雅;v:吹牛",
"swanky":"a:爱出风头",
"swap":"v:交换,对调,掉换,交流,调换",
"swapping":"v:交换",
"sward":"n:草地,草皮,草坪",
"swarm":"v:挤满,蜂拥;n:蜂群",
"swarthy":"a:黝黑,黑不溜秋",
"swash":"v:冲刷,晃动,激,爬升,奔流,虚夸,洗,打击;n:冲刷,冲击,虚张声势",
"swashbuckler":"n:流氓,虚张声势",
"swat":"v:拍,拍打;n:打,猛击",
"swatch":"n:样本,样品",
"swath":"n:一行,条,行",
"swathe":"v:裹,包围,缠,绷,缠绕,绑",
"swatter":"n:割晒机,苍蝇拍子,苍蝇拍",
"sway":"v:摇曳,摆动,摇晃,动摇,摇动,晃动,摇摆,统治,支配;n:影响,势力,权势,摇动",
"swaying":"v:凹陷;a:摇摇晃晃",
"swear":"v:诅,戒除;n:誓言,宣誓,咒骂,盟,发誓;d:矢口",
"swear off":"v:戒除",
"swearing":"v:发誓",
"swearword":"n:脏字",
"sweat":"n:汗,汗水;v:发酵",
"sweat pants":"v:卫生裤",
"sweater":"n:毛衣",
"sweating":"v:发汗",
"sweatshirt":"n:运动衫",
"sweaty":"a:汗津津,汗浸浸,汗漉漉",
"sweden":"n:瑞典",
"sweep":"v:打扫,扫,掠过,扫视;n:扩张,肃清,区域,游弋,吹,眺望,弯路,风帆,长驱直入",
"sweep away":"v:清除,廓清,肃清",
"sweep off":"v:荡,卷",
"sweeper":"n:扫雷艇",
"sweeping":"n:扫除,扫荡;a:笼统;v:清扫",
"sweet":"n:糖果,糖;a:嫣然",
"sweet acacia":"n:金合欢",
"sweet oil":"n:菜油",
"sweet orange":"n:甜橙",
"sweet potato":"n:甘薯,芋头,山芋,番薯,苕,苕子",
"sweet wormwood":"n:青蒿",
"sweet-scented":"a:香",
"sweet-smelling":"a:芳",
"sweet-talk":"v:奉承",
"sweetbread":"n:杂碎",
"sweeten":"v:搞好,减轻,增加,缓和",
"sweetheart":"n:情人,心上人,爱人,恋人;v:求爱;a:欢",
"sweethearts":"n:情侣",
"sweetie":"n:情人",
"sweetly":"d:美妙,可爱,亲切",
"sweetmeat":"n:果脯,甜食,糖果",
"sweetmeats":"n:甜食,蜜饯,糖食,糖果",
"sweetness":"n:甜蜜,温柔,可爱,美味,亲切,甜味,温和,愉快,芳香,美妙,甘甜,新鲜",
"sweets":"n:糖,糖果",
"sweetshop":"n:糖果店",
"swell":"v:肿,膨胀,上涨,增加;n:名人,涌浪,增大,肿胀,加强,肿大;a:胀",
"swell up":"v:隆起,隆,涨",
"swelled head":"n:自高自大",
"swelling":"n:肿块,膨胀,肿胀,隆起,增大,狂潮;v:膨胀,突起,肿大,隆起,肿,肿胀;a:鼓",
"swelter":"n:酷热,混乱,闷热;v:闷热,中暑;a:闷热",
"sweltering":"a:炎炎",
"swerve":"v:转弯,闪避,偏斜;n:偏斜,转向,背离",
"swift":"a:迅速,快,迅疾;n:纺车,急流;d:骤",
"swiftly":"d:倏忽,率然,飞,赶,一溜烟;v:飞,赶",
"swiftness":"n:迅速",
"swig":"n:痛饮;v:痛饮",
"swill":"n:狂饮,痛饮,猪食,泔水,洗涤;v:涮,痛饮,冲洗",
"swilling":"v:泔水",
"swim":"v:游泳,游,游水,浮游;n:眩晕",
"swim bladder":"n:鱼鳔",
"swimming":"n:游泳,眩晕",
"swimming crab":"n:蝤蛑,梭子蟹",
"swimmingly":"d:顺利,顺畅",
"swimsuit":"n:游泳衣",
"swimwear":"n:游泳衣",
"swindle":"v:骗,骗取,欺诈,诈取,诈骗,蒙蔽,行骗,蒙哄,拐,拐骗,撞骗,欺骗,坑骗;n:冒牌货",
"swindler":"n:骗子,诈骗犯,江湖骗子,拐子,二道贩子",
"swindling":"v:欺骗",
"swine":"n:猪,下流,猪猡,生猪,彘",
"swineherd":"n:猪倌",
"swing":"v:摆动;n:摇动,音律,振幅,转动,趋势,推动力,挥动,开展,旋律,旋转;a:荡荡悠悠",
"swing around":"v:旋转",
"swing door":"v:转门",
"swing shift":"n:中班",
"swingeing":"a:重",
"swinging":"a:重;n:吊环;v:摆动",
"swipe":"n:猛打,马夫,贼,猛击;v:猛击,猛打",
"swirl":"v:旋转,打转,纷飞,潆洄,蜷曲,晕;n:纷飞,围绕,弯曲",
"swish":"n:时髦,挥动;v:刷;d:刷",
"swishing":"v:噪声;n:噪声",
"swiss":"n:卫兵",
"swiss chard":"n:牛皮菜",
"switch":"v:打开,关掉,交换,接通,转换,改变;n:假发",
"switch off":"v:关掉,关,断开",
"switch on":"v:合闸,接通,起动,启动,打开,参见",
"switchboard":"n:总机,交换机,交换台,配电盘",
"switchgear":"n:控制",
"switching":"v:关掉,换向",
"switzerland":"n:瑞士",
"swivel":"v:转,旋转;n:底座",
"swiz":"n:诈取",
"swizzle":"n:喝酒",
"swollen":"a:肿;v:肿",
"swollen-headed":"v:自高自大",
"swoon":"v:昏倒,晕;n:神魂颠倒",
"swoop":"v:猛扑",
"sword":"n:剑,刀,武力,战争,铗,刃,战斗力",
"sword bean":"n:刀豆",
"sword dance":"n:剑舞,舞剑",
"sword grass":"n:菖兰",
"sword lily":"n:唐菖蒲",
"swordfish":"n:箭鱼",
"swordplay":"n:舞剑,唇枪舌剑,剑术",
"swordsman":"n:剑客,军人,武士,侠客",
"swordsmanship":"n:剑术",
"sworn":"n:盟;v:盟",
"swot":"n:辛苦",
"sybaritic":"a:骄奢淫逸",
"sycophancy":"n:谄媚,拍马",
"sycophant":"n:哈巴狗,篾片,马屁精",
"sydney":"n:悉尼",
"syllable":"n:音节,字段,字节,只言片语,音名,音缀",
"syllabus":"n:大纲,课程表,提纲,摘要",
"syllogism":"n:三段论,演绎法,诡辩,三段论法",
"symbiosis":"n:共生,共栖",
"symbol":"n:符号,象征,标志,记号,标记,信条,表征;v:征,符,象征",
"symbolic":"a:象征性",
"symbolism":"n:表象,记号,符号论,象征性",
"symbolization":"n:象征",
"symbolize":"v:象征,代表,标志",
"symmetrical":"a:对称,匀称",
"symmetry":"n:对称,对称性;a:对称",
"sympathetic":"a:欣赏,古道热肠;v:欣赏",
"sympathize":"v:同情,赞成,同意,共鸣,吊慰,一致,安慰;n:同感",
"sympathize with":"v:矜,惋惜,怜,同情,惋叹",
"sympathy":"n:同情,同情心,赞成,慰问,吊慰,共鸣,一致,恻隐之心,怜悯,同感,协调,共振,同意,感应,引力;v:同情,共鸣",
"symphonic music":"n:交响乐",
"symphony":"n:交响乐,交响曲,谐音,调和",
"symphony orchestra":"n:交响乐团",
"symposium":"n:研讨会,座谈会,宴会,酒会,讨论会",
"symptom":"n:症状,征兆,症候;v:标",
"synagogue":"n:犹太教",
"sync":"n:同步",
"synchronise":"v:同步",
"synchronization":"n:同步,同时,同期",
"synchronize":"v:同步,校准,对准",
"synchrony":"n:同步",
"syncopate":"v:切分",
"syncopation":"n:切分",
"syncope":"n:晕厥,昏厥",
"syndicalism":"n:工团主义",
"syndicate":"n:委员会,辛迪加,理事会",
"syndrome":"n:综合症,集合,并发症",
"synergism":"n:合作,互助,协同",
"synergy":"n:配合,协同",
"synod":"n:讨论会,会合,会议",
"synonym":"n:代名词,同义词,同义字,类义词,异名,近义词",
"synonymous":"a:同义",
"synonymy":"n:同义",
"synopsis":"n:摘要,梗概,提要,撮要,提纲,大意,说明书,简介,一览,对照表",
"syntax":"n:语法,句法",
"synthesis":"n:合成,综合;v:接合,合成",
"synthesize":"v:合成,综合",
"synthesized":"a:综合性",
"synthetic resin":"n:塑胶",
"synthetic rubber":"n:合成橡胶",
"syphilis":"n:梅毒",
"syphon":"n:虹吸管,水管;a:虹吸",
"syria":"n:叙利亚",
"syringe":"v:灌溉,注射,浇,洗涤;n:水枪,洗涤器",
"syrup":"n:糖浆,果汁,浆,露,糖水",
"system":"n:系统,制度,体系,设备,方法,方式,装置,网络,体制,系,组织,说,世界,制,规律,网点,分类法,宇宙,次序,体,主义,机体",
"systematic":"a:系统,有板有眼,有条有理",
"systematically":"a:有条不紊;d:有条不紊",
"systematics":"n:分类,分类学",
"systematization":"v:分类;n:分类",
"systemic circulation":"n:体循环,大循环",
"systole":"v:收缩;n:收缩",
"syzygium aromaticum":"n:丁香",
"t":"n:使,梯恩梯",
"t-shirt":"n:汗衫",
"t-square":"n:丁字规",
"ta":"n:助教",
"tab":"n:护耳,平板,药片,账单,标号,带子,工作台;v:记录,选取,选择",
"tabernacle":"n:会堂,礼拜堂,教堂,帐篷,住所",
"table":"n:桌子,桌,表,饭桌,表格,食物,目录,写字台,工作台,台子,手术台,图表,手掌,台,水面,台地;v:支付,制表,搁置",
"table lamp":"n:台灯,桌灯",
"table linen":"n:亚麻布,餐巾",
"table napkin":"n:餐巾",
"table of contents":"n:目录",
"table salt":"n:氯化钠",
"table service":"n:餐具",
"table talk":"n:座谈",
"table tennis":"n:乒乓球,桌球,台球,乒",
"tableau":"n:图像,景色,画面,图画,表格",
"tablecloth":"n:桌布,台布",
"tableland":"n:高原,台地",
"tablespoon":"n:汤匙,羹匙",
"tablet":"n:药片,片剂,碑,界石,牌匾,牌,片,写字板,平板,牌子",
"tabletop":"n:桌面",
"tableware":"n:餐具,食具",
"tabling":"v:餐巾,制表,桌布",
"tabloid":"n:小报,药片,摘要,文摘",
"taboo":"v:禁止,避讳,忌讳;n:禁忌,戒律",
"tabor":"n:手鼓",
"tabular":"a:列表",
"tabulate":"v:制表",
"tabulating":"v:制表",
"tabulation":"n:制表,列表,表格",
"tachometer":"n:速度计,流速计",
"tacit":"a:不言而喻,默",
"tacit consent":"n:默许",
"taciturn":"a:沉默寡言,沉默;d:默默无言;v:沉默寡言",
"taciturnity":"n:缄默,默示",
"tack":"n:方针,方法,策略,钉;v:附加,添,绷",
"tackle":"v:处理,解决,对付,应付,阻拦;n:用具,装备,前锋,滑车",
"tackling":"n:用具",
"tact":"n:机智,老练,得体,触觉,圆滑,权变",
"tactful":"a:圆滑,策略,圆,敏感,宛转,委婉,婉转,婉曲,老练,婉;n:策略",
"tactician":"n:策士,战略家",
"tactics":"n:战术,策略,权略,权谋,术",
"tactility":"n:触觉",
"tad":"n:小孩,小孩子,少量",
"tadpole":"n:蝌蚪",
"tadpole shrimp":"n:鲎虫",
"tae kwon do":"n:跆拳道",
"taffeta":"n:府绸,塔夫绸",
"taffy":"n:太妃糖,奉承",
"tag":"n:终端,标志,标签;v:尾随,捉住,追随",
"tag end":"n:残余,末尾,末端",
"tagging":"v:标记",
"taichung":"n:台中",
"tail":"n:尾巴,尾部,尾翼;v:接上,嵌入;a:一系列",
"tail assembly":"n:尾部,尾翼",
"tail coat":"n:燕尾服",
"tail end":"n:末期,末尾,后部,屑,末端",
"tail fin":"n:尾翼",
"tail lamp":"n:尾灯",
"tailbone":"n:尾骨",
"tailcoat":"n:燕尾服",
"tailing":"n:残渣,跟踪,渣滓,矿渣,尾随,屑,糟",
"taillight":"n:尾灯",
"tailor":"v:裁剪,剪裁,缝制;n:裁缝",
"tailoring":"n:成衣,缝纫;v:成衣,特制;a:特制",
"tailpiece":"n:附属物,尾翼",
"tailpipe":"n:吸管",
"tailspin":"n:混乱,螺旋",
"tailwind":"n:顺风",
"taint":"v:毒化;n:腐败,痕迹",
"taipei":"n:台北",
"taiwan":"n:台湾,台",
"taiyuan":"n:太原",
"tajikistan":"n:塔吉克",
"take":"v:要,去,到,带,得,采取,拿,需要,将,发生,吃,接受,坐,认为,拿走,带有;n:看法,捕获量,捕获,观点,收获,收获量,镜头;p:以;d:将",
"take a breath":"v:换气",
"take a breather":"v:缓气,喘气",
"take a chance":"v:碰运气",
"take a powder":"v:逃跑,离去",
"take after":"v:象,像",
"take aim":"v:瞄,瞄准",
"take apart":"v:拆,拆开",
"take away":"v:下,搬走,夺去,夺,卸,搬,撤,取走,抓走",
"take back":"v:取回,取消",
"take care":"v:注意,小心,留神,操劳,慢走",
"take chances":"v:冒险",
"take down":"v:笔录,笔记,收录",
"take effect":"v:行之有效,见效",
"take fire":"v:着火",
"take flight":"v:出奔,逃跑,逃",
"take for":"v:认为,作,当,作为",
"take for granted":"v:轻信,认命",
"take hold of":"v:揽,抓住,接,掌握",
"take in":"v:接受,蒙蔽,收容,摄取,收入,归拢,吸食,欺骗,接纳,纳,收",
"take into account":"v:考虑,顾及",
"take issue":"v:唱反调",
"take it easy":"v:少安毋躁",
"take kindly to":"v:喜欢",
"take leave":"v:失陪,拜辞,辞",
"take notice":"v:理会",
"take off":"v:出发,扒,扣除,摘,出航,宽衣,腾飞,移送,脱掉,扣,杀",
"take office":"v:任职,接任,到职",
"take on":"v:担负,生气,担当,雇佣,收录,担待,揽,担,负,管,肩负,录用,面目一新,肩",
"take orders":"n:禀承",
"take out":"v:抽,付与,掏,拔掉,抽出,出手",
"take over":"v:袭用,接办,取代,占据,接受,接替,收缴,袭取,接管,接,接手,收货",
"take pains":"v:尽力,着意,操心",
"take part":"v:插手",
"take place":"v:来,出,举行",
"take root":"v:固定",
"take shape":"v:成型,形成,成形",
"take stock":"v:盘存",
"take the air":"v:兜风",
"take the field":"v:出马",
"take the floor":"v:发言",
"take the road":"v:出发",
"take the stand":"v:作证",
"take time off":"v:偷空,休息",
"take to":"v:从事,服侍,喜爱,开始",
"take to heart":"v:介,认真,在意",
"take to task":"v:难,责骂",
"take turns":"v:倒换,更替,替换,换班,轮,轮换",
"take up":"v:抄,担承,占,从事,旁及,上任,收紧,开始,占用,绰,就,挈,仗",
"take-in":"n:欺骗",
"take-up":"n:收缩,调整",
"takeoff":"n:起飞,起跳,升起;v:升起,发射",
"takeover":"n:接管,接收",
"taking":"n:收入;v:发作",
"takings":"n:收缩,收入;v:收缩",
"talbot":"n:猎狗",
"talc":"n:滑石,云母,滑动",
"talcum":"n:爽身粉,滑石,滑石粉",
"talcum powder":"n:滑石粉,爽身粉,扑粉",
"tale":"n:故事,童话,坏话,谣言,传说,计算;v:解释",
"talent":"n:才能,天才,才华,才,才干,天资,天分,人才,天赋,才力,本领,内行,器,能耐,天禀,才分,材,奇才,本事,头角,才气,身手",
"talented":"a:俊",
"talisman":"n:护符,法宝",
"talk":"v:谈,说话,说,谈话,谈论,讲;n:口气",
"talk about":"v:摆,话,论,唠,叨念,话说",
"talk down":"v:说服,指示",
"talk of":"v:谈论",
"talk over":"v:念叨,商量,说合,商谈,议,讨论",
"talkative":"a:喋喋",
"talker":"n:空谈家",
"talkie":"n:有声片",
"talking":"n:讲话,讨论;v:口舌",
"talking book":"n:有声读物",
"talks":"v:谈判,会谈",
"tall":"a:高,高大,颀长",
"tall order":"n:苛求",
"tallboy":"n:通风管,高脚杯",
"tallness":"n:高度",
"tallow":"n:脂",
"tallow oil":"n:脂油",
"tally":"v:相符,吻合,符合,计算;n:标签,筹码,点数,得分,计算,筹,符节,名牌",
"tallying":"v:点货",
"talon":"n:爪子,爪,手指,魔爪",
"talons":"n:钩爪",
"talus":"n:斜坡,斜面",
"tam-tam":"n:锣",
"tamarack":"n:落叶松",
"tambourine":"n:手鼓",
"tame":"v:驯服,抑制,驯养,驯,制服,降伏,驯化,降;a:食客,驯熟,家,温驯;n:家",
"tamed":"v:千依百顺",
"tameness":"n:平凡,温柔,沉闷,驯熟,驯服",
"tamp":"v:打夯,夯,砸;n:夯",
"tamper":"v:玩弄,贿赂,窜改,削弱,损害,篡改;n:夯砣,夯",
"tamping":"v:打夯,镇压",
"tampon":"n:假发",
"tan":"n:褐色,制革;v:硝,制革",
"tandem":"a:串联,串行,串列;n:串联",
"tang":"n:气息,风味,意味,唐,滋味",
"tang dynasty":"n:唐朝",
"tangent":"n:切线,正切,切面",
"tangerine":"n:柑橘,橘子,蜜橘,蜜柑",
"tangible":"a:有形",
"tangle":"v:缠;n:打架",
"tangled":"a:乱蓬蓬",
"tango":"n:探戈舞,探戈",
"tangshan":"n:唐山",
"tank":"n:坦克,油箱,罐,槽,容器,桶,水罐,箱,水柜,游泳池",
"tank car":"n:槽车",
"tank farm":"n:油库",
"tanker":"n:油轮,油船,罐车,加油机,加油车",
"tanks":"n:水罐",
"tanner":"n:皮匠",
"tannic acid":"n:鞣酸,单宁酸",
"tannin":"n:鞣料,鞣酸,单宁酸",
"tanning":"n:制革",
"tantalization":"n:逗人,逗弄",
"tantalize":"v:逗弄,愚弄,撩,挑逗,吊胃口,引逗",
"tantalum":"n:钽",
"tantrum":"n:发脾气,怒发冲冠,暴怒,怒骂",
"tanzania":"n:坦桑尼亚",
"tao":"n:陶",
"taoism":"n:道经,道学,道",
"taoist":"n:道士,道,道家",
"tap":"v:开拓;n:分支,酒吧间,塞子",
"tap dance":"n:踢踏舞",
"tape":"n:磁带,带,纸带,录音带,带子,卷尺,舌头,传动带,纸条,皮尺",
"tape drive":"v:磁带机",
"tape recorder":"n:录音机",
"tapeline":"n:卷尺",
"taper":"n:锥形,斜度;a:锥形",
"tapering":"a:尖",
"tapes":"n:传送带",
"tapestry":"n:挂毯,壁毯",
"tapeworm":"n:绦虫,蛔虫",
"tapioca":"n:木薯",
"tapir":"n:貘",
"tapper":"n:电键",
"tapping":"n:支路,出铁,分支,抽头;v:抽头,出铁",
"taproom":"n:酒吧间,酒吧",
"taproot":"n:主根,直根",
"tar":"n:焦油,水手,柏油,水兵",
"tarantula":"n:毒蜘蛛",
"tardiness":"n:迟缓,缓慢,拖拉",
"tardy":"a:迟迟,迟缓,拖欠,迟;v:拖欠",
"tare":"n:皮重,野豌豆;v:校准",
"target":"n:目标,靶子,靶,对象,指标,靶心,觇标;v:准",
"target practice":"n:打靶",
"target range":"n:靶场,打靶场",
"tariff":"n:关税,价格,税则,税率,价目表,计价,收费",
"tarmac":"n:停机坪",
"tarnish":"v:玷污,黯然失色,晦暗,变色,污蔑,污损,降低,脱色,生锈;n:污点,锈,污垢",
"taro":"n:蕖,莒,芋头,芋,芋艿",
"tarpaulin":"n:苫,苫布,雨衣,油布,船员",
"tarring":"n:塔林",
"tarry":"v:等待,耽搁,逗留;n:等候,逗留;a:柏油",
"tarsal":"n:跗骨",
"tarsal bone":"n:跗骨",
"tarsus":"n:跗骨",
"tart":"n:馅饼;a:尖酸,酸溜溜",
"tartar":"n:牙垢,钉子户,塔塔尔族,悍妇,牙花",
"tartaric acid":"n:果酸",
"task":"n:任务,工作,功课,课题",
"task force":"n:特遣部队,特遣队",
"taskmaster":"n:工头,监工",
"tassel":"n:流苏,穗,穗子,绶,缨子,须子,缨,穗状花序;v:抽穗",
"tassels":"n:流苏",
"taste":"n:爱好;v:感到,品味,浅尝,少量,经验;a:一点儿,少量",
"tasteful":"a:雅致,讲究,大方",
"tastefully":"d:雅致",
"tasteless":"a:寡,乏味,淡,无味",
"taster":"n:触须,吸管",
"tasty":"a:可口,好吃,入味,旨;v:入味;n:美味",
"tat":"n:粗麻布,打击",
"tatami":"n:草席",
"tatar":"n:鞑靼,塔塔尔族",
"tatter":"v:撕碎",
"tattered":"a:破烂,破碎,破破烂烂",
"tattle":"v:空谈,闲谈,闲聊;n:闲谈,传闻",
"tattletale":"n:告密者",
"tattoo":"v:刺配",
"taunt":"v:嘲弄,嘲笑,嘲讽,辱骂,奚落;n:嘲笑,笑柄",
"taurus":"n:金牛座",
"taut":"a:紧,整齐,紧绷绷,严峻,紧巴巴",
"tautness":"n:紧张;a:紧张",
"tautology":"n:重复,重言",
"tavern":"n:酒店,酒馆,客栈,旅馆,客店",
"tawny":"n:茶色,黄褐色",
"tax":"n:税,税务,税款;v:淘,捐,讨,非难,绞,谴责",
"tax avoidance":"n:逃税",
"tax bill":"n:税法",
"tax collection":"n:征税",
"tax collector":"n:税务员",
"tax evasion":"n:偷税,漏税",
"taxation":"n:税收,征税,纳税,税制,税款,税额,抽税;v:征税",
"taxes":"n:赋税,税捐",
"taxi":"n:计程车,出租车,出租汽车;v:滑行",
"taxicab":"n:出租汽车",
"taxing":"v:滑行",
"taxis":"n:分类,分队,次序",
"taxiway":"n:滑行道",
"taxonomy":"n:分类学;v:分类",
"taxpayer":"n:纳税人",
"tb":"n:肺结核,肺病",
"tchaikovsky":"n:柴科夫斯基",
"tea":"n:茶,茶叶,茶点,热茶,茶水,茶树,茶汤,大麻,茗",
"tea caddy":"n:茶叶罐",
"tea ceremony":"n:茶道",
"tea garden":"n:茶园",
"tea leaf":"n:茶叶",
"tea party":"n:茶会",
"tea service":"n:茶具",
"tea set":"n:茶具",
"teach":"v:教,教书,教学,教育,教训,教导,教授,执教,讲授,传授,教课,讲课,传人,导,诲,训诲,训喻,授,管教,训,传,傅,教诲;n:教授",
"teacher":"n:老师,教师,教员,师长,师,导师,先生,教书匠,教士,傅",
"teachers":"n:师资",
"teaching":"n:教学,教导,教义,教训,学,学说,讲授;v:教诲,教课,教导",
"teaching method":"n:教法",
"teachings":"v:说",
"teacup":"n:茶杯,茶碗",
"teak":"n:柚木,柚",
"teakettle":"n:茶壶",
"team":"n:队,球队,团体,集体,组,小队,小分队,剧组,班,班组;v:打交道",
"team up":"v:打交道",
"teammate":"n:队友",
"teamwork":"n:合作,配合,协同,协力",
"teapot":"n:茶壶",
"tear":"v:流泪,破损,狂奔;n:泪液,珍珠,水珠,狂奔",
"tear apart":"v:撕破",
"tear away":"v:撕掉",
"tear down":"v:拆卸,拆毁",
"tear gland":"v:泪腺",
"tear into":"v:劈头盖脸",
"tear off":"v:撕掉,撕下",
"tear up":"v:撕掉",
"tearaway":"n:暴徒",
"teardrop":"n:泪珠,泪水,泪",
"tearful":"a:眼泪汪汪,泪汪汪,潸,汪汪",
"tearing":"v:断裂,裂开,撕裂;a:撕",
"tearoom":"n:茶室,茶楼",
"tears":"n:眼泪",
"tease":"v:取笑,逗,逗弄,捉弄,戏弄,打趣,开玩笑,惹,梳理,挑逗,撮弄,逗引;n:戏弄",
"teaser":"n:难题",
"teasing":"n:闹着玩儿;a:撩乱",
"teaspoon":"n:茶匙",
"teaspoonful":"n:茶匙",
"teat":"n:乳头,奶头,乳房",
"tech":"n:技术",
"technetium":"n:锝",
"technical":"a:技术;n:技术性",
"technical school":"n:技校,专科学校,技术学校",
"technicality":"n:技术性,学术性",
"technician":"n:技术员,技师,专家,技工",
"technique":"n:技术,方法,技巧,工艺,手法,术,技法,技能,技",
"technocracy":"n:技术",
"technologically":"d:科技",
"technologist":"n:专家,技术员,工艺师",
"technology":"n:技术,工艺,工程,技艺,工艺学,术语",
"tectonic":"a:构造",
"tediousness":"n:沉闷",
"tedium":"n:单调,沉闷",
"tee":"n:三通,目标;v:准备",
"teem":"v:充满,产,盛产,倾注,浇铸,富于,生",
"teeming":"v:浇注",
"teen":"n:伤害,损害,悲哀,不幸,痛苦;v:激怒",
"teenager":"n:青少年",
"teeter":"v:摇摇欲坠,颠簸,摇摆;n:颠簸",
"teeth":"n:牙齿",
"tehran":"n:德黑兰",
"telecast":"n:电视",
"telecom":"n:电信",
"telecommunication":"n:电信",
"telecommunications":"n:电讯",
"teleconference":"n:电话会议",
"telegram":"n:电报,函电,电,报",
"telegraph":"n:电报;v:电汇",
"telegraph key":"v:电键",
"telegrapher":"n:报务员",
"telegraphist":"n:报务员",
"telegraphy":"n:电报,电信",
"telemeter":"n:测距器,遥测;v:遥测",
"telemetry":"n:遥测;v:遥测",
"teleology":"n:目的论",
"telephone":"n:电话;v:打电话",
"telephone booth":"n:电话间",
"telephone box":"n:电话间",
"telephone directory":"n:电话簿",
"telephone exchange":"n:总机,电话局",
"telephone kiosk":"n:电话间",
"telephone operator":"n:话务员",
"telephone receiver":"n:听筒,受话器",
"telephone set":"n:电话机",
"telephone system":"n:电话",
"telephoning":"v:打电话",
"telephonist":"n:接线生,话务员",
"telephony":"n:电话",
"telephoto":"n:传真电报,传真",
"telephoto lens":"n:长镜头",
"telephotography":"n:传真",
"teleplay":"n:电视剧",
"telescope":"n:望远镜;v:缩短",
"telethon":"n:连续剧",
"televise":"v:收看",
"television":"n:电视,电视机",
"television set":"n:彩电",
"telex":"n:电传机,电传,电报,用户电报",
"tell":"v:告诉,说,讲,知道,吩咐,讲述,影响,辨别,明白,判断,告,诉说,嘱,了解,打中,吐,知,泄漏,吐露,招呼,嘱咐,关照,交代,叙说,证明,语,击中,点数,知照,指派,诉,吐口,计数,详,告语,知会,述说,晓,表明,通,谕,告送;n:传闻",
"tell off":"v:指派",
"teller":"n:出纳员,出纳",
"telling":"v:讲",
"telltale":"n:证据,指示器",
"tellurium":"n:碲",
"telly":"n:电视机,电视",
"temblor":"n:地震",
"temerity":"n:鲁莽,轻率",
"temp":"n:临时工,临时",
"temper":"n:脾气,暴躁,性情;v:减轻,调和",
"tempera":"n:水彩",
"temperament":"n:气质,性情,脾气,性格,暴躁,意气,脾性,喜怒无常,律吕,乐律,心性,气性,音律",
"temperance":"n:节欲,戒酒,适中,节制;v:节制",
"temperate":"a:温和,哀而不伤",
"temperateness":"n:中庸",
"temperature":"n:温度,气温,体温,热,温,发烧,高烧,热度,冷热,燃点",
"temperature scale":"n:温度表",
"tempering":"n:回火;v:回火",
"tempest":"n:暴风雨,动乱,风暴,风雷,暴动,急风暴雨,骚动;v:狂暴",
"tempestuous":"a:汹,汹涌,汹涌澎湃;v:汹涌澎湃",
"templar":"n:法学家,律师",
"template":"n:模板,靠模",
"temple":"n:庙宇,庙,寺庙,太阳穴,寺院,教堂,神殿,鬓角,寺,殿,庙堂,颞颥,电影院,礼拜堂,大厦,召",
"temples":"n:两鬓,鬓角",
"tempo":"n:速度,步调,速率,拍子",
"temporal":"a:太阳穴",
"temporarily":"d:临时,暂,姑,权时",
"temporariness":"n:暂时",
"temporary":"a:临时,一时,行,暂行,浮",
"temporary worker":"n:零工",
"temporize":"v:见风使舵,拖延,妥协,姑息,泡蘑菇,骑墙,因循",
"tempt":"v:诱惑,引诱,吸引,勾引,怂恿,引起,诱导,尝试,蔑视,试探,激怒,教唆,试验",
"temptation":"n:诱惑,考验",
"ten":"a:十",
"ten thousand":"n:万",
"ten-strike":"n:大量",
"tenacious":"a:顽强,韧,不屈不挠;v:不屈不挠",
"tenacity":"n:坚韧,不屈不挠,韧性,紧握,牛劲,强,顽强,固执,坚持,顽固",
"tenancy":"n:租期,租佃,占据,租用",
"tenant":"n:房客,佃户,承租人,租户;v:租借",
"tenant farmer":"n:佃户",
"tenantry":"n:房客,租户,佃户,承租人",
"tench":"n:鲤鱼",
"tend":"v:趋向,照料,看,有助于,服侍,照管,归于,注意,偏重,看护,抚育,照护,办理,守望,招待,管理,护理,看管,牧,照看,牧放",
"tendencies":"n:动态",
"tendency":"n:倾向,趋势,趋向,势头,意向,势,样子,偏好,倾,性情,倾向性,动向,旨趣,癖好",
"tendentiousness":"n:倾向性",
"tender":"a:温柔;v:提出,偿付,估价,提供,标,清偿;n:提供,偿付,提出,压痛,挡车工",
"tenderfoot":"n:新手,生手",
"tenderloin":"n:里脊,腩,脢",
"tenderness":"n:柔情,压痛,柔和",
"tending":"v:田间管理",
"tendon":"n:腱,肌腱,筋",
"tendril":"n:卷须,蔓",
"tenement":"n:公寓,住房,房屋,地产",
"tenet":"n:教义,原则,教条,原理,信条",
"tennessee":"n:田纳西州",
"tennis":"n:网球",
"tennis ball":"n:网球",
"tennis court":"n:网球场",
"tennis racket":"n:网球拍",
"tenor":"n:男高音,大意,要旨,进程,方向,品位,趋向,性质",
"tenpin":"n:柱子",
"tenpin bowling":"n:保龄球",
"tense":"a:紧张;n:时",
"tenseness":"n:紧张",
"tensile strength":"n:抗张强度",
"tension":"n:紧张,张力,应力,压力,拉力,电压,伸张;a:紧张",
"tensity":"n:紧张,张力",
"tent":"n:帐篷,幕,帐幕,住处,照料,观察,营帐,寓所,注意,看护,天幕",
"tentacle":"n:触须,触角,触手",
"tentacles":"n:魔爪",
"tentative":"n:假说,实验,试验;a:初步,暂定;v:暂定",
"tentatively":"d:姑,姑且,权",
"tenting":"v:隆起",
"tenuity":"n:薄,薄弱,单薄,纤细,贫乏,细,微弱",
"tenuous":"a:纤细,纤小,细长",
"tenure":"n:占有,保有,享有,所有权,使用",
"tepid":"a:不冷不热,温和",
"terbium":"n:铽",
"term":"n:术语,学期,词,条件,名词,条款,任期,用语,关系,词语,项;v:叫做",
"termagant":"n:悍妇,母老虎,泼妇",
"terminal":"n:终端,端子,接头,终点,端,终点站,字母,电极,末端,端点,末,期末,音素,结尾;a:末尾,端的",
"terminate":"v:结束,终止,解除,归于,罢,满期,终了,毕,限定",
"terminating":"v:终端",
"termination":"n:结束,终止,终端,结果,结局,词尾,界限,末端,限定,终结,成果,终点,限度;v:终止",
"terminator":"n:终端",
"terminology":"n:术语",
"terminus":"n:终点,终点站,目标,极限,界石,界限,末端,界桩,期末,终端",
"termite":"n:白蚁",
"terms":"n:词语",
"terpsichorean":"n:舞蹈家",
"terra alba":"n:瓷土",
"terra firma":"n:旱地,大地,陆地",
"terrace":"n:平台,阳台,梯田,露台,坪,坛,陆地,路堤,地坛,台地",
"terraced":"n:梯;v:梯",
"terracotta":"n:陶瓦",
"terrain":"n:地形,地势,地带,地区,地面,形势,地域",
"terrazzo":"n:水磨石",
"terrestrial":"n:陆地",
"terrestrial planet":"n:类地行星",
"terrible":"a:可怕,糟糕,厉害,凶,凶猛,鬼,够戗,了不得,怕人,了得;d:极,很,非常;v:不得了",
"terribly":"d:非常,很,极,厉害,要命,不亦乐乎,够戗",
"terrier":"n:狗",
"terrific":"a:了不起,够意思,怕人,了不得",
"terrified":"a:恐惧,怔忪,惶恐,怔,恐慌;v:掉魂;n:怔忡",
"terrify":"v:威胁,吓唬,恐吓,恐",
"terrifying":"a:可怕,恐怖,吓人;v:骇人听闻,可怕,恐怖,怕人,吓人",
"terrine":"n:陶罐",
"territorial waters":"n:领海,领水,水域",
"territoriality":"n:地区性",
"territory":"n:领土,地区,土地,领地,领域,国土,疆域,版图,江山,地面,疆土,范围,域,国境,境,河山,舆",
"terror":"n:恐怖,惊骇;a:恐怖",
"terrorism":"n:威吓,胁迫",
"terrorize":"v:恐怖,胁迫,恐",
"terse":"a:精练,简洁,要言不烦,紧凑,精炼,精粹,简练",
"tertiary":"n:第三系",
"tessellate":"v:镶嵌",
"test":"v:校验,精炼,验;n:化验,介壳,宣誓,考查,甲壳,种皮,试药",
"test drive":"v:试车",
"test tube":"n:试管",
"testament":"n:遗嘱,誓约,契约,遗言",
"tester":"n:华盖",
"testicle":"n:睾丸,睾,外肾,精巢",
"testify":"v:作证,证明,表明,声明,证言,见证,证实",
"testimonial":"n:证明书,证明,奖金,表扬信,鉴定书,感谢信,奖品,纪念品,奖状",
"testimony":"n:证词,证据,证言,证明,表明,表示,宣言,见证,声明,证,抗议",
"testiness":"n:暴躁",
"testing":"v:测验,验证,测试,检验,校验;n:检验",
"testing ground":"n:窗口",
"testis":"n:睾丸,精巢,外肾,睾",
"testy":"a:急躁",
"tetanus":"n:破伤风",
"tether":"v:拘束,束缚;n:范围,限度",
"tetracycline":"n:四环素",
"tetrahedron":"n:四面体",
"teuton":"n:日耳曼",
"texas":"n:德克萨斯",
"text":"n:正文,课文,文本,文字,原文,教科书,课本,版本,原作,论题,主题",
"textbook":"n:教科书,课本,教本,读本",
"textile":"n:纺织,纺织品,织物,布",
"textiles":"n:布帛",
"textual":"a:校勘学",
"textual criticism":"n:考证",
"texture":"n:结构,质地,纹理,理,组织,肌理,气质,性格,实质,特征,织品,织物",
"thai":"n:泰语",
"thailand":"n:泰国,泰",
"thalamus":"n:丘脑,床,花托,室,闺房",
"thalidomide":"n:镇静剂",
"thallium":"n:铊",
"thames":"n:泰晤士河",
"than":"p:比;c:比",
"thank":"v:感谢,谢谢,谢,道谢,致谢,酬谢;n:谢意,谢忱",
"thank you":"n:谢谢,多谢",
"thankfulness":"n:谢意,谢忱",
"thanks":"i:多谢,谢谢;n:谢礼;v:领教",
"thanks to":"p:由于,感谢,亏得,托;v:搭帮,多亏",
"thanksgiving":"n:感恩节,感谢,感恩,谢恩",
"thanksgiving day":"n:感恩节",
"that":"r:那;c:以致;a:那个;d:那样",
"that much":"n:那么些",
"thatch":"n:茅草;v:盖",
"thatched roof":"n:茨",
"thaumaturge":"n:魔术师,术士",
"thaw":"v:融化;n:缓和",
"thawing":"v:解冻",
"the gambia":"n:冈比亚",
"the hague":"n:海牙",
"the holy see":"n:教廷",
"the least bit":"n:半,一丝一毫",
"the like":"n:辈",
"the right way":"n:正路",
"the star-spangled banner":"n:花旗,星条旗",
"theater":"n:剧院,戏剧,影剧院,战场,讲堂,场所",
"theater ticket":"n:戏票",
"theatre":"n:剧院,戏院,剧场,戏剧,战场,戏园子,讲堂,场所",
"theatre of operations":"n:战区",
"theatricality":"n:戏剧性",
"theatricals":"n:戏剧",
"thee":"r:你",
"theft":"n:偷窃,盗窃,偷盗,失窃",
"their":"a:厥",
"theism":"n:有神论",
"them":"r:她们,他们,它们,人家;a:他们,它们,她们",
"theme":"n:主题,题目,话题,主旋律,题材,论文,作文,论题,词干",
"theme song":"n:主题歌",
"then":"d:然后,那时,当时;c:然则;r:这儿,那时,这时候,咱;n:后来,当时;p:继",
"thence":"d:因此",
"theocracy":"n:神权",
"theodolite":"n:经纬仪",
"theologian":"n:神学家",
"theology":"n:神学",
"theorem":"n:定理,法则,公理,定律",
"theoretician":"n:理论家,空想家",
"theoretics":"n:理论",
"theories":"n:理论",
"theorist":"n:理论家,空谈家",
"theorize":"v:推理,理论化",
"theory":"n:理论,学说,论,原理,意见,推测,见解,虚,论说;a:虚;v:说",
"theory of relativity":"n:相对论",
"therapeutics":"n:治疗学,疗法",
"therapy":"n:治疗,疗法",
"there":"r:那儿,那边,那里;d:那里,那儿;n:那儿,那里",
"thereabout":"d:附近,上下,左右,大约",
"thereabouts":"d:左右,附近,大约,上下",
"thereafter":"d:此后,以后,尔后,已",
"thereby":"d:因此;c:从而",
"therefor":"d:因此",
"therefore":"d:所以,用,于是;c:故此,因此,所以,故,故而",
"therefrom":"d:从此;c:由此",
"therein":"d:其中,个中",
"thereof":"d:由此,因此",
"thereto":"d:又",
"thereupon":"d:爰,遂,从此,因此;c:于是,跟着",
"therewith":"d:以此,于是,立刻,同时",
"therm":"n:千卡,大卡,温泉",
"thermal":"a:热",
"thermal barrier":"n:跃变层,热障",
"thermal spring":"n:温泉",
"thermistor":"n:热敏电阻",
"thermocouple":"n:热电偶",
"thermodynamics":"n:热力学",
"thermometer":"n:温度计,寒暑表,温度表,体温表",
"thermos":"n:暖瓶,暖水瓶,热水瓶",
"thermos bottle":"n:冰瓶,暖瓶,暖水瓶",
"thermos flask":"n:暖壶,热水瓶",
"thermostat":"n:恒温器,恒温箱",
"thesaurus":"n:汇编,辞典,同义词,百科全书,宝库,仓库",
"these":"r:这些,这些个;n:提纲;a:这些",
"thesis":"n:论文,论点,命题,假设,正题,论题,论著,见解,论断,作文",
"thespian":"a:演员",
"thew":"n:活力,体力,肌肉",
"they":"r:他们,它们,她们,人们,其,人家,众人",
"thiamine":"n:硫胺素,硫胺",
"thick":"a:厚,浓密,浓,粗,茂密,稠,密,厚实,粗大,浓厚,浓重;d:密,时常,深,过度;n:笨蛋,傻子,浆液",
"thicken":"v:加厚,加强,勾,增多",
"thickener":"n:糊料",
"thickening":"v:肥厚,加厚;a:肥厚",
"thicket":"n:灌木丛,树丛,丛",
"thickheaded":"a:冥顽,顽钝",
"thickly":"d:浓",
"thickness":"n:厚度,厚,粗,粗细,模糊不清,浓厚,愚笨,稠密,浓度,浓,迟钝,稠度,密度,密,薄厚,厚薄,粗大;a:迟钝,厚",
"thickset":"n:丛林;a:粗壮",
"thief":"n:小偷,贼,窃贼,盗贼,偷,盗窃犯,盗,贼人,宄",
"thieve":"v:偷窃,窃取,偷;n:小偷",
"thievery":"n:偷窃,贼赃",
"thieves":"n:小偷",
"thievish":"a:鬼头鬼脑",
"thigh":"n:大腿,髀,股",
"thighbone":"n:髀,股骨",
"thimble":"n:顶针,洋地黄,针箍,套管,套筒,离合器",
"thimbleful":"n:一点儿,少量,些微;a:一点儿",
"thin":"a:薄,瘦,细,稀薄,单薄,清瘦,稀,稀疏,淡,瘦瘠,淡薄,削瘦,单;v:疏苗",
"thin out":"v:疏苗,间",
"thing":"n:事,事情,东西,事物,物,生物,事态,事件,事儿,情形,行为,家伙,事业,形势,消息,细节,题目,玩意儿,家具,行动,局面,物件,目标,用具,成就,财产,玩艺,要点,玩意,议会,歌曲,宇宙,动产,举动,成果,主题,个体,服装",
"thingamabob":"n:零件",
"things":"n:事态",
"think":"v:认为,想,以为,觉得,看,考虑,当,思考,打算,感到,想起,想象,想像,心想,思索,思,想得到,动脑筋,企图,构思,计较,思念,料想,怀念,想念,念,掂量,合计,寻思,判断,打量,斟酌,猜想,算,缅想,缅怀,忖量,思虑,掂掇,凝思;n:想法",
"think back":"v:回想,追思",
"think of":"v:建议,思考,恁,怀,想起,怀念,认为,思念,想念,考虑,缅怀,思,缅想,念",
"think over":"v:考虑,虑,忖量,酌,寻思,计较,凝思,掂掇,掂量,合计,斟酌",
"think tank":"n:智囊团",
"thinker":"n:思想家",
"thinking":"n:思想,想法,考虑,思维,思考;v:惟,思;a:思想",
"thinner":"n:稀释剂",
"thinning":"n:间苗,疏苗;v:间苗,稀释",
"third":"a:丙",
"third degree":"n:逼供,拷问",
"third dimension":"n:立体感",
"third party":"n:第三者",
"third world":"n:第三世界",
"thirst":"n:渴望,渴,口渴,饥渴,热望,干旱;v:渴",
"thirst for knowledge":"n:求知欲",
"thirstily":"a:渴;d:渴",
"thirstiness":"n:渴,渴望,干旱",
"thirsty":"a:渴,口渴,干渴",
"thirty":"n:死;a:卅",
"thirty-seven":"n:三七",
"this":"r:这,这个,此,这里,之,这一,本,该,这时,敝;a:这,这个;n:底;v:是",
"this evening":"n:今晚,今夜",
"thistle":"n:蓟",
"thither":"d:那里",
"thole":"n:允许,接受,遭受",
"thong":"n:皮带",
"thorax":"n:胸,胸廓,胸部,膛,胸腔,胸膛,匈",
"thorium":"n:钍",
"thorn":"n:刺,荆棘,棘",
"thorn apple":"n:曼陀罗",
"thorny":"a:棘手,扎手,辣手",
"thorough":"a:彻底,一丝不苟,周到,地道,透彻,深入,透辟,周全;n:洞;v:一丝不苟",
"thoroughfare":"n:通行,要道,大街,逵,通道,通衢,冲,阳关道,水路,衢,通路,干道,通途",
"thoroughgoing":"a:深,彻底",
"thoroughly":"d:透顶,透,根本,根,清,穷,一干二净;n:根",
"thoroughness":"n:完全",
"thorpe":"n:村庄",
"those":"r:彼,人们,那些;a:那些",
"thou":"r:你,汝,尔",
"though":"c:虽然,尽管,虽;d:然而",
"thought":"n:思想,想法,念头,思考,思维,心思,思潮,打算,灵魂,关心,观念,维,顾虑,念,意念,意图,忧虑,挂念,惟,意向,感怀,胸臆;v:念,惟,思",
"thoughtful":"a:周到,到,周至,周,绵密;n:周",
"thoughtfulness":"n:无微不至",
"thoughtless":"a:粗心,粗心大意,着三不着两,不经意",
"thoughtlessly":"d:等闲,混;a:等闲;v:混",
"thoughts":"n:思潮,感想,心思;v:感怀",
"thousand":"a:千,层次,仟;n:千,无数,许多",
"thrall":"n:束缚,奴仆,奴役",
"thralldom":"n:奴役,束缚",
"thrash":"v:打,痛打,鞭打,翻腾,脱粒,击,抽打,胜过,抽;n:打击,击败",
"thrasher":"n:打谷机",
"thrashing":"v:颠簸,打散;n:脱粒,鞭打",
"thread":"n:线;v:穿线,贯通,通过",
"threads":"n:服装,衣服",
"thready":"a:线形",
"threat":"n:威胁,恐吓,危险,威吓,凶兆,样子",
"threaten":"v:威胁,扬言,要挟,逼,恫吓,恐吓,威吓,张牙舞爪,恐,吓",
"three":"a:三,叁",
"three-d":"n:立体电影,三维",
"three-dimensional":"a:立体",
"three-ply":"a:三合板",
"threnody":"n:哀悼,挽歌,悲歌,哀歌,悲哀",
"thresh":"v:脱粒,打场;n:脱粒",
"thresher":"n:打谷机",
"threshing":"v:脱粒",
"threshold":"n:开始,门槛,阈,门限,畿,阈限,阃,门坎,门口,界线,门槛儿,入门,限度,界限,开端,槛,辚,入口",
"thrice":"d:十分,非常,屡次,再三",
"thrift":"n:节俭,节约,繁荣,劳动,兴旺,工作,繁茂",
"thrifty":"a:节俭,俭省,经济,俭;v:数米而炊",
"thrill":"n:震颤,刺激性,战栗,颤动,心跳,发抖,脉搏;v:颤动,发抖",
"thrilling":"a:惊险,毛骨悚然,来劲,扣人心弦;v:扣人心弦,震撼人心",
"thripid":"n:蓟马",
"thrive":"v:兴旺,欣欣向荣,繁荣,繁茂,蔓延,成功,发胖,上膘,致富,勃发,蒸蒸日上",
"thriving":"a:兴隆,兴旺,蓬勃,欣欣,兴盛,勃勃,发达,繁盛,昌明,炽盛;v:昌明,勃勃,发达,蓬勃,欣欣向荣,繁盛,兴旺,蒸蒸日上",
"throat":"n:喉咙,嗓子,喉头,喉,咽喉,嗓子眼,嗓音,入口,嗓,会厌;v:开槽,掘",
"throb":"v:跳动,跳,激动;n:跳动",
"throe":"n:剧痛,痛苦,阵痛",
"thrombus":"n:血块,血栓",
"throne":"n:王位,国王,位,宝座,帝位,皇帝",
"throng":"v:挤满,蜂拥,拥,拥塞;n:大量,众多;a:拥挤",
"throttle":"v:扼杀,窒息,减速,压制,抑制;p:经由,通过,由于,穿过;n:油门;d:穿过",
"throttle valve":"v:闸门",
"through":"p:通过,从,穿过,过,透过,经过,由于,出来,经历,以,透,经,由,贯穿,因为,完全,通,彻底,直达,到底,从头到尾,全体,全面,完毕,多亏,用尽;v:穿过,直达,通;a:干道,接通;f:过",
"through the use of":"p:以,由于",
"through with":"n:完成",
"throughout":"d:一,自始至终,从头至尾,全部,竟;p:全面;v:到头;a:一",
"throughput":"n:吞吐量,生产能力,产量,流量,生产量",
"throw":"v:扔,扔掉,投掷,掷,抛,丢,摔,抛弃,投,放弃,丢掉,打开;n:丢,摔",
"throw a fit":"v:大发雷霆",
"throw away":"v:弃,扔掉,丢掉,丢开,浪费,屏弃,甩掉,掼,委,弃绝,扔",
"throw back":"v:拒绝",
"throw in":"v:认输,投放,插话",
"throw off":"v:抛弃,甩,抛开",
"throw out":"v:腆,逐出,赶走",
"throw overboard":"v:撇",
"throw up":"v:哕,重提,撂手,吐",
"throwback":"n:返回,阻止,后退;v:返回",
"thrower":"n:喷射器",
"thrum":"n:花药,雄蕊,机头,线头,花丝,穗子;v:乱弹",
"thrush":"n:画眉,口炎,鹅口疮",
"thrust":"v:刺,推,插;n:推,塞,拉力;a:莽撞",
"thrust out":"v:推出",
"thruster":"n:推进器",
"thruway":"n:高速公路",
"thud":"n:砰;v:扑腾;d:咕咚",
"thug":"n:暴徒,凶手,刺客",
"thule":"n:极点,绝顶,北极",
"thulium":"n:铥",
"thumb":"n:大拇指,拇指;v:翻阅",
"thumbprint":"n:手印",
"thumbtack":"n:摁钉儿,图钉",
"thump":"v:捶,扑腾,捶打,悸动;d:砰,扑通;n:砰",
"thumping":"d:扑通",
"thunder":"n:雷声,雷,轰隆,霹雳;v:骂,轰鸣;d:砰",
"thunderbolt":"n:晴天霹雳,霹雳,雷电,霆,雷霆,恐吓,落雷,霹雷",
"thunderclap":"n:雷声,雷霆,霹雷,霹雳",
"thundercloud":"n:雷雨云",
"thundering":"v:异常,非常",
"thunderous":"a:雷鸣,山响;v:雷动",
"thundershower":"n:雷阵雨",
"thunderstorm":"n:雷雨,雷暴",
"thundery":"a:雷鸣",
"thursday":"n:周四,礼拜四",
"thus":"d:这样,因此,于是,这么,如此,因而,如下,就此,由此,例如,斯;c:由此,所以,因此,由此可见,因而,从而",
"thus far":"a:到此为止,至此,至今,迄今为止",
"thwart":"v:挫败,阻挠,穿过,反对;d:横跨",
"thyroid":"n:甲状腺,甲状软骨",
"tianjin":"n:天津,天京,津",
"tibet":"n:西藏",
"tibia":"n:胫骨",
"tic":"v:抽搐,抽搦;n:抽搐",
"tick":"n:赊,枕套,信用,钩;v:对号,一点,标记,打点,赊销,吞吞吐吐,责骂,滴沥;a:片刻",
"tick off":"v:责骂",
"tick over":"v:吞吞吐吐",
"ticker":"n:心脏,座钟,摆,挂表,收报机",
"ticker tape":"n:纸带",
"ticket":"n:票,车票,入场券,标签,门票,票证,传票,客票,券,规划,政纲,计划,执照,方针,证明书,许可证",
"ticket agent":"n:售票员",
"ticket booth":"n:售票处",
"ticket collector":"n:收票员",
"ticket office":"n:票房",
"ticking":"n:褥套",
"tickle":"v:发痒,痒痒,痒,逗笑,撩拨;a:高兴,痒;n:搔痒",
"tickler":"n:备忘录,难题,难事,记事本",
"tickling":"v:反馈",
"ticklish":"a:难人",
"ticktock":"v:滴答,滴滴答答;n:嘀嗒",
"tidal bore":"n:潮涌",
"tidal current":"n:潮流",
"tidal wave":"n:地震波,潮流",
"tidbit":"n:珍闻",
"tide":"n:潮水,涨潮,潮汐,形势,潮,浪潮,潮流;v:克服,渡",
"tide over":"v:渡过,度过,渡",
"tidewater":"n:潮水",
"tideway":"n:潮流",
"tidiness":"n:整洁,整齐",
"tidings":"n:音信,音讯,音,消息",
"tidy":"a:整齐,楚楚,严密,整;v:整饬",
"tidy up":"v:理,收拾",
"tie":"v:系,捆;n:结扎,缘分,和局",
"tie beam":"n:屋梁",
"tie clip":"n:领带夹",
"tie down":"v:束缚",
"tie in":"v:连接",
"tie rod":"n:连杆",
"tie up":"v:缚,捆绑,打,绑,冻结,维,缠,捆扎,湾,絷,捆缚,绾",
"tie-in":"n:联系,关系",
"tie-up":"n:停顿,断绝,关系,牵连",
"tieback":"n:挂钩",
"tiepin":"n:领带夹",
"tier":"n:排,层,等级,行,胸围,类别",
"tiff":"v:斗嘴,勃谿,动怒,口角,争吵,生气;n:争执,口角,酒,重晶石",
"tiffany":"n:纱",
"tiger":"n:老虎,虎,於菟,暴徒,狗鱼",
"tight":"a:紧,瘦,严密,紧凑,严,紧张,紧巴巴,严紧,紧绷绷,小气;v:勒",
"tighten":"v:紧,绷,紧缩,固定,收紧,勒,上弦,煞",
"tighten up":"v:收紧",
"tightfisted":"v:手紧;a:手紧",
"tightly":"d:紧紧,紧;v:绸缪",
"tightness":"n:紧密",
"tights":"n:紧身衣",
"tightwad":"n:吝啬鬼",
"tigress":"n:雌老虎,母老虎",
"til":"p:直到,为止,直到_为止",
"tile":"n:瓦,瓦片,瓷砖,礼帽,托盘,花砖,牌,瓦块",
"tiler":"n:瓦匠,泥瓦匠,瓦工,泥水匠",
"tiling":"n:瓷砖,花砖,瓦工",
"till":"v:耕田,耕作,赶,耕种,佃,翻耕,耕;p:为止;n:抽屉;c:直到",
"tillage":"n:耕种,耕作;v:耕作,耕种",
"tiller":"n:分蘖,农夫;v:分蘖",
"tilt":"n:倾斜;v:掀动,战斗,戳,偏袒,偏斜,歪斜",
"tilt angle":"v:仰角",
"tilted":"v:偏斜,斜",
"tilting":"a:偏斜;v:偏斜",
"timber":"n:木材,木料,木头,树木,森林,才干,素质,原木,才能,材,音色",
"timber hitch":"n:绳结",
"timberland":"n:林场,林地",
"timbre":"n:音色,音质,音品",
"time":"n:时间,时候,过,次,时代,时刻,日子,时光,岁月,回,时,时机,机会,光阴,闲暇,光,一生,钟,工夫,时日,次数,日,现代,时节,季节,形势,功夫,早晚,节奏,年代,倍;v:调和;d:过",
"time bill":"n:时间表,期票",
"time clock":"n:定时器,考勤钟",
"time immemorial":"n:远古",
"time interval":"n:时段",
"time lag":"n:时差",
"time note":"n:期票",
"time out":"n:停工,暂停",
"time sheet":"n:时间表",
"time zone":"n:时区",
"time-out":"n:暂停",
"timekeeper":"n:计时员",
"timeless":"a:永生永世;d:永生永世",
"timeliness":"n:及时,适时,天时,时间性",
"timely":"a:及时,适时;v:适逢;d:及时",
"timepiece":"n:钟表",
"timer":"n:定时器,计时器,计时员,跑表",
"times":"n:倍,时世,年头,时光,时报,时代,时,倍数;p:乘",
"timetable":"n:时间表,时刻表,课表",
"timeworn":"v:年深日久;a:年深日久",
"timid":"a:怯,怕人,畏葸,虚,怕事,畏怯;v:怯声怯气",
"timidity":"n:胆小",
"timing":"n:定时,计时,同步,调速;v:安排,定时,计时;d:定时",
"timpani":"n:定音鼓",
"tin":"n:罐头,锡,听,罐,白铁,听子;v:镀锡",
"tin can":"n:听子,潜艇,罐头,深水炸弹",
"tin ear":"n:重听",
"tin hat":"n:钢盔,醉鬼",
"tin plate":"n:白铁",
"tincture":"n:气味,色彩,色调,酊剂,染料,颜色,色,药酒,迹象,色泽,特征;v:染,着色",
"tincture of iodine":"n:碘酒,碘酊",
"tinder":"n:火绒,导火线,火种",
"tine":"n:叉",
"tinfoil":"n:锡箔,锡纸",
"ting":"n:铃声",
"tinge":"n:气味,色调,色泽;v:染色,染",
"tinging":"v:染色",
"tingle":"v:刺痛,激动,麻;n:刺痛,鸣响,震颤,兴奋",
"tingly":"a:酸溜溜",
"tinker":"n:修补,流浪者,小炉匠,小炉儿匠;v:修补",
"tinned":"a:马口铁,听装;v:听装",
"tinning":"v:镀锡;n:罐头",
"tinnitus":"n:耳鸣",
"tinplate":"n:马口铁,洋铁",
"tinsel":"n:箔条",
"tinsmith":"n:锡匠",
"tint":"n:色彩,气息,色泽,着色,色调;v:染色",
"tinting":"v:着色",
"tiny":"a:微小,细微,细小,渺小,微细,微,小不点儿,眇;n:癣,小不点儿,小孩子",
"tip":"n:小费;v:推倒,举报,倾覆,警告,提醒;a:尖",
"tip off":"v:警告",
"tip-off":"n:警告,暗示,告诫,提示",
"tippet":"n:披肩,斗篷,披巾",
"tipple":"n:烈酒,酒",
"tippler":"n:酒鬼,酒徒",
"tipsiness":"n:倾斜",
"tipsy":"a:醉,酕醄,酒酣耳热,醉醺醺;v:醉",
"tiptoe":"n:脚尖;d:偷偷;v:跐",
"tiptop":"n:极盛,最高点,绝顶;d:至高无上,极,非常;a:呱呱叫,拔尖",
"tirade":"n:长篇大论",
"tire":"v:疲倦,厌倦,疲劳,厌烦,打扮,装饰;n:轮带,围裙",
"tire chain":"n:防滑链",
"tire out":"v:累,筋疲力尽",
"tired":"a:累,疲倦,厌倦,疲劳,疲乏,劳累,困,倦,生气,委顿,困乏,乏,劳乏,疲;v:顿",
"tired of":"a:厌烦",
"tiredness":"n:疲劳,倦意",
"tirelessly":"d:娓娓",
"tiring":"a:困人",
"tissue":"n:组织,薄纸,面纸,织物,卫生纸",
"tissue paper":"n:绵纸,卫生纸",
"tit":"n:奶头,乳头,山雀",
"tit for tat":"n:回敬",
"titan":"n:巨人,巨头",
"titanic":"a:巨大",
"titanium":"n:钛",
"titillate":"v:搔痒;n:搔痒",
"titillation":"n:搔痒",
"titivate":"v:打扮,装扮,装饰",
"title":"n:头衔,爵位,冠军,所有权,标题,称号,题目,书名,名字,贵族,职务,地契,权利,尊称,资格,学位,题,字幕,称谓,锦标,题名",
"title deed":"n:地契,税契,房契",
"titmouse":"n:花雀,黄雀,山雀,小气鬼",
"titre":"n:纤度",
"titter":"v:傻笑,噗嗤,窃笑,咯咯,痴笑;n:小姑娘;d:咯咯,扑哧",
"tittle":"v:闲谈,杂谈;n:符号,微粒",
"tittle-tattle":"n:杂谈",
"titty":"n:乳房",
"titular":"v:挂名,有名无实;n:名义;a:有名无实",
"tnt":"n:梯恩梯",
"to":"p:一,去,对,和,到,给,向,于,每,跟,比,对于,往,靠,及,达到,至,望,朝,照,为止,缺,诸,朝着,致使,奔,向着,到_为止,照着;v:臣服,投;d:关闭;r:诸",
"to a fault":"p:过度,极端,无以复加",
"to a man":"p:一体",
"to advantage":"p:更加,有利",
"to be sure":"v:诚然,无疑,当然",
"to boot":"p:加之,并且",
"to date":"p:迄今",
"to the full":"p:充分,尽力,饱,尽量;d:尽量",
"to the limit":"p:尽",
"to-do":"n:吵闹,骚扰,混乱",
"toad":"n:癞蛤蟆,蟾蜍,蟆,虾蟆,蟾,蛤蟆",
"toadstool":"n:毒蕈,毒菌",
"toady":"n:哈巴狗;v:谄媚",
"toadyism":"n:奉承",
"toast":"v:敬酒,烤肉,祝酒,干杯,烘烤;n:土司,祝酒,祝酒词",
"toaster":"n:烤箱",
"toastmaster":"n:主持人",
"toasty":"a:温暖,舒畅",
"tobacco":"n:烟草,烟,烟丝,烟叶,卷烟,旱烟,纸烟,烟瘾",
"tobacco pipe":"n:烟斗",
"tobacco plant":"n:烟草",
"toboggan":"v:猛跌",
"tocsin":"n:警钟,警报",
"tod":"n:树丛",
"today":"n:今天,今日;d:于今;a:现代",
"toddle":"v:跳舞,闲荡;n:散步",
"toddy":"n:威士忌",
"toe":"n:脚趾,脚,脚尖,尖,脚指头,趾,尖头,趾头,指头",
"toehold":"n:立足点",
"toenail":"n:趾甲",
"toff":"n:花花公子",
"toffee":"n:奶糖",
"tofu":"n:豆腐",
"tog":"v:打扮;n:上衣",
"toga":"n:罩袍,制服,长袍",
"together":"d:一起,共同,同,一块儿,同时,一道,互相,一同,连续,共,一齐,交,混合,齐,一发,搭帮;v:统,相与;n:旅;a:联翩",
"together with":"p:一同,和,一起,与_一起,偕,与",
"toggle":"n:触发器",
"toggle switch":"n:触发器",
"togo":"n:多哥",
"toil":"n:辛劳,劳苦,劳累,陷阱,辛苦;v:累,辛劳,跋涉",
"toilet":"n:厕所,马桶,打扮,洗手间,卫生间,服装,化妆,浴室,厕,盥洗室,梳妆台,厕所间;v:洗涤,打扮",
"toilet articles":"n:盥",
"toilet bowl":"n:抽水马桶",
"toilet paper":"n:手纸,卫生纸,桑皮纸,草纸",
"toilet powder":"n:爽身粉",
"toilet soap":"n:香胰子",
"toilet tissue":"n:桑皮纸,手纸,草纸",
"toilet water":"n:香水",
"toiletry":"n:化妆品",
"toilette":"n:服装,礼服,梳妆,装束,化妆,衣服",
"toiling":"v:劳苦",
"toilsome":"a:辛苦",
"token":"n:纪念品,象征;v:象征",
"tokenism":"n:表面文章,装门面",
"tokyo":"n:东京",
"tole":"n:诱惑,怂恿",
"tolerable":"a:过得去",
"tolerance":"n:公差,容忍,耐性,忍受,耐力,气量,气宇,肚量,度量,器量,度,心路,气度",
"tolerant":"a:宽容,开阔,相容,耐烦;v:相容",
"tolerate":"v:容忍,忍受,容许,忍,姑息,宽容,容,默认,假借,包容,耐受,宽让",
"toleration":"n:宽容,忍受,默认,默许",
"toll":"n:税;v:报丧,勾引",
"tolstoy":"n:托尔斯泰",
"toluene":"n:甲苯",
"tom thumb":"n:大拇指",
"tomato":"n:西红柿,番茄,脸,姑娘,洋柿子",
"tomb":"n:坟墓,陵墓,墓,墓碑,墓穴,坟茔,坟,窀穸,墓葬,冢;v:埋葬",
"tombs":"n:墓葬",
"tombstone":"n:墓碑,墓碣,神道碑,牙齿",
"tomfoolery":"n:蠢事",
"tomorrow":"n:明天,明日,未来,明儿,来日,往后",
"tomtit":"n:山雀",
"ton":"n:吨,许多,大量,时髦,总吨位,流行",
"tonal":"a:音调",
"tonality":"n:色调,音律,音调",
"tone":"n:口气,声调,语调,口吻,语气,音调,色调,声,气氛,调子,音质,风气,情调,紧张,情况,格调,音色,笔调,抑扬,音乐,风格,话音,乐音;v:调色,提高,调和,调头;a:紧张",
"tone up":"v:提高",
"tonga":"n:汤加",
"tongs":"n:火钳,夹子,火剪,钳子,夹剪,钳",
"tongue":"n:舌头,舌,语言,口舌,火舌,说法,湾,针,口才,律师,衔铁,语;v:申斥,谴责,说,舔",
"tongue twister":"n:急口令,拗口令",
"tongue-lashing":"n:训斥,辱骂,斥责",
"tongue-tied":"v:语塞",
"tonic":"n:补药,主音,补品,强壮剂,补益,基音,兴奋剂;a:补益",
"tonight":"n:今晚,今夜",
"toning":"v:调色",
"tonnage":"n:吨位,排水量",
"tonsil":"n:扁桃腺,扁桃体",
"tonsillitis":"n:扁桃体炎",
"tonsure":"v:剃度,剃;n:出家,削发",
"too":"d:太,也,很,过,过于,还,已,又,而且,非常,还是,同样,极,亦,泰,忒,加之",
"too bad":"a:糟糕",
"too much":"a:过多,苦,多",
"too soon":"d:为时过早",
"tool":"n:工具,刀具,手段,用具,爪牙,方法,家伙,器具,具,傀儡,走狗,刀叉;v:闲逛,闲荡",
"tool cabinet":"n:工具箱",
"tool case":"n:工具箱",
"tool chest":"n:工具箱",
"tool kit":"n:工具箱",
"toolkit":"n:工具包",
"toolmaker":"n:制造,维修",
"tools":"n:农具",
"toot":"v:吹,叫;n:酒宴,痛饮;d:呜,呜呜",
"tooth":"n:牙齿,牙,齿,锯齿,嗜好;v:咬",
"tooth decay":"n:龋齿",
"tooth root":"n:牙根",
"toothache":"n:牙痛",
"toothbrush":"n:牙刷",
"toothpaste":"n:牙膏",
"toothpick":"n:牙签",
"tootle":"n:空谈,废话;v:空谈",
"top":"n:顶,瓶盖,盖,顶端,陀螺,顶部,面;v:覆盖,绞死;a:尖",
"top brass":"n:要员",
"top dog":"n:老板",
"top off":"v:结束,告终",
"top out":"v:优选",
"top-heavy":"a:头重脚轻",
"top-notch":"a:拔尖",
"top-secret":"a:绝密",
"topaz":"n:黄玉,蜂鸟",
"topcoat":"n:外套,大衣",
"topic":"n:话题,题目,主题,论题,原则,细目,原理,标题,题名,概论,题",
"topicality":"n:地区性",
"topknot":"n:头饰",
"topmost":"a:十",
"topography":"n:地形,地形学,地志,外形,地势",
"topology":"n:拓扑,拓扑学,地志",
"topping":"n:上层,顶部;v:打尖",
"topple":"v:倒,倒塌,推翻,摇摆,摇动,摇摇欲坠,倾覆,推倒",
"tops":"a:最好,首屈一指;n:轻油",
"topside":"n:舱面,楼上;d:上面",
"topsoil":"n:表土",
"topsy-turvy":"n:颠倒",
"tor":"n:高峰",
"torah":"n:经学,教导",
"torch":"n:手电筒,火炬,火把,电筒,吹管,喷灯,焊炬,手枪,电棒",
"torchlight":"n:火炬",
"torment":"v:折磨;n:拷问,苛责",
"tormented":"a:苦恼;v:苦恼",
"torn":"a:破;v:破损",
"tornado":"n:龙卷风,旋风,羊角,大水,激流",
"toroid":"n:环行线,环",
"torpedo":"n:鱼雷;v:破坏",
"torpedo boat":"n:鱼雷艇",
"torpid":"a:蛰伏,麻木不仁;v:蛰伏",
"torpidity":"n:麻痹,蛰伏,迟钝,麻木",
"torpidly":"d:不死不活",
"torpor":"n:麻木;v:蛰伏",
"torque":"n:力矩,项链",
"torr":"v:托;n:乇",
"torrent":"n:急流,激流,洪流,洪水,爆发,迸发,连发,湍流",
"torrential":"a:瓢泼,波澜壮阔,湍,滔滔,滂沱,湍急;v:滚",
"torridity":"n:炎热",
"torsion":"n:扭转,扭力",
"torsion balance":"n:扭力天平",
"torso":"n:躯干,上焦,胴,雕像",
"tort":"v:侵权;n:侵权",
"tortoise":"n:乌龟,金龟,玄武,龟,王八",
"tortoiseshell":"n:龟板,龟甲",
"tortuous":"a:曲折,迂回,迂曲,盘陀;v:迂回",
"torture":"v:折磨,拷打;n:毒刑",
"torus":"n:花托",
"tory":"n:保守派",
"tosh":"n:废话;a:友善;v:装饰",
"toss":"v:扔,颠簸,抛,掷,丢,甩,投;n:二传",
"tot":"n:小孩,微量,总和,总数,少量,合计;v:加,合计",
"total":"n:总数;a:全部,全,总的;v:总计",
"total eclipse":"n:全食",
"totalitarian":"n:极权",
"totalitarianism":"n:极权主义",
"totality":"n:总和,总体,全部,总数,完备,全体,完全",
"totally":"d:全,统统;a:百分之百",
"tote":"v:带,携带,负;n:总数",
"totem":"n:图腾",
"totter":"v:摇摇欲坠,摇摆;n:动摇,摇摆",
"tottering":"v:风雨飘摇,松动,东倒西歪,摇摆;a:颤巍巍,跌跌撞撞",
"toucan":"n:犀鸟",
"touch":"v:碰,感动,接触,摸;n:接触,试验,笔锋;a:少量",
"touch down":"v:降落",
"touch off":"v:引发",
"touch on":"v:触及,论及",
"touch up":"v:贴金,描,润饰,润,修改",
"touch-and-go":"a:快速",
"touchdown":"n:接地",
"touched":"v:动心",
"touching":"a:动人,感人,缠绵;p:关于,提到",
"touchstone":"n:检验,试金石",
"tough":"a:强硬,老,硬,艰苦,结实;n:恶棍,无赖",
"toughen":"v:锻炼,严厉,坚韧,健",
"toughie":"n:流氓,难题,恶棍,困境,暴徒",
"toughness":"n:韧性,刚毅",
"toupee":"n:假发",
"tour":"v:巡回演出;n:漫游",
"tour de force":"n:力作,杰作",
"tour guide":"n:导游",
"tourer":"n:旅游者,游客,游览车",
"touring car":"n:旅游车",
"tourism":"n:旅游,观光",
"tourist":"n:游客,旅游者,游人,观光者",
"tourist class":"n:统舱",
"tourmaline":"n:电气石,电石",
"tournament":"n:比赛,锦标赛,联赛",
"tourney":"n:锦标赛",
"tousle":"v:搅乱;n:乱发",
"tout":"v:吹捧,招徕;n:招揽",
"tout ensemble":"n:概观",
"tow":"n:拖;v:拉,牵引",
"tow truck":"n:拖车",
"toward":"p:向,对,朝,走向,接近,往,对于,左右,奔,投,向着,约;v:投;d:将近",
"towards":"p:对,向,朝,对于,冲,往,跟,向着,关于,照",
"towboat":"n:拖驳,拖船,拖轮",
"towel":"n:毛巾,手巾,羊肚儿手巾",
"towel rail":"n:毛巾架",
"tower":"n:塔,塔楼;v:突起,突兀",
"tower of strength":"n:铜墙铁壁",
"towering":"a:参天,巍峨,崔嵬,崔巍,屹然,冲天,巍巍,嵯峨,峥嵘;n:崔巍,崔嵬;d:屹然,巍然;v:高耸",
"towing":"v:拖带",
"towline":"n:纤,纤绳",
"town":"n:镇,城镇,城市,城,市镇,镇子,市区,村镇,集镇,城堡,农庄,汤,市井,堡",
"townie":"n:居民",
"townsfolk":"n:市民",
"township":"n:乡",
"townsman":"n:市民,乡亲,镇民",
"townspeople":"n:市民",
"towrope":"n:纤绳",
"toxic":"n:毒物,毒剂",
"toxicity":"n:毒性",
"toxicology":"n:毒理学",
"toxin":"n:毒素,毒",
"toy":"n:玩具,玩物;v:戏弄,调戏",
"toyshop":"n:玩具店",
"trace":"n:痕迹;v:查找,追究,追,探寻,回溯;a:微量",
"tracer":"n:描图员,探针,曳光弹",
"tracer bullet":"n:曳光弹",
"traces":"n:遗迹;v:套",
"trachea":"n:气管,导管",
"tracing":"n:追溯,探索,追查,追踪;v:描图,寻找",
"track":"n:跑道,磁道,轨道,小路,足迹;v:前进,蹑踪,追赶,通过",
"track down":"v:追寻,追赶",
"track meet":"n:径赛",
"tracker":"n:纤夫",
"tracking":"n:车辙,跟踪;v:跟踪",
"trackless":"a:无轨",
"tracks":"n:行迹",
"trackway":"n:行迹,导轨",
"tract":"n:道,系统,传单,地带,短文,地域,管,束,土地",
"tractability":"n:驯良",
"tractable":"a:听话,驯服,驯良",
"traction":"n:牵引,拖曳,吸力;v:拖带,拖曳",
"tractor":"n:拖拉机,铁牛",
"trade":"n:贸易,生意;v:行道,对换",
"trade deficit":"n:逆差,入超",
"trade in":"v:贴换,买卖",
"trade secret":"n:诀窍",
"trade wind":"n:贸易风",
"trade-off":"n:交易,交换",
"trademark":"n:商标,牌子,牌号,牌",
"trader":"n:商人,私商,商船,商",
"tradesman":"n:商人,坐商,店主",
"tradespeople":"n:零售商",
"tradition":"n:传统,传说,惯例,移交,引渡",
"traditional":"a:老,正宗",
"traduce":"v:中伤,诋毁,诽谤",
"traffic":"n:交通,来往,运输;v:出卖,运输",
"traffic island":"n:交通岛",
"traffic lane":"n:车道",
"traffic light":"n:红灯",
"trafficker":"n:贩子,生意人,奸商",
"trafficking":"v:贩卖",
"tragedy":"n:悲剧,惨案,惨变,惨剧",
"tragic":"a:悲惨,凄惨,惨,凄怆",
"tragicomedy":"n:悲喜剧",
"trail":"n:山径,轨迹;v:预示,拖曳,提,伸展,预告,四散",
"trailblazer":"n:尖兵",
"trailer":"n:拖车,挂车,挂斗,拖斗,尾部",
"train":"v:培,造,调理,代培,训;n:一行,造就,次序,结果",
"train of thought":"n:思绪,思路",
"train station":"n:火车站",
"train ticket":"n:火车票",
"trainee":"n:实习生,练习生,学徒,学员",
"trainer":"n:教练员,教员,教练",
"training":"n:训练,锻炼,修养,练习;v:练兵,整枝",
"training college":"n:师范学院",
"training school":"n:专科,专科学校",
"training ship":"n:教练船",
"traipse":"n:闲逛;v:漫步",
"trait":"n:特征,特点,性状,性格,特性,脾气,品质,容貌,特色",
"traitor":"n:叛徒,卖国贼,汉奸,奸,奸贼,内奸,逆;a:奸",
"trajectory":"n:轨道,轨迹,弹道,路径,航线",
"tram":"n:电车,纬线,煤车;v:调整",
"tramcar":"n:电车,煤车",
"trammel":"n:紧箍咒,束缚,拘束,妨害,网;v:束缚,拘束,妨害",
"trammels":"n:羁绊,紧箍咒",
"tramp":"v:踩,跋涉,步行,践踏,流浪,徘徊,漂泊;n:妓女,流氓,淫妇,瘪三,候鸟",
"trample":"v:踩,蔑视,蹂躏,踏;n:践踏,踩",
"tramway":"n:电车,索道",
"trance":"n:恍惚,昏睡;v:恍恍忽忽,昏睡",
"tranquil":"a:宁静,平静,清静,恬静,幽,安谧,靖,宓,安,镇,僻静,安宁,静谧,恬",
"tranquility":"n:平静,稳定,镇定",
"tranquilize":"v:镇定,安定",
"tranquilizer":"n:镇静剂,止痛药",
"tranquillity":"n:宁帖,平静,镇定,稳定",
"tranquillize":"v:安定,镇定",
"tranquillizer":"n:镇静剂,止痛药",
"transact":"v:处理,交易,执行,办理,谈判,进行,协议,办事",
"transaction":"n:处理,交易,事务,执行,买卖,业务,办理,和解;v:执行",
"transceiver":"n:电台",
"transcend":"v:超越,胜过,超出,凌驾,超,超过",
"transcendence":"n:卓绝,超越,卓越,超绝",
"transcendent":"a:尤物",
"transcribe":"v:转录,记录,抄,誊,录制,改编,誊写,抄录,改作,誊录,抄写,翻译",
"transcribing":"v:抄写",
"transcript":"n:记录,转述,副本,写本,抄本,改写本,抄报",
"transcription":"n:转录,抄写,誊写,抄报,翻译,副本,摹本,抄本;v:改编,抄写,转录",
"transducer":"n:传感器,发送器,变频器",
"transfer":"v:传送,转移;n:汇兑,迁移,授受,升迁,转机,变换",
"transference":"n:转移,移情,传送,输电,交付,转送;v:传送,转移,传递",
"transfiguration":"n:变形,改观,美化,变态",
"transfigure":"v:理想化,变形,美化",
"transfix":"v:刺穿,戳穿",
"transform":"v:转变,转换,变换,变,改造,转化,改,变化,变形,改变,转移,变态,改革,变革,改建,蜕变,化",
"transformation":"n:变换,转化,转变,变化,蜕变,改革,纠正,变态,变形;v:纠正",
"transformer":"n:变压器,互感器",
"transfuse":"v:灌输,渗入,注入,注射,渗透,输血,输液",
"transfusion":"n:输血,输液,渗透,灌输;v:输血,输导,输液",
"transgress":"v:违法,违犯,违反,犯规,侵越,犯法,违法乱纪,越轨,越界,超过",
"transgression":"n:超度,超过,违反,愆",
"transgressor":"n:罪人",
"transhipment":"n:转运",
"transience":"n:短暂,无常",
"transient":"n:候鸟,过客,侯鸟;a:短暂,无常;v:稍纵即逝",
"transistor":"n:晶体管,三极管",
"transit":"n:运输,通过,转变;v:转口,飞渡;a:公交",
"transit instrument":"n:经纬仪",
"transition":"n:过渡,转变,变化,变迁,转换,转折,变调,演变;v:转移,过渡",
"transitional":"a:过渡,变迁",
"transitive":"n:及物动词",
"transitory":"a:朝露",
"translate":"v:翻译,译,解释,说明,调任,转移,通译,移译,调动,翻改,翻",
"translation":"n:翻译,译文,译本,平移,改变,平动,翻新,传送,转化,转移,调任,换算,解释,调换,翻改,移位,调动,说明,转播",
"translator":"n:翻译,译者,译码器,译员,通译",
"transliterate":"v:拼写,直译,音译",
"transliterating":"v:音译;n:音译",
"transliteration":"n:译音,直译,音译;v:音译",
"translucent":"a:若明若暗",
"transmigrate":"v:迁徙,移居,转生",
"transmigration":"n:转生,轮回;v:轮回",
"transmission":"n:传输,传送,发送,传播,传递,透射,传染,变速器,传动,输电,传导,发射,通话,转播,遗传,传达,递送;v:穿透,传递,传导,发送,透射,传播,传送,发射",
"transmission line":"n:传输线",
"transmit":"v:传输,发送,传送,传播,传递,传,送,遗传,传达,传导,输送,透射,转发,播送,播音,发射,转告,传动,发报,透光,留传,送达,发信,输电,传染,转交,导,寄,通,转",
"transmittal":"n:传送,传输;v:传递",
"transmittance":"n:透明度",
"transmitter":"n:发射机,发报机,发送机,介质,话筒,送话器",
"transmitting":"v:传播,传动,透光,发射",
"transmogrification":"n:变形",
"transmogrify":"v:变形",
"transmutation":"n:衍变,嬗变,变化,蜕变,演变;v:蜕变",
"transmute":"v:变化,变形,改变,变质,蜕变",
"transnational":"a:跨国",
"transom":"n:气窗,横梁",
"transparency":"n:透明度,透明,幻灯片,明澈,透明体,明了",
"transparent":"a:透明,透,澄,澄莹,澄清,透亮,明澈;v:澄清,透亮",
"transpiration":"n:蒸发,发散,透露",
"transpire":"v:发生,泄露,排出,透露,蒸发,发汗,发散",
"transplant":"v:移植,移栽,移居;n:移栽",
"transplantation":"n:移植,迁移,移栽,殖民,移民",
"transplanting":"v:移植",
"transponder":"n:应答器",
"transport":"v:运输,运送,搬运;n:传送,运输船",
"transport ship":"n:运输舰",
"transportation":"n:运输,交通,搬运,流放,运送,转运,输送,运费,迁移;v:输送,运输",
"transporter":"n:运输机,传送带",
"transpose":"v:颠倒,变调,换位,转调,移项,调换,易位;n:反转片",
"transposing":"v:更换,置换,移项",
"transposition":"n:易位,转换,移项,转调,互换,移动,对换,交叉,调换,交错,置换;v:互换,交叉,移动,交错,置换,移项",
"transship":"v:转运,过载",
"transubstantiation":"n:变形",
"transverse":"n:横轴,横向;a:横,横渡;v:横贯",
"trap":"n:陷阱,圈套;v:发射",
"trapdoor":"n:天窗,活板门",
"trapeze":"n:吊杆,吊架",
"trapezium":"n:梯形",
"trapezoid":"n:梯形",
"trapped":"v:瓮中之鳖;a:瓮中之鳖",
"trapping":"v:俘获,捕获",
"trappings":"n:礼服,服饰,装饰,马具",
"traps":"n:夹子,行李,什物,家具",
"trash":"n:垃圾,渣滓,废料,废话,货色,劣货,黑货,落叶,废物;v:捣毁,消灭",
"trash can":"n:垃圾桶",
"trashiness":"n:没用",
"trauma":"n:创伤,外伤,损伤,痍",
"travail":"n:阵痛,工作,劳动,辛苦;v:生产",
"travel":"v:旅行;n:旅",
"travel agent":"n:旅行社",
"travel allowance":"n:车马费",
"travel by":"v:搭,搭乘,坐",
"travel time":"n:走时",
"traveler":"n:旅客,旅人,行旅,客",
"traveling":"n:带球走,移动,流动,旅行,游历;v:带球走",
"traveling bag":"n:旅行包,旅行袋,行囊",
"traveling salesman":"n:跑街",
"traveller":"n:行旅,客",
"travelling":"v:旅行,游历,流动,移动",
"travels":"n:游记",
"traversal":"n:障碍物",
"traverse":"v:穿过,横贯,横穿,横渡,通过,横跨,测定,流过,转动,否认,经历,游历,反驳;n:障碍物,否认,隔板,窗帘,阻碍,反驳,抗辩,横梁,障碍;a:横",
"travesty":"n:漫画,曲解;v:歪曲",
"trawl":"v:拖网;n:拖网",
"tray":"n:托盘,盘子,盘,浅儿,三,槃,碟",
"treacherous":"a:背信弃义,奸诈,变幻莫测,险恶,诡谲,诡诈,奸猾,奸滑,奸邪,阴险,奸险,奸",
"treachery":"n:背信弃义,变节,叛逆,谋反,背信,反叛,凶险",
"treacle":"n:糖蜜,糖浆",
"tread":"n:梯级,踏,步行,交尾,鞋底,底,蹠;v:蹂躏,交尾",
"tread down":"v:踏平,蹂躏,践踏",
"tread on":"v:跋,踺,履,蹋",
"treadle":"n:踏板;v:登",
"treason":"n:叛国罪,叛逆,谋反,背信",
"treasure":"n:财宝,宝贝;v:珍视,珍重,珍爱,热爱,爱惜",
"treasure house":"n:宝藏,宝库",
"treasured":"a:心爱;v:宝",
"treasurer":"n:司库,出纳员,收款员",
"treasures":"n:金玉",
"treasury":"n:宝库,国库,金库,国库券,库房,库,宝藏,府",
"treasury bill":"n:国库券,库券",
"treasury bond":"n:国库券,公债券",
"treasury department":"n:财政部",
"treasury stock":"n:国库券",
"treat":"v:对待,对,待,处理,待遇,治疗,请,看待,讨论,论述;n:娱乐",
"treating":"v:处理,加工",
"treatise":"n:论文,专著,论著",
"treatment":"n:处理,治疗,待遇,论述,疗法,讨论,处置,作业,诊疗;v:处理",
"treaty":"n:条约,协定,协议,谈判,交涉;v:调解",
"treble":"a:高音",
"tree":"n:树,大树,树形,乔木,木材,木料;v:穷追",
"tree diagram":"n:树形图",
"tree frog":"n:雨蛙",
"tree of heaven":"n:椿,樗,臭椿",
"tree stump":"n:树桩,树墩,树根",
"tree toad":"n:雨蛙",
"trees":"n:树木",
"treetop":"n:树梢,树丛,标",
"trek":"n:跋涉,步行,旅行;v:迁移,跋涉,拉",
"trellis":"n:框架,格子",
"tremble":"v:发抖,颤抖,颤动,担心,哆嗦,焦虑;n:震颤",
"trembling":"v:发抖,战栗,震颤",
"tremendous":"a:巨大,雄厚,巨,磅礴,庞大;d:非常",
"tremendously":"d:不胜",
"tremolo":"n:颤音",
"tremor":"n:地震,震颤,战栗,振动;v:振动,震颤,震荡",
"trench":"n:战壕,沟,壕沟,海沟,堑壕,沟渠,渠,峡谷,电缆,沟槽",
"trench knife":"n:战刀",
"trench mortar":"n:迫击炮",
"trench warfare":"n:壕堑战,堑壕战",
"trenchancy":"n:锐利",
"trenchant":"a:犀利,鞭辟入里",
"trencher":"n:饮食",
"trencherman":"n:食客",
"trend":"n:趋势,趋向,走向,倾向,潮流,动向,方向;v:侧向",
"trends":"n:动态",
"trendy":"a:入时,时新",
"trepidation":"n:颤动,惊惶,颤抖,动摇,发抖,慌张,痉挛,震颤,恐怖,战栗;a:慌张;v:颤动",
"trespass":"v:侵占,打扰;n:打扰,罪过,干犯",
"tress":"n:辫子,发辫,卷发",
"trestle":"n:支架,栈桥,高架桥",
"trestle bridge":"n:栈桥",
"trial":"n:审判,试验,考验,审问,尝试,试用,困难,磨难,试车,试制;v:尝试,考验,试验",
"trial period":"n:试用期",
"trial run":"n:测验",
"triangle":"n:三角形,三角,三角铁,三角板",
"triangular prism":"n:三棱镜",
"triangulation":"n:推论;v:推论",
"triassic":"n:三叠纪,三叠系",
"tribal chief":"n:酋长",
"tribalism":"n:派性",
"tribe":"n:部落,许多,部族,种族,家族,族,群",
"tribulation":"n:困苦,苦难,灾难,磨难,艰辛;a:困苦",
"tribunal":"n:法庭,公堂,裁判,制裁",
"tribune":"n:讲坛,看台,论坛",
"tributary":"n:支流,汊流,附庸国,属国,支脉",
"tribute":"n:礼物,敬意,贡,贡品,赠品",
"trice":"n:瞬间,一刹那",
"trichina":"n:旋毛虫",
"trichinosis":"n:旋毛虫病",
"trick":"n:花招,伎俩,诡计,戏法,把戏,习惯;v:变戏法",
"trick up":"v:打扮,装饰",
"trickery":"n:手段,诡计,欺骗,权略,西洋景,圈套,哄骗,权诈,奸计,诈欺,智术,花枪,权谋",
"trickiness":"n:复杂,繁难,欺骗,诡计多端",
"trickle":"v:滴,淌,泖;n:滴",
"trickling":"v:泫然",
"trickster":"n:骗子,魔术师",
"tricky":"a:微妙,狡猾,权诈,刁钻,鬼,诡,狡滑,鬼祟;v:绕脖子",
"tricolor":"n:三原色",
"tricycle":"n:三轮车",
"trident":"n:制海权",
"trier":"n:审问者,法官",
"trifle":"n:小事,琐事,鸡毛蒜皮;v:小看,游手好闲",
"trifle away":"v:浪费",
"trifles":"n:鸡毛蒜皮,牛溲马勃,琐事,薄物细故",
"trifling":"a:区区,轻微,琐碎,琐细,细,微末,委琐",
"trifoliate orange":"n:枸橘,枳",
"trig":"v:修饰,打扮,制止,滚动",
"trigger":"n:扳机;v:启动,激起",
"triggering":"v:启动",
"trigonometry":"n:三角学,三角",
"trike":"n:三轮车",
"trilateral":"a:三边形,三角形",
"trill":"v:嘟噜;n:颤音",
"trillion":"n:大量",
"trilobite":"n:三叶虫",
"trilogy":"n:三部曲",
"trim":"v:修剪;n:小五金,整齐,装饰,调整,预备,整顿,状态;a:齐整",
"trimester":"n:学期",
"trimming":"n:装饰;v:调整",
"trimness":"n:整齐",
"trinitrotoluene":"n:黄色炸药",
"trinity":"n:三位一体",
"trinket":"n:琐事",
"trip":"v:卷起,栽,弄错,摔交,跳闸,打击,旅行,释放,摔跟头;n:失足,说错,跳闸;a:短程",
"trip up":"v:摔交,摔跟头",
"tripe":"n:废话,肚,内脏,渣滓,肚子",
"triple jump":"n:三级跳远",
"triplet":"n:三通",
"tripod":"n:三脚架,三角架",
"tripoli":"n:硅藻土",
"tripping":"v:释放,解扣",
"trite":"a:陈腐,滥",
"triteness":"n:陈腐,平凡;a:陈腐",
"tritium":"n:氚,超重氢",
"triton":"n:法螺",
"triumph":"v:奏凯,得胜;n:功绩",
"triumphal":"a:胜利,凯旋",
"triumphal arch":"n:凯旋门",
"triumphant":"a:胜利,成功,凯,扬扬得意",
"triumphantly":"d:胜利",
"trivet":"n:三脚架",
"trivia":"n:琐事,薄物细故",
"trivial":"a:琐碎,琐细,平常,稀松,淡,区区,琐,稗,细小",
"trivialities":"n:鸡毛蒜皮,薄物细故",
"triviality":"n:琐事,小事,鸡毛蒜皮,薄物细故,琐碎",
"trivialize":"v:轻视",
"trochlear nerve":"n:滑车神经",
"trod":"v:车辙,足迹;n:车辙,足迹",
"troglodyte":"n:老顽固,类人猿",
"trojan":"n:勇士",
"trojan horse":"n:特洛伊木马",
"troll":"v:传递,轮唱,旋转;n:轮唱,反复",
"trolley":"n:电车,无轨电车,缆车,手推车;v:搭乘",
"trolleybus":"n:无轨电车,电车",
"trollop":"n:荡妇,妓女",
"trombone":"n:长号",
"troop":"n:部队,军队;v:集合,编成",
"trooper":"n:骑兵,战马,伞兵,骑警,痛骂",
"troops":"n:兵力,部,兵员,军队,人马,队伍,旅,兵,部队,军,师",
"trope":"n:转义,比喻",
"trophy":"n:奖杯,奖品,锦标,标,纪念品;v:标",
"tropic":"n:回归线;a:夏至线",
"tropic of cancer":"n:北回归线,夏至线",
"tropic of capricorn":"n:冬至线,南回归线",
"tropical":"a:热带,炎热",
"tropical year":"n:太阳年",
"tropics":"n:热带",
"troposphere":"n:对流层",
"trot":"n:快步,小跑;v:疾走,跳舞;d:快步,骤",
"troth":"n:真实,誓言,约定,忠诚,婚约",
"trouble":"v:麻烦;n:周折,不适,岔子,纷扰,断层,难处,风潮,干扰,老大难,娄子;a:烦,操神,颠连",
"troubled":"a:苦恼,乱糟糟,烦",
"troublemaker":"n:肇事者",
"troublesome":"a:麻烦,难,讨厌,伤脑筋,棘手,繁难,别扭,累人,缠手,罗嗦,辣手;v:伤脑筋,讨厌",
"troubling":"a:烦人",
"trough":"n:槽,水槽,波谷,凹槽,谷",
"trounce":"v:打败,痛打,痛骂",
"troupe":"n:剧团,戏班子,戏班,歌剧团",
"trouper":"n:团员,演员",
"trouser":"n:裤子",
"trouser leg":"n:裤管",
"trousering":"n:裤料",
"trousers":"n:长裤,裤子,下身,裤",
"trousseau":"n:嫁妆,妆,妆奁",
"trout":"n:鳟鱼,鲑鱼,鳟",
"trowel":"n:抹子",
"troy weight":"n:金衡",
"truancy":"n:逃学,玩忽职守,缺课,旷课",
"truant":"v:玩忽职守,逃学,偷懒",
"truce":"n:停战,休战,暂时,中止;v:休战,停战",
"truck":"n:卡车,货车,交易,垃圾;v:交易",
"trucker":"n:小贩",
"truckle":"n:滑车,滑轮",
"truculence":"n:凶猛,好战,残暴",
"truculent":"a:凶猛,气势汹汹,汹汹,好战",
"truculently":"d:气势汹汹",
"trudge":"v:跋涉",
"true":"a:的,真,真正,真实,确实,正确,忠实;v:整形,校准,信,修整;d:固然,真实,确;n:真格的,真实",
"true to":"p:一致,与_一致,忠于",
"true to life":"p:有血有肉,栩栩如生",
"true-blue":"a:忠实",
"truelove":"n:情人,意中人",
"truing":"v:修整",
"truism":"n:陈词滥调",
"truly":"d:真正,真,确实,确,未免,正经,恂,谌,硬是,真个",
"trump":"v:向壁虚造,胜过;n:好人",
"trump up":"v:捏造,伪造,向壁虚造",
"trumpery":"n:废料,废物,胡话",
"trumpet":"n:喇叭,小号;v:自吹自擂,鼓吹,鸣号",
"trumpeter":"n:号兵,号手,吹鼓手,司号员",
"truncate":"v:截断,修剪,舍去",
"truncated cone":"n:圆锥台",
"truncation":"n:截断,切断;v:截断",
"truncheon":"n:警棍,遗物",
"trundle":"v:推,滚,滚动;n:滚动",
"trunk":"n:树干,箱子,衣箱,箱,身躯,干线,干,躯干,总线,车箱,枚,本体,槽,胴,中继,主干,篢,笼子,总管,长途电话,母线,株,主流",
"trunk line":"n:中继线",
"trunk road":"n:干线,干道,大路",
"trunks":"n:游泳裤,短裤",
"truss":"n:桁架,构架,束,钢梁,花束,把,捆;v:捆绑",
"trussing":"v:梁",
"trust":"v:相信,信任;n:鲟鱼,确信;a:信托",
"trust territory":"v:托管地",
"trustee":"n:理事,保管人,董事;v:扣押",
"trusteeship":"v:托管;n:托管",
"trustful":"a:深信不疑",
"trusting":"a:深信不疑",
"trustworthiness":"n:信用,可靠,确实,信任",
"trustworthy":"a:可靠,把稳,妥靠,确实,信实,靠得住",
"truth":"n:真相,事实,真理,实话,真实性,真话,实情,真实,道理,真情,诚实,公理,理,谜底,理路",
"truthful":"a:诚实,真实,忠诚,忠实",
"truthfully":"d:如实",
"truthfulness":"n:真实性",
"try":"v:试图,试,设法,努力,企图;n:试验",
"try on":"v:试试看,试穿,假装",
"try out":"v:考验,试验,甄别",
"try square":"n:曲尺",
"try-on":"v:尝试,诈骗,试穿,试验;n:试用,试穿",
"tryout":"n:试验,试用",
"tryst":"v:幽会,定,相会,赴约,约会;n:约会,幽会",
"tsar":"n:沙皇",
"tsetse":"n:舌蝇",
"tsunami":"n:海啸,海震",
"tub":"n:浴盆,盆,澡盆,桶,矿车;v:盆浴",
"tuba":"n:大号,喇叭",
"tubal":"a:管,输卵管",
"tube":"n:管,管子,电子管,电视,内胎,灯,管乐器,地下铁道,软管,筒,通道,真空管,筒子",
"tuber":"n:块茎,根茎,结节",
"tubercle":"n:根瘤,结节,结核",
"tubercle bacillus":"n:结核杆菌",
"tubercular":"a:结核病",
"tuberculin":"n:结核菌素,结素",
"tuberculosis":"n:结核病,肺结核,结核,肺痨,痨,痨病",
"tuberculous":"a:结核病",
"tuberose":"n:晚香玉",
"tubing":"n:管道,管材",
"tubular":"a:管状,管;n:管式",
"tuck":"v:卷起,塞入,抿,畅饮,击鼓,缩短,喝,搂;n:糕点,活力,精力,酒席",
"tuck away":"v:畅饮",
"tuck in":"v:掖,塞入",
"tucker":"v:装填,填充;n:衣领",
"tuesday":"n:周二,礼拜二",
"tuft":"n:束,丛,树林,簇,撮;v:丛生",
"tug":"n:拉,拖船,拖轮;v:挣扎,尽力,揪,拖曳",
"tug-of-war":"n:拔河,激战",
"tugboat":"n:拖驳,拖船,拖轮",
"tuition":"n:学费,教诲",
"tuition fee":"n:学杂费",
"tulip":"n:郁金香",
"tulle":"n:绢,面纱",
"tum":"n:鼓声",
"tumble":"v:摔倒,摔,倒塌,了解,猛跌,恍然大悟,打滚,跌,跌倒,搅乱,倾覆,乱七八糟,栽,打中,摔跟头,栽跟头,倒头,降落,垮,转体,翻筋斗,领会,翻滚;n:混乱,摔交,跌倒,翻滚",
"tumble-down":"a:东倒西歪",
"tumbledown":"a:拖",
"tumbler":"n:不倒翁,扳不倒儿",
"tumbling":"n:翻筋斗,摔交;v:东倒西歪",
"tumescence":"n:肿大,肿胀",
"tumid":"a:肿大",
"tumidity":"n:夸张,肿大,肿胀",
"tummy":"n:肚子,腹部",
"tumor":"n:肿瘤,瘤,赘疣,瘤子,癌,疙瘩,肿块",
"tumour":"n:癌,瘤,疙瘩,赘疣",
"tumult":"n:激动,骚动,喧哗,喧嚣,烦乱,喧扰,吵闹,扰攘",
"tumultuous":"v:扰攘,喧扰,喧哗;a:乱哄哄,喧哗,汹汹",
"tumulus":"n:坟墓",
"tuna":"n:金枪鱼,鲔",
"tunable":"a:和谐",
"tunas":"n:金枪鱼",
"tundra":"n:苔原",
"tune":"n:曲子,曲调;v:调节,调头,定调子",
"tune up":"v:调整",
"tune-up":"n:调节,调谐",
"tuneful":"a:和谐",
"tuneup":"n:调整",
"tungsten":"n:钨",
"tungsten steel":"n:钨钢",
"tunic":"n:紧身,种皮,层,膜",
"tuning":"n:收听,调谐;v:调谐;a:音",
"tunisia":"n:突尼斯",
"tunnel":"n:隧道,地道,坑道;v:掘进",
"tunnel vision":"n:目光短浅,一孔之见",
"tunneling":"v:隧道",
"tunnelling":"v:隧道",
"tunny":"n:金枪鱼",
"turban":"n:头巾,包头,螺旋",
"turbid":"a:浑,混浊,瓤;v:混",
"turbidity":"n:浑浊,浊,浓密,混乱",
"turbine":"n:涡轮,涡轮机,汽轮机,轮机,透平机,透平",
"turbo":"n:透平机,涡轮机",
"turbocharge":"v:加快,增强",
"turbulence":"n:湍流,涡流,动荡,骚动,骚乱,狂暴,汹,动乱,扰动",
"turbulent":"a:动荡不安,汹涌,汹涌澎湃,骚乱;v:汹涌澎湃,动荡不安,扰动",
"turbulent flow":"n:湍流,溜",
"turbulently":"d:横",
"tureen":"n:汤碗,蒸",
"turf":"n:草皮,草地,地盘,草煤,菌丝,草炭",
"turfy":"a:草皮",
"turgidity":"n:膨胀,夸张,肿胀,肿大",
"turk":"n:顽童,突厥,淘气鬼",
"turkey":"n:火鸡,土耳其,吐绶鸡",
"turkish":"a:土耳其",
"turmeric":"n:姜黄,郁金,姜",
"turmoil":"n:混乱,动乱,乱,骚动,纷扰,喧嚷,丧乱,变乱",
"turn":"v:转,变成,变,翻,转身,转向,转动,打开,拐,发,出,转弯,别,生产,关掉;n:变动,说法,演员,样子,转折点,车床,轮班,次序,口吻,弯曲,形状,意外,性情,遭,转体,关键,回音,转角,散步,弯子,行为",
"turn around":"v:滴溜,扭头,翻,回首,转身,调头",
"turn away":"v:辞退,背",
"turn back":"v:扭转,折返,倒转,回来,折,折回",
"turn down":"v:枪毙,顶",
"turn in":"v:交,上缴",
"turn off":"v:岔,断开,关,避开,关掉,灭",
"turn on":"v:打开",
"turn one's stomach":"v:令人作呕",
"turn out":"v:原来,变成,出产,切断,出,出动,证明,到场",
"turn over":"v:滚动,交代,移交,翻,翻车,折,复,颠,翻耕,翻滚,反,交付",
"turn tail":"v:逃跑,临阵脱逃",
"turn the tables":"v:扳回",
"turn the tide":"v:反败为胜",
"turn to":"v:变成",
"turn up":"v:发生,照面儿,到场,骚动",
"turn-on":"n:开关",
"turnabout":"n:旋转,变节,实例;v:变节",
"turnaround":"n:转变,来回",
"turnbuckle":"n:螺丝扣",
"turncoat":"n:叛徒",
"turner":"n:车工",
"turning":"n:弯,翻转,拐角,转向,弯曲,旋转,转动;v:拐弯",
"turnip":"n:萝卜,荛,菁,葑,芜菁",
"turnkey":"n:看守,狱卒",
"turnoff":"n:岔道,产品,支路,避开,岔,岔口;v:分岔",
"turnout":"n:到会者,道岔,服装,外貌,生产,马车,罢工,分岔,岔道,起床,装备;v:分岔",
"turnover":"n:周转,营业额,翻转,进出,转让,回,成交,翻车;v:更新,进出,翻车",
"turnover rate":"n:周转率",
"turnstile":"n:转台,转盘",
"turntable":"n:转盘,转台",
"turpentine":"n:松节油,松脂",
"turpitude":"n:堕落,卑劣,卑鄙",
"turps":"n:松节油",
"turquoise":"n:绿宝石,天蓝色",
"turret":"n:塔楼,炮塔,角楼",
"turret clock":"n:塔钟",
"turtle":"n:海龟,龟,甲鱼",
"turtledove":"n:鸠,雉鸠,情人,斑鸠",
"tusk":"n:象牙,齿,尖头,獠牙",
"tussle":"v:扭打;n:搏斗",
"tussock":"n:簇,草丛,丛",
"tussock moth":"n:毒蛾",
"tut":"i:哼,嘘",
"tutelage":"n:教育,教,教导,监护,指导;v:监护",
"tutor":"v:辅导;n:师傅",
"tutorial":"n:指南",
"tutti":"n:合奏",
"tv":"n:电视",
"tv set":"n:电视机",
"tv station":"n:电视台",
"twaddle":"n:闲聊,废话;v:聊天",
"twain":"n:双,二,两",
"twang":"n:鼻音,迹象,痛苦,遗迹,痕迹,土音",
"tweak":"v:拧,扭,捏;n:妙计",
"tweaking":"v:拧,扭",
"tweed":"n:花呢",
"tweezers":"n:镊子,镊",
"twenty":"a:廿;n:许多",
"twice":"d:两次,兼",
"twiddle":"n:波纹,捻;v:玩弄",
"twig":"n:树枝;v:发现,看出,懂得,了解,注意",
"twilight":"n:黄昏,暮色,黎明,薄暮,曙光,微光,模糊",
"twill":"n:斜纹",
"twin":"n:对,孪生子,双;a:孪生,双胞胎,双生;v:成对",
"twine":"n:盘缠,纠缠;v:缠",
"twiner":"n:蔓草",
"twinge":"n:内疚,阵痛,剧痛,痛心;v:刺痛",
"twinkle":"n:眨眼,闪光,一刹那,瞬间,闪耀;v:闪烁,眨眼,眨,闪亮,忽闪",
"twinkling":"n:眨眼,瞬间,瞬,转瞬间,转眼间;d:瞬间",
"twinning":"v:成对,双生,孪生;a:双生,孪生",
"twins":"n:双胞胎",
"twirl":"v:旋转,捻,转动,投球,扔;n:回旋,旋转",
"twist":"v:歪曲,扭,缠绕,拧,搓;n:胃口,别扭,姑娘,动量矩,妇人,扭摆舞,盘缠,怪癖,牵强,曲,角动量,食欲",
"twisted":"a:扭曲",
"twister":"n:捻线机,沙柱,谎话,旋风",
"twisting":"v:扭转,捻线;a:曲曲弯弯",
"twisty":"a:扭曲",
"twit":"v:嘲笑,挖苦,责备;n:笨蛋",
"twitch":"v:抽搐,抽动,跳;n:抽筋,痉挛",
"twitter":"v:叽叽喳喳,啼,呢喃,颤抖,打颤,抖动;n:兴奋",
"twittering":"v:呢喃;n:呢喃",
"twixt":"p:之间,在_之间",
"two":"a:两,二;n:俩",
"two-dimensional":"a:二维",
"two-ply":"a:双重",
"two-seater":"n:双座",
"two-time":"v:出卖,欺骗,背叛",
"two-timer":"n:叛徒",
"two-way":"a:双向",
"twofer":"n:便宜货",
"twofold":"a:双重,双",
"twopenny":"a:廉价;n:少量",
"tycoon":"n:巨头,财阀,大将军,巨贾",
"tying":"v:捆扎;n:结子",
"tyke":"n:小孩子,小孩",
"tympani":"n:定音鼓",
"tympanic cavity":"n:鼓室",
"tympanist":"n:鼓手",
"tympanum":"n:耳膜,鸣,鼓,鼓室,鼓膜,中耳",
"type":"n:类型,种,类;v:付排,象征,代表,鉴定",
"type metal":"n:铅字合金",
"typecast":"v:浇铸",
"typed":"a:打字",
"typeface":"n:字面,版面,字体",
"typeset":"v:排版,排字,排印",
"typesetting":"v:排版,排字;a:排版",
"typewrite":"v:打字,打印",
"typewriter":"n:打字机",
"typewriting":"v:打字;n:打字",
"typhoid":"n:伤寒",
"typhoid fever":"n:伤寒",
"typhoon":"n:台风,飓风",
"typhus":"n:伤寒",
"typical":"a:典型,象征,道地,地道;n:代表性",
"typicality":"n:典型性",
"typify":"v:代表,概,象征,预示",
"typing":"v:打字",
"typist":"n:打字员",
"typographic":"a:活版",
"typography":"n:印刷,活版,排印,印刷品,印刷术",
"typology":"n:预兆,类型学",
"tyrannic":"a:专横,暴君",
"tyrannical":"a:暴虐,强横,横逆,耆,残暴,豪强,虐,霸,戾",
"tyrannize":"v:压制,虐待,强横霸道,横行霸道",
"tyrannosaur":"n:恐龙",
"tyrannous":"a:暴虐,暴政",
"tyranny":"n:暴政,专制,暴虐,苛政,专横,残暴,暴,虐政",
"tyrant":"n:暴君,土豪,霸主;a:横蛮",
"tyre":"n:外胎,轮带,胎;v:外带",
"tyro":"n:新手,初学者,生手",
"u-boat":"n:潜水艇",
"ubiquitous":"a:无所不在,无;v:无所不在",
"ubiquity":"n:无所不在",
"udder":"n:乳房,乳腺",
"ufo":"n:飞碟",
"uganda":"n:乌干达",
"ugh":"i:啊,呸",
"uglification":"n:丑化",
"ugliness":"n:丑陋,难看,丑相",
"ugly":"a:难看,丑,丑陋,丑恶,寒碜",
"uh":"d:哦",
"uhf":"n:超高频,特高频",
"uk":"n:联合王国",
"ukase":"n:圣旨",
"ukraine":"n:乌克兰",
"ulan bator":"n:乌兰巴托",
"ulcer":"n:溃疡,疠,痈疽",
"ulcerate":"v:败坏,溃烂,溃",
"ulceration":"n:溃疡,溃烂,糜烂,腐败",
"ulcerous":"a:溃疡",
"ulna":"n:尺骨,正骨",
"ulnar":"a:尺骨",
"ulnar artery":"n:尺动脉",
"ulster":"n:北爱尔兰",
"ulterior":"a:不可告人",
"ultimate":"n:最后,顶点,终极;a:最终,终极",
"ultimately":"d:最后,郅",
"ultimatum":"n:最后通牒",
"ultra":"a:极端,过激",
"ultrahigh frequency":"n:特高频",
"ultramodern":"a:极",
"ultrasonic":"a:超音速;n:超声波",
"ultrasound":"n:超声波",
"ultraviolet light":"n:紫外光",
"ululate":"v:吼,大叫,悲泣,嚎",
"ulysses":"n:智勇双全",
"umbilical":"a:脐",
"umbilicus":"n:脐,核心",
"umbra":"n:本影,阴影,中,暗影",
"umbrage":"n:生气,树荫,愤怒,不快,怀疑,阴影,悔恨,遗憾,树阴",
"umbrella":"n:伞,雨伞,晴雨伞,保护伞;v:掩护",
"ump":"n:裁判员",
"umpire":"v:裁判,仲裁,裁定,公断,裁决;n:裁判,裁判员",
"umpteen":"a:多数",
"un":"n:家伙,东西,人",
"unabashed":"a:泰然,没羞",
"unabashedly":"d:老着脸皮",
"unable":"a:不,无法,无力,力所不及;d:无法;v:无力",
"unable to help":"a:干瞪眼",
"unabridged":"a:完整",
"unaccommodating":"a:板板六十四",
"unaccomplished":"a:无成",
"unaccountability":"n:莫名其妙",
"unacquainted":"a:生",
"unadorned":"a:质,赤裸裸,朴实",
"unadulterated":"a:纯正,纯粹",
"unaffected":"a:大方,质朴,烂漫,真率",
"unafraid":"a:无畏;v:无畏",
"unaided":"a:独立,无助",
"unaligned":"a:不结盟",
"unalterable":"a:铁,划一不二,一成不变;v:一成不变,划一不二;n:铁",
"unaltered":"a:照旧",
"unambiguous":"a:明确,不含糊",
"unanimity":"n:一致",
"unanimous":"v:众口一词;a:一致",
"unanimously":"d:众口一词,交口",
"unanswerable":"a:无",
"unapproachable":"a:不",
"unarmed":"v:赤手空拳,手无寸铁",
"unassailable":"a:无懈可击",
"unassisted":"a:独立,无助",
"unassuming":"a:平易,谦逊",
"unattainable":"a:高不可攀,可望而不可即;v:高不可攀",
"unavailability":"n:无效",
"unavailable":"a:无效",
"unavailing":"a:无用,无益",
"unavoidable":"a:免不了,不免",
"unavoidably":"d:不免,免不得",
"unaware":"a:懵,不意",
"unawareness":"n:无意识,不意",
"unawares":"d:不知不觉,冷不防,不料,忽然,猛不防,突然",
"unbalance":"v:失衡,失调;n:失衡",
"unbalanced":"v:畸轻畸重,畸形;a:畸轻畸重;n:畸形",
"unbearable":"a:不堪,难堪,够戗",
"unbearably":"d:慌,够戗",
"unbeatable":"a:无敌",
"unbecoming":"v:不成体统;a:不成体统",
"unbeknown":"a:未知",
"unbelief":"n:怀疑",
"unbelievable":"a:荒诞不经,荒诞",
"unbeliever":"n:异教徒",
"unbend":"v:伸直,放松,卸下,松弛,宽解,宽舒,解开",
"unbending":"a:挺,不屈,倔强",
"unbent":"a:直",
"unbiased":"a:不偏不倚,持平;v:持平",
"unbidden":"a:自愿",
"unbind":"v:释放,解放,解开,松开",
"unblemished":"a:清白",
"unblocked":"a:畅通,畅通无阻",
"unblushing":"a:没羞,厚颜",
"unbolt":"v:打开,拉开",
"unborn":"a:有待",
"unbosom":"v:吐露",
"unbounded":"a:无边无际",
"unbreakable":"n:钢铁;a:牢靠",
"unbridled":"a:放肆,疯狂,狂妄,肆,恣睢,恣意,嚣张;v:肆无忌惮",
"unbroken":"a:连绵,绵绵,联绵,绵联",
"unbuckle":"v:解开",
"unburden":"v:卸",
"uncalled":"a:未经",
"uncanny":"a:不可捉摸,怪模怪样;v:不可捉摸",
"uncap":"v:打开,脱,透露",
"unceasing":"v:不已;a:不断",
"unceasingly":"d:不已,不断",
"unceremonious":"a:随便",
"uncertain":"a:不定,渺茫,含糊其词;v:未定,未知,飘忽,含糊其词;n:未知数",
"uncertainly":"d:不定,备不住",
"uncertainty":"n:半信半疑,含糊,无常,易变",
"unchain":"v:释放,解放",
"unchained":"a:解放",
"unchangeable":"v:一成不变;a:一成不变",
"uncharged":"a:未",
"uncharitable":"a:苛刻,严厉",
"unchaste":"a:淫荡",
"uncivil":"a:野蛮",
"uncivilized":"a:蛮荒,野蛮,蒙昧",
"unclad":"a:赤裸裸",
"unclasp":"v:放松,放开,解开,松开",
"uncle":"n:叔叔,叔父,伯伯,伯父,舅舅,大,姨父,姨夫,舅父,姑父,郎舅,老大爷,大伯,大爷,舅,伯,姨丈,表叔,大舅子,老伯,叔,娘舅,叔公,表舅,伯公,大叔",
"unclean":"a:不干不净,拖泥带水,肮脏,淫猥;v:拖泥带水",
"unclear":"a:不明,暗",
"unclench":"v:松开",
"uncloak":"v:脱去,暴露,揭开",
"unclothe":"v:揭露,暴露",
"unclouded":"a:明晰,晴朗",
"uncoil":"v:解开,展开",
"uncombed":"a:蓬乱",
"uncomfortable":"a:不安,别扭",
"uncommitted":"a:未遂",
"uncommon":"a:罕见,异乎寻常,非凡,稀有,希,稀,生僻,不凡,冷,奇",
"uncommonly":"d:极其,异乎寻常,难得,非常,不含糊;a:不含糊",
"uncommunicative":"a:沉默寡言,沉默,拘礼;v:沉默寡言",
"uncompleted":"a:有头无尾",
"uncomplicated":"a:简单,简简单单",
"uncompromising":"a:绝",
"unconcern":"n:不在乎,漫不经心,漠不关心,冷淡",
"unconcerned":"a:冷漠,麻木不仁,漠漠,无动于衷,恝,漠,漠不关心;v:无动于衷",
"unconditional":"a:无条件;d:无条件",
"unconditioned":"a:无条件",
"uncongenial":"a:忤",
"unconquerable":"a:无敌",
"unconscionable":"a:没良心;v:没良心",
"unconscious":"a:不省人事,不知不觉;n:蒙,无意识",
"unconsciously":"d:不知不觉,无意识,不觉",
"unconsciousness":"n:无意识",
"unconsolidated":"a:松散",
"unconstitutionality":"n:违宪",
"unconstitutionally":"d:松散",
"unconstrained":"v:落泊,无拘无束;a:落托",
"uncontrollable":"a:失控",
"unconventional":"a:放荡,通脱,俶,倜,落拓,别致,俶傥,倜傥,超脱",
"unconvincing":"a:勉强",
"uncooked":"a:生",
"uncork":"v:吐露,开口",
"uncountable":"a:不可数,不可胜数;v:不可胜数",
"uncounted":"a:无数",
"uncouple":"v:脱开,甩车,拆散,分开",
"uncoupling":"v:拆开",
"uncouth":"a:粗野,笨拙,土,古怪,土气,土里土气",
"uncover":"v:揭开,揭露,破获,揭,脱,揭破,清查,败露",
"uncovered":"a:裸露",
"unction":"n:连接,热心,同情,热情,感动,甜言蜜语,油膏,假意,兴趣",
"unctuous":"a:油滑;v:油腔滑调",
"unctuously":"d:假惺惺",
"uncultivated":"a:野生,野,野蛮",
"uncultured":"a:蒙昧,目不识丁,俚俗",
"uncurl":"v:伸直,展开",
"undamaged":"a:完好无缺,无缺;v:完好无缺",
"undaunted":"a:无畏,明目张胆",
"undecided":"a:悬而未决,三心二意;v:未定,悬而未决",
"undemonstrative":"a:不动声色",
"undeniable":"v:无可讳言,无可争辩;a:无可讳言",
"undependable":"a:靠不住",
"under":"p:根据,底下,下面,按照,之下,低于;d:下面,属,低于;n:下方,以下,底下,手下,下头,之下,下面,下;v:属;a:下面",
"under cover of":"p:掩护下,在_掩护下",
"under pain of":"p:代价,以_为代价",
"under penalty of":"p:代价,以_为代价",
"under the cover of":"p:趁着,以_为幌子,幌子",
"under way":"a:进行,前进",
"under-the-table":"a:秘密",
"underage":"n:短少,不足",
"underarm":"a:腋下",
"underbelly":"n:小腹,小肚子",
"undercarriage":"n:起落架,支架,底盘",
"underclothes":"n:内衣裤,内衣,衬衣,汗衫",
"underclothing":"n:衬衣",
"undercoat":"n:衬裙",
"undercurrent":"n:暗流,潜流,暗潮",
"undercut":"v:挖,下陷;n:里脊肉,下陷,下旋球",
"underdone":"a:嫩",
"underestimate":"v:低估,看轻",
"underestimation":"n:轻视,低估",
"underfoot":"d:脚下,践踏,贱视,碍手碍脚",
"undergarment":"n:内衣,衬衣",
"undergo":"v:经历,遭受,忍受,经受,历,经验;p:经",
"undergraduate":"n:大学生,本科生,本科",
"underground":"n:地下,地铁,地道;a:暗",
"undergrowth":"n:灌木",
"underhand":"a:秘密",
"underline":"v:强调,加强",
"underling":"n:喽罗,下手,党羽,下属",
"underlings":"n:党羽,爪牙",
"underlining":"n:衬里,里子",
"underlip":"n:下唇",
"underlying":"v:优先;a:在下",
"undermine":"v:破坏,败坏,拆墙脚,搞垮,拆台,戕贼",
"underneath":"n:下头,下面,下方,下;p:之下,在_之下;d:底下;a:弦外之音",
"underpants":"n:小衣,衬裤,裤衩",
"underpart":"n:腹部,下体",
"underpass":"n:地道",
"underpin":"v:支援,加固,加强,支持",
"underpinning":"n:内衣,支撑",
"underpinnings":"n:基础",
"underrate":"v:低估,看轻,轻视,贬低",
"underscore":"v:配乐,强调",
"undersecretary":"n:次长",
"undersell":"v:抛售",
"undershirt":"n:汗衫,汗褂儿,紧身儿,汗褂",
"undershirts":"n:裤衩",
"undershoot":"v:脱靶;n:实例",
"undershorts":"n:裤衩",
"underside":"n:下面,小腹",
"undersized":"a:矮小",
"underskirt":"n:衬裙",
"understand":"v:理解,了,了解,明白,懂,会,懂得,知道,清楚,听说,认识,谅解,领会,获悉,通晓,晓得,熟悉,推测,解,会意,以为,领悟,通达,悟,喻,领,识,知晓,理会,了然,明,通,照,谅",
"understandable":"a:情有可原;v:情有可原",
"understandably":"d:难怪",
"understanding":"n:了解,理解,谅解,理解力,默契,认识,协议,智力,同情,觉悟,悟性,脚;v:会意,体会,心领;a:知心;d:会心",
"understatement":"n:掩饰",
"understudy":"n:演,预备;v:实习",
"undertake":"v:承担,负责,答应,担保,就,进行,保证,着手,从事,承办,担当,担负,断言,应承,约定,允诺,肩,担,担待;n:肩",
"undertaking":"n:事业,企业,任务,企图,应承,担保,工作,约定,保证,计划,承诺,承包,承办",
"underthings":"n:内衣裤",
"undertone":"n:小声,浅色;d:小声",
"undervaluation":"n:低估,轻视",
"undervalue":"v:低估,轻视,看轻",
"underwater":"a:水下,潜泳,水底",
"underwear":"n:内衣,衬衣,小衣裳",
"underworld":"n:地狱,下界,阴间,地球",
"underwrite":"v:赞同,认购,署名,认捐",
"underwriting":"v:保险业,认捐",
"undesirability":"n:讨厌",
"undesirable":"a:不良;v:使不得",
"undetermined":"a:未定",
"undeveloped":"a:不成",
"undies":"n:内衣,衬衫",
"undiminished":"a:不减",
"undisciplined":"a:潦倒,散漫;v:放纵",
"undiscovered":"a:隐藏",
"undisguised":"a:赤裸裸,露骨",
"undisguisedly":"d:公然",
"undismayed":"v:镇定自若",
"undisputed":"a:毫无疑问,无可争辩;d:毫无疑问",
"undistinguished":"a:平凡,庸庸碌碌",
"undisturbed":"a:平静",
"undivided":"a:专一",
"undo":"v:解开,打开,消除,毁灭,脱去,糟蹋,放松,勾引,解,取消,说明,诱奸,败坏,破坏,解释,废除",
"undoing":"n:祸根,取消,毁灭,破落,复旧,解开",
"undomesticated":"a:野",
"undoubted":"v:无可置疑;a:无可置疑",
"undoubtedly":"d:无疑,毫无疑问,肯定,明明,必定,决然",
"undress":"v:暴露;n:便服",
"undressed":"a:便服,裸体",
"undue":"a:过分,过,过度,逾分",
"undulant":"a:起伏",
"undulate":"v:起伏,荡漾,波动",
"undulation":"n:振动,心跳,波动,搏动",
"unduly":"d:过,过于,过度",
"undying":"a:不朽",
"unearned":"a:不劳而获",
"unearth":"v:发现,揭发,破获,揭露,挖掘,发掘",
"unease":"n:不安",
"uneasy":"a:不安,担心,心神不安,仄,忡",
"uneconomic":"a:浪费",
"uneducated person":"n:老粗儿",
"unemployed":"a:无业",
"unemployment":"n:失业",
"unemployment rate":"n:失业率",
"unending":"a:不停",
"unendurable":"a:不堪,不可;d:不堪",
"unenlightened":"a:闭塞,蒙昧,愚蒙,土",
"unequal":"a:不同,不等;v:不等",
"unequaled":"a:无敌",
"unequalled":"a:无出其右,绝伦",
"unequivocal":"a:明确,明白,不含糊",
"uneven":"a:不平,参差不齐,崎岖,参差,七扭八歪,凹凸不平,盘陀,陂陀",
"uneven bars":"n:高低杠",
"unexampled":"a:空前",
"unexceptionable":"a:无懈可击",
"unexceptionally":"d:毫无例外",
"unexpected":"a:意外,突然,出乎意料,飞,突兀,横,不虞,想不到;v:突兀,想不到,飞",
"unexpectedly":"d:出乎意料,突然,不意,忽然,陡然,猝然,骤然,不图,竟然,猛不防,居然,不料,不谓,竟,竟是,蓦地;v:不谓",
"unexploded":"v:哑",
"unfailing":"a:经久不衰,无穷无尽;v:无穷无尽",
"unfair":"a:不公",
"unfairness":"a:不平;n:不平",
"unfaithful":"a:二心,贰心;n:二心",
"unfaithfulness":"n:贰心",
"unfaltering":"a:稳定",
"unfamiliar":"a:陌生,新奇,冷僻,眼生,生",
"unfamiliar with":"a:隔膜",
"unfashionable":"a:土",
"unfasten":"v:解开,松开,放开,放松",
"unfathomable":"a:深不可测,莫测高深;v:高深莫测",
"unfavorable":"a:不利",
"unfeeling":"a:冷酷,麻木不仁,心硬",
"unfeelingly":"d:眼睁睁",
"unfetter":"v:释放",
"unfettered":"v:无拘无束",
"unfilled":"a:空",
"unfinished":"v:未了;a:未了",
"unfit":"n:郎当;a:不伦不类;v:郎当",
"unfix":"v:解开,拆,放松",
"unflagging":"a:持续",
"unflappability":"n:镇定",
"unflappable":"a:镇定自若,镇定;v:镇定自若",
"unfledged":"v:乳臭未干,羽毛未丰;a:乳臭未干,羽毛未丰",
"unflinching":"a:坚定,坚定不移,坚韧不拔",
"unflinchingly":"d:坚韧不拔",
"unfold":"v:打开,展开,舒展,开展,呈现,说明,发展,展,铺,显露,铺开,舒,张开",
"unforeseen":"a:意外",
"unforgettable":"a:难忘",
"unfortunate":"a:不幸,倒霉,触霉头",
"unfortunately":"d:不幸,可惜,不巧",
"unfounded":"a:虚妄,飞,谰,无稽;v:飞",
"unfreeze":"v:解冻",
"unfrequented":"a:冷,冷落",
"unfrock":"v:开除,罢黜",
"unfurl":"v:展开,揭示,展,撑,展示,公开,打开",
"ungainly":"a:笨拙,笨重",
"ungenerous":"a:薄,小手小脚",
"ungentlemanly":"a:下流",
"ungetatable":"a:交通",
"ungracious":"a:无礼,粗野",
"ungrateful":"a:忘恩负义,没良心;v:忘恩负义,没良心",
"ungrudging":"a:慷慨,自愿",
"unguarded":"a:一不小心",
"unguent":"n:油,药膏,软膏",
"ungulate":"a:有蹄类;n:有蹄类",
"unhand":"v:放掉",
"unhandy":"a:笨拙,不得劲",
"unhappily":"d:不幸,偏巧,可惜",
"unhappy":"a:不快,不悦,窝憋,恼",
"unhealthy":"a:不良,不对",
"unheard":"a:闻所未闻",
"unheard-of":"a:前所未闻",
"unhelpful":"v:无济于事",
"unhesitating":"a:迅速",
"unhindered":"a:顺畅",
"unhitch":"v:解开",
"unhook":"v:脱钩",
"unhorse":"v:推翻",
"unhurried":"a:缓,逍遥,不慌不忙,悠悠,从容",
"unhurriedly":"d:慢条斯理,慢腾腾,从容不迫,慢悠悠;a:慢慢腾腾,慢悠悠,慢腾腾;v:慢条斯理",
"unicellular":"a:单细胞",
"unicorn":"n:独角兽,麟,麒麟",
"unidirectional":"a:单向",
"unification":"n:统一,联合,标准化,一致,合一",
"unified":"v:统一,一元化;a:统一",
"uniform":"a:均匀;n:军装;v:划一,划一不二;d:一律",
"uniformity":"n:均匀,单调,一致,划一,一样,一律",
"uniformly":"d:一律",
"uniforms":"n:制服",
"unify":"v:统一,一元化,标准化,一体化,合一",
"unilateral":"a:单方面,片面;n:单方",
"unilateralism":"n:单方,片面,单向",
"unimaginable":"a:不可思议",
"unimpaired":"a:健全",
"unimpeachable":"a:无可非议,无;v:无可非议",
"unimpeded":"a:畅,畅通,畅行,无阻",
"unimportant":"a:稀松,不要紧,等闲;v:不足道",
"uninhabited":"a:渺无人烟",
"uninhibited":"a:畅,不羁",
"uninspired":"a:平凡",
"unintelligent":"v:一窍不通;a:一窍不通",
"unintelligible":"a:晦涩,模,费解;v:不知所云",
"unintentionally":"d:不禁;v:无心",
"uninteresting":"a:无味,枯燥,平淡,干燥,枯,无聊",
"uninterrupted":"a:连绵,联绵,不断",
"uninterruptedly":"d:不断",
"union":"n:工会,联邦,结合,联盟,会,联合,一致,合并,团结,愈合,同盟,婚姻,协会,结婚,融洽;v:结合,联合,愈合",
"unionism":"n:工联主义",
"unionize":"v:联合,统一",
"unique":"a:独特,唯一,独一无二,无与伦比,别致,超绝,绝,惟一,独到;v:无与伦比,天下无双",
"uniquely":"d:惟有",
"uniqueness":"n:独一无二",
"unison":"n:一致,齐唱,同音,齐奏;v:同音,齐唱,齐奏",
"unit":"n:单位,单元,装置,部件,部队,组合,元件,元,小组,部,机组,成分,个体,分部,分队,附件,基数,小队",
"unitary":"a:统一,单元,单一",
"unite":"v:团结,一致,联合,结合,统一,合并,团聚,协力,团,合一,接合,结,戮,联,统,混合,粘合",
"united kingdom":"n:联合王国",
"united nations":"n:联合国",
"united states":"n:美国",
"unitedly":"d:一致,协力,联合",
"unity":"n:团结,统一,一,一致,整体,统一性,和睦,统一体,单一,同样,调和,个体,共有,唯一;a:单一",
"univalent":"n:单价;a:单价",
"universal":"a:普遍,万能,宇宙,普及,普",
"universal suffrage":"n:普选权",
"universalism":"n:普遍性",
"universality":"n:普遍性,一般性,共性",
"universally":"d:举世",
"universe":"n:宇宙,世界,银河系,天地,整体,宇,全世界,森罗万象,全人类",
"university":"n:大学,综合大学",
"unjust":"a:不义,不公,不平,暗无天日",
"unjustifiable":"a:曲,无理,小鞋;n:小鞋",
"unkempt":"a:蓬乱,披头散发;v:披头散发",
"unkind":"a:刻薄,薄",
"unkindly":"d:刻薄",
"unknowing":"a:无知,不知不觉",
"unknowingly":"d:不知不觉",
"unknown":"v:不见经传,不明,未详,未知;a:不见经传;n:未知数",
"unlatch":"v:解开",
"unlawful":"a:非法,流里流气,流气,不法",
"unlearn":"v:忘掉",
"unlearned":"n:胸无点墨;v:胸无点墨",
"unleash":"v:发动,放纵",
"unless":"c:除非,除外;v:除外",
"unlettered":"n:胸无点墨;a:胸无点墨",
"unlighted":"a:黑灯瞎火",
"unlike":"p:不同;a:不同",
"unlikely":"a:未必,靠不住",
"unlikeness":"n:不同,差别",
"unlimited":"a:无限,敞开,无边无际",
"unlink":"v:拆散,解开",
"unload":"v:卸货,卸,卸下,卸载,摆脱,排污,倾吐,下,放空,抛售,卸车",
"unloading":"v:放空,排污,卸货",
"unlock":"v:揭露,解开,破译",
"unlocking":"v:解开",
"unlooked-for":"a:意外",
"unloose":"v:释放,解开,放松",
"unluckily":"d:不幸,偏偏,偏巧",
"unluckiness":"n:灾",
"unlucky":"a:不幸,倒霉,不祥,晦气,坎坷,背时,蹇,背",
"unmake":"v:毁灭,破坏,解开,废除,改变,毁坏",
"unman":"v:阉割",
"unmanageable":"a:不可收拾;v:不可收拾",
"unmanly":"a:怯懦",
"unmarketable":"v:滞销;a:滞销",
"unmarried":"n:单身,未婚,独身;a:未婚,独身;v:未婚",
"unmarried man":"n:矜",
"unmask":"v:暴露,拆穿,揭发,揭露",
"unmatched":"a:独一无二,无比,无敌;v:无敌",
"unmeaning":"a:呆板",
"unmentionable":"n:内衣",
"unmerciful":"a:残忍",
"unmerited":"a:不当,不配",
"unmistakably":"d:真",
"unmixed":"a:白,醇,清,清醇,正,纯",
"unmoved":"a:无动于衷;v:无动于衷",
"unnamed":"a:无名",
"unnatural":"a:板,别扭,乖戾,勉强,矫揉造作",
"unnecessarily":"d:无谓,徒然,无须,不消",
"unnecessary":"a:多余,无须",
"unnumbered":"a:不可胜数",
"unobjectionable":"a:无可非议;v:无可非议",
"unobstructed":"a:无阻,通畅",
"unoccupied":"a:虚,空,闲",
"unofficial":"a:非正式,稗,外",
"unorganized":"a:散漫",
"unorthodox":"a:左",
"unpack":"v:打开,分开;n:间距",
"unpacking":"v:分割",
"unpalatable":"a:难吃,无味",
"unparalleled":"a:空前;v:无与伦比,盖世,无可比拟,无双;d:无比",
"unperturbed":"a:宽绰,镇定,恬然,坦然",
"unpick":"v:拆开",
"unpin":"v:拔掉",
"unplanned":"a:计划",
"unpleasant":"a:不合,难",
"unpleasantness":"n:不快,煞风景,倾轧,不和,芥蒂",
"unplumbed":"a:深不可测",
"unpolished":"a:粗野",
"unpopular":"a:不得人心,落落寡合",
"unpopularity":"n:不得人心",
"unpractical":"a:不切实际;v:架空,不切实际",
"unprecedented":"a:空前,前所未有,见所未见,亘古未有;v:前所未有,见所未见",
"unpredictable":"a:不可捉摸,奇,不测;v:不可捉摸;n:不测",
"unprepared":"a:不意",
"unpreparedness":"n:不意",
"unprincipled":"a:无原则;v:无原则",
"unprocessed":"a:生,原",
"unproductive":"a:瘠薄",
"unprofessional":"a:外行",
"unprofitable":"v:无益,无利可图;a:无利可图",
"unpromising":"v:不稂不莠,不堪造就;a:不堪造就,不稂不莠",
"unprompted":"a:自发",
"unprovoked":"a:无端",
"unquestionable":"a:毫无疑问;v:无可置疑",
"unquestionably":"d:决然",
"unquiet":"n:不安,动荡,焦虑;a:动荡",
"unravel":"v:散开,阐明,解开,解决,拆散,绎,点破,拆开",
"unread":"a:目不识丁",
"unreal":"a:虚幻,假;v:子虚乌有;n:虚幻",
"unrealistic":"a:不切实际,疏阔",
"unreality":"n:不切实际,幻想,虚构",
"unreasonable":"a:无理,不像话,戾,赖皮",
"unreasonableness":"n:横逆",
"unreasoning":"a:蛮",
"unrefined":"a:俚俗,粗野,生,粗",
"unrelenting":"a:坚定不移;v:交谈",
"unreliable":"a:靠不住,玄乎,玄",
"unremarkable":"a:平凡",
"unremitting":"a:不懈,坚持不懈,持续,不停;v:始终不懈",
"unrepentant":"a:顽固",
"unreserved":"a:率直,坦率;d:无条件",
"unrest":"n:动乱,不安,动荡,乱,风潮,骚乱;a:乱",
"unrestrained":"a:无拘无束,狂,任性,自在;v:无拘无束,漫;n:浪",
"unrestricted":"v:敞开;a:敞开",
"unrighteous":"a:不义,邪恶",
"unripe":"a:生",
"unrivaled":"a:无比,举世无双,无双,无敌;v:无双",
"unrivalled":"a:举世无双",
"unroll":"v:展开,打开,铺开,解开,披,现出,展",
"unruffled":"a:平静,镇定,安详,镇静",
"unruliness":"n:野性,无法无天,不羁",
"unruly":"a:暴躁,调皮,乱来,猖,野,不羁,狂放,刁蛮;v:乱来",
"unsafe":"a:悬乎",
"unsalable":"v:滞销",
"unsatisfactory":"a:秃",
"unsay":"v:撤回,取消,收回",
"unscathed":"a:安然无恙",
"unscramble":"v:整理,清理,破解",
"unscrupulous":"v:胆大妄为,肆无忌惮,无所顾忌,恬不知耻;a:不择手段,胆大妄为,丧心病狂,恣意",
"unscrupulously":"d:恬不知耻,不择手段,肆无忌惮,无所顾忌,恣意妄为",
"unseal":"v:打开,启封",
"unseeing":"a:茫然",
"unselfish":"a:无私,大公无私;v:大公无私",
"unserviceable":"a:使不得",
"unset":"v:清除;a:清除",
"unsettle":"v:波动,搅乱",
"unsettled":"v:未决,悬而未决;a:易变",
"unshackle":"v:释放",
"unshakable":"n:雷打不动,铁;a:铁,雷打不动",
"unshaken":"a:坚定",
"unshaped":"a:畸形",
"unsheathe":"v:开战,脱去,宣战",
"unsightly":"a:难看,碜,媸,寒碜,丑",
"unskilled":"a:拙劣,嫩",
"unskillful":"a:笨拙",
"unsnap":"v:松",
"unsnarl":"v:解决,松开",
"unsociable":"a:落落寡合",
"unsocial":"a:孤僻",
"unsoiled":"a:洁净,清白",
"unsolder":"v:分离,拆开,分解,分裂",
"unsophisticated":"a:纯真,纯朴,浑,淳朴,简易,土头土脑",
"unsparing":"a:大方",
"unspeakable":"a:莫可名状,说不得;v:说不得",
"unspecific":"a:不详",
"unspecified":"v:不详;a:不详",
"unstable":"a:不安,心浮",
"unsteadily":"d:浮漂",
"unsteady":"a:不定,颤巍巍,摇摆,活动,虚飘飘",
"unstudied":"a:不通",
"unsubstantial":"a:虚幻",
"unsuccessful":"a:失败,不利",
"unsuitable":"a:不适,不便,不当",
"unsullied":"a:清白",
"unsurpassed":"a:绝伦,卓绝,卓跞",
"unswerving":"a:坚定不移;v:始终不渝",
"unswervingly":"d:毫不动摇",
"unsympathetic":"a:无情,麻木不仁",
"unsystematic":"a:紊乱",
"untamed":"n:野性;a:野",
"untangle":"v:解开,清理,解决",
"unthinkable":"a:不,不可思议",
"unthinkingly":"d:不假思索",
"untidy":"a:凌乱,零乱;v:错落,拖泥带水",
"untie":"v:解开,松开,解放,纾,解,解决",
"until":"p:直到_为止;c:到;v:赶",
"untimeliness":"n:不合时宜",
"untiring":"a:不懈;v:始终不懈",
"unto":"p:对,到,直到,按",
"untouched":"v:无动于衷",
"untoward":"a:不幸",
"untrammeled":"a:倜傥,挥斥",
"untrammelled":"a:挥斥",
"untrimmed":"a:参差",
"untrustworthy":"a:靠不住",
"untruth":"n:虚伪,谎话,虚假,虚妄,瞎话",
"untwist":"v:解开,拆开,松开",
"untwisting":"v:解开",
"unused":"a:新,不用,闲散",
"unusual":"a:异常,异乎寻常,特别,反常,奇特,与众不同,非常,各,异样,罕有,特;r:各;v:与众不同;d:特",
"unusually":"d:异乎寻常,出奇,贼;n:贼;a:出奇",
"unvarnished":"a:质朴",
"unveil":"v:揭幕,显露,揭示,揭露",
"unveiled":"v:公开",
"unveiling":"v:揭幕式",
"unwanted":"a:多余",
"unwarranted":"a:莫须有",
"unwary":"a:粗心大意",
"unwelcome":"a:臭,冷;n:冷淡",
"unwelcome person":"v:不速之客",
"unwell":"a:不适,不快,不好过",
"unwieldiness":"n:笨重",
"unwieldy":"a:笨重,大而无当,笨,粗笨,侉",
"unwilling":"a:不愿,厌恶;v:不甘",
"unwillingly":"d:勉勉强强",
"unwillingness":"n:勉强",
"unwind":"v:放松,解开,分开,展开,伸直",
"unwisdom":"n:愚蠢",
"unwise":"a:失策,愚蠢",
"unwitting":"a:不知不觉,无意;v:无意",
"unwittingly":"d:不知不觉,无意;v:无心",
"unwonted":"a:异常",
"unworried":"a:不虞",
"unworthy":"a:辜负,拙劣,不肖",
"unwounded":"a:完好",
"unwrap":"v:散开,打开,展开,解开",
"unwritten law":"n:不成文法,习惯法",
"unyielding":"a:不屈不挠,刚,刚强;n:强项;d:刚;v:不屈不挠",
"unyoke":"v:分散,解开,拆开,分开,解,解除",
"unzip":"v:拉开",
"up":"d:起来,到;n:兴奋剂,高地,快感,高处,上坡路;v:上升,提高;p:溯",
"up and down":"p:来回,上下",
"up till":"p:直到",
"up to":"p:到,迄,截,以至,直到,直至,暨,为止,洎",
"up to now":"p:迄今为止,至此",
"up until":"p:直到,到",
"up-and-coming":"a:进取",
"up-country":"d:内地",
"upbeat":"n:兴旺,上升",
"upbraid":"v:责备,噌,谴责;n:熊",
"upbraiding":"v:责备",
"upbringing":"n:教养,教育,养育,培养,家教,抚养,抚育",
"upchuck":"v:呕吐",
"upcountry":"a:内陆;n:内地",
"update":"v:更新,修正;n:现代化",
"updating":"v:调整,校正",
"upend":"v:颠倒,倒转,竖立,倒置",
"upgrade":"v:提升,升格,升级,提高;n:上坡,升级,上升;d:上坡",
"upheaval":"n:动乱,动荡,剧变,骚扰,举起;v:隆起",
"uphill":"n:登高,上,上升;d:上坡;v:上坡",
"uphold":"v:维护,坚持,支持,确认,赞同,支援,举起,批准,树,抬高,主持,右,鼓励,弘扬,崇尚,伸张,拥护",
"upholster":"v:装饰,布置",
"upholstery":"n:装饰布",
"upkeep":"n:维修,保养费,维护,保养,维修费;v:维护,保养",
"upland":"n:高地,旱地,山地,台地",
"uplift":"n:激发,隆起;v:隆起,提起,举起,发扬",
"uplifted":"v:上升",
"upon":"p:在,上,之上,在_上,在_之上",
"upper":"n:上,上铺,兴奋剂,鞋帮,腰带,上边",
"upper bound":"n:上限",
"upper class":"n:上流",
"upper crust":"n:脑袋,头",
"upper hand":"n:上风",
"upper jaw":"n:上颌",
"upper limit":"n:上限",
"uppercase":"a:大写",
"uppermost":"d:首先,最初;a:至上",
"uppish":"a:傲慢",
"uppity":"a:高傲",
"upraise":"v:提高,举起,抬起",
"upraised":"v:举起",
"upright":"a:正直,直;v:挺,端,竖,堂堂正正,雅正;n:方正,正大;d:笔直",
"uprightness":"n:笃实,垂直",
"uprising":"n:起义,暴动,上升,斜坡,起床,升起;v:反叛,起义,暴动",
"upriver":"v:上行;a:上行",
"uproar":"n:鼓噪,骚动,喧闹,喧哗;d:哇啦,哇哇;v:哄",
"uproarious":"a:捧腹大笑,汹,骚动,汹汹,吵闹,哄然",
"uproariously":"d:哄然",
"uproot":"v:拔除,根除,根绝,灭绝,铲除,锄",
"upset":"v:打翻,打乱,心烦意乱;n:不和,颠覆;a:乱腾腾",
"upsetting":"a:烦恼,骚,令人不安",
"upshot":"n:结果,结局,终点,要,结论,要点",
"upside":"n:上边,上部,上面,优点,正面",
"upside down":"n:倒,乌七八糟",
"upside-down":"d:颠倒,混乱;a:颠倒,乱七八糟",
"upstage":"n:后台",
"upstairs":"d:楼上;n:楼上",
"upstanding":"a:直立,强健",
"upstart":"n:暴发户",
"upstate":"n:内地",
"upstream":"d:上游,逆流;n:上游;v:上行",
"upsurge":"n:高潮,高涨,潮;v:增长;a:高涨",
"upswing":"n:改进,进步,提高;v:上进,改进,提高",
"uptake":"n:吸收,摄取;v:吸收,摄取",
"uptick":"n:上升",
"uptight":"a:紧张,愤怒",
"upturn":"n:好转,上升;v:好转,翻转,向上",
"upturning":"v:倒转",
"upward":"a:向上,上,上去;v:向上;d:向上",
"upwards":"d:向上,上涨,腾贵,以上",
"upwind":"a:顶风;d:顶风",
"uraemia":"n:尿毒症",
"uraemic":"a:尿毒症",
"uranium":"n:铀",
"uranus":"n:天王星",
"urban":"a:城市,都市;n:都市,市内",
"urban area":"n:城区,市区",
"urbane":"a:彬彬有礼,秀气,文雅",
"urbanity":"n:优雅,文雅",
"urbanization":"n:都市化",
"urbanize":"v:都市化",
"urchin":"n:顽童,少年,海胆,儿童",
"urea":"n:尿素,脲",
"uremia":"n:尿毒症",
"ureter":"n:输尿管",
"urethra":"n:尿道,输尿管",
"urethral":"a:尿道",
"urethritis":"n:尿道炎",
"urge":"v:敦促,劝,催促,督促,催,怂恿,强调,促使,鼓励;n:推动力",
"urge on":"v:鞭策",
"urgency":"n:紧急,迫切,催促,强调;a:紧急",
"urgent":"a:紧急,急,迫切,紧迫,急迫,眉睫,迫,急切,紧,加急,火,促,急溜溜,当紧,火急",
"urging":"v:冲动,激扬",
"urinal":"n:便池,尿盆",
"urinary":"a:尿",
"urinary organ":"n:泌尿器",
"urinate":"v:小便,排尿,小解,溲,尿",
"urination":"n:排尿,撒尿,小便",
"urine":"n:尿,小便,尿肥,小水",
"urn":"n:咖啡壶,水壶,瓮,骨灰盒,坛,甏,坟墓,缸",
"urology":"n:泌尿学",
"ursa major":"n:大熊座",
"ursa minor":"n:小熊座",
"ursine":"a:熊",
"urticaria":"n:风疹,荨麻疹",
"uruguay":"n:乌拉圭",
"us":"r:我,俺,我辈,我们,吾人,俺们,你我,咱,咱们;n:美国,我辈",
"us army":"n:美军",
"usa":"n:美国,美利坚合众国",
"usability":"n:可用性,适用,适用性,有用",
"usable":"a:使得,合用;v:使得",
"usage":"n:使用,用法,习惯,习俗,惯例,对待,功用",
"use":"v:用,使用;n:功用,惯例;p:以",
"use up":"v:罄,竭尽,尽,完,竭,用尽,耗尽,消耗",
"used":"a:旧",
"used to":"v:经常",
"useful":"a:有用,有益,中用",
"usefulness":"n:用,效用,效能",
"useless":"a:无用,不行,白搭,无济于事,不稂不莠,乏,无效,浑俗和光,老;v:不稂不莠,无济于事,使不得,无用,无益",
"uselessness":"n:没用",
"user":"n:用户,使用,行使,享有,享受",
"username":"n:用户名",
"usher":"v:引进;n:传达",
"usher in":"v:引进",
"using":"v:以",
"ussr":"n:苏联",
"usual":"a:通常,常见,寻常,日常,恒",
"usually":"d:通常,常,常常,平常,平素,素日,素,素常,素来,率,照例;n:素日",
"usurious":"a:高利,盘剥",
"usurp":"v:盗用,篡夺,窃据,侵犯,篡位,窃取,侵占,霸占,侵害,篡,盗",
"usurpation":"n:篡夺,侵占",
"usury":"n:高利贷,放印子,印子钱,印子,高利",
"utensil":"n:用具,器皿,家伙,具,器具,器",
"utensils":"n:器物",
"uterine":"a:子宫",
"uterine tube":"n:输卵管",
"uterus":"n:子宫,宫",
"utilise":"v:利用",
"utilitarian":"a:功利",
"utilitarianism":"n:功利主义",
"utilities":"n:用具",
"utility":"n:实用,效用,有用,应用,公用事业,功利;v:应用",
"utility man":"n:龙套",
"utilization":"n:利用,应用,效用;v:应用",
"utilize":"v:利用,运用,运",
"utmost":"a:莫大;n:极限;d:至",
"utopia":"n:乌托邦",
"utopian":"a:理想家",
"utter":"v:说;a:净尽",
"utterance":"n:发音,话,发表,语调,表达,流通,发声,言辞,话语,行使,死,发言,终极",
"utterly":"d:根本,十分,不堪,十全,绝顶,净尽,十二分,万般",
"uvula":"n:小舌,悬雍垂",
"uzbek":"n:乌孜别克",
"uzbekistan":"n:乌兹别克斯坦",
"v":"n:保险箱",
"vacancy":"n:空缺,缺额,缺,空额,空,空间,空位,阙,无所事事,遗缺,空房,空虚,闲暇,心不在焉,空地,出神,空隙,缺略",
"vacant":"a:空,茫然,空虚,惘然若失",
"vacantly":"d:茫然",
"vacate":"v:辞职,腾出,腾,休假,退出,解除,空",
"vacation":"n:假期;v:放假",
"vaccinate":"v:接种,种牛痘,种痘",
"vaccination":"n:接种,种痘,预防注射;v:种痘",
"vaccine":"n:疫苗,牛痘苗,痘苗,苗;a:疫苗",
"vacillate":"v:优柔寡断,游移,振荡,动摇,波动,摇摆",
"vacillating":"a:踌躇,犹豫",
"vacillation":"n:优柔寡断,犹豫不决,波动,振荡,摇摆,踌躇",
"vacuity":"n:无所事事,真空,空隙,空",
"vacuole":"n:液泡",
"vacuous":"a:空,真空",
"vacuum":"n:真空,空虚;a:真空",
"vacuum bottle":"n:保温瓶",
"vacuum flask":"n:保温瓶,热水瓶",
"vacuum pump":"n:真空泵",
"vagabond":"n:无赖,流氓;a:流浪,漂泊;v:流浪",
"vagabondage":"n:流浪",
"vagary":"n:异想天开,妄想,变幻莫测,幻想",
"vagina":"n:阴道,膣,阴沟,鞘,叶鞘",
"vaginal":"a:叶鞘",
"vagrancy":"n:流浪,漂泊,变幻无常,离题",
"vagrant":"n:游民,流浪者,无赖,流氓",
"vague":"a:含糊,笼统,模模糊糊,隐晦;n:迷走神经;v:闪烁",
"vaguely":"d:依稀,影影绰绰",
"vagueness":"n:含糊",
"vagus nerve":"n:交感神经",
"vain":"a:浮华,空头,谿",
"vainglorious":"a:自负",
"vainglory":"n:虚荣心,虚荣,自负",
"vainly":"d:白白",
"vale":"n:谷,峪,沟;i:再见",
"valediction":"n:告别,辞别",
"valedictory":"a:告别,辞别",
"valence":"n:价,化合价,原子价,结合;v:结合",
"valency":"n:原子价",
"valentine":"n:情人,对象",
"valentine day":"n:情人节",
"valet":"n:男仆,随从;v:侍候",
"valetudinarianism":"n:体弱多病",
"valiant":"a:英勇,勇敢,雄赳赳,骁勇,猛,赳赳,强悍,飒爽,英武,勇武;n:英烈",
"valiantly":"d:雄赳赳",
"valid":"a:有效,正确,正当,确实",
"validate":"v:确认,确证,证实,批准",
"validation":"n:有效",
"validity":"n:有效,正确,妥当,效力,真确,合法性,正当",
"valise":"n:背包,旅行袋,提包",
"valium":"n:安定",
"valley":"n:山谷,谷,谷地,流域,崖谷,山洼,峪,波谷,山沟,山窝,低谷",
"valor":"n:英勇,勇猛",
"valorous":"a:无畏,勇猛",
"valour":"n:英勇,勇猛",
"valuable":"a:宝贵,贵重,珍贵,值钱,可贵,贵",
"valuables":"n:财",
"valuate":"v:鉴定,评价,估价",
"valuation":"n:估价,价值,评价,赋值;v:计价",
"value":"n:值,价值,数值,价格,意义;v:估量;d:尚",
"valued":"a:重要,宝贵,贵重",
"valve":"n:阀门,阀,真空管,瓣膜,管,电子管,活门,截门,门,裂片,管子,活瓣,灯,瓣,豆瓣",
"valvular":"a:活门",
"vamp":"v:拼凑,修补,翻新,捏造,添补;n:补钉",
"vamp up":"v:添补",
"vampire":"n:吸血鬼",
"van":"n:囚车,先锋,家具,翼,大篷车,领袖,前卫,前列,领导人,范,前驱,先驱,行李车;v:选",
"vanadium":"n:钒",
"vancouver":"n:温哥华",
"vandalize":"v:破坏",
"vandyke brown":"n:深褐色",
"vane":"n:风向标,叶片,叶轮,翼,文",
"vanguard":"n:先锋,前锋,先锋队,前卫,前茅,尖兵,先驱,领导者",
"vanilla":"n:香草",
"vanish":"v:消失,绝迹,消,消散,没,消逝,隐没,杳无踪迹,泯,消灭,泯没,溜掉,泯灭,隐退,涣,冰释",
"vanishing cream":"n:雪花膏",
"vanity":"n:虚荣心,虚荣,自负,空虚,自大,梳妆台,无用,假大空;a:虚荣",
"vanity fair":"n:名利场",
"vanquish":"v:击败,克服,征服,降伏,抑制,战胜;n:击败,征服",
"vanquisher":"n:胜利者",
"vantage":"n:获利,优势,利益",
"vapid":"a:乏味,平淡",
"vapidity":"n:乏味,无味,走味,平淡",
"vapor":"n:蒸气,蒸汽,水汽,雾气,烟雾,烟,汽;v:蒸发",
"vaporise":"v:蒸发",
"vaporization":"n:汽化,气化",
"vaporize":"v:蒸发,汽化,气化,散失",
"vaporizer":"n:喷雾器,汽化器",
"vapors":"n:废气,烟雾",
"vapory":"a:烟雾",
"vapour":"n:水汽,雾,烟,空想,雾气,自大;v:吹牛,挥发,自夸",
"vapours":"n:烟雾",
"variability":"n:变异性,无常,易变",
"variable":"a:无常,易变;n:变数,变星",
"variable quantity":"n:变量",
"variable star":"n:变星",
"variables":"n:变数",
"variance":"n:不和,偏差,变化,变量,冲突,变更,离散,相异,变动,争论",
"variant":"n:变量,变形,异体;a:不同",
"variate":"n:变量",
"variation":"n:变化,变异,变动,变奏曲,变种,变量,演变,调整,偏差,异体;v:调整",
"varicolored":"a:杂色,五颜六色;n:杂色",
"varicoloured":"a:五颜六色",
"varied":"a:多变,多种多样,杂,多样,花花搭搭,各种各样",
"variegated":"a:斑驳,花;n:杂色",
"variegation":"a:花斑,杂色;n:花斑,上色",
"variety":"n:品种,变种,种,种类,变化,多样化,花样,多样性,项目,变形,名堂,彩,异体,杂凑",
"variety show":"n:杂耍",
"various":"a:各种,各,各种各样,多种,多方面;r:各;n:各式各样",
"varlet":"n:无赖,歹徒,跟班",
"varmint":"n:淘气鬼,歹徒,害兽",
"varnish":"n:清漆,漆;v:掩饰,粉饰,文饰,美化",
"varnish tree":"n:漆树",
"varnished":"a:油光",
"vary":"v:变化,不同,改变,不等,变换,多样化,可变,不一,变异,变化多端,违背,相异,变更,修改",
"vascular":"a:血管,导管",
"vascular strand":"n:维管束",
"vase":"n:花瓶,瓶,瓷瓶,水瓮,瓿",
"vaseline":"n:凡士林,矿脂",
"vassal":"n:部属,诸侯,附庸,奴隶",
"vassalage":"n:效忠,领地",
"vast":"a:辽阔,大量,广大,巨大,广阔,无垠,茫茫,无边,浩瀚,无边无际,无际,宏大,苍茫,褒,宽旷;n:大海,汪洋;v:无限",
"vastness":"n:巨大",
"vat":"n:缸,染缸",
"vatican":"n:梵蒂冈",
"vaudeville":"n:杂耍",
"vault":"n:金库,墓穴,拱顶;v:跃居,跳跃",
"vaulted":"a:穹形;n:拱形",
"vaulting horse":"n:拱柱",
"vaunt":"v:自夸,宣扬,自吹自擂,夸张;n:自负,自夸",
"vaunting":"a:吹嘘",
"vcr":"n:录像机",
"vector":"n:矢量,向量,带菌者,幅,航向",
"vectoring":"v:引导",
"veer":"v:改变,转变,放出,放松",
"veg":"n:蔬菜",
"vega":"n:织女星,织女",
"vegetable":"n:蔬菜,菜,植物,素",
"vegetable garden":"n:菜畦,菜园子,菜圃",
"vegetable marrow":"n:西葫芦",
"vegetable oil":"n:菜油",
"vegetable soup":"n:菜汤",
"vegetable sponge":"n:丝瓜",
"vegetables":"n:蔬菜,菜蔬",
"vegetarian":"n:食草动物",
"vegetarianism":"n:素食",
"vegetate":"v:结晶,流出,增殖,生长,长大;n:结晶",
"vegetation":"n:植被,植物,草木,覆盖,发育;v:覆盖",
"vegetative":"a:植物,蔬菜,无所作为;v:无所作为",
"veggie":"n:蔬菜",
"veggies":"n:蔬菜",
"vehemence":"n:热烈,热心,激烈,猛烈",
"vehement":"a:强烈,激烈,猛烈,激昂慷慨,激切;v:激切",
"vehemently":"d:强烈",
"vehicle":"n:车辆,飞行器,车,交通工具,媒介,车子,飞船,轱,媒质",
"vehicular":"a:车",
"veil":"n:面纱,面罩,幕,烟幕;v:弥漫,隐匿,遮盖",
"veiled":"a:含蓄;n:隐藏",
"veiling":"n:面纱,帐幔;v:遮蔽",
"vein":"n:静脉,血管,矿脉,脉,性格,叶脉,筋络,毛刺,倾向,裂缝,情绪,射流,性情,翅脉,裂痕,纹理,风格,筋,气质,心境",
"veins":"n:纹理",
"velar":"n:舌根音,舌面后音",
"veld":"n:草原",
"velocipede":"n:自行车",
"velocity":"n:速度,速,速率,迅速",
"velour":"n:毛皮,丝绒,天鹅绒,棉绒",
"velum":"n:帆,软腭,膜",
"velvet":"n:天鹅绒,丝绒,平绒,赚头",
"velveteen":"n:平绒,棉绒",
"velvety":"a:软绵绵",
"venal":"a:贪污;v:贪",
"venality":"n:见利忘义,贪财,贪污,受贿",
"venation":"n:纹理,脉络,翅脉",
"vend":"v:出售,鬻,卖,粥,发表,贩卖,叫卖",
"vending machine":"n:售货机",
"vendor":"n:小贩,卖方,卖主",
"veneer":"n:胶合板,镶板;v:粉饰,胶合",
"venerability":"n:尊敬",
"venerate":"v:崇拜,尊敬,尊,尊崇,钦仰,敬慕,敬仰",
"veneration":"n:尊崇,崇拜,尊敬",
"venereal":"a:性交,性病",
"venereal disease":"n:性病,花柳病",
"venetian":"n:威尼斯",
"venezuela":"n:委内瑞拉",
"vengeance":"n:复仇,报仇,报复",
"venice":"n:威尼斯",
"venison":"n:鹿肉,野味",
"venom":"n:恶毒,毒汁,怨恨,毒,毒物,恶意,诽谤;v:放毒",
"venomous":"a:有毒,恶意,狠毒,险,刻毒;v:有毒",
"venous":"a:静脉,脉络",
"vent":"n:发泄;v:排气,发出,泄露,放出,吐露,泄漏",
"ventilate":"v:通风,通气,透风,透气,排气,发表,换气,发泄,宣布",
"ventilated":"v:透风",
"ventilation":"n:通风;v:通风",
"ventilator":"n:风箱,气窗,通风管,气孔,通风机,换气扇,风扇",
"ventral":"a:腹,腹鳍;n:腹鳍",
"ventral fin":"n:腹鳍",
"ventricle":"n:心室,室,脑室",
"ventricles":"n:心室",
"ventricular":"a:室",
"ventriloquism":"n:口技",
"ventriloquy":"n:口技",
"venture":"v:敢,冒昧;n:冒险;a:冒昧",
"venturesome":"a:大胆",
"venturous":"a:大胆",
"venue":"n:场地",
"venus":"n:维纳斯,色情,长庚,美人,爱神,启明,性爱,美女",
"venushair":"n:铁线蕨",
"veracious":"a:诚实",
"veracity":"n:诚实,确实,正确,真实",
"veranda":"n:走廊,阳台,游廊,廊子,露台,晾台,凉台",
"verb":"n:动词",
"verbal":"a:口头,词句;n:言语",
"verbally":"d:口头",
"verbatim":"d:逐字",
"verbiage":"n:冗词,措辞,冗长,饾饤",
"verbose":"a:罗嗦,冗赘,詹,累赘,繁芜",
"verbosity":"n:冗长,赘言,冗赘",
"verdant":"a:苍翠,青翠,葱绿,翠绿,嫩绿,生疏,青葱,葱茏,葱郁",
"verde":"n:佛得角",
"verdict":"n:裁决,决定,判断,结论,意见,冤狱,谳,定案",
"verdigris":"n:铜绿",
"verdure":"n:青翠,生气,繁盛,青绿,新鲜",
"verge":"n:边缘;v:逼近,濒临",
"veriest":"a:十足,绝对",
"verification":"n:验证,证明,确定,证据,证实,校验;v:鉴定,核对,证实,验证,检验",
"verified":"a:凿凿;v:凿凿",
"verify":"v:证实,验证,校验,检验,核实,证明,校准,考,对证,稽考,证验,查证,探明,查对;n:证",
"verifying":"v:核对",
"verisimilitude":"n:逼真,可能性",
"veritable":"a:真正,确实",
"verity":"n:真理,真实",
"vermicelli":"n:挂面,粉丝",
"vermiform appendix":"n:阑尾",
"vermiform process":"n:阑尾",
"vermilion":"n:银朱,朱砂;a:朱红",
"vermin":"n:歹徒,害虫,寄生虫,坏蛋,害鸟,蠹虫,害兽,害人虫",
"verminous":"a:害虫",
"vernacular":"n:土话,下流话,行话,白话,大白话,俗话,方言,口语",
"vernal":"a:春天,和煦",
"vernal equinox":"n:春分点,春分",
"vernier":"n:游标",
"verruca":"n:疣",
"versailles":"n:凡尔赛",
"versatile":"a:多才多艺;v:多才多艺",
"versatility":"n:多才多艺",
"verse":"n:诗,诗句,诗歌,韵文,诗篇,章",
"versed":"a:反,熟练,精通",
"versicle":"n:短句",
"versification":"n:诗体",
"versifier":"n:诗人",
"version":"n:说法,版本,形式,译文,文本,译本,本,型,模型;v:执行",
"verso":"n:封底,封四,背面,反面;a:反面",
"versus":"p:对,相对,与_相对",
"vertebra":"n:椎骨,脊椎,脊椎骨,脊,椎,脊骨",
"vertebrae":"n:脊",
"vertebral":"a:脊椎",
"vertebrate":"n:脊椎动物",
"vertebrates":"n:脊椎动物",
"vertex":"n:顶点,顶,头顶,绝顶,极点",
"vertical":"a:垂直,直,竖,纵,铅直,立;n:纵向,垂线,垂直线,垂直面;v:竖,铅直",
"vertical section":"n:纵剖面,纵切面",
"vertiginous":"a:旋转,眩晕",
"vertigo":"n:眩晕,头晕,眼花",
"verve":"n:生气,活力,热情,气势,气韵,神韵,才能",
"very":"d:很,非常,十分,大,极,太,真;a:生,绷,滚,精,煞,不得了;v:不得了,滚",
"very fast":"a:急速,飞快,嘌",
"very high frequency":"n:甚高频",
"very important person":"n:要人",
"very low frequency":"n:甚低频",
"very much":"a:良,倍儿,非常,殊",
"vesicle":"n:泡,囊,水疱",
"vesper":"n:黄昏,长庚星,太白星,薄暮",
"vessel":"n:船,容器,血管,船舶,器皿,导管,船只,舰,盛器,飞船,脉管,舟,管,皿",
"vessels":"n:船只,船,舟楫,管",
"vest":"n:背心;v:给与",
"vestal":"n:处女,修女;a:修女",
"vestibular":"a:门厅",
"vestibule":"n:前厅,前庭,门厅,门道",
"vestige":"n:遗迹,痕迹,证据,残迹,迹,一点儿,足迹",
"vestiges":"n:残迹,残余",
"vestigial":"a:痕迹",
"vestment":"n:法衣,外衣,礼服,衣服,制服",
"vet":"v:治疗,检查;a:老练;n:兽医",
"vetch":"n:野豌豆,巢菜",
"veteran":"n:老兵,退伍军人,老将,老手,老资格,元老,复员军人,转业军人",
"veterinarian":"n:兽医",
"veterinary":"n:兽医",
"veto":"n:禁止;v:禁止",
"vex":"v:病,忧烦",
"vexation":"n:烦恼,恼火,着急,生气,苦恼,心烦",
"vexed":"a:糟心,苦恼;v:争论不休",
"vexing":"a:烦人,烦恼",
"via":"p:通过,经,经过,途经,取道;n:管道,道,道路,路;v:取道",
"viaduct":"n:栈道,跨线桥,旱桥,高架桥",
"vial":"n:玻璃瓶",
"viand":"n:食物,佳肴,食品",
"viands":"n:食品",
"vibes":"v:颤动,摇摆,振动;n:颤动,摇摆,振动",
"vibrancy":"n:活跃,振动,响亮,颤动;v:振动",
"vibrant":"a:响亮,振动",
"vibrate":"v:振动,震动,颤动,摇动,摆动,震荡,颤,抖动,震撼,撼动,震",
"vibration":"n:振动,振荡,震动,摆动,颤动,震颤,激动,摇摆,犹豫;v:振荡,颤动,摇摆,振动,摆动",
"vibrational":"a:震动",
"vibrator":"n:振荡器,簧",
"vibratory":"a:振动,震动",
"vicar":"n:教皇,两面派",
"vicarious":"a:代理,替代",
"vice":"n:恶习,老虎钳,毛病,恶,缺点,罪恶;p:代;a:恶",
"vice versa":"p:反过来",
"vicegerent":"n:代理人",
"viceregal":"a:总督",
"viceroy":"v:开始,着手;n:总督",
"vicinity":"n:附近,接近,周围,邻近,前后;v:接近",
"vicious":"a:凶恶,恶毒,恶性,邪恶,险,坠落,狠毒,歹,辣,险恶,歹毒,辣手",
"vicious cycle":"n:恶性循环",
"viciousness":"n:歹毒",
"vicissitude":"n:变迁,交替,变动,盛衰,兴衰,推移,变化",
"vicissitudes":"n:沧桑,变迁",
"victim":"n:受害者,牺牲品,受害人,被害者,牺牲",
"victimization":"n:害人,牺牲;v:害人",
"victimize":"v:迫害,害,欺骗,穿孔,鱼肉,牺牲,穿透",
"victor":"n:胜利者",
"victoria":"n:维多利亚",
"victorious":"a:胜利,得胜,凯",
"victoriously":"d:取胜",
"victory":"n:胜利,胜,战胜,胜仗,战果,捷;v:胜",
"victual":"n:剩饭,饮料,食物,粮食",
"victuals":"n:给养",
"videlicet":"d:就是说,即",
"video":"n:电视,视频,影像;a:视频,电视",
"videodisc":"n:影碟",
"videodisk":"n:影碟",
"videophone":"n:电视电话,可视电话",
"videotape":"n:录像带;v:录像",
"vie":"v:竞争,争,抢",
"vienna":"n:维也纳",
"viet nam":"n:越南",
"vietnam":"n:越南",
"view":"n:观点,看法,景色,意见,见解;v:揣度,检查,视察,看做",
"viewer":"n:观众",
"viewfinder":"n:反光镜",
"viewing":"v:观测,观看,检视,观察",
"viewpoint":"n:观点,看法,观念,视点,见解",
"views":"n:见解",
"vigil":"n:守夜,值夜,熬夜",
"vigilance":"n:警惕,警戒,守夜;v:警觉",
"vigilant":"a:机警,警",
"vignette":"n:小品文,描述",
"vigor":"n:活力,魄力,精力,精神,血气,劲头,生气,朝气,劲,愣劲儿,锐,元气,干劲,魄",
"vigorous":"a:有力,旺盛,强有力,强烈,朝气蓬勃,精神,蓬勃,神气,苍劲,积极,猛,猛烈,带劲,刚劲,虎虎,遒劲,奕奕,峭拔,武,茁壮,勃,刚健,盛,怒,起劲,勃勃,轰轰烈烈,能动;n:虎;v:盛",
"vigorously":"d:力,起劲,强烈,大力,欢,勃然,冲;n:力",
"vigour":"n:劲,干劲,体力,元气,劲头,气力,强壮,锐,优势,气魄,魄,血气",
"vile":"a:卑鄙,可耻,鬼",
"vilification":"n:诽谤",
"vilify":"v:辱骂,谤,诬蔑,丑化,诽谤,攻击,中伤,贬低,污蔑,诋毁,诟骂",
"villa":"n:别墅,墅",
"village":"n:村子,村庄,村,乡村,村落,农村,乡下,乡,乡间,村寨,农庄,屯落,小区,庄,群落,聚落,屯子,堡,庄子",
"villager":"n:村民,乡民,乡下人,村夫",
"villagers":"n:乡亲",
"villain":"n:恶棍,坏蛋,反面人物,坏人,丑类,乡巴佬,凶徒,恶人,慝,小人",
"villainous":"a:坏人,缺德,恶棍,无行",
"villainy":"n:邪恶,凶恶,卑劣,罪恶",
"villus":"n:绒毛",
"vim":"n:精力,力气,活力",
"vindicate":"v:维护,开脱,剖白,表白",
"vindication":"n:维护,辩白,辩护,辩解,证明",
"vindictive":"a:恶意,复仇",
"vine":"n:藤,缠绕茎,藤子,秧子,藤本植物",
"vinegar":"n:醋,醯,米醋,酢",
"vinegary":"a:酸",
"vineyard":"n:葡萄园",
"vino":"n:酒,果酒",
"vinous":"a:酒",
"vintage":"n:酒",
"viola":"n:中提琴",
"violate":"v:违背,违犯,破坏,侵犯,违,违反,触犯,糟蹋,妨害,背,违拗,妨碍,强奸,仵,睽,侵害,侵入,牾,污辱,犯",
"violation":"n:侵害,违反,侵犯,违背,犯规,违犯,违例,污辱,妨害,强奸",
"violence":"n:暴力,猛烈,暴行,激烈,热烈,暴虐,歪曲,暴,窜改,侵害,伤害,曲解,烈度,强暴,强奸,违犯",
"violent":"a:猛烈,激烈,强烈,猛,粗暴,凶猛,暴烈,狂暴,急,怒,强暴,鸷;v:激",
"violent storm":"n:急风暴雨,狂风暴雨,暴风,疾风暴雨",
"violently":"d:猛,横,大肆;a:横暴,横",
"violet":"n:紫罗兰;a:紫",
"violin":"n:小提琴",
"violoncello":"n:大提琴",
"vip":"n:达官贵人,大人物",
"viper":"n:蝰蛇,毒蛇",
"viperous":"a:恶毒",
"virago":"n:悍妇,泼妇",
"viral":"a:病毒",
"virgin":"n:处女,黄花闺女,处子,室女,童女,黄花",
"virginal":"a:处女,纯洁",
"virginia":"n:弗吉尼亚",
"virginia creeper":"n:爬山虎",
"virginity":"n:贞操,贞,新鲜,童贞,纯洁",
"virgo":"n:室女",
"virile":"a:男,壮年,英武",
"virility":"n:气魄,雄浑,成年,男子气,成人,年富力强",
"virology":"n:病毒学",
"virtual":"a:虚,实际上",
"virtual image":"n:虚象",
"virtually":"d:实际上,事实上,简直,无形中;a:无形",
"virtue":"n:美德,优点,德行,品德,长处,贞操,效力,效能,英勇,操守,德,价值,节操,功效,力",
"virtuoso":"n:大师,名家",
"virtuous":"a:善良,贤惠,贤慧;n:贤德",
"virulence":"n:刻毒,有毒,恶毒,毒性,恶意",
"virulent":"a:有毒",
"virus":"n:病毒,恶意,恶毒,毒害,毒素",
"vis-a-vis":"p:与_相对,与_比较,比较,相对",
"visa":"n:签证",
"visage":"n:脸,面貌,外表,面庞,面容,面目,脸色",
"viscera":"n:脏器,内部,内容,内脏,脏,脏腑;a:脏",
"visceral":"a:内脏,体腔",
"viscose":"n:粘胶",
"viscose rayon":"n:粘胶",
"viscosity":"n:粘度,粘性",
"viscount":"n:子爵,子",
"viscous":"a:粘,溏",
"vise":"n:台钳,虎钳",
"visibility":"n:能见度,可见度,明白,明显,显著",
"visible":"a:可见,在望,有形,明",
"visibly":"d:显然,明明白白",
"vision":"n:视力,幻想,视觉,幻象,远见,幻影,眼光,想象力,景象,眼力,目光,美景,姿态,显圣,想像力;v:显示,想像,想见",
"visionary":"a:虚无缥缈,想象,空幻,梦幻;v:虚无缥缈;n:空想家",
"visit":"v:访问,参观,看,拜访,看望;n:拜会,巡视,往来,视察",
"visitant":"n:贵宾,来客,候鸟",
"visitation":"n:视察,报应;v:视察",
"visiting":"a:访问,视察",
"visiting card":"n:名帖,刺,片子",
"visitor":"n:客人,游客,来宾,来客,客,游人,学监,宾客,检查员",
"visor":"n:帽舌,遮阳,面罩;v:遮阳",
"vista":"n:前景,展望",
"visual":"a:视觉,可见,目视,看",
"visual hallucination":"n:幻视",
"visual purple":"n:视紫质",
"visualization":"n:形象,目测,显像",
"visualize":"v:想象,显现,构想",
"visually":"d:有目共睹",
"vital":"a:生命,致命,紧要,活力,生机",
"vital capacity":"n:肺活量",
"vital statistics":"n:统计",
"vitality":"n:活力,生命力,元气,生气,体力,朝气,生机,持久力,精神,活气,春",
"vitalize":"v:搞活",
"vitals":"n:要害,核心",
"vitamin":"n:维生素,维他命",
"vitamin a":"n:维生素Ａ",
"vitamin b":"n:硫胺,维生素Ｂ,核黄素",
"vitamin c":"n:抗坏血酸",
"vitamin g":"n:核黄素",
"vitamin m":"n:叶酸",
"vitiate":"v:损害,损坏,弄坏,污染",
"vitiation":"n:损害",
"vitreous":"a:玻璃,透明",
"vitriol":"n:蓝矾,矾,硫酸,硫酸盐",
"vitriolic":"a:硫酸,尖刻",
"vituperate":"v:骂,谩骂,辱骂,责骂",
"vituperation":"n:辱骂",
"vituperative":"a:责骂,舌战",
"viva":"n:欢呼声,欢声,口试",
"vivacious":"a:活泼,焕发;v:焕发",
"vivacity":"n:活泼,快活,愉快",
"vivid":"a:生动,鲜艳,活泼,真切,形象,传神,逼真,活灵活现,绘声绘色,活,清晰",
"vividly":"d:活灵活现",
"viviparous":"a:胎生",
"vivisect":"v:解剖",
"vixen":"n:泼妇,母老虎,悍妇",
"vixenish":"a:泼辣",
"vizier":"n:大臣",
"vladivostok":"n:符拉迪沃斯托克",
"vocable":"n:单词,词",
"vocabulary":"n:词汇,语汇,字汇",
"vocal":"a:声音,有声;n:歌曲",
"vocalic":"a:元音,母音",
"vocalise":"v:发声",
"vocalist":"n:歌唱家,歌手,声乐",
"vocalization":"n:发声",
"vocalize":"v:哼,叫,发声,谈,喊,说,唱",
"vocally":"d:口头",
"vocation":"n:职业,天职,行业,才能,使命,天命",
"vocational":"a:职业,行业",
"vocational school":"n:职高,职业高中",
"vocative":"a:称呼,呼唤",
"vociferate":"v:叫喊,叫嚣,叫嚷,吵闹,喧嚷",
"vociferous":"a:叫喊,喧嚷",
"vodka":"n:伏特加",
"vogue":"n:流行,时髦,风气,时样,时尚;a:时髦",
"voice":"n:声音,嗓音,嗓门,嗓子,声,语音,歌手,意见,人声,歌喉,发言权,语声,歌声,语言,口音,呼声;v:发抒,抒发",
"voice box":"n:音箱",
"voice over":"n:话外音",
"voiced":"v:带音",
"voiced sound":"n:浊音",
"void":"n:空位,空隙,空穴,孔隙,空虚,真空;a:浮,虚,空闲,空虚;v:退出,取消,排泄,放出",
"voiding":"v:残羹剩饭;n:残羹剩饭",
"volatile":"a:浮,飞行",
"volatility":"n:挥发性,快活,反复无常,轻快,轻浮",
"volatilize":"v:挥发,飞",
"volcanic":"a:火山,猛烈",
"volcano":"n:火山",
"vole":"n:田鼠",
"volga":"n:伏尔加河,伏尔加",
"volga river":"n:伏尔加河",
"volition":"n:意志,决心",
"volitional":"a:意志",
"volley":"v:排放,齐鸣,迸发,拦击;n:连发,迸发",
"volleyball":"n:排球",
"volt":"n:伏特,闪避,伏",
"volt-ampere":"n:伏安",
"volta":"n:回",
"voltage":"n:电压",
"voltaic":"a:电流",
"volte-face":"n:变卦",
"voltmeter":"n:电压表,伏特计,电压计,电量计",
"volubility":"n:流畅,谈锋,流利,饶舌",
"voluble":"a:健谈,流利",
"volume":"n:体积,卷,量,容量,音量,容积,大量,本,许多,编,材积,书籍,书卷,册,分量,册子,额,响度,大小,总数,强度,辑,集,卷轴",
"volumetric":"a:容积,容量",
"voluminous":"a:长篇,洋洋洒洒,浩如烟海",
"voluminousness":"n:长篇",
"voluntarily":"d:自愿,自动,志愿,自觉自愿,自行;n:志愿;v:自愿",
"voluntarism":"n:募兵制",
"voluntary":"a:志愿,自愿,义务;v:自动",
"voluntary muscle":"n:随意肌",
"volunteer":"v:自愿;n:志愿兵;a:义务",
"volunteers":"n:志愿军,义勇军",
"voluptuous":"a:骄奢淫逸",
"vomit":"v:呕吐,吐,唾弃,涌流,呕",
"vomiting":"v:呕吐",
"von":"n:冯,领地",
"voodoo":"n:巫术",
"voracious":"a:贪吃,贪婪;v:贪得无厌,强取豪夺",
"voracity":"n:暴食,贪婪,贪食",
"vortex":"n:涡流,涡,旋风,旋涡,漩涡,漩,洑",
"votary":"n:信徒,爱好者",
"vote":"v:投票;n:表决权,投票权,议决",
"vote down":"v:否决",
"vote in":"v:选出",
"vote of confidence":"n:信任投票",
"voter":"n:选民",
"voting":"n:投票;a:投票",
"voting booth":"n:投票站",
"votive":"a:奉献,还愿",
"vouch":"v:担保,保证,证明,作证,确定,断言",
"voucher":"n:凭证,保证人,单据,凭单,证件,传票,票据,收据,收条,证书",
"vouchsafe":"v:给,赐予,开恩,允诺,赐",
"vow":"v:发誓;n:誓约;d:矢口",
"vowel":"n:元音,母音",
"vowel rhyme":"n:叠韵",
"voyage":"n:航行;v:飞行",
"vulcan":"n:锻工,铁匠",
"vulcanization":"n:硫化,硬化;v:硫化",
"vulcanize":"v:硫化,热补,硬化",
"vulgar":"a:庸俗,粗俗,粗鄙,俗,俗气,低级,鄙俗,俗不可耐,粗,鄙,俚,陋,俚俗,鄙吝,伧俗,伧",
"vulgarian":"n:俗物",
"vulgarism":"n:粗俗,歹话,齐东野语,俗语,粗鄙,庸俗",
"vulgarity":"n:粗俗,粗野,下流,下流话,庸俗",
"vulgarization":"n:庸俗化,大众化",
"vulgate":"n:口语,土话,俗话",
"vulnerability":"n:弱点,脆弱性,要害",
"vulnerable":"a:薄弱,脆弱",
"vulpine":"a:狡猾,狐狸",
"vulture":"n:秃鹫,坐山雕,鹫,雕",
"vulva":"n:阴门,女阴,阴户,外阴,孔",
"w/":"p:与_一起,带有,对,在_身边,具有,一边,用,身边,在_一边,一起",
"wacky":"a:疯疯癫癫,古怪",
"wad":"n:钱,叠,填料,一块;v:得意洋洋",
"wadding":"n:填料;v:絮",
"waddle":"v:拽",
"wade":"v:涉水,涉,蹚,插手;n:跋涉",
"wader":"n:涉禽",
"wadi":"n:绿洲",
"wading":"v:浅水",
"wafer":"n:薄片,胶纸,芯片",
"waffle":"v:含糊其词,胡扯,瞎扯,瞎诌",
"waft":"n:一阵风,浮动,飘浮,信号,信号旗;v:漂荡,浮动",
"wafting":"v:漂荡",
"wag":"v:摇,摇摆,摆动,变迁,摇动,掉,出发,推移;n:摇动,偷懒,摆动",
"wage":"v:进行,作;n:工钱,薪水,薪金,薪资,代价,工薪",
"wage increase":"v:调资",
"wager":"n:打赌;v:保证,担保",
"wages":"n:工资,薪,薪资,待遇,薪水,工钱",
"waggery":"n:恶作剧,开玩笑,滑稽",
"waggish":"a:滑稽",
"waggle":"v:摆动",
"waggon":"n:矿车,手推车",
"wagon":"n:车,货车,矿车,手推车,小车",
"wagon train":"n:车队",
"wagoner":"n:车夫",
"waif":"n:信号,流浪者",
"wail":"v:哭,痛哭,呼啸,悲叹,嚎哭;n:呼号;d:嚎啕",
"wailing wall":"n:慰藉",
"wainscot":"n:墙裙",
"waist":"n:腰部,腰,腰身,上衣,背心",
"waistband":"n:腰带,裤带",
"waistcoat":"n:背心,坎肩,背搭子,坎肩儿,马甲",
"waistline":"n:腰身,腰围,腰肢",
"wait":"v:等,等待,等候;n:埋伏",
"wait on":"v:侍,伺候,侍候",
"waiter":"n:服务员,侍者,堂倌,茶房,伙计,跑堂儿的,托盘,店小二",
"waiting":"n:等,等待,等候,侍候,服侍",
"waiting room":"n:候机室",
"waitress":"n:女招待",
"waive":"v:放弃,撇开,弃权,停止,撤回,丢弃",
"waiver":"n:放弃,弃权",
"wake":"v:醒来,醒,叫醒,唤醒,起来,睡醒,引起,发觉,苏醒,醒悟;n:守灵,航迹,踪迹",
"wake up":"v:醒来,悟,叫醒,睡醒,唤醒",
"wakefulness":"v:失眠;n:失眠",
"waken":"v:醒来,唤醒,鼓励",
"wale":"n:岗子,箍,条纹,岗;v:鞭打",
"wales":"n:威尔士",
"walk":"v:走;n:徒步,管区,行为,走边",
"walk about":"v:徘徊,跞,跄",
"walk of life":"n:各行各业",
"walk on air":"n:得意洋洋",
"walk out":"v:罢工",
"walk through":"v:预演",
"walkie-talkie":"n:步话机,步谈机",
"walking":"v:步行,步法",
"walking stick":"n:拐杖,拐,拐弯抹角,竹节虫,杖",
"walkout":"n:罢工,罢课,退席",
"walkway":"n:通道,小路,小道,走道",
"walky-talky":"n:步话机",
"wall":"n:墙,墙壁,壁,城墙,围墙,四壁,堵,城,土堤;v:垒",
"wall unit":"n:组合柜",
"wallaby":"n:失业,袋鼠",
"wallboard":"n:壁板",
"wallet":"n:钱包,皮夹子,皮夹,钱夹,夹子,钱袋,腰包,旅行袋,行囊,荷包",
"wallop":"v:猛冲,猛打,猛击,击溃;n:效力,猛击,痛打,冲击力",
"walloping":"n:溃败,猛打;a:庞大",
"wallow":"v:涌出;n:打滚,泥坑",
"wallpaper":"n:壁纸,糊墙纸,墙纸",
"walls":"v:闪",
"wally":"n:玩具,装饰品",
"walnut":"n:核桃,胡桃",
"walrus":"n:海象",
"waltz":"n:华尔兹,圆舞曲;v:旋转",
"wampum":"n:钱",
"wan":"a:苍白,病态;n:万",
"wand":"n:魔杖,指挥棒,杖,杆,棍棒",
"wander":"v:漫游,徘徊,游荡,流浪,偏离,漫步,离开,逛荡,漂泊,偏移,漂移,飘零,漂荡,漂游,闯荡,错乱,流;n:流浪",
"wanderer":"n:流浪者,流浪汉",
"wandering":"n:流浪,胡话,错乱,漫游,漂移,迁移,徘徊,偏移;v:漂游,飘零;a:漫游",
"wandering nerve":"n:迷走神经",
"wane":"v:亏,衰败,衰微,减少,没落,缺;n:减少,没落,衰退",
"wangle":"v:粉饰,哄骗,花言巧语,掩饰,伪造;n:伪造,哄骗,诡计",
"waning":"v:衰落,减少,阑珊;a:阑珊",
"want":"v:要,需要,希望,愿意,没有;n:不足,贫穷,穷困",
"wanted":"v:通缉",
"wanting":"p:短少,缺,没有;v:欠,差;a:没有,缺乏",
"wanton":"v:任性;a:随便,肆;n:荡妇",
"wantonly":"d:任意,大肆,肆意",
"wapiti":"n:麋鹿,马鹿",
"war":"n:战争,斗争,战,仗,战事,军事,战术,武器;v:打仗,作战,斗争,竞争",
"war paint":"n:化妆",
"war whoop":"n:欢呼声",
"war-torn":"n:兵乱;a:兵连祸结",
"warble":"n:颤音,唱歌,歌手,哨",
"warbler":"n:鸣禽,莺,歌手",
"ward":"n:病房,监护,区,守护,监禁,监督,监视;v:抵挡,收容,挡,守护",
"ward off":"v:搪,抵挡,御,架,挡,辟",
"warden":"n:保管人,会长,区长,校长,院长,保管员,县长,州长",
"warder":"n:卫兵,守卫,保管员,看守,狱吏",
"wardrobe":"n:衣橱,衣柜,床头柜,立柜",
"ware":"v:留心,当心,小心,注意;n:商品,器皿,货品;a:谨慎,知道",
"warehouse":"n:仓库,货栈,栈房,仓房,堆栈,库,栈,寄存处",
"warehouseman":"n:批发商",
"wares":"n:商品",
"warfare":"n:战争,斗争,冲突,作战,战,仗",
"warhead":"n:弹头",
"warily":"d:小心翼翼",
"wariness":"n:戒心,警惕,小心,注意,谨慎",
"warlike":"a:好战,黩武,战争,军事",
"warlock":"n:魔术师,骗子",
"warlord":"n:军阀,督军",
"warm":"a:温暖,暖和,热烈,热,暖,热情,温;v:激发,亲热,热身,同情,示警,鼓励,热中,熏,焐,占;n:暖色",
"warm up":"v:暖和,热,焐,暖,热身,预热,温",
"warm-up":"n:预热,加热,热身,加温",
"warmblooded":"v:预热",
"warmed":"a:亲热",
"warmer":"n:加热器,取暖器",
"warmhearted":"a:热情,热心,热烈,亲热,热",
"warmheartedness":"a:热忱;n:热肠",
"warmly":"d:热烈,热情",
"warmness":"n:冷暖",
"warmonger":"n:战争贩子",
"warmth":"n:温暖,热情,亲切,暖和,暖,兴奋,诚恳,热心",
"warn":"v:警告,提醒,告诫,叮嘱,预告,打招呼,戒,示警,叮咛,儆,警戒,告戒,诫,警,训诫;n:申饬",
"warning":"n:警告,警报,鉴戒,告诫,预告,前兆,通知,号召,殷鉴,召唤,闻者足戒,训诫,警戒;v:警告",
"warp":"n:经线,乖戾,经纱,偏见;v:偏,卷曲,歪;p:经",
"warping":"v:放淤,淤灌;n:淤灌",
"warrant":"n:收据,搜查证,根据,保证,理由;v:断定",
"warrant officer":"n:准尉",
"warranty":"n:保单,根据,保证,理由,授权",
"warren":"n:大杂院",
"warring":"v:交战,敌对",
"warrior":"n:战士,武士,勇士,军人,斗士,壮士,武夫",
"warsaw":"n:华沙",
"warship":"n:军舰,战舰,战船,舰只,兵船,舰艇,舰,兵舰,舰船",
"warships":"n:舰只",
"wart":"n:瘊子,疣,瘊,肉赘,薷,赘疣",
"wartime":"n:战时",
"wary":"a:小心,谨慎,小心翼翼;v:是",
"wash":"v:洗,洗掉,洗手,冲洗,洗涤,冲走;n:冲击,水墨画,涡流,香水,洗濯;a:水洗",
"wash away":"v:清洗,洗刷,冲,荡涤,涤荡",
"wash down":"v:洗掉",
"wash drawing":"v:水墨画,水彩画",
"wash off":"v:洗掉,洗刷",
"wash one's hands":"v:净手",
"wash out":"v:冲刷,放弃,刷洗",
"washbasin":"n:洗脸盆,脸盆",
"washboard":"n:洗衣板,搓板",
"washbowl":"n:脸盆,洗脸盆",
"washcloth":"n:浴巾,毛巾",
"washed-out":"a:褪色",
"washer":"n:垫圈,洗涤器,洗衣机,衬垫",
"washing":"n:洗,洗涤;a:水洗;v:洗净",
"washing machine":"n:洗衣机",
"washing soda":"n:苏打",
"washington":"n:华盛顿",
"washout":"v:洗净;n:洗净",
"washroom":"n:盥洗室,厕所,厕",
"washstand":"n:脸盆架",
"washy":"a:淡,稀薄",
"wasp":"n:黄蜂,蚂蜂,马蜂,胡蜂,蜂",
"waspish":"a:黄蜂",
"wassail":"v:干杯,痛饮,欢宴,祝酒;n:欢宴,酒宴,宴会",
"wastage":"n:损耗,耗损,浪费,消耗,废料,废墟,荒地,消耗量,废物,损失;v:耗损,流失",
"waste":"v:浪费;n:损耗;a:糜费,靡费,旷",
"waste material":"n:废料",
"waste matter":"n:废物,糟粕",
"waste paper":"n:废纸",
"waste product":"n:废物",
"wasteful":"a:浪费,挥霍,糜,侈,奢侈,大手大脚,费,奢靡,靡",
"wasteland":"n:荒地,荒原,荒漠,废墟,荒野,莱,荒",
"wastepaper":"n:纸屑,废纸",
"wastepaper basket":"n:字纸篓",
"waster":"n:废品,废物",
"wasting":"n:糟蹋,消耗,浪费;a:消瘦",
"wastrel":"n:饭桶,废物,废品,浪子,败家子",
"wat":"n:寺院",
"watch":"v:看;n:鼓,守夜",
"watch fire":"v:营火",
"watch glass":"v:表蒙子",
"watch guard":"v:表带,表链",
"watch out":"v:看,警戒,注意",
"watch over":"v:看守,留心",
"watchband":"n:表带",
"watchdog":"n:监视器",
"watcher":"n:哨兵",
"watchful":"a:注意,观察,惕,警戒",
"watchfulness":"n:警惕心",
"watchman":"n:更夫,警卫员",
"watchtower":"n:碉楼,岗楼,了望塔,望楼,堠,谯,谯楼",
"watchword":"n:口号,口令,暗号,暗语,标语",
"water":"n:水,水面,河,洪水,水域;v:垂涎,给水",
"water buffalo":"n:水牛",
"water cabbage":"n:水浮莲",
"water caltrop":"n:菱角,菱",
"water cart":"n:洒水车",
"water clock":"n:漏刻,漏,滴漏",
"water closet":"n:盥洗室,厕所",
"water cooler":"n:冷却器",
"water down":"v:冲淡",
"water fennel":"n:水芹",
"water flea":"n:水蚤",
"water gage":"n:水标,水压",
"water gate":"n:闸门",
"water gauge":"n:水表",
"water glass":"n:水玻璃",
"water heater":"n:热水器",
"water hole":"n:水坑,水池",
"water hyacinth":"n:水葫芦",
"water ice":"n:人造冰,刨冰",
"water lettuce":"n:水浮莲",
"water level":"v:水情,水准器",
"water lily":"n:睡莲",
"water meter":"n:水表",
"water mill":"n:水车",
"water parting":"n:分水岭",
"water pimpernel":"n:水绿",
"water pipe":"n:水管,水烟袋",
"water pistol":"n:水枪",
"water pollution":"n:水污染",
"water pump":"n:抽水机",
"water ski":"n:滑水",
"water snake":"n:水蛇",
"water supply":"n:供水,自来水",
"water system":"n:供水,河系",
"water tap":"n:水龙头",
"water vapor":"n:水汽,水蒸气",
"water vapour":"n:水汽,水蒸气",
"water wagon":"n:洒水车",
"water wheel":"n:水轮,水车",
"water-repellent":"a:防水",
"water-soluble":"a:水溶性",
"waterborne":"a:水上",
"watercolor":"n:水彩,水彩画",
"watercolour":"n:水彩",
"watercourse":"n:水流,河道,运河,水道,河,河床",
"watercraft":"n:船舶,船只",
"waterfall":"n:瀑布,瀑",
"waterfowl":"n:水鸟,水禽",
"waterfront":"n:水边",
"wateriness":"n:清淡",
"watering can":"n:喷桶,喷壶,水壶",
"watering place":"n:饮水处",
"waterless":"a:干",
"waterline":"n:水平线,水线,水印",
"waterlogged":"a:涝,淹,进水",
"waterloo":"n:滑铁卢,惨败",
"waterman":"n:船工",
"watermark":"n:水锈,水印",
"watermelon":"n:西瓜",
"waterproof":"n:雨衣;v:防水;a:防水",
"waters":"n:领海,水流,水域",
"watershed":"n:分水岭,流域",
"waterside":"n:水边",
"waterspout":"n:水龙卷,水落管,水柱,暴雨",
"watertight":"a:滴水不漏,水泄不通",
"waterway":"n:水道,水路,航道,航路,排水沟",
"waterways":"n:河渠",
"waterwheel":"n:水轮,水车",
"watery":"a:浅,淡,稀,湿",
"watt":"n:瓦特,烛,瓦",
"wattle":"n:肉垂,金合欢,篱笆,枝条,触须",
"waugh":"n:沃",
"wave":"v:挥手;n:风潮,波纹,海波,水体,高潮",
"wave form":"n:波形",
"wave front":"n:波峰",
"wave guide":"n:波导管",
"wave off":"n:赶走",
"wave shape":"n:波形",
"waveband":"n:波段,频带",
"waveform":"n:波形",
"wavelength":"n:波长",
"wavelet":"n:涟漪",
"waver":"v:动摇,犹豫不决,摇摆,游移,徘徊,闪动,优柔寡断,颤动,踟蹰,两边倒,摇摆不定;n:犹豫",
"wavering":"v:优柔寡断",
"wavy":"a:鬈,潋滟,摇摆",
"wax":"n:蜡,火漆;v:打蜡,上蜡,击败,盛衰,灌,增大",
"wax crayon":"n:蜡笔",
"wax insect":"n:白蜡虫",
"wax myrtle":"n:杨梅",
"waxen":"a:蜡黄",
"waxiness":"n:蜡质,柔顺",
"waxing":"v:上蜡,唱片,打蜡;n:唱片,上蜡",
"waxwork":"n:蜡人,蜡像",
"way":"n:方式,方法,办法,路,方面,样子,道路,途中,途径,前进,情况,进行,习惯,手段,方向,做法,道,点,距离,决心,法子,通道,法,路线,街道,作风,地区,方,路程,路途,路子,门路,方针,路径,附近,行业,风气,蹊径,式样,途,门径,途程,路道,辙,道道儿;v:除去",
"way out":"v:活路,出路,生路",
"way-out":"a:抽象",
"waybill":"n:货单",
"wayfarer":"n:旅客,行旅",
"wayfaring":"n:旅行",
"waylay":"v:伏击,拦路抢劫",
"ways":"n:滑道",
"wayside":"n:路边,路旁",
"wayward":"a:任性,刚愎,古怪",
"we":"r:我们,我,咱们,人们,你我,俺们,吾人,吾,伲,我辈,吾辈,吾侪,俺,寡人;n:我辈;d:咱",
"weak":"a:弱,虚弱,软弱,薄弱,衰弱,微弱,软,淡,脆弱,懦弱,单,虚,柔弱,绵软,薄,酥,清淡,乏力;v:耍",
"weak force":"n:枯木朽株,一手一足",
"weak point":"n:短处,缺点,弱项,短",
"weak spot":"n:弱项,疵点,弱点",
"weak-kneed":"a:软弱",
"weaken":"v:削弱,衰弱,减弱,疲软,弱化,冲淡,衰减,铄,杀,煞,减杀;a:衰弱",
"weakened":"a:疲软",
"weakening":"n:衰减,削减,阻尼;v:阻尼,衰减",
"weakling":"n:懦夫",
"weakly":"d:有气无力",
"weakness":"n:弱点,软弱,缺点,弱,虚弱,衰弱,短处,薄弱,懦弱,嗜好,柔弱,怯懦,看跌,优柔寡断;a:虚弱",
"weal":"n:福利,伤痕,幸福",
"wealth":"n:财富,幸福,财产,钱,大量,富裕,丰富,繁荣,富,财,钱财,财宝,丰饶,赀,福利;a:富",
"wealthy":"a:富有,有钱,富,阔,丰富,阜",
"wealthy man":"n:阔老",
"wean":"v:断奶,拉开",
"weaning":"v:断奶",
"weapon":"n:武器,兵器,铁,战具,器械;v:武装",
"weaponry":"n:仗,兵器",
"weapons":"n:兵,刀枪,兵戈,刀兵,仗,兵器,兵戎",
"wear":"v:穿,戴,磨损,穿着,留,穿上;n:穿戴,耐用,佩戴,穿着",
"wear away":"v:磨损,磨耗,磨灭,消逝,剥蚀",
"wear down":"v:磨,消损,消磨,磨耗",
"wear off":"v:磨损,消损",
"wear on":"v:消逝",
"wear out":"v:累,磨损",
"wearable":"n:衣服;a:耐磨",
"wearied":"a:劳顿,疲乏",
"weariness":"n:疲倦,倦意",
"wearing":"v:磨损",
"wearing apparel":"n:衣服,服装",
"wearisome":"a:劳",
"weary":"a:厌倦,疲乏;v:疲乏",
"weasel":"v:躲闪,支吾,避免,告密,躲避;n:青鼬",
"weasel word":"n:含糊其词",
"weather":"n:天气,天,气候,气;v:通风,剥蚀",
"weather chart":"n:天气图",
"weather eye":"n:留神",
"weather map":"n:天气图",
"weather-beaten":"a:饱经风霜",
"weathering":"v:风化;n:风化",
"weave":"v:打,结,盘绕,组合;n:纺织;a:针织",
"weaving":"n:织布;v:织布",
"web":"n:网,蜘蛛网,布,织物,腹部,网络,膜,万维网",
"web page":"n:网页",
"webbing":"n:带子",
"webfoot":"n:蹼足",
"website":"n:站点,网站",
"wed":"v:结婚,娶,嫁,婚嫁;n:婚嫁",
"wedded":"a:死守,结婚",
"wedding":"n:婚礼,结婚,婚,婚事,喜事,婚宴,洞房花烛,结合",
"wedding day":"n:吉期,佳期,吉日",
"wedding party":"n:婚礼",
"wedge":"v:揳,揢,劈;n:楔",
"wedge-shaped":"a:楔形",
"wedlock":"n:结婚,婚姻",
"wednesday":"n:礼拜三,周三",
"wee-wee":"v:撒尿,小便",
"weed":"n:杂草,野草,草;v:清理,菑,拔草,除去",
"weed out":"v:攘除,除去,除草,芟",
"weeding":"v:除草",
"weeds":"n:杂草,蔓草,野草",
"weedy":"a:杂草丛生",
"week":"n:星期,周,礼拜,工作日",
"weekday":"n:周日",
"weekend":"n:周末",
"weekly":"n:周报,周刊",
"weep":"v:哭,哭泣,流,泣,哀悼,流泪,落泪,哭鼻子,渗出,叹息;n:渗出,流泪",
"weeping":"a:哭泣,流泪",
"weepy":"a:眼泪汪汪",
"weevil":"n:象鼻虫",
"weft":"n:织物,信号,纬,纬线,信号旗,纬纱",
"wei":"n:魏,渭,韦",
"weigh":"v:重,称,压,权衡,掂量,重要,估量,秤,量,估计,测量,斟酌,约,衡量,坠,起锚,过磅,推敲,志,吃重;n:权,衡量,志",
"weigh anchor":"v:起航",
"weigh down":"v:压,坠",
"weighbridge":"n:台秤,地秤,地磅",
"weight":"n:重量,体重,重,分量,重物,权,影响,影响力,砝码;v:量,偏袒,强调;a:肥胖",
"weight down":"v:头重脚轻",
"weighted":"v:加权",
"weightily":"d:重",
"weightiness":"n:重",
"weighting":"v:加权,加重",
"weightless":"a:失重,无足轻重",
"weightlessness":"n:失重",
"weighty":"a:重要,鼎;n:千斤",
"weiqi":"n:围棋",
"weir":"n:坝,堰,汕",
"weird":"a:离奇,可怕;n:预言",
"weirdo":"n:怪人",
"welcome":"v:欢迎;n:款待;a:香",
"weld":"n:结合;v:焊",
"welder":"n:焊工,焊机",
"welding":"v:焊接,固化;n:焊工,焊接",
"welfare":"n:福利;a:福利",
"welkin":"n:高空,天空",
"well":"n:井;d:优待;a:好;i:那么,这个,嗳,好,咦,后来,可是,唉,至于,啊,哎呀;v:涌",
"well out":"p:涌出",
"well-advised":"a:审慎",
"well-balanced":"a:匀称",
"well-behaved":"a:乖",
"well-being":"n:福祉",
"well-chosen":"a:精选,恰当",
"well-defined":"a:明确",
"well-dressed":"a:衣冠楚楚",
"well-fed":"a:饱暖",
"well-heeled":"a:富有,发迹",
"well-intentioned":"a:善意",
"well-knit":"a:健壮",
"well-known":"a:著名,有名,妇孺皆知,成名;v:饮誉",
"well-lined":"a:装满",
"well-made":"a:匀称",
"well-marked":"a:显眼",
"well-off":"a:富裕",
"well-read":"a:博览群书",
"well-rounded":"a:成熟",
"well-to-do":"a:宽裕",
"wellhead":"n:泉源,井口,源泉,水源",
"wellington":"n:惠灵顿",
"wellspring":"n:源泉,水源,泉源",
"welsh":"n:威尔士;v:逃避",
"welt":"n:岗,沿条儿,鞭打,滚边,岗子,贴边;v:隆起,鞭打",
"welter":"v:打滚,浸,滚,混乱,挣扎;n:动摇,翻腾,纷扰,打滚,混乱",
"wen":"n:瘤,粉瘤,温",
"wench":"n:女仆,少女,荡妇,女工,少妇,妓女",
"wend":"v:走,往,去,行",
"wept":"v:是",
"werewolf":"n:是",
"west":"n:西方,西,西部,西边,西面,西部片,西点,右",
"west point":"n:西点",
"westerly":"n:西风;a:西",
"western":"n:西部片,西,欧美;a:西部,西",
"western hemisphere":"n:西半球",
"westernization":"v:西化;n:洋务",
"westernize":"v:西化,欧化",
"westminster":"n:议会",
"westward":"n:西方",
"westwards":"n:西方",
"wet":"n:湿气,雨天,液体,饮酒;a:湿漉漉;v:湿",
"wet dream":"n:梦遗",
"wet nurse":"n:嬷,奶娘,乳母,嬷嬷,姆,奶妈",
"wet-nurse":"v:奶",
"wetness":"n:湿润,水分,雨天,雨水",
"wetting":"n:润湿,湿,沾化",
"whack":"n:试;v:分配",
"whacked":"a:疲惫不堪",
"whacking":"d:非常,极;n:殴打",
"whale":"v:捕鲸;n:庞然大物",
"whale shark":"n:鲸鲨",
"whalebone":"n:鲸须",
"whaling":"n:捕鲸;v:捕鲸",
"whammy":"n:诅咒,晦气",
"wharf":"n:码头,船埠,埠,埠头",
"what":"r:什么,什麽;d:好不,好容易,多么,何等,何其,甚,怎样;i:啊,哦,哦呀;a:底,嚄;n:底",
"what for":"n:为什么,干吗",
"what is more":"d:何况,而且",
"what with":"p:由于,因为",
"whatever":"r:什么,无论,任何,什麽;a:不拘;c:不拘",
"wheal":"n:水疱,红肿,风疹块,矿井",
"wheat":"n:小麦,麦子,麦,生手,麦草",
"wheat flour":"n:面,白面儿,白面,面粉",
"wheaten":"a:小麦",
"wheedle":"v:哄,甜言蜜语,骗",
"wheel":"n:轮子,车轮,轮,旋转;v:轮转,转动,回翔,推动,开动,转弯",
"wheel horse":"n:辕马",
"wheel spoke":"n:轮辐",
"wheelbarrow":"n:手推车,小车,独轮车,手车",
"wheelbase":"n:轴距",
"wheelchair":"n:轮椅",
"wheelhouse":"n:驾驶室",
"wheeling":"v:旋转",
"wheeze":"n:笑话;v:喘息",
"wheezy":"a:喘息",
"whelk":"n:海螺,面疱",
"whelm":"v:沉没,压倒,淹没",
"whelp":"n:崽子,小鬼,仔;v:计划,生",
"when":"r:几时,多会儿,多早晚,几儿,何日,哪会子,咱,哪会儿,多咱,何时;c:却;n:时候;d:什么时候;v:每逢;p:当",
"whence":"n:根源,来源;d:为什么",
"whenever":"c:随时,每当__就__;r:哪会儿;v:每逢;p:每当",
"where":"r:何方,何处,哪儿,哪里;n:地点;v:何在;d:哪里",
"whereabouts":"n:下落,行踪,去处,去向,着落;d:落;v:落",
"whereas":"c:而,却,倒,但是,反过来,然而,反之,其实",
"whereby":"d:怎么,怎样,由此",
"wherefore":"n:原因,理由;d:所以,何以",
"whereof":"d:那个,什么的",
"whereupon":"c:因此",
"wherever":"r:哪儿,哪里;d:哪里,哪儿",
"wherewith":"d:用以",
"wherewithal":"n:资力,资金,手段",
"wherry":"n:轻舟",
"whet":"v:磨,刺激,助长,增强;n:激励,钢,研磨",
"whether":"c:不管,无论;v:是否",
"whetstone":"n:砺,砥,砥砺,磨刀石,油石",
"whey":"n:乳清",
"which":"r:哪;a:那个",
"whichever":"r:任何",
"while":"c:当;n:功夫;p:直到,趁着,趁,即;v:消;d:却,一边",
"while away":"v:消,打发,消磨",
"whiles":"c:有时",
"whilom":"d:曾经,以前,从前",
"whilst":"c:当",
"whim":"n:幻想,绞车,任性,绞盘,奇想,卷扬机",
"whimper":"v:抽噎,啼,呜咽,哀诉;n:呜咽",
"whimsical":"a:古怪,异想天开,想入非非;v:随心所欲,异想天开",
"whimsicality":"n:想入非非",
"whimsically":"d:随心所欲",
"whimsy":"n:奇想,异想天开",
"whine":"n:哀诉,牢骚;v:哀诉",
"whinny":"v:咴儿咴儿,嘶;n:萧萧",
"whip":"v:打败,逃走,搅拌,缠,鞭挞,鞭策,超过,攻击,督促,扇动,凌驾,驱使;n:马车夫,鞭",
"whip hand":"v:优势,右手",
"whip up":"v:扇动",
"whip-round":"n:捐款",
"whipcord":"n:马裤呢",
"whiplash":"n:击打,鞭打",
"whipping":"n:鞭打,惩罚,打败;v:抖动",
"whipping boy":"n:替罪羊",
"whipping top":"n:陀螺",
"whippoorwill":"n:夜鹰",
"whir":"n:呼呼",
"whirl":"v:旋转;n:环,涡流",
"whirligig":"n:循环,陀螺",
"whirling":"v:涡流,湍流,扑朔迷离;n:湍流,涡流;a:婆娑",
"whirlpool":"n:漩涡,旋涡,纷乱,混乱,洑,涡",
"whirlwind":"n:旋风;v:扶摇",
"whirlybird":"n:直升飞机,直升机",
"whisk":"v:搅拌,摇,拂,挥动,飞跑,拂拭;n:掸,拂,搅拌器,掸帚",
"whisk broom":"n:笤帚",
"whisk off":"v:拂拭",
"whisker":"n:连鬓胡子,胡须,络腮胡子,触须,掸帚,下巴颏儿",
"whiskers":"n:胡须,络腮胡子,落腮胡子,连鬓胡子",
"whiskey":"n:威士忌,威士忌酒",
"whisking":"v:扫",
"whisky":"n:威士忌,威士忌酒",
"whisper":"v:悄悄;n:私话,密谈;d:咕噜,喳喳",
"whispering":"n:流言蜚语,耳语,窃窃私语;v:耳语",
"whispering campaign":"n:流言蜚语",
"whist":"n:静,嘘",
"whistle":"n:哨子,汽笛,哨;v:啸鸣",
"whit":"n:丝毫",
"white":"n:白色,蛋白,怀特,洁白,霜;a:刷白,粉,白乎乎,白不呲咧,皑,白不拉几",
"white arsenic":"n:砒",
"white book":"n:白皮书",
"white corpuscle":"n:白血球,淋巴液",
"white elephant":"n:赘疣",
"white flag":"n:降旗",
"white gold":"n:金属",
"white heat":"n:白热化",
"white horse":"n:白马",
"white house":"n:白宫",
"white lead":"n:铅白,铅粉",
"white line":"n:威士忌酒,空行",
"white man":"n:白人",
"white matter":"n:白质",
"white mulberry":"n:桑",
"white paper":"n:白纸",
"white pine":"n:雪松",
"white plague":"n:结核,肺结核",
"white poplar":"n:白杨树",
"white potato":"n:土豆,马铃薯",
"white water":"n:清流",
"white whale":"n:白鲸",
"white wine":"n:白葡萄酒",
"white-collar":"n:白领阶层;a:白领",
"white-hot":"a:白热",
"white-livered":"a:懦弱",
"whitebait":"n:银鱼",
"whitefish":"n:白鲸,白鱼",
"whiten":"a:刷白;v:漂白",
"whitener":"n:漂白剂",
"whiteness":"n:白",
"whitening":"n:白垩,漂白,白粉",
"whites":"n:白带,带",
"whitewash":"v:粉刷,粉饰,涂脂抹粉;n:香粉,粉",
"whitewashed":"a:粉;v:粉",
"whiting":"n:白垩,白粉",
"whitsunday":"n:圣灵降临节",
"whittle":"v:削减,削,切,削瘦,减少,损害;n:屠刀",
"whittle away":"v:削,切",
"whittle down":"v:削,切",
"whiz":"n:能手,嘘,专家,同意;v:嗖",
"whizz":"n:嘘,专家;v:呼啸",
"who":"r:谁,哪个,哪些,何人,何许人,孰,谁个",
"whodunit":"n:侦探小说",
"whoever":"r:谁",
"whole":"a:整个,一,全,整;n:全部,全体,总体,完整;d:竟,整整;v:举,合,完",
"whole blood":"n:纯种",
"whole note":"n:全音符",
"whole number":"n:整数",
"whole step":"n:全音",
"whole tone":"n:全音",
"wholehearted":"a:全心全意,一,赤胆忠心,真心,衷心",
"wholeheartedly":"d:全心全意,一心一意,尽力;a:真心诚意",
"wholeheartedness":"n:真心诚意,诚心,赤胆忠心,真心",
"wholeness":"n:完整性,完全,全体,一切",
"wholesale":"a:批发;d:完全,趸批;v:批;n:批发",
"wholesaler":"n:批发商",
"wholesome":"a:健康,卫生,健",
"wholly":"d:完全,全部,十足,万万,一并,通统,统;a:完全;v:统",
"whom":"r:谁",
"whoop":"v:引起,高呼,呐喊,高喊,哄抬,宣扬;n:高呼,些微,呐喊,大叫,高喊",
"whoopee":"i:狂欢",
"whooping cough":"n:百日咳",
"whop":"v:打,打垮,打败",
"whopper":"n:庞然大物,弥天大谎",
"whopping":"a:非常,巨大;n:打;d:非常",
"whore":"n:婊子;v:卖淫",
"whorehouse":"n:妓院",
"whorl":"n:轮,螺纹",
"why":"d:为什么,为何,何必,何以;r:为什么,怎地,为何,咋,怎,怎的;i:哎呀,哎,咦,啊,当然;n:理由;v:争;c:之所以",
"wick":"n:灯心,灯芯,导火线,村,捻子,镇,芯子",
"wicked":"a:邪恶,缺德,坏,恶,贼;n:贼",
"wickedness":"n:恶;a:恶",
"wicker":"n:柳丝,柳条,枝条",
"wicker basket":"n:栲栳",
"wickerwork":"n:柳编",
"wicket":"n:边门,便门,窗口,售票口,闸门",
"wicket door":"n:边门,闼,便门",
"wicket gate":"n:边门",
"wide":"a:宽,广,广阔,宽阔,开阔,广大,广博,宽大,空旷,阔,博大,淹,宽旷;v:淹",
"wide screen":"n:宽银幕",
"wide-angle":"a:广角",
"wide-angle lens":"n:广角镜头",
"widely":"d:广泛,广;a:广",
"widen":"v:扩大,加宽,开阔,放宽",
"widespread":"a:广泛,普遍;v:盛",
"widow":"n:寡妇,遗孀,孀妇,嫠妇,孤孀;v:分离",
"widowed":"v:守节",
"widower":"n:鳏夫,鳏",
"widowhood":"n:寡,守寡",
"width":"n:宽度,宽狭,门面,广阔,宽窄;a:宽",
"wield":"v:行使,掌握,运用,挥舞,祭,支配,统治,振,用,执,使用,舞弄,执掌,舞,运,挥",
"wife":"n:妻子,老婆,夫人,女人,妻,妻室,妇,内助,屋里人,浑家,元配,爱人,内当家,中馈,娘儿们,家眷,婆姨,脚镣,家室,内子,婆娘,室,堂客,媳妇儿",
"wifely":"a:妻子",
"wig":"n:假发,头,知识分子,责骂,海狗,头脑;v:发疯,痛骂,发狂,激动",
"wigging":"n:责备",
"wiggle":"v:扭动,摆动;n:扭动",
"wiggler":"n:孑孓",
"wight":"n:鬼怪,动物,妖精",
"wigwag":"v:打,摇摆,摇动,摆动",
"wild":"a:野生,野,狂,狂暴,野蛮,荒凉;n:荒野,荒地",
"wild boar":"n:野猪",
"wild cabbage":"n:甘蓝",
"wild cotton":"n:苘麻",
"wild duck":"n:凫,野鸽",
"wild flower":"n:野花",
"wild horse":"n:烈马",
"wild man":"n:野人",
"wild rice":"n:菰,稆",
"wild-eyed":"a:激进",
"wildcat":"n:山猫,野猫,猞猁",
"wildebeest":"n:羚羊",
"wilder":"v:困惑,迷途,迷失,迷惑",
"wilderness":"n:荒野,荒原,旷野,荒地,野地,草莽,荒郊,许多,荒漠",
"wildfire":"n:野火,磷火,闪电,鬼火",
"wildflower":"n:野花",
"wilding":"n:野兽",
"wildly":"d:不成体统",
"wildness":"n:野蛮,撒野",
"wile":"n:诡计;v:诱骗",
"wilful":"a:故意,执拗,任性",
"wilfully":"d:任意",
"wiliness":"n:诡计多端,狡猾",
"will":"n:决心,愿望,志气,志愿,意旨,希望,志,心地,心志,志向,心意,遗命;v:遗赠",
"willful":"a:任性,随便,执拗,恣意",
"willfully":"d:肆意,随心所欲,故意",
"willing":"n:愿意;a:甘心情愿",
"willingly":"d:甘心,甘愿,愿心,自,乐",
"willingness":"n:情愿",
"willow":"n:柳树,柳枝,杨柳,柳",
"willowy":"a:袅娜",
"willpower":"n:毅力",
"wilt":"v:枯萎,萎蔫,凋谢,衰弱",
"wilting":"v:萎蔫",
"wily":"a:诡计多端;n:贼",
"wimp":"n:畏缩不前,窗口",
"wimple":"n:微波,涟漪,弯曲;v:摇动",
"win":"v:赢得,赢,获胜,获得,胜利,胜,争取,取胜,获,取得,博得,得胜,夺得,成功,说服;n:成功",
"win over":"v:胜诉,争取,拉",
"wince":"v:畏缩;n:畏缩,退缩",
"winch":"n:绞车,曲柄,绞盘",
"wind":"v:绕;n:绞车,管乐器;a:卷绕",
"wind bell":"n:风铃",
"wind gauge":"n:风速计",
"wind instrument":"n:管乐器",
"wind off":"n:解开,开放",
"wind scale":"n:风级",
"wind tunnel":"n:风洞",
"wind up":"v:了结,煞尾,收场,脱稿,关门大吉,终结",
"windbag":"n:经受,气囊,遭受,肺,风箱",
"windbreak":"n:防风林,防风,风障,风衣",
"windburn":"n:风害",
"winder":"n:绞车,猛击",
"windfall":"n:横财,外快",
"windflower":"n:白头翁",
"windiness":"n:多嘴,大话,空谈",
"winding":"a:弯弯曲曲,弯曲,曲折;n:线圈",
"windjammer":"n:帆船",
"windlass":"n:绞盘,卷扬机,辘轳,绞车",
"windmill":"n:风车,螺旋桨;v:自转",
"window":"n:窗户,窗,窗子,窗口,橱窗,窗框,眼镜,牖",
"window frame":"n:窗棂",
"window screen":"n:纱窗",
"window shade":"n:窗帘,百页窗",
"windowpane":"n:玻璃板",
"windowsill":"n:窗沿,窗台",
"windpipe":"n:气管",
"windproof":"a:防风",
"windscreen":"n:风挡",
"windshield":"n:风挡",
"windstorm":"n:风暴,暴风",
"windup":"n:结局,结束,完结,终结",
"windward":"n:上风,逆风,迎风;v:迎风;d:迎风",
"windy":"a:刮风",
"wine":"n:酒,葡萄酒,美酒,酒会,酿,果酒,黄酒,烈酒,老酒;v:酿,喝酒",
"wine bottle":"n:酒瓶",
"wine cellar":"n:酒窖",
"wineglass":"n:酒杯",
"winery":"n:酒厂,糟行",
"wing":"n:翅膀,机翼,翼,翅,飞翔,天使,飞行,边锋;v:飞跑",
"wingding":"n:狂怒",
"winged":"a:飞翔",
"winged spindle tree":"n:卫矛",
"wingspan":"n:翼展",
"wink":"v:眨眼,眨,使,使眼色;n:小睡",
"wink at":"v:递眼色,纵容",
"winker":"n:眼睛,眼罩,眼睫毛",
"winking":"v:眨眼",
"winkle":"v:闪耀,闪烁,剔出,逐出",
"winner":"n:优胜者,胜利者,得主",
"winning":"n:赢得,获胜,奖金,成功,奖品;v:优胜",
"winnow":"v:吹散,甄别,精选;n:风",
"winnower":"n:扇车,风车",
"winnowing":"n:扬场;v:扬场",
"wino":"n:酒鬼",
"winsome":"a:可爱,迷人",
"winsomeness":"n:魅力",
"winter":"n:冬天,冬季;v:越冬",
"winter solstice":"n:冬至",
"winter squash":"v:南瓜",
"winter sweet":"n:腊梅",
"wintertime":"n:冬天,冬季,冬",
"wipe":"v:擦,消灭;n:拭",
"wipe away":"v:擦掉,抹掉",
"wipe off":"v:挥,还清,消除,抹",
"wipe out":"v:灭,洗雪,一笔勾销,诛灭,攻歼,剪,擦洗,剿除,犁庭扫穴,扑灭,消灭,雪,遮蔽,铲除,锄,剪灭,吃,封闭,剿灭,炸毁,治,涤荡,湔,扫荡,报销,打掉,勾销,清除,扫除,一扫而光,夷",
"wiper":"n:手巾,凶手,毛巾",
"wire":"n:电线,线,导线,铁丝,钢丝,电,线路,电报,铜丝;v:接线",
"wire cloth":"n:铁纱",
"wire gauge":"n:线规",
"wired":"a:有线",
"wireless":"n:无线电;a:无线",
"wiretap":"n:窃听器;v:窃听",
"wiring":"n:线路,接线;v:接线",
"wisdom":"n:智慧,聪明,学问,才智,知识,学识,智力,智,名言,哲,慧心",
"wisdom tooth":"n:智牙,智齿",
"wise":"a:明智,英明;n:程度,方法,方式;v:懂得,方式,引导",
"wise man":"n:智者,哲",
"wise men":"n:先贤",
"wisecrack":"n:妙语,俏皮话;v:谐谑;a:谐谑",
"wiser":"a:智者",
"wish":"v:希望,想,要;n:欲望,意思,意旨,请求",
"wishful":"a:渴望,想望,希望",
"wishful thinking":"n:一厢情愿,异想天开,痴想,妄想,想入非非",
"wishing":"v:愿望",
"wishy-washy":"a:软弱无力",
"wisp":"n:缕,束,把,股",
"wisteria":"n:紫藤",
"wistful":"a:渴望,想望",
"wit":"n:智慧,风趣,头脑,妙语,才智,智力;v:知道",
"witch":"n:巫婆,女巫;v:迷惑",
"witch doctor":"n:巫医",
"witchcraft":"n:巫术,魔法,妖术,魅力",
"witchery":"n:巫术,妖术,诱惑力,魔力,魅力,魔法",
"with":"p:和,用,与,对,跟,以,一起,同,把,将,因,具有,由于,拿,对于,关于,带有,赞成,身边,一边,虽,顺着,连同,顺,会同,与_一起,与共,在_身边,在_一边;v:带有",
"with a view to":"p:着眼于,考虑到",
"with an eye to":"p:着眼于,考虑到",
"with reference to":"p:关于",
"with regard to":"p:对于,关于,就,至于",
"with regards to":"p:关于",
"with relation to":"p:关于",
"with respect to":"p:关于",
"with the exception of":"p:除_以外,以外",
"with the intention of":"p:打算,企图",
"with the object of":"p:为了",
"with the purpose of":"p:为了",
"with the view of":"p:为了",
"withal":"d:此外,加之,然而,同时,而且,又;p:以,用",
"withdraw":"v:撤回,收回,退出,撤退,撤销,退,抽出,撤离,取消,撤,缩,回收,提取,缩回,退却,脱离,打消,取回,吊销,退回,吊,注销,撤走,翻",
"withdrawal":"n:退出,撤销,提款,撤退,收回,退兵,戒除;v:退兵,戒除",
"withdrawn":"a:沉闷,孤独",
"withe":"n:柳条,藤条,枝条",
"wither":"v:枯萎,谢,干枯,萎缩,衰弱,枯,败,萎谢,损坏,凋零,破灭,减弱,衰亡,凋残,凋萎",
"withered":"a:枯;v:枯,干枯,枯萎,败",
"withering":"a:毁灭性,摧毁;n:枯干",
"withers":"n:感情",
"withhold":"v:扣留,截留,扣压,抑制,顶住,扣缴",
"withholdings":"v:抑制",
"within":"n:里面,之内,内,内部,以内,里边,其间;p:之内,以内,小于,在_之内;d:在内,内",
"within reach of":"p:附近,在_附近",
"within the reach of":"p:在_身边,身边",
"without":"p:不,没有,无,毫无,缺乏;n:外面,外部",
"without doubt":"p:毫无疑义,无疑,毋庸置疑,不惑,当然,无可置疑",
"without regard to":"p:不管,不顾",
"without respect to":"p:不管,不顾",
"withstand":"v:经受,抵挡,抗拒,抵抗,搪,顶住,招架,抵,架,抗击,抵御,反抗",
"witness":"v:表明,证实,表示,证,证婚;n:见证,证实,证",
"witness box":"n:证人席",
"witticism":"n:俏皮话,妙语,名言,趣话",
"wittiness":"n:机智",
"witting":"a:有意,知道;n:理解",
"wittingly":"d:故意,有意",
"witty":"a:机智,聪明,俏皮,古怪",
"wive":"v:娶",
"wizard":"n:术士,奇才,巫神,神巫;a:妙",
"wizardry":"n:法术,魔法,巫术,妖术",
"wizened":"a:枯槁,干瘪,枯萎,干巴;v:干枯",
"wobble":"v:晃动,游移,摆动,晃悠,摇摆;n:摇摆,晃动",
"wobbling":"v:摆动",
"woe":"n:苦恼,悲哀,祸,灾难,灾殃;i:哎呀,啊",
"woebegone":"a:愁眉苦脸",
"woeful":"a:不幸,悲郁,悲哀",
"wog":"n:病菌",
"wok":"n:镬,锅子",
"wold":"n:高原,荒原,山地",
"wolf":"n:狼,伪君子,饥饿,狼疮,色鬼",
"wolf's bane":"n:乌头",
"wolfhound":"n:狼狗,猎狗",
"wolfish":"a:豺狼成性,凶猛",
"wolfram":"n:钨",
"wolfram steel":"n:钨钢",
"wolverine":"n:狼",
"woman":"n:女人,妇女,女子,妇人,女,女性,情人,婆娘,妇道人家,情妇;a:女",
"womanhood":"n:女人,女性,成年期",
"womanish":"a:娘娘腔",
"womankind":"n:女人,女性,女子,妇女",
"womanly":"a:女式",
"womb":"n:子宫,宫,发源地,胎",
"women":"n:妇女,娘儿们,堂客,红粉,半边天;a:巾帼",
"womenfolk":"n:妇女,娘儿们,半边天,女人",
"won":"v:不成,不行",
"wonder":"n:奇迹,惊奇;v:惊奇,惊讶,纳闷儿,诧异,惊叹;a:古怪,奇,惊奇",
"wonder child":"v:神童",
"wonderful":"a:美妙,奇妙,妙,精彩,了不得,胜,神乎其神,神妙,带劲;v:胜",
"wonderland":"n:仙境",
"wonderment":"n:惊愕,惊奇,惊叹,奇迹,好奇心,奇观",
"wondrous":"d:非常;a:奇",
"wonk":"n:书呆子",
"wont":"a:习以为常;n:习惯",
"woo":"v:求婚,追求,求爱,拉拢,劝说,招致,恳求",
"wood":"n:木头,树林,木材,森林,木料,木柴,木,木板,木质,丛林,木棍,原木;a:愤怒",
"wood coal":"n:褐煤,木炭",
"wood engraving":"n:木刻画,木版画",
"wood pigeon":"n:斑鸠,野鸽,鹁鸪",
"wood shavings":"n:刨花",
"wood spirit":"n:甲醇",
"wood tar":"n:木焦油",
"woodbine":"n:忍冬",
"woodblock":"n:木块,版画",
"woodcarving":"n:木雕",
"woodchuck":"n:土拨鼠",
"woodcock":"n:山鹬",
"woodcraft":"n:森林学,木刻",
"woodcut":"n:版画,木刻画,木刻,木版画",
"woodcutter":"n:樵夫,樵",
"wooden":"a:木,木制,呆板,板,呆",
"wooden shoe":"n:木屐",
"wooden-headed":"a:笨拙",
"woodiness":"n:木质",
"woodland":"n:林地,树林",
"woodman":"n:樵夫,荛",
"woodpecker":"n:啄木鸟",
"woods":"n:森林,树林,树行子,林,林木,林子",
"woodsy":"a:森林",
"woodwind":"n:木管乐器",
"woodwind instrument":"n:竹",
"woodwork":"n:木工",
"woodworker":"n:木工",
"woody":"a:木本,木质",
"woody plant":"n:木本植物",
"woof":"n:纬线,织物,质地,组织,纬纱,布,低调,纬,低音",
"wool":"n:羊毛,毛线,毛,棉花,毛织品,绒毛,呢绒,绒线",
"wool grass":"n:蒯",
"woolen":"a:羊毛,毛线,呢绒",
"woolens":"n:毛织品,毛料",
"woolgathering":"n:出神,空想",
"woollen":"n:毛织物,毛线,毛织品",
"woolly":"n:毛衣",
"woolly mammoth":"n:毛象",
"woozy":"a:头昏眼花",
"word":"n:话,词,字,单词,言语,信,消息,诺言,歌词,词儿,命令,台词;v:说",
"word for word":"n:逐字逐句,逐字",
"word meaning":"n:词义",
"wordage":"n:字数,措词,文字,冗长",
"wordbook":"n:字书,词汇表,词典,字汇",
"wordiness":"n:多嘴",
"wording":"n:措辞,说法,措词,字,用语;v:措辞",
"wordless":"a:沉默",
"wordplay":"n:双关语,俏皮话",
"words":"n:唇舌,用语,语,笔墨,词,话,口舌,言词",
"wordy":"a:累赘,絮叨;v:絮叨",
"work":"v:工作;n:使役,做法",
"work animal":"n:役畜",
"work at":"n:做,从事,攻",
"work bench":"n:工作台",
"work day":"n:工作日,工日,平日",
"work force":"n:劳动力",
"work off":"v:除去",
"work on":"n:从事",
"work out":"v:拟订,编造,搞,设,用尽,起,拟定,制订,编制,达成",
"work song":"n:号子",
"work up":"v:激发,激动",
"work-shy":"a:懒汉",
"workable":"v:行得通,使得,落实;a:使得",
"workaday":"a:工作日",
"workaholic":"n:工作狂",
"workbench":"n:工作台",
"workbook":"n:说明书",
"workday":"n:工作日,劳动日",
"worker":"n:工人,工作者,工,职工,劳动者,劳工,技工",
"workers":"n:职工",
"workforce":"n:员工",
"workhorse":"n:驮马",
"workhouse":"n:感化院",
"working":"n:工作,作用,劳动,计算,驾驶,加工,维护,操作,运转;v:开挖,运行,加工",
"working class":"n:工人阶级",
"working day":"n:劳动日",
"working man":"n:工人",
"working-class":"a:工人阶级",
"workings":"n:运转",
"workload":"n:工作量",
"workman":"n:工人,工匠,技巧,制品,工作者,作品,劳动者,工,男丁",
"workmanship":"n:工艺,手艺,做工,功夫",
"workmate":"n:搭档,同事",
"workout":"n:锻炼,测验",
"workpiece":"n:工件,制件",
"workplace":"n:车间,工厂",
"workroom":"n:工作室",
"works":"n:作品,著作,工厂,机件,厂,论著,书籍,功德",
"worksheet":"n:工作单",
"workshop":"n:车间,研讨会,工场,作坊,厂房,作,坊,讨论会",
"workstation":"n:工作站",
"worktable":"n:工作台",
"world":"n:世界,世上,地球,天地,人类,大量,世俗,宇宙,世间,天体,万物,世面,世故,世事,人事,世态,坛,界,凡人,现世",
"world cup":"n:世界杯",
"world view":"n:宇宙观,世界观",
"world wide web":"n:万维网",
"world-shaking":"a:翻天覆地,石破天惊;v:翻天",
"world-weary":"a:厌世",
"worldly":"a:世间,尘世;n:世俗",
"worldwide":"a:全球性",
"worm":"n:蠕虫,虫,虫子,痛苦,螺线;v:排挤",
"worm wheel":"n:涡轮",
"wormwood":"n:艾,苦恼,蘩,蒿子",
"worn":"a:旧;v:破损",
"worn out":"a:疲乏,磨损,筋疲力尽,精疲力尽,精疲力竭",
"worn-out":"a:破旧,废旧;v:磨损",
"worried":"a:着急,不安,焦急,烦恼,焦;v:忧虑,搔;n:回肠",
"worriment":"n:忧虑,苦恼,烦恼,烦闷",
"worry":"v:担心;n:苦恼;a:急",
"worse":"n:失败,损失,不利;a:干",
"worsen":"v:恶化,损坏",
"worship":"v:崇拜;n:名誉,仰慕,威严,尊严",
"worshipful":"a:崇拜",
"worst":"v:打败,击败;d:最",
"worsted":"n:毛线",
"worth":"n:价值,值;a:值;p:值_钱",
"worthless":"a:一文不值,不稂不莠,不肖,不名一文,郎当;v:不名一文,一文不值,不稂不莠;n:郎当",
"worthwhile":"a:值得,划得来,合算,上算",
"worthy":"n:贤人,贤达,名人",
"would":"v:打算,将,或许,肯,愿意,似乎",
"would-be":"a:所谓,自称",
"wound":"n:伤口,伤,创伤;v:创",
"wound up":"v:结束",
"wounded":"a:伤员,伤兵",
"wounds":"n:伤口",
"wove":"v:布纹",
"wow":"n:颤动;i:哦",
"wrack":"n:破坏,灭亡,毁坏,残败,雾气,毁灭,海草,水气;v:摧毁,毁坏",
"wraith":"n:幻影,阴魂,鬼魂,鬼",
"wrangle":"v:争吵;n:争吵,口角,纷争,拌嘴",
"wrap":"v:包,裹,围,包裹,缠,披,包住,收工,卷;n:外套,围巾,披肩,头巾,匝,包裹,包装纸,大衣,围脖,罩衫",
"wrap up":"v:包装,捂,包裹,包住,收工",
"wrapper":"n:包装纸,封套,皮,包皮,护封",
"wrapping":"n:包皮",
"wrapping paper":"n:包装纸",
"wraps":"n:外衣,披肩,头巾,围巾",
"wrath":"n:愤怒,惩罚,狂怒,激怒,雷霆;a:愤怒",
"wrathful":"a:激怒,激愤,愤怒;v:激愤",
"wreak":"v:满足,露出,泄,报仇,处罚,发,肆虐,惩罚",
"wreath":"n:花环,花圈,花冠,环,圈",
"wreathe":"v:盘绕",
"wreck":"v:失事,破坏,毁坏,摧残,毁灭,击毁,破击,翻船,摧毁;n:毁坏,遭难,祸害,破坏,破灭",
"wreckage":"n:残骸,破坏,失事,遭难,折断,毁坏,破灭;v:失事,折断",
"wrecked":"a:残破",
"wrecking":"n:营救,故障,毁坏,失事,破坏;v:故障",
"wrecking bar":"n:撬棍",
"wren":"n:鹪鹩",
"wrench":"v:扭伤,拧,扭;n:扳子",
"wrest":"v:夺取,歪曲,夺,拧,抢夺",
"wrestle":"v:摔跤,扭打,搏斗,斟酌,摔,拼命,角力,撂交,搬动,深思,扑跌;n:摔跤,搏斗,角力,力战,奋斗,斗争,角",
"wrestling":"n:搏斗,扑跌,摔跤;v:摔交,扑跌",
"wretch":"n:可怜虫,坏人,浑蛋",
"wretched":"a:可怜,悲惨,凄惨,别扭,惨,凄,凄苦,凄怆,凄恻,凄楚",
"wretchedness":"n:可怜",
"wriggle":"v:扭动,蜿蜒,蠕动,蠢动;n:蠕动,扭动,蠢动;a:蠢",
"wriggler":"n:孑孓",
"wriggling":"v:蠕蠕",
"wriggly":"a:蠕动,蜿蜒",
"wright":"n:工匠,工人",
"wring":"v:拧,绞,榨取,折磨,挤,歪曲;n:绞",
"wring out":"v:榨取",
"wringing":"v:扭",
"wrinkle":"n:皱纹;v:打皱",
"wrinkled":"a:皱巴巴;v:皱皱巴巴",
"wrinkles":"n:皱纹",
"wrinkly":"a:皱",
"wrist":"n:腕,腕子,手腕子,轴,枢轴,臂腕",
"wrist bone":"n:腕骨",
"wrist watch":"n:手表",
"wristband":"n:袖口",
"wristbands":"n:袖口",
"wristwatch":"n:手表",
"writ":"n:文书,公文,文件,票,命令",
"writ large":"n:显而易见",
"write":"v:写,写信,写作,写字,书写,编写,写入,撰写,回信,记,做,创作,通信,作,著作,编,著述,录,手写,寄信,执笔,起草,缮写,填写,著,抄,报销,撰述,铭记,致函,批点,存入,修,撰著,练笔,题,著书,抹杀,誊,著文,撰;n:书,笔",
"write down":"v:录,载,记,记录",
"write in":"v:写入",
"write off":"v:抹杀,报销",
"write out":"v:缮写,起草,缮",
"write-off":"n:注销,折旧,贬值,勾销",
"writer":"n:作家,作者,著作,撰稿人,文学家,笔者,打字机,著者,记录器,书记",
"writhe":"v:打滚,翻腾,扭,折腾,痛苦,蠕动;n:翻滚,扭动",
"writing":"n:作品,写,写作,著作,文字,书写,字迹,笔迹,书法,文件,执笔,笔墨,铭,手迹,契据,字句,翰,文墨,习字;v:写作,写字",
"writing ink":"n:墨水",
"writing pad":"n:拍纸簿",
"writing paper":"n:笺注,笺纸",
"writing style":"n:写法,笔势",
"writings":"n:篇章,字,文辞,文章,著,作,著作",
"written":"v:笔头,成文;a:书面;n:笔头",
"written agreement":"n:约据",
"written language":"n:文字",
"wrong":"n:错误;v:枉,侮辱,超过,辜负,屈枉,错,诬害,误解;a:差;d:失当,颠倒,不对,翻转,逆",
"wrongdoer":"n:罪犯",
"wrongdoing":"n:犯罪,罪,坏事,尤",
"wrongful":"a:非法,恶劣",
"wrought":"a:形成,制造;v:精制",
"wrought iron":"n:镔铁,镔,锻铁",
"wu":"n:吴,巫,武",
"wuhan":"n:武汉",
"wunderkind":"n:神童",
"wurst":"n:香肠",
"wushu":"n:把式,把势",
"wuxia":"n:巫峡",
"www":"n:万维网",
"wye":"n:三通",
"x ray":"n:爱克斯光",
"x-ray":"n:伦琴射线",
"xenon":"n:氙",
"xerox":"v:复印",
"xi":"n:席",
"xian":"n:西安",
"xinjiang":"n:新疆,疆",
"xizang":"n:西藏",
"xmas":"n:圣诞节",
"xylem":"n:木质部",
"xylophone":"n:木琴",
"y":"n:三通",
"yacht":"n:游艇,快艇,帆船,赛艇",
"yak":"n:犏牛,牦牛;v:瞎扯,闲扯",
"yalta":"n:雅尔塔",
"yalu river":"n:鸭绿江",
"yam":"n:薯,山药",
"yam bean":"n:地瓜",
"yama":"n:阎罗王,阎罗,阎王",
"yammer":"n:诉苦,大叫,叫,叫嚷,哭诉;v:叹息",
"yanan":"n:延安",
"yang":"n:杨",
"yangtze river":"n:扬子江",
"yank":"v:使劲",
"yaounde":"n:雅温得",
"yap":"n:发牢骚,叫嚷,歹徒,嘴;v:狺狺,发牢骚,狂吠;d:汪汪",
"yard":"n:院子,码,场地,院落,厂子,厂,庭园,院",
"yard goods":"n:布匹,织物",
"yardage":"n:尺码",
"yardstick":"n:尺度,准绳,矱",
"yarn":"n:纱,纱线,故事,毛线,奇谈,官纱,谎话,绳子,谣言",
"yashmak":"n:面纱",
"yawing":"v:偏转",
"yawn":"n:呵欠,哈欠;v:欠,打哈欠",
"yaws":"n:雅司病",
"ye":"n:叶;r:你们",
"yea":"d:而且,的确,甚至,是,唯;n:赞成票,肯定",
"yeah":"n:是的",
"year":"n:年,年度,年头,时代,岁数,学年,岁,年级,兹,老年,春秋,秋",
"year-end":"n:年底,年终;a:年终",
"yearbook":"n:年鉴,年刊,年报",
"yearling":"n:一年生植物,羔羊",
"yearly":"n:全年,年,年刊;a:年,全年;d:年年",
"yearn":"v:渴望,盼望,怀念,想念,向往,渴慕,恋慕,热望,思念,企望,怀想,留恋",
"yearning":"n:渴望,思慕,热望,怀念",
"yearningly":"d:渴;a:渴",
"years":"n:岁月,年岁,年代,年头,年头儿,年光,时光,年华,年月,岁数",
"yeast":"n:酵母,发酵粉,激动,泡沫,曲,动乱,酵母菌;v:发酵",
"yeasty":"a:动荡",
"yell":"v:喊,大叫,嚷,叫喊;n:号",
"yellow":"n:黄色,黄种,蛋黄;a:黄",
"yellow fever":"n:黄热病",
"yellow metal":"n:黄铜",
"yellow race":"n:黄种",
"yellow river":"n:黄河",
"yellow spot":"n:黄斑",
"yellow warbler":"n:黄莺",
"yellowish":"n:昏黄",
"yellowish brown":"n:焦黄,土黄",
"yellowish pink":"n:肉色",
"yellowy":"a:黄色",
"yelp":"v:叫喊,尖叫,狺狺,吠",
"yemen":"n:也门",
"yen":"n:日元,渴望;v:热望",
"yenisei":"n:叶尼塞河",
"yeoman":"n:自耕农,自由民,侍者,卫士,随从",
"yeomanry":"n:自耕农,自由民",
"yes":"n:赞成;i:是,唉,啊,欸;d:哎;v:是",
"yes-man":"n:应声虫",
"yesterday":"n:昨天,昨日,过去,昨儿个,最近,昨,昨儿;d:最近",
"yesteryear":"n:去年",
"yet":"d:还,尚未,已经,未,现在,又;c:可",
"yeti":"n:雪人",
"yew":"n:紫杉",
"yi":"n:尹",
"yid":"n:犹太人",
"yield":"v:屈服;n:收获,收益,回收,击穿,利益,出产",
"yield up":"v:放弃",
"yielding":"a:出产,弱项;n:弱项",
"yin":"n:殷,尹",
"yip":"n:叫喊,怨言;v:喊叫,叫喊",
"yogurt":"n:酸牛奶,酸奶,酸乳",
"yoke":"n:轭,枷锁,奴役;v:结合",
"yokel":"n:庄稼汉,乡巴佬",
"yokohama":"n:横滨",
"yolk":"n:蛋黄,卵黄,核心",
"yonder":"d:那边,那里,远处;r:远处;a:那边",
"yore":"n:昔日",
"you":"r:你,你们,您,若,咱们,诸位,子,各位,尔,汝,乃,足下,台端,侬,汝曹,汝辈,列位,钧,尔曹,恁",
"young":"a:年轻,小,年青,少,早,年幼,幼稚,幼小,幼;n:妙龄",
"young girl":"n:姑",
"young lady":"n:闺秀,小姐",
"young man":"n:年轻人,青年人,男朋友,小兄弟,年青人,后生",
"young woman":"n:女郎",
"younger":"a:晚",
"youngster":"n:年轻人,小伙子,小孩子,少年,小字辈,儿",
"youngsters":"n:青少年",
"your":"a:大,贵,令,高,华,乃,碰头,玉,钧;r:钧,尊,乃;n:玉",
"youth":"n:青年,年轻,青春,年轻人,小伙子,少年,精神,初期,轻快,后生,少壮,儿",
"youthful":"a:年轻,青年;n:妙龄",
"youthfulness":"n:青春",
"youths":"n:青少年",
"yowl":"n:咆哮,狂啸;v:嚎",
"ytterbium":"n:镱",
"yttrium":"n:钇",
"yuan":"n:元,元朝,袁,苑",
"yuan dynasty":"n:元朝",
"yue":"n:岳",
"yugoslavia":"n:南斯拉夫",
"yuk":"v:大笑",
"yule":"n:圣诞节",
"yummy":"a:美味",
"yunnan":"n:云南",
"yuppie":"n:雅皮士",
"yurt":"n:毡包,毡帐,毡房,包,蒙古包",
"zaire":"n:扎伊尔",
"zambia":"n:赞比亚",
"zany":"n:丑角,傻瓜,小丑",
"zanzibar":"n:桑给巴尔",
"zap":"v:打败,砰,传送,弄死,除掉,攻击;n:生气,活力,精力,攻击;d:砰",
"zapper":"n:遥控器",
"zeal":"n:热情,热心,热忱,热诚,劲头,劲,奋发,奋起",
"zealotry":"n:热情,狂热",
"zealous":"a:热情,热心,热忱",
"zebra":"n:斑马,瘤牛",
"zebra crossing":"n:斑马线",
"zebu":"n:瘤牛",
"zen":"n:禅宗",
"zenith":"n:全盛,顶点,极点,顶峰,绝顶,极盛,天穹",
"zephyr":"n:微风,和风",
"zero":"n:零;a:○",
"zero point":"n:零点",
"zero tolerance":"n:严惩不贷",
"zest":"n:热情,兴趣,风趣,热心,香料,风味,香味",
"zeus":"n:宙斯",
"zhou":"n:周",
"zhuang":"n:庄",
"zigzag":"a:曲折,蜿蜒,曲里拐弯,弯曲",
"zigzagging":"v:盘曲,盘陀;a:盘曲,盘陀",
"zilch":"n:零,普通人,无,小人物,某某",
"zimbabwe":"n:津",
"zinc":"n:锌,锌白",
"zinc oxide":"n:锌白",
"zinc sulfate":"n:硫酸锌",
"zinc vitriol":"n:硫酸锌",
"zing":"n:热情,兴致,精力,活力,趣味",
"zingy":"a:激动",
"zion":"n:天堂,犹太人,天国",
"zip":"n:拉锁;v:压缩,逮捕,突进",
"zip code":"v:邮政编码",
"zip fastener":"v:拉链",
"zoroastrianism":"n:拜火教",
"zurich":"n:苏黎世",
}

def submit_redis():
	import redis
	r = redis.Redis(host='dev.werror.com', db=0, port=4328,  decode_responses=True)
	r.hmset("__ecdic", ecdic)
	print("done")

def load_dc():
	from diskcache import Index
	db= Index('/dcdata')
	for k,v in ecdic.items():
		db[k] = v
	print ('finished')	

if __name__ == '__main__': 
	import redis
	r = redis.Redis(host='gpu.werror.com', db=0, port=9221,  decode_responses=True)
	for w,v in ecdic.items(): 
		r.hset(f"word:{w}",'ectran', v)
	#r.hmset("ecdic", ecdic)
	print("done")	