lex_lemma = {
"'d_md":"would",
"'d_vbd":"had",
"'s_prp":"us",
"'s_vbz":"be",
"'s_pos":"'s",
"best_jjs":"good",
"best_rbs":"well",
"better_jjr":"good",
"better_rbr":"well",
"calves_nns":"calf",
"calves_vbz":"calve",
"diagnoses_nns":"diagnosis",
"diagnoses_vbz":"diagnose",
"does_nns":"doe",
"does_vbz":"do",
"halves_nns":"half",
"halves_vbz":"halve",
"hydrolyses_nns":"hydrolysis",
"hydrolyses_vbz":"hydrolysis",
"interleaves_nns":"interleaf",
"interleaves_vbz":"interleave",
"leaves_nns":"leaf",
"leaves_vbz":"leave",
"lives_nns":"life",
"lives_vbz":"live",
"metamorphoses_nns":"metamorphosis",
"metamorphoses_vbz":"metamorphose",
"misdiagnoses_nns":"misdiagnosis",
"misdiagnoses_vbz":"misdiagnose",
"paralyses_nns":"paralysis",
"paralyses_vbz":"paralyse",
"shelves_nns":"shelf",
"shelves_vbz":"shelve",
"thieves_nns":"thief",
"thieves_vbz":"thieve",
"thromboses_nns":"thrombosis",
"thromboses_vbz":"thrombose",
"wives_nns":"wife",
"wives_vbz":"wive",
"a-bombs":"a-bomb",
"a-horizons":"a-horizon",
"aardvarks":"aardvark",
"aardwolves":"aardwolf",
"aarps":"aarp",
"aases":"aas",
"abs":"ab",
"abas":"aba",
"abacas":"abaca",
"abaci":"abacus",
"abacuses":"abacus",
"abalones":"abalone",
"abamps":"abamp",
"abamperes":"abampere",
"abandoned":"abandon",
"abandoning":"abandon",
"abandons":"abandon",
"abandonments":"abandonment",
"abased":"abase",
"abases":"abase",
"abasing":"abase",
"abasements":"abasement",
"abashed":"abash",
"abashes":"abash",
"abashing":"abash",
"abashments":"abashment",
"abated":"abate",
"abates":"abate",
"abating":"abate",
"abatements":"abatement",
"abatises":"abatis",
"abattises":"abattis",
"abattoirs":"abattoir",
"abbacies":"abbacy",
"abbes":"abbe",
"abbesses":"abbess",
"abbeys":"abbey",
"abbots":"abbot",
"abbreviated":"abbreviate",
"abbreviates":"abbreviate",
"abbreviating":"abbreviate",
"abbreviations":"abbreviation",
"abbreviators":"abbreviator",
"ABCs":"ABC",
"abdicated":"abdicate",
"abdicates":"abdicate",
"abdicating":"abdicate",
"abdications":"abdication",
"abdomens":"abdomen",
"abdominocenteses":"abdominocentesis",
"abdominousnesses":"abdominousness",
"abducenses":"abducens",
"abducentes":"abducens",
"abducents":"abducent",
"abducted":"abduct",
"abducting":"abduct",
"abducts":"abduct",
"abductors":"abductor",
"abeles":"abele",
"abelmoschuses":"abelmoschus",
"abelmosks":"abelmosk",
"aberrances":"aberrance",
"aberrancies":"aberrancy",
"aberrations":"aberration",
"abets":"abet",
"abetted":"abet",
"abetting":"abet",
"abetments":"abetment",
"abetters":"abetter",
"abettors":"abettor",
"abeyances":"abeyance",
"abhenries":"abhenry",
"abhorred":"abhor",
"abhorring":"abhor",
"abhors":"abhor",
"abhorrences":"abhorrence",
"abidances":"abidance",
"abided":"abide",
"abides":"abide",
"abiding":"abide",
"abode":"abide",
"abieses":"abies",
"abilities":"ability",
"abiogeneses":"abiogenesis",
"abjections":"abjection",
"abjurations":"abjuration",
"abjured":"abjure",
"abjures":"abjure",
"abjuring":"abjure",
"ablactations":"ablactation",
"ablated":"ablate",
"ablating":"ablate",
"ablations":"ablation",
"ablatives":"ablative",
"ablauts":"ablaut",
"abler":"able",
"ablest":"able",
"able-bodiedisms":"able-bodiedism",
"able-bodisms":"able-bodism",
"ableisms":"ableism",
"ablisms":"ablism",
"ablses":"abls",
"ablutions":"ablution",
"abms":"abm",
"abnegated":"abnegate",
"abnegating":"abnegate",
"abnegations":"abnegation",
"abnormalcies":"abnormalcy",
"abnormalities":"abnormality",
"abnormities":"abnormity",
"abos":"abo",
"abodes":"abode",
"aboideaus":"aboideau",
"aboideaux":"aboideau",
"aboiteaus":"aboiteau",
"aboiteaux":"aboiteau",
"abolished":"abolish",
"abolishes":"abolish",
"abolishing":"abolish",
"abolishments":"abolishment",
"abolitions":"abolition",
"abolitionists":"abolitionist",
"abomasa":"abomasum",
"abomasums":"abomasum",
"abominated":"abominate",
"abominates":"abominate",
"abominating":"abominate",
"abominations":"abomination",
"abors":"abor",
"aboriginals":"aboriginal",
"aborigines":"aborigine",
"aborted":"abort",
"aborting":"abort",
"aborticides":"aborticide",
"abortifacients":"abortifacient",
"abortions":"abortion",
"abortuses":"abortus",
"aboulias":"aboulia",
"abounded":"abound",
"abounding":"abound",
"abounds":"abound",
"about-faced":"about-face",
"about-faces":"about-face",
"about-facing":"about-face",
"about-shipped":"about-ship",
"about-shipping":"about-ship",
"about-ships":"about-ship",
"abradants":"abradant",
"abraded":"abrade",
"abrades":"abrade",
"abrading":"abrade",
"abraders":"abrader",
"abramises":"abramis",
"abrasions":"abrasion",
"abrasives":"abrasive",
"abrasivenesses":"abrasiveness",
"abreacted":"abreact",
"abreacting":"abreact",
"abreactions":"abreaction",
"abridged":"abridge",
"abridges":"abridge",
"abridging":"abridge",
"abridgements":"abridgement",
"abridgments":"abridgment",
"abrocomas":"abrocoma",
"abrocomes":"abrocome",
"abrogated":"abrogate",
"abrogating":"abrogate",
"abrogations":"abrogation",
"abronias":"abronia",
"abruptions":"abruption",
"abruptnesses":"abruptness",
"abruzzis":"abruzzi",
"abscised":"abscise",
"abscising":"abscise",
"abscissae":"abscissa",
"abscissas":"abscissa",
"abscissions":"abscission",
"absconded":"abscond",
"absconding":"abscond",
"absconds":"abscond",
"abscondments":"abscondment",
"absences":"absence",
"absinths":"absinth",
"absinthes":"absinthe",
"absolutes":"absolute",
"absolutions":"absolution",
"absolutisms":"absolutism",
"absolutized":"absolutize",
"absolutizing":"absolutize",
"absolved":"absolve",
"absolves":"absolve",
"absolving":"absolve",
"absorbed":"absorb",
"absorbing":"absorb",
"absorbs":"absorb",
"absorbents":"absorbent",
"absorptances":"absorptance",
"absorptions":"absorption",
"absorptivities":"absorptivity",
"absquatulated":"absquatulate",
"absquatulates":"absquatulate",
"absquatulating":"absquatulate",
"abstained":"abstain",
"abstaining":"abstain",
"abstains":"abstain",
"abstainers":"abstainer",
"abstentions":"abstention",
"abstinences":"abstinence",
"abstinents":"abstinent",
"abstracted":"abstract",
"abstracting":"abstract",
"abstracts":"abstract",
"abstractednesses":"abstractedness",
"abstracters":"abstracter",
"abstractions":"abstraction",
"abstractionisms":"abstractionism",
"abstractionists":"abstractionist",
"abstractors":"abstractor",
"abstrusenesses":"abstruseness",
"abstrusities":"abstrusity",
"absurdities":"absurdity",
"absurdnesses":"absurdness",
"abudefdufs":"abudefduf",
"abulias":"abulia",
"abundances":"abundance",
"abused":"abuse",
"abuses":"abuse",
"abusing":"abuse",
"abuts":"abut",
"abutted":"abut",
"abutting":"abut",
"abutilons":"abutilon",
"abuttals":"abuttal",
"abought":"aby",
"abye":"aby",
"abyes":"aby",
"abying":"aby",
"abys":"aby",
"abysms":"abysm",
"abysses":"abyss",
"abyssinias":"abyssinia",
"Abyssinians":"Abyssinian",
"acs":"ac",
"acacias":"acacia",
"academes":"academe",
"academias":"academia",
"academics":"academic",
"academicians":"academician",
"academicisms":"academicism",
"academisms":"academism",
"academies":"academy",
"acalyphas":"acalypha",
"acanthaceaes":"acanthaceae",
"acanthisittas":"acanthisitta",
"acanthisittidaes":"acanthisittidae",
"acanthocephalas":"acanthocephala",
"acanthocephalans":"acanthocephalan",
"acanthocereuses":"acanthocereus",
"acanthocybiums":"acanthocybium",
"acanthophises":"acanthophis",
"acanthopterygians":"acanthopterygian",
"acanthopterygiis":"acanthopterygii",
"acanthoscelideses":"acanthoscelides",
"acanthuridaes":"acanthuridae",
"acanthuruses":"acanthurus",
"acanthi":"acanthus",
"acanthuses":"acanthus",
"acapnias":"acapnia",
"acapulcos":"acapulco",
"acaracides":"acaracide",
"acariases":"acariasis",
"acariasises":"acariasis",
"acaricides":"acaricide",
"acaridaes":"acaridae",
"acaridiases":"acaridiasis",
"acarinas":"acarina",
"acarioses":"acariosis",
"acari":"acarus",
"acaryotes":"acaryote",
"acceded":"accede",
"accedes":"accede",
"acceding":"accede",
"accelerandos":"accelerando",
"accelerated":"accelerate",
"accelerates":"accelerate",
"accelerating":"accelerate",
"accelerations":"acceleration",
"accelerators":"accelerator",
"accented":"accent",
"accenting":"accent",
"accents":"accent",
"accentings":"accenting",
"accentuated":"accentuate",
"accentuates":"accentuate",
"accentuating":"accentuate",
"accentuations":"accentuation",
"accepted":"accept",
"accepting":"accept",
"accepts":"accept",
"acceptabilities":"acceptability",
"acceptablenesses":"acceptableness",
"acceptances":"acceptance",
"acceptations":"acceptation",
"accessed":"access",
"accesses":"access",
"accessing":"access",
"accessaries":"accessary",
"accessibilities":"accessibility",
"accessions":"accession",
"accessories":"accessory",
"acciaccaturas":"acciaccatura",
"acciaccature":"acciaccatura",
"accidences":"accidence",
"accidents":"accident",
"accidentals":"accidental",
"accipiters":"accipiter",
"accipitridaes":"accipitridae",
"accipitriformeses":"accipitriformes",
"acclaimed":"acclaim",
"acclaiming":"acclaim",
"acclaims":"acclaim",
"acclamations":"acclamation",
"acclimated":"acclimate",
"acclimates":"acclimate",
"acclimating":"acclimate",
"acclimations":"acclimation",
"acclimatisations":"acclimatisation",
"acclimatizations":"acclimatization",
"acclimatized":"acclimatize",
"acclimatizes":"acclimatize",
"acclimatizing":"acclimatize",
"acclivities":"acclivity",
"accolades":"accolade",
"accommodated":"accommodate",
"accommodates":"accommodate",
"accommodating":"accommodate",
"accommodations":"accommodation",
"accommodators":"accommodator",
"accompaniments":"accompaniment",
"accompanists":"accompanist",
"accompanied":"accompany",
"accompanies":"accompany",
"accompanying":"accompany",
"accompanyists":"accompanyist",
"accomplices":"accomplice",
"accomplished":"accomplish",
"accomplishes":"accomplish",
"accomplishing":"accomplish",
"accomplishments":"accomplishment",
"accorded":"accord",
"according":"accord",
"accords":"accord",
"accordances":"accordance",
"accordions":"accordion",
"accosted":"accost",
"accosting":"accost",
"accosts":"accost",
"accouchements":"accouchement",
"accoucheurs":"accoucheur",
"accoucheuses":"accoucheuse",
"accounted":"account",
"accounting":"account",
"accounts":"account",
"accountabilities":"accountability",
"accountancies":"accountancy",
"accountants":"accountant",
"accountings":"accounting",
"accoutered":"accouter",
"accoutering":"accouter",
"accouters":"accouter",
"accouterments":"accouterment",
"accoutrements":"accoutrement",
"accras":"accra",
"accredited":"accredit",
"accrediting":"accredit",
"accredits":"accredit",
"accreted":"accrete",
"accreting":"accrete",
"accretions":"accretion",
"accroideses":"accroides",
"accruals":"accrual",
"accrued":"accrue",
"accrues":"accrue",
"accruing":"accrue",
"accruements":"accruement",
"acculturated":"acculturate",
"acculturating":"acculturate",
"acculturations":"acculturation",
"accumulated":"accumulate",
"accumulates":"accumulate",
"accumulating":"accumulate",
"accumulations":"accumulation",
"accumulators":"accumulator",
"accuracies":"accuracy",
"accusals":"accusal",
"accusations":"accusation",
"accusatives":"accusative",
"accused":"accuse",
"accuses":"accuse",
"accusing":"accuse",
"accusers":"accuser",
"accustomed":"accustom",
"accustoming":"accustom",
"accustoms":"accustom",
"aced":"ace",
"aces":"ace",
"acing":"ace",
"acebutolols":"acebutolol",
"acedias":"acedia",
"acephalias":"acephalia",
"acephalisms":"acephalism",
"acephalies":"acephaly",
"acequias":"acequia",
"acers":"acer",
"aceraceaes":"aceraceae",
"acerbated":"acerbate",
"acerbates":"acerbate",
"acerbating":"acerbate",
"acerbities":"acerbity",
"acerolas":"acerola",
"acetabula":"acetabulum",
"acetabulums":"acetabulum",
"acetaldols":"acetaldol",
"acetamides":"acetamide",
"acetaminophens":"acetaminophen",
"acetanilids":"acetanilid",
"acetanilides":"acetanilide",
"acetates":"acetate",
"acetified":"acetify",
"acetifies":"acetify",
"acetifying":"acetify",
"acetones":"acetone",
"acetonemias":"acetonemia",
"acetonurias":"acetonuria",
"acetophenetidins":"acetophenetidin",
"acetphenetidins":"acetphenetidin",
"acetylenes":"acetylene",
"achaeans":"achaean",
"achaemenidae":"achaemenid",
"achaemenides":"achaemenid",
"achaemenids":"achaemenid",
"achaians":"achaian",
"ached":"ache",
"aches":"ache",
"aching":"ache",
"acherons":"acheron",
"acherontias":"acherontia",
"achetas":"acheta",
"achievabilities":"achievability",
"achieved":"achieve",
"achieves":"achieve",
"achieving":"achieve",
"achievements":"achievement",
"achievers":"achiever",
"achimeneses":"achimenes",
"achings":"aching",
"achiras":"achira",
"achoeroduses":"achoerodus",
"achondroplasias":"achondroplasia",
"achrases":"achras",
"achromasias":"achromasia",
"achromatisms":"achromatism",
"achromycins":"achromycin",
"achylias":"achylia",
"aciculae":"acicula",
"acicula":"aciculum",
"aciculums":"aciculum",
"acids":"acid",
"acidified":"acidify",
"acidifies":"acidify",
"acidifying":"acidify",
"acidities":"acidity",
"acidophils":"acidophil",
"acidophiles":"acidophile",
"acidulated":"acidulate",
"acidulates":"acidulate",
"acidulating":"acidulate",
"acidulousnesses":"acidulousness",
"acinonyxes":"acinonyx",
"acinoses":"acinos",
"acini":"acinus",
"acipensers":"acipenser",
"acipenseridaes":"acipenseridae",
"ack-acks":"ack-ack",
"ackees":"ackee",
"acknowledged":"acknowledge",
"acknowledges":"acknowledge",
"acknowledging":"acknowledge",
"acknowledgements":"acknowledgement",
"acknowledgments":"acknowledgment",
"acmes":"acme",
"acnidosporidias":"acnidosporidia",
"acocantheras":"acocanthera",
"acokantheras":"acokanthera",
"aconitums":"aconitum",
"acoraceaes":"acoraceae",
"acorns":"acorn",
"acoruses":"acorus",
"acouchis":"acouchi",
"acouchies":"acouchy",
"acquainted":"acquaint",
"acquainting":"acquaint",
"acquaints":"acquaint",
"acquaintances":"acquaintance",
"acquaintanceships":"acquaintanceship",
"acquiesced":"acquiesce",
"acquiesces":"acquiesce",
"acquiescing":"acquiesce",
"acquiescences":"acquiescence",
"acquired":"acquire",
"acquires":"acquire",
"acquiring":"acquire",
"acquirements":"acquirement",
"acquirers":"acquirer",
"acquirings":"acquiring",
"acquisitions":"acquisition",
"acquits":"acquit",
"acquitted":"acquit",
"acquitting":"acquit",
"acquittals":"acquittal",
"acquittances":"acquittance",
"acrasiomyceteses":"acrasiomycetes",
"acres":"acre",
"acre-feet":"acre-foot",
"acreages":"acreage",
"acreses":"acres",
"acridids":"acridid",
"acrididaes":"acrididae",
"acridities":"acridity",
"acridnesses":"acridness",
"acridothereses":"acridotheres",
"acrimonies":"acrimony",
"acrises":"acris",
"acroanaesthesias":"acroanaesthesia",
"acroanesthesias":"acroanesthesia",
"acrobateses":"acrobates",
"acrobaticses":"acrobatics",
"acrocarps":"acrocarp",
"acrocarpuses":"acrocarpus",
"acrocephaluses":"acrocephalus",
"acrocephalies":"acrocephaly",
"acrocliniums":"acroclinium",
"acrocomias":"acrocomia",
"acrocyanoses":"acrocyanosis",
"acroleins":"acrolein",
"acromegalias":"acromegalia",
"acromegalies":"acromegaly",
"acromicrias":"acromicria",
"acromikrias":"acromikria",
"acromia":"acromion",
"acromimia":"acromion",
"acropolises":"acropolis",
"acroporas":"acropora",
"acrostics":"acrostic",
"acrostichums":"acrostichum",
"acrylates":"acrylate",
"acrylics":"acrylic",
"acrylonitriles":"acrylonitrile",
"acted":"act",
"acting":"act",
"acts":"act",
"actaeas":"actaea",
"acths":"acth",
"actiases":"actias",
"actinarias":"actinaria",
"actings":"acting",
"actinias":"actinia",
"actinians":"actinian",
"actiniarias":"actiniaria",
"actiniarians":"actiniarian",
"actinidias":"actinidia",
"actinidiaceaes":"actinidiaceae",
"actiniopterises":"actiniopteris",
"actiniums":"actinium",
"actinomerises":"actinomeris",
"actinomycetacaeas":"actinomycetacaea",
"actinomycetaleses":"actinomycetales",
"actinomyxidias":"actinomyxidia",
"actinopodas":"actinopoda",
"actinotherapies":"actinotherapy",
"actinozoas":"actinozoa",
"actinozoans":"actinozoan",
"actions":"action",
"actitises":"actitis",
"activases":"activase",
"activated":"activate",
"activates":"activate",
"activating":"activate",
"activatings":"activating",
"activations":"activation",
"activators":"activator",
"actives":"active",
"activenesses":"activeness",
"activists":"activist",
"activities":"activity",
"activized":"activize",
"activizing":"activize",
"actors":"actor",
"actresses":"actress",
"actses":"acts",
"actualisations":"actualisation",
"actualities":"actuality",
"actualizations":"actualization",
"actualized":"actualize",
"actualizes":"actualize",
"actualizing":"actualize",
"actuaries":"actuary",
"actuated":"actuate",
"actuates":"actuate",
"actuating":"actuate",
"actuations":"actuation",
"acuities":"acuity",
"aculars":"acular",
"acumens":"acumen",
"acuminated":"acuminate",
"acuminating":"acuminate",
"acuminted":"acuminate",
"acupressures":"acupressure",
"acupunctured":"acupuncture",
"acupunctures":"acupuncture",
"acupuncturing":"acupuncture",
"acuter":"acute",
"acutes":"acute",
"acutest":"acute",
"acutenesses":"acuteness",
"acyclovirs":"acyclovir",
"ads":"ad",
"ad-libbed":"ad-lib",
"ad-libbing":"ad-lib",
"ad-libs":"ad-lib",
"adactylias":"adactylia",
"adactylisms":"adactylism",
"adactylies":"adactyly",
"adages":"adage",
"adagios":"adagio",
"adalias":"adalia",
"adams":"adam",
"adam-and-eves":"adam-and-eve",
"adamances":"adamance",
"adamants":"adamant",
"adamses":"adams",
"adansonias":"adansonia",
"adapids":"adapid",
"adapins":"adapin",
"adapted":"adapt",
"adapting":"adapt",
"adapts":"adapt",
"adaptations":"adaptation",
"adapters":"adapter",
"adaptors":"adaptor",
"added":"add",
"adding":"add",
"adds":"add",
"addaxes":"addax",
"addenda":"addendum",
"addendums":"addendum",
"adders":"adder",
"addicting":"addict",
"addicts":"addict",
"addictions":"addiction",
"additions":"addition",
"addled":"addle",
"addles":"addle",
"addling":"addle",
"addle-heads":"addle-head",
"addressed":"address",
"addresses":"address",
"addressing":"address",
"addressographs":"addressograph",
"adduced":"adduce",
"adduces":"adduce",
"adducing":"adduce",
"adducted":"adduct",
"adducting":"adduct",
"adducts":"adduct",
"adductors":"adductor",
"ades":"ade",
"adelgeses":"adelges",
"adelgidaes":"adelgidae",
"adelies":"adelie",
"adenantheras":"adenanthera",
"adenectomies":"adenectomy",
"adeniums":"adenium",
"adenocarcinomas":"adenocarcinoma",
"adenocarcinomata":"adenocarcinoma",
"adenohypophyses":"adenohypophysis",
"adenoids":"adenoid",
"adenoidectomies":"adenoidectomy",
"adenomas":"adenoma",
"adenomata":"adenoma",
"adenomyoses":"adenomyosis",
"adenoses":"adenosis",
"adenotas":"adenota",
"adepts":"adept",
"adeptnesses":"adeptness",
"adequacies":"adequacy",
"adequatenesses":"adequateness",
"adermins":"adermin",
"adhs":"adh",
"adhered":"adhere",
"adheres":"adhere",
"adhering":"adhere",
"adherences":"adherence",
"adherents":"adherent",
"adhesions":"adhesion",
"adhesives":"adhesive",
"adhesivenesses":"adhesiveness",
"adiantaceaes":"adiantaceae",
"adiantums":"adiantum",
"adieus":"adieu",
"adieux":"adieu",
"adiges":"adige",
"adioses":"adios",
"adiposenesses":"adiposeness",
"adiposes":"adiposis",
"adiposities":"adiposity",
"adirondackses":"adirondacks",
"adjacencies":"adjacency",
"adjoined":"adjoin",
"adjoining":"adjoin",
"adjoins":"adjoin",
"adjourned":"adjourn",
"adjourning":"adjourn",
"adjourns":"adjourn",
"adjournments":"adjournment",
"adjudged":"adjudge",
"adjudges":"adjudge",
"adjudging":"adjudge",
"adjudicated":"adjudicate",
"adjudicates":"adjudicate",
"adjudicating":"adjudicate",
"adjunctions":"adjunction",
"adjurations":"adjuration",
"adjured":"adjure",
"adjures":"adjure",
"adjuring":"adjure",
"adjusted":"adjust",
"adjusting":"adjust",
"adjusts":"adjust",
"adjusters":"adjuster",
"adjustments":"adjustment",
"adjustors":"adjustor",
"adjutancies":"adjutancy",
"adjutants":"adjutant",
"adlumias":"adlumia",
"admen":"adman",
"admeasured":"admeasure",
"admeasuring":"admeasure",
"administered":"administer",
"administering":"administer",
"administers":"administer",
"administrated":"administrate",
"administrates":"administrate",
"administrating":"administrate",
"administrations":"administration",
"administrators":"administrator",
"administratrices":"administratrix",
"admirabilities":"admirability",
"admirablenesses":"admirableness",
"admirals":"admiral",
"admiralties":"admiralty",
"admirations":"admiration",
"admired":"admire",
"admires":"admire",
"admiring":"admire",
"admirers":"admirer",
"admissions":"admission",
"admits":"admit",
"admitted":"admit",
"admitting":"admit",
"admittances":"admittance",
"admixed":"admix",
"admixing":"admix",
"admixt":"admix",
"admixtures":"admixture",
"admonished":"admonish",
"admonishes":"admonish",
"admonishing":"admonish",
"admonishers":"admonisher",
"admonishments":"admonishment",
"admonitions":"admonition",
"adnexas":"adnexa",
"ados":"ado",
"adobes":"adobe",
"adolescents":"adolescent",
"adonics":"adonic",
"adonises":"adonis",
"adopted":"adopt",
"adopting":"adopt",
"adopts":"adopt",
"adopters":"adopter",
"adoptions":"adoption",
"adorabilities":"adorability",
"adorablenesses":"adorableness",
"adorations":"adoration",
"adored":"adore",
"adoring":"adore",
"adorers":"adorer",
"adorned":"adorn",
"adorning":"adorn",
"adorns":"adorn",
"adornments":"adornment",
"adps":"adp",
"adpses":"adps",
"adrenals":"adrenal",
"adrenalectomies":"adrenalectomy",
"adrenalins":"adrenalin",
"adrenalines":"adrenaline",
"adrenocorticotrophins":"adrenocorticotrophin",
"adrenocorticotropins":"adrenocorticotropin",
"adrianoples":"adrianople",
"adrianopolises":"adrianopolis",
"adriatics":"adriatic",
"adroitnesses":"adroitness",
"adsorbed":"adsorb",
"adsorbing":"adsorb",
"adsorbents":"adsorbent",
"adsorptions":"adsorption",
"adularias":"adularia",
"adulated":"adulate",
"adulating":"adulate",
"adulations":"adulation",
"adulators":"adulator",
"adults":"adult",
"adulterated":"adulterate",
"adulterating":"adulterate",
"aulterated":"adulterate",
"adulterations":"adulteration",
"adulterers":"adulterer",
"adulteresses":"adulteress",
"adulteries":"adultery",
"adulthoods":"adulthood",
"adumbrated":"adumbrate",
"adumbrates":"adumbrate",
"adumbrating":"adumbrate",
"advanced":"advance",
"advances":"advance",
"advancing":"advance",
"advancements":"advancement",
"advantaged":"advantage",
"advantages":"advantage",
"advantaging":"advantage",
"advantageousnesses":"advantageousness",
"advents":"advent",
"adventisms":"adventism",
"adventists":"adventist",
"adventitias":"adventitia",
"adventured":"adventure",
"adventures":"adventure",
"adventuring":"adventure",
"adventurers":"adventurer",
"adventurousnesses":"adventurousness",
"adverbs":"adverb",
"adversaries":"adversary",
"adversities":"adversity",
"adverted":"advert",
"adverting":"advert",
"adverts":"advert",
"advertences":"advertence",
"advertencies":"advertency",
"advertised":"advertise",
"advertises":"advertise",
"advertising":"advertise",
"advertisements":"advertisement",
"advertisers":"advertiser",
"advertisings":"advertising",
"advertized":"advertize",
"advertizes":"advertize",
"advertizing":"advertize",
"advertizings":"advertizing",
"advices":"advice",
"advils":"advil",
"advised":"advise",
"advises":"advise",
"advising":"advise",
"advisements":"advisement",
"advisers":"adviser",
"advisors":"advisor",
"advisories":"advisory",
"advocacies":"advocacy",
"advocated":"advocate",
"advocates":"advocate",
"advocating":"advocate",
"adygeis":"adygei",
"adyghes":"adyghe",
"adyta":"adytum",
"adzed":"adz",
"adzing":"adz",
"adzs":"adz",
"adzes":"adze",
"aecs":"aec",
"aecidia":"aecidium",
"aecia":"aecium",
"aedeses":"aedes",
"aegeans":"aegean",
"aegicerases":"aegiceras",
"aegilopses":"aegilops",
"aegirs":"aegir",
"aegises":"aegis",
"aegospotamis":"aegospotami",
"aegospotamoses":"aegospotamos",
"aegypiidaes":"aegypiidae",
"aegypiuses":"aegypius",
"aenguses":"aengus",
"aeolias":"aeolia",
"aeolians":"aeolian",
"aeolics":"aeolic",
"aeolises":"aeolis",
"aeons":"aeon",
"aeoniums":"aeonium",
"aepyceroses":"aepyceros",
"aepyornidaes":"aepyornidae",
"aepyorniformeses":"aepyorniformes",
"aepyornises":"aepyornis",
"aerated":"aerate",
"aerates":"aerate",
"aerating":"aerate",
"aerials":"aerial",
"aeries":"aerie",
"aerified":"aerify",
"aerifies":"aerify",
"aerifying":"aerify",
"aerobacters":"aerobacter",
"aerobaticses":"aerobatics",
"aerobes":"aerobe",
"aerobicses":"aerobics",
"aerobia":"aerobium",
"aerodromes":"aerodrome",
"aerodynamicses":"aerodynamics",
"aeroembolisms":"aeroembolism",
"aerofoils":"aerofoil",
"aerogenerators":"aerogenerator",
"aerograms":"aerogram",
"aerogrammes":"aerogramme",
"aeromechanicses":"aeromechanics",
"aeromedicines":"aeromedicine",
"aeronauts":"aeronaut",
"aeronauticses":"aeronautics",
"aerophytes":"aerophyte",
"aeroplanes":"aeroplane",
"aerosols":"aerosol",
"aerier":"aery",
"aeriest":"aery",
"aesculuses":"aesculus",
"aesthetes":"aesthete",
"aesthetics":"aesthetic",
"aestheticians":"aesthetician",
"aestheticses":"aesthetics",
"aestivated":"aestivate",
"aestivates":"aestivate",
"aestivating":"aestivate",
"aestivations":"aestivation",
"aethers":"aether",
"aethionemas":"aethionema",
"aethusas":"aethusa",
"aetiologists":"aetiologist",
"aetiologies":"aetiology",
"aetobatuses":"aetobatus",
"affabilities":"affability",
"affablenesses":"affableness",
"affairs":"affair",
"affaires":"affaire",
"affairses":"affairs",
"affected":"affect",
"affecting":"affect",
"affects":"affect",
"affectations":"affectation",
"affections":"affection",
"affectionatenesses":"affectionateness",
"affenpinschers":"affenpinscher",
"affianced":"affiance",
"affiances":"affiance",
"affiancing":"affiance",
"afficionados":"afficionado",
"affidavits":"affidavit",
"affiliated":"affiliate",
"affiliates":"affiliate",
"affiliating":"affiliate",
"affiliations":"affiliation",
"affinities":"affinity",
"affirmed":"affirm",
"affirming":"affirm",
"affirms":"affirm",
"affirmations":"affirmation",
"affirmatives":"affirmative",
"affixed":"affix",
"affixes":"affix",
"affixing":"affix",
"afflicted":"afflict",
"afflicting":"afflict",
"afflicts":"afflict",
"afflictions":"affliction",
"affluences":"affluence",
"affluents":"affluent",
"afforded":"afford",
"affording":"afford",
"affords":"afford",
"afforested":"afforest",
"afforesting":"afforest",
"afforests":"afforest",
"affrays":"affray",
"affricates":"affricate",
"affricatives":"affricative",
"affrighted":"affright",
"affrighting":"affright",
"affrights":"affright",
"affronted":"affront",
"affronting":"affront",
"affronts":"affront",
"affusions":"affusion",
"Afghans":"Afghan",
"afghanis":"afghani",
"afghanistanis":"afghanistani",
"aficionados":"aficionado",
"afl-cios":"afl-cio",
"aflaxens":"aflaxen",
"afps":"afp",
"aframomums":"aframomum",
"afrasians":"afrasian",
"African-Americans":"African-American",
"afrikaanses":"afrikaans",
"afrikanders":"afrikander",
"Afrikaners":"Afrikaner",
"Afros":"Afro",
"Afro-Americans":"Afro-American",
"afroasiatics":"afroasiatic",
"afrocarpuses":"afrocarpus",
"afropavos":"afropavo",
"after-shaves":"after-shave",
"afterbodies":"afterbody",
"afterimages":"afterimage",
"afterlives":"afterlife",
"aftermaths":"aftermath",
"afternoons":"afternoon",
"aftersensations":"aftersensation",
"afterthoughts":"afterthought",
"afterwords":"afterword",
"ags":"ag",
"agalactias":"agalactia",
"agalactoses":"agalactosis",
"agamas":"agama",
"agamids":"agamid",
"agamidaes":"agamidae",
"agamogeneses":"agamogenesis",
"agapanthuses":"agapanthus",
"agapes":"agape",
"agapornises":"agapornis",
"agars":"agar",
"agar-agars":"agar-agar",
"agarics":"agaric",
"agaricaceaes":"agaricaceae",
"agaricaleses":"agaricales",
"agaricuses":"agaricus",
"agastaches":"agastache",
"agates":"agate",
"agathises":"agathis",
"agavaceaes":"agavaceae",
"agaves":"agave",
"aged":"age",
"ageing":"age",
"ages":"age",
"aging":"age",
"agednesses":"agedness",
"ageings":"ageing",
"ageisms":"ageism",
"agelaiuses":"agelaius",
"agencies":"agency",
"agendas":"agenda",
"agenda":"agendum",
"agendums":"agendum",
"agenesias":"agenesia",
"ageneses":"agenesis",
"agents":"agent",
"agents-general":"agent-general",
"ageratinas":"ageratina",
"ageratums":"ageratum",
"aggiornamenti":"aggiornamento",
"agglomerated":"agglomerate",
"agglomerating":"agglomerate",
"agglutinated":"agglutinate",
"agglutinating":"agglutinate",
"agglutinations":"agglutination",
"aggraded":"aggrade",
"aggrading":"aggrade",
"aggrandisements":"aggrandisement",
"aggrandized":"aggrandize",
"aggrandizes":"aggrandize",
"aggrandizing":"aggrandize",
"aggrandizements":"aggrandizement",
"aggravated":"aggravate",
"aggravates":"aggravate",
"aggravating":"aggravate",
"aggravations":"aggravation",
"aggregated":"aggregate",
"aggregates":"aggregate",
"aggregating":"aggregate",
"aggregations":"aggregation",
"aggressed":"aggress",
"aggresses":"aggress",
"aggressing":"aggress",
"aggressions":"aggression",
"aggressivenesses":"aggressiveness",
"aggressors":"aggressor",
"aggrieved":"aggrieve",
"aggrieves":"aggrieve",
"aggrieving":"aggrieve",
"agilities":"agility",
"agings":"aging",
"agios":"agio",
"agiotages":"agiotage",
"agisms":"agism",
"agitated":"agitate",
"agitates":"agitate",
"agitating":"agitate",
"agitations":"agitation",
"agitators":"agitator",
"agitprops":"agitprop",
"agkistrodons":"agkistrodon",
"aglaomorphas":"aglaomorpha",
"aglaonemas":"aglaonema",
"aglets":"aglet",
"agnails":"agnail",
"agnates":"agnate",
"agnathas":"agnatha",
"agnathans":"agnathan",
"agnations":"agnation",
"agnomina":"agnomen",
"agnonomina":"agnomen",
"agnostics":"agnostic",
"agnosticisms":"agnosticism",
"agones":"agon",
"agonidaes":"agonidae",
"agonized":"agonize",
"agonizes":"agonize",
"agonizing":"agonize",
"agonuses":"agonus",
"agonies":"agony",
"agorae":"agora",
"agoras":"agora",
"agouties":"agouti",
"agoutis":"agouti",
"agranulocytoses":"agranulocytosis",
"agranuloses":"agranulosis",
"agraphias":"agraphia",
"agrarians":"agrarian",
"agreed":"agree",
"agreeing":"agree",
"agrees":"agree",
"agreeabilities":"agreeability",
"agreeablenesses":"agreeableness",
"agreements":"agreement",
"agribusinesses":"agribusiness",
"agricultures":"agriculture",
"agriculturists":"agriculturist",
"agrimonias":"agrimonia",
"agrimonies":"agrimony",
"agriocharises":"agriocharis",
"agrippas":"agrippa",
"agrobacteriums":"agrobacterium",
"agronomies":"agronomy",
"agropyrons":"agropyron",
"agrostemmas":"agrostemma",
"agrostises":"agrostis",
"aguas":"agua",
"agues":"ague",
"agueweeds":"agueweed",
"ais":"ai",
"aided":"aid",
"aiding":"aid",
"aids":"aid",
"aids-de-camp":"aid-de-camp",
"aides":"aide",
"aide-de-camps":"aide-de-camp",
"aides-de-camp":"aide-de-camp",
"aides-memoire":"aide-memoire",
"aideses":"aides",
"aidmen":"aidman",
"aidoneuses":"aidoneus",
"aidses":"aids",
"aiglets":"aiglet",
"aigrets":"aigret",
"aigrettes":"aigrette",
"aiguilettes":"aiguilette",
"ailed":"ail",
"ailing":"ail",
"ails":"ail",
"ailanthuses":"ailanthus",
"ailments":"ailment",
"ailuropodas":"ailuropoda",
"ailuropodidaes":"ailuropodidae",
"ailuruses":"ailurus",
"aimed":"aim",
"aiming":"aim",
"aims":"aim",
"aimlessnesses":"aimlessness",
"Ainus":"Ainu",
"aiolis":"aioli",
"aired":"air",
"airing":"air",
"airs":"air",
"air-conditioned":"air-condition",
"air-conditioning":"air-condition",
"air-conditioners":"air-conditioner",
"air-conditionings":"air-conditioning",
"air-dried":"air-dry",
"air-dries":"air-dry",
"air-drying":"air-dry",
"airbrakes":"airbrake",
"airbrushed":"airbrush",
"airbrushing":"airbrush",
"aircraftmen":"aircraftman",
"aircraftsmen":"aircraftsman",
"aircraftwomen":"aircraftswoman",
"airdocks":"airdock",
"airdromes":"airdrome",
"airdropped":"airdrop",
"airdropping":"airdrop",
"airdrops":"airdrop",
"aires":"aire",
"Airedales":"Airedale",
"airfields":"airfield",
"airfoils":"airfoil",
"airforces":"airforce",
"airguns":"airgun",
"airinesses":"airiness",
"airings":"airing",
"airlifted":"airlift",
"airlifting":"airlift",
"airlifts":"airlift",
"airlines":"airline",
"airliners":"airliner",
"airlocks":"airlock",
"airmailed":"airmail",
"airmailing":"airmail",
"airmails":"airmail",
"airmen":"airman",
"airplanes":"airplane",
"airports":"airport",
"airposts":"airpost",
"airses":"airs",
"airscrews":"airscrew",
"airships":"airship",
"airstreams":"airstream",
"airstrips":"airstrip",
"airwaves":"airwave",
"airways":"airway",
"airwomen":"airwoman",
"airworthier":"airworthy",
"airworthiest":"airworthy",
"airier":"airy",
"airiest":"airy",
"aisles":"aisle",
"aixes":"aix",
"aizoaceaes":"aizoaceae",
"ajaias":"ajaia",
"ajugas":"ajuga",
"akabas":"akaba",
"akans":"akan",
"akaryocytes":"akaryocyte",
"akaryotes":"akaryote",
"akees":"akee",
"akeridaes":"akeridae",
"akhas":"akha",
"akinesias":"akinesia",
"akineses":"akinesis",
"akus":"aku",
"akvavits":"akvavit",
"als":"al",
"al-iraqs":"al-iraq",
"al-magribs":"al-magrib",
"alae":"ala",
"alabamas":"alabama",
"alabamians":"alabamian",
"alabasters":"alabaster",
"alacrities":"alacrity",
"alamedas":"alameda",
"alamos":"alamo",
"alars":"alar",
"alarmed":"alarm",
"alarming":"alarm",
"alarms":"alarm",
"alarums":"alarum",
"alaskas":"alaska",
"alaudas":"alauda",
"alaudidaes":"alaudidae",
"albacores":"albacore",
"albanies":"albany",
"albatrelluses":"albatrellus",
"albatrosses":"albatross",
"albedos":"albedo",
"albinos":"albino",
"albites":"albite",
"albizias":"albizia",
"albizzias":"albizzia",
"albuginaceaes":"albuginaceae",
"albugos":"albugo",
"albulas":"albula",
"albulidaes":"albulidae",
"albums":"album",
"albumens":"albumen",
"albumins":"albumin",
"albuminoids":"albuminoid",
"albuminurias":"albuminuria",
"albuterols":"albuterol",
"alcas":"alca",
"alcahests":"alcahest",
"alcaics":"alcaic",
"alcaides":"alcaide",
"alcaldes":"alcalde",
"alceas":"alcea",
"alcedinidaes":"alcedinidae",
"alcedos":"alcedo",
"alcelaphuses":"alcelaphus",
"alceses":"alces",
"alchemized":"alchemize",
"alchemizing":"alchemize",
"alchemies":"alchemy",
"alcidaes":"alcidae",
"alcideses":"alcides",
"alcohols":"alcohol",
"alcoholics":"alcoholic",
"alcoholisms":"alcoholism",
"alcoves":"alcove",
"alcyonaceas":"alcyonacea",
"alcyonarias":"alcyonaria",
"aldactones":"aldactone",
"alders":"alder",
"alderflies":"alderfly",
"aldermen":"alderman",
"aldols":"aldol",
"aldomets":"aldomet",
"aldosteronisms":"aldosteronism",
"aldrovandas":"aldrovanda",
"alecosts":"alecost",
"alectises":"alectis",
"alectorias":"alectoria",
"alectorises":"alectoris",
"alecturas":"alectura",
"alehoofs":"alehoof",
"alehouses":"alehouse",
"aleps":"alep",
"aleph-noughts":"aleph-nought",
"aleph-nulls":"aleph-null",
"aleph-zeroes":"aleph-zero",
"aleph-zeros":"aleph-zero",
"alepisauruses":"alepisaurus",
"aleppos":"aleppo",
"alerted":"alert",
"alerting":"alert",
"alerts":"alert",
"alertings":"alerting",
"alertnesses":"alertness",
"aletrises":"aletris",
"aleuriteses":"aleurites",
"aleuts":"aleut",
"aleutians":"aleutian",
"aleutianses":"aleutians",
"aleves":"aleve",
"alewives":"alewife",
"alexanders":"alexander",
"alexanderses":"alexanders",
"alexandrias":"alexandria",
"alexias":"alexia",
"aleyrodeses":"aleyrodes",
"aleyrodidaes":"aleyrodidae",
"alfalfas":"alfalfa",
"alfilarias":"alfilaria",
"alfilerias":"alfileria",
"alforjas":"alforja",
"algae":"alga",
"algas":"alga",
"algaes":"algae",
"algarobillas":"algarobilla",
"algarrobas":"algarroba",
"algarrobillas":"algarrobilla",
"algerias":"algeria",
"algeries":"algerie",
"algeripithecuses":"algeripithecus",
"algierses":"algiers",
"algins":"algin",
"algonkians":"algonkian",
"algonkins":"algonkin",
"algonquians":"algonquian",
"algonquins":"algonquin",
"algorithms":"algorithm",
"aliases":"alias",
"alibied":"alibi",
"alibiing":"alibi",
"alibis":"alibi",
"aliened":"alien",
"aliening":"alien",
"aliens":"alien",
"alienages":"alienage",
"alienated":"alienate",
"alienates":"alienate",
"alienating":"alienate",
"alienations":"alienation",
"alienisms":"alienism",
"alighted":"alight",
"alighting":"alight",
"alit":"alight",
"aligned":"align",
"aligning":"align",
"aligns":"align",
"alignments":"alignment",
"alikenesses":"alikeness",
"alimented":"aliment",
"alimenting":"aliment",
"aliments":"aliment",
"alimentations":"alimentation",
"alimonies":"alimony",
"alinements":"alinement",
"aliquants":"aliquant",
"aliquots":"aliquot",
"alismas":"alisma",
"alismaleses":"alismales",
"alismataceaes":"alismataceae",
"alismatidaes":"alismatidae",
"aliterates":"aliterate",
"alivenesses":"aliveness",
"alizarins":"alizarin",
"alizarines":"alizarine",
"alkahests":"alkahest",
"alkalies":"alkali",
"alkalis":"alkali",
"alkalified":"alkalify",
"alkalifies":"alkalify",
"alkalifying":"alkalify",
"alkalinurias":"alkalinuria",
"alkalized":"alkalize",
"alkalizes":"alkalize",
"alkalizing":"alkalize",
"alkalizers":"alkalizer",
"alkalurias":"alkaluria",
"alkanes":"alkane",
"alkanets":"alkanet",
"alkenes":"alkene",
"alkerans":"alkeran",
"alkies":"alkie",
"alkyds":"alkyd",
"alkyls":"alkyl",
"all-rounders":"all-rounder",
"allantoides":"allantois",
"allayed":"allay",
"allaying":"allay",
"allays":"allay",
"allegations":"allegation",
"alleged":"allege",
"alleges":"allege",
"alleging":"allege",
"allegements":"allegement",
"alleghenieses":"alleghenies",
"allegiances":"allegiance",
"allegorized":"allegorize",
"allegorizing":"allegorize",
"allegories":"allegory",
"allegrettos":"allegretto",
"allegros":"allegro",
"alleles":"allele",
"allelomorphs":"allelomorph",
"alleluias":"alleluia",
"allemandes":"allemande",
"allergies":"allergy",
"alleviated":"alleviate",
"alleviates":"alleviate",
"alleviating":"alleviate",
"alleviations":"alleviation",
"alleys":"alley",
"alleyways":"alleyway",
"allgoods":"allgood",
"allhallowses":"allhallows",
"alliaceaes":"alliaceae",
"alliances":"alliance",
"alliarias":"alliaria",
"allices":"allice",
"alligators":"alligator",
"alligatorfishes":"alligatorfish",
"alligatoridaes":"alligatoridae",
"allionias":"allionia",
"allioniaceaes":"allioniaceae",
"allises":"allis",
"alliterated":"alliterate",
"alliterating":"alliterate",
"alliterations":"alliteration",
"alliums":"allium",
"allmouths":"allmouth",
"allocated":"allocate",
"allocates":"allocate",
"allocating":"allocate",
"allocations":"allocation",
"allods":"allod",
"allodia":"allodium",
"allografts":"allograft",
"allonges":"allonge",
"allopurinols":"allopurinol",
"allosaurs":"allosaur",
"allosauruses":"allosaurus",
"allots":"allot",
"allotted":"allot",
"allotting":"allot",
"allotments":"allotment",
"allotropisms":"allotropism",
"allotropies":"allotropy",
"allowed":"allow",
"allowing":"allow",
"allows":"allow",
"allowanced":"allowance",
"allowances":"allowance",
"allowancing":"allowance",
"allowed_for":"allow_for",
"allowing_for":"allow_for",
"allows_for":"allow_for",
"alloyed":"alloy",
"alloying":"alloy",
"alloys":"alloy",
"allspices":"allspice",
"alluded":"allude",
"alludes":"allude",
"alluding":"allude",
"allured":"allure",
"allures":"allure",
"alluring":"allure",
"allurements":"allurement",
"allusions":"allusion",
"alluviations":"alluviation",
"alluvia":"alluvium",
"alluviums":"alluvium",
"allied":"ally",
"allies":"ally",
"allying":"ally",
"allyls":"allyl",
"alma-atas":"alma-ata",
"almanacs":"almanac",
"almandines":"almandine",
"almandites":"almandite",
"almaties":"almaty",
"almighties":"almighty",
"almohads":"almohad",
"almohades":"almohade",
"almonds":"almond",
"almoners":"almoner",
"almonries":"almonry",
"almses":"alms",
"alms-givings":"alms-giving",
"almshouses":"almshouse",
"almsmen":"almsman",
"almswomen":"almswoman",
"alnuses":"alnus",
"alocasias":"alocasia",
"alodia":"alodium",
"aloes":"aloe",
"aloeaceaes":"aloeaceae",
"aloeses":"aloes",
"alohas":"aloha",
"alonenesses":"aloneness",
"aloofnesses":"aloofness",
"alopecuruses":"alopecurus",
"alopexes":"alopex",
"alopiidaes":"alopiidae",
"alopiuses":"alopius",
"alosas":"alosa",
"alouattas":"alouatta",
"alpacas":"alpaca",
"alphas":"alpha",
"alphabets":"alphabet",
"alphabetisations":"alphabetisation",
"alphabetizations":"alphabetization",
"alphabetized":"alphabetize",
"alphabetizing":"alphabetize",
"alpinias":"alpinia",
"alprazolams":"alprazolam",
"alpses":"alps",
"alses":"als",
"alsaces":"alsace",
"alsatias":"alsatia",
"Alsatians":"Alsatian",
"also-rans":"also-ran",
"alsobias":"alsobia",
"alsophilas":"alsophila",
"alstonias":"alstonia",
"alstroemeriaceaes":"alstroemeriaceae",
"alts":"alt",
"altaics":"altaic",
"altars":"altar",
"altarpieces":"altarpiece",
"altered":"alter",
"altering":"alter",
"alters":"alter",
"alterations":"alteration",
"altercated":"altercate",
"altercates":"altercate",
"altercating":"altercate",
"altercations":"altercation",
"alterings":"altering",
"alternantheras":"alternanthera",
"alternated":"alternate",
"alternates":"alternate",
"alternating":"alternate",
"alternations":"alternation",
"alternatives":"alternative",
"althaeas":"althaea",
"altheas":"althea",
"altimeters":"altimeter",
"altitudes":"altitude",
"altos":"alto",
"alto-relievos":"alto-relievo",
"alto-rilievos":"alto-rilievo",
"altocumuli":"altocumulus",
"altocumuluses":"altocumulus",
"altogethers":"altogether",
"altostrati":"altostratus",
"altostratuses":"altostratus",
"altruisms":"altruism",
"altruists":"altruist",
"alulae":"alula",
"alulas":"alula",
"alums":"alum",
"alumblooms":"alumbloom",
"aluminas":"alumina",
"aluminiums":"aluminium",
"aluminized":"aluminize",
"aluminizing":"aluminize",
"aluminums":"aluminum",
"alumnae":"alumna",
"alumnas":"alumna",
"alumni":"alumnus",
"alumroots":"alumroot",
"alupents":"alupent",
"alveolars":"alveolar",
"alveolitises":"alveolitis",
"alveoli":"alveolus",
"alveoluses":"alveolus",
"alyssums":"alyssum",
"alyteses":"alytes",
"alzheimerses":"alzheimers",
"ams":"am",
"amadavats":"amadavat",
"amahs":"amah",
"amalgams":"amalgam",
"amalgamated":"amalgamate",
"amalgamates":"amalgamate",
"amalgamating":"amalgamate",
"amalgamations":"amalgamation",
"amanitas":"amanita",
"amanuenses":"amanuensis",
"amaranthaceaes":"amaranthaceae",
"amaranthuses":"amaranthus",
"amarelles":"amarelle",
"amaryllidaceaes":"amaryllidaceae",
"amassed":"amass",
"amasses":"amass",
"amassing":"amass",
"amaterasus":"amaterasu",
"amateurs":"amateur",
"amativenesses":"amativeness",
"amatungulus":"amatungulu",
"amauropeltas":"amauropelta",
"amazed":"amaze",
"amazes":"amaze",
"amazing":"amaze",
"amazements":"amazement",
"Amazons":"Amazon",
"amazonas":"amazona",
"ambaris":"ambari",
"ambaries":"ambary",
"ambassadors":"ambassador",
"ambers":"amber",
"amberbells":"amberbell",
"amberboas":"amberboa",
"amberfishes":"amberfish",
"amberjacks":"amberjack",
"ambiances":"ambiance",
"ambidexterities":"ambidexterity",
"ambidextrousnesses":"ambidextrousness",
"ambiences":"ambience",
"ambiguities":"ambiguity",
"ambits":"ambit",
"ambitioned":"ambition",
"ambitioning":"ambition",
"ambitions":"ambition",
"ambitiousnesses":"ambitiousness",
"ambivalences":"ambivalence",
"ambivalencies":"ambivalency",
"ambled":"amble",
"ambles":"amble",
"ambling":"amble",
"amblers":"ambler",
"amblopliteses":"ambloplites",
"amblyrhynchuses":"amblyrhynchus",
"amboes":"ambo",
"ambos":"ambo",
"amboynas":"amboyna",
"ambrosias":"ambrosia",
"ambrosiaceaes":"ambrosiaceae",
"ambries":"ambry",
"ambulacra":"ambulacrum",
"ambulances":"ambulance",
"ambulated":"ambulate",
"ambulating":"ambulate",
"ambulatories":"ambulatory",
"ambuscaded":"ambuscade",
"ambuscades":"ambuscade",
"ambuscading":"ambuscade",
"ambushed":"ambush",
"ambushes":"ambush",
"ambushing":"ambush",
"ambystomas":"ambystoma",
"ambystomatidaes":"ambystomatidae",
"ambystomids":"ambystomid",
"amebae":"ameba",
"amebas":"ameba",
"amebiases":"amebiasis",
"amebioses":"amebiosis",
"ameers":"ameer",
"ameiuridaes":"ameiuridae",
"ameiuruses":"ameiurus",
"amelanchiers":"amelanchier",
"ameliorated":"ameliorate",
"ameliorates":"ameliorate",
"ameliorating":"ameliorate",
"ameliorations":"amelioration",
"amens":"amen",
"amen-ras":"amen-ra",
"amenabilities":"amenability",
"amenablenesses":"amenableness",
"amended":"amend",
"amending":"amend",
"amends":"amend",
"amendments":"amendment",
"amendses":"amends",
"amenias":"amenia",
"amenitieses":"amenities",
"amenities":"amenity",
"amenorrheas":"amenorrhea",
"amenorrhoeas":"amenorrhoea",
"aments":"ament",
"amentias":"amentia",
"amentiferaes":"amentiferae",
"amerced":"amerce",
"amercing":"amerce",
"amercements":"amercement",
"americas":"america",
"Americans":"American",
"americanized":"americanize",
"Americanizing":"Americanize",
"americiums":"americium",
"amerinds":"amerind",
"amerindians":"amerindian",
"amexes":"amex",
"amharics":"amharic",
"amias":"amia",
"amiabilities":"amiability",
"amiablenesses":"amiableness",
"amianthums":"amianthum",
"amicabilities":"amicability",
"amicablenesses":"amicableness",
"amidopyrines":"amidopyrine",
"amigos":"amigo",
"amiidaes":"amiidae",
"amines":"amine",
"aminoalkanes":"aminoalkane",
"aminobenzines":"aminobenzine",
"aminophyllines":"aminophylline",
"aminoplasts":"aminoplast",
"aminopyrines":"aminopyrine",
"amiodarones":"amiodarone",
"amirs":"amir",
"amitriptylines":"amitriptyline",
"amities":"amity",
"ammos":"ammo",
"ammodyteses":"ammodytes",
"ammodytidaes":"ammodytidae",
"ammonias":"ammonia",
"ammoniacs":"ammoniac",
"ammoniated":"ammoniate",
"ammoniating":"ammoniate",
"ammonified":"ammonify",
"ammonifies":"ammonify",
"ammonifying":"ammonify",
"ammonites":"ammonite",
"ammoniums":"ammonium",
"ammonoids":"ammonoid",
"ammotraguses":"ammotragus",
"ammunitions":"ammunition",
"amnesias":"amnesia",
"amnesiacs":"amnesiac",
"amnesics":"amnesic",
"amnestied":"amnesty",
"amnesties":"amnesty",
"amnestying":"amnesty",
"amniocenteses":"amniocentesis",
"amnia":"amnion",
"amnions":"amnion",
"amnioses":"amnios",
"amoebae":"amoeba",
"amoebas":"amoeba",
"amoebiases":"amoebiasis",
"amoebidas":"amoebida",
"amoebinas":"amoebina",
"amoebioses":"amoebiosis",
"amoles":"amole",
"amons":"amon",
"amon-ras":"amon-ra",
"amors":"amor",
"amoretretti":"amoretto",
"amoretti":"amoretto",
"amorini":"amorino",
"amoririni":"amorino",
"amorousnesses":"amorousness",
"amortisations":"amortisation",
"amortizations":"amortization",
"amounted":"amount",
"amounting":"amount",
"amounts":"amount",
"amours":"amour",
"amoxicillins":"amoxicillin",
"amoxils":"amoxil",
"amoys":"amoy",
"amps":"amp",
"amperes":"ampere",
"ampere-seconds":"ampere-second",
"amphetamines":"amphetamine",
"amphiarthroses":"amphiarthrosis",
"amphibias":"amphibia",
"amphibians":"amphibian",
"amphibolipses":"amphibolips",
"amphibologies":"amphibology",
"amphibolies":"amphiboly",
"amphicarpas":"amphicarpa",
"amphicarpaeas":"amphicarpaea",
"amphictyonies":"amphictyony",
"amphigories":"amphigory",
"amphigouris":"amphigouri",
"amphimixes":"amphimixis",
"amphineuras":"amphineura",
"amphioxidaes":"amphioxidae",
"amphioxi":"amphioxus",
"amphioxuses":"amphioxus",
"amphipodas":"amphipoda",
"amphiprions":"amphiprion",
"amphisbaenae":"amphisbaena",
"amphisbaenas":"amphisbaena",
"amphisbaenias":"amphisbaenia",
"amphisbaenidaes":"amphisbaenidae",
"amphitheaters":"amphitheater",
"amphitheatres":"amphitheatre",
"amphicia":"amphithecium",
"amphithecia":"amphithecium",
"amphiumas":"amphiuma",
"amphiumidaes":"amphiumidae",
"amphophorae":"amphora",
"amphophoras":"amphora",
"amphorae":"amphora",
"amphoras":"amphora",
"ampicillins":"ampicillin",
"ampler":"ample",
"amplest":"ample",
"amplifications":"amplification",
"amplified":"amplify",
"amplifies":"amplify",
"amplifying":"amplify",
"amplitudes":"amplitude",
"ampoules":"ampoule",
"ampuls":"ampul",
"ampules":"ampule",
"ampullae":"ampulla",
"amputated":"amputate",
"amputates":"amputate",
"amputating":"amputate",
"amrinones":"amrinone",
"amsinckias":"amsinckia",
"amsonias":"amsonia",
"amsterdams":"amsterdam",
"amulets":"amulet",
"amurs":"amur",
"amusds":"amusd",
"amused":"amuse",
"amuses":"amuse",
"amusing":"amuse",
"amusements":"amusement",
"amygdalae":"amygdala",
"amygdalas":"amygdala",
"amygdalaceaes":"amygdalaceae",
"amygdaluses":"amygdalus",
"amylums":"amylum",
"amyotonias":"amyotonia",
"amyotrophias":"amyotrophia",
"amyotrophies":"amyotrophy",
"amytals":"amytal",
"ans":"an",
"anabaenas":"anabaena",
"anabases":"anabasis",
"anabolisms":"anabolism",
"anabruses":"anabrus",
"anacanthinis":"anacanthini",
"anacardiaceaes":"anacardiaceae",
"anacardiums":"anacardium",
"anachronisms":"anachronism",
"anacoluthias":"anacoluthia",
"anacoluthons":"anacoluthon",
"anacondas":"anaconda",
"anacruses":"anacrusis",
"anacycluses":"anacyclus",
"anadenantheras":"anadenanthera",
"anadiploses":"anadiplosis",
"anaemias":"anaemia",
"anaerobes":"anaerobe",
"anaerobia":"anaerobium",
"anaesthesias":"anaesthesia",
"anaesthetics":"anaesthetic",
"anaesthetists":"anaesthetist",
"anagallises":"anagallis",
"anagastas":"anagasta",
"anagnorises":"anagnorisis",
"anagrammatized":"anagrammatize",
"anagrammatizes":"anagrammatize",
"anagrammatizing":"anagrammatize",
"anagyrises":"anagyris",
"analectas":"analecta",
"analectses":"analects",
"analemmas":"analemma",
"analemmata":"analemma",
"analgesics":"analgesic",
"analogs":"analog",
"analogized":"analogize",
"analogizing":"analogize",
"analogues":"analogue",
"analogies":"analogy",
"analphabetics":"analphabetic",
"analysed":"analyse",
"analyses":"analyse",
"analysing":"analyse",
"analysers":"analyser",
"analysts":"analyst",
"analyzed":"analyze",
"analyzes":"analyze",
"analyzing":"analyze",
"analyzers":"analyzer",
"anamneses":"anamnesis",
"anamorphoses":"anamorphosis",
"ananases":"ananas",
"anapaests":"anapaest",
"anapests":"anapest",
"anaphalises":"anaphalis",
"anaphoras":"anaphora",
"anaplasties":"anaplasty",
"anaproxes":"anaprox",
"anapsids":"anapsid",
"anapsidas":"anapsida",
"anatyxes":"anaptyxis",
"anapurnas":"anapurna",
"anarchists":"anarchist",
"anarchies":"anarchy",
"anarhichadidaes":"anarhichadidae",
"anarhichases":"anarhichas",
"anases":"anas",
"anasas":"anasa",
"anaspidas":"anaspida",
"anastaticas":"anastatica",
"anastomoses":"anastomosis",
"anastomuses":"anastomus",
"anastrophes":"anastrophe",
"anathemas":"anathema",
"anathematized":"anathematize",
"anathematizes":"anathematize",
"anathematizing":"anathematize",
"anatidaes":"anatidae",
"anatolias":"anatolia",
"anatolians":"anatolian",
"anatomicals":"anatomical",
"anatomized":"anatomize",
"anatomizes":"anatomize",
"anatomizing":"anatomize",
"anatomies":"anatomy",
"anattos":"anatto",
"anburies":"anbury",
"ancestors":"ancestor",
"ancestries":"ancestry",
"anchored":"anchor",
"anchoring":"anchor",
"anchors":"anchor",
"anchorages":"anchorage",
"anchorites":"anchorite",
"anchormen":"anchorman",
"anchorpersons":"anchorperson",
"anchorwomen":"anchorwoman",
"anchovies":"anchovy",
"anchyloses":"anchylosis",
"ancients":"ancient",
"ancientnesses":"ancientness",
"ancillas":"ancilla",
"ancillaries":"ancillary",
"ancistrodons":"ancistrodon",
"ancones":"ancon",
"ancylidaes":"ancylidae",
"ancylostomatidaes":"ancylostomatidae",
"ancyluses":"ancylus",
"andalucias":"andalucia",
"andalusias":"andalusia",
"andantes":"andante",
"andantinos":"andantino",
"andelmins":"andelmin",
"andersens":"andersen",
"andiras":"andira",
"andirons":"andiron",
"andreaeas":"andreaea",
"andreaealeses":"andreaeales",
"andrenas":"andrena",
"andrenids":"andrenid",
"andrenidaes":"andrenidae",
"andrews":"andrew",
"andricuses":"andricus",
"androclinia":"androclinium",
"androecia":"androecium",
"androgens":"androgen",
"androgeneses":"androgenesis",
"androgenies":"androgeny",
"androgynes":"androgyne",
"androgynies":"androgyny",
"androids":"android",
"andromedas":"andromeda",
"andropogons":"andropogon",
"androsphinges":"androsphinx",
"androsphinxes":"androsphinx",
"anecdotes":"anecdote",
"anecdotists":"anecdotist",
"aneideses":"aneides",
"anemias":"anemia",
"anemometers":"anemometer",
"anemones":"anemone",
"anemonellas":"anemonella",
"anemopses":"anemopsis",
"anencephalias":"anencephalia",
"anencephalies":"anencephaly",
"aneroids":"aneroid",
"anesthesias":"anesthesia",
"anesthesiologists":"anesthesiologist",
"anesthetics":"anesthetic",
"anesthetists":"anesthetist",
"anesthetized":"anesthetize",
"anesthetizes":"anesthetize",
"anesthetizing":"anesthetize",
"anestrums":"anestrum",
"anestruses":"anestrus",
"anethums":"anethum",
"aneurins":"aneurin",
"anfractuosities":"anfractuosity",
"angeled":"angel",
"angeling":"angel",
"angels":"angel",
"angelenos":"angeleno",
"angelfishes":"angelfish",
"angelicas":"angelica",
"angelims":"angelim",
"angeliques":"angelique",
"angeluses":"angelus",
"angered":"anger",
"angering":"anger",
"angers":"anger",
"angevins":"angevin",
"angevines":"angevine",
"anginas":"angina",
"angiohemophilias":"angiohemophilia",
"angiomas":"angioma",
"angiomata":"angioma",
"angiopterises":"angiopteris",
"angiosperms":"angiosperm",
"angiospermaes":"angiospermae",
"angiotensins":"angiotensin",
"angiotonins":"angiotonin",
"angled":"angle",
"angles":"angle",
"angling":"angle",
"anglers":"angler",
"anglerfishes":"anglerfish",
"angleworms":"angleworm",
"anglicised":"anglicise",
"anglicises":"anglicise",
"anglicising":"anglicise",
"anglicisms":"anglicism",
"anglicized":"anglicize",
"anglicizes":"anglicize",
"anglicizing":"anglicize",
"anglified":"anglify",
"anglifies":"anglify",
"anglifying":"anglify",
"anglos":"anglo",
"anglo-catholicisms":"anglo-catholicism",
"anglo-frenches":"anglo-french",
"anglo-normen":"anglo-norman",
"Anglo-Saxons":"Anglo-Saxon",
"anglophils":"anglophil",
"anglophiles":"anglophile",
"angoras":"angora",
"argoras":"angora",
"angosturas":"angostura",
"angraecums":"angraecum",
"angrinesses":"angriness",
"angrier":"angry",
"angriest":"angry",
"angstroms":"angstrom",
"anguidaes":"anguidae",
"anguillas":"anguilla",
"anguillidaes":"anguillidae",
"anguilliformeses":"anguilliformes",
"anguillulas":"anguillula",
"anguises":"anguis",
"anguished":"anguish",
"anguishes":"anguish",
"anguishing":"anguish",
"angularities":"angularity",
"angulated":"angulate",
"angulating":"angulate",
"anguses":"angus",
"angwantibos":"angwantibo",
"anhimas":"anhima",
"anhimidaes":"anhimidae",
"anhingas":"anhinga",
"anhingidaes":"anhingidae",
"anis":"ani",
"anigozanthuses":"anigozanthus",
"anils":"anil",
"anilines":"aniline",
"animas":"anima",
"animadversions":"animadversion",
"animadverted":"animadvert",
"animadverting":"animadvert",
"animadverts":"animadvert",
"animals":"animal",
"animal-worships":"animal-worship",
"animalcules":"animalcule",
"animalcula":"animalculum",
"animalculums":"animalculum",
"animalias":"animalia",
"animalisations":"animalisation",
"animalisms":"animalism",
"animalities":"animality",
"animalizations":"animalization",
"animalized":"animalize",
"animalizing":"animalize",
"animated":"animate",
"animates":"animate",
"animating":"animate",
"animatenesses":"animateness",
"animations":"animation",
"animators":"animator",
"animes":"anime",
"animosities":"animosity",
"animuses":"animus",
"anionics":"anionic",
"anises":"anise",
"aniseeds":"aniseed",
"anisettes":"anisette",
"anisopteras":"anisoptera",
"anisotremuses":"anisotremus",
"ankaras":"ankara",
"ankles":"ankle",
"anklebones":"anklebone",
"anklets":"anklet",
"ankletses":"anklets",
"ankuses":"ankus",
"ankyloglossias":"ankyloglossia",
"ankylosaurs":"ankylosaur",
"ankylosauruses":"ankylosaurus",
"ankyloses":"ankylosis",
"anlagen":"anlage",
"anlages":"anlage",
"annalses":"annals",
"annams":"annam",
"annameses":"annamese",
"annamites":"annamite",
"annapolises":"annapolis",
"annapurnas":"annapurna",
"annattos":"annatto",
"annealed":"anneal",
"annealing":"anneal",
"anneals":"anneal",
"annealings":"annealing",
"annelids":"annelid",
"annelidas":"annelida",
"annexed":"annex",
"annexes":"annex",
"annexing":"annex",
"annexas":"annexa",
"annexations":"annexation",
"anniellidaes":"anniellidae",
"annihilated":"annihilate",
"annihilates":"annihilate",
"annihilating":"annihilate",
"annihilations":"annihilation",
"annihilators":"annihilator",
"anniversaries":"anniversary",
"annonas":"annona",
"annonaceaes":"annonaceae",
"annotated":"annotate",
"annotates":"annotate",
"annotating":"annotate",
"annotatings":"annotating",
"annotations":"annotation",
"announced":"announce",
"announces":"announce",
"announcing":"announce",
"announcements":"announcement",
"announcers":"announcer",
"annoyed":"annoy",
"annoying":"annoy",
"annoys":"annoy",
"annoyances":"annoyance",
"annoyers":"annoyer",
"annoyings":"annoying",
"annuals":"annual",
"annualries":"annualry",
"annuitants":"annuitant",
"annuities":"annuity",
"annulled":"annul",
"annulling":"annul",
"annuls":"annul",
"annulets":"annulet",
"annulments":"annulment",
"annuli":"annulus",
"annuluses":"annulus",
"annunciated":"annunciate",
"annunciates":"annunciate",
"annunciating":"annunciate",
"annunciations":"annunciation",
"annwfns":"annwfn",
"annwns":"annwn",
"anoas":"anoa",
"anobiidaes":"anobiidae",
"anodized":"anodize",
"anodizing":"anodize",
"anodontas":"anodonta",
"anodynes":"anodyne",
"anoectochiluses":"anoectochilus",
"anoestrums":"anoestrum",
"anoestruses":"anoestrus",
"anogrammas":"anogramma",
"anointed":"anoint",
"anointing":"anoint",
"anoints":"anoint",
"anointings":"anointing",
"anointments":"anointment",
"anoles":"anole",
"anolises":"anolis",
"anomalas":"anomala",
"anomalopidaes":"anomalopidae",
"anomalopses":"anomalops",
"anomalopteryxes":"anomalopteryx",
"anomalousnesses":"anomalousness",
"anomalies":"anomaly",
"anomias":"anomia",
"anomiidaes":"anomiidae",
"anons":"anon",
"anonyms":"anonym",
"anonymities":"anonymity",
"anopheleses":"anopheles",
"anopluras":"anoplura",
"anoraks":"anorak",
"anorchias":"anorchia",
"anorchidisms":"anorchidism",
"anorchisms":"anorchism",
"anorthographies":"anorthography",
"anosmias":"anosmia",
"anostracas":"anostraca",
"anses":"ans",
"ansaids":"ansaid",
"ansers":"anser",
"ansereses":"anseres",
"anseriformeses":"anseriformes",
"anserinaes":"anserinae",
"answered":"answer",
"answering":"answer",
"answers":"answer",
"answerabilities":"answerability",
"answerablenesses":"answerableness",
"answerers":"answerer",
"ants":"ant",
"antae":"anta",
"antabuses":"antabuse",
"antacids":"antacid",
"antagonisms":"antagonism",
"antagonists":"antagonist",
"antagonized":"antagonize",
"antagonizes":"antagonize",
"antagonizing":"antagonize",
"antalkalies":"antalkali",
"antalkalis":"antalkali",
"antananarivos":"antananarivo",
"antarctics":"antarctic",
"antarcticas":"antarctica",
"antbirds":"antbird",
"anted":"ante",
"anteed":"ante",
"anteing":"ante",
"antes":"ante",
"anteaters":"anteater",
"antecedences":"antecedence",
"antecedencies":"antecedency",
"antecedents":"antecedent",
"antechambers":"antechamber",
"antedated":"antedate",
"antedates":"antedate",
"antedating":"antedate",
"antediluvians":"antediluvian",
"antedons":"antedon",
"antedonidaes":"antedonidae",
"antefixa":"antefix",
"antefixes":"antefix",
"antelopes":"antelope",
"antennae":"antenna",
"antennas":"antenna",
"antennarias":"antennaria",
"antennariidaes":"antennariidae",
"antependia":"antependium",
"antepenults":"antepenult",
"antepenultimates":"antepenultimate",
"anteriors":"anterior",
"anteriorities":"anteriority",
"anterooms":"anteroom",
"anthelia":"anthelion",
"anthelices":"anthelix",
"anthelminthics":"anthelminthic",
"anthelmintics":"anthelmintic",
"anthems":"anthem",
"anthemia":"anthemion",
"anthemises":"anthemis",
"anthers":"anther",
"antheraeas":"antheraea",
"anthericums":"anthericum",
"antheridia":"antheridium",
"antheridiia":"antheridium",
"antheropeases":"antheropeas",
"antherozoids":"antherozoid",
"antheses":"anthesis",
"anthidiums":"anthidium",
"anthoceropsidas":"anthoceropsida",
"anthoceroses":"anthoceros",
"anthocerotaceaes":"anthocerotaceae",
"anthocerotaleses":"anthocerotales",
"anthodia":"anthodium",
"anthologized":"anthologize",
"anthologizing":"anthologize",
"anthologies":"anthology",
"anthonomuses":"anthonomus",
"anthophytas":"anthophyta",
"anthozoas":"anthozoa",
"anthozoans":"anthozoan",
"anthracites":"anthracite",
"anthracoses":"anthracosis",
"anthraces":"anthrax",
"anthraxes":"anthrax",
"anthriscuses":"anthriscus",
"anthropocentricities":"anthropocentricity",
"anthropocentrisms":"anthropocentrism",
"anthropogeneses":"anthropogenesis",
"anthropogenies":"anthropogeny",
"anthropoids":"anthropoid",
"anthropoideas":"anthropoidea",
"anthropolatries":"anthropolatry",
"anthropomorphisms":"anthropomorphism",
"anthropomorphized":"anthropomorphize",
"anthropomorphizing":"anthropomorphize",
"anthropophagus":"anthropophagi",
"anthropophagites":"anthropophagite",
"anthropophaguses":"anthropophagus",
"anthuriums":"anthurium",
"anthuses":"anthus",
"anthyllises":"anthyllis",
"antis":"anti",
"anti-heroes":"anti-hero",
"anti-inflammatories":"anti-inflammatory",
"anti-semites":"anti-semite",
"antiaircrafts":"antiaircraft",
"antiarrhythmics":"antiarrhythmic",
"antibacterials":"antibacterial",
"antibiotics":"antibiotic",
"antibodies":"antibody",
"anticked":"antic",
"anticking":"antic",
"antics":"antic",
"anticipated":"anticipate",
"anticipates":"anticipate",
"anticipating":"anticipate",
"anticipations":"anticipation",
"anticipators":"anticipator",
"anticlimaxes":"anticlimax",
"anticlinonoria":"anticlinorium",
"anticoagulants":"anticoagulant",
"anticonvulsants":"anticonvulsant",
"antidepressants":"antidepressant",
"antidiabetics":"antidiabetic",
"antidiarrheals":"antidiarrheal",
"antidiuretics":"antidiuretic",
"antidorcases":"antidorcas",
"antidotes":"antidote",
"antielectrons":"antielectron",
"antiemetics":"antiemetic",
"antiepileptics":"antiepileptic",
"antifeminisms":"antifeminism",
"antifungals":"antifungal",
"antigonias":"antigonia",
"antigonuses":"antigonus",
"antihelices":"antihelix",
"antihelixes":"antihelix",
"antiheroes":"antihero",
"antihypertensives":"antihypertensive",
"antilocapras":"antilocapra",
"antilocapridaes":"antilocapridae",
"antilogs":"antilog",
"antilogarithms":"antilogarithm",
"antilogies":"antilogy",
"antilopes":"antilope",
"antimalarials":"antimalarial",
"antimicrobials":"antimicrobial",
"antimicrobics":"antimicrobic",
"antimonies":"antimony",
"antimuons":"antimuon",
"antimycotics":"antimycotic",
"antineoplastics":"antineoplastic",
"antineutrinos":"antineutrino",
"antinomies":"antinomy",
"antipasti":"antipasto",
"antipastos":"antipasto",
"antipathies":"antipathy",
"antiphons":"antiphon",
"antiphonals":"antiphonal",
"antiphonaries":"antiphonary",
"antiphonies":"antiphony",
"antipodals":"antipodal",
"antipsychotics":"antipsychotic",
"antipyretics":"antipyretic",
"antiquarians":"antiquarian",
"antiquaries":"antiquary",
"antiquated":"antiquate",
"antiquates":"antiquate",
"antiquating":"antiquate",
"antiqued":"antique",
"antiques":"antique",
"antiquing":"antique",
"antiquities":"antiquity",
"antirrhinums":"antirrhinum",
"antisepses":"antisepsis",
"antiseptics":"antiseptic",
"antisepticized":"antisepticize",
"antisepticizing":"antisepticize",
"antisera":"antiserum",
"antiserums":"antiserum",
"antispasmodics":"antispasmodic",
"antitauons":"antitauon",
"antitheses":"antithesis",
"antitoxins":"antitoxin",
"antitrades":"antitrade",
"antitragi":"antitragus",
"antiverts":"antivert",
"antlions":"antlion",
"antonies":"antony",
"antonyms":"antonym",
"antrozouses":"antrozous",
"antra":"antrum",
"antwerps":"antwerp",
"antwerpens":"antwerpen",
"anuluses":"anulus",
"anunnakis":"anunnaki",
"anuras":"anura",
"anurans":"anuran",
"anureses":"anuresis",
"anurias":"anuria",
"anuses":"anus",
"anverses":"anvers",
"anvils":"anvil",
"anxieties":"anxiety",
"anxiolytics":"anxiolytic",
"anxiousnesses":"anxiousness",
"anybodies":"anybody",
"aortae":"aorta",
"aortas":"aorta",
"aotuses":"aotus",
"aoudads":"aoudad",
"Apaches":"Apache",
"apalachicolas":"apalachicola",
"apanages":"apanage",
"apars":"apar",
"aparejos":"aparejo",
"apartheids":"apartheid",
"apartments":"apartment",
"apathies":"apathy",
"apatosaurs":"apatosaur",
"apatosauruses":"apatosaurus",
"apaturas":"apatura",
"aped":"ape",
"apes":"ape",
"aping":"ape",
"ape-men":"ape-man",
"apemen":"apeman",
"apers":"aper",
"apereas":"aperea",
"aperients":"aperient",
"apertures":"aperture",
"aperies":"apery",
"apexes":"apex",
"apices":"apex",
"aphaereses":"aphaeresis",
"aphasmidias":"aphasmidia",
"aphelia":"aphelion",
"aphelilia":"aphelion",
"aphereses":"apheresis",
"aphididaes":"aphididae",
"aphidoideas":"aphidoidea",
"aphides":"aphis",
"aphises":"aphis",
"aphonias":"aphonia",
"aphorisms":"aphorism",
"aphorized":"aphorize",
"aphorizing":"aphorize",
"aphrizas":"aphriza",
"aphrodites":"aphrodite",
"aphrophoras":"aphrophora",
"aphyllanthaceaes":"aphyllanthaceae",
"aphyllantheses":"aphyllanthes",
"aphyllophoraleses":"aphyllophorales",
"apias":"apia",
"apiaceaes":"apiaceae",
"apiarists":"apiarist",
"apiaries":"apiary",
"apicultures":"apiculture",
"apiculturists":"apiculturist",
"apidaes":"apidae",
"apioses":"apios",
"apises":"apis",
"apiums":"apium",
"aplacophoras":"aplacophora",
"aplacophorans":"aplacophoran",
"aplectrums":"aplectrum",
"aplodontias":"aplodontia",
"aplodontiidaes":"aplodontiidae",
"aplombs":"aplomb",
"aplysias":"aplysia",
"aplysiidaes":"aplysiidae",
"apoapses":"apoapsis",
"apocalypses":"apocalypse",
"apocopated":"apocopate",
"apocopating":"apocopate",
"apocynaceaes":"apocynaceae",
"apocynums":"apocynum",
"apodemuses":"apodemus",
"apodidaes":"apodidae",
"apodiformeses":"apodiformes",
"apodoses":"apodosis",
"apogees":"apogee",
"apogons":"apogon",
"apogonidaes":"apogonidae",
"apoideas":"apoidea",
"apollos":"apollo",
"apologetics":"apologetic",
"apologias":"apologia",
"apologists":"apologist",
"apologized":"apologize",
"apologizes":"apologize",
"apologizing":"apologize",
"apologues":"apologue",
"apologies":"apology",
"apolunes":"apolune",
"apomixes":"apomixis",
"aponeuroses":"aponeurosis",
"apophthegms":"apophthegm",
"apophyses":"apophysis",
"apoplexies":"apoplexy",
"aporocactuses":"aporocactus",
"aposelenes":"aposelene",
"aposiopeses":"aposiopesis",
"apostasies":"apostasy",
"apostates":"apostate",
"apostatized":"apostatize",
"apostatizes":"apostatize",
"apostatizing":"apostatize",
"apostrophized":"apostrophize",
"apostrophizing":"apostrophize",
"apothecaries":"apothecary",
"apothecia":"apothecium",
"apothegms":"apothegm",
"apotheoses":"apotheosis",
"apotheosized":"apotheosize",
"apotheosizes":"apotheosize",
"apotheosizing":"apotheosize",
"appalled":"appal",
"appalling":"appal",
"appals":"appal",
"appalachianses":"appalachians",
"appalls":"appall",
"Appaloosas":"Appaloosa",
"appanages":"appanage",
"apparatuses":"apparatus",
"appareled":"apparel",
"appareling":"apparel",
"apparelled":"apparel",
"apparelling":"apparel",
"apparels":"apparel",
"apparencies":"apparency",
"apparentnesses":"apparentness",
"apparitions":"apparition",
"appealed":"appeal",
"appealing":"appeal",
"appeals":"appeal",
"appealingnesses":"appealingness",
"appeared":"appear",
"appearing":"appear",
"appears":"appear",
"appearances":"appearance",
"appearings":"appearing",
"appeased":"appease",
"appeases":"appease",
"appeasing":"appease",
"appeasements":"appeasement",
"appeasers":"appeaser",
"appellants":"appellant",
"appellations":"appellation",
"appellatives":"appellative",
"appended":"append",
"appending":"append",
"appends":"append",
"appendages":"appendage",
"appendectomies":"appendectomy",
"appendicectomies":"appendectomy",
"appendices":"appendix",
"appendixed":"appendix",
"appendixes":"appendix",
"appendixing":"appendix",
"apperceived":"apperceive",
"apperceiving":"apperceive",
"appertained":"appertain",
"appertaining":"appertain",
"appertains":"appertain",
"appetences":"appetence",
"appetencies":"appetency",
"appetites":"appetite",
"applauded":"applaud",
"applauding":"applaud",
"applauds":"applaud",
"applauders":"applauder",
"applauses":"applause",
"apples":"apple",
"apple-polished":"apple-polish",
"apple-polishing":"apple-polish",
"applemints":"applemint",
"applesauces":"applesauce",
"appliances":"appliance",
"applicabilities":"applicability",
"applicants":"applicant",
"applications":"application",
"applicators":"applicator",
"appliers":"applier",
"appliqued":"applique",
"appliqueing":"applique",
"appliques":"applique",
"applied":"apply",
"applies":"apply",
"applying":"apply",
"appoggiaturas":"appoggiatura",
"appointed":"appoint",
"appointing":"appoint",
"appoints":"appoint",
"appointees":"appointee",
"appointments":"appointment",
"apportioned":"apportion",
"apportioning":"apportion",
"apportions":"apportion",
"apportionings":"apportioning",
"apportionments":"apportionment",
"apposed":"appose",
"apposing":"appose",
"appositenesses":"appositeness",
"appraisals":"appraisal",
"appraised":"appraise",
"appraises":"appraise",
"appraising":"appraise",
"appraisers":"appraiser",
"appreciated":"appreciate",
"appreciates":"appreciate",
"appreciating":"appreciate",
"appreciations":"appreciation",
"appreciativenesses":"appreciativeness",
"appreciators":"appreciator",
"apprehended":"apprehend",
"apprehending":"apprehend",
"apprehends":"apprehend",
"apprehensions":"apprehension",
"apprehensivenesses":"apprehensiveness",
"apprenticed":"apprentice",
"apprentices":"apprentice",
"apprenticing":"apprentice",
"apprenticeships":"apprenticeship",
"apprisals":"apprisal",
"apprised":"apprise",
"apprises":"apprise",
"apprising":"apprise",
"apprized":"apprize",
"apprizes":"apprize",
"apprizing":"apprize",
"approached":"approach",
"approaches":"approach",
"approaching":"approach",
"approachabilities":"approachability",
"approachings":"approaching",
"approbated":"approbate",
"approbating":"approbate",
"appropriated":"appropriate",
"appropriates":"appropriate",
"appropriating":"appropriate",
"appropriatenesses":"appropriateness",
"appropriations":"appropriation",
"appropriators":"appropriator",
"approvals":"approval",
"approved":"approve",
"approves":"approve",
"approving":"approve",
"approvers":"approver",
"approvings":"approving",
"approximated":"approximate",
"approximates":"approximate",
"approximating":"approximate",
"approximations":"approximation",
"appurtenances":"appurtenance",
"appurtenanceses":"appurtenances",
"aprs":"apr",
"apricots":"apricot",
"Aprils":"April",
"aprons":"apron",
"apses":"apse",
"apter":"apt",
"aptest":"apt",
"aptenodyteses":"aptenodytes",
"apterygidaes":"apterygidae",
"apterygiformeses":"apterygiformes",
"apteryxes":"apteryx",
"aptitudes":"aptitude",
"aptnesses":"aptness",
"apulias":"apulia",
"apuses":"apus",
"aqabas":"aqaba",
"aquae":"aqua",
"aquas":"aqua",
"aqualungs":"aqualung",
"aquamarines":"aquamarine",
"aquanauts":"aquanaut",
"aquaria":"aquarium",
"aquariums":"aquarium",
"aquarii":"aquarius",
"aquariuses":"aquarius",
"aquatics":"aquatic",
"aquaticses":"aquatics",
"aquavits":"aquavit",
"aqueducts":"aqueduct",
"aquicultures":"aquiculture",
"aquifoliaceaes":"aquifoliaceae",
"aquilas":"aquila",
"aquileges":"aquilege",
"aquilegias":"aquilegia",
"aquinases":"aquinas",
"aquitaines":"aquitaine",
"aquitanias":"aquitania",
"ars":"ar",
"aras":"ara",
"Arabs":"Arab",
"arabias":"arabia",
"Arabians":"Arabian",
"arabics":"arabic",
"arabises":"arabis",
"arabized":"arabize",
"arabizing":"arabize",
"araceaes":"araceae",
"arachises":"arachis",
"arachnids":"arachnid",
"arachnidas":"arachnida",
"arachnoids":"arachnoid",
"araks":"arak",
"araleses":"arales",
"araliaceaes":"araliaceae",
"aramuses":"aramus",
"araneas":"aranea",
"araneaes":"araneae",
"araneidas":"araneida",
"araneuses":"araneus",
"arapahos":"arapaho",
"arapahoes":"arapahoe",
"ararats":"ararat",
"araribas":"arariba",
"ararobas":"araroba",
"araucarias":"araucaria",
"araucariaceaes":"araucariaceae",
"araujias":"araujia",
"arawaks":"arawak",
"arawakans":"arawakan",
"arbs":"arb",
"arbiters":"arbiter",
"arbitragers":"arbitrager",
"arbitrageurs":"arbitrageur",
"arbitraments":"arbitrament",
"arbitrarinesses":"arbitrariness",
"arbitraries":"arbitrary",
"arbitrated":"arbitrate",
"arbitrates":"arbitrate",
"arbitrating":"arbitrate",
"arbitrations":"arbitration",
"arbitrators":"arbitrator",
"arbitrements":"arbitrement",
"arbores":"arbor",
"arbors":"arbor",
"arboreta":"arboretum",
"arboretums":"arboretum",
"arboricultures":"arboriculture",
"arboriculturists":"arboriculturist",
"arborized":"arborize",
"arborizes":"arborize",
"arborizing":"arborize",
"arborolatries":"arborolatry",
"arbours":"arbour",
"arbutuses":"arbutus",
"arced":"arc",
"arcing":"arc",
"arcs":"arc",
"arc-boutants":"arc-boutant",
"arcas":"arca",
"arcades":"arcade",
"arcana":"arcanum",
"arcanums":"arcanum",
"arcdegrees":"arcdegree",
"arcellidaes":"arcellidae",
"arceuthobiums":"arceuthobium",
"arched":"arch",
"archer":"arch",
"arches":"arch",
"archest":"arch",
"arching":"arch",
"archaebacterias":"archaebacteria",
"archaebacteriums":"archaebacterium",
"archaeobacterias":"archaeobacteria",
"archaeologists":"archaeologist",
"archaeologies":"archaeology",
"archaeopteryxes":"archaeopteryx",
"archaeornitheses":"archaeornithes",
"archaeozoics":"archaeozoic",
"archaicisms":"archaicism",
"archaisms":"archaism",
"archaized":"archaize",
"archaizing":"archaize",
"archangels":"archangel",
"archbishops":"archbishop",
"archdeaconries":"archdeaconry",
"archduchies":"archduchy",
"archegonia":"archegonium",
"archenemies":"archenemy",
"archentera":"archenteron",
"archeologists":"archeologist",
"archeologies":"archeology",
"archeopteryxes":"archeopteryx",
"archeozoics":"archeozoic",
"archers":"archer",
"archerfishes":"archerfish",
"archespores":"archespore",
"archesporiums":"archesporium",
"archetypes":"archetype",
"archiannelidas":"archiannelida",
"archidiskidons":"archidiskidon",
"archils":"archil",
"archilochuses":"archilochus",
"archimandrites":"archimandrite",
"archipalliums":"archipallium",
"archipelagoes":"archipelago",
"archipelagos":"archipelago",
"architects":"architect",
"architectonicses":"architectonics",
"architectures":"architecture",
"architeuthises":"architeuthis",
"archived":"archive",
"archives":"archive",
"archiving":"archive",
"archiveses":"archives",
"archnesses":"archness",
"archosarguses":"archosargus",
"archosaurs":"archosaur",
"archosaurias":"archosauria",
"archosaurians":"archosaurian",
"archpriests":"archpriest",
"archways":"archway",
"arcidaes":"arcidae",
"arcminutes":"arcminute",
"arcseconds":"arcsecond",
"arctics":"arctic",
"arctictises":"arctictis",
"arctiids":"arctiid",
"arctiidaes":"arctiidae",
"arctiums":"arctium",
"arctocebuses":"arctocebus",
"arctocephaluses":"arctocephalus",
"arctonyxes":"arctonyx",
"arctostaphyloses":"arctostaphylos",
"arctotises":"arctotis",
"arcuses":"arcus",
"ardeas":"ardea",
"ardeidaes":"ardeidae",
"ardisias":"ardisia",
"ardors":"ardor",
"ardours":"ardour",
"arduousnesses":"arduousness",
"areas":"area",
"arecas":"areca",
"arecaceaes":"arecaceae",
"arecidaes":"arecidae",
"arenas":"arena",
"arenarias":"arenaria",
"arenaria-melanocephalas":"arenaria-melanocephala",
"arengas":"arenga",
"areolae":"areola",
"areolas":"areola",
"areres":"arere",
"arethusas":"arethusa",
"argals":"argal",
"argalis":"argali",
"argasids":"argasid",
"argasidaes":"argasidae",
"argemones":"argemone",
"argentinas":"argentina",
"argentinidaes":"argentinidae",
"argiopes":"argiope",
"argiopidaes":"argiopidae",
"argons":"argon",
"argonautas":"argonauta",
"argonautidaes":"argonautidae",
"argonnes":"argonne",
"argonons":"argonon",
"argosies":"argosy",
"argots":"argot",
"argued":"argue",
"argues":"argue",
"arguing":"argue",
"arguers":"arguer",
"argufied":"argufy",
"argufies":"argufy",
"argufying":"argufy",
"arguings":"arguing",
"arguments":"argument",
"argumentations":"argumentation",
"argumenta":"argumentum",
"arguses":"argus",
"argusianuses":"argusianus",
"argy-bargies":"argy-bargy",
"argyles":"argyle",
"argyleses":"argyles",
"argynnises":"argynnis",
"argyranthemums":"argyranthemum",
"argyreias":"argyreia",
"argyrols":"argyrol",
"argyrotaenias":"argyrotaenia",
"argyroxiphiums":"argyroxiphium",
"arhants":"arhant",
"arhats":"arhat",
"arias":"aria",
"arianrhods":"arianrhod",
"arianrods":"arianrod",
"aricaras":"aricara",
"aridities":"aridity",
"aridnesses":"aridness",
"arieses":"aries",
"ariettas":"arietta",
"ariette":"arietta",
"ariettes":"ariette",
"ariidaes":"ariidae",
"arikaras":"arikara",
"ariluses":"arilus",
"ariocarpuses":"ariocarpus",
"ariommas":"ariomma",
"ariosos":"arioso",
"arisaemas":"arisaema",
"arisarums":"arisarum",
"arisen":"arise",
"arises":"arise",
"arising":"arise",
"arose":"arise",
"arishths":"arishth",
"aristae":"arista",
"aristocracies":"aristocracy",
"aristocrats":"aristocrat",
"aristolochias":"aristolochia",
"aristolochiaceaes":"aristolochiaceae",
"aristolochialeses":"aristolochiales",
"aristoteleans":"aristotelean",
"aristotelias":"aristotelia",
"aristotelians":"aristotelian",
"ariuses":"arius",
"arizonas":"arizona",
"arizonans":"arizonan",
"arizonians":"arizonian",
"arks":"ark",
"arkansans":"arkansan",
"arkansases":"arkansas",
"arkansawyers":"arkansawyer",
"armed":"arm",
"arming":"arm",
"arms":"arm",
"armadas":"armada",
"armadillidiidaes":"armadillidiidae",
"armadillidiums":"armadillidium",
"armadillos":"armadillo",
"armaments":"armament",
"armamentariia":"armamentarium",
"armamentariums":"armamentarium",
"armchairs":"armchair",
"armenias":"armenia",
"Armenians":"Armenian",
"armerias":"armeria",
"armfuls":"armful",
"armigers":"armiger",
"armillarias":"armillaria",
"armillariellas":"armillariella",
"armins":"armin",
"armings":"arming",
"arminiuses":"arminius",
"armistices":"armistice",
"armlets":"armlet",
"armored":"armor",
"armoring":"armor",
"armors":"armor",
"armor-bearers":"armor-bearer",
"armoracias":"armoracia",
"armorers":"armorer",
"armories":"armory",
"armours":"armour",
"armourers":"armourer",
"armouries":"armoury",
"armpits":"armpit",
"armses":"arms",
"arms-runners":"arms-runner",
"armstrongs":"armstrong",
"armies":"army",
"armyworms":"armyworm",
"arnicas":"arnica",
"arnos":"arno",
"arnoserises":"arnoseris",
"aroids":"aroid",
"aromas":"aroma",
"aromatics":"aromatic",
"aromatized":"aromatize",
"aromatizes":"aromatize",
"aromatizing":"aromatize",
"arousals":"arousal",
"aroused":"arouse",
"arouses":"arouse",
"arousing":"arouse",
"arpeggios":"arpeggio",
"arquebuses":"arquebus",
"arracks":"arrack",
"arraigned":"arraign",
"arraigning":"arraign",
"arraignments":"arraignment",
"arranged":"arrange",
"arranges":"arrange",
"arranging":"arrange",
"arrangements":"arrangement",
"arrangers":"arranger",
"arrangings":"arranging",
"arrases":"arras",
"arrayed":"array",
"arraying":"array",
"arrays":"array",
"arrearages":"arrearage",
"arrested":"arrest",
"arresting":"arrest",
"arrests":"arrest",
"arresters":"arrester",
"arrhenatherums":"arrhenatherum",
"arriere-pensees":"arriere-pensee",
"arrises":"arris",
"arrivals":"arrival",
"arrived":"arrive",
"arrives":"arrive",
"arriving":"arrive",
"arrivedercis":"arrivederci",
"arrivers":"arriver",
"arrobas":"arroba",
"arrogances":"arrogance",
"arrogated":"arrogate",
"arrogates":"arrogate",
"arrogating":"arrogate",
"arrogations":"arrogation",
"arrowed":"arrow",
"arrowing":"arrow",
"arrows":"arrow",
"arrowroots":"arrowroot",
"arrowworms":"arrowworm",
"arroyos":"arroyo",
"arses":"arse",
"arseholes":"arsehole",
"arsenals":"arsenal",
"arsenics":"arsenic",
"arsenopyrites":"arsenopyrite",
"arsons":"arson",
"arsonists":"arsonist",
"arts":"art",
"artamidaes":"artamidae",
"artamuses":"artamus",
"artefacts":"artefact",
"artemias":"artemia",
"artemises":"artemis",
"artemisias":"artemisia",
"arterias":"arteria",
"arteriectasias":"arteriectasia",
"arteriectases":"arteriectasis",
"arteriolas":"arteriola",
"arterioles":"arteriole",
"arterioscleroses":"arteriosclerosis",
"arteries":"artery",
"arthropodas":"arthropoda",
"arthropterises":"arthropteris",
"arthurs":"arthur",
"artichokes":"artichoke",
"articled":"article",
"articles":"article",
"articling":"article",
"articulated":"articulate",
"articulates":"articulate",
"articulating":"articulate",
"articulatenesses":"articulateness",
"articulatios":"articulatio",
"articulations":"articulation",
"artifacts":"artifact",
"artifices":"artifice",
"artificers":"artificer",
"artilleries":"artillery",
"artillerymen":"artilleryman",
"artiodactyls":"artiodactyl",
"artiodactylas":"artiodactyla",
"artisans":"artisan",
"artists":"artist",
"artistries":"artistry",
"artlessnesses":"artlessness",
"artocarpuses":"artocarpus",
"artses":"arts",
"artsds":"artsd",
"artworks":"artwork",
"artier":"arty",
"artiest":"arty",
"arugulas":"arugula",
"aruis":"arui",
"arums":"arum",
"arundinarias":"arundinaria",
"arundos":"arundo",
"aruspices":"aruspex",
"arvicolas":"arvicola",
"aryans":"aryan",
"arytaenoids":"arytaenoid",
"arytenoids":"arytenoid",
"ases":"as",
"asamiyas":"asamiya",
"asarabaccas":"asarabacca",
"asarums":"asarum",
"ascaphidaes":"ascaphidae",
"ascaphuses":"ascaphus",
"ascaridaes":"ascaridae",
"ascaridias":"ascaridia",
"ascarises":"ascaris",
"ascended":"ascend",
"ascending":"ascend",
"ascends":"ascend",
"ascendances":"ascendance",
"ascendancies":"ascendancy",
"ascendants":"ascendant",
"ascendences":"ascendence",
"ascendencies":"ascendency",
"ascendents":"ascendent",
"ascendings":"ascending",
"ascensions":"ascension",
"ascents":"ascent",
"ascertained":"ascertain",
"ascertaining":"ascertain",
"ascertains":"ascertain",
"asceses":"ascesis",
"ascetics":"ascetic",
"asceticisms":"asceticism",
"aschelmintheses":"aschelminthes",
"ascidiaceaes":"ascidiaceae",
"ascidcidia":"ascidium",
"ascidia":"ascidium",
"asclepiadaceaes":"asclepiadaceae",
"asclepiases":"asclepias",
"ascogonia":"ascogonium",
"ascomycetes":"ascomycete",
"ascomyceteses":"ascomycetes",
"ascomycotas":"ascomycota",
"ascomycotinas":"ascomycotina",
"ascophyllums":"ascophyllum",
"ascribed":"ascribe",
"ascribes":"ascribe",
"ascribing":"ascribe",
"ascriptions":"ascription",
"asci":"ascus",
"asdics":"asdic",
"asepses":"asepsis",
"asexualities":"asexuality",
"ashes":"ash",
"ashbins":"ashbin",
"ashcakes":"ashcake",
"ashcans":"ashcan",
"ashirs":"ashir",
"ashkenazim":"ashkenazi",
"ashkhabads":"ashkhabad",
"ashtrays":"ashtray",
"ashurs":"ashur",
"ashier":"ashy",
"ashiest":"ashy",
"Asians":"Asian",
"asiatics":"asiatic",
"asides":"aside",
"asilidaes":"asilidae",
"asiminas":"asimina",
"asios":"asio",
"asked":"ask",
"asking":"ask",
"asks":"ask",
"askers":"asker",
"askings":"asking",
"asls":"asl",
"asps":"asp",
"aspalathuses":"aspalathus",
"asparagaceaes":"asparagaceae",
"asparaguses":"asparagus",
"aspects":"aspect",
"aspergills":"aspergill",
"aspergillaceaes":"aspergillaceae",
"aspergillaleses":"aspergillales",
"aspergilloses":"aspergillosis",
"aspergilla":"aspergillum",
"aspergillums":"aspergillum",
"aspergilluses":"aspergillus",
"asperities":"asperity",
"aspersed":"asperse",
"asperses":"asperse",
"aspersing":"asperse",
"aspersions":"aspersion",
"aspersoria":"aspersorium",
"asperulas":"asperula",
"asphalted":"asphalt",
"asphalting":"asphalt",
"asphalts":"asphalt",
"asphodelaceaes":"asphodelaceae",
"asphodelines":"asphodeline",
"asphodeluses":"asphodelus",
"asphyxiated":"asphyxiate",
"asphyxiates":"asphyxiate",
"asphyxiating":"asphyxiate",
"asphyxiations":"asphyxiation",
"aspidelapses":"aspidelaps",
"aspidiotuses":"aspidiotus",
"aspidistras":"aspidistra",
"aspidophoroideses":"aspidophoroides",
"aspirants":"aspirant",
"aspirated":"aspirate",
"aspirates":"aspirate",
"aspirating":"aspirate",
"aspirations":"aspiration",
"aspired":"aspire",
"aspires":"aspire",
"aspiring":"aspire",
"aspirins":"aspirin",
"aspises":"aspis",
"aspleniaceaes":"aspleniaceae",
"aspleniums":"asplenium",
"asses":"ass",
"ass-kissers":"ass-kisser",
"assagais":"assagai",
"assegais":"assagai",
"assailed":"assail",
"assailing":"assail",
"assails":"assail",
"assailants":"assailant",
"assameses":"assamese",
"assassins":"assassin",
"assassinated":"assassinate",
"assassinating":"assassinate",
"assassinations":"assassination",
"assassinators":"assassinator",
"assaulted":"assault",
"assaulting":"assault",
"assaults":"assault",
"assayed":"assay",
"assaying":"assay",
"assays":"assay",
"assay-marks":"assay-mark",
"assayers":"assayer",
"assemblages":"assemblage",
"assembled":"assemble",
"assembles":"assemble",
"assembling":"assemble",
"assemblers":"assembler",
"assemblings":"assembling",
"assemblies":"assembly",
"assemblymen":"assemblyman",
"assented":"assent",
"assenting":"assent",
"assents":"assent",
"assentings":"assenting",
"assentors":"assentor",
"asserted":"assert",
"asserting":"assert",
"asserts":"assert",
"assertions":"assertion",
"assertivenesses":"assertiveness",
"assertors":"assertor",
"assessed":"assess",
"assesses":"assess",
"assessing":"assess",
"assessments":"assessment",
"assessors":"assessor",
"assets":"asset",
"asseverated":"asseverate",
"asseverates":"asseverate",
"asseverating":"asseverate",
"asseverations":"asseveration",
"assholes":"asshole",
"assiduities":"assiduity",
"assiduousnesses":"assiduousness",
"assigned":"assign",
"assigning":"assign",
"assigns":"assign",
"assignats":"assignat",
"assignations":"assignation",
"assignings":"assigning",
"assignments":"assignment",
"assimilated":"assimilate",
"assimilates":"assimilate",
"assimilating":"assimilate",
"assimilations":"assimilation",
"assisted":"assist",
"assisting":"assist",
"assists":"assist",
"assistances":"assistance",
"assistants":"assistant",
"assizes":"assize",
"assizeses":"assizes",
"associabilities":"associability",
"associablenesses":"associableness",
"associated":"associate",
"associates":"associate",
"associating":"associate",
"associations":"association",
"assoiled":"assoil",
"assoiling":"assoil",
"assoils":"assoil",
"assonances":"assonance",
"assorting":"assort",
"assorts":"assort",
"assortments":"assortment",
"assouans":"assouan",
"assuaged":"assuage",
"assuages":"assuage",
"assuaging":"assuage",
"assuagements":"assuagement",
"assuans":"assuan",
"assumed":"assume",
"assumes":"assume",
"assuming":"assume",
"assumptions":"assumption",
"assurances":"assurance",
"assured":"assure",
"assures":"assure",
"assuring":"assure",
"assurednesses":"assuredness",
"astacidaes":"astacidae",
"astacuras":"astacura",
"astacuses":"astacus",
"astatines":"astatine",
"asteraceaes":"asteraceae",
"asteridaes":"asteridae",
"asterisked":"asterisk",
"asterisking":"asterisk",
"asterisks":"asterisk",
"asteroids":"asteroid",
"asteroideas":"asteroidea",
"asteropes":"asterope",
"asthenias":"asthenia",
"asthenopias":"asthenopia",
"asthenies":"astheny",
"asthmas":"asthma",
"astigmatisms":"astigmatism",
"astigmias":"astigmia",
"astonished":"astonish",
"astonishes":"astonish",
"astonishing":"astonish",
"astonishments":"astonishment",
"astounded":"astound",
"astounding":"astound",
"astounds":"astound",
"astragals":"astragal",
"astragali":"astragalus",
"astragaluses":"astragalus",
"astreuses":"astreus",
"astringences":"astringence",
"astringencies":"astringency",
"astringents":"astringent",
"astroglias":"astroglia",
"astrolatries":"astrolatry",
"astrologers":"astrologer",
"astrologists":"astrologist",
"astrologies":"astrology",
"astrolomas":"astroloma",
"astronauts":"astronaut",
"astronauticses":"astronautics",
"astronavigations":"astronavigation",
"astroniums":"astronium",
"astronomers":"astronomer",
"astronomies":"astronomy",
"astrophytons":"astrophyton",
"astropogons":"astropogon",
"astutenesses":"astuteness",
"asuncions":"asuncion",
"aswans":"aswan",
"asylums":"asylum",
"asymmetries":"asymmetry",
"asynchronisms":"asynchronism",
"asynchronies":"asynchrony",
"asynclitisms":"asynclitism",
"asyndeta":"asyndeton",
"asynergias":"asynergia",
"asynergies":"asynergy",
"asystoles":"asystole",
"ats":"at",
"at-bats":"at-bat",
"atabrines":"atabrine",
"atakapas":"atakapa",
"atakapans":"atakapan",
"atamans":"ataman",
"atars":"atar",
"ataractics":"ataractic",
"ataraxes":"atarax",
"ataraxics":"ataraxic",
"atavisms":"atavism",
"atavists":"atavist",
"ataxias":"ataxia",
"ataxies":"ataxy",
"atayalics":"atayalic",
"ateleioses":"ateleiosis",
"ateleses":"ateles",
"ateliers":"atelier",
"atelioses":"ateliosis",
"atenolols":"atenolol",
"athabascans":"athabascan",
"athabaskans":"athabaskan",
"athapascans":"athapascan",
"athapaskans":"athapaskan",
"athars":"athar",
"atheisms":"atheism",
"atheists":"atheist",
"athenas":"athena",
"athenaeums":"athenaeum",
"athenes":"athene",
"atheneums":"atheneum",
"athenses":"athens",
"atherinidaes":"atherinidae",
"atherinopses":"atherinopsis",
"atherodydes":"atherodyde",
"atheromas":"atheroma",
"atheromata":"atheroma",
"atheroscleroses":"atherosclerosis",
"atheruruses":"atherurus",
"athiorhodaceaes":"athiorhodaceae",
"athletes":"athlete",
"athleticisms":"athleticism",
"athleticses":"athletics",
"athodyds":"athodyd",
"athrotaxes":"athrotaxis",
"athyriaceaes":"athyriaceae",
"athyriums":"athyrium",
"atlantas":"atlanta",
"atlantics":"atlantic",
"atlantideses":"atlantides",
"atlantes":"atlas",
"atlases":"atlas",
"ATMs":"ATM",
"atmolyses":"atmolysis",
"atmometers":"atmometer",
"atmospheres":"atmosphere",
"atmosphericses":"atmospherics",
"atoms":"atom",
"atomisations":"atomisation",
"atomisers":"atomiser",
"atomizations":"atomization",
"atomized":"atomize",
"atomizes":"atomize",
"atomizing":"atomize",
"atomizers":"atomizer",
"atomies":"atomy",
"atonalisms":"atonalism",
"atonalities":"atonality",
"atoned":"atone",
"atones":"atone",
"atoning":"atone",
"atonements":"atonement",
"atonias":"atonia",
"atonicities":"atonicity",
"atonies":"atony",
"atopognosias":"atopognosia",
"atopognoses":"atopognosis",
"atopies":"atopy",
"atps":"atp",
"atrichornises":"atrichornis",
"atrichornithidaes":"atrichornithidae",
"atriplexes":"atriplex",
"atria":"atrium",
"atriums":"atrium",
"atrociousnesses":"atrociousness",
"atrocities":"atrocity",
"atromid-ses":"atromid-s",
"atropas":"atropa",
"atrophied":"atrophy",
"atrophies":"atrophy",
"atrophying":"atrophy",
"atropidaes":"atropidae",
"atrovents":"atrovent",
"attacapas":"attacapa",
"attacapans":"attacapan",
"attached":"attach",
"attaches":"attach",
"attaching":"attach",
"attachments":"attachment",
"attacked":"attack",
"attacking":"attack",
"attacks":"attack",
"attackers":"attacker",
"attained":"attain",
"attaining":"attain",
"attains":"attain",
"attainabilities":"attainability",
"attainablenesses":"attainableness",
"attainders":"attainder",
"attainments":"attainment",
"attainted":"attaint",
"attainting":"attaint",
"attaints":"attaint",
"attaleas":"attalea",
"attars":"attar",
"attempted":"attempt",
"attempting":"attempt",
"attempts":"attempt",
"attended":"attend",
"attending":"attend",
"attends":"attend",
"attendances":"attendance",
"attendants":"attendant",
"attenders":"attender",
"attendings":"attending",
"attentions":"attention",
"attentivenesses":"attentiveness",
"attenuated":"attenuate",
"attenuates":"attenuate",
"attenuating":"attenuate",
"attenuations":"attenuation",
"attested":"attest",
"attesting":"attest",
"attests":"attest",
"attestants":"attestant",
"attestations":"attestation",
"attics":"attic",
"atticuses":"atticus",
"attilas":"attila",
"attired":"attire",
"attires":"attire",
"attiring":"attire",
"attitudes":"attitude",
"attitudinized":"attitudinize",
"attitudinizes":"attitudinize",
"attitudinizing":"attitudinize",
"attorned":"attorn",
"attorning":"attorn",
"attorneys":"attorney",
"attorneys-at-law":"attorney-at-law",
"attracted":"attract",
"attracting":"attract",
"attracts":"attract",
"attractions":"attraction",
"attractivenesses":"attractiveness",
"attributed":"attribute",
"attributes":"attribute",
"attributing":"attribute",
"attributions":"attribution",
"attritions":"attrition",
"attuned":"attune",
"attuning":"attune",
"atypicalities":"atypicality",
"aus":"au",
"aubergines":"aubergine",
"auctioned":"auction",
"auctioning":"auction",
"auctions":"auction",
"auctioneered":"auctioneer",
"auctioneering":"auctioneer",
"auctioneers":"auctioneer",
"audaciousnesses":"audaciousness",
"audacities":"audacity",
"audads":"audad",
"audens":"auden",
"audibilities":"audibility",
"audiblenesses":"audibleness",
"audiences":"audience",
"audios":"audio",
"audiologies":"audiology",
"audiometries":"audiometry",
"audiovisuals":"audiovisual",
"audited":"audit",
"auditing":"audit",
"audits":"audit",
"auditioned":"audition",
"auditioning":"audition",
"auditions":"audition",
"auditors":"auditor",
"auditoria":"auditorium",
"auditoriums":"auditorium",
"autoclaves":"autoclave",
"auditories":"auditory",
"augs":"aug",
"augers":"auger",
"aughts":"aught",
"augmented":"augment",
"augmenting":"augment",
"augments":"augment",
"augured":"augur",
"auguring":"augur",
"augurs":"augur",
"auguries":"augury",
"Augusts":"August",
"augustas":"augusta",
"Augustines":"Augustine",
"augustinians":"augustinian",
"augustuses":"augustus",
"aulacorhyncuses":"aulacorhyncus",
"aulostomidaes":"aulostomidae",
"aulostomuses":"aulostomus",
"aunts":"aunt",
"aunties":"auntie",
"aurae":"aura",
"auras":"aura",
"aurars":"aurar",
"aureolas":"aureola",
"aureolarias":"aureolaria",
"aureoles":"aureole",
"aureomycins":"aureomycin",
"aurei":"aureus",
"auricles":"auricle",
"auriculas":"auricula",
"auricularias":"auricularia",
"auriculariaceaes":"auriculariaceae",
"auricularialeses":"auriculariales",
"auriparuses":"auriparus",
"aurochses":"aurochs",
"aurorae":"aurora",
"auroras":"aurora",
"auscultated":"auscultate",
"auscultating":"auscultate",
"auspexes":"auspex",
"auspices":"auspex",
"auspiceses":"auspices",
"auspiciousnesses":"auspiciousness",
"Aussies":"Aussie",
"austerenesses":"austereness",
"austerities":"austerity",
"austerlitzs":"austerlitz",
"austins":"austin",
"australias":"australia",
"Australians":"Australian",
"australopithecuses":"australopithecus",
"austrias":"austria",
"austro-asiatics":"austro-asiatic",
"austrocedruses":"austrocedrus",
"austronesians":"austronesian",
"austrotaxuses":"austrotaxus",
"autacoids":"autacoid",
"autarchies":"autarchy",
"autarkies":"autarky",
"authenticated":"authenticate",
"authenticating":"authenticate",
"authentications":"authentication",
"authenticities":"authenticity",
"authored":"author",
"authoring":"author",
"authors":"author",
"authorisations":"authorisation",
"authoritarians":"authoritarian",
"authoritarianisms":"authoritarianism",
"authoritieses":"authorities",
"authorities":"authority",
"authorizations":"authorization",
"authorized":"authorize",
"authorizes":"authorize",
"authorizing":"authorize",
"authorships":"authorship",
"autoed":"auto",
"autoing":"auto",
"autos":"auto",
"auto-changers":"auto-changer",
"autos-da-fe":"auto-da-fe",
"auto-mechanics":"auto-mechanic",
"autoantibodies":"autoantibody",
"autobiographers":"autobiographer",
"autobiographies":"autobiography",
"autobuses":"autobus",
"autocatalyses":"autocatalysis",
"autochthones":"autochthon",
"autochthons":"autochthon",
"autochthonies":"autochthony",
"autocoids":"autocoid",
"autocracies":"autocracy",
"autocrats":"autocrat",
"autocues":"autocue",
"autoeroticisms":"autoeroticism",
"autoerotisms":"autoerotism",
"autogeneses":"autogenesis",
"autogenicses":"autogenics",
"autogenies":"autogeny",
"autogiros":"autogiro",
"autographed":"autograph",
"autographing":"autograph",
"autographs":"autograph",
"autogyros":"autogyro",
"autolatries":"autolatry",
"autolyzed":"autolyze",
"autolyzing":"autolyze",
"automated":"automate",
"automates":"automate",
"automating":"automate",
"automatics":"automatic",
"automations":"automation",
"automatized":"automatize",
"automatizes":"automatize",
"automatizing":"automatize",
"automata":"automaton",
"automatons":"automaton",
"automerises":"automeris",
"automobiles":"automobile",
"automobilists":"automobilist",
"autonomies":"autonomy",
"autophytes":"autophyte",
"autopilots":"autopilot",
"autopsies":"autopsy",
"autosomes":"autosome",
"autostradas":"autostrada",
"autostrade":"autostrada",
"autosuggestions":"autosuggestion",
"autotomized":"autotomize",
"autotomizing":"autotomize",
"autotomies":"autotomy",
"autotrophs":"autotroph",
"autotypes":"autotype",
"autotypies":"autotypy",
"autumns":"autumn",
"auxiliaries":"auxiliary",
"avs":"av",
"avadavats":"avadavat",
"avahis":"avahi",
"availed":"avail",
"availing":"avail",
"avails":"avail",
"availabilities":"availability",
"availablenesses":"availableness",
"avalanched":"avalanche",
"avalanches":"avalanche",
"avalanching":"avalanche",
"avalokiteshvaras":"avalokiteshvara",
"avalokitesvaras":"avalokitesvara",
"avarams":"avaram",
"avarices":"avarice",
"avariciousnesses":"avariciousness",
"avaritias":"avaritia",
"avatars":"avatar",
"avenas":"avena",
"avenged":"avenge",
"avenges":"avenge",
"avenging":"avenge",
"avengers":"avenger",
"avenses":"avens",
"aventails":"aventail",
"aventurines":"aventurine",
"avenues":"avenue",
"avering":"aver",
"averred":"aver",
"averring":"aver",
"avers":"aver",
"averaged":"average",
"averages":"average",
"averaging":"average",
"averagenesses":"averageness",
"averments":"averment",
"averrhoas":"averrhoa",
"aversions":"aversion",
"averted":"avert",
"averting":"avert",
"averts":"avert",
"aveses":"aves",
"avestas":"avesta",
"avestans":"avestan",
"aviaries":"aviary",
"aviated":"aviate",
"aviates":"aviate",
"aviating":"aviate",
"aviations":"aviation",
"aviators":"aviator",
"aviatresses":"aviatress",
"aviatrices":"aviatrix",
"aviatrixes":"aviatrix",
"avicennias":"avicennia",
"avicenniaceaes":"avicenniaceae",
"avidities":"avidity",
"avidnesses":"avidness",
"avifaunae":"avifauna",
"avifaunas":"avifauna",
"avitaminoses":"avitaminosis",
"avocados":"avocado",
"avocations":"avocation",
"avoided":"avoid",
"avoiding":"avoid",
"avoids":"avoid",
"avoidances":"avoidance",
"avoirdupoises":"avoirdupois",
"avouched":"avouch",
"avouches":"avouch",
"avouching":"avouch",
"avowed":"avow",
"avowing":"avow",
"avows":"avow",
"avowals":"avowal",
"avulsed":"avulse",
"avulsing":"avulse",
"awaited":"await",
"awaiting":"await",
"awaits":"await",
"awaked":"awake",
"awakes":"awake",
"awaking":"awake",
"awoke":"awake",
"awoken":"awake",
"awakened":"awaken",
"awakening":"awaken",
"awakens":"awaken",
"awakenings":"awakening",
"awarded":"award",
"awarding":"award",
"awards":"award",
"awardings":"awarding",
"awarenesses":"awareness",
"awed":"awe",
"awes":"awe",
"awing":"awe",
"awfulnesses":"awfulness",
"awkwarder":"awkward",
"awkwardest":"awkward",
"awkwardnesses":"awkwardness",
"awlworts":"awlwort",
"awnings":"awning",
"axed":"ax",
"axes":"ax",
"axing":"ax",
"axerophthols":"axerophthol",
"axilemmata":"axilemma",
"axillae":"axilla",
"axillas":"axilla",
"axillaries":"axillary",
"axioms":"axiom",
"axles":"axle",
"axmen":"axman",
"axolotls":"axolotl",
"axons":"axon",
"axones":"axone",
"axseeds":"axseed",
"ayapanas":"ayapana",
"ayes":"aye",
"aye-ayes":"aye-aye",
"aymaras":"aymara",
"aythyas":"aythya",
"azs":"az",
"azactams":"azactam",
"azadirachtas":"azadirachta",
"azaleas":"azalea",
"azaleastrums":"azaleastrum",
"azathioprines":"azathioprine",
"azedaraches":"azedarach",
"azederaches":"azederach",
"azerbaijans":"azerbaijan",
"Azerbaijanis":"Azerbaijani",
"azerbajdzhans":"azerbajdzhan",
"azidothymidines":"azidothymidine",
"azimuths":"azimuth",
"azoimides":"azoimide",
"azollas":"azolla",
"azollaceaes":"azollaceae",
"azotaemias":"azotaemia",
"azotemias":"azotemia",
"azts":"azt",
"aztreonams":"aztreonam",
"azures":"azure",
"bs":"b",
"b-girls":"b-girl",
"b-horizons":"b-horizon",
"bas":"ba",
"baaed":"baa",
"baaing":"baa",
"baas":"baa",
"baalim":"baal",
"baals":"baal",
"babas":"baba",
"babassus":"babassu",
"babbitings":"babbiting",
"babbitted":"babbitt",
"babbitting":"babbitt",
"babbitts":"babbitt",
"babbittings":"babbitting",
"babbled":"babble",
"babbles":"babble",
"babbling":"babble",
"babblers":"babbler",
"babblings":"babbling",
"babes":"babe",
"babels":"babel",
"babesias":"babesia",
"babesiidaes":"babesiidae",
"babis":"babi",
"babinskis":"babinski",
"babiroussas":"babiroussa",
"babirusas":"babirusa",
"babirussas":"babirussa",
"babkas":"babka",
"baboos":"baboo",
"baboons":"baboon",
"babus":"babu",
"babushkas":"babushka",
"babied":"baby",
"babies":"baby",
"babying":"baby",
"baby-sat":"baby-sit",
"baby-sits":"baby-sit",
"baby-sitting":"baby-sit",
"baby-walkers":"baby-walker",
"babyhoods":"babyhood",
"babyminders":"babyminder",
"babyrousas":"babyrousa",
"babysitters":"babysitter",
"baccas":"bacca",
"baccalaureates":"baccalaureate",
"baccarats":"baccarat",
"bacchanals":"bacchanal",
"bacchanalias":"bacchanalia",
"bacchantes":"bacchant",
"bacchants":"bacchant",
"baccharises":"baccharis",
"bacchii":"bacchius",
"baccies":"baccy",
"bached":"bach",
"baches":"bach",
"baching":"bach",
"bachelored":"bachelor",
"bacheloring":"bachelor",
"bachelors":"bachelor",
"bachelor-at-armses":"bachelor-at-arms",
"bachelors-at-arms":"bachelor-at-arms",
"bacillaceaes":"bacillaceae",
"bacillariophyceaes":"bacillariophyceae",
"bacillis":"bacilli",
"bacilli":"bacillus",
"backed":"back",
"backing":"back",
"backs":"back",
"back-checked":"back-check",
"back-checking":"back-check",
"back-numbers":"back-number",
"back-ordered":"back-order",
"back-ordering":"back-order",
"back-pedaled":"back-pedal",
"back-pedaling":"back-pedal",
"back-pedalled":"back-pedal",
"back-pedalling":"back-pedal",
"back-pedals":"back-pedal",
"backaches":"backache",
"backbit":"backbite",
"backbites":"backbite",
"backbiting":"backbite",
"backbitten":"backbite",
"backbiters":"backbiter",
"backboards":"backboard",
"backbones":"backbone",
"backchats":"backchat",
"backcloths":"backcloth",
"backcrossed":"backcross",
"backcrossing":"backcross",
"backdated":"backdate",
"backdating":"backdate",
"backdowns":"backdown",
"backdrops":"backdrop",
"backers":"backer",
"backfilled":"backfill",
"backfilling":"backfill",
"backfired":"backfire",
"backfires":"backfire",
"backfiring":"backfire",
"backflows":"backflow",
"backflowings":"backflowing",
"backgrounded":"background",
"backgrounding":"background",
"backgrounds":"background",
"backgroundings":"backgrounding",
"backhands":"backhand",
"backings":"backing",
"backlashes":"backlash",
"backlogs":"backlog",
"backpacked":"backpack",
"backpacking":"backpack",
"backpacks":"backpack",
"backpackings":"backpacking",
"backpedaled":"backpedal",
"backpedaling":"backpedal",
"backpedalled":"backpedal",
"backpedalling":"backpedal",
"backrests":"backrest",
"backsheeshes":"backsheesh",
"backsides":"backside",
"backslid":"backslide",
"backslidden":"backslide",
"backslides":"backslide",
"backsliding":"backslide",
"backsliders":"backslider",
"backslidings":"backsliding",
"backspaced":"backspace",
"backspacing":"backspace",
"backspacers":"backspacer",
"backstages":"backstage",
"backstitched":"backstitch",
"backstitching":"backstitch",
"backswimmers":"backswimmer",
"backswords":"backsword",
"backtalks":"backtalk",
"backtracked":"backtrack",
"backtracking":"backtrack",
"backtracks":"backtrack",
"backups":"backup",
"backwardnesses":"backwardness",
"backwashes":"backwash",
"backwoodses":"backwoods",
"backwoodsmen":"backwoodsman",
"bacons":"bacon",
"bacteremias":"bacteremia",
"bacterias":"bacteria",
"bacteriacides":"bacteriacide",
"bacteriaemias":"bacteriaemia",
"bactericides":"bactericide",
"bacteriemias":"bacteriemia",
"bacteriophages":"bacteriophage",
"bacteriostastases":"bacteriostasis",
"bacteria":"bacterium",
"bacterized":"bacterize",
"bacterizes":"bacterize",
"bacterizing":"bacterize",
"bacteroidaceaes":"bacteroidaceae",
"bacteroideses":"bacteroides",
"bacula":"baculum",
"baculums":"baculum",
"bads":"bad",
"worse":"bad",
"worst":"bad",
"bad-mouthed":"bad-mouth",
"bad-mouthing":"bad-mouth",
"baddies":"baddie",
"badged":"badge",
"badges":"badge",
"badging":"badge",
"badgered":"badger",
"badgering":"badger",
"badgers":"badger",
"badgerers":"badgerer",
"badgerings":"badgering",
"badinaged":"badinage",
"badinaging":"badinage",
"badlandses":"badlands",
"badmen":"badman",
"badnesses":"badness",
"baffled":"baffle",
"baffles":"baffle",
"baffling":"baffle",
"bafflements":"bafflement",
"bagged":"bag",
"bagging":"bag",
"bags":"bag",
"bagascoses":"bagascosis",
"bagassoses":"bagassosis",
"bagatelles":"bagatelle",
"bagdads":"bagdad",
"bagfuls":"bagful",
"baggages":"baggage",
"baggers":"bagger",
"baggings":"bagging",
"baggier":"baggy",
"baggies":"baggy",
"baggiest":"baggy",
"baghdads":"baghdad",
"bagies":"bagie",
"bagmen":"bagman",
"bagnios":"bagnio",
"bagpipes":"bagpipe",
"bagpipers":"bagpiper",
"baguets":"baguet",
"baguettes":"baguette",
"bahais":"baha'i",
"bahamases":"bahamas",
"bahasas":"bahasa",
"bahrains":"bahrain",
"bahrainis":"bahraini",
"bahreins":"bahrein",
"bahreinis":"bahreini",
"bahts":"baht",
"bais":"bai",
"baics":"baic",
"bailed":"bail",
"bailing":"bail",
"bails":"bail",
"bailers":"bailer",
"baileys":"bailey",
"bailiffs":"bailiff",
"bailors":"bailor",
"bailsmen":"bailsman",
"bains-marie":"bain-marie",
"baiomyses":"baiomys",
"bairdiellas":"bairdiella",
"baited":"bait",
"baiting":"bait",
"baits":"bait",
"baked":"bake",
"bakes":"bake",
"baking":"bake",
"bakeapples":"bakeapple",
"bakers":"baker",
"bakeries":"bakery",
"bakings":"baking",
"bakras":"bakra",
"baksheeshes":"baksheesh",
"bakshises":"bakshis",
"bakshishes":"bakshish",
"bakus":"baku",
"balaclavas":"balaclava",
"balaenas":"balaena",
"balaenicepses":"balaeniceps",
"balaenicipitidaes":"balaenicipitidae",
"balaenidaes":"balaenidae",
"balaenopteras":"balaenoptera",
"balaenopteridaes":"balaenopteridae",
"balalaikas":"balalaika",
"balanced":"balance",
"balances":"balance",
"balancing":"balance",
"balancers":"balancer",
"balancings":"balancing",
"balanidaes":"balanidae",
"balanuses":"balanus",
"balases":"balas",
"balatas":"balata",
"balboas":"balboa",
"balconies":"balcony",
"balder":"bald",
"baldest":"bald",
"baldachinos":"baldachin",
"ballses":"balls",
"balderdashes":"balderdash",
"baldheads":"baldhead",
"baldnesses":"baldness",
"baldpates":"baldpate",
"baldrs":"baldr",
"baldrics":"baldric",
"baldricks":"baldrick",
"baldies":"baldy",
"baled":"bale",
"bales":"bale",
"baling":"bale",
"baleens":"baleen",
"balefires":"balefire",
"balefulnesses":"balefulness",
"balibagos":"balibago",
"balisteses":"balistes",
"balistidaes":"balistidae",
"balked":"balk",
"balking":"balk",
"balks":"balk",
"Balkanized":"Balkanize",
"Balkanizes":"Balkanize",
"Balkanizing":"Balkanize",
"balkanses":"balkans",
"balklines":"balkline",
"balkier":"balky",
"balkiest":"balky",
"balled":"ball",
"balling":"ball",
"balls":"ball",
"ballads":"ballad",
"balladeers":"balladeer",
"ballasted":"ballast",
"ballasting":"ballast",
"ballcocks":"ballcock",
"ballerinas":"ballerina",
"ballets":"ballet",
"ballistae":"ballista",
"ballisticses":"ballistics",
"ballocks":"ballock",
"ballooned":"balloon",
"ballooning":"balloon",
"balloons":"balloon",
"balloonfishes":"balloonfish",
"balloted":"ballot",
"balloting":"ballot",
"ballots":"ballot",
"ballotas":"ballota",
"ballotings":"balloting",
"ballparks":"ballpark",
"ballpens":"ballpen",
"ballplayers":"ballplayer",
"ballpoints":"ballpoint",
"ballrooms":"ballroom",
"balls-ups":"balls-up",
"ballsier":"ballsy",
"ballsiest":"ballsy",
"ballups":"ballup",
"ballyhooed":"ballyhoo",
"ballyhooing":"ballyhoo",
"ballyhoos":"ballyhoo",
"ballyragged":"ballyrag",
"ballyragging":"ballyrag",
"ballyrags":"ballyrag",
"balms":"balm",
"balmorals":"balmoral",
"balmier":"balmy",
"balmiest":"balmy",
"balochis":"balochi",
"baloneys":"baloney",
"balsas":"balsa",
"balsams":"balsam",
"balsaminaceaes":"balsaminaceae",
"balsamorhizas":"balsamorhiza",
"baltics":"baltic",
"balto-slavics":"balto-slavic",
"balto-slavonics":"balto-slavonic",
"baluchis":"baluchi",
"balusters":"baluster",
"balusterses":"balusters",
"balustrades":"balustrade",
"balzacs":"balzac",
"bambaras":"bambara",
"bambini":"bambino",
"bambinos":"bambino",
"bamboos":"bamboo",
"bamboozled":"bamboozle",
"bamboozles":"bamboozle",
"bamboozling":"bamboozle",
"bambusas":"bambusa",
"bambuseaes":"bambuseae",
"bani":"ban",
"banning":"ban",
"bans":"ban",
"banalities":"banality",
"banalized":"banalize",
"banalizing":"banalize",
"bananas":"banana",
"banded":"band",
"banding":"band",
"bands":"band",
"bandaged":"bandage",
"bandages":"bandage",
"bandaging":"bandage",
"bandagings":"bandaging",
"bandanas":"bandana",
"bandannas":"bandanna",
"bandboxes":"bandbox",
"bandeaus":"bandeau",
"bandeaux":"bandeau",
"bandelets":"bandelet",
"bandelettes":"bandelette",
"banderilleros":"banderillero",
"bandings":"banding",
"bandits":"bandit",
"banditti":"bandit",
"banditries":"banditry",
"bandlets":"bandlet",
"bandoleers":"bandoleer",
"bandoliers":"bandolier",
"bandoras":"bandore",
"bandores":"bandore",
"bandsmen":"bandsman",
"bandstands":"bandstand",
"bandtails":"bandtail",
"bandwagons":"bandwagon",
"bandied":"bandy",
"belabours":"belabour",
"bandier":"bandy",
"bandies":"bandy",
"bandiest":"bandy",
"bandying":"bandy",
"bandy-bandies":"bandy-bandy",
"banes":"bane",
"baneberries":"baneberry",
"banged":"bang",
"banging":"bang",
"bangs":"bang",
"bangers":"banger",
"bangiaceaes":"bangiaceae",
"bangings":"banging",
"bangkoks":"bangkok",
"bangladeshes":"bangladesh",
"bangles":"bangle",
"bangtails":"bangtail",
"banguis":"bangui",
"banians":"banian",
"banished":"banish",
"banishes":"banish",
"banishing":"banish",
"banishments":"banishment",
"banisters":"banister",
"banjoes":"banjo",
"banjos":"banjo",
"banked":"bank",
"banking":"bank",
"banks":"bank",
"bankbooks":"bankbook",
"bankers":"banker",
"bankias":"bankia",
"banknotes":"banknote",
"bankrolled":"bankroll",
"bankrolling":"bankroll",
"bankrolls":"bankroll",
"bankrupted":"bankrupt",
"bankrupting":"bankrupt",
"bankrupts":"bankrupt",
"bankruptcies":"bankruptcy",
"bannered":"banner",
"bannering":"banner",
"banners":"banner",
"bannerets":"banneret",
"bannings":"banning",
"bannisters":"bannister",
"banqueted":"banquet",
"banqueting":"banquet",
"banquets":"banquet",
"banquetings":"banqueting",
"bantengs":"banteng",
"bantered":"banter",
"bantering":"banter",
"banters":"banter",
"bantings":"banting",
"Bantus":"Bantu",
"banyans":"banyan",
"baobabs":"baobab",
"baphias":"baphia",
"baptisias":"baptisia",
"baptisms":"baptism",
"baptisteries":"baptistery",
"baptistries":"baptistry",
"baptistses":"baptists",
"baptized":"baptize",
"baptizes":"baptize",
"baptizing":"baptize",
"barring":"bar",
"bars":"bar",
"barandukis":"baranduki",
"barbed":"barb",
"barbing":"barb",
"barbs":"barb",
"barbacans":"barbacan",
"barbareas":"barbarea",
"barbarians":"barbarian",
"barbarisations":"barbarisation",
"barbarisms":"barbarism",
"barbarities":"barbarity",
"barbarizations":"barbarization",
"barbarized":"barbarize",
"barbarizes":"barbarize",
"barbarizing":"barbarize",
"barbarossas":"barbarossa",
"barbarousnesses":"barbarousness",
"barbascos":"barbasco",
"barbecued":"barbecue",
"barbecues":"barbecue",
"barbecuing":"barbecue",
"barbels":"barbel",
"barbered":"barber",
"barbering":"barber",
"barbers":"barber",
"barberries":"barberry",
"barbicans":"barbican",
"barbitals":"barbital",
"barbitones":"barbitone",
"barbus":"barbu",
"barcaroles":"barcarole",
"barcarolles":"barcarolle",
"barded":"bard",
"barding":"bard",
"bards":"bard",
"bared":"bare",
"barer":"bare",
"barest":"bare",
"baring":"bare",
"barenesses":"bareness",
"barfed":"barf",
"barfing":"barf",
"barfs":"barf",
"barflies":"barfly",
"bargained":"bargain",
"bargaining":"bargain",
"bargains":"bargain",
"bargainers":"bargainer",
"barged":"barge",
"barges":"barge",
"barging":"barge",
"bargees":"bargee",
"bargemen":"bargeman",
"barhopped":"barhop",
"barhopping":"barhop",
"barillas":"barilla",
"barings":"baring",
"barishes":"barish",
"barites":"barite",
"baritones":"baritone",
"bariums":"barium",
"barked":"bark",
"barking":"bark",
"barks":"bark",
"barkeeps":"barkeep",
"barkeepers":"barkeeper",
"barklice":"barklouse",
"barkier":"barky",
"barkiest":"barky",
"barleys":"barley",
"barley-sugars":"barley-sugar",
"barleycorns":"barleycorn",
"barms":"barm",
"barmen":"barman",
"barmier":"barmy",
"barmiest":"barmy",
"barns":"barn",
"barnacles":"barnacle",
"barnstormed":"barnstorm",
"barnstorming":"barnstorm",
"barnstorms":"barnstorm",
"barnstormers":"barnstormer",
"barnyards":"barnyard",
"barometers":"barometer",
"barons":"baron",
"baronages":"baronage",
"barondukis":"baronduki",
"baronesses":"baroness",
"baronets":"baronet",
"baronetcies":"baronetcy",
"baronies":"barony",
"baroques":"baroque",
"baroquenesses":"baroqueness",
"barosaurs":"barosaur",
"barosauruses":"barosaurus",
"barotses":"barotse",
"barques":"barque",
"barracked":"barrack",
"barracking":"barrack",
"barracks":"barrack",
"barrackings":"barracking",
"barracudas":"barracuda",
"barraged":"barrage",
"barrages":"barrage",
"barraging":"barrage",
"barramundas":"barramunda",
"barramundies":"barramundi",
"barramundis":"barramundi",
"barrancas":"barranca",
"barrancos":"barranco",
"barreled":"barrel",
"barreling":"barrel",
"barrelled":"barrel",
"barrelling":"barrel",
"barrels":"barrel",
"barrel-rolled":"barrel-roll",
"barrel-rolling":"barrel-roll",
"barrelfishes":"barrelfish",
"barrelfuls":"barrelful",
"barrelhouses":"barrelhouse",
"barrens":"barren",
"barrennesses":"barrenness",
"barrenworts":"barrenwort",
"barretters":"barretter",
"barricaded":"barricade",
"barricades":"barricade",
"barricading":"barricade",
"barries":"barrie",
"barriers":"barrier",
"barrings":"barring",
"barrios":"barrio",
"barristers":"barrister",
"barrooms":"barroom",
"barrows":"barrow",
"barrow-boys":"barrow-boy",
"barrow-men":"barrow-man",
"barrowfuls":"barrowful",
"barses":"bars",
"barts":"bart",
"bartended":"bartend",
"bartending":"bartend",
"bartenders":"bartender",
"bartered":"barter",
"bartering":"barter",
"barters":"barter",
"bartletts":"bartlett",
"bartonias":"bartonia",
"bartramias":"bartramia",
"barundukis":"barunduki",
"baryes":"barye",
"baryons":"baryon",
"baryteses":"barytes",
"barytones":"barytone",
"based":"base",
"baser":"base",
"bases":"base",
"basest":"base",
"basing":"base",
"baseballs":"baseball",
"baseboards":"baseboard",
"basels":"basel",
"basemen":"baseman",
"basements":"basement",
"basenesses":"baseness",
"basenjis":"basenji",
"bases-on-balls":"base_on_balls",
"bases_on_balls":"base_on_balls",
"bashed":"bash",
"bashes":"bash",
"bashing":"bash",
"bashfulnesses":"bashfulness",
"basics":"basic",
"basicses":"basics",
"basidiomycetes":"basidiomycete",
"basidiomyceteses":"basidiomycetes",
"basidiomycotas":"basidiomycota",
"basidiomycotinas":"basidiomycotina",
"basidia":"basidium",
"basidiia":"basidium",
"basified":"basify",
"basifies":"basify",
"basifying":"basify",
"basils":"basil",
"basileis":"basileus",
"basilicas":"basilica",
"basilicatas":"basilicata",
"basiliscuses":"basiliscus",
"basins":"basin",
"basinfuls":"basinful",
"basked":"bask",
"basking":"bask",
"basks":"bask",
"baskets":"basket",
"basketballs":"basketball",
"basketeers":"basketeer",
"basketfuls":"basketful",
"basketmakers":"basketmaker",
"basketweavers":"basketweaver",
"basles":"basle",
"basophils":"basophil",
"basophiles":"basophile",
"basothos":"basotho",
"basses":"bass",
"bassariscidaes":"bassariscidae",
"bassariscuses":"bassariscus",
"bassarisks":"bassarisk",
"basse-normandies":"basse-normandie",
"bassets":"basset",
"bassias":"bassia",
"bassi":"basso",
"bassos":"basso",
"basswoods":"basswood",
"basts":"bast",
"bastards":"bastard",
"bastardisations":"bastardisation",
"bastardizations":"bastardization",
"bastardized":"bastardize",
"bastardizes":"bastardize",
"bastardizing":"bastardize",
"bastardies":"bastardy",
"basted":"baste",
"bastes":"baste",
"basting":"baste",
"bastinadoed":"bastinado",
"bastinadoes":"bastinado",
"bastinadoing":"bastinado",
"bastings":"basting",
"bastions":"bastion",
"bastnaesites":"bastnaesite",
"bastnasites":"bastnasite",
"basutos":"basuto",
"basutolands":"basutoland",
"bats":"bat",
"batted":"bat",
"batting":"bat",
"bataans":"bataan",
"batches":"batch",
"bated":"bate",
"bating":"bate",
"bateaux":"bateau",
"batfishes":"batfish",
"batfowled":"batfowl",
"batfowling":"batfowl",
"bathed":"bath",
"bathing":"bath",
"baths":"bath",
"bathers":"bather",
"bathhouses":"bathhouse",
"bathings":"bathing",
"batholites":"batholite",
"batholiths":"batholith",
"bathoses":"bathos",
"bathrobes":"bathrobe",
"bathrooms":"bathroom",
"bathtubs":"bathtub",
"bathursts":"bathurst",
"bathyergidaes":"bathyergidae",
"bathyerguses":"bathyergus",
"bathymetries":"bathymetry",
"bathyscapes":"bathyscape",
"bathyscaphs":"bathyscaph",
"bathyscaphes":"bathyscaphe",
"batidaceaes":"batidaceae",
"batises":"batis",
"batmen":"batman",
"batoideis":"batoidei",
"batrachias":"batrachia",
"batrachians":"batrachian",
"batrachoididaes":"batrachoididae",
"batrachosepses":"batrachoseps",
"batsmen":"batsman",
"batswanas":"batswana",
"battalions":"battalion",
"battened":"batten",
"battening":"batten",
"battens":"batten",
"battered":"batter",
"battering":"batter",
"batters":"batter",
"battercakes":"battercake",
"batterings":"battering",
"batteries":"battery",
"battled":"battle",
"battles":"battle",
"battling":"battle",
"battle-axes":"battle-ax",
"battledores":"battledore",
"battlefields":"battlefield",
"battlefronts":"battlefront",
"battlegrounds":"battleground",
"battlements":"battlement",
"battlers":"battler",
"battleships":"battleship",
"battlewagons":"battlewagon",
"battues":"battue",
"battier":"batty",
"battiest":"batty",
"batwomen":"batwoman",
"baubles":"bauble",
"bauds":"baud",
"baudelaires":"baudelaire",
"bauhinias":"bauhinia",
"baulks":"baulk",
"baulkier":"baulky",
"baulkiest":"baulky",
"bawds":"bawd",
"bawdinesses":"bawdiness",
"bawdries":"bawdry",
"bawdier":"bawdy",
"bawdies":"bawdy",
"bawdiest":"bawdy",
"bawdyhouses":"bawdyhouse",
"bawled":"bawl",
"bawling":"bawl",
"bawls":"bawl",
"bawlings":"bawling",
"bayed":"bay",
"baying":"bay",
"bays":"bay",
"bayas":"baya",
"bayberries":"bayberry",
"bayers":"bayer",
"bayoneted":"bayonet",
"bayoneting":"bayonet",
"bayonets":"bayonet",
"bayonetted":"bayonet",
"bayonetting":"bayonet",
"bayous":"bayou",
"bazaars":"bazaar",
"bazars":"bazar",
"bazookas":"bazooka",
"bbs":"bb",
"bbls":"bbl",
"bbses":"bbs",
"bds":"bd",
"am":"be",
"are":"be",
"been":"be",
"bes":"be",
"is":"be",
"was":"be",
"were":"be",
"'re":"be",
"'m":"be",
"beached":"beach",
"beaches":"beach",
"beaching":"beach",
"beachheads":"beachhead",
"beaconed":"beacon",
"beaconing":"beacon",
"beacons":"beacon",
"beaded":"bead",
"beading":"bead",
"beads":"bead",
"bead-rubies":"bead-ruby",
"beadings":"beading",
"beadses":"beads",
"beadsmen":"beadsman",
"beadworks":"beadwork",
"beadier":"beady",
"beadiest":"beady",
"beaked":"beak",
"beaking":"beak",
"beaks":"beak",
"beamed":"beam",
"beaming":"beam",
"beams":"beam",
"beamier":"beamy",
"beamiest":"beamy",
"beaned":"bean",
"beaning":"bean",
"beans":"bean",
"beanballs":"beanball",
"beaners":"beaner",
"beaneries":"beanery",
"beanies":"beanie",
"beanos":"beano",
"beantowns":"beantown",
"beared":"bear",
"bearing":"bear",
"bears":"bear",
"bore":"bear",
"born":"bear",
"borne":"bear",
"bearberries":"bearberry",
"bearcats":"bearcat",
"bearded":"beard",
"bearding":"beard",
"beards":"beard",
"bearers":"bearer",
"bearings":"bearing",
"bearskins":"bearskin",
"bearwoods":"bearwood",
"beasts":"beast",
"beastlinesses":"beastliness",
"beastlier":"beastly",
"beastliest":"beastly",
"beaten":"beat",
"beating":"beat",
"beats":"beat",
"beaters":"beater",
"beatified":"beatify",
"beatifies":"beatify",
"beatifying":"beatify",
"beatings":"beating",
"beatitudes":"beatitude",
"beaus":"beau",
"beaux":"beau",
"beaugregories":"beaugregory",
"beaumontias":"beaumontia",
"beauts":"beaut",
"beauteousnesses":"beauteousness",
"beauticians":"beautician",
"beautified":"beautify",
"beautifies":"beautify",
"beautifying":"beautify",
"beauties":"beauty",
"beavered":"beaver",
"beavering":"beaver",
"beavers":"beaver",
"bebops":"bebop",
"becalmed":"becalm",
"becalming":"becalm",
"becalms":"becalm",
"beccaficos":"beccafico",
"bechamels":"bechamel",
"bechanced":"bechance",
"bechances":"bechance",
"bechancing":"bechance",
"beches-de-mer":"beche-de-mer",
"bechuanas":"bechuana",
"becks":"beck",
"beckets":"becket",
"becketts":"beckett",
"beckoned":"beckon",
"beckoning":"beckon",
"beckons":"beckon",
"beclouded":"becloud",
"beclouding":"becloud",
"beclouds":"becloud",
"became":"become",
"becomes":"become",
"becoming":"become",
"became_known":"become_known",
"becomes_know":"become_known",
"bedded":"bed",
"bedding":"bed",
"beds":"bed",
"bed-wettings":"bed-wetting",
"bedaubed":"bedaub",
"bedaubing":"bedaub",
"bedaubs":"bedaub",
"bedazzled":"bedazzle",
"bedazzles":"bedazzle",
"bedazzling":"bedazzle",
"bedbugs":"bedbug",
"bedchambers":"bedchamber",
"bedclotheses":"bedclothes",
"bedcovers":"bedcover",
"bedders":"bedder",
"beddings":"bedding",
"bedecked":"bedeck",
"bedecking":"bedeck",
"bedecks":"bedeck",
"bedesmen":"bedesman",
"bedeviled":"bedevil",
"bedeviling":"bedevil",
"bedevilled":"bedevil",
"bedevilling":"bedevil",
"bedevils":"bedevil",
"bedevilments":"bedevilment",
"bedewed":"bedew",
"bedewing":"bedew",
"bedframes":"bedframe",
"bedighted":"bedight",
"bedighting":"bedight",
"bedights":"bedight",
"bedimmed":"bedim",
"bedimming":"bedim",
"bedims":"bedim",
"bedizened":"bedizen",
"bedizening":"bedizen",
"bedizens":"bedizen",
"bedlams":"bedlam",
"bedouins":"bedouin",
"bedraggled":"bedraggle",
"bedraggling":"bedraggle",
"bedrocks":"bedrock",
"bedrooms":"bedroom",
"bedsides":"bedside",
"bedsits":"bedsit",
"bedsitters":"bedsitter",
"bedsores":"bedsore",
"bedspreads":"bedspread",
"bedsteads":"bedstead",
"bedtimes":"bedtime",
"beduins":"beduin",
"bees":"bee",
"beebalms":"beebalm",
"beebreads":"beebread",
"beeches":"beech",
"beechwoods":"beechwood",
"beefed":"beef",
"beefing":"beef",
"beefs":"beef",
"beeves":"beef",
"beefaloes":"beefalo",
"beefalos":"beefalo",
"beefburgers":"beefburger",
"beefeaters":"beefeater",
"beefwoods":"beefwood",
"beefier":"beefy",
"beefiest":"beefy",
"beehives":"beehive",
"beekeepers":"beekeeper",
"beekeepings":"beekeeping",
"beelzebubs":"beelzebub",
"beentos":"beento",
"beeped":"beep",
"beeping":"beep",
"beeps":"beep",
"beers":"beer",
"beerier":"beery",
"beeriest":"beery",
"beets":"beet",
"beetflies":"beetfly",
"beethovens":"beethoven",
"beetled":"beetle",
"beetles":"beetle",
"beetling":"beetle",
"beetleweeds":"beetleweed",
"beetroots":"beetroot",
"befallen":"befall",
"befalling":"befall",
"befalls":"befall",
"befell":"befall",
"befits":"befit",
"befitted":"befit",
"befitting":"befit",
"befogged":"befog",
"befogging":"befog",
"befogs":"befog",
"befooled":"befool",
"befooling":"befool",
"befools":"befool",
"befoolings":"befooling",
"befouled":"befoul",
"befouling":"befoul",
"befouls":"befoul",
"befoulments":"befoulment",
"befriended":"befriend",
"befriending":"befriend",
"befuddled":"befuddle",
"befuddles":"befuddle",
"befuddling":"befuddle",
"befuddlements":"befuddlement",
"begged":"beg",
"begging":"beg",
"begs":"beg",
"begat":"beget",
"begets":"beget",
"begetting":"beget",
"begot":"beget",
"begotten":"beget",
"begetters":"begetter",
"beggared":"beggar",
"beggaring":"beggar",
"beggars":"beggar",
"beggar-tickses":"beggar-ticks",
"beggarweeds":"beggarweed",
"beggaries":"beggary",
"beggings":"begging",
"began":"begin",
"beginning":"begin",
"begins":"begin",
"begun":"begin",
"beginners":"beginner",
"beginnings":"beginning",
"begirded":"begird",
"begirding":"begird",
"begirds":"begird",
"begirt":"begird",
"begonias":"begonia",
"begoniaceaes":"begoniaceae",
"begrimed":"begrime",
"begrimes":"begrime",
"begriming":"begrime",
"begrudged":"begrudge",
"begrudges":"begrudge",
"begrudging":"begrudge",
"beguiled":"beguile",
"beguiles":"beguile",
"beguiling":"beguile",
"beguilements":"beguilement",
"beguilers":"beguiler",
"behaved":"behave",
"behaves":"behave",
"behaving":"behave",
"behaviors":"behavior",
"behaviorisms":"behaviorism",
"behaviorists":"behaviorist",
"behaviours":"behaviour",
"behaviourisms":"behaviourism",
"behaviourists":"behaviourist",
"beheaded":"behead",
"beheading":"behead",
"beheads":"behead",
"beheadings":"beheading",
"behemoths":"behemoth",
"behinds":"behind",
"behmens":"behmen",
"behmenisms":"behmenism",
"beheld":"behold",
"beholden":"behold",
"beholding":"behold",
"beholds":"behold",
"beholders":"beholder",
"beholdings":"beholding",
"behooves":"behoof",
"behooved":"behoove",
"behooving":"behoove",
"beiges":"beige",
"beijings":"beijing",
"beings":"being",
"beingnesses":"beingness",
"beiruts":"beirut",
"bejeweled":"bejewel",
"bejeweling":"bejewel",
"bejewelled":"bejewel",
"bejewelling":"bejewel",
"bejewels":"bejewel",
"bels":"bel",
"bel-merodaches":"bel-merodach",
"belabored":"belabor",
"belaboring":"belabor",
"belabors":"belabor",
"belamcandas":"belamcanda",
"belaruses":"belarus",
"belarusians":"belarusian",
"belayed":"belay",
"belaying":"belay",
"belays":"belay",
"belched":"belch",
"belches":"belch",
"belching":"belch",
"belchings":"belching",
"beldams":"beldam",
"beldames":"beldame",
"beleaguered":"beleaguer",
"beleaguering":"beleaguer",
"beleaguers":"beleaguer",
"beleaguerings":"beleaguering",
"belemnitidaes":"belemnitidae",
"belemnoideas":"belemnoidea",
"belfasts":"belfast",
"belfries":"belfry",
"belgiques":"belgique",
"belgiums":"belgium",
"belgrades":"belgrade",
"belied":"belie",
"belies":"belie",
"belying":"belie",
"beliefs":"belief",
"believes":"believe",
"believabilities":"believability",
"believed":"believe",
"believing":"believe",
"believers":"believer",
"belittled":"belittle",
"belittles":"belittle",
"belittling":"belittle",
"belittlings":"belittling",
"belizes":"belize",
"e-books":"e-book",
"bells":"bell",
"bell-bottoms":"bell-bottom",
"belladonnas":"belladonna",
"bellarmines":"bellarmine",
"bellbottomses":"bellbottoms",
"bellboys":"bellboy",
"belles-lettreses":"belles-lettres",
"bellflowers":"bellflower",
"bellhops":"bellhop",
"belligerences":"belligerence",
"belligerencies":"belligerency",
"belligerents":"belligerent",
"bellings":"belling",
"bellises":"bellis",
"bellmen":"bellman",
"bellowed":"bellow",
"bellowing":"bellow",
"bellows":"bellow",
"bellowings":"bellowing",
"bellowses":"bellows",
"bellworts":"bellwort",
"bellied":"belly",
"bellies":"belly",
"bellying":"belly",
"belly-flopped":"belly-flop",
"belly-flopping":"belly-flop",
"belly-flops":"belly-flop",
"bellyached":"bellyache",
"bellyaches":"bellyache",
"bellyaching":"bellyache",
"bellyachers":"bellyacher",
"bellybuttons":"bellybutton",
"bellyfuls":"bellyful",
"belonged":"belong",
"belonging":"belong",
"belongs":"belong",
"belongingses":"belongings",
"belonidaes":"belonidae",
"belorussias":"belorussia",
"belorussians":"belorussian",
"belostomatidaes":"belostomatidae",
"beloveds":"beloved",
"belted":"belt",
"belting":"belt",
"belts":"belt",
"belugas":"beluga",
"belvederes":"belvedere",
"bemas":"bema",
"bembas":"bemba",
"bemired":"bemire",
"bemires":"bemire",
"bemiring":"bemire",
"bemisias":"bemisia",
"bemoaned":"bemoan",
"bemoaning":"bemoan",
"bemoans":"bemoan",
"bemocked":"bemock",
"bemocking":"bemock",
"bemocks":"bemock",
"bemused":"bemuse",
"bemuses":"bemuse",
"bemusing":"bemuse",
"bemusements":"bemusement",
"benamed":"bename",
"benames":"bename",
"benaming":"bename",
"benempt":"bename",
"benched":"bench",
"benches":"bench",
"benching":"bench",
"benchmarks":"benchmark",
"bending":"bend",
"bends":"bend",
"bent":"bend",
"bendabilities":"bendability",
"benders":"bender",
"bendings":"bending",
"bendses":"bends",
"bendier":"bendy",
"bendiest":"bendy",
"benedicks":"benedick",
"benedicts":"benedict",
"benedictions":"benediction",
"benefactions":"benefaction",
"benefactors":"benefactor",
"benefices":"benefice",
"beneficences":"beneficence",
"beneficiaries":"beneficiary",
"beneficiations":"beneficiation",
"benefited":"benefit",
"benefiting":"benefit",
"benefits":"benefit",
"benevolences":"benevolence",
"benghazis":"benghazi",
"benis":"beni",
"benignancies":"benignancy",
"benignities":"benignity",
"benins":"benin",
"benjamins":"benjamin",
"bennes":"benne",
"bennets":"bennet",
"bennettitaceaes":"bennettitaceae",
"bennettitaleses":"bennettitales",
"bennettitises":"bennettitis",
"bennis":"benni",
"bennies":"bennie",
"benniseeds":"benniseed",
"bents":"bent",
"bentgrasses":"bentgrass",
"benthoses":"benthos",
"benumbed":"benumb",
"benumbing":"benumb",
"benumbs":"benumb",
"benweeds":"benweed",
"benzedrines":"benzedrine",
"benzenes":"benzene",
"benzines":"benzine",
"benzocaines":"benzocaine",
"benzofurans":"benzofuran",
"benzoins":"benzoin",
"benzols":"benzol",
"benzyls":"benzyl",
"beograds":"beograd",
"bequeathed":"bequeath",
"bequeathing":"bequeath",
"bequeaths":"bequeath",
"bequests":"bequest",
"berated":"berate",
"berates":"berate",
"berating":"berate",
"beratings":"berating",
"berberidaceaes":"berberidaceae",
"berberises":"berberis",
"berceuses":"berceuse",
"bercies":"bercy",
"bereaved":"bereave",
"bereaving":"bereave",
"bereft":"bereave",
"bereavements":"bereavement",
"bergs":"berg",
"bergalls":"bergall",
"bergamots":"bergamot",
"beriths":"berith",
"berkeleys":"berkeley",
"berkeliums":"berkelium",
"berkshireses":"berkshires",
"berlins":"berlin",
"bermudas":"bermuda",
"bermudans":"bermudan",
"bermudases":"bermudas",
"bermudians":"bermudian",
"berns":"bern",
"bernes":"berne",
"berried":"berry",
"berries":"berry",
"berrying":"berry",
"bersaglieri":"bersagliere",
"berteroas":"berteroa",
"berthed":"berth",
"berthing":"berth",
"berths":"berth",
"berthas":"bertha",
"bertholletias":"bertholletia",
"berycomorphis":"berycomorphi",
"berylliums":"beryllium",
"beseeched":"beseech",
"beseeches":"beseech",
"beseeching":"beseech",
"besought":"beseech",
"beseemed":"beseem",
"beseeming":"beseem",
"beseems":"beseem",
"besets":"beset",
"besetted":"beset",
"besetting":"beset",
"besetments":"besetment",
"besieged":"besiege",
"besieges":"besiege",
"besieging":"besiege",
"besiegers":"besieger",
"besiegings":"besieging",
"besmeared":"besmear",
"besmearing":"besmear",
"besmears":"besmear",
"besmirched":"besmirch",
"besmirches":"besmirch",
"besmirching":"besmirch",
"besots":"besot",
"besotted":"besot",
"besotting":"besot",
"bespattered":"bespatter",
"bespattering":"bespatter",
"bespatters":"bespatter",
"bespeaking":"bespeak",
"bespeaks":"bespeak",
"bespoke":"bespeak",
"bespoken":"bespeak",
"bespreading":"bespread",
"bespreads":"bespread",
"besprinkled":"besprinkle",
"besprinkles":"besprinkle",
"besprinkling":"besprinkle",
"besseras":"bessera",
"besseyas":"besseya",
"bested":"best",
"besting":"best",
"bests":"best",
"besteaded":"bestead",
"besteading":"bestead",
"besteads":"bestead",
"bestialities":"bestiality",
"bestialized":"bestialize",
"bestializes":"bestialize",
"bestializing":"bestialize",
"bestiaries":"bestiary",
"bestirred":"bestir",
"bestirring":"bestir",
"bestirs":"bestir",
"bestowed":"bestow",
"bestowing":"bestow",
"bestows":"bestow",
"bestowals":"bestowal",
"bestowments":"bestowment",
"bestrewed":"bestrew",
"bestrewing":"bestrew",
"bestrewn":"bestrew",
"bestrews":"bestrew",
"bestrid":"bestride",
"bestridden":"bestride",
"bestrides":"bestride",
"bestriding":"bestride",
"bestrode":"bestride",
"bets":"bet",
"betted":"bet",
"betting":"bet",
"betas":"beta",
"betaken":"betake",
"betakes":"betake",
"betaking":"betake",
"betook":"betake",
"betatrons":"betatron",
"betels":"betel",
"betelgeuses":"betelgeuse",
"bethinking":"bethink",
"bethinks":"bethink",
"bethought":"bethink",
"betided":"betide",
"betides":"betide",
"betiding":"betide",
"betises":"betise",
"betokened":"betoken",
"betokening":"betoken",
"betokens":"betoken",
"betonies":"betony",
"betrayed":"betray",
"betraying":"betray",
"betrays":"betray",
"betrayals":"betrayal",
"betrayers":"betrayer",
"betrothed":"betroth",
"betrothing":"betroth",
"betroths":"betroth",
"betrothals":"betrothal",
"bettered":"better",
"bettering":"better",
"betters":"better",
"betterments":"betterment",
"bettongias":"bettongia",
"bettors":"bettor",
"betulas":"betula",
"betulaceaes":"betulaceae",
"betweeenbrains":"betweeenbrain",
"beveled":"bevel",
"beveling":"bevel",
"bevelled":"bevel",
"bevelling":"bevel",
"bevels":"bevel",
"beverages":"beverage",
"bevvies":"bevvy",
"bevies":"bevy",
"bewailed":"bewail",
"bewailing":"bewail",
"bewails":"bewail",
"bewildered":"bewilder",
"bewildering":"bewilder",
"bewilders":"bewilder",
"bewilderments":"bewilderment",
"bewitched":"bewitch",
"bewitches":"bewitch",
"bewitching":"bewitch",
"bewitcheries":"bewitchery",
"bewitchments":"bewitchment",
"bewrayed":"bewray",
"bewraying":"bewray",
"bewrays":"bewray",
"bezants":"bezant",
"beziques":"bezique",
"bezzants":"bezzant",
"bharats":"bharat",
"bhishties":"bheesty",
"bhutaneses":"bhutanese",
"bhutanis":"bhutani",
"bis":"bi",
"bialies":"bialy",
"bialystokers":"bialystoker",
"biased":"bias",
"biases":"bias",
"biasing":"bias",
"biassed":"bias",
"biassing":"bias",
"bibbed":"bib",
"bibbing":"bib",
"bibs":"bib",
"bibles":"bible",
"bible-worships":"bible-worship",
"bibliographies":"bibliography",
"bibliolatries":"bibliolatry",
"bibliophiles":"bibliophile",
"bibliopoles":"bibliopole",
"bibliopolists":"bibliopolist",
"bibliothecs":"bibliothec",
"bibliothecae":"bibliotheca",
"bibliothecas":"bibliotheca",
"biboses":"bibos",
"bicarbonates":"bicarbonate",
"bicennaries":"bicentenary",
"bicentenaries":"bicentenary",
"bicentennials":"bicentennial",
"bicepses":"biceps",
"bichlorides":"bichloride",
"bichromates":"bichromate",
"bickered":"bicker",
"bickering":"bicker",
"bickers":"bicker",
"bickerings":"bickering",
"bicorns":"bicorn",
"bicornes":"bicorne",
"bicuspids":"bicuspid",
"bicycled":"bicycle",
"bicycles":"bicycle",
"bicycling":"bicycle",
"bicycle-built-for-twos":"bicycle-built-for-two",
"bicyclists":"bicyclist",
"bade":"bid",
"bidden":"bid",
"bidding":"bid",
"bids":"bid",
"bidas":"bida",
"biddings":"bidding",
"biddies":"biddy",
"biddy-biddies":"biddy-biddy",
"bided":"bide",
"biding":"bide",
"bode":"bide",
"bidenses":"bidens",
"biegnets":"biegnet",
"biers":"bier",
"biffed":"biff",
"biffing":"biff",
"biffs":"biff",
"bifocals":"bifocal",
"bifurcated":"bifurcate",
"bifurcating":"bifurcate",
"bifurcations":"bifurcation",
"bigger":"big",
"biggest":"big",
"bigamies":"bigamy",
"bigarades":"bigarade",
"bigeyes":"bigeye",
"bigfeet":"bigfoot",
"bigfoots":"bigfoot",
"bighorns":"bighorn",
"bigmouths":"bigmouth",
"bignesses":"bigness",
"bignonias":"bignonia",
"bignoniaceaes":"bignoniaceae",
"bigotries":"bigotry",
"bigwigs":"bigwig",
"bijoux":"bijou",
"biked":"bike",
"bikes":"bike",
"biking":"bike",
"bikinis":"bikini",
"bilateralisms":"bilateralism",
"bilateralities":"bilaterality",
"bilberries":"bilberry",
"bilboes":"bilbo",
"bilbos":"bilbo",
"bilobes":"bilbo",
"bilbies":"bilby",
"bilestones":"bilestone",
"bilged":"bilge",
"bilges":"bilge",
"bilging":"bilge",
"bilgewaters":"bilgewater",
"bilharzias":"bilharzia",
"bilharziases":"bilharziasis",
"bilimbis":"bilimbi",
"biliousnesses":"biliousness",
"bilked":"bilk",
"bilking":"bilk",
"bilks":"bilk",
"billed":"bill",
"billing":"bill",
"bills":"bill",
"billboards":"billboard",
"billeted":"billet",
"billeting":"billet",
"billets":"billet",
"billets-doux":"billet-doux",
"billfishes":"billfish",
"billfolds":"billfold",
"billhooks":"billhook",
"billings":"billing",
"billingsgates":"billingsgate",
"billions":"billion",
"billionses":"billions",
"billionths":"billionth",
"billowed":"billow",
"billowing":"billow",
"billows":"billow",
"billowier":"billowy",
"billowiest":"billowy",
"billies":"billy",
"billy-hos":"billy-ho",
"billycans":"billycan",
"billyos":"billyo",
"billyohs":"billyoh",
"billysticks":"billystick",
"bilsteds":"bilsted",
"bimboes":"bimbo",
"bimbos":"bimbo",
"bimillenaries":"bimillenary",
"bimillenniums":"bimillennium",
"bimlis":"bimli",
"bimonthlies":"bimonthly",
"binned":"bin",
"binning":"bin",
"bins":"bin",
"binaries":"binary",
"binding":"bind",
"binds":"bind",
"bound":"bind",
"binders":"binder",
"binderies":"bindery",
"bindings":"binding",
"bines":"bine",
"binfuls":"binful",
"binges":"binge",
"bingeys":"bingey",
"bingles":"bingle",
"bingos":"bingo",
"bingies":"bingy",
"binoculars":"binocular",
"binocularses":"binoculars",
"binturongs":"binturong",
"bioassayed":"bioassay",
"bioassaying":"bioassay",
"biodegraded":"biodegrade",
"biodegrading":"biodegrade",
"bioengineerings":"bioengineering",
"bioflavinoids":"bioflavinoid",
"biogeneses":"biogenesis",
"biogenies":"biogeny",
"biographers":"biographer",
"biographies":"biography",
"biologicals":"biological",
"biologists":"biologist",
"biologies":"biology",
"bionomicses":"bionomics",
"biopsies":"biopsy",
"bioscopies":"bioscopy",
"biosyntheses":"biosynthesis",
"biosystematicses":"biosystematics",
"biosystematies":"biosystematy",
"biotas":"biota",
"biotechnologies":"biotechnology",
"biotins":"biotin",
"biquadrates":"biquadrate",
"biquadratics":"biquadratic",
"birched":"birch",
"birches":"birch",
"birching":"birch",
"birchbarks":"birchbark",
"birded":"bird",
"birding":"bird",
"birds":"bird",
"bird-dogged":"bird-dog",
"bird-dogging":"bird-dog",
"bird-dogs":"bird-dog",
"bird-on-the-wings":"bird-on-the-wing",
"bird-watched":"bird-watch",
"bird-watching":"bird-watch",
"birdbaths":"birdbath",
"birdbrains":"birdbrain",
"birdcalls":"birdcall",
"birders":"birder",
"birdhouses":"birdhouse",
"birdied":"birdie",
"birdieing":"birdie",
"birdies":"birdie",
"birdlimes":"birdlime",
"birdmen":"birdman",
"birdseeds":"birdseed",
"birdsongs":"birdsong",
"birefringences":"birefringence",
"birettas":"biretta",
"birled":"birle",
"birles":"birle",
"birling":"birle",
"birlings":"birling",
"birminghams":"birmingham",
"biros":"biro",
"birthed":"birth",
"birthing":"birth",
"births":"birth",
"birthcontrols":"birthcontrol",
"birthdays":"birthday",
"birthings":"birthing",
"birthmarks":"birthmark",
"birthplaces":"birthplace",
"birthrates":"birthrate",
"birthrights":"birthright",
"birthroots":"birthroot",
"birthworts":"birthwort",
"bisayans":"bisayan",
"bisayases":"bisayas",
"biscuits":"biscuit",
"biscutellas":"biscutella",
"bises":"bise",
"bisected":"bisect",
"bisecting":"bisect",
"bisectrices":"bisectrix",
"bisexuals":"bisexual",
"bisexualities":"bisexuality",
"bishops":"bishop",
"bishoprics":"bishopric",
"biskeks":"biskek",
"bismarcks":"bismarck",
"bismarks":"bismark",
"bismuths":"bismuth",
"bissaus":"bissau",
"bisters":"bister",
"bistouries":"bistoury",
"bistres":"bistre",
"bistros":"bistro",
"bits":"bit",
"bitted":"bit",
"bitting":"bit",
"bitches":"bitch",
"bitchinesses":"bitchiness",
"bitchier":"bitchy",
"bitchiest":"bitchy",
"bit":"bite",
"bites":"bite",
"biting":"bite",
"bitten":"bite",
"bitises":"bitis",
"bitmaps":"bitmap",
"bitstocks":"bitstock",
"bitts":"bitt",
"bitterer":"bitter",
"bitterest":"bitter",
"bitters":"bitter",
"bitter-barks":"bitter-bark",
"bittercresses":"bittercress",
"bitternesses":"bitterness",
"bitternuts":"bitternut",
"bitterroots":"bitterroot",
"bittersweets":"bittersweet",
"bitterweeds":"bitterweed",
"bitterwoods":"bitterwood",
"bittier":"bitty",
"bittiest":"bitty",
"bituminized":"bituminize",
"bituminizing":"bituminize",
"bivalves":"bivalve",
"bivalvias":"bivalvia",
"bivouacked":"bivouac",
"bivouacking":"bivouac",
"bivouacs":"bivouac",
"bivouackings":"bivouacking",
"bivvies":"bivvy",
"biweeklies":"biweekly",
"bizs":"biz",
"bizarrenesses":"bizarreness",
"bizes":"bize",
"bks":"bk",
"blabbed":"blab",
"blabbing":"blab",
"blabs":"blab",
"blabbermouths":"blabbermouth",
"blaberuses":"blaberus",
"blacked":"black",
"blacker":"black",
"blackest":"black",
"blacking":"black",
"blacks":"black",
"blackamoors":"blackamoor",
"blackballed":"blackball",
"blackballing":"blackball",
"blackballs":"blackball",
"blackbeards":"blackbeard",
"blackbeetles":"blackbeetle",
"blackberries":"blackberry",
"blackberry-lilies":"blackberry-lily",
"blackbirds":"blackbird",
"blackboards":"blackboard",
"blackbodies":"blackbody",
"blackbucks":"blackbuck",
"blackburns":"blackburn",
"blackcaps":"blackcap",
"blackcocks":"blackcock",
"blackdamps":"blackdamp",
"blackened":"blacken",
"blackening":"blacken",
"blackens":"blacken",
"blackenings":"blackening",
"blackfishes":"blackfish",
"blackflies":"blackfly",
"Blackfeet":"Blackfoot",
"blackfriars":"blackfriar",
"blackguarded":"blackguard",
"blackguarding":"blackguard",
"blackguards":"blackguard",
"blackheads":"blackhead",
"blackhearts":"blackheart",
"blackings":"blacking",
"blackjacked":"blackjack",
"blackjacking":"blackjack",
"blackjacks":"blackjack",
"blacklegs":"blackleg",
"blacklisted":"blacklist",
"blacklisting":"blacklist",
"blacklists":"blacklist",
"blackmailed":"blackmail",
"blackmailing":"blackmail",
"blackmails":"blackmail",
"blackmailers":"blackmailer",
"blacknesses":"blackness",
"blackouts":"blackout",
"blackpolls":"blackpoll",
"blackseeds":"blackseed",
"blacksmiths":"blacksmith",
"blacksnakes":"blacksnake",
"blacktails":"blacktail",
"blackthorns":"blackthorn",
"blacktops":"blacktop",
"blacktoppings":"blacktopping",
"blackwoods":"blackwood",
"bladders":"bladder",
"bladdernoses":"bladdernose",
"bladderpods":"bladderpod",
"bladderwracks":"bladderwrack",
"blades":"blade",
"blaeberries":"blaeberry",
"blahs":"blah",
"blamed":"blame",
"blames":"blame",
"blaming":"blame",
"blamelessnesses":"blamelessness",
"blameworthinesses":"blameworthiness",
"blanched":"blanch",
"blanches":"blanch",
"blanching":"blanch",
"blander":"bland",
"blandest":"bland",
"blandfordias":"blandfordia",
"blandished":"blandish",
"blandishes":"blandish",
"blandishing":"blandish",
"blandishments":"blandishment",
"blandnesses":"blandness",
"blanked":"blank",
"blanker":"blank",
"blankest":"blank",
"blanking":"blank",
"blanks":"blank",
"blanketed":"blanket",
"blanketing":"blanket",
"blankets":"blanket",
"blanquillos":"blanquillo",
"blared":"blare",
"blares":"blare",
"blaring":"blare",
"blarinas":"blarina",
"blarings":"blaring",
"blarneys":"blarney",
"blasphemed":"blaspheme",
"blasphemes":"blaspheme",
"blaspheming":"blaspheme",
"blasphemies":"blasphemy",
"blasted":"blast",
"blasting":"blast",
"blasts":"blast",
"blastemas":"blastema",
"blastemata":"blastema",
"blastocladias":"blastocladia",
"blastocladialeses":"blastocladiales",
"blastocoels":"blastocoel",
"blastoderms":"blastoderm",
"blastodiaceaes":"blastodiaceae",
"blastodiscs":"blastodisc",
"blastoffs":"blastoff",
"blastomyceses":"blastomyces",
"blastospheres":"blastosphere",
"blastulae":"blastula",
"blastulas":"blastula",
"blats":"blat",
"blatted":"blat",
"blatting":"blat",
"blathered":"blather",
"blathering":"blather",
"blathers":"blather",
"blatherskites":"blatherskite",
"blattas":"blatta",
"blattarias":"blattaria",
"blattellas":"blattella",
"blattered":"blatter",
"blattering":"blatter",
"blattidaes":"blattidae",
"blattodeas":"blattodea",
"blauboks":"blaubok",
"blazed":"blaze",
"blazes":"blaze",
"blazing":"blaze",
"blazers":"blazer",
"blazings":"blazing",
"blazoned":"blazon",
"blazoning":"blazon",
"blazons":"blazon",
"blazonries":"blazonry",
"bleached":"bleach",
"bleaches":"bleach",
"bleaching":"bleach",
"bleachers":"bleacher",
"bleaker":"bleak",
"bleakest":"bleak",
"bleaknesses":"bleakness",
"bleared":"blear",
"blearing":"blear",
"blears":"blear",
"blearier":"bleary",
"bleariest":"bleary",
"bleated":"bleat",
"bleating":"bleat",
"bleats":"bleat",
"blebs":"bleb",
"blechnaceaes":"blechnaceae",
"blechnums":"blechnum",
"bled":"bleed",
"bleeding":"bleed",
"bleeds":"bleed",
"bleeders":"bleeder",
"bleedings":"bleeding",
"bleeped":"bleep",
"bleeping":"bleep",
"bleeps":"bleep",
"blemished":"blemish",
"blemishes":"blemish",
"blemishing":"blemish",
"blenched":"blench",
"blenches":"blench",
"blenching":"blench",
"blended":"blend",
"blending":"blend",
"blends":"blend",
"blent":"blend",
"blendes":"blende",
"blenders":"blender",
"blendings":"blending",
"blenniidaes":"blenniidae",
"blennioids":"blennioid",
"blennioideas":"blennioidea",
"blenniuses":"blennius",
"blennies":"blenny",
"blephilias":"blephilia",
"blesboks":"blesbok",
"blesbucks":"blesbuck",
"blessed":"bless",
"blesses":"bless",
"blessing":"bless",
"blest":"bless",
"blessednesses":"blessedness",
"blessings":"blessing",
"blethers":"blether",
"bletillas":"bletilla",
"bleus":"bleu",
"blewitses":"blewits",
"blighs":"bligh",
"blighias":"blighia",
"blighted":"blight",
"blighting":"blight",
"blights":"blight",
"blighters":"blighter",
"blighties":"blighty",
"blimps":"blimp",
"blinded":"blind",
"blinder":"blind",
"blindest":"blind",
"blinding":"blind",
"blinds":"blind",
"blinders":"blinder",
"blindfishes":"blindfish",
"blindfolded":"blindfold",
"blindfolding":"blindfold",
"blindfolds":"blindfold",
"blindnesses":"blindness",
"blindstoreys":"blindstorey",
"blindstories":"blindstory",
"blindworms":"blindworm",
"blinis":"blini",
"blinked":"blink",
"blinking":"blink",
"blinks":"blink",
"blinkers":"blinker",
"blinkses":"blinks",
"blintzs":"blintz",
"blintzes":"blintze",
"blinies":"bliny",
"blips":"blip",
"blisses":"bliss",
"blissfulnesses":"blissfulness",
"blissuses":"blissus",
"blistered":"blister",
"blistering":"blister",
"blisters":"blister",
"blither":"blithe",
"blithest":"blithe",
"blithenesses":"blitheness",
"blithered":"blither",
"blithering":"blither",
"blithers":"blither",
"blitts":"blitt",
"blitzed":"blitz",
"blitzing":"blitz",
"blitzs":"blitz",
"blizzards":"blizzard",
"bloated":"bloat",
"bloating":"bloat",
"blobbed":"blob",
"blobbing":"blob",
"blobs":"blob",
"blocs":"bloc",
"blocked":"block",
"blocking":"block",
"blocks":"block",
"blockaded":"blockade",
"blockades":"blockade",
"blockading":"blockade",
"blockages":"blockage",
"blockheads":"blockhead",
"blockhouses":"blockhouse",
"blockings":"blocking",
"blockier":"blocky",
"blockiest":"blocky",
"blokes":"bloke",
"blollies":"blolly",
"blonder":"blond",
"blondest":"blond",
"blonds":"blond",
"blondes":"blonde",
"blondnesses":"blondness",
"blooded":"blood",
"blooding":"blood",
"bloods":"blood",
"blood-twigs":"blood-twig",
"bloodbaths":"bloodbath",
"bloodberries":"bloodberry",
"bloodhounds":"bloodhound",
"bloodlettings":"bloodletting",
"bloodlines":"bloodline",
"bloodroots":"bloodroot",
"bloodsheds":"bloodshed",
"bloodstones":"bloodstone",
"bloodsuckers":"bloodsucker",
"bloodthirstinesses":"bloodthirstiness",
"bloodthirstier":"bloodthirsty",
"bloodthirstiest":"bloodthirsty",
"bloodied":"bloody",
"bloodier":"bloody",
"bloodies":"bloody",
"bloodiest":"bloody",
"bloodying":"bloody",
"bloomed":"bloom",
"blooming":"bloom",
"blooms":"bloom",
"bloomerias":"bloomeria",
"bloomerses":"bloomers",
"bloomeries":"bloomery",
"bloomings":"blooming",
"bloomier":"bloomy",
"bloomiest":"bloomy",
"blooped":"bloop",
"blooping":"bloop",
"bloopers":"blooper",
"blossomed":"blossom",
"blossoming":"blossom",
"blossoms":"blossom",
"blossomings":"blossoming",
"blots":"blot",
"blotted":"blot",
"blotting":"blot",
"blotched":"blotch",
"blotches":"blotch",
"blotching":"blotch",
"blotchier":"blotchy",
"blotchiest":"blotchy",
"blotters":"blotter",
"blouses":"blouse",
"blew":"blow",
"blowing":"blow",
"blown":"blow",
"blows":"blow",
"blowballs":"blowball",
"blowers":"blower",
"blowfishes":"blowfish",
"blowflies":"blowfly",
"blowguns":"blowgun",
"blowhards":"blowhard",
"blowholes":"blowhole",
"blowjobs":"blowjob",
"blowlamps":"blowlamp",
"blowouts":"blowout",
"blowpipes":"blowpipe",
"blowsier":"blowsy",
"blowsiest":"blowsy",
"blowtorches":"blowtorch",
"blowtubes":"blowtube",
"blowups":"blowup",
"blowier":"blowy",
"blowiest":"blowy",
"blowzier":"blowzy",
"blowziest":"blowzy",
"blew_one's_nose":"blow_one's_nose",
"blowing_one's_nose":"blow_one's_nose",
"blows_one's_nose":"blow_one's_nose",
"blts":"blt",
"blubbed":"blub",
"blubbing":"blub",
"blubs":"blub",
"blubbered":"blubber",
"blubbering":"blubber",
"blubbers":"blubber",
"bluchers":"blucher",
"blucherses":"bluchers",
"bludgeoned":"bludgeon",
"bludgeoning":"bludgeon",
"bludgeons":"bludgeon",
"blued":"blue",
"blueing":"blue",
"bluer":"blue",
"blues":"blue",
"bluest":"blue",
"bluing":"blue",
"blue-bellies":"blue-belly",
"blue-blindnesses":"blue-blindness",
"blue-penciled":"blue-pencil",
"blue-penciling":"blue-pencil",
"blue-pencilled":"blue-pencil",
"blue-pencilling":"blue-pencil",
"blue-pencills":"blue-pencil",
"bluebells":"bluebell",
"blueberries":"blueberry",
"bluebills":"bluebill",
"bluebirds":"bluebird",
"bluebonnets":"bluebonnet",
"bluebottles":"bluebottle",
"bluefins":"bluefin",
"bluefishes":"bluefish",
"bluegills":"bluegill",
"blueheads":"bluehead",
"blueings":"blueing",
"bluejackets":"bluejacket",
"bluenesses":"blueness",
"bluepoints":"bluepoint",
"blueprinted":"blueprint",
"blueprinting":"blueprint",
"blueprints":"blueprint",
"blueses":"blues",
"bluestems":"bluestem",
"bluestockings":"bluestocking",
"bluets":"bluet",
"bluethroats":"bluethroat",
"blueweeds":"blueweed",
"bluewings":"bluewing",
"bluffed":"bluff",
"bluffer":"bluff",
"bluffest":"bluff",
"bluffing":"bluff",
"bluffs":"bluff",
"bluings":"bluing",
"blundered":"blunder",
"blundering":"blunder",
"blunders":"blunder",
"blunderers":"blunderer",
"blunted":"blunt",
"blunter":"blunt",
"bluntest":"blunt",
"blunting":"blunt",
"bluntnesses":"bluntness",
"blurred":"blur",
"blurring":"blur",
"blurs":"blur",
"blurbs":"blurb",
"blurrinesses":"blurriness",
"blurrier":"blurry",
"blurriest":"blurry",
"blurted":"blurt",
"blurting":"blurt",
"blurts":"blurt",
"blushed":"blush",
"blushes":"blush",
"blushing":"blush",
"blushers":"blusher",
"blustered":"bluster",
"blustering":"bluster",
"blusters":"bluster",
"blusterers":"blusterer",
"bms":"bm",
"bmrs":"bmr",
"bmuses":"bmus",
"bnses":"bns",
"boas":"boa",
"boars":"boar",
"boarded":"board",
"boarding":"board",
"boards":"board",
"boarders":"boarder",
"boardings":"boarding",
"boardinghouses":"boardinghouse",
"boardrooms":"boardroom",
"boarfishes":"boarfish",
"boasted":"boast",
"boasting":"boast",
"boasts":"boast",
"boasters":"boaster",
"boastfulnesses":"boastfulness",
"boastings":"boasting",
"boated":"boat",
"boating":"boat",
"boats":"boat",
"boatbills":"boatbill",
"boaters":"boater",
"boathouses":"boathouse",
"boatings":"boating",
"boatloads":"boatload",
"boatmen":"boatman",
"boatswains":"boatswain",
"bobbed":"bob",
"bobbing":"bob",
"bobs":"bob",
"bobbers":"bobber",
"bobberies":"bobbery",
"bobbins":"bobbin",
"bobbled":"bobble",
"bobbles":"bobble",
"bobbling":"bobble",
"bobbies":"bobby",
"bobbysocks":"bobbysock",
"bobbysockers":"bobbysocker",
"bobbysockses":"bobbysocks",
"bobbysoxers":"bobbysoxer",
"bobcats":"bobcat",
"bobfloats":"bobfloat",
"bobolinks":"bobolink",
"bobsleds":"bobsled",
"bobsleighs":"bobsleigh",
"bobtails":"bobtail",
"bobwhites":"bobwhite",
"bocces":"bocce",
"boccis":"bocci",
"boccies":"boccie",
"bocconias":"bocconia",
"boches":"boche",
"bocks":"bock",
"bods":"bod",
"boddhisatvas":"boddhisatva",
"boded":"bode",
"bodes":"bode",
"boding":"bode",
"bodegas":"bodega",
"bodhisattvas":"bodhisattva",
"bodices":"bodice",
"bodings":"boding",
"bodkins":"bodkin",
"bodo-garos":"bodo-garo",
"bodonis":"bodoni",
"bodied":"body",
"bodies":"body",
"bodying":"body",
"body-builds":"body-build",
"bodybuilders":"bodybuilder",
"bodybuildings":"bodybuilding",
"bodyguards":"bodyguard",
"bodysurfed":"bodysurf",
"bodysurfing":"bodysurf",
"boehms":"boehm",
"boehmes":"boehme",
"boehmenisms":"boehmenism",
"boehmerias":"boehmeria",
"boers":"boer",
"boeufs":"boeuf",
"boffos":"boffo",
"bogged":"bog",
"bogging":"bog",
"bogs":"bog",
"bogged-down":"bog-down",
"bogging-down":"bog-down",
"bogs-down":"bog-down",
"bogarts":"bogart",
"bogbeans":"bogbean",
"bogeys":"bogey",
"bogeymen":"bogeyman",
"boggled":"boggle",
"boggles":"boggle",
"boggling":"boggle",
"bogies":"bogie",
"bogmats":"bogmat",
"bogotas":"bogota",
"bogged_down":"bog_down",
"bogging_down":"bog_down",
"bogs_down":"bog_down",
"bohmes":"bohme",
"boidaes":"boidae",
"boiled":"boil",
"boiling":"boil",
"boils":"boil",
"boilers":"boiler",
"boilersuits":"boilersuit",
"boilings":"boiling",
"boises":"boise",
"bokkoses":"bokkos",
"bokmals":"bokmal",
"bolas":"bola",
"bolancis":"bolanci",
"bolases":"bolas",
"bolbitises":"bolbitis",
"bolder":"bold",
"boldest":"bold",
"boldnesses":"boldness",
"boles":"bole",
"boleros":"bolero",
"boletaceaes":"boletaceae",
"boletelluses":"boletellus",
"boleti":"boletus",
"boletuses":"boletus",
"boleyns":"boleyn",
"bolides":"bolide",
"bolingbrokes":"bolingbroke",
"bolivares":"bolivar",
"bolivars":"bolivar",
"bolivianos":"boliviano",
"bolls":"boll",
"bollards":"bollard",
"bollixed":"bollix",
"bollixes":"bollix",
"bollixing":"bollix",
"bollocks":"bollock",
"bolos":"bolo",
"bolognas":"bologna",
"bolograms":"bologram",
"bolographs":"bolograph",
"boloneys":"boloney",
"bolsheviki":"bolshevik",
"bolsheviks":"bolshevik",
"bolshevisms":"bolshevism",
"bolshies":"bolshie",
"bolstered":"bolster",
"bolstering":"bolster",
"bolsters":"bolster",
"bolted":"bolt",
"bolting":"bolt",
"bolts":"bolt",
"boltis":"bolti",
"boltonias":"boltonia",
"boluses":"bolus",
"bomareas":"bomarea",
"bombed":"bomb",
"bombing":"bomb",
"bombs":"bomb",
"bombacaceaes":"bombacaceae",
"bombarded":"bombard",
"bombarding":"bombard",
"bombards":"bombard",
"bombardments":"bombardment",
"bombardons":"bombardon",
"bombasts":"bombast",
"bombaxes":"bombax",
"bombers":"bomber",
"bombinas":"bombina",
"bombinated":"bombinate",
"bombinates":"bombinate",
"bombinating":"bombinate",
"bombings":"bombing",
"bombproofs":"bombproof",
"bombshells":"bombshell",
"bombuses":"bombus",
"bombycids":"bombycid",
"bombycidaes":"bombycidae",
"bombycillas":"bombycilla",
"bombycillidaes":"bombycillidae",
"bombyliidaes":"bombyliidae",
"bombyxes":"bombyx",
"bonanzas":"bonanza",
"bonasas":"bonasa",
"bonavists":"bonavist",
"bonbons":"bonbon",
"bonded":"bond",
"bonding":"bond",
"bonds":"bond",
"bondages":"bondage",
"bondings":"bonding",
"bondmaids":"bondmaid",
"bondmen":"bondman",
"bondsmen":"bondsman",
"bondswomen":"bondswoman",
"bonducs":"bonduc",
"bondwomen":"bondwoman",
"boned":"bone",
"bones":"bone",
"boning":"bone",
"bonefishes":"bonefish",
"boneheads":"bonehead",
"bonelets":"bonelet",
"boners":"boner",
"boneses":"bones",
"bonesets":"boneset",
"bonfires":"bonfire",
"bonged":"bong",
"bonging":"bong",
"bongoes":"bongo",
"bongos":"bongo",
"bonhomies":"bonhomie",
"boninesses":"boniness",
"bonitos":"bonito",
"bonneted":"bonnet",
"bonneting":"bonnet",
"bonnets":"bonnet",
"bonnetheads":"bonnethead",
"bonnier":"bonny",
"bonniest":"bonny",
"bonobos":"bonobo",
"bonteboks":"bontebok",
"bonuses":"bonus",
"bonxies":"bonxie",
"bonier":"bony",
"boniest":"bony",
"booed":"boo",
"booing":"boo",
"boos":"boo",
"boo-boos":"boo-boo",
"boobs":"boob",
"boobies":"booby",
"booby-trapped":"booby-trap",
"booby-trapping":"booby-trap",
"booby-traps":"booby-trap",
"boodles":"boodle",
"boogers":"booger",
"boogeymen":"boogeyman",
"boogies":"boogie",
"boogie-woogies":"boogie-woogie",
"boogiemen":"boogieman",
"boohooed":"boohoo",
"boohooing":"boohoo",
"boohoos":"boohoo",
"booked":"book",
"booking":"book",
"books":"book",
"bookbindereries":"bookbindery",
"bookbinderies":"bookbindery",
"bookcases":"bookcase",
"bookdealers":"bookdealer",
"bookends":"bookend",
"bookers":"booker",
"bookies":"bookie",
"bookings":"booking",
"bookkeepers":"bookkeeper",
"bookkeepings":"bookkeeping",
"booklets":"booklet",
"booklice":"booklouse",
"booklovers":"booklover",
"bookmakers":"bookmaker",
"bookmen":"bookman",
"bookmarks":"bookmark",
"bookmarkers":"bookmarker",
"bookplates":"bookplate",
"bookshelves":"bookshelf",
"bookshops":"bookshop",
"bookstalls":"bookstall",
"bookstores":"bookstore",
"bookworms":"bookworm",
"booles":"boole",
"boomed":"boom",
"booming":"boom",
"booms":"boom",
"boomers":"boomer",
"boomeranged":"boomerang",
"boomeranging":"boomerang",
"boomerangs":"boomerang",
"boons":"boon",
"boondockses":"boondocks",
"boondoggled":"boondoggle",
"boondoggling":"boondoggle",
"boones":"boone",
"boors":"boor",
"boorishnesses":"boorishness",
"boosted":"boost",
"boosting":"boost",
"boosts":"boost",
"boosters":"booster",
"boosterses":"boosters",
"booted":"boot",
"booting":"boot",
"boots":"boot",
"bootblacks":"bootblack",
"bootees":"bootee",
"booteeses":"bootees",
"booths":"booth",
"booties":"booty",
"bootieses":"booties",
"bootlegged":"bootleg",
"bootlegging":"bootleg",
"bootlegs":"bootleg",
"bootleggers":"bootlegger",
"bootlicked":"bootlick",
"bootlicking":"bootlick",
"bootlicks":"bootlick",
"bootlickers":"bootlicker",
"bootmakers":"bootmaker",
"booyongs":"booyong",
"boozed":"booze",
"boozes":"booze",
"boozing":"booze",
"booze-ups":"booze-up",
"boozers":"boozer",
"boozings":"boozing",
"boozier":"boozy",
"booziest":"boozy",
"bops":"bop",
"bopeeps":"bopeep",
"borages":"borage",
"boraginaceaes":"boraginaceae",
"boragos":"borago",
"borassuses":"borassus",
"boraces":"borax",
"boraxes":"borax",
"borborygmi":"borborygmus",
"bordeauxes":"bordeaux",
"bordellos":"bordello",
"bordered":"border",
"bordering":"border",
"borders":"border",
"bordereaux":"bordereau",
"borderlands":"borderland",
"borderlines":"borderline",
"bored":"bore",
"bores":"bore",
"boring":"bore",
"bore-holes":"bore-hole",
"boreases":"boreas",
"borecoles":"borecole",
"boredoms":"boredom",
"borers":"borer",
"borings":"boring",
"boringnesses":"boringness",
"borneos":"borneo",
"bornites":"bornite",
"borons":"boron",
"boroughs":"borough",
"borrowed":"borrow",
"borrowing":"borrow",
"borrows":"borrow",
"borrowings":"borrowing",
"borsches":"borsch",
"borschts":"borscht",
"borshes":"borsh",
"borshches":"borshch",
"borshts":"borsht",
"borstals":"borstal",
"bortsches":"bortsch",
"borzois":"borzoi",
"boses":"bos",
"bok":"boschbok",
"boschboks":"boschbok",
"bushbok":"boschbok",
"bushboks":"boschbok",
"boselaphuses":"boselaphus",
"boshes":"bosh",
"bosies":"bosie",
"boskier":"bosky",
"boskiest":"bosky",
"bosnias":"bosnia",
"bosnia-herzegovinas":"bosnia-herzegovina",
"bosomed":"bosom",
"bosoming":"bosom",
"bosoms":"bosom",
"bossed":"boss",
"bosses":"boss",
"bossing":"boss",
"bossier":"bossy",
"bossiest":"bossy",
"bostons":"boston",
"bosuns":"bosun",
"boswellias":"boswellia",
"botanicals":"botanical",
"botanists":"botanist",
"botanized":"botanize",
"botanizes":"botanize",
"botanizing":"botanize",
"botanies":"botany",
"botargoes":"botargo",
"botauruses":"botaurus",
"botched":"botch",
"botches":"botch",
"botching":"botch",
"botchers":"botcher",
"botchier":"botchy",
"botchiest":"botchy",
"botflies":"botfly",
"bothered":"bother",
"bothering":"bother",
"bothers":"bother",
"botherations":"botheration",
"bothidaes":"bothidae",
"bothropses":"bothrops",
"bothies":"bothy",
"botrychiums":"botrychium",
"bottled":"bottle",
"bottles":"bottle",
"bottling":"bottle",
"bottle-fed":"bottle-feed",
"bottle-feeding":"bottle-feed",
"bottle-feeds":"bottle-feed",
"bottlefuls":"bottleful",
"bottlegrasses":"bottlegrass",
"bottlenecks":"bottleneck",
"bottlenoses":"bottlenose",
"bottomed":"bottom",
"bottoming":"bottom",
"bottoms":"bottom",
"bottomlands":"bottomland",
"bottomries":"bottomry",
"botulinums":"botulinum",
"botulinuses":"botulinus",
"boubous":"boubou",
"bouchees":"bouchee",
"boucles":"boucle",
"bouffes":"bouffe",
"bougainvillaeas":"bougainvillaea",
"bougainvilleas":"bougainvillea",
"boughs":"bough",
"bouillons":"bouillon",
"boulders":"boulder",
"boules":"boule",
"boulevards":"boulevard",
"boulles":"boulle",
"bounced":"bounce",
"bounces":"bounce",
"bouncing":"bounce",
"bouncers":"bouncer",
"bouncinesses":"bounciness",
"bouncings":"bouncing",
"bouncing_betties":"bouncing_betty",
"bouncier":"bouncy",
"bounciest":"bouncy",
"bounded":"bound",
"bounding":"bound",
"bounds":"bound",
"boundaries":"boundary",
"boundednesses":"boundedness",
"bounders":"bounder",
"boundlessnesses":"boundlessness",
"boundses":"bounds",
"bounteousnesses":"bounteousness",
"bountifulnesses":"bountifulness",
"bounties":"bounty",
"bouquets":"bouquet",
"bourdons":"bourdon",
"bourgeoises":"bourgeois",
"bourgeoisies":"bourgeoisie",
"bourgognes":"bourgogne",
"bourguignons":"bourguignon",
"bourns":"bourn",
"bournes":"bourne",
"bourtrees":"bourtree",
"boused":"bouse",
"bouses":"bouse",
"bousing":"bouse",
"bouts":"bout",
"boutelouas":"bouteloua",
"boutiques":"boutique",
"bouyeis":"bouyei",
"bovidaes":"bovidae",
"bovinaes":"bovinae",
"bovinis":"bovini",
"bovrils":"bovril",
"bowed":"bow",
"bowing":"bow",
"bows":"bow",
"bow-wows":"bow-wow",
"bowdlerisations":"bowdlerisation",
"bowdlerizations":"bowdlerization",
"bowdlerized":"bowdlerize",
"bowdlerizes":"bowdlerize",
"bowdlerizing":"bowdlerize",
"boweled":"bowel",
"boweling":"bowel",
"bowelled":"bowel",
"bowelling":"bowel",
"bowels":"bowel",
"bowered":"bower",
"bowering":"bower",
"bowers":"bower",
"bowerbirds":"bowerbird",
"bowfins":"bowfin",
"bowheads":"bowhead",
"bowieas":"bowiea",
"bowings":"bowing",
"bowknots":"bowknot",
"bowled":"bowl",
"bowling":"bowl",
"bowls":"bowl",
"bowlders":"bowlder",
"bowlegs":"bowleg",
"bowlers":"bowler",
"bowlfuls":"bowlful",
"bowlines":"bowline",
"bowmen":"bowman",
"bowstringed":"bowstring",
"bowstringing":"bowstring",
"bowstrings":"bowstring",
"bowstrung":"bowstring",
"bowwowed":"bowwow",
"bowwowing":"bowwow",
"bowwows":"bowwow",
"boxed":"box",
"boxes":"box",
"boxing":"box",
"boxberries":"boxberry",
"boxers":"boxer",
"boxfishes":"boxfish",
"boxfuls":"boxful",
"boxhauled":"boxhaul",
"boxhauling":"boxhaul",
"boxings":"boxing",
"boxthorns":"boxthorn",
"boxwoods":"boxwood",
"boxier":"boxy",
"boxiest":"boxy",
"box-kodaks":"box_kodak",
"boys":"boy",
"boycotted":"boycott",
"boycotting":"boycott",
"boycotts":"boycott",
"boyfriends":"boyfriend",
"boyhoods":"boyhood",
"boykinias":"boykinia",
"boynes":"boyne",
"boys-and-girlses":"boys-and-girls",
"boysenberries":"boysenberry",
"bozos":"bozo",
"bpis":"bpi",
"bpms":"bpm",
"bpses":"bps",
"brs":"br",
"bras":"bra",
"brabbled":"brabble",
"brabbles":"brabble",
"brabbling":"brabble",
"braced":"brace",
"braces":"brace",
"bracing":"brace",
"bracelets":"bracelet",
"bracers":"bracer",
"braceros":"bracero",
"braceses":"braces",
"brachiated":"brachiate",
"brachiating":"brachiate",
"brachinuses":"brachinus",
"brachiopods":"brachiopod",
"brachiopodas":"brachiopoda",
"brachia":"brachium",
"brachychitons":"brachychiton",
"brachycomes":"brachycome",
"brachydactylias":"brachydactylia",
"brachylogies":"brachylogy",
"brachystegias":"brachystegia",
"brachytactylies":"brachytactyly",
"brachyuras":"brachyura",
"bracings":"bracing",
"brackens":"bracken",
"bracketed":"bracket",
"bracketing":"bracket",
"brackets":"bracket",
"bradded":"brad",
"bradding":"brad",
"brads":"brad",
"bradawls":"bradawl",
"bradypodidaes":"bradypodidae",
"bradypuses":"bradypus",
"bragged":"brag",
"bragging":"brag",
"brags":"brag",
"brages":"brage",
"braggs":"bragg",
"braggadocios":"braggadocio",
"braggarts":"braggart",
"braggings":"bragging",
"bragis":"bragi",
"brahmas":"brahma",
"Brahmans":"Brahman",
"brahmen":"brahman",
"brahmanis":"brahmani",
"brahmanisms":"brahmanism",
"brahmaputras":"brahmaputra",
"Brahmins":"Brahmin",
"brahminisms":"brahminism",
"brahmses":"brahms",
"brahuis":"brahui",
"braided":"braid",
"braiding":"braid",
"braids":"braid",
"braidings":"braiding",
"brailed":"brail",
"brailing":"brail",
"Brailled":"Braille",
"brailling":"braille",
"brained":"brain",
"braining":"brain",
"brains":"brain",
"brain-fags":"brain-fag",
"brain-teasers":"brain-teaser",
"braincases":"braincase",
"brainchildren":"brainchild",
"brainpans":"brainpan",
"brainpowers":"brainpower",
"brainstems":"brainstem",
"brainstorms":"brainstorm",
"brainwashed":"brainwash",
"brainwashing":"brainwash",
"brainwaves":"brainwave",
"brainier":"brainy",
"brainiest":"brainy",
"braised":"braise",
"braising":"braise",
"braked":"brake",
"brakes":"brake",
"braking":"brake",
"brakemen":"brakeman",
"brakeses":"brakes",
"brakesmen":"brakesman",
"bramas":"brama",
"brambles":"bramble",
"bramblings":"brambling",
"bramblier":"brambly",
"brambliest":"brambly",
"bramidaes":"bramidae",
"branched":"branch",
"branches":"branch",
"branching":"branch",
"branchiae":"branchia",
"branchias":"branchia",
"branchings":"branching",
"branchiobdellas":"branchiobdella",
"branchiobdellidaes":"branchiobdellidae",
"branchiopods":"branchiopod",
"branchiopodas":"branchiopoda",
"branchiopodans":"branchiopodan",
"branchiostegidaes":"branchiostegidae",
"branchiostomidaes":"branchiostomidae",
"branchiuras":"branchiura",
"branchlets":"branchlet",
"branded":"brand",
"branding":"brand",
"brands":"brand",
"brandings":"branding",
"brandished":"brandish",
"brandishes":"brandish",
"brandishing":"brandish",
"brandied":"brandy",
"brandies":"brandy",
"brandying":"brandy",
"brants":"brant",
"brantas":"branta",
"brasenias":"brasenia",
"brasher":"brash",
"brashest":"brash",
"brashnesses":"brashness",
"brashier":"brashy",
"brashiest":"brashy",
"brasiers":"brasier",
"brasils":"brasil",
"brasilias":"brasilia",
"brasses":"brass",
"brassias":"brassia",
"brassicas":"brassica",
"brassicaceaes":"brassicaceae",
"brassies":"brassie",
"brassieres":"brassiere",
"brassier":"brassy",
"brassiest":"brassy",
"brats":"brat",
"brattier":"bratty",
"brattiest":"bratty",
"braunschweigs":"braunschweig",
"bravadoes":"bravado",
"bravados":"bravado",
"braved":"brave",
"braver":"brave",
"bravest":"brave",
"braving":"brave",
"braveries":"bravery",
"bravings":"braving",
"bravoes":"bravo",
"bravos":"bravo",
"brawled":"brawl",
"brawling":"brawl",
"brawls":"brawl",
"brawns":"brawn",
"brawnier":"brawny",
"brawniest":"brawny",
"brayed":"bray",
"braying":"bray",
"brays":"bray",
"brazed":"braze",
"brazing":"braze",
"brazened":"brazen",
"brazening":"brazen",
"brazennesses":"brazenness",
"braziers":"brazier",
"brazils":"brazil",
"brazilwoods":"brazilwood",
"brazoses":"brazos",
"brazzavilles":"brazzaville",
"breached":"breach",
"breaches":"breach",
"breaching":"breach",
"breaded":"bread",
"breading":"bread",
"breads":"bread",
"bread-bins":"bread-bin",
"breadbaskets":"breadbasket",
"breadboards":"breadboard",
"breadboxes":"breadbox",
"breadfruits":"breadfruit",
"breadlines":"breadline",
"breadroots":"breadroot",
"breadstuffs":"breadstuff",
"breadths":"breadth",
"breaking":"break",
"breaks":"break",
"broke":"break",
"broken":"break",
"break-ins":"break-in",
"breakabilities":"breakability",
"breakages":"breakage",
"breakaways":"breakaway",
"breakaxes":"breakax",
"breakdowns":"breakdown",
"breakers":"breaker",
"breakerses":"breakers",
"breakfasted":"breakfast",
"breakfasting":"breakfast",
"breakfasts":"breakfast",
"breakings":"breaking",
"breakouts":"breakout",
"breakstones":"breakstone",
"breakthroughs":"breakthrough",
"breakups":"breakup",
"breakwaters":"breakwater",
"breamed":"bream",
"breaming":"bream",
"breams":"bream",
"breasted":"breast",
"breasting":"breast",
"breasts":"breast",
"breast-fed":"breast-feed",
"breast-feeding":"breast-feed",
"breast-feeds":"breast-feed",
"breastbones":"breastbone",
"breastpins":"breastpin",
"breastplates":"breastplate",
"breastworks":"breastwork",
"breaths":"breath",
"breathalysers":"breathalyser",
"breathalyzers":"breathalyzer",
"breathed":"breathe",
"breathes":"breathe",
"breathing":"breathe",
"breathers":"breather",
"breathings":"breathing",
"breathier":"breathy",
"breathiest":"breathy",
"breeched":"breech",
"breeches":"breech",
"breeching":"breech",
"breechblocks":"breechblock",
"breechcloths":"breechcloth",
"breechclouts":"breechclout",
"breecheses":"breeches",
"bred":"breed",
"breeding":"breed",
"breeds":"breed",
"breeders":"breeder",
"breedings":"breeding",
"breezed":"breeze",
"breezes":"breeze",
"breezing":"breeze",
"breezinesses":"breeziness",
"breezier":"breezy",
"breeziest":"breezy",
"bregmata":"bregma",
"breid":"brei",
"breiing":"brei",
"breis":"brei",
"breizs":"breiz",
"brens":"bren",
"brents":"brent",
"breslaus":"breslau",
"bretagnes":"bretagne",
"brothers":"brethren",
"breveted":"brevet",
"breveting":"brevet",
"brevets":"brevet",
"brevetted":"brevet",
"brevetting":"brevet",
"breviaries":"breviary",
"brevicipitidaes":"brevicipitidae",
"brevities":"brevity",
"brevoortias":"brevoortia",
"brewed":"brew",
"brewing":"brew",
"brews":"brew",
"brewages":"brewage",
"brewers":"brewer",
"breweries":"brewery",
"briars":"briar",
"briarwoods":"briarwood",
"bribed":"bribe",
"bribes":"bribe",
"bribing":"bribe",
"bribers":"briber",
"briberies":"bribery",
"bric-a-bracs":"bric-a-brac",
"bricked":"brick",
"bricking":"brick",
"bricks":"brick",
"brickellias":"brickellia",
"brickfields":"brickfield",
"brickyards":"brickyard",
"bricoles":"bricole",
"bridals":"bridal",
"bridalwreaths":"bridalwreath",
"brides":"bride",
"bride-to-bes":"bride-to-be",
"bridecakes":"bridecake",
"bridegrooms":"bridegroom",
"bridesmaids":"bridesmaid",
"bridged":"bridge",
"bridges":"bridge",
"bridging":"bridge",
"bridgeheads":"bridgehead",
"bridgets":"bridget",
"bridgeworks":"bridgework",
"bridled":"bridle",
"bridles":"bridle",
"bridling":"bridle",
"bries":"brie",
"briefed":"brief",
"briefer":"brief",
"briefest":"brief",
"briefing":"brief",
"briefs":"brief",
"briefcases":"briefcase",
"briefnesses":"briefness",
"briers":"brier",
"brierpatches":"brierpatch",
"brierwoods":"brierwood",
"brigs":"brig",
"brigaded":"brigade",
"brigades":"brigade",
"brigading":"brigade",
"brigadiers":"brigadier",
"brigands":"brigand",
"brigantines":"brigantine",
"brighter":"bright",
"brightest":"bright",
"brights":"bright",
"brightened":"brighten",
"brightening":"brighten",
"brightens":"brighten",
"brightnesses":"brightness",
"brigids":"brigid",
"brills":"brill",
"brilliances":"brilliance",
"brilliancies":"brilliancy",
"brilliants":"brilliant",
"brimmed":"brim",
"brimming":"brim",
"brims":"brim",
"brimstones":"brimstone",
"brined":"brine",
"brines":"brine",
"brining":"brine",
"bringing":"bring",
"brings":"bring",
"brought":"bring",
"bringings":"bringing",
"brininesses":"brininess",
"brinjals":"brinjal",
"brinks":"brink",
"brinier":"briny",
"brinies":"briny",
"briniest":"briny",
"brionies":"briony",
"bryonies":"briony",
"briquets":"briquet",
"briquettes":"briquette",
"brises":"bris",
"brisked":"brisk",
"brisker":"brisk",
"briskest":"brisk",
"brisking":"brisk",
"brisknesses":"briskness",
"brislings":"brisling",
"bristled":"bristle",
"bristles":"bristle",
"bristling":"bristle",
"bristlegrasses":"bristlegrass",
"bristlier":"bristly",
"bristliest":"bristly",
"Brits":"Brit",
"britains":"britain",
"briths":"brith",
"briticisms":"briticism",
"britishes":"british",
"Britishers":"Britisher",
"britishisms":"britishism",
"Britons":"Briton",
"britses":"brits",
"britts":"britt",
"brittanics":"brittanic",
"brittanies":"brittany",
"brittler":"brittle",
"brittles":"brittle",
"brittlest":"brittle",
"brittlebushes":"brittlebush",
"brittlenesses":"brittleness",
"brittlestars":"brittlestar",
"broached":"broach",
"broaches":"broach",
"broaching":"broach",
"broader":"broad",
"broadest":"broad",
"broads":"broad",
"broadaxes":"broadax",
"broadbeans":"broadbean",
"broadbills":"broadbill",
"broadcasted":"broadcast",
"broadcasting":"broadcast",
"broadcasts":"broadcast",
"broadcasters":"broadcaster",
"broadcastings":"broadcasting",
"broadened":"broaden",
"broadening":"broaden",
"broadens":"broaden",
"broadenings":"broadening",
"broadleaves":"broadleaf",
"broadnesses":"broadness",
"broadsheets":"broadsheet",
"broadsides":"broadside",
"broadswords":"broadsword",
"broadtails":"broadtail",
"broadways":"broadway",
"brocaded":"brocade",
"brocading":"brocade",
"broccolis":"broccoli",
"brochures":"brochure",
"brogans":"brogan",
"brogues":"brogue",
"broidered":"broider",
"broidering":"broider",
"broiders":"broider",
"broiled":"broil",
"broiling":"broil",
"broils":"broil",
"broilings":"broiling",
"brokenheartednesses":"brokenheartedness",
"brokered":"broker",
"brokering":"broker",
"brokers":"broker",
"brokerages":"brokerage",
"brollies":"brolly",
"bromated":"bromate",
"bromates":"bromate",
"bromating":"bromate",
"bromes":"brome",
"bromegrasses":"bromegrass",
"bromeliaceaes":"bromeliaceae",
"bromeosins":"bromeosin",
"bromides":"bromide",
"brominated":"brominate",
"brominates":"brominate",
"brominating":"brominate",
"bromines":"bromine",
"bromuses":"bromus",
"broncs":"bronc",
"bronchos":"broncho",
"bronchi":"bronchus",
"bronchuses":"bronchus",
"broncos":"bronco",
"brontosaurs":"brontosaur",
"brontosauruses":"brontosaurus",
"bronxes":"bronx",
"bronzed":"bronze",
"bronzes":"bronze",
"bronzing":"bronze",
"brooched":"brooch",
"brooches":"brooch",
"brooching":"brooch",
"brooded":"brood",
"brooding":"brood",
"broods":"brood",
"brooders":"brooder",
"broodings":"brooding",
"broodmares":"broodmare",
"broodier":"broody",
"brown-nosers":"brown-noser",
"broodiest":"broody",
"brooked":"brook",
"brooking":"brook",
"brooks":"brook",
"brooklimes":"brooklime",
"brookweeds":"brookweed",
"broomed":"broom",
"brooming":"broom",
"brooms":"broom",
"broomcorns":"broomcorn",
"broomweeds":"broomweed",
"brosmiuses":"brosmius",
"brothes":"broth",
"broths":"broth",
"brothels":"brothel",
"brethren":"brother",
"brothers-in-law":"brother-in-law",
"brotherhoods":"brotherhood",
"brotulidaes":"brotulidae",
"brouhahas":"brouhaha",
"broussonetias":"broussonetia",
"brows":"brow",
"browallias":"browallia",
"browbeaten":"browbeat",
"browbeating":"browbeat",
"browbeats":"browbeat",
"browned":"brown",
"browner":"brown",
"brownest":"brown",
"browning":"brown",
"browns":"brown",
"brown-nosed":"brown-nose",
"brown-noses":"brown-nose",
"brown-nosing":"brown-nose",
"brownies":"brownie",
"brownings":"browning",
"brownnesses":"brownness",
"brownouts":"brownout",
"browntails":"browntail",
"browsed":"browse",
"browses":"browse",
"browsing":"browse",
"browsers":"browser",
"browsings":"browsing",
"bruces":"bruce",
"brucelloses":"brucellosis",
"bruchidaes":"bruchidae",
"bruchuses":"bruchus",
"bruckenthalias":"bruckenthalia",
"brugeses":"bruges",
"brugmansias":"brugmansia",
"bruins":"bruin",
"bruised":"bruise",
"bruises":"bruise",
"bruising":"bruise",
"bruisers":"bruiser",
"bruited":"bruit",
"bruiting":"bruit",
"bruits":"bruit",
"brumbies":"brumby",
"brunanburhs":"brunanburh",
"brunets":"brunet",
"brunettes":"brunette",
"brunfelsias":"brunfelsia",
"brunhilds":"brunhild",
"brunnhildes":"brunnhilde",
"brunswicks":"brunswick",
"brushed":"brush",
"brushes":"brush",
"brushing":"brush",
"brushings":"brushing",
"brushups":"brushup",
"brushwoods":"brushwood",
"brushier":"brushy",
"brushiest":"brushy",
"brusquenesses":"brusqueness",
"brusselses":"brussels",
"brutalisations":"brutalisation",
"brutalities":"brutality",
"brutalizations":"brutalization",
"brutalized":"brutalize",
"brutalizes":"brutalize",
"brutalizing":"brutalize",
"brutes":"brute",
"brutified":"brutify",
"brutifies":"brutify",
"brutifying":"brutify",
"brutuses":"brutus",
"bryas":"brya",
"bryaceaes":"bryaceae",
"bryaleses":"bryales",
"brynhilds":"brynhild",
"bryophytas":"bryophyta",
"bryophytes":"bryophyte",
"bryopsidas":"bryopsida",
"bryozoas":"bryozoa",
"bryozoans":"bryozoan",
"brythonics":"brythonic",
"bryums":"bryum",
"bses":"bs",
"bsarches":"bsarch",
"btus":"btu",
"bubaluses":"bubalus",
"bubbled":"bubble",
"bubbles":"bubble",
"bubbling":"bubble",
"bubblers":"bubbler",
"bubblinesses":"bubbliness",
"bubblier":"bubbly",
"bubblies":"bubbly",
"bubbliest":"bubbly",
"buboes":"bubo",
"bubulcuses":"bubulcus",
"buccaneers":"buccaneer",
"buccaneerings":"buccaneering",
"buccinidaes":"buccinidae",
"bucconidaes":"bucconidae",
"bucephalas":"bucephala",
"buceroses":"buceros",
"bucerotidaes":"bucerotidae",
"buchanans":"buchanan",
"bucharests":"bucharest",
"buchloes":"buchloe",
"bucked":"buck",
"bucking":"buck",
"bucks":"buck",
"buckaroos":"buckaroo",
"buckbeans":"buckbean",
"bucketed":"bucket",
"bucketing":"bucket",
"buckets":"bucket",
"bucketfuls":"bucketful",
"buckeyes":"buckeye",
"buckled":"buckle",
"buckles":"buckle",
"buckling":"buckle",
"bucklered":"buckler",
"bucklering":"buckler",
"bucklers":"buckler",
"buckleyas":"buckleya",
"buckoes":"bucko",
"buckras":"buckra",
"buckramed":"buckram",
"buckraming":"buckram",
"buckrams":"buckram",
"buckshots":"buckshot",
"buckskins":"buckskin",
"buckthorns":"buckthorn",
"buckteeth":"bucktooth",
"buckwheats":"buckwheat",
"bucolics":"bucolic",
"bucurestis":"bucuresti",
"budded":"bud",
"budding":"bud",
"buds":"bud",
"budapests":"budapest",
"Buddhas":"Buddha",
"buddleias":"buddleia",
"buddied":"buddy",
"buddies":"buddy",
"buddying":"buddy",
"budged":"budge",
"budges":"budge",
"budging":"budge",
"budgereegahs":"budgereegah",
"budgerigars":"budgerigar",
"budgerygahs":"budgerygah",
"budgeted":"budget",
"budgeting":"budget",
"budgets":"budget",
"budgies":"budgie",
"budorcases":"budorcas",
"buffed":"buff",
"buffing":"buff",
"buffs":"buff",
"buffaloed":"buffalo",
"buffaloes":"buffalo",
"buffaloing":"buffalo",
"buffalos":"buffalo",
"buffalofishes":"buffalofish",
"buffers":"buffer",
"bufferins":"bufferin",
"buffeted":"buffet",
"buffeting":"buffet",
"buffets":"buffet",
"buffetings":"buffeting",
"buffleheads":"bufflehead",
"buffi":"buffo",
"buffos":"buffo",
"buffoons":"buffoon",
"buffooneries":"buffoonery",
"bufonidaes":"bufonidae",
"bugged":"bug",
"bugging":"bug",
"bugs":"bug",
"bug-hunters":"bug-hunter",
"bugaboos":"bugaboo",
"bugbanes":"bugbane",
"bugbears":"bugbear",
"buggered":"bugger",
"buggering":"bugger",
"buggers":"bugger",
"buggeries":"buggery",
"buggier":"buggy",
"buggies":"buggy",
"buggiest":"buggy",
"bughouses":"bughouse",
"bugled":"bugle",
"bugles":"bugle",
"bugling":"bugle",
"buglers":"bugler",
"bugleweeds":"bugleweed",
"buglosses":"bugloss",
"bugologists":"bugologist",
"buhls":"buhl",
"building":"build",
"builds":"build",
"built":"build",
"builders":"builder",
"buildings":"building",
"bujumburas":"bujumbura",
"bulbed":"bulb",
"bulbing":"bulb",
"bulbs":"bulb",
"bulbils":"bulbil",
"bulblets":"bulblet",
"bulged":"bulge",
"bulges":"bulge",
"bulging":"bulge",
"bulghurs":"bulghur",
"bulginesses":"bulginess",
"bulgurs":"bulgur",
"bulgier":"bulgy",
"bulgiest":"bulgy",
"bulked":"bulk",
"bulking":"bulk",
"bulks":"bulk",
"bulkinesses":"bulkiness",
"bulkier":"bulky",
"bulkiest":"bulky",
"bulled":"bull",
"bulling":"bull",
"bulls":"bull",
"bullae":"bulla",
"bullas":"bulla",
"bullaces":"bullace",
"bullbats":"bullbat",
"bullbriers":"bullbrier",
"bulldogs":"bulldog",
"bulldozed":"bulldoze",
"bulldozing":"bulldoze",
"bulldozers":"bulldozer",
"bullets":"bullet",
"bulletined":"bulletin",
"bulletining":"bulletin",
"bulletins":"bulletin",
"bullfights":"bullfight",
"bullfighters":"bullfighter",
"bullfinches":"bullfinch",
"bullfrogs":"bullfrog",
"bullheadednesses":"bullheadedness",
"bullhorns":"bullhorn",
"bullnoses":"bullnose",
"bullocks":"bullock",
"bullpens":"bullpen",
"bullrushes":"bullrush",
"bullshits":"bullshit",
"bullsnakes":"bullsnake",
"bullterriers":"bullterrier",
"bullwhipped":"bullwhip",
"bullwhipping":"bullwhip",
"bullwhips":"bullwhip",
"bullied":"bully",
"bullies":"bully",
"bullying":"bully",
"bullyings":"bullying",
"bullyragged":"bullyrag",
"bullyragging":"bullyrag",
"bullyrags":"bullyrag",
"bulnesias":"bulnesia",
"bulrushes":"bulrush",
"bulwarked":"bulwark",
"bulwarking":"bulwark",
"bulwarks":"bulwark",
"bulwarkses":"bulwarks",
"bummed":"bum",
"bummer":"bum",
"bummest":"bum",
"bumming":"bum",
"bums":"bum",
"bumbled":"bumble",
"bumbles":"bumble",
"bumbling":"bumble",
"bumblebees":"bumblebee",
"bumblers":"bumbler",
"bumelias":"bumelia",
"bumped":"bump",
"bumping":"bump",
"bumps":"bump",
"bumpers":"bumper",
"bumpkins":"bumpkin",
"bumptiousnesses":"bumptiousness",
"bumpier":"bumpy",
"bumpiest":"bumpy",
"buns":"bun",
"bunces":"bunce",
"bunched":"bunch",
"bunches":"bunch",
"bunching":"bunch",
"bunchberries":"bunchberry",
"bunchgrasses":"bunchgrass",
"bunchier":"bunchy",
"bunchiest":"bunchy",
"buncoed":"bunco",
"buncoing":"bunco",
"buncos":"bunco",
"buncombes":"buncombe",
"bunde":"bund",
"bunds":"bund",
"bundled":"bundle",
"bundles":"bundle",
"bundling":"bundle",
"bunged":"bung",
"bunging":"bung",
"bungs":"bung",
"bungalows":"bungalow",
"bungaruses":"bungarus",
"bungees":"bungee",
"bungled":"bungle",
"bungles":"bungle",
"bungling":"bungle",
"bunglers":"bungler",
"bunji-bunjis":"bunji-bunji",
"bunked":"bunk",
"bunking":"bunk",
"bunks":"bunk",
"bunkered":"bunker",
"bunkering":"bunker",
"bunkers":"bunker",
"bunkhouses":"bunkhouse",
"bunkoed":"bunko",
"bunkoing":"bunko",
"bunkos":"bunko",
"bunkums":"bunkum",
"bunnies":"bunny",
"bunses":"buns",
"bunsens":"bunsen",
"bunted":"bunt",
"bunting":"bunt",
"bunts":"bunt",
"buntings":"bunting",
"bunyans":"bunyan",
"buoyed":"buoy",
"buoying":"buoy",
"buoys":"buoy",
"buoyancies":"buoyancy",
"buphthalmums":"buphthalmum",
"burred":"bur",
"burring":"bur",
"burs":"bur",
"buras":"bura",
"burberries":"burberry",
"burbled":"burble",
"burbles":"burble",
"burbling":"burble",
"burbots":"burbot",
"burdened":"burden",
"burdening":"burden",
"burdens":"burden",
"burdensomenesses":"burdensomeness",
"burdocks":"burdock",
"bureaus":"bureau",
"bureaux":"bureau",
"bureaucracies":"bureaucracy",
"bureaucrats":"bureaucrat",
"bureaucratisms":"bureaucratism",
"bureaucratized":"bureaucratize",
"bureaucratizing":"bureaucratize",
"burgeoned":"burgeon",
"burgeoning":"burgeon",
"burgesses":"burgess",
"burghers":"burgher",
"burglared":"burglar",
"burglaring":"burglar",
"burglars":"burglar",
"burglarized":"burglarize",
"burglarizes":"burglarize",
"burglarizing":"burglarize",
"burglaries":"burglary",
"burgled":"burgle",
"burgles":"burgle",
"burgling":"burgle",
"burgoos":"burgoo",
"burgoynes":"burgoyne",
"burgrasses":"burgrass",
"burgundies":"burgundy",
"burhinidaes":"burhinidae",
"burhinuses":"burhinus",
"burials":"burial",
"burked":"burke",
"burkes":"burke",
"burking":"burke",
"burled":"burl",
"burling":"burl",
"burls":"burl",
"burlaps":"burlap",
"burlesked":"burlesk",
"burlesking":"burlesk",
"burlesks":"burlesk",
"burlesqued":"burlesque",
"burlesques":"burlesque",
"burlesquing":"burlesque",
"burleys":"burley",
"burlier":"burly",
"burliest":"burly",
"burmas":"burma",
"burmannias":"burmannia",
"burmanniaceaes":"burmanniaceae",
"burmeisterias":"burmeisteria",
"burmese-yis":"burmese-yi",
"burned":"burn",
"burning":"burn",
"burns":"burn",
"burnt":"burn",
"burners":"burner",
"burnings":"burning",
"burnished":"burnish",
"burnishes":"burnish",
"burnishing":"burnish",
"burnishers":"burnisher",
"burnooses":"burnoose",
"burnouses":"burnous",
"burnsides":"burnside",
"buroos":"buroo",
"burped":"burp",
"burping":"burp",
"burps":"burp",
"burpings":"burping",
"burrs":"burr",
"burrawongs":"burrawong",
"burros":"burro",
"burrowed":"burrow",
"burrowing":"burrow",
"burrows":"burrow",
"burrier":"burry",
"burriest":"burry",
"bursae":"bursa",
"bursas":"bursa",
"bursaries":"bursary",
"burseras":"bursera",
"burseraceaes":"burseraceae",
"bursted":"burst",
"bursting":"burst",
"bursts":"burst",
"bursters":"burster",
"burundukis":"burunduki",
"buried":"bury",
"buries":"bury",
"burying":"bury",
"buryings":"burying",
"bused":"bus",
"buses":"bus",
"busing":"bus",
"bussed":"bus",
"busses":"bus",
"bussing":"bus",
"busbars":"busbar",
"busboys":"busboy",
"busbies":"busby",
"bushed":"bush",
"bushes":"bush",
"bushing":"bush",
"bushbabies":"bushbaby",
"bushbucks":"bushbuck",
"busheled":"bushel",
"busheling":"bushel",
"bushelled":"bushel",
"bushelling":"bushel",
"bushels":"bushel",
"bushies":"bushie",
"bushings":"bushing",
"bushmen":"bushman",
"bushtits":"bushtit",
"bushwhacked":"bushwhack",
"bushwhacking":"bushwhack",
"bushwhacks":"bushwhack",
"bushwhackers":"bushwhacker",
"bushier":"bushy",
"bushiest":"bushy",
"businesses":"business",
"businessmen":"businessman",
"businessmens":"businessmen",
"businesspersons":"businessperson",
"businesswomen":"businesswoman",
"busked":"busk",
"busking":"busk",
"buskins":"buskin",
"busmen":"busman",
"busted":"bust",
"busting":"bust",
"busts":"bust",
"busters":"buster",
"bustled":"bustle",
"bustles":"bustle",
"bustling":"bustle",
"bustier":"busty",
"bustiest":"busty",
"busied":"busy",
"busier":"busy",
"busies":"busy",
"busiest":"busy",
"busying":"busy",
"busybodies":"busybody",
"busyworks":"busywork",
"buts":"but",
"butacaines":"butacaine",
"butanols":"butanol",
"butats":"butat",
"butazolidins":"butazolidin",
"butches":"butch",
"butchered":"butcher",
"butchering":"butcher",
"butchers":"butcher",
"butcherings":"butchering",
"butcheries":"butchery",
"buteas":"butea",
"butenes":"butene",
"buteos":"buteo",
"butlers":"butler",
"butleries":"butlery",
"butted":"butt",
"butting":"butt",
"butts":"butt",
"buttes":"butte",
"buttered":"butter",
"buttering":"butter",
"butter-and-eggses":"butter-and-eggs",
"butter-prints":"butter-print",
"butterballs":"butterball",
"butterbeans":"butterbean",
"butterburs":"butterbur",
"buttercups":"buttercup",
"butterfishes":"butterfish",
"butterflowers":"butterflower",
"butterflies":"butterfly",
"butterflyfishes":"butterflyfish",
"butternuts":"butternut",
"butterweeds":"butterweed",
"butteries":"buttery",
"buttinskies":"buttinsky",
"buttocks":"buttock",
"buttockses":"buttocks",
"buttoned":"button",
"buttoning":"button",
"buttons":"button",
"buttonholed":"buttonhole",
"buttonholes":"buttonhole",
"buttonholing":"buttonhole",
"buttonquails":"buttonquail",
"buttonwoods":"buttonwood",
"buttressed":"buttress",
"buttresses":"buttress",
"buttressing":"buttress",
"buttressings":"buttressing",
"butties":"butty",
"bututs":"butut",
"butylenes":"butylene",
"buxaceaes":"buxaceae",
"buxuses":"buxus",
"bought":"buy",
"buying":"buy",
"buys":"buy",
"buybacks":"buyback",
"buyers":"buyer",
"buyis":"buyi",
"buyings":"buying",
"buzzed":"buzz",
"buzzes":"buzz",
"buzzing":"buzz",
"buzzards":"buzzard",
"buzzers":"buzzer",
"buzzwords":"buzzword",
"bws":"bw",
"bwrs":"bwr",
"by-blows":"by-blow",
"by-lines":"by-line",
"by-products":"by-product",
"byes":"bye",
"bye-byes":"bye-bye",
"byelaruses":"byelarus",
"byelorussias":"byelorussia",
"byelorussians":"byelorussian",
"bygones":"bygone",
"bylaws":"bylaw",
"bypasses":"bypass",
"bypaths":"bypath",
"byplays":"byplay",
"byrnies":"byrnie",
"byroads":"byroad",
"byssuses":"byssus",
"byways":"byway",
"bywords":"byword",
"byzants":"byzant",
"byzantines":"byzantine",
"byzantinisms":"byzantinism",
"cs":"c",
"c-horizons":"c-horizon",
"c-notes":"c-note",
"c-sections":"c-section",
"cas":"ca",
"cabbed":"cab",
"cabbing":"cab",
"cabs":"cab",
"caballed":"cabal",
"caballing":"cabal",
"cabals":"cabal",
"cabalas":"cabala",
"caballeros":"caballero",
"cabanas":"cabana",
"cabarets":"cabaret",
"cabassets":"cabasset",
"cabassouses":"cabassous",
"cabbaged":"cabbage",
"cabbages":"cabbage",
"cabbaging":"cabbage",
"cabbageworms":"cabbageworm",
"cabbalas":"cabbala",
"cabbalahs":"cabbalah",
"cabbies":"cabby",
"cabdrivers":"cabdriver",
"cabernets":"cabernet",
"cabined":"cabin",
"cabining":"cabin",
"cabins":"cabin",
"cabinets":"cabinet",
"cabinetmakings":"cabinetmaking",
"cabinetries":"cabinetry",
"cabinetworks":"cabinetwork",
"cabled":"cable",
"cables":"cable",
"cabling":"cable",
"cablegrams":"cablegram",
"cabmen":"cabman",
"cabombas":"cabomba",
"cabombaceaes":"cabombaceae",
"caboodles":"caboodle",
"cabooses":"caboose",
"cabrillas":"cabrilla",
"cabriolets":"cabriolet",
"cabstands":"cabstand",
"cacajaos":"cacajao",
"cacalias":"cacalia",
"cacaos":"cacao",
"cacatuas":"cacatua",
"cachalots":"cachalot",
"cached":"cache",
"caches":"cache",
"caching":"cache",
"cachets":"cachet",
"cachexias":"cachexia",
"cachexies":"cachexy",
"cachinnated":"cachinnate",
"cachinnating":"cachinnate",
"cacicuses":"cacicus",
"caciques":"cacique",
"cackled":"cackle",
"cackles":"cackle",
"cackling":"cackle",
"cacklers":"cackler",
"cacodaemons":"cacodaemon",
"cacodemons":"cacodemon",
"cacodyls":"cacodyl",
"cacoetheses":"cacoethes",
"cacogenicses":"cacogenics",
"cacographies":"cacography",
"cacomistles":"cacomistle",
"cacomixles":"cacomixle",
"cacophonies":"cacophony",
"cactaceaes":"cactaceae",
"cacti":"cactus",
"cactuses":"cactus",
"cads":"cad",
"cadasters":"cadaster",
"cadastres":"cadastre",
"cadavers":"cadaver",
"caddiceflies":"caddicefly",
"caddied":"caddie",
"caddies":"caddie",
"caddying":"caddie",
"caddisflies":"caddisfly",
"caddisworms":"caddisworm",
"caddos":"caddo",
"caddoans":"caddoan",
"cadences":"cadence",
"cadencies":"cadency",
"cadenzas":"cadenza",
"cadets":"cadet",
"cadged":"cadge",
"cadges":"cadge",
"cadging":"cadge",
"cadgers":"cadger",
"cadis":"cadi",
"cadmiums":"cadmium",
"cadras":"cadra",
"cadres":"cadre",
"caducei":"caduceus",
"caecilians":"caecilian",
"caeciliidaes":"caeciliidae",
"caeca":"caecum",
"caecums":"caecum",
"caenogeneses":"caenogenesis",
"caenolesteses":"caenolestes",
"caenolestidaes":"caenolestidae",
"caesalpinias":"caesalpinia",
"caesalpiniaceaes":"caesalpiniaceae",
"caesalpinioideaes":"caesalpinioideae",
"caesars":"caesar",
"Caesareans":"Caesarean",
"caesarisms":"caesarism",
"caesaropapisms":"caesaropapism",
"caesiums":"caesium",
"caestuses":"caestus",
"cestuses":"caestus",
"caesurae":"caesura",
"caesuras":"caesura",
"cafes":"cafe",
"cafeterias":"cafeteria",
"caffeins":"caffein",
"caffeines":"caffeine",
"caffeinisms":"caffeinism",
"caffers":"caffer",
"caffres":"caffre",
"caftans":"caftan",
"caged":"cage",
"cages":"cage",
"caging":"cage",
"cagers":"cager",
"cagier":"cagey",
"cagiest":"cagey",
"cahiers":"cahier",
"cahoots":"cahoot",
"caimans":"caiman",
"caimen":"caiman",
"caimitillos":"caimitillo",
"caimitos":"caimito",
"cainogeneses":"cainogenesis",
"cairinas":"cairina",
"cairns":"cairn",
"cairngorms":"cairngorm",
"cairos":"cairo",
"caissons":"caisson",
"cajanuses":"cajanus",
"cajoled":"cajole",
"cajoles":"cajole",
"cajoling":"cajole",
"cajoleries":"cajolery",
"caked":"cake",
"cakes":"cake",
"caking":"cake",
"cakewalked":"cakewalk",
"cakewalking":"cakewalk",
"cakiles":"cakile",
"cakier":"caky",
"cakiest":"caky",
"calabas":"calaba",
"calabashes":"calabash",
"calabazillas":"calabazilla",
"calaburas":"calabura",
"calamagrostises":"calamagrostis",
"calamaris":"calamari",
"calamaries":"calamary",
"calamines":"calamine",
"calaminthas":"calamintha",
"calamities":"calamity",
"calami":"calamus",
"calamuses":"calamus",
"calans":"calan",
"calandrinias":"calandrinia",
"calapooyas":"calapooya",
"calapuyas":"calapuya",
"calashes":"calash",
"calathi":"calathus",
"calcanei":"calcaneum",
"calcaneuses":"calcaneus",
"calcedonies":"calcedony",
"calceolarias":"calceolaria",
"calciferols":"calciferol",
"calcified":"calcify",
"calcifies":"calcify",
"calcifying":"calcify",
"calcimined":"calcimine",
"calcimining":"calcimine",
"calcined":"calcine",
"calcining":"calcine",
"calciums":"calcium",
"calcium-cyanamides":"calcium-cyanamide",
"calculated":"calculate",
"calculates":"calculate",
"calculating":"calculate",
"calculations":"calculation",
"calculators":"calculator",
"calculi":"calculus",
"calculuses":"calculus",
"caldaria":"caldarium",
"calderas":"caldera",
"caldrons":"caldron",
"caleches":"caleche",
"calefactions":"calefaction",
"calefactories":"calefactory",
"calendared":"calendar",
"calendaring":"calendar",
"calendars":"calendar",
"calendered":"calender",
"calendering":"calender",
"calves":"calf",
"calfskins":"calfskin",
"calibers":"caliber",
"calibrated":"calibrate",
"calibrates":"calibrate",
"calibrating":"calibrate",
"calibrations":"calibration",
"calibres":"calibre",
"caliches":"caliche",
"calicoes":"calico",
"calicos":"calico",
"caliculuses":"caliculus",
"calidrises":"calidris",
"califs":"calif",
"californias":"california",
"californiums":"californium",
"calipers":"caliper",
"caliperses":"calipers",
"caliphs":"caliph",
"calisayas":"calisaya",
"calisthenicses":"calisthenics",
"calices":"calix",
"calked":"calk",
"calking":"calk",
"calks":"calk",
"calkins":"calkin",
"called":"call",
"calling":"call",
"calls":"call",
"callas":"calla",
"callathumps":"callathump",
"callers":"caller",
"callicebuses":"callicebus",
"calligraphers":"calligrapher",
"calligraphists":"calligraphist",
"calligraphies":"calligraphy",
"callimorphas":"callimorpha",
"callinecteses":"callinectes",
"callings":"calling",
"callionymidaes":"callionymidae",
"calliopes":"calliope",
"calliophises":"calliophis",
"calliopses":"calliopsis",
"callipers":"calliper",
"calliperses":"callipers",
"calliphoras":"calliphora",
"calliphoridaes":"calliphoridae",
"callirhoes":"callirhoe",
"callisauruses":"callisaurus",
"callistephuses":"callistephus",
"callisthenicses":"callisthenics",
"callithricidaes":"callithricidae",
"callithrixes":"callithrix",
"callithumps":"callithump",
"callitrichaceaes":"callitrichaceae",
"callitriches":"callitriche",
"callitrises":"callitris",
"callophises":"callophis",
"callorhinuses":"callorhinus",
"callosities":"callosity",
"callouses":"callous",
"callousnesses":"callousness",
"callownesses":"callowness",
"callunas":"calluna",
"callused":"callus",
"calluses":"callus",
"callusing":"callus",
"calmed":"calm",
"calmer":"calm",
"calmest":"calm",
"calming":"calm",
"calms":"calm",
"calmings":"calming",
"calmnesses":"calmness",
"calocarpums":"calocarpum",
"calocedruses":"calocedrus",
"calochortuses":"calochortus",
"calomels":"calomel",
"calophyllums":"calophyllum",
"calopogons":"calopogon",
"calories":"calorie",
"calostomataceaes":"calostomataceae",
"calpes":"calpe",
"calqued":"calque",
"calques":"calque",
"calquing":"calque",
"calthas":"caltha",
"caltrops":"caltrop",
"calumets":"calumet",
"calumniated":"calumniate",
"calumniates":"calumniate",
"calumniating":"calumniate",
"calumnies":"calumny",
"calvarias":"calvaria",
"calvaries":"calvary",
"calvatias":"calvatia",
"calved":"calve",
"calving":"calve",
"calvins":"calvin",
"calces":"calx",
"calxes":"calx",
"calycanthaceaes":"calycanthaceae",
"calycanthuses":"calycanthus",
"calycles":"calycle",
"calycophyllums":"calycophyllum",
"calyculuses":"calyculus",
"calypsoes":"calypso",
"calypsos":"calypso",
"calypters":"calypter",
"calystegias":"calystegia",
"calyces":"calyx",
"calyxes":"calyx",
"camachiles":"camachile",
"camails":"camail",
"camaraderies":"camaraderie",
"camarillas":"camarilla",
"camases":"camas",
"camashes":"camash",
"camasses":"camass",
"camassias":"camassia",
"cambaruses":"cambarus",
"cambered":"camber",
"cambering":"camber",
"cambers":"camber",
"cambia":"cambium",
"cambiums":"cambium",
"cambodias":"cambodia",
"Cambodians":"Cambodian",
"cambrians":"cambrian",
"cambridges":"cambridge",
"camels":"camel",
"camelhairs":"camelhair",
"camelias":"camelia",
"camelidaes":"camelidae",
"camelinas":"camelina",
"camellias":"camellia",
"camelopards":"camelopard",
"cameluses":"camelus",
"cameos":"cameo",
"cameras":"camera",
"cameramen":"cameraman",
"camerlengos":"camerlengo",
"camerlingos":"camerlingo",
"cameroons":"cameroon",
"camerouns":"cameroun",
"camfers":"camfer",
"camions":"camion",
"camisades":"camisade",
"camisados":"camisado",
"camisoles":"camisole",
"camomiles":"camomile",
"camoshes":"camosh",
"camouflaged":"camouflage",
"camouflages":"camouflage",
"camouflaging":"camouflage",
"camped":"camp",
"camping":"camp",
"camps":"camp",
"campaigned":"campaign",
"campaigning":"campaign",
"campaigns":"campaign",
"campaigners":"campaigner",
"campaignings":"campaigning",
"campanas":"campana",
"campaniles":"campanile",
"campanili":"campanile",
"campanulas":"campanula",
"campanulaceaes":"campanulaceae",
"campanulaleses":"campanulales",
"campeachies":"campeachy",
"campephiluses":"campephilus",
"campers":"camper",
"campesinos":"campesino",
"campgrounds":"campground",
"camphorated":"camphorate",
"camphorating":"camphorate",
"camphorweeds":"camphorweed",
"campings":"camping",
"campions":"campion",
"campos":"campo",
"campongs":"campong",
"camponotuses":"camponotus",
"campsites":"campsite",
"camptosoruses":"camptosorus",
"campused":"campus",
"campuses":"campus",
"campusing":"campus",
"campussed":"campus",
"campussing":"campus",
"campier":"campy",
"campiest":"campy",
"campyloneurums":"campyloneurum",
"campylorhynchuses":"campylorhynchus",
"camwoods":"camwood",
"canned":"can",
"canning":"can",
"cans":"can",
"could":"can",
"canaans":"canaan",
"canaanitics":"canaanitic",
"canachiteses":"canachites",
"Canadians":"Canadian",
"canafistolas":"canafistola",
"canafistulas":"canafistula",
"canaled":"canal",
"canaling":"canal",
"canalled":"canal",
"canalling":"canal",
"canals":"canal",
"canaliculi":"canaliculus",
"canalisations":"canalisation",
"canalizations":"canalization",
"canalized":"canalize",
"canalizes":"canalize",
"canalizing":"canalize",
"canangas":"cananga",
"canangiums":"canangium",
"canapes":"canape",
"canarieses":"canaries",
"canaries":"canary",
"canastas":"canasta",
"canavalias":"canavalia",
"canberras":"canberra",
"canceled":"cancel",
"canceling":"cancel",
"cancelled":"cancel",
"cancelling":"cancel",
"cancels":"cancel",
"cancers":"cancer",
"cancerweeds":"cancerweed",
"cancridaes":"cancridae",
"cancroids":"cancroid",
"candelas":"candela",
"candelabras":"candelabra",
"candelabra":"candelabrum",
"cannibalises":"cannibalise",
"candelillas":"candelilla",
"candidacies":"candidacy",
"candidates":"candidate",
"candidatures":"candidature",
"candidiases":"candidiasis",
"candidnesses":"candidness",
"candled":"candle",
"candles":"candle",
"candling":"candle",
"candleberries":"candleberry",
"candlefishes":"candlefish",
"candlelights":"candlelight",
"candlemases":"candlemas",
"candlenuts":"candlenut",
"candlepinses":"candlepins",
"candlesticks":"candlestick",
"candors":"candor",
"candours":"candour",
"candied":"candy",
"candies":"candy",
"candying":"candy",
"candyflosses":"candyfloss",
"candymakers":"candymaker",
"candyweeds":"candyweed",
"caned":"cane",
"canes":"cane",
"caning":"cane",
"canecutters":"canecutter",
"canellas":"canella",
"canella-albas":"canella-alba",
"canellaceaes":"canellaceae",
"canfuls":"canful",
"caniculas":"canicula",
"canicules":"canicule",
"canids":"canid",
"canidaes":"canidae",
"canines":"canine",
"canings":"caning",
"canises":"canis",
"canistels":"canistel",
"canisters":"canister",
"cankered":"canker",
"cankering":"canker",
"cankers":"canker",
"cankerweeds":"cankerweed",
"cannas":"canna",
"cannabidaceaes":"cannabidaceae",
"cannabins":"cannabin",
"cannabises":"cannabis",
"cannaceaes":"cannaceae",
"canneries":"cannery",
"cannibals":"cannibal",
"cannibalized":"cannibalize",
"cannibalizes":"cannibalize",
"cannibalizing":"cannibalize",
"cannisters":"cannister",
"cannoned":"cannon",
"cannoning":"cannon",
"cannons":"cannon",
"cannonaded":"cannonade",
"cannonades":"cannonade",
"cannonading":"cannonade",
"cannonballs":"cannonball",
"cannoneers":"cannoneer",
"cannonries":"cannonry",
"cannulas":"cannula",
"cannulations":"cannulation",
"cannulizations":"cannulization",
"cannier":"canny",
"canniest":"canny",
"canoed":"canoe",
"canoeing":"canoe",
"canoes":"canoe",
"canoeists":"canoeist",
"canons":"canon",
"canonisations":"canonisation",
"canonizations":"canonization",
"canonized":"canonize",
"canonizes":"canonize",
"canonizing":"canonize",
"canonries":"canonry",
"canopied":"canopy",
"canopies":"canopy",
"canopying":"canopy",
"canted":"cant",
"canting":"cant",
"cants":"cant",
"cantalas":"cantala",
"cantaloups":"cantaloup",
"cantaloupes":"cantaloupe",
"cantatas":"cantata",
"canteens":"canteen",
"cantered":"canter",
"cantering":"canter",
"canters":"canter",
"cantharelluses":"cantharellus",
"canthi":"canthus",
"cantilenas":"cantilena",
"cantinas":"cantina",
"cantos":"canto",
"cantoned":"canton",
"cantoning":"canton",
"cantons":"canton",
"cantoneses":"cantonese",
"cantonments":"cantonment",
"cantors":"cantor",
"cantier":"canty",
"cantiest":"canty",
"canulae":"canula",
"canulas":"canula",
"canulations":"canulation",
"canulizations":"canulization",
"canvased":"canvas",
"canvases":"canvas",
"canvasing":"canvas",
"canvassed":"canvas",
"canvassing":"canvas",
"canvasbacks":"canvasback",
"canvasses":"canvass",
"canvassers":"canvasser",
"canvassings":"canvassing",
"canyons":"canyon",
"canzones":"canzone",
"canzoni":"canzone",
"caoutchoucs":"caoutchouc",
"capped":"cap",
"capping":"cap",
"caps":"cap",
"capabilities":"capability",
"capablenesses":"capableness",
"capaciousnesses":"capaciousness",
"capacitances":"capacitance",
"capacitors":"capacitor",
"capacities":"capacity",
"caparisoned":"caparison",
"caparisoning":"caparison",
"caparisons":"caparison",
"capes":"cape",
"capelans":"capelan",
"capelins":"capelin",
"capellas":"capella",
"capered":"caper",
"capering":"caper",
"capers":"caper",
"capercaillies":"capercaillie",
"capercailzies":"capercailzie",
"capeweeds":"capeweed",
"capibaras":"capibara",
"capillarities":"capillarity",
"capillaries":"capillary",
"capitals":"capital",
"capitalisations":"capitalisation",
"capitalisms":"capitalism",
"capitalists":"capitalist",
"capitalizations":"capitalization",
"capitalized":"capitalize",
"capitalizes":"capitalize",
"capitalizing":"capitalize",
"capitates":"capitate",
"capitols":"capitol",
"capitonidaes":"capitonidae",
"capitularies":"capitulary",
"capitulated":"capitulate",
"capitulating":"capitulate",
"capitulations":"capitulation",
"capitulums":"capitulum",
"capizs":"capiz",
"caplins":"caplin",
"capos":"capo",
"caporettos":"caporetto",
"capotes":"capote",
"capotens":"capoten",
"capparidaceaes":"capparidaceae",
"capparises":"capparis",
"cappellettis":"cappelletti",
"cappuccinos":"cappuccino",
"capras":"capra",
"caprellas":"caprella",
"capreoluses":"capreolus",
"capricci":"capriccio",
"capriccios":"capriccio",
"caprices":"caprice",
"capriciousnesses":"capriciousness",
"Capricorns":"Capricorn",
"capricornises":"capricornis",
"capricornuses":"capricornus",
"caprifigs":"caprifig",
"caprifoliaceaes":"caprifoliaceae",
"caprimulgids":"caprimulgid",
"caprimulgidaes":"caprimulgidae",
"caprimulgiformeses":"caprimulgiformes",
"caprimulguses":"caprimulgus",
"caprioled":"capriole",
"caprioling":"capriole",
"caproidaes":"caproidae",
"capromyidaes":"capromyidae",
"caproses":"capros",
"capsellas":"capsella",
"capsicums":"capsicum",
"capsids":"capsid",
"capsidaes":"capsidae",
"capsized":"capsize",
"capsizes":"capsize",
"capsizing":"capsize",
"capsizings":"capsizing",
"capstones":"capstone",
"capsuled":"capsule",
"capsules":"capsule",
"capsuling":"capsule",
"capsulized":"capsulize",
"capsulizing":"capsulize",
"captained":"captain",
"captaining":"captain",
"captains":"captain",
"captaincies":"captaincy",
"captainships":"captainship",
"captioned":"caption",
"captioning":"caption",
"captions":"caption",
"captivated":"captivate",
"captivates":"captivate",
"captivating":"captivate",
"captivations":"captivation",
"captives":"captive",
"captivities":"captivity",
"captoprils":"captopril",
"captors":"captor",
"captured":"capture",
"captures":"capture",
"capturing":"capture",
"capuccinos":"capuccino",
"capuchins":"capuchin",
"capulins":"capulin",
"capita":"caput",
"caputs":"caput",
"capybaras":"capybara",
"cars":"car",
"car-mechanics":"car-mechanic",
"carabaos":"carabao",
"carabidaes":"carabidae",
"carabineers":"carabineer",
"carabiners":"carabiner",
"carabiniers":"carabinier",
"carabinieri":"carabiniere",
"caracals":"caracal",
"caracases":"caracas",
"caracks":"carack",
"caracoled":"caracole",
"caracoling":"caracole",
"caracolitos":"caracolito",
"caraculs":"caracul",
"carafates":"carafate",
"carafes":"carafe",
"caraganas":"caragana",
"carageens":"carageen",
"carambolas":"carambola",
"caramels":"caramel",
"caranchas":"carancha",
"carandas":"caranda",
"carandays":"caranday",
"carangids":"carangid",
"carangidaes":"carangidae",
"caranxes":"caranx",
"carapaces":"carapace",
"carapidaes":"carapidae",
"carassiuses":"carassius",
"carats":"carat",
"caravans":"caravan",
"caravansaries":"caravansary",
"caravanserais":"caravanserai",
"caraways":"caraway",
"carbamides":"carbamide",
"carbohydrates":"carbohydrate",
"carbons":"carbon",
"carbonadoed":"carbonado",
"carbonadoes":"carbonado",
"carbonadoing":"carbonado",
"carbonados":"carbonado",
"carbonated":"carbonate",
"carbonating":"carbonate",
"carboniferouses":"carboniferous",
"carbonisations":"carbonisation",
"carbonizations":"carbonization",
"carbonized":"carbonize",
"carbonizes":"carbonize",
"carbonizing":"carbonize",
"carboxyls":"carboxyl",
"carbureted":"carburet",
"carbureting":"carburet",
"carburets":"carburet",
"carburetted":"carburet",
"carburetting":"carburet",
"carburetors":"carburetor",
"carburettors":"carburettor",
"carbies":"carby",
"carcajous":"carcajou",
"carcases":"carcase",
"carcasses":"carcass",
"carcharhinidaes":"carcharhinidae",
"carcharhinuses":"carcharhinus",
"carchariases":"carcharias",
"carchariidaes":"carchariidae",
"carcharodons":"carcharodon",
"carcinomas":"carcinoma",
"carcinomata":"carcinoma",
"carded":"card",
"carding":"card",
"cards":"card",
"cardamines":"cardamine",
"cardamoms":"cardamom",
"cardamons":"cardamon",
"cardamums":"cardamum",
"cardboards":"cardboard",
"cardcases":"cardcase",
"cardcastles":"cardcastle",
"cardhouses":"cardhouse",
"cardigans":"cardigan",
"cardiidaes":"cardiidae",
"cardinals":"cardinal",
"cardiograms":"cardiogram",
"cardiographs":"cardiograph",
"cardiographies":"cardiography",
"cardiologists":"cardiologist",
"cardiomegalies":"cardiomegaly",
"cardiopathies":"cardiopathy",
"cardiospermums":"cardiospermum",
"cardiums":"cardium",
"cardizems":"cardizem",
"cardoons":"cardoon",
"cardses":"cards",
"cardsharps":"cardsharp",
"cardsharpers":"cardsharper",
"carduelinaes":"carduelinae",
"carduelises":"carduelis",
"carduuses":"carduus",
"cared":"care",
"cares":"care",
"caring":"care",
"careened":"careen",
"careening":"careen",
"careens":"careen",
"careered":"career",
"careering":"career",
"careers":"career",
"carefreenesses":"carefreeness",
"carefulnesses":"carefulness",
"caregivers":"caregiver",
"carelessnesses":"carelessness",
"carelians":"carelian",
"caressed":"caress",
"caresses":"caress",
"caressing":"caress",
"caressings":"caressing",
"caretakers":"caretaker",
"carettas":"caretta",
"carexes":"carex",
"carfares":"carfare",
"cargoes":"cargo",
"cargos":"cargo",
"cariamas":"cariama",
"cariamidaes":"cariamidae",
"caribs":"carib",
"Caribbeans":"Caribbean",
"caribes":"caribe",
"caribeeses":"caribees",
"caribous":"caribou",
"caricas":"carica",
"caricaceaes":"caricaceae",
"caricatured":"caricature",
"caricatures":"caricature",
"caricaturing":"caricature",
"carieses":"caries",
"carillons":"carillon",
"carinae":"carina",
"carinas":"carina",
"carinates":"carinate",
"carings":"caring",
"cariocas":"carioca",
"carlinas":"carlina",
"carloads":"carload",
"carmen":"carman",
"carmelites":"carmelite",
"carmines":"carmine",
"carnages":"carnage",
"carnalities":"carnality",
"carnations":"carnation",
"carnaubas":"carnauba",
"carnegies":"carnegie",
"carnegieas":"carnegiea",
"carnelians":"carnelian",
"carneyed":"carney",
"carneying":"carney",
"carneys":"carney",
"carnified":"carnify",
"carnifies":"carnify",
"carnifying":"carnify",
"carnivals":"carnival",
"carnivoras":"carnivora",
"carnosauras":"carnosaura",
"carnied":"carny",
"carnies":"carny",
"carnying":"carny",
"carobs":"carob",
"caroled":"carol",
"caroling":"carol",
"carolled":"carol",
"carolling":"carol",
"carols":"carol",
"carolers":"caroler",
"carollers":"caroller",
"caroli":"carolus",
"caroluses":"carolus",
"caromed":"carom",
"caroming":"carom",
"caroms":"carom",
"carotenes":"carotene",
"carotenemias":"carotenemia",
"carotins":"carotin",
"carousals":"carousal",
"caroused":"carouse",
"carouses":"carouse",
"carousing":"carouse",
"carousels":"carousel",
"carousers":"carouser",
"carped":"carp",
"carping":"carp",
"carps":"carp",
"carpals":"carpal",
"carpentered":"carpenter",
"carpentering":"carpenter",
"carpenters":"carpenter",
"carpenterias":"carpenteria",
"carpentries":"carpentry",
"carpers":"carper",
"carpeted":"carpet",
"carpeting":"carpet",
"carpets":"carpet",
"carpetbagged":"carpetbag",
"carpetbagging":"carpetbag",
"carpetings":"carpeting",
"carpetweeds":"carpetweed",
"carphophises":"carphophis",
"carpinaceaes":"carpinaceae",
"carpings":"carping",
"carpinuses":"carpinus",
"carpobrotuses":"carpobrotus",
"carpocapsas":"carpocapsa",
"carpodacuses":"carpodacus",
"carpogonia":"carpogonium",
"carports":"carport",
"carpi":"carpus",
"carpuses":"carpus",
"carracks":"carrack",
"carrageens":"carrageen",
"carrageenans":"carrageenan",
"carrageenins":"carrageenin",
"carragheens":"carragheen",
"carrefours":"carrefour",
"carrels":"carrel",
"carrells":"carrell",
"carriages":"carriage",
"carriers":"carrier",
"carrizos":"carrizo",
"carrolls":"carroll",
"carrots":"carrot",
"carrottops":"carrottop",
"carried":"carry",
"carries":"carry",
"carrying":"carry",
"carry-forwards":"carry-forward",
"carry-overs":"carry-over",
"carryalls":"carryall",
"carryings-on":"carrying-on",
"carted":"cart",
"carting":"cart",
"carts":"cart",
"cartages":"cartage",
"cartes":"carte",
"cartels":"cartel",
"carters":"carter",
"carthamuses":"carthamus",
"carthorses":"carthorse",
"cartilages":"cartilage",
"cartings":"carting",
"cartographers":"cartographer",
"cartographies":"cartography",
"cartoned":"carton",
"cartoning":"carton",
"cartons":"carton",
"cartonfuls":"cartonful",
"cartooned":"cartoon",
"cartooning":"cartoon",
"cartoons":"cartoon",
"cartouches":"cartouch",
"cartridges":"cartridge",
"cartroads":"cartroad",
"cartularies":"cartulary",
"cartwheels":"cartwheel",
"carums":"carum",
"caruncles":"caruncle",
"carunculas":"caruncula",
"carved":"carve",
"carves":"carve",
"carving":"carve",
"carvers":"carver",
"carvings":"carving",
"caryas":"carya",
"carides":"caryatid",
"caryatides":"caryatid",
"caryatids":"caryatid",
"caryocars":"caryocar",
"caryocaraceaes":"caryocaraceae",
"caryophyllaceaes":"caryophyllaceae",
"caryophyllaleses":"caryophyllales",
"caryophyllidaes":"caryophyllidae",
"caryopses":"caryopsis",
"caryotas":"caryota",
"casabas":"casaba",
"Casanovas":"Casanova",
"casavas":"casava",
"cascabels":"cascabel",
"cascaded":"cascade",
"cascades":"cascade",
"cascading":"cascade",
"cascadeses":"cascades",
"cascaras":"cascara",
"cascarillas":"cascarilla",
"cased":"case",
"cases":"case",
"casing":"case",
"casefuls":"caseful",
"casefied":"casefy",
"casefies":"casefy",
"casefying":"casefy",
"casehardened":"caseharden",
"casehardening":"caseharden",
"caseins":"casein",
"casements":"casement",
"caseworkers":"caseworker",
"cashed":"cash",
"cashes":"cash",
"cashing":"cash",
"cash-and-carries":"cash-and-carry",
"cashboxes":"cashbox",
"cashews":"cashew",
"cashiered":"cashier",
"cashiering":"cashier",
"cashiers":"cashier",
"cashmeres":"cashmere",
"casings":"casing",
"casinos":"casino",
"casino-hotels":"casino-hotel",
"casks":"cask",
"casketed":"casket",
"casketing":"casket",
"caskets":"casket",
"caskfuls":"caskful",
"casmerodiuses":"casmerodius",
"casquets":"casquet",
"casquetels":"casquetel",
"Cassandras":"Cassandra",
"cassavas":"cassava",
"casseroles":"casserole",
"cassettes":"cassette",
"cassias":"cassia",
"cassies":"cassie",
"cassinos":"cassino",
"cassiopes":"cassiope",
"cassites":"cassite",
"cassiuses":"cassius",
"cassowaries":"cassowary",
"casting":"cast",
"casts":"cast",
"castaneas":"castanea",
"castanets":"castanet",
"castanetses":"castanets",
"castanopses":"castanopsis",
"castanospermums":"castanospermum",
"castaways":"castaway",
"castes":"caste",
"castellanies":"castellany",
"casters":"caster",
"castigated":"castigate",
"castigates":"castigate",
"castigating":"castigate",
"castigations":"castigation",
"castiles":"castile",
"castillas":"castilla",
"castilleias":"castilleia",
"castillejas":"castilleja",
"castings":"casting",
"castled":"castle",
"castles":"castle",
"castling":"castle",
"castlings":"castling",
"castors":"castor",
"castoridaes":"castoridae",
"castoroideses":"castoroides",
"castrated":"castrate",
"castrates":"castrate",
"castrating":"castrate",
"castrations":"castration",
"castrati":"castrato",
"castratos":"castrato",
"casuals":"casual",
"casualnesses":"casualness",
"casualties":"casualty",
"casuaridaes":"casuaridae",
"casuariiformeses":"casuariiformes",
"casuarinaceaes":"casuarinaceae",
"casuarinaleses":"casuarinales",
"casuariuses":"casuarius",
"casuists":"casuist",
"casuistries":"casuistry",
"cats":"cat",
"catted":"cat",
"catting":"cat",
"catabases":"catabasis",
"catabolisms":"catabolism",
"catacalas":"catacala",
"cataclases":"cataclasis",
"cataclysms":"cataclysm",
"catacombs":"catacomb",
"cataflams":"cataflam",
"cataloes":"catalo",
"catalos":"catalo",
"cataloged":"catalog",
"cataloging":"catalog",
"catalogs":"catalog",
"catalogers":"cataloger",
"catalogued":"catalogue",
"catalogues":"catalogue",
"cataloguing":"catalogue",
"cataloguers":"cataloguer",
"catalpas":"catalpa",
"catalufas":"catalufa",
"catalyses":"catalysis",
"catalysts":"catalyst",
"catalyzed":"catalyze",
"catalyzing":"catalyze",
"catamenias":"catamenia",
"catamounts":"catamount",
"catamountains":"catamountain",
"cataphoreses":"cataphoresis",
"cataplasms":"cataplasm",
"catapreses":"catapres",
"catapulted":"catapult",
"catapulting":"catapult",
"catapults":"catapult",
"cataracts":"cataract",
"catasetums":"catasetum",
"catastases":"catastasis",
"catastrophes":"catastrophe",
"catatonias":"catatonia",
"catawbas":"catawba",
"catbirds":"catbird",
"catbriers":"catbrier",
"catcalled":"catcall",
"catcalling":"catcall",
"catches":"catch",
"catching":"catch",
"caught":"catch",
"catchers":"catcher",
"catchflies":"catchfly",
"catchings":"catching",
"catchpennies":"catchpenny",
"catchweeds":"catchweed",
"catchwords":"catchword",
"catchier":"catchy",
"catchiest":"catchy",
"catclaws":"catclaw",
"cates":"cate",
"catechized":"catechize",
"catechizes":"catechize",
"catechizing":"catechize",
"catechus":"catechu",
"catechumens":"catechumen",
"categorisations":"categorisation",
"categorizations":"categorization",
"categorized":"categorize",
"categorizing":"categorize",
"categories":"category",
"catenae":"catena",
"catenas":"catena",
"catenaries":"catenary",
"catenated":"catenate",
"catenates":"catenate",
"catenating":"catenate",
"catered":"cater",
"catering":"cater",
"caters":"cater",
"caterpillars":"caterpillar",
"caterwauled":"caterwaul",
"caterwauling":"caterwaul",
"caterwauls":"caterwaul",
"catfishes":"catfish",
"catguts":"catgut",
"cathari":"cathar",
"cathars":"cathar",
"catharactas":"catharacta",
"catharanthuses":"catharanthus",
"catharists":"catharist",
"catharses":"catharsis",
"catharteses":"cathartes",
"cathartics":"cathartic",
"cathartids":"cathartid",
"cathartidaes":"cathartidae",
"cathedrae":"cathedra",
"cathedras":"cathedra",
"cathedrals":"cathedral",
"catherines":"catherine",
"catheterized":"catheterize",
"catheterizing":"catheterize",
"cathexes":"cathexis",
"catholicisms":"catholicism",
"catholicities":"catholicity",
"catholicized":"catholicize",
"catholicizes":"catholicize",
"catholicizing":"catholicize",
"cathouses":"cathouse",
"catkins":"catkin",
"catmints":"catmint",
"catnaps":"catnap",
"catnips":"catnip",
"catoptrophoruses":"catoptrophorus",
"catostomidaes":"catostomidae",
"catostomuses":"catostomus",
"catskillses":"catskills",
"catsups":"catsup",
"cattaloes":"cattalo",
"cattalos":"cattalo",
"catteries":"cattery",
"catties":"cattie",
"cattinesses":"cattiness",
"cattlemen":"cattleman",
"cattleships":"cattleship",
"cattleyas":"cattleya",
"cattier":"catty",
"cattiest":"catty",
"caucasias":"caucasia",
"Caucasians":"Caucasian",
"caucasuses":"caucasus",
"caucused":"caucus",
"caucuses":"caucus",
"caucusing":"caucus",
"caudatas":"caudata",
"caudates":"caudate",
"caudexes":"caudex",
"caudillos":"caudillo",
"cauls":"caul",
"cauldrons":"cauldron",
"cauliflowers":"cauliflower",
"caules":"caulis",
"caulked":"caulk",
"caulking":"caulk",
"caulks":"caulk",
"caulophyllums":"caulophyllum",
"causas":"causa",
"causalities":"causality",
"causations":"causation",
"caused":"cause",
"causes":"cause",
"causing":"cause",
"causeries":"causerie",
"causewayed":"causeway",
"causewaying":"causeway",
"causeways":"causeway",
"causings":"causing",
"caustics":"caustic",
"cauterisations":"cauterisation",
"cauterizations":"cauterization",
"cauterized":"cauterize",
"cauterizes":"cauterize",
"cauterizing":"cauterize",
"cauteries":"cautery",
"cautioned":"caution",
"cautioning":"caution",
"cautions":"caution",
"cautiouses":"cautious",
"cautiousnesses":"cautiousness",
"cavaliers":"cavalier",
"cavallas":"cavalla",
"cavallies":"cavally",
"cavalries":"cavalry",
"cavalrymen":"cavalryman",
"cavatinas":"cavatina",
"cavatine":"cavatina",
"caved":"cave",
"caves":"cave",
"caving":"cave",
"caveats":"caveat",
"cavefishes":"cavefish",
"cavemen":"caveman",
"caverned":"cavern",
"caverning":"cavern",
"caverns":"cavern",
"cavetti":"cavetto",
"cavias":"cavia",
"caviars":"caviar",
"caviares":"caviare",
"caviidaes":"caviidae",
"caviled":"cavil",
"caviling":"cavil",
"cavilled":"cavil",
"cavilling":"cavil",
"cavils":"cavil",
"cavities":"cavity",
"cavo-relievos":"cavo-relievo",
"cavo-rilievi":"cavo-rilievo",
"cavorted":"cavort",
"cavorting":"cavort",
"cavorts":"cavort",
"cavums":"cavum",
"cavies":"cavy",
"cawed":"caw",
"cawing":"caw",
"caws":"caw",
"cays":"cay",
"cayennes":"cayenne",
"caymans":"cayman",
"caymen":"cayman",
"cayugas":"cayuga",
"cayuses":"cayuse",
"caziques":"cazique",
"cbcs":"cbc",
"cbeled":"cbel",
"cbeling":"cbel",
"cbelled":"cbel",
"cbelling":"cbel",
"cbels":"cbel",
"ccs":"cc",
"CDs":"CD",
"cd-rs":"cd-r",
"CD-ROMs":"CD-ROM",
"cd-wos":"cd-wo",
"ces":"ce",
"ceased":"cease",
"ceases":"cease",
"ceasing":"cease",
"cease-fires":"cease-fire",
"ceaselessnesses":"ceaselessness",
"cebidaes":"cebidae",
"cebuans":"cebuan",
"cebuanos":"cebuano",
"cebuellas":"cebuella",
"cebuses":"cebus",
"cecidomyidaes":"cecidomyidae",
"cecities":"cecity",
"cecropias":"cecropia",
"cecropiaceaes":"cecropiaceae",
"ceca":"cecum",
"cecums":"cecum",
"cedars":"cedar",
"cedarbirds":"cedarbird",
"cedarwoods":"cedarwood",
"ceded":"cede",
"cedes":"cede",
"ceding":"cede",
"cedis":"cedi",
"cedillas":"cedilla",
"cedings":"ceding",
"cedrelas":"cedrela",
"cedruses":"cedrus",
"cefobids":"cefobid",
"cefoperazones":"cefoperazone",
"cefotaximes":"cefotaxime",
"ceftazidimes":"ceftazidime",
"ceftins":"ceftin",
"ceftriaxones":"ceftriaxone",
"cefuroximes":"cefuroxime",
"ceibas":"ceiba",
"ceibos":"ceibo",
"ceiled":"ceil",
"ceiling":"ceil",
"ceilings":"ceiling",
"celandines":"celandine",
"celastraceaes":"celastraceae",
"celastruses":"celastrus",
"celebeses":"celebes",
"celebrants":"celebrant",
"celebrated":"celebrate",
"celebrates":"celebrate",
"celebrating":"celebrate",
"celebraters":"celebrater",
"celebrations":"celebration",
"celebrators":"celebrator",
"celebrities":"celebrity",
"celeriacs":"celeriac",
"celerities":"celerity",
"celeries":"celery",
"celestas":"celesta",
"celestials":"celestial",
"celibacies":"celibacy",
"cells":"cell",
"cellae":"cella",
"cellared":"cellar",
"cellaring":"cellar",
"cellars":"cellar",
"cellarets":"cellaret",
"cellblocks":"cellblock",
"cellos":"cello",
"celluloids":"celluloid",
"celoms":"celom",
"celomas":"celoma",
"celosias":"celosia",
"celts":"celt",
"Celtics":"Celtic",
"celtises":"celtis",
"celtuces":"celtuce",
"cembali":"cembalo",
"cembalos":"cembalo",
"cemented":"cement",
"cementing":"cement",
"cements":"cement",
"cementites":"cementite",
"cementums":"cementum",
"cemeteries":"cemetery",
"cenchruses":"cenchrus",
"cenobites":"cenobite",
"cenogeneses":"cenogenesis",
"cenozoics":"cenozoic",
"censed":"cense",
"censes":"cense",
"censing":"cense",
"censers":"censer",
"censored":"censor",
"censoring":"censor",
"censors":"censor",
"censorings":"censoring",
"censorships":"censorship",
"censured":"censure",
"censures":"censure",
"censuring":"censure",
"censused":"census",
"censuses":"census",
"censusing":"census",
"cents":"cent",
"centals":"cental",
"centares":"centare",
"centaurs":"centaur",
"centaureas":"centaurea",
"centauriums":"centaurium",
"centauruses":"centaurus",
"centauries":"centaury",
"centavos":"centavo",
"centenaries":"centenary",
"centennials":"centennial",
"centered":"center",
"centering":"center",
"centers":"center",
"centerboards":"centerboard",
"centerfields":"centerfield",
"centerings":"centering",
"centerlines":"centerline",
"centerpieces":"centerpiece",
"centesimi":"centesimo",
"centesimos":"centesimo",
"centiliters":"centiliter",
"centilitres":"centilitre",
"centillions":"centillion",
"centimes":"centime",
"centimeters":"centimeter",
"centimetres":"centimetre",
"centimos":"centimo",
"centners":"centner",
"centos":"cento",
"centrals":"central",
"centralisations":"centralisation",
"centralities":"centrality",
"centralizations":"centralization",
"centralized":"centralize",
"centralizes":"centralize",
"centralizing":"centralize",
"centranthuses":"centranthus",
"centrarchids":"centrarchid",
"centrarchidaes":"centrarchidae",
"centred":"centre",
"centres":"centre",
"centring":"centre",
"centreboards":"centreboard",
"centreds":"centred",
"centrepieces":"centrepiece",
"centrifuges":"centrifuge",
"centriscidaes":"centriscidae",
"centrists":"centrist",
"centrocercuses":"centrocercus",
"centroids":"centroid",
"centrolobiums":"centrolobium",
"centropomidaes":"centropomidae",
"centropomuses":"centropomus",
"centropristises":"centropristis",
"centropuses":"centropus",
"centrosemas":"centrosema",
"centrosomes":"centrosome",
"centrospermaes":"centrospermae",
"centra":"centrum",
"centrums":"centrum",
"centunculuses":"centunculus",
"centuries":"century",
"CEOs":"CEO",
"cephalalgias":"cephalalgia",
"cephalantheras":"cephalanthera",
"cephalaspids":"cephalaspid",
"cephalaspidas":"cephalaspida",
"cephalexins":"cephalexin",
"cephalhematomas":"cephalhematoma",
"cephalobidaes":"cephalobidae",
"cephalochordatas":"cephalochordata",
"cephalohematomas":"cephalohematoma",
"cephalopods":"cephalopod",
"cephalopodas":"cephalopoda",
"cephalopteruses":"cephalopterus",
"cephalosporins":"cephalosporin",
"cephalotaceaes":"cephalotaceae",
"cephalotaxaceaes":"cephalotaxaceae",
"cephalotaxuses":"cephalotaxus",
"cephalothoraces":"cephalothorax",
"cephalothoraxes":"cephalothorax",
"cephalotuses":"cephalotus",
"cepphuses":"cepphus",
"cers":"cer",
"cerambycidaes":"cerambycidae",
"ceramicists":"ceramicist",
"ceramists":"ceramist",
"cerapteryxes":"cerapteryx",
"cerasteses":"cerastes",
"cerastiums":"cerastium",
"ceratins":"ceratin",
"ceratitises":"ceratitis",
"ceratodontidaes":"ceratodontidae",
"ceratoduses":"ceratodus",
"ceratonias":"ceratonia",
"ceratopetalums":"ceratopetalum",
"ceratophyllaceaes":"ceratophyllaceae",
"ceratophyllums":"ceratophyllum",
"ceratopogons":"ceratopogon",
"ceratopogonidaes":"ceratopogonidae",
"ceratopsias":"ceratopsia",
"ceratopsians":"ceratopsian",
"ceratopsidaes":"ceratopsidae",
"ceratopterises":"ceratopteris",
"ceratosaurs":"ceratosaur",
"ceratosauruses":"ceratosaurus",
"ceratostomataceaes":"ceratostomataceae",
"ceratostomellas":"ceratostomella",
"ceratotheriums":"ceratotherium",
"cercariiae":"cercaria",
"cercidiphyllaceaes":"cercidiphyllaceae",
"cercidiphyllums":"cercidiphyllum",
"cercidiums":"cercidium",
"cercises":"cercis",
"cercocebuses":"cercocebus",
"cercopidaes":"cercopidae",
"cercopithecidaes":"cercopithecidae",
"cercopithecuses":"cercopithecus",
"cercosporas":"cercospora",
"cercosporellas":"cercosporella",
"cerci":"cercus",
"cereals":"cereal",
"cerebella":"cerebellum",
"cerebellums":"cerebellum",
"cerebrated":"cerebrate",
"cerebrates":"cerebrate",
"cerebrating":"cerebrate",
"cerebrations":"cerebration",
"cerebra":"cerebrum",
"cerebrums":"cerebrum",
"cerements":"cerement",
"ceremonials":"ceremonial",
"ceremonies":"ceremony",
"cereuses":"cereus",
"cerimen":"ceriman",
"cerises":"cerise",
"ceriums":"cerium",
"ceros":"cero",
"ceroxylons":"ceroxylon",
"cerripeds":"cerriped",
"cerripedes":"cerripede",
"certainties":"certainty",
"certhias":"certhia",
"certhiidaes":"certhiidae",
"certificated":"certificate",
"certificates":"certificate",
"certificating":"certificate",
"certifications":"certification",
"certified":"certify",
"certifies":"certify",
"certifying":"certify",
"certioraris":"certiorari",
"certitudes":"certitude",
"ceruleans":"cerulean",
"cerumens":"cerumen",
"cerussites":"cerussite",
"cervanteses":"cervantes",
"cervids":"cervid",
"cervidaes":"cervidae",
"cervices":"cervix",
"cervixes":"cervix",
"cervuses":"cervus",
"ceryles":"ceryle",
"cesareans":"cesarean",
"cesarians":"cesarian",
"cesiums":"cesium",
"cessations":"cessation",
"cessions":"cession",
"cessionaries":"cessionary",
"cesspits":"cesspit",
"cesspools":"cesspool",
"cestidas":"cestida",
"cestidaes":"cestidae",
"cestodas":"cestoda",
"cestodes":"cestode",
"cestrums":"cestrum",
"cestums":"cestum",
"cesti":"cestus",
"cesurae":"cesura",
"cesuras":"cesura",
"cetaceas":"cetacea",
"cetaceans":"cetacean",
"cetchups":"cetchup",
"ceteraches":"ceterach",
"cetonias":"cetonia",
"cetoniidaes":"cetoniidae",
"cetorhinidaes":"cetorhinidae",
"cetorhinuses":"cetorhinus",
"cetrarias":"cetraria",
"ceylons":"ceylon",
"ceylonites":"ceylonite",
"cfs":"cf",
"CFCs":"CFC",
"cha-chas":"cha-cha",
"cha-cha-chas":"cha-cha-cha",
"chablises":"chablis",
"chacmas":"chacma",
"chads":"chad",
"chadics":"chadic",
"chadlocks":"chadlock",
"chaenomeleses":"chaenomeles",
"chaenopses":"chaenopsis",
"chaetae":"chaeta",
"chaetodipteruses":"chaetodipterus",
"chaetodontidaes":"chaetodontidae",
"chaetognaths":"chaetognath",
"chaetognathas":"chaetognatha",
"chafed":"chafe",
"chafes":"chafe",
"chafing":"chafe",
"chafeweeds":"chafeweed",
"chaffed":"chaff",
"chaffing":"chaff",
"chaffs":"chaff",
"chaffered":"chaffer",
"chaffering":"chaffer",
"chaffers":"chaffer",
"chaffinches":"chaffinch",
"chaffweeds":"chaffweed",
"chagas":"chaga",
"chagatais":"chagatai",
"chaggas":"chagga",
"chagrined":"chagrin",
"chagrining":"chagrin",
"chagrins":"chagrin",
"chahtas":"chahta",
"chained":"chain",
"chaining":"chain",
"chains":"chain",
"chain-smoked":"chain-smoke",
"chain-smoking":"chain-smoke",
"chainmen":"chainman",
"chainses":"chains",
"chainsaws":"chainsaw",
"chaired":"chair",
"chairing":"chair",
"chairs":"chair",
"chairlifts":"chairlift",
"chairmanned":"chairman",
"chairmanning":"chairman",
"chairmans":"chairman",
"chairmen":"chairman",
"chairpersons":"chairperson",
"chairwomen":"chairwoman",
"chaises":"chaise",
"chaises_longues":"chaise_longue",
"chaise_longues":"chaise_longue",
"chajas":"chaja",
"chalazae":"chalaza",
"chalazas":"chalaza",
"chalazions":"chalazion",
"chalcanthites":"chalcanthite",
"chalcedonies":"chalcedony",
"chalcids":"chalcid",
"chalcidaes":"chalcidae",
"chalcidflies":"chalcidfly",
"chalcididaes":"chalcididae",
"chalcises":"chalcis",
"chalcocites":"chalcocite",
"chalcopyrites":"chalcopyrite",
"chalcostigmas":"chalcostigma",
"chalices":"chalice",
"chalked":"chalk",
"chalking":"chalk",
"chalks":"chalk",
"chalkboards":"chalkboard",
"challahs":"challah",
"challenged":"challenge",
"challenges":"challenge",
"challenging":"challenge",
"challengers":"challenger",
"chalonses":"chalons",
"chalons-sur-marnes":"chalons-sur-marne",
"chalutzim":"chalutz",
"chalybites":"chalybite",
"chams":"cham",
"chamaeas":"chamaea",
"chamaecristas":"chamaecrista",
"chamaecyparises":"chamaecyparis",
"chamaecytisuses":"chamaecytisus",
"chamaedaphnes":"chamaedaphne",
"chamaeleos":"chamaeleo",
"chamaeleons":"chamaeleon",
"chamaeleonidaes":"chamaeleonidae",
"chamaeleontidaes":"chamaeleontidae",
"chamaemelums":"chamaemelum",
"chambered":"chamber",
"chambering":"chamber",
"chambers":"chamber",
"chamberlains":"chamberlain",
"chambermaids":"chambermaid",
"chamberpots":"chamberpot",
"chameleons":"chameleon",
"chamfrons":"chamfron",
"chammies":"chammy",
"chamoises":"chamois",
"chamoix":"chamois",
"chamomiles":"chamomile",
"champed":"champ",
"champing":"champ",
"champs":"champ",
"champagnes":"champagne",
"champagne-ardennes":"champagne-ardenne",
"champaigns":"champaign",
"champerties":"champerty",
"champignons":"champignon",
"championed":"champion",
"championing":"champion",
"champions":"champion",
"championships":"championship",
"chanals":"chanal",
"chanars":"chanar",
"chanced":"chance",
"chances":"chance",
"chancing":"chance",
"chancels":"chancel",
"chancelleries":"chancellery",
"Chancellors":"Chancellor",
"chancellories":"chancellory",
"chanceries":"chancery",
"chancier":"chancy",
"chanciest":"chancy",
"chandeliers":"chandelier",
"chandleries":"chandlery",
"chanfrons":"chanfron",
"changs":"chang",
"changans":"changan",
"changed":"change",
"changes":"change",
"changing":"change",
"change-of-paces":"change-of-pace",
"change-ups":"change-up",
"changeabilities":"changeability",
"changeablenesses":"changeableness",
"changefulnesses":"changefulness",
"changelessnesses":"changelessness",
"changelings":"changeling",
"changeovers":"changeover",
"changers":"changer",
"channeled":"channel",
"channeling":"channel",
"channelled":"channel",
"channelling":"channel",
"channels":"channel",
"channelisations":"channelisation",
"channelizations":"channelization",
"channelized":"channelize",
"channelizes":"channelize",
"channelizing":"channelize",
"chansons":"chanson",
"chansonniers":"chansonnier",
"chanted":"chant",
"chanting":"chant",
"chants":"chant",
"chantarelles":"chantarelle",
"chanters":"chanter",
"chanterelles":"chanterelle",
"chanteys":"chantey",
"chantings":"chanting",
"chantries":"chantry",
"chanties":"chanty",
"chanukahs":"chanukah",
"chaoses":"chaos",
"chapped":"chap",
"chapping":"chap",
"chaps":"chap",
"chaparrals":"chaparral",
"chapatis":"chapati",
"chapattis":"chapatti",
"chapeaus":"chapeau",
"chapeaux":"chapeau",
"chapels":"chapel",
"chapelgoers":"chapelgoer",
"chaperoned":"chaperon",
"chaperoning":"chaperon",
"chaperons":"chaperon",
"chaperones":"chaperone",
"chapiters":"chapiter",
"chaplains":"chaplain",
"chaplaincies":"chaplaincy",
"chaplainships":"chaplainship",
"chaplets":"chaplet",
"chapmen":"chapman",
"chaptered":"chapter",
"chaptering":"chapter",
"chapters":"chapter",
"chapterhouses":"chapterhouse",
"charred":"char",
"charring":"char",
"chars":"char",
"charas":"chara",
"charabancs":"charabanc",
"characeaes":"characeae",
"characids":"characid",
"characidaes":"characidae",
"characins":"characin",
"characinidaes":"characinidae",
"charactered":"character",
"charactering":"character",
"characters":"character",
"characteristics":"characteristic",
"characterizations":"characterization",
"characterized":"characterize",
"characterizes":"characterize",
"characterizing":"characterize",
"characteries":"charactery",
"charades":"charade",
"charadriis":"charadrii",
"charadriidaes":"charadriidae",
"charadriiformeses":"charadriiformes",
"charadriuses":"charadrius",
"charaleses":"charales",
"charcoaled":"charcoal",
"charcoaling":"charcoal",
"charcoals":"charcoal",
"chards":"chard",
"chardonnays":"chardonnay",
"charged":"charge",
"charges":"charge",
"charging":"charge",
"chargers":"charger",
"charinas":"charina",
"charinesses":"chariness",
"charioted":"chariot",
"charioting":"chariot",
"chariots":"chariot",
"charismas":"charisma",
"charismata":"charisma",
"charities":"charity",
"charivaris":"charivari",
"charladies":"charlady",
"charlatans":"charlatan",
"charlatanisms":"charlatanism",
"charlemagnes":"charlemagne",
"charleses":"charles",
"charlestons":"charleston",
"charlocks":"charlock",
"charmed":"charm",
"charming":"charm",
"charms":"charm",
"charmers":"charmer",
"charnels":"charnel",
"charophyceaes":"charophyceae",
"charrs":"charr",
"charronias":"charronia",
"charted":"chart",
"charting":"chart",
"charts":"chart",
"chartered":"charter",
"chartering":"charter",
"charters":"charter",
"chartreuses":"chartreuse",
"chartularies":"chartulary",
"charwomen":"charwoman",
"charier":"chary",
"chariest":"chary",
"chased":"chase",
"chases":"chase",
"chasing":"chase",
"chaseds":"chased",
"chasers":"chaser",
"chasms":"chasm",
"chasses":"chasse",
"chaster":"chaste",
"chastest":"chaste",
"chastened":"chasten",
"chastening":"chasten",
"chastens":"chasten",
"chastenesses":"chasteness",
"chastenings":"chastening",
"chastised":"chastise",
"chastises":"chastise",
"chastising":"chastise",
"chastisements":"chastisement",
"chastities":"chastity",
"chats":"chat",
"chatted":"chat",
"chatting":"chat",
"chateaus":"chateau",
"chateaux":"chateau",
"chateau-thierries":"chateau-thierry",
"chateuras":"chateura",
"chattanoogas":"chattanooga",
"chattels":"chattel",
"chattered":"chatter",
"chattering":"chatter",
"chatters":"chatter",
"chatterboxes":"chatterbox",
"chatterers":"chatterer",
"chatterings":"chattering",
"chattier":"chatty",
"chattiest":"chatty",
"chaucers":"chaucer",
"chauffers":"chauffer",
"chauffeured":"chauffeur",
"chauffeuring":"chauffeur",
"chauffeurs":"chauffeur",
"chaulmoogras":"chaulmoogra",
"chaulmugras":"chaulmugra",
"chaunas":"chauna",
"chauvinisms":"chauvinism",
"chauvinists":"chauvinist",
"chawed":"chaw",
"chawing":"chaw",
"chaws":"chaw",
"chawbacons":"chawbacon",
"chazanim":"chazan",
"chazans":"chazan",
"cheaper":"cheap",
"cheapest":"cheap",
"cheap-jacks":"cheap-jack",
"cheapened":"cheapen",
"cheapening":"cheapen",
"cheapens":"cheapen",
"cheapnesses":"cheapness",
"cheapskates":"cheapskate",
"cheated":"cheat",
"cheating":"cheat",
"cheats":"cheat",
"cheaters":"cheater",
"cheatgrasses":"cheatgrass",
"cheatings":"cheating",
"Chechens":"Chechen",
"chechoslovaks":"chechoslovak",
"checked":"check",
"checking":"check",
"checks":"check",
"checkbooks":"checkbook",
"checkered":"checker",
"checkering":"checker",
"checkers":"checker",
"checkerberries":"checkerberry",
"checkerblooms":"checkerbloom",
"checkerboards":"checkerboard",
"checkerses":"checkers",
"checkmated":"checkmate",
"checkmating":"checkmate",
"checkouts":"checkout",
"checkreins":"checkrein",
"checkrooms":"checkroom",
"checkups":"checkup",
"cheddars":"cheddar",
"chadarim":"cheder",
"chedarim":"cheder",
"cheeked":"cheek",
"cheeking":"cheek",
"cheeks":"cheek",
"cheekbones":"cheekbone",
"cheekinesses":"cheekiness",
"cheekier":"cheeky",
"cheekiest":"cheeky",
"cheeped":"cheep",
"cheeping":"cheep",
"cheeps":"cheep",
"cheered":"cheer",
"cheering":"cheer",
"cheers":"cheer",
"cheerfulnesses":"cheerfulness",
"cheerings":"cheering",
"cheerios":"cheerio",
"cheerlessnesses":"cheerlessness",
"cheerier":"cheery",
"cheeriest":"cheery",
"cheesed":"cheese",
"cheeses":"cheese",
"cheesing":"cheese",
"cheeseboards":"cheeseboard",
"cheeseflowers":"cheeseflower",
"cheesier":"cheesy",
"cheesiest":"cheesy",
"cheetahs":"cheetah",
"cheewinks":"cheewink",
"chefs":"chef",
"chefs-d'ouvre":"chef-d'ouvre",
"cheilantheses":"cheilanthes",
"cheiloschises":"cheiloschisis",
"cheiloses":"cheilosis",
"cheiranthuses":"cheiranthus",
"chekhovs":"chekhov",
"chekovs":"chekov",
"chelas":"chela",
"chelated":"chelate",
"chelates":"chelate",
"chelating":"chelate",
"chelicerae":"chelicera",
"cheliceratas":"chelicerata",
"chelidoniums":"chelidonium",
"chelifers":"chelifer",
"chelones":"chelone",
"chelonethidas":"chelonethida",
"chelonias":"chelonia",
"chelonians":"chelonian",
"chelonidaes":"chelonidae",
"cheloniidaes":"cheloniidae",
"chelydras":"chelydra",
"chelydridaes":"chelydridae",
"chemicals":"chemical",
"chemises":"chemise",
"chemisorptions":"chemisorption",
"chemists":"chemist",
"chemistries":"chemistry",
"chemosorptions":"chemosorption",
"chens":"chen",
"chenfishes":"chenfish",
"chenopodiaceaes":"chenopodiaceae",
"chenopodialeses":"chenopodiales",
"chenopodiums":"chenopodium",
"chequed":"cheque",
"cheques":"cheque",
"chequing":"cheque",
"chequebooks":"chequebook",
"cheremises":"cheremis",
"cheremisses":"cheremiss",
"cherimollas":"cherimolla",
"cherimoyas":"cherimoya",
"cherished":"cherish",
"cherishes":"cherish",
"cherishing":"cherish",
"chermidaes":"chermidae",
"Cherokees":"Cherokee",
"cherries":"cherry",
"cherrystones":"cherrystone",
"cherubim":"cherub",
"cherubs":"cherub",
"chervils":"chervil",
"chesses":"chess",
"chessboards":"chessboard",
"chessmen":"chessman",
"chests":"chest",
"chestnuts":"chestnut",
"chestier":"chesty",
"chestiest":"chesty",
"chetahs":"chetah",
"cheval-de-frises":"cheval-de-frise",
"chevaliers":"chevalier",
"chevaux-de-frises":"chevaux-de-frise",
"chevres":"chevre",
"chevrons":"chevron",
"chevrotains":"chevrotain",
"chewed":"chew",
"chewing":"chew",
"chews":"chew",
"chewas":"chewa",
"chewings":"chewing",
"chewinks":"chewink",
"chewier":"chewy",
"chewiest":"chewy",
"Cheyennes":"Cheyenne",
"chis":"chi",
"chi-chis":"chi-chi",
"chiaroscuros":"chiaroscuro",
"chiasms":"chiasm",
"chiasmas":"chiasma",
"chiasmata":"chiasma",
"chiasmi":"chiasmus",
"chicer":"chic",
"chicest":"chic",
"chics":"chic",
"chicagos":"chicago",
"chicaned":"chicane",
"chicanes":"chicane",
"chicaning":"chicane",
"chicaneries":"chicanery",
"chicanos":"chicano",
"chiccories":"chiccory",
"chichipes":"chichipe",
"chicks":"chick",
"chickabiddies":"chickabiddy",
"chickamaugas":"chickamauga",
"Chickasaws":"Chickasaw",
"chickens":"chicken",
"chickenfeeds":"chickenfeed",
"chickenpoxes":"chickenpox",
"chickerees":"chickeree",
"chickpeas":"chickpea",
"chickweeds":"chickweed",
"chicles":"chicle",
"chicnesses":"chicness",
"chicos":"chico",
"chicories":"chicory",
"chicots":"chicot",
"chid":"chide",
"chidden":"chide",
"chided":"chide",
"chides":"chide",
"chiding":"chide",
"chidings":"chiding",
"chiefs":"chief",
"chieftains":"chieftain",
"chieftaincies":"chieftaincy",
"chieftainships":"chieftainship",
"chiffons":"chiffon",
"chiffoniers":"chiffonier",
"chigetais":"chigetai",
"chiggers":"chigger",
"chiggerflowers":"chiggerflower",
"chigoes":"chigoe",
"chilblains":"chilblain",
"chilblainses":"chilblains",
"children":"child",
"childbearings":"childbearing",
"childbeds":"childbed",
"childbirths":"childbirth",
"childcares":"childcare",
"childhoods":"childhood",
"childishnesses":"childishness",
"chiles":"chile",
"chilis":"chili",
"chiliads":"chiliad",
"chilled":"chill",
"chiller":"chill",
"chillest":"chill",
"chilling":"chill",
"chills":"chill",
"chillies":"chilli",
"chillis":"chilli",
"chillinesses":"chilliness",
"chillings":"chilling",
"chillier":"chilly",
"chilliest":"chilly",
"chilomastices":"chilomastix",
"chilomastixes":"chilomastix",
"chilomeniscuses":"chilomeniscus",
"chilomycteruses":"chilomycterus",
"chilopodas":"chilopoda",
"chilopses":"chilopsis",
"chimaeras":"chimaera",
"chimaeridaes":"chimaeridae",
"chimaphilas":"chimaphila",
"chimed":"chime",
"chimes":"chime",
"chiming":"chime",
"chimeras":"chimera",
"chimneys":"chimney",
"chimneypieces":"chimneypiece",
"chimneysweeps":"chimneysweep",
"chimneysweepers":"chimneysweeper",
"chimonanthuses":"chimonanthus",
"chimps":"chimp",
"chimpanzees":"chimpanzee",
"chinned":"chin",
"chinning":"chin",
"chins":"chin",
"chin-wags":"chin-wag",
"chin-waggings":"chin-wagging",
"chinas":"china",
"chinaberries":"chinaberry",
"chinamen":"chinaman",
"chincapins":"chincapin",
"chinches":"chinch",
"chincherinchees":"chincherinchee",
"chinchillas":"chinchilla",
"chinchillidaes":"chinchillidae",
"chinchillons":"chinchillon",
"chinchonas":"chinchona",
"chinese_eddoes":"chinese_eddo",
"chingpos":"chingpo",
"chinked":"chink",
"chinking":"chink",
"chinks":"chink",
"chinkapins":"chinkapin",
"chinos":"chino",
"Chinooks":"Chinook",
"chinookans":"chinookan",
"chinquapins":"chinquapin",
"chintzier":"chintzy",
"chintziest":"chintzy",
"chiococcas":"chiococca",
"chionanthuses":"chionanthus",
"chipped":"chip",
"chipping":"chip",
"chips":"chip",
"chipboards":"chipboard",
"chipewyans":"chipewyan",
"chippewas":"chippewa",
"chippewaians":"chippewaian",
"chippeways":"chippeway",
"chippewyans":"chippewyan",
"chippies":"chippie",
"chippings":"chipping",
"chippier":"chippy",
"chippiest":"chippy",
"chirked":"chirk",
"chirking":"chirk",
"chirocephaluses":"chirocephalus",
"chiromancers":"chiromancer",
"chiromancies":"chiromancy",
"chironomidaes":"chironomidae",
"chironomuses":"chironomus",
"chiropodists":"chiropodist",
"chiropodies":"chiropody",
"chiropteras":"chiroptera",
"chiropterans":"chiropteran",
"chirped":"chirp",
"chirping":"chirp",
"chirps":"chirp",
"chirpier":"chirpy",
"chirpiest":"chirpy",
"chirred":"chirr",
"chirring":"chirr",
"chirruped":"chirrup",
"chirruping":"chirrup",
"chirrups":"chirrup",
"chiseled":"chisel",
"chiseling":"chisel",
"chiselled":"chisel",
"chiselling":"chisel",
"chisels":"chisel",
"chiselers":"chiseler",
"chisellers":"chiseller",
"chisinaus":"chisinau",
"chislevs":"chislev",
"chits":"chit",
"chitarroni":"chitarrone",
"chitchats":"chitchat",
"chitchatted":"chitchat",
"chitchatting":"chitchat",
"chitlingses":"chitlings",
"chitlinses":"chitlins",
"chitons":"chiton",
"chittamwoods":"chittamwood",
"chitterlingses":"chitterlings",
"chittimwoods":"chittimwood",
"chivs":"chiv",
"chivved":"chiv",
"chivving":"chiv",
"chivalries":"chivalry",
"chivarees":"chivaree",
"chives":"chive",
"chiveses":"chives",
"chevied":"chivy",
"chevies":"chivy",
"chevying":"chivy",
"chivied":"chivy",
"chivies":"chivy",
"chivvied":"chivy",
"chivvies":"chivy",
"chivvying":"chivy",
"chivying":"chivy",
"chlamyderas":"chlamydera",
"chlamydiaceaes":"chlamydiaceae",
"chlamydomonadaceaes":"chlamydomonadaceae",
"chlamydomonases":"chlamydomonas",
"chlamydosauruses":"chlamydosaurus",
"chlamyphores":"chlamyphore",
"chlamyphoruses":"chlamyphorus",
"chlamyses":"chlamys",
"chloasmas":"chloasma",
"chlorambucils":"chlorambucil",
"chloramines":"chloramine",
"chloramine-ts":"chloramine-t",
"chloramphenicols":"chloramphenicol",
"chloranthaceaes":"chloranthaceae",
"chloranthuses":"chloranthus",
"chlordiazepoxides":"chlordiazepoxide",
"chlorellas":"chlorella",
"chlorides":"chloride",
"chlorinated":"chlorinate",
"chlorinating":"chlorinate",
"chlorines":"chlorine",
"chlorises":"chloris",
"chlorococcaleses":"chlorococcales",
"chlorococcums":"chlorococcum",
"chlorofluorocarbons":"chlorofluorocarbon",
"chloroformed":"chloroform",
"chloroforming":"chloroform",
"chloroforms":"chloroform",
"chloromycetins":"chloromycetin",
"chlorophises":"chlorophis",
"chlorophoneuses":"chlorophoneus",
"chlorophthalmidaes":"chlorophthalmidae",
"chlorophyceaes":"chlorophyceae",
"chlorophyls":"chlorophyl",
"chlorophylls":"chlorophyll",
"chlorophytas":"chlorophyta",
"chlorophytes":"chlorophyte",
"chloroses":"chlorosis",
"chlorothiazides":"chlorothiazide",
"chloroxylons":"chloroxylon",
"chlorpromazines":"chlorpromazine",
"chlortetracyclines":"chlortetracycline",
"chloruras":"chlorura",
"choanocytes":"choanocyte",
"chochos":"chocho",
"chocked":"chock",
"chocking":"chock",
"chocks":"chock",
"chocolates":"chocolate",
"Choctaws":"Choctaw",
"choeronycterises":"choeronycteris",
"choicer":"choice",
"choices":"choice",
"choicest":"choice",
"choicenesses":"choiceness",
"choired":"choir",
"choiring":"choir",
"choirs":"choir",
"choirmasters":"choirmaster",
"choked":"choke",
"chokes":"choke",
"choking":"choke",
"chokeberries":"chokeberry",
"chokecherries":"chokecherry",
"chokedamps":"chokedamp",
"chokers":"choker",
"chokeys":"chokey",
"chokings":"choking",
"chokos":"choko",
"chokier":"choky",
"chokies":"choky",
"chokiest":"choky",
"cholecarciferols":"cholecarciferol",
"cholecystectomies":"cholecystectomy",
"cholers":"choler",
"choleras":"cholera",
"chollas":"cholla",
"choloepuses":"choloepus",
"chomped":"chomp",
"chomping":"chomp",
"chomps":"chomp",
"chondrichthians":"chondrichthian",
"chondrichthyeses":"chondrichthyes",
"chondrified":"chondrify",
"chondrifies":"chondrify",
"chondrifying":"chondrify",
"chondriosomes":"chondriosome",
"chondrodystrophies":"chondrodystrophy",
"chondromas":"chondroma",
"chondromata":"chondroma",
"chondruses":"chondrus",
"choo-choos":"choo-choo",
"chooses":"choose",
"choosing":"choose",
"chose":"choose",
"chosen":"choose",
"choosier":"choosy",
"choosiest":"choosy",
"chopped":"chop",
"chopping":"chop",
"chops":"chop",
"chophouses":"chophouse",
"chopins":"chopin",
"chopines":"chopine",
"chopineses":"chopines",
"choppers":"chopper",
"choppinesses":"choppiness",
"choppier":"choppy",
"choppiest":"choppy",
"chopsteaks":"chopsteak",
"chopsticks":"chopstick",
"chopstickses":"chopsticks",
"choragi":"choragus",
"choraguses":"choragus",
"chorals":"choral",
"chorales":"chorale",
"chorded":"chord",
"chording":"chord",
"chords":"chord",
"chordamesoderms":"chordamesoderm",
"chordatas":"chordata",
"chordeileses":"chordeiles",
"chordomesoderms":"chordomesoderm",
"chordospartiums":"chordospartium",
"chores":"chore",
"choreas":"chorea",
"choreographed":"choreograph",
"choreographing":"choreograph",
"choreographies":"choreography",
"choriambs":"choriamb",
"choriamambi":"choriambus",
"chorines":"chorine",
"chorioallantoises":"chorioallantois",
"choriotises":"choriotis",
"chorizagrotises":"chorizagrotis",
"chorizemas":"chorizema",
"chorizos":"chorizo",
"choroids":"choroid",
"chortled":"chortle",
"chortles":"chortle",
"chortling":"chortle",
"chorused":"chorus",
"choruses":"chorus",
"chorusing":"chorus",
"chosens":"chosen",
"chosons":"choson",
"chous":"chou",
"choused":"chouse",
"chouses":"chouse",
"chousing":"chouse",
"chowed":"chow",
"chowing":"chow",
"chows":"chow",
"chrestomathies":"chrestomathy",
"chrisms":"chrism",
"chrismatories":"chrismatory",
"chrisoms":"chrisom",
"christs":"christ",
"christened":"christen",
"christening":"christen",
"christens":"christen",
"christendoms":"christendom",
"christenings":"christening",
"christianias":"christiania",
"christianities":"christianity",
"christianized":"christianize",
"christianizing":"christianize",
"christmased":"christmas",
"Christmases":"Christmas",
"christmasing":"christmas",
"christmasberries":"christmasberry",
"christmastides":"christmastide",
"christmastimes":"christmastime",
"christologies":"christology",
"christophers":"christopher",
"christies":"christy",
"chromas":"chroma",
"chromaesthesias":"chromaesthesia",
"chromaticities":"chromaticity",
"chromesthesias":"chromesthesia",
"chromiums":"chromium",
"chromos":"chromo",
"chromonemata":"chromonema",
"chronicled":"chronicle",
"chronicles":"chronicle",
"chronicling":"chronicle",
"chroniclers":"chronicler",
"chronologies":"chronology",
"chronoperateses":"chronoperates",
"chrysalids":"chrysalid",
"chrisalides":"chrysalis",
"chrysalides":"chrysalis",
"chrysalises":"chrysalis",
"chrysaoras":"chrysaora",
"chrysarobins":"chrysarobin",
"chrysemyses":"chrysemys",
"chrysobalanuses":"chrysobalanus",
"chrysochloridaes":"chrysochloridae",
"chrysochlorises":"chrysochloris",
"chrysolepises":"chrysolepis",
"chrysolophuses":"chrysolophus",
"chrysomelids":"chrysomelid",
"chrysomelidaes":"chrysomelidae",
"chrysophryses":"chrysophrys",
"chrysophyceaes":"chrysophyceae",
"chrysophyllums":"chrysophyllum",
"chrysophytas":"chrysophyta",
"chrysopids":"chrysopid",
"chrysopidaes":"chrysopidae",
"chrysopses":"chrysopsis",
"chrysospleniums":"chrysosplenium",
"chrysothamnuses":"chrysothamnus",
"chubs":"chub",
"chubbinesses":"chubbiness",
"chubbier":"chubby",
"chubbiest":"chubby",
"chucked":"chuck",
"chucking":"chuck",
"chucks":"chuck",
"chucker-outs":"chucker-out",
"chuckholes":"chuckhole",
"chuckled":"chuckle",
"chuckles":"chuckle",
"chuckling":"chuckle",
"chuckwallas":"chuckwalla",
"chufas":"chufa",
"chuffier":"chuffy",
"chuffiest":"chuffy",
"chugged":"chug",
"chugging":"chug",
"chugs":"chug",
"chug-a-lugged":"chug-a-lug",
"chug-a-lugging":"chug-a-lug",
"chummed":"chum",
"chumming":"chum",
"chums":"chum",
"chumminesses":"chumminess",
"chummier":"chummy",
"chummiest":"chummy",
"chumps":"chump",
"chungas":"chunga",
"chunked":"chunk",
"chunking":"chunk",
"chunks":"chunk",
"chunkier":"chunky",
"chunkiest":"chunky",
"chunnels":"chunnel",
"churched":"church",
"churches":"church",
"churching":"church",
"churchgoers":"churchgoer",
"churchills":"churchill",
"churchmen":"churchman",
"churchwomen":"churchwoman",
"churchier":"churchy",
"churchiest":"churchy",
"churchyards":"churchyard",
"churingas":"churinga",
"churls":"churl",
"churned":"churn",
"churning":"churn",
"churns":"churn",
"churred":"churr",
"churring":"churr",
"churrs":"churr",
"chutes":"chute",
"chute-the-chutes":"chute-the-chute",
"chutneys":"chutney",
"chutzpahs":"chutzpah",
"chuvashes":"chuvash",
"chylodermas":"chyloderma",
"chymosins":"chymosin",
"chytridiaceaes":"chytridiaceae",
"chytridialeses":"chytridiales",
"chytridiomyceteses":"chytridiomycetes",
"cis":"ci",
"cias":"cia",
"ciaos":"ciao",
"ciboria":"ciborium",
"cibotiums":"cibotium",
"cicadae":"cicada",
"cicadas":"cicada",
"cicadellidaes":"cicadellidae",
"cicadidaes":"cicadidae",
"cicalas":"cicala",
"cicatrices":"cicatrice",
"cicelies":"cicely",
"cicers":"cicer",
"ciceros":"cicero",
"cicerones":"cicerone",
"ciceroni":"cicerone",
"cichlids":"cichlid",
"cichlidaes":"cichlidae",
"cichoriums":"cichorium",
"cicindelidaes":"cicindelidae",
"cicisbei":"cicisbeo",
"ciconias":"ciconia",
"ciconiidaes":"ciconiidae",
"ciconiiformeses":"ciconiiformes",
"cicutas":"cicuta",
"ciders":"cider",
"cigs":"cig",
"cigars":"cigar",
"cigarets":"cigaret",
"cigarettes":"cigarette",
"cigarfishes":"cigarfish",
"cigarillos":"cigarillo",
"ciggies":"ciggy",
"cilantros":"cilantro",
"ciliatas":"ciliata",
"ciliates":"ciliate",
"cilioflagellatas":"cilioflagellata",
"ciliophoras":"ciliophora",
"ciliophorans":"ciliophoran",
"cilia":"cilium",
"ciliums":"cilium",
"cimabues":"cimabue",
"cimarrons":"cimarron",
"cimetidines":"cimetidine",
"cimexes":"cimex",
"cimices":"cimex",
"cimicidaes":"cimicidae",
"cimicifugas":"cimicifuga",
"cinched":"cinch",
"cinches":"cinch",
"cinching":"cinch",
"cinchonas":"cinchona",
"cinclidaes":"cinclidae",
"cincluses":"cinclus",
"cinctured":"cincture",
"cinctures":"cincture",
"cincturing":"cincture",
"cinders":"cinder",
"cinderellas":"cinderella",
"cines":"cine",
"cine-cameras":"cine-camera",
"cine-films":"cine-film",
"cinemas":"cinema",
"cinematized":"cinematize",
"cinematizing":"cinematize",
"cinematographers":"cinematographer",
"cinematographies":"cinematography",
"cinerarias":"cineraria",
"cineraria":"cinerarium",
"cingula":"cingulum",
"cinnabars":"cinnabar",
"cinnamenes":"cinnamene",
"cinnamomums":"cinnamomum",
"cinnamons":"cinnamon",
"cinques":"cinque",
"cinquefoils":"cinquefoil",
"ciphered":"cipher",
"ciphering":"cipher",
"ciphers":"cipher",
"cipros":"cipro",
"ciprofloxacins":"ciprofloxacin",
"circaeas":"circaea",
"circaetuses":"circaetus",
"circled":"circle",
"circles":"circle",
"circling":"circle",
"circuited":"circuit",
"circuiting":"circuit",
"circuits":"circuit",
"circuities":"circuity",
"circulars":"circular",
"circularisations":"circularisation",
"circularities":"circularity",
"circularizations":"circularization",
"circularized":"circularize",
"circularizes":"circularize",
"circularizing":"circularize",
"circulated":"circulate",
"circulates":"circulate",
"circulating":"circulate",
"circulations":"circulation",
"circulators":"circulator",
"circumambulated":"circumambulate",
"circumambulates":"circumambulate",
"circumambulating":"circumambulate",
"circumcised":"circumcise",
"circumcising":"circumcise",
"circumferences":"circumference",
"circumferentials":"circumferential",
"circumfrsed":"circumfuse",
"circumfused":"circumfuse",
"circumfusing":"circumfuse",
"circumlocutions":"circumlocution",
"circumnavigated":"circumnavigate",
"circumnavigates":"circumnavigate",
"circumnavigating":"circumnavigate",
"circumnutated":"circumnutate",
"circumnutating":"circumnutate",
"circumrotated":"circumrotate",
"circumrotating":"circumrotate",
"circumscribed":"circumscribe",
"circumscribes":"circumscribe",
"circumscribing":"circumscribe",
"circumspections":"circumspection",
"circumstances":"circumstance",
"circumstanceses":"circumstances",
"circumstantiated":"circumstantiate",
"circumstantiating":"circumstantiate",
"circumvented":"circumvent",
"circumventing":"circumvent",
"circumvents":"circumvent",
"circumvolved":"circumvolve",
"circumvolving":"circumvolve",
"circuses":"circus",
"cirios":"cirio",
"cirques":"cirque",
"cirrhoses":"cirrhosis",
"cirrhuses":"cirrhus",
"cirripedias":"cirripedia",
"cirrocumuli":"cirrocumulus",
"cirrocumuluses":"cirrocumulus",
"cirrostrati":"cirrostratus",
"cirrostratuses":"cirrostratus",
"cirri":"cirrus",
"cirruses":"cirrus",
"cirsiums":"cirsium",
"cises":"cis",
"ciscs":"cisc",
"ciscoes":"cisco",
"ciscos":"cisco",
"cistaceaes":"cistaceae",
"cistercians":"cistercian",
"cisterns":"cistern",
"cisternas":"cisterna",
"cistothoruses":"cistothorus",
"cistuses":"cistus",
"citadels":"citadel",
"citations":"citation",
"cited":"cite",
"cites":"cite",
"citing":"cite",
"citelluses":"citellus",
"citharichthyses":"citharichthys",
"cithers":"cither",
"citified":"citify",
"citifies":"citify",
"citifying":"citify",
"citizens":"citizen",
"citizenries":"citizenry",
"citlaltepetls":"citlaltepetl",
"citranges":"citrange",
"citrins":"citrin",
"citrons":"citron",
"citronciruses":"citroncirus",
"citronwoods":"citronwood",
"citrulluses":"citrullus",
"citruses":"citrus",
"cities":"city",
"cives":"cive",
"civets":"civet",
"civieses":"civies",
"civilians":"civilian",
"civilities":"civility",
"civilizations":"civilization",
"civilized":"civilize",
"civilizes":"civilize",
"civilizing":"civilize",
"civvieses":"civvies",
"civies":"civvy",
"civvies":"civvy",
"cls":"cl",
"clabbered":"clabber",
"clabbering":"clabber",
"clabbers":"clabber",
"clacked":"clack",
"clacking":"clack",
"clacks":"clack",
"cladding":"clad",
"clads":"clad",
"claddings":"cladding",
"cladodes":"cladode",
"cladonias":"cladonia",
"cladoniaceaes":"cladoniaceae",
"cladophylls":"cladophyll",
"cladorhyncuses":"cladorhyncus",
"cladrastises":"cladrastis",
"claforans":"claforan",
"claimed":"claim",
"claiming":"claim",
"claims":"claim",
"claimants":"claimant",
"clairvoyances":"clairvoyance",
"clammed":"clam",
"clamming":"clam",
"clams":"clam",
"clamatoreses":"clamatores",
"clambered":"clamber",
"clambering":"clamber",
"clambers":"clamber",
"clamminesses":"clamminess",
"clammier":"clammy",
"clammiest":"clammy",
"clammyweeds":"clammyweed",
"clamored":"clamor",
"clamoring":"clamor",
"clamors":"clamor",
"clamorings":"clamoring",
"clamours":"clamour",
"clamourings":"clamouring",
"clamped":"clamp",
"clamping":"clamp",
"clamps":"clamp",
"clamshells":"clamshell",
"clans":"clan",
"clanged":"clang",
"clanging":"clang",
"clangs":"clang",
"clangored":"clangor",
"clangoring":"clangor",
"clangors":"clangor",
"clangorings":"clangoring",
"clangours":"clangour",
"clangulas":"clangula",
"clanked":"clank",
"clanking":"clank",
"clanks":"clank",
"clannishnesses":"clannishness",
"clansmen":"clansman",
"clanswomen":"clanswoman",
"clapped":"clap",
"clapping":"clap",
"claps":"clap",
"clapboards":"clapboard",
"clappers":"clapper",
"clapperses":"clappers",
"clappings":"clapping",
"claptraps":"claptrap",
"clarets":"claret",
"clarifications":"clarification",
"clarified":"clarify",
"clarifies":"clarify",
"clarifying":"clarify",
"clarinetists":"clarinetist",
"clarinettists":"clarinettist",
"clani":"clarino",
"clanos":"clarino",
"clarities":"clarity",
"claroes":"claro",
"claros":"claro",
"claries":"clary",
"clashed":"clash",
"clashes":"clash",
"clashing":"clash",
"clasped":"clasp",
"clasping":"clasp",
"clasps":"clasp",
"classed":"class",
"classes":"class",
"classing":"class",
"classics":"classic",
"classicized":"classicize",
"classicizing":"classicize",
"classifications":"classification",
"classified":"classify",
"classifies":"classify",
"classifying":"classify",
"classmates":"classmate",
"classrooms":"classroom",
"classier":"classy",
"classiest":"classy",
"clathraceaes":"clathraceae",
"clathruses":"clathrus",
"clattered":"clatter",
"clattering":"clatter",
"clatters":"clatter",
"claudications":"claudication",
"clauses":"clause",
"clavariaceaes":"clavariaceae",
"clavicembalos":"clavicembalo",
"clavicepses":"claviceps",
"clavicipitaceaes":"clavicipitaceae",
"clavicles":"clavicle",
"claviers":"clavier",
"clavuses":"clavus",
"clawed":"claw",
"clawing":"claw",
"claws":"claw",
"clawfeet":"clawfoot",
"clawhammers":"clawhammer",
"claxons":"claxon",
"clays":"clay",
"clayier":"clayey",
"clayiest":"clayey",
"claytonias":"claytonia",
"claywares":"clayware",
"cleaned":"clean",
"cleaner":"clean",
"cleanest":"clean",
"cleaning":"clean",
"cleans":"clean",
"cleaners":"cleaner",
"cleanerses":"cleaners",
"cleanings":"cleaning",
"cleanlier":"cleanly",
"cleanliest":"cleanly",
"cleansed":"cleanse",
"cleanses":"cleanse",
"cleansing":"cleanse",
"cleansers":"cleanser",
"cleansings":"cleansing",
"cleanups":"cleanup",
"cleared":"clear",
"clearer":"clear",
"clearest":"clear",
"clearing":"clear",
"clears":"clear",
"clearances":"clearance",
"clearcutnesses":"clearcutness",
"clearings":"clearing",
"clearinghouses":"clearinghouse",
"clearnesses":"clearness",
"clearstories":"clearstory",
"clearweeds":"clearweed",
"cleated":"cleat",
"cleating":"cleat",
"cleats":"cleat",
"cleavages":"cleavage",
"cleaved":"cleave",
"cleaves":"cleave",
"cleaving":"cleave",
"cleft":"cleave",
"clove":"cleave",
"cloven":"cleave",
"cleavers":"cleaver",
"cleaverses":"cleavers",
"clefts":"cleft",
"clegs":"cleg",
"cleggs":"clegg",
"cleisteses":"cleistes",
"cleistocarps":"cleistocarp",
"cleistotheciums":"cleistothecium",
"clemmed":"clem",
"clemming":"clem",
"clems":"clem",
"clemencies":"clemency",
"clementines":"clementine",
"clenched":"clench",
"clenches":"clench",
"clenching":"clench",
"cleomes":"cleome",
"cleped":"clepe",
"clepes":"clepe",
"cleping":"clepe",
"clept":"clepe",
"ycleped":"clepe",
"yclept":"clepe",
"clepsydrae":"clepsydra",
"clepsydras":"clepsydra",
"clerestories":"clerestory",
"clergies":"clergy",
"clergymen":"clergyman",
"clergywomen":"clergywoman",
"clerics":"cleric",
"clericals":"clerical",
"clerids":"clerid",
"cleridaes":"cleridae",
"clerisies":"clerisy",
"clerked":"clerk",
"clerking":"clerk",
"clerks":"clerk",
"clerkings":"clerking",
"clerklier":"clerkly",
"clerkliest":"clerkly",
"cleruchies":"cleruchy",
"clethras":"clethra",
"clethraceaes":"clethraceae",
"clethrionomyses":"clethrionomys",
"clevelands":"cleveland",
"cleverer":"clever",
"cleverest":"clever",
"clevernesses":"cleverness",
"clewed":"clew",
"clewing":"clew",
"clews":"clew",
"clis":"cli",
"clianthuses":"clianthus",
"cliches":"cliche",
"clicked":"click",
"clicking":"click",
"clicks":"click",
"clickety-clacks":"clickety-clack",
"clickety-clicks":"clickety-click",
"clients":"client",
"clienteles":"clientele",
"cliffs":"cliff",
"cliffbrakes":"cliffbrake",
"cliftonias":"cliftonia",
"climacterics":"climacteric",
"climates":"climate",
"climaxed":"climax",
"climaxes":"climax",
"climaxing":"climax",
"climbed":"climb",
"climbing":"climb",
"climbs":"climb",
"climb-downs":"climb-down",
"climbers":"climber",
"climbings":"climbing",
"climes":"clime",
"clinandria":"clinandrium",
"clinched":"clinch",
"clinches":"clinch",
"clinching":"clinch",
"clinchers":"clincher",
"clinging":"cling",
"clings":"cling",
"clung":"cling",
"clingfishes":"clingfish",
"clingstones":"clingstone",
"clingier":"clingy",
"clingiest":"clingy",
"clinics":"clinic",
"clinids":"clinid",
"clinidaes":"clinidae",
"clinked":"clink",
"clinking":"clink",
"clinks":"clink",
"clinkers":"clinker",
"clinocephalisms":"clinocephalism",
"clinocephalies":"clinocephaly",
"clinometers":"clinometer",
"clinopodiums":"clinopodium",
"clinorils":"clinoril",
"clintons":"clinton",
"clintonias":"clintonia",
"clipped":"clip",
"clipping":"clip",
"clips":"clip",
"clippers":"clipper",
"clipperses":"clippers",
"clippings":"clipping",
"cliqued":"clique",
"cliques":"clique",
"cliquing":"clique",
"cliquishnesses":"cliquishness",
"clits":"clit",
"clitella":"clitellum",
"clitocybes":"clitocybe",
"clitorias":"clitoria",
"clitores":"clitoris",
"clitorises":"clitoris",
"cliverses":"clivers",
"cloacas":"cloaca",
"cloaked":"cloak",
"cloaking":"cloak",
"cloaks":"cloak",
"cloakmakers":"cloakmaker",
"cloakrooms":"cloakroom",
"clobbered":"clobber",
"clobbering":"clobber",
"clobbers":"clobber",
"clocked":"clock",
"clocking":"clock",
"clocks":"clock",
"clockmakers":"clockmaker",
"clockses":"clocks",
"clocksmiths":"clocksmith",
"clods":"clod",
"clodhoppers":"clodhopper",
"clofibrates":"clofibrate",
"clogged":"clog",
"clogging":"clog",
"clogs":"clog",
"cloggier":"cloggy",
"cloggiest":"cloggy",
"cloistered":"cloister",
"cloistering":"cloister",
"cloisters":"cloister",
"clomids":"clomid",
"clomiphenes":"clomiphene",
"clomped":"clomp",
"clomping":"clomp",
"clomps":"clomp",
"clons":"clon",
"clones":"clone",
"clonidines":"clonidine",
"clonuses":"clonus",
"clopped":"clop",
"clopping":"clop",
"clops":"clop",
"closed":"close",
"closer":"close",
"closes":"close",
"closest":"close",
"closing":"close",
"close-ups":"close-up",
"closedowns":"closedown",
"closenesses":"closeness",
"closeouts":"closeout",
"closeted":"closet",
"closeting":"closet",
"closets":"closet",
"closings":"closing",
"clostridias":"clostridia",
"clostridiums":"clostridium",
"closured":"closure",
"closures":"closure",
"closuring":"closure",
"clots":"clot",
"clotted":"clot",
"clotting":"clot",
"clotburs":"clotbur",
"cloths":"cloth",
"clad":"clothe",
"clothed":"clothe",
"clothes":"clothes",
"clothing":"clothe",
"clotheshorses":"clotheshorse",
"clothespins":"clothespin",
"clothespresses":"clothespress",
"clothiers":"clothier",
"clothings":"clothing",
"clottings":"clotting",
"clotures":"cloture",
"clouded":"cloud",
"clouding":"cloud",
"clouds":"cloud",
"cloudberries":"cloudberry",
"cloudbursts":"cloudburst",
"cloudinesses":"cloudiness",
"cloudings":"clouding",
"cloudier":"cloudy",
"cloudiest":"cloudy",
"clouted":"clout",
"clouting":"clout",
"clouts":"clout",
"cloves":"clove",
"clovers":"clover",
"cloverleafs":"cloverleaf",
"cloverleaves":"cloverleaf",
"cloveroots":"cloveroot",
"clovises":"clovis",
"clowned":"clown",
"clowning":"clown",
"clowns":"clown",
"clownings":"clowning",
"cloyed":"cloy",
"cloying":"cloy",
"cloys":"cloy",
"clubbed":"club",
"clubbing":"club",
"clubs":"club",
"clubbier":"clubby",
"clubbiest":"clubby",
"clubfeet":"clubfoot",
"clubheads":"clubhead",
"clubhouses":"clubhouse",
"clubmen":"clubman",
"clubmosses":"clubmoss",
"clubwomen":"clubwoman",
"clucked":"cluck",
"clucking":"cluck",
"clucks":"cluck",
"clued":"clue",
"clues":"clue",
"cluing":"clue",
"clumbers":"clumber",
"clumped":"clump",
"clumping":"clump",
"clumps":"clump",
"clumsinesses":"clumsiness",
"clumsier":"clumsy",
"clumsiest":"clumsy",
"clunks":"clunk",
"clupeas":"clupea",
"clupeids":"clupeid",
"clupeidaes":"clupeidae",
"clusiaceaes":"clusiaceae",
"clustered":"cluster",
"clustering":"cluster",
"clusters":"cluster",
"clutched":"clutch",
"clutches":"clutch",
"clutching":"clutch",
"clutcheses":"clutches",
"cluttered":"clutter",
"cluttering":"clutter",
"clutters":"clutter",
"clypei":"clypeus",
"clysters":"clyster",
"cms":"cm",
"cnemidophoruses":"cnemidophorus",
"cnicuses":"cnicus",
"cnidarias":"cnidaria",
"cnidarians":"cnidarian",
"cnidoscoluses":"cnidoscolus",
"cnidosporidias":"cnidosporidia",
"cnses":"cns",
"cos":"co",
"co-eds":"co-ed",
"co-occurrences":"co-occurrence",
"co-ops":"co-op",
"co-opted":"co-opt",
"co-opting":"co-opt",
"co-optations":"co-optation",
"co-options":"co-option",
"co-starred":"co-star",
"co-starring":"co-star",
"co-stars":"co-star",
"co-workers":"co-worker",
"coached":"coach",
"coaches":"coach",
"coaching":"coach",
"coach-and-fours":"coach-and-four",
"coachings":"coaching",
"coachmen":"coachman",
"coachwhips":"coachwhip",
"coacted":"coact",
"coacting":"coact",
"coactions":"coaction",
"coagulated":"coagulate",
"coagulates":"coagulate",
"coagulating":"coagulate",
"coagulations":"coagulation",
"coagula":"coagulum",
"coagulums":"coagulum",
"coaled":"coal",
"coaling":"coal",
"coals":"coal",
"coalbins":"coalbin",
"coalesced":"coalesce",
"coalesces":"coalesce",
"coalescing":"coalesce",
"coalescences":"coalescence",
"coalescencies":"coalescency",
"coalfishes":"coalfish",
"coalholes":"coalhole",
"coalitions":"coalition",
"coalmines":"coalmine",
"coalpits":"coalpit",
"coarser":"coarse",
"coarsest":"coarse",
"coarsened":"coarsen",
"coarsening":"coarsen",
"coarsenesses":"coarseness",
"coarsenings":"coarsening",
"coasted":"coast",
"coasting":"coast",
"coasts":"coast",
"coated":"coat",
"coating":"coat",
"coats":"coat",
"coatis":"coati",
"coati-mondis":"coati-mondi",
"coati-mundis":"coati-mundi",
"coatings":"coating",
"coatracks":"coatrack",
"coatrooms":"coatroom",
"coattailses":"coattails",
"coauthors":"coauthor",
"coaxed":"coax",
"coaxes":"coax",
"coaxing":"coax",
"coaxings":"coaxing",
"cobs":"cob",
"cobalamins":"cobalamin",
"cobalts":"cobalt",
"cobbled":"cobble",
"cobbles":"cobble",
"cobbling":"cobble",
"cobblers":"cobbler",
"cobblestones":"cobblestone",
"cobblings":"cobbling",
"cobias":"cobia",
"cobitidaes":"cobitidae",
"cobnuts":"cobnut",
"cobras":"cobra",
"cobwebbed":"cobweb",
"cobwebbing":"cobweb",
"cobwebs":"cobweb",
"cocas":"coca",
"cocains":"cocain",
"cocaines":"cocaine",
"coccis":"cocci",
"coccidaes":"coccidae",
"coccidias":"coccidia",
"coccidioidomycoses":"coccidioidomycosis",
"coccidiomycoses":"coccidiomycosis",
"coccidiums":"coccidium",
"coccinellidaes":"coccinellidae",
"coccoideas":"coccoidea",
"coccothrausteses":"coccothraustes",
"cocculuses":"cocculus",
"cocci":"coccus",
"coccuses":"coccus",
"coccyges":"coccyx",
"coccyxes":"coccyx",
"coccyzuses":"coccyzus",
"cochins":"cochin",
"cochineals":"cochineal",
"cochleae":"cochlea",
"cochleas":"cochlea",
"cochlearias":"cochlearia",
"cochleariuses":"cochlearius",
"cocked":"cock",
"cocking":"cock",
"cocks":"cock",
"cock-a-leekies":"cock-a-leekie",
"cockateels":"cockateel",
"cockatiels":"cockatiel",
"cockatoos":"cockatoo",
"cockchafers":"cockchafer",
"cockcrows":"cockcrow",
"cockered":"cocker",
"cockering":"cocker",
"cockers":"cocker",
"cockeyes":"cockeye",
"cockhorses":"cockhorse",
"cockinesses":"cockiness",
"cockled":"cockle",
"cockles":"cockle",
"cockling":"cockle",
"cockleburs":"cocklebur",
"cockleburrs":"cockleburr",
"cockneys":"cockney",
"cockneyfied":"cockneyfy",
"cockneyfies":"cockneyfy",
"cockneyfying":"cockneyfy",
"cockpits":"cockpit",
"cockroaches":"cockroach",
"cockscombs":"cockscomb",
"cocksfeet":"cocksfoot",
"cocksfoots":"cocksfoot",
"cockshies":"cockshy",
"cockspurs":"cockspur",
"cocksuckers":"cocksucker",
"cocksurenesses":"cocksureness",
"cocktails":"cocktail",
"cockups":"cockup",
"cockier":"cocky",
"cockiest":"cocky",
"cocky-leekies":"cocky-leeky",
"cocos":"coco",
"cocoas":"cocoa",
"cocoanuts":"cocoanut",
"cocobolos":"cocobolo",
"coconspirators":"coconspirator",
"coconuts":"coconut",
"cocooned":"cocoon",
"cocooning":"cocoon",
"cocoons":"cocoon",
"cocopas":"cocopa",
"cocopahs":"cocopah",
"cocoses":"cocos",
"cocoswoods":"cocoswood",
"cocottes":"cocotte",
"cocoyams":"cocoyam",
"cocozelles":"cocozelle",
"cocuswoods":"cocuswood",
"cocytuses":"cocytus",
"codded":"cod",
"codding":"cod",
"cods":"cod",
"codas":"coda",
"codariocalyxes":"codariocalyx",
"coddled":"coddle",
"coddles":"coddle",
"coddling":"coddle",
"coded":"code",
"codes":"code",
"coding":"code",
"codices":"codex",
"codfishes":"codfish",
"codgers":"codger",
"codiaeums":"codiaeum",
"codifications":"codification",
"codified":"codify",
"codifies":"codify",
"codifying":"codify",
"codlins-and-creams":"codlins-and-cream",
"coelacanths":"coelacanth",
"coelenteratas":"coelenterata",
"coelenterates":"coelenterate",
"coelentera":"coelenteron",
"coeloglossums":"coeloglossum",
"coelomata":"coelom",
"coeloms":"coelom",
"coenobites":"coenobite",
"coenuri":"coenurus",
"coerced":"coerce",
"coerces":"coerce",
"coercing":"coerce",
"coercions":"coercion",
"coerebas":"coereba",
"coerebidaes":"coerebidae",
"coevals":"coeval",
"coevalses":"coevals",
"coexisted":"coexist",
"coexisting":"coexist",
"coextended":"coextend",
"coextending":"coextend",
"coffeas":"coffea",
"coffees":"coffee",
"coffeeberries":"coffeeberry",
"coffeecakes":"coffeecake",
"coffeehouses":"coffeehouse",
"coffered":"coffer",
"coffering":"coffer",
"coffers":"coffer",
"cofferdams":"cofferdam",
"coffined":"coffin",
"coffining":"coffin",
"coffins":"coffin",
"cogged":"cog",
"cogging":"cog",
"cogs":"cog",
"cogencies":"cogency",
"cogitated":"cogitate",
"cogitates":"cogitate",
"cogitating":"cogitate",
"cogitations":"cogitation",
"cognates":"cognate",
"cognations":"cognation",
"cognitions":"cognition",
"cognizances":"cognizance",
"cognized":"cognize",
"cognizes":"cognize",
"cognizing":"cognize",
"cognomens":"cognomen",
"cognoscenti":"cognoscente",
"cognoscentis":"cognoscenti",
"cogwheels":"cogwheel",
"cohabited":"cohabit",
"cohabiting":"cohabit",
"cohabits":"cohabit",
"cohabitations":"cohabitation",
"cohered":"cohere",
"coheres":"cohere",
"cohering":"cohere",
"coherences":"coherence",
"coherencies":"coherency",
"coherers":"coherer",
"cohesions":"cohesion",
"cohesivenesses":"cohesiveness",
"cohos":"coho",
"cohoes":"cohoe",
"cohoshes":"cohosh",
"cohunes":"cohune",
"coifed":"coif",
"coiffed":"coif",
"coiffing":"coif",
"coifing":"coif",
"coifs":"coif",
"coiffeurs":"coiffeur",
"coiffured":"coiffure",
"coiffures":"coiffure",
"coiffuring":"coiffure",
"coigns":"coign",
"coignes":"coigne",
"coigues":"coigue",
"coiled":"coil",
"coiling":"coil",
"coils":"coil",
"coined":"coin",
"coining":"coin",
"coins":"coin",
"coinages":"coinage",
"coincided":"coincide",
"coincides":"coincide",
"coinciding":"coincide",
"coincidences":"coincidence",
"coinsured":"coinsure",
"coinsuring":"coinsure",
"coitions":"coition",
"coituses":"coitus",
"coked":"coke",
"cokes":"coke",
"coking":"coke",
"cols":"col",
"colas":"cola",
"colanders":"colander",
"colapteses":"colaptes",
"colberts":"colbert",
"colchicaceaes":"colchicaceae",
"colchicums":"colchicum",
"colder":"cold",
"coldest":"cold",
"colds":"cold",
"cold-shouldered":"cold-shoulder",
"cold-shouldering":"cold-shoulder",
"cold-shoulders":"cold-shoulder",
"coldheartednesses":"coldheartedness",
"coldnesses":"coldness",
"coles":"cole",
"colectomies":"colectomy",
"coleonyxes":"coleonyx",
"coleopteras":"coleoptera",
"coleorhizae":"coleorhiza",
"coleridges":"coleridge",
"coleslaws":"coleslaw",
"coleuses":"coleus",
"coleworts":"colewort",
"colics":"colic",
"colicroots":"colicroot",
"colimas":"colima",
"colinuses":"colinus",
"coliseums":"coliseum",
"collaborated":"collaborate",
"collaborates":"collaborate",
"collaborating":"collaborate",
"collaborations":"collaboration",
"collaborationists":"collaborationist",
"collaborators":"collaborator",
"collages":"collage",
"collapsed":"collapse",
"collapses":"collapse",
"collapsing":"collapse",
"collared":"collar",
"collaring":"collar",
"collars":"collar",
"collarbones":"collarbone",
"collardses":"collards",
"collated":"collate",
"collates":"collate",
"collating":"collate",
"collaterals":"collateral",
"collateralized":"collateralize",
"collateralizing":"collateralize",
"collations":"collation",
"colleagued":"colleague",
"colleagues":"colleague",
"colleaguing":"colleague",
"collected":"collect",
"collecting":"collect",
"collects":"collect",
"collectings":"collecting",
"collections":"collection",
"collectives":"collective",
"collectivisations":"collectivisation",
"collectivisms":"collectivism",
"collectivists":"collectivist",
"collectivities":"collectivity",
"collectivizations":"collectivization",
"collectivized":"collectivize",
"collectivizes":"collectivize",
"collectivizing":"collectivize",
"collectors":"collector",
"colleges":"college",
"collegians":"collegian",
"collegigia":"collegium",
"collegigiums":"collegium",
"collembolas":"collembola",
"collembolans":"collembolan",
"collets":"collet",
"collided":"collide",
"collides":"collide",
"colliding":"collide",
"collies":"collie",
"colliers":"collier",
"collieries":"colliery",
"colligated":"colligate",
"colligates":"colligate",
"colligating":"colligate",
"collimated":"collimate",
"collimates":"collimate",
"collimating":"collimate",
"collinses":"collins",
"collinsias":"collinsia",
"collinsonias":"collinsonia",
"collisions":"collision",
"collocalias":"collocalia",
"collocated":"collocate",
"collocates":"collocate",
"collocating":"collocate",
"collogued":"collogue",
"collogues":"collogue",
"colloguing":"collogue",
"colloquialisms":"colloquialism",
"colloquia":"colloquium",
"colloquiums":"colloquium",
"colloquies":"colloquy",
"collotypes":"collotype",
"colluded":"collude",
"colludes":"collude",
"colluding":"collude",
"collusions":"collusion",
"colluvia":"colluvium",
"colluviums":"colluvium",
"collied":"colly",
"collier":"colly",
"colliest":"colly",
"collying":"colly",
"collyria":"collyrium",
"collyriums":"collyrium",
"colobuses":"colobus",
"colocasias":"colocasia",
"colognes":"cologne",
"colombos":"colombo",
"cola":"colon",
"colons":"colon",
"colonials":"colonial",
"colonics":"colonic",
"colonisations":"colonisation",
"colonists":"colonist",
"colonizations":"colonization",
"colonized":"colonize",
"colonizing":"colonize",
"colonizers":"colonizer",
"colonnades":"colonnade",
"colonies":"colony",
"colored":"color",
"coloring":"color",
"colors":"color",
"coloradillos":"coloradillo",
"colorados":"colorado",
"colorcasting":"colorcast",
"coloreds":"colored",
"colorimeters":"colorimeter",
"colorimetries":"colorimetry",
"colorings":"coloring",
"colorlessnesses":"colorlessness",
"colorses":"colors",
"colossi":"colossus",
"colossuses":"colossus",
"colostomies":"colostomy",
"colostrums":"colostrum",
"colotomies":"colotomy",
"coloured":"colour",
"colouring":"colour",
"colours":"colour",
"coloureds":"coloured",
"colourimeters":"colourimeter",
"colourings":"colouring",
"colourmen":"colourman",
"colourses":"colours",
"colpoceles":"colpocele",
"colpocystoceles":"colpocystocele",
"colted":"colt",
"colting":"colt",
"colts":"colt",
"colters":"colter",
"coltsfoots":"coltsfoot",
"colubers":"coluber",
"colubrids":"colubrid",
"colubridaes":"colubridae",
"colubrinas":"colubrina",
"colugos":"colugo",
"columbas":"columba",
"columbariums":"columbarium",
"columbias":"columbia",
"columbidaes":"columbidae",
"columbiformeses":"columbiformes",
"columbines":"columbine",
"columbites":"columbite",
"columbos":"columbo",
"columbuses":"columbus",
"columellae":"columella",
"columns":"column",
"columnists":"columnist",
"coluteas":"colutea",
"colies":"coly",
"colymbiformeses":"colymbiformes",
"colzas":"colza",
"comas":"coma",
"Comanches":"Comanche",
"comandras":"comandra",
"comaraderies":"comaraderie",
"comatosenesses":"comatoseness",
"comatulae":"comatula",
"comatulids":"comatulid",
"combed":"comb",
"combing":"comb",
"combs":"comb",
"comb-outs":"comb-out",
"combated":"combat",
"combating":"combat",
"combats":"combat",
"combatted":"combat",
"combatting":"combat",
"combatants":"combatant",
"combativenesses":"combativeness",
"combinations":"combination",
"combined":"combine",
"combines":"combine",
"combining":"combine",
"combings":"combing",
"combinings":"combining",
"combos":"combo",
"combretaceaes":"combretaceae",
"combustibles":"combustible",
"combustions":"combustion",
"came":"come",
"comes":"come",
"coming":"come",
"come-ons":"come-on",
"comebacks":"comeback",
"comedians":"comedian",
"comedones":"comedo",
"comedos":"comedo",
"comedies":"comedy",
"comelinesses":"comeliness",
"comelier":"comely",
"comeliest":"comely",
"comers":"comer",
"comestibles":"comestible",
"comets":"comet",
"comforted":"comfort",
"comforting":"comfort",
"comforts":"comfort",
"comfortables":"comfortable",
"comfortablenesses":"comfortableness",
"comforters":"comforter",
"comfortses":"comforts",
"comfreys":"comfrey",
"comfier":"comfy",
"comfiest":"comfy",
"comics":"comic",
"comings":"coming",
"comints":"comint",
"comities":"comity",
"commas":"comma",
"commanded":"command",
"commanding":"command",
"commands":"command",
"commandants":"commandant",
"commandeered":"commandeer",
"commandeering":"commandeer",
"commandeers":"commandeer",
"commanders":"commander",
"commandments":"commandment",
"commandoes":"commando",
"commandos":"commando",
"commelinaceaes":"commelinaceae",
"commelinaleses":"commelinales",
"commelinidaes":"commelinidae",
"commemorated":"commemorate",
"commemorates":"commemorate",
"commemorating":"commemorate",
"commemorations":"commemoration",
"commenced":"commence",
"commences":"commence",
"commencing":"commence",
"commencements":"commencement",
"commended":"commend",
"commending":"commend",
"commends":"commend",
"commendations":"commendation",
"commensuratenesses":"commensurateness",
"commented":"comment",
"commenting":"comment",
"comments":"comment",
"commentaries":"commentary",
"commentated":"commentate",
"commentating":"commentate",
"commentators":"commentator",
"commerces":"commerce",
"commercials":"commercial",
"commercialisations":"commercialisation",
"commercialisms":"commercialism",
"commercializations":"commercialization",
"commercialized":"commercialize",
"commercializes":"commercialize",
"commercializing":"commercialize",
"commies":"commie",
"commingled":"commingle",
"commingles":"commingle",
"commingling":"commingle",
"comminuted":"comminute",
"comminutes":"comminute",
"comminuting":"comminute",
"commiphoras":"commiphora",
"commiserated":"commiserate",
"commiserates":"commiserate",
"commiserating":"commiserate",
"commiserations":"commiseration",
"commissars":"commissar",
"commissariats":"commissariat",
"commissaries":"commissary",
"commissioned":"commission",
"commissioning":"commission",
"commissions":"commission",
"commissioners":"commissioner",
"commissionings":"commissioning",
"commits":"commit",
"committed":"commit",
"committing":"commit",
"commitednesses":"commitedness",
"commitments":"commitment",
"committals":"committal",
"committees":"committee",
"committeemen":"committeeman",
"commixed":"commix",
"commixes":"commix",
"commixing":"commix",
"commixtures":"commixture",
"commos":"commo",
"commodes":"commode",
"commodiousnesses":"commodiousness",
"commodities":"commodity",
"commodores":"commodore",
"commons":"common",
"commonalities":"commonality",
"commonalties":"commonalty",
"commoners":"commoner",
"commonnesses":"commonness",
"commonplaces":"commonplace",
"commonplacenesses":"commonplaceness",
"commonses":"commons",
"commonweals":"commonweal",
"commonwealths":"commonwealth",
"commotions":"commotion",
"commoved":"commove",
"commoves":"commove",
"commoving":"commove",
"communalized":"communalize",
"communalizes":"communalize",
"communalizing":"communalize",
"communed":"commune",
"communes":"commune",
"communing":"commune",
"communicated":"communicate",
"communicates":"communicate",
"communicating":"communicate",
"communicatings":"communicating",
"communications":"communication",
"communions":"communion",
"communiques":"communique",
"communisations":"communisation",
"communists":"communist",
"communities":"community",
"communizations":"communization",
"communized":"communize",
"communizes":"communize",
"communizing":"communize",
"commutabilities":"commutability",
"commutated":"commutate",
"commutating":"commutate",
"commutations":"commutation",
"commuted":"commute",
"commutes":"commute",
"commuting":"commute",
"commuters":"commuter",
"commutings":"commuting",
"comps":"comp",
"compacted":"compact",
"compacting":"compact",
"compacts":"compact",
"compactions":"compaction",
"compactnesses":"compactness",
"companioned":"companion",
"companioning":"companion",
"companions":"companion",
"companionabilities":"companionability",
"companionablenesses":"companionableness",
"companionships":"companionship",
"companied":"company",
"companies":"company",
"companying":"company",
"comparabilities":"comparability",
"compared":"compare",
"compares":"compare",
"comparing":"compare",
"comparings":"comparing",
"comparisons":"comparison",
"comparted":"compart",
"comparting":"compart",
"compartmented":"compartment",
"compartmenting":"compartment",
"compartments":"compartment",
"compartmentalized":"compartmentalize",
"compartmentalizes":"compartmentalize",
"compartmentalizing":"compartmentalize",
"compassed":"compass",
"compasses":"compass",
"compassing":"compass",
"compassions":"compassion",
"compassionated":"compassionate",
"compassionates":"compassionate",
"compassionating":"compassionate",
"compassionatenesses":"compassionateness",
"compatibilities":"compatibility",
"compatriots":"compatriot",
"compeers":"compeer",
"compelled":"compel",
"compelling":"compel",
"compels":"compel",
"compendia":"compendium",
"compendiums":"compendium",
"compensated":"compensate",
"compensates":"compensate",
"compensating":"compensate",
"compensations":"compensation",
"compensators":"compensator",
"competed":"compete",
"competes":"compete",
"competing":"compete",
"competences":"competence",
"competencies":"competency",
"competitions":"competition",
"competitivenesses":"competitiveness",
"competitors":"competitor",
"compilations":"compilation",
"compiled":"compile",
"compiles":"compile",
"compiling":"compile",
"compilers":"compiler",
"compilings":"compiling",
"complacences":"complacence",
"complacencies":"complacency",
"complained":"complain",
"complaining":"complain",
"complains":"complain",
"complainants":"complainant",
"complainers":"complainer",
"complaints":"complaint",
"complaisances":"complaisance",
"complections":"complection",
"complemented":"complement",
"complementing":"complement",
"complements":"complement",
"completed":"complete",
"completes":"complete",
"completing":"complete",
"completions":"completion",
"complexes":"complex",
"complexioned":"complexion",
"complexioning":"complexion",
"complexions":"complexion",
"complexities":"complexity",
"complexnesses":"complexness",
"compliances":"compliance",
"compliancies":"compliancy",
"complicacies":"complicacy",
"complicated":"complicate",
"complicates":"complicate",
"complicating":"complicate",
"complicatednesses":"complicatedness",
"complicatings":"complicating",
"complications":"complication",
"complicities":"complicity",
"complimented":"compliment",
"complimenting":"compliment",
"compliments":"compliment",
"complimentses":"compliments",
"complins":"complin",
"complines":"compline",
"complots":"complot",
"complotted":"complot",
"complotting":"complot",
"complied":"comply",
"complies":"comply",
"complying":"comply",
"compos":"compo",
"components":"component",
"comported":"comport",
"comporting":"comport",
"comports":"comport",
"comportments":"comportment",
"composed":"compose",
"composes":"compose",
"composing":"compose",
"composers":"composer",
"composings":"composing",
"compositaes":"compositae",
"composites":"composite",
"compositions":"composition",
"compositors":"compositor",
"composted":"compost",
"composting":"compost",
"composures":"composure",
"compotes":"compote",
"compounded":"compound",
"compounding":"compound",
"compounds":"compound",
"compoundings":"compounding",
"comprehended":"comprehend",
"comprehending":"comprehend",
"comprehends":"comprehend",
"comprehensibilities":"comprehensibility",
"comprehensions":"comprehension",
"comprehensives":"comprehensive",
"comprehensivenesses":"comprehensiveness",
"compressed":"compress",
"compresses":"compress",
"compressing":"compress",
"compressibilities":"compressibility",
"compressings":"compressing",
"compressions":"compression",
"comprimarios":"comprimario",
"comprised":"comprise",
"comprises":"comprise",
"comprising":"comprise",
"comprisings":"comprising",
"compromised":"compromise",
"compromises":"compromise",
"compromising":"compromise",
"comptonias":"comptonia",
"comptrollers":"comptroller",
"compulsions":"compulsion",
"compulsivenesses":"compulsiveness",
"compulsivities":"compulsivity",
"compunctions":"compunction",
"computations":"computation",
"computed":"compute",
"computes":"compute",
"computing":"compute",
"computers":"computer",
"computerized":"computerize",
"computerizing":"computerize",
"comrades":"comrade",
"comradelinesses":"comradeliness",
"comraderies":"comradery",
"comradeships":"comradeship",
"conned":"con",
"conning":"con",
"cons":"con",
"conacastes":"conacaste",
"conakries":"conakry",
"concatenated":"concatenate",
"concatenating":"concatenate",
"concatenations":"concatenation",
"concaved":"concave",
"concaves":"concave",
"concaving":"concave",
"concavenesses":"concaveness",
"concavities":"concavity",
"concealed":"conceal",
"concealing":"conceal",
"conceals":"conceal",
"concealings":"concealing",
"concealments":"concealment",
"conceded":"concede",
"concedes":"concede",
"conceding":"concede",
"concedings":"conceding",
"conceits":"conceit",
"conceivabilities":"conceivability",
"conceivablenesses":"conceivableness",
"conceived":"conceive",
"conceives":"conceive",
"conceiving":"conceive",
"conceivers":"conceiver",
"concentrated":"concentrate",
"concentrates":"concentrate",
"concentrating":"concentrate",
"concentrations":"concentration",
"concepts":"concept",
"conceptions":"conception",
"conceptualisations":"conceptualisation",
"conceptualities":"conceptuality",
"conceptualizations":"conceptualization",
"conceptualized":"conceptualize",
"conceptualizes":"conceptualize",
"conceptualizing":"conceptualize",
"conceptuses":"conceptus",
"concerned":"concern",
"concerning":"concern",
"concerns":"concern",
"concerted":"concert",
"concerting":"concert",
"concerts":"concert",
"concert-goers":"concert-goer",
"concertanti":"concertante",
"concertinaed":"concertina",
"concertinaing":"concertina",
"concertinas":"concertina",
"concertini":"concertino",
"concertized":"concertize",
"concertizing":"concertize",
"concerti":"concerto",
"concertos":"concerto",
"concerti_grossi":"concerto_grosso",
"concerto_grossos":"concerto_grosso",
"concessions":"concession",
"concessionaires":"concessionaire",
"concessionaries":"concessionary",
"concessioners":"concessioner",
"conches":"conch",
"conchs":"conch",
"conchae":"concha",
"conchfishes":"conchfish",
"conchies":"conchie",
"conchologies":"conchology",
"concierges":"concierge",
"conciliated":"conciliate",
"conciliates":"conciliate",
"conciliating":"conciliate",
"conciliations":"conciliation",
"conciliators":"conciliator",
"concinnities":"concinnity",
"concisenesses":"conciseness",
"concluded":"conclude",
"concludes":"conclude",
"concluding":"conclude",
"conclusions":"conclusion",
"conclusivenesses":"conclusiveness",
"concocted":"concoct",
"concocting":"concoct",
"concocts":"concoct",
"concoctions":"concoction",
"concomitants":"concomitant",
"concords":"concord",
"concordances":"concordance",
"concordats":"concordat",
"concourses":"concourse",
"concreted":"concrete",
"concreting":"concrete",
"concretions":"concretion",
"concretisms":"concretism",
"concretized":"concretize",
"concretizing":"concretize",
"concubines":"concubine",
"concupiscences":"concupiscence",
"concurred":"concur",
"concurring":"concur",
"concurs":"concur",
"concurrences":"concurrence",
"concussed":"concuss",
"concussing":"concuss",
"concussions":"concussion",
"condemned":"condemn",
"condemning":"condemn",
"condemns":"condemn",
"condemnations":"condemnation",
"condensates":"condensate",
"condensations":"condensation",
"condensed":"condense",
"condenses":"condense",
"condensing":"condense",
"condensers":"condenser",
"condensings":"condensing",
"condescended":"condescend",
"condescending":"condescend",
"condescends":"condescend",
"condescensions":"condescension",
"conditioned":"condition",
"conditioning":"condition",
"conditions":"condition",
"conditionals":"conditional",
"condos":"condo",
"condoled":"condole",
"condoling":"condole",
"condolences":"condolence",
"condoms":"condom",
"condominiums":"condominium",
"condoned":"condone",
"condones":"condone",
"condoning":"condone",
"condors":"condor",
"condordances":"condordance",
"condottieri":"condottiere",
"conduced":"conduce",
"conduces":"conduce",
"conducing":"conduce",
"conducted":"conduct",
"conducting":"conduct",
"conducts":"conduct",
"conductions":"conduction",
"conductivities":"conductivity",
"conductors":"conductor",
"conduits":"conduit",
"condylomas":"condyloma",
"condylomata":"condyloma",
"condyluras":"condylura",
"coned":"cone",
"cones":"cone",
"coning":"cone",
"conenoses":"conenose",
"conepatuses":"conepatus",
"conessis":"conessi",
"conestogas":"conestoga",
"coneys":"coney",
"confabbed":"confab",
"confabbing":"confab",
"confabs":"confab",
"confabulates":"confabulate",
"confabulating":"confabulate",
"confabulted":"confabulate",
"confabulations":"confabulation",
"confectioned":"confection",
"confectioning":"confection",
"confections":"confection",
"confectionaries":"confectionary",
"confectioners":"confectioner",
"confectioneries":"confectionery",
"confederacies":"confederacy",
"confederated":"confederate",
"confederates":"confederate",
"confederating":"confederate",
"confederations":"confederation",
"conferred":"confer",
"conferring":"confer",
"confers":"confer",
"conferences":"conference",
"conferments":"conferment",
"conferrals":"conferral",
"confervae":"conferva",
"confervas":"conferva",
"confessed":"confess",
"confesses":"confess",
"confessing":"confess",
"confessions":"confession",
"confessors":"confessor",
"confidants":"confidant",
"confided":"confide",
"confides":"confide",
"confiding":"confide",
"confidences":"confidence",
"configurations":"configuration",
"configurationisms":"configurationism",
"confined":"confine",
"confines":"confine",
"confining":"confine",
"confinements":"confinement",
"confirmed":"confirm",
"confirming":"confirm",
"confirms":"confirm",
"confirmations":"confirmation",
"confiscated":"confiscate",
"confiscates":"confiscate",
"confiscating":"confiscate",
"confiscations":"confiscation",
"conflagrations":"conflagration",
"conflated":"conflate",
"conflates":"conflate",
"conflating":"conflate",
"conflicted":"conflict",
"conflicting":"conflict",
"conflicts":"conflict",
"confluences":"confluence",
"confluxes":"conflux",
"conformed":"conform",
"conforming":"conform",
"conforms":"conform",
"conformances":"conformance",
"conformations":"conformation",
"conformisms":"conformism",
"conformities":"conformity",
"confounded":"confound",
"confounding":"confound",
"confounds":"confound",
"confoundings":"confounding",
"confraternities":"confraternity",
"confreres":"confrere",
"confronted":"confront",
"confronting":"confront",
"confronts":"confront",
"confrontations":"confrontation",
"confrontings":"confronting",
"confuciuses":"confucius",
"confused":"confuse",
"confuses":"confuse",
"confusing":"confuse",
"confusions":"confusion",
"confuted":"confute",
"confutes":"confute",
"confuting":"confute",
"confutings":"confuting",
"congaed":"conga",
"congaing":"conga",
"congas":"conga",
"congealed":"congeal",
"congealing":"congeal",
"congeals":"congeal",
"congeed":"congee",
"congeeing":"congee",
"congees":"congee",
"congenators":"congenator",
"congeners":"congener",
"congenialities":"congeniality",
"congenialnesses":"congenialness",
"congers":"conger",
"congerieses":"congeries",
"congested":"congest",
"congesting":"congest",
"congests":"congest",
"congestions":"congestion",
"congiuses":"congius",
"conglobated":"conglobate",
"conglobates":"conglobate",
"conglobating":"conglobate",
"conglomerated":"conglomerate",
"conglomerates":"conglomerate",
"conglomerating":"conglomerate",
"conglomerations":"conglomeration",
"conglutinated":"conglutinate",
"conglutinates":"conglutinate",
"conglutinating":"conglutinate",
"congos":"congo",
"congous":"congou",
"congratulated":"congratulate",
"congratulates":"congratulate",
"congratulating":"congratulate",
"congratulations":"congratulation",
"congratulationses":"congratulations",
"congregated":"congregate",
"congregates":"congregate",
"congregating":"congregate",
"congregatings":"congregating",
"congregations":"congregation",
"congresses":"congress",
"congress-gaiters":"congress-gaiter",
"congressmen":"congressman",
"congresswomen":"congresswoman",
"congridaes":"congridae",
"congruences":"congruence",
"congruencies":"congruency",
"congruities":"congruity",
"congruousnesses":"congruousness",
"conics":"conic",
"conidiospores":"conidiospore",
"conidiums":"conidium",
"conifers":"conifer",
"coniferaleses":"coniferales",
"coniferophytas":"coniferophyta",
"coniferophytinas":"coniferophytina",
"coniferopsidas":"coniferopsida",
"coniluruses":"conilurus",
"coniogrammes":"coniogramme",
"coniums":"conium",
"conjectured":"conjecture",
"conjectures":"conjecture",
"conjecturing":"conjecture",
"conjoined":"conjoin",
"conjoining":"conjoin",
"conjoins":"conjoin",
"conjugated":"conjugate",
"conjugates":"conjugate",
"conjugating":"conjugate",
"conjugations":"conjugation",
"conjunctions":"conjunction",
"conjunctivae":"conjunctiva",
"conjunctivas":"conjunctiva",
"conjunctives":"conjunctive",
"conjunctivitises":"conjunctivitis",
"conjurations":"conjuration",
"conjured":"conjure",
"conjures":"conjure",
"conjuring":"conjure",
"conjurers":"conjurer",
"conjurings":"conjuring",
"conjurors":"conjuror",
"conjuries":"conjury",
"conked":"conk",
"conking":"conk",
"conks":"conk",
"conkers":"conker",
"connaraceaes":"connaraceae",
"connaruses":"connarus",
"connected":"connect",
"connecting":"connect",
"connects":"connect",
"connectednesses":"connectedness",
"connecters":"connecter",
"connecticuts":"connecticut",
"connectings":"connecting",
"connections":"connection",
"connectives":"connective",
"connectors":"connector",
"connexions":"connexion",
"connivances":"connivance",
"connived":"connive",
"connives":"connive",
"conniving":"connive",
"connochaeteses":"connochaetes",
"connoisseurs":"connoisseur",
"connoisseurships":"connoisseurship",
"connotations":"connotation",
"connoted":"connote",
"connotes":"connote",
"connoting":"connote",
"conocarpuses":"conocarpus",
"conocliniums":"conoclinium",
"conodontas":"conodonta",
"conodontophoridas":"conodontophorida",
"conoids":"conoid",
"conopodiums":"conopodium",
"conospermums":"conospermum",
"conquered":"conquer",
"conquering":"conquer",
"conquers":"conquer",
"conquerings":"conquering",
"conquerors":"conqueror",
"conquests":"conquest",
"conquistadores":"conquistador",
"conquistadors":"conquistador",
"conradinas":"conradina",
"consanguinities":"consanguinity",
"consciences":"conscience",
"conscientiousnesses":"conscientiousness",
"consciousnesses":"consciousness",
"conscribed":"conscribe",
"conscribing":"conscribe",
"conscripted":"conscript",
"conscripting":"conscript",
"conscripts":"conscript",
"conscriptions":"conscription",
"consecrated":"consecrate",
"consecrates":"consecrate",
"consecrating":"consecrate",
"consensuses":"consensus",
"consented":"consent",
"consenting":"consent",
"consents":"consent",
"consequences":"consequence",
"consequents":"consequent",
"conservancies":"conservancy",
"conservations":"conservation",
"conservationists":"conservationist",
"conservatives":"conservative",
"conservativists":"conservativist",
"conservatoires":"conservatoire",
"conservators":"conservator",
"conservatories":"conservatory",
"conserved":"conserve",
"conserves":"conserve",
"conserving":"conserve",
"conserveses":"conserves",
"conservings":"conserving",
"considered":"consider",
"considering":"consider",
"considers":"consider",
"consideratenesses":"considerateness",
"considerations":"consideration",
"consigned":"consign",
"consigning":"consign",
"consigns":"consign",
"consigners":"consigner",
"consignments":"consignment",
"consignors":"consignor",
"consisted":"consist",
"consisting":"consist",
"consists":"consist",
"consistences":"consistence",
"consistencies":"consistency",
"consistories":"consistory",
"consociated":"consociate",
"consociates":"consociate",
"consociating":"consociate",
"consolations":"consolation",
"consoled":"console",
"consoles":"console",
"consoling":"console",
"consolidas":"consolida",
"consolidated":"consolidate",
"consolidating":"consolidate",
"consolidations":"consolidation",
"consonances":"consonance",
"consonancies":"consonancy",
"consonannancies":"consonancy",
"consonants":"consonant",
"consorted":"consort",
"consorting":"consort",
"consorts":"consort",
"consortia":"consortium",
"consortiums":"consortium",
"conspectuses":"conspectus",
"conspicuousnesses":"conspicuousness",
"conspiracies":"conspiracy",
"conspirators":"conspirator",
"conspired":"conspire",
"conspires":"conspire",
"conspiring":"conspire",
"constables":"constable",
"constabularies":"constabulary",
"constancies":"constancy",
"constants":"constant",
"constantans":"constantan",
"constantinoples":"constantinople",
"constatations":"constatation",
"constellated":"constellate",
"constellates":"constellate",
"constellating":"constellate",
"constellations":"constellation",
"consternated":"consternate",
"consternates":"consternate",
"consternating":"consternate",
"consternations":"consternation",
"constipated":"constipate",
"constipates":"constipate",
"constipating":"constipate",
"constipations":"constipation",
"constituencies":"constituency",
"constituents":"constituent",
"constituted":"constitute",
"constitutes":"constitute",
"constituting":"constitute",
"constitutions":"constitution",
"constitutionals":"constitutional",
"constitutionalists":"constitutionalist",
"constrained":"constrain",
"constraining":"constrain",
"constrains":"constrain",
"constraints":"constraint",
"constricted":"constrict",
"constricting":"constrict",
"constricts":"constrict",
"constrictions":"constriction",
"constringed":"constringe",
"constringes":"constringe",
"constringing":"constringe",
"construals":"construal",
"constructed":"construct",
"constructing":"construct",
"constructs":"construct",
"constructions":"construction",
"constructionists":"constructionist",
"constructors":"constructor",
"construed":"construe",
"construes":"construe",
"construing":"construe",
"consubstantiated":"consubstantiate",
"consubstantiates":"consubstantiate",
"consubstantiating":"consubstantiate",
"consuetudinals":"consuetudinal",
"consuetudinaries":"consuetudinary",
"consuls":"consul",
"consulted":"consult",
"consulting":"consult",
"consults":"consult",
"consultants":"consultant",
"consultations":"consultation",
"consumed":"consume",
"consumes":"consume",
"consuming":"consume",
"consumers":"consumer",
"consummated":"consummate",
"consummates":"consummate",
"consummating":"consummate",
"consumptions":"consumption",
"consumptives":"consumptive",
"contacted":"contact",
"contacting":"contact",
"contacts":"contact",
"contactings":"contacting",
"contagions":"contagion",
"contagia":"contagium",
"contained":"contain",
"containing":"contain",
"contains":"contain",
"containers":"container",
"containerized":"containerize",
"containerizing":"containerize",
"containerships":"containership",
"contaminants":"contaminant",
"contaminated":"contaminate",
"contaminates":"contaminate",
"contaminating":"contaminate",
"contaminations":"contamination",
"contangoed":"contango",
"contangoes":"contango",
"contangoing":"contango",
"contangos":"contango",
"contes":"conte",
"contemned":"contemn",
"contemning":"contemn",
"contemns":"contemn",
"contemplated":"contemplate",
"contemplates":"contemplate",
"contemplating":"contemplate",
"contemplations":"contemplation",
"contemplativenesses":"contemplativeness",
"contemplators":"contemplator",
"contemporaneities":"contemporaneity",
"contemporaneousnesses":"contemporaneousness",
"contemporarieses":"contemporaries",
"contemporaries":"contemporary",
"contempts":"contempt",
"contemptibilities":"contemptibility",
"contended":"contend",
"contending":"contend",
"contends":"contend",
"contenders":"contender",
"contented":"content",
"contenting":"content",
"contents":"content",
"contentednesses":"contentedness",
"contentions":"contention",
"contentiousnesses":"contentiousness",
"contentses":"contents",
"contesse":"contessa",
"contested":"contest",
"contesting":"contest",
"contests":"contest",
"contestants":"contestant",
"contestations":"contestation",
"contexts":"context",
"contiguities":"contiguity",
"contiguousnesses":"contiguousness",
"continences":"continence",
"continencies":"continency",
"continents":"continent",
"continentals":"continental",
"contingencies":"contingency",
"contingents":"contingent",
"continuances":"continuance",
"continuants":"continuant",
"continuations":"continuation",
"continued":"continue",
"continues":"continue",
"continuing":"continue",
"continuities":"continuity",
"continuos":"continuo",
"continuousnesses":"continuousness",
"contintinua":"continuum",
"contintinuums":"continuum",
"continua":"continuum",
"contos":"conto",
"contopuses":"contopus",
"contorted":"contort",
"contorting":"contort",
"contorts":"contort",
"contortions":"contortion",
"contoured":"contour",
"contouring":"contour",
"contours":"contour",
"contras":"contra",
"contrabandists":"contrabandist",
"contrabasses":"contrabass",
"contrabassoons":"contrabassoon",
"contraceptions":"contraception",
"contraceptives":"contraceptive",
"contracted":"contract",
"contracting":"contract",
"contracts":"contract",
"contractings":"contracting",
"contractions":"contraction",
"contractors":"contractor",
"contradicted":"contradict",
"contradicting":"contradict",
"contradicts":"contradict",
"contradictions":"contradiction",
"contradictories":"contradictory",
"contradistinguished":"contradistinguish",
"contradistinguishing":"contradistinguish",
"contrafagottos":"contrafagotto",
"contrails":"contrail",
"contraindicated":"contraindicate",
"contraindicating":"contraindicate",
"contraltos":"contralto",
"contraptions":"contraption",
"contrarieties":"contrariety",
"contrarinesses":"contrariness",
"contraries":"contrary",
"contrasted":"contrast",
"contrasting":"contrast",
"contrasts":"contrast",
"contravened":"contravene",
"contravenes":"contravene",
"contravening":"contravene",
"contraventions":"contravention",
"contredansed":"contredanse",
"contredanses":"contredanse",
"contredansing":"contredanse",
"contributed":"contribute",
"contributes":"contribute",
"contributing":"contribute",
"contributions":"contribution",
"contributors":"contributor",
"contributories":"contributory",
"contritenesses":"contriteness",
"contritions":"contrition",
"contrivances":"contrivance",
"contrived":"contrive",
"contrives":"contrive",
"contriving":"contrive",
"contrivers":"contriver",
"controlled":"control",
"controlling":"control",
"controls":"control",
"controllers":"controller",
"controllings":"controlling",
"controversialists":"controversialist",
"controversies":"controversy",
"controverted":"controvert",
"controverting":"controvert",
"controverts":"controvert",
"contumacies":"contumacy",
"contumelies":"contumely",
"contused":"contuse",
"contuses":"contuse",
"contusing":"contuse",
"contusions":"contusion",
"conundrums":"conundrum",
"conurbations":"conurbation",
"conuropses":"conuropsis",
"convalesced":"convalesce",
"convalesces":"convalesce",
"convalescing":"convalesce",
"convalescences":"convalescence",
"convalescents":"convalescent",
"convallarias":"convallaria",
"convallariaceaes":"convallariaceae",
"convected":"convect",
"convecting":"convect",
"convenances":"convenance",
"convened":"convene",
"convenes":"convene",
"convening":"convene",
"conveners":"convener",
"conveniences":"convenience",
"convenienceses":"conveniences",
"convenings":"convening",
"convents":"convent",
"conventicles":"conventicle",
"conventions":"convention",
"conventionalisations":"conventionalisation",
"conventionalisms":"conventionalism",
"conventionalities":"conventionality",
"conventionalizations":"conventionalization",
"conventionalized":"conventionalize",
"conventionalizes":"conventionalize",
"conventionalizing":"conventionalize",
"converged":"converge",
"converges":"converge",
"converging":"converge",
"convergences":"convergence",
"convergencies":"convergency",
"convergings":"converging",
"conversances":"conversance",
"conversancies":"conversancy",
"conversations":"conversation",
"conversaziozioni":"conversazione",
"conversed":"converse",
"converses":"converse",
"conversing":"converse",
"conversions":"conversion",
"converted":"convert",
"converting":"convert",
"converts":"convert",
"converters":"converter",
"convertibles":"convertible",
"convertings":"converting",
"convertors":"convertor",
"convexities":"convexity",
"convexnesses":"convexness",
"conveyed":"convey",
"conveying":"convey",
"conveys":"convey",
"conveyances":"conveyance",
"conveyancings":"conveyancing",
"conveyers":"conveyer",
"conveyings":"conveying",
"conveyors":"conveyor",
"convicted":"convict",
"convicting":"convict",
"convicts":"convict",
"convictfishes":"convictfish",
"convictions":"conviction",
"convinced":"convince",
"convinces":"convince",
"convincing":"convince",
"convivialities":"conviviality",
"convocations":"convocation",
"convoked":"convoke",
"convokes":"convoke",
"convoking":"convoke",
"convoluted":"convolute",
"convolutes":"convolute",
"convoluting":"convolute",
"convolutions":"convolution",
"convolved":"convolve",
"convolves":"convolve",
"convolving":"convolve",
"convolvulaceaes":"convolvulaceae",
"convolvuli":"convolvulus",
"convolvuluses":"convolvulus",
"convoyed":"convoy",
"convoying":"convoy",
"convoys":"convoy",
"convulsed":"convulse",
"convulses":"convulse",
"convulsing":"convulse",
"convulsions":"convulsion",
"convulsionaries":"convulsionary",
"conies":"cony",
"conyzas":"conyza",
"cooed":"coo",
"cooing":"coo",
"coos":"coo",
"cooeed":"cooee",
"cooeeing":"cooee",
"cooees":"cooee",
"cooeyed":"cooey",
"cooeying":"cooey",
"cooeys":"cooey",
"cooked":"cook",
"cooking":"cook",
"cooks":"cook",
"cooks-general":"cook-general",
"cookbooks":"cookbook",
"cookers":"cooker",
"cookeries":"cookery",
"cookhouses":"cookhouse",
"cookies":"cookie",
"cookings":"cooking",
"cookwares":"cookware",
"cooled":"cool",
"cooler":"cool",
"coolest":"cool",
"cooling":"cool",
"cools":"cool",
"coolers":"cooler",
"coolidges":"coolidge",
"coolies":"coolie",
"coolings":"cooling",
"coolnesses":"coolness",
"coolwarts":"coolwart",
"coons":"coon",
"coonskins":"coonskin",
"coonties":"coontie",
"cooped":"coop",
"cooping":"coop",
"coops":"coop",
"coopered":"cooper",
"coopering":"cooper",
"coopers":"cooper",
"cooperated":"cooperate",
"cooperates":"cooperate",
"cooperating":"cooperate",
"cooperations":"cooperation",
"cooperatives":"cooperative",
"cooperativenesses":"cooperativeness",
"cooperators":"cooperator",
"cooperies":"coopery",
"co-opts":"co-opt",
"co-ordinate":"coordinate",
"co-ordinated":"coordinate",
"co-ordinates":"coordinate",
"co-ordinating":"coordinate",
"coordinated":"coordinate",
"coordinates":"coordinate",
"coordinating":"coordinate",
"coordinators":"coordinator",
"cooters":"cooter",
"copped":"cop",
"copping":"cop",
"cops":"cop",
"copaibas":"copaiba",
"copalines":"copaline",
"copalites":"copalite",
"coped":"cope",
"copes":"cope",
"coping":"cope",
"copecks":"copeck",
"copenhagens":"copenhagen",
"copepods":"copepod",
"copepodas":"copepoda",
"copernicias":"copernicia",
"copernicuses":"copernicus",
"copiers":"copier",
"copings":"coping",
"copiousnesses":"copiousness",
"copolymerized":"copolymerize",
"copolymerizes":"copolymerize",
"copolymerizing":"copolymerize",
"coppered":"copper",
"coppering":"copper",
"coppers":"copper",
"copperheads":"copperhead",
"coppices":"coppice",
"coprinaceaes":"coprinaceae",
"coprinuses":"coprinus",
"copses":"copse",
"coptises":"coptis",
"copulae":"copula",
"copulas":"copula",
"copulated":"copulate",
"copulates":"copulate",
"copulating":"copulate",
"copulations":"copulation",
"copulatives":"copulative",
"copied":"copy",
"copies":"copy",
"copying":"copy",
"copy-edited":"copy-edit",
"copy-editing":"copy-edit",
"copycats":"copycat",
"copyists":"copyist",
"copyreading":"copyread",
"copyreads":"copyread",
"copyreaders":"copyreader",
"copyrighted":"copyright",
"copyrighting":"copyright",
"copyrights":"copyright",
"coquets":"coquet",
"coquetted":"coquet",
"coquetting":"coquet",
"coquetries":"coquetry",
"coquettes":"coquette",
"coquitos":"coquito",
"coras":"cora",
"coracans":"coracan",
"coraciases":"coracias",
"coraciidaes":"coraciidae",
"coraciiformeses":"coraciiformes",
"coragypses":"coragyps",
"corakans":"corakan",
"corals":"coral",
"coralbellses":"coralbells",
"coralberries":"coralberry",
"corallorhizas":"corallorhiza",
"coralroots":"coralroot",
"coralwoods":"coralwood",
"coralworts":"coralwort",
"corantos":"coranto",
"corbeled":"corbel",
"corbeling":"corbel",
"corbelled":"corbel",
"corbelling":"corbel",
"corbels":"corbel",
"corbiculae":"corbicula",
"corbie-steps":"corbie-step",
"corbiesteps":"corbiestep",
"corbinas":"corbina",
"corded":"cord",
"cording":"cord",
"cords":"cord",
"cordaitaceaes":"cordaitaceae",
"cordaitaleses":"cordaitales",
"cordaiteses":"cordaites",
"cordarones":"cordarone",
"cordgrasses":"cordgrass",
"cordias":"cordia",
"cordials":"cordial",
"cordialities":"cordiality",
"cordobas":"cordoba",
"cordoned":"cordon",
"cordoning":"cordon",
"cordovas":"cordova",
"cordses":"cords",
"corduroys":"corduroy",
"corduroyses":"corduroys",
"cordylidaes":"cordylidae",
"cordylines":"cordyline",
"cordyluses":"cordylus",
"cored":"core",
"cores":"core",
"coring":"core",
"coregonidaes":"coregonidae",
"coregonuses":"coregonus",
"coreids":"coreid",
"coreidaes":"coreidae",
"coreopses":"coreopsis",
"corgards":"corgard",
"corgis":"corgi",
"corianders":"coriander",
"coriandrums":"coriandrum",
"coricidins":"coricidin",
"corinths":"corinth",
"Corinthians":"Corinthian",
"coriums":"corium",
"corixas":"corixa",
"corixidaes":"corixidae",
"corked":"cork",
"corking":"cork",
"corks":"cork",
"corkscrewed":"corkscrew",
"corkscrewing":"corkscrew",
"corkscrews":"corkscrew",
"corkwoods":"corkwood",
"corkier":"corky",
"corkiest":"corky",
"cormorants":"cormorant",
"corned":"corn",
"corning":"corn",
"corns":"corn",
"cornaceaes":"cornaceae",
"corncrakes":"corncrake",
"corncribs":"corncrib",
"corneae":"cornea",
"corneas":"cornea",
"cornels":"cornel",
"cornelians":"cornelian",
"cornered":"corner",
"cornering":"corner",
"corners":"corner",
"cornerstones":"cornerstone",
"cornets":"cornet",
"cornets-a-pistons":"cornet-a-pistons",
"cornetcies":"cornetcy",
"cornetists":"cornetist",
"corneums":"corneum",
"cornfields":"cornfield",
"cornflours":"cornflour",
"cornflowers":"cornflower",
"cornhuskers":"cornhusker",
"cornhuskings":"cornhusking",
"corniced":"cornice",
"cornices":"cornice",
"cornicing":"cornice",
"cornmeals":"cornmeal",
"cornpones":"cornpone",
"cornsmuts":"cornsmut",
"cornstarches":"cornstarch",
"cornua":"cornu",
"cornucopias":"cornucopia",
"cornuses":"cornus",
"cornier":"corny",
"corniest":"corny",
"corodies":"corody",
"corollas":"corolla",
"corollaries":"corollary",
"coronae":"corona",
"coronas":"corona",
"coronaches":"coronach",
"coronals":"coronal",
"coronaries":"coronary",
"coronations":"coronation",
"coroners":"coroner",
"coronets":"coronet",
"corozos":"corozo",
"corps":"corp",
"corporals":"corporal",
"corporations":"corporation",
"corporealities":"corporeality",
"corposants":"corposant",
"corpses":"corpse",
"corpsmen":"corpsman",
"corpulences":"corpulence",
"corpora":"corpus",
"corpuses":"corpus",
"corpuscles":"corpuscle",
"corraded":"corrade",
"corrades":"corrade",
"corrading":"corrade",
"corralled":"corral",
"corralling":"corral",
"corrals":"corral",
"corrasions":"corrasion",
"corrected":"correct",
"correcting":"correct",
"corrects":"correct",
"correctings":"correcting",
"corrections":"correction",
"correctitudes":"correctitude",
"correctives":"corrective",
"correctnesses":"correctness",
"corregidors":"corregidor",
"correlated":"correlate",
"correlates":"correlate",
"correlating":"correlate",
"correlations":"correlation",
"correlatives":"correlative",
"correlativities":"correlativity",
"corresponded":"correspond",
"corresponding":"correspond",
"corresponds":"correspond",
"correspondences":"correspondence",
"correspondents":"correspondent",
"corridas":"corrida",
"corridors":"corridor",
"corries":"corrie",
"corrigenda":"corrigendum",
"corroborated":"corroborate",
"corroborates":"corroborate",
"corroborating":"corroborate",
"corroborations":"corroboration",
"corroborators":"corroborator",
"corroborees":"corroboree",
"corroded":"corrode",
"corrodes":"corrode",
"corroding":"corrode",
"corrodentias":"corrodentia",
"corrodings":"corroding",
"corrodies":"corrody",
"corrosions":"corrosion",
"corrugated":"corrugate",
"corrugating":"corrugate",
"corrupted":"corrupt",
"corrupting":"corrupt",
"corrupts":"corrupt",
"corruptions":"corruption",
"corruptnesses":"corruptness",
"corruscations":"corruscation",
"corsages":"corsage",
"corsairs":"corsair",
"corses":"corse",
"corselets":"corselet",
"corseted":"corset",
"corseting":"corset",
"corsets":"corset",
"corsicas":"corsica",
"corslets":"corslet",
"cortaderias":"cortaderia",
"corteges":"cortege",
"corteses":"cortes",
"cortexes":"cortex",
"cortices":"cortex",
"cortezs":"cortez",
"corticiums":"corticium",
"corticoids":"corticoid",
"corticosteroids":"corticosteroid",
"corticotrophins":"corticotrophin",
"corticotropins":"corticotropin",
"cortinariaceaes":"cortinariaceae",
"cortinariuses":"cortinarius",
"cortisols":"cortisol",
"corundoms":"corundom",
"corundums":"corundum",
"coruscated":"coruscate",
"coruscates":"coruscate",
"coruscating":"coruscate",
"corvidaes":"corvidae",
"corvuses":"corvus",
"coryantheses":"coryanthes",
"corybantes":"corybant",
"corybants":"corybant",
"corydalidaes":"corydalidae",
"corydalises":"corydalis",
"corydaluses":"corydalus",
"corylaceaes":"corylaceae",
"corylopses":"corylopsis",
"coryluses":"corylus",
"coryphas":"corypha",
"coryphaenidaes":"coryphaenidae",
"coryphaei":"coryphaeus",
"coryphees":"coryphee",
"corythosaurs":"corythosaur",
"corythosauruses":"corythosaurus",
"coryzas":"coryza",
"coses":"cos",
"coseys":"cosey",
"coshed":"cosh",
"coshes":"cosh",
"coshing":"cosh",
"coshered":"cosher",
"coshering":"cosher",
"cosigned":"cosign",
"cosigning":"cosign",
"cosignatories":"cosignatory",
"cosigners":"cosigner",
"cosinesses":"cosiness",
"cosmetics":"cosmetic",
"cosmeticians":"cosmetician",
"cosmeticized":"cosmeticize",
"cosmeticizing":"cosmeticize",
"cosmeticses":"cosmetics",
"cosmocampuses":"cosmocampus",
"cosmogonies":"cosmogony",
"cosmographers":"cosmographer",
"cosmographists":"cosmographist",
"cosmographies":"cosmography",
"cosmologies":"cosmology",
"cosmonauts":"cosmonaut",
"cosmopolitans":"cosmopolitan",
"cosmopolites":"cosmopolite",
"cosmoses":"cosmos",
"cosses":"coss",
"cosseted":"cosset",
"cosseting":"cosset",
"cossets":"cosset",
"costing":"cost",
"costs":"cost",
"costae":"costa",
"costas":"costa",
"costalgias":"costalgia",
"costarred":"costar",
"costarring":"costar",
"costermongers":"costermonger",
"costias":"costia",
"costlinesses":"costliness",
"costlier":"costly",
"costliest":"costly",
"costmaries":"costmary",
"costotomies":"costotomy",
"costumed":"costume",
"costumes":"costume",
"costuming":"costume",
"costumiers":"costumier",
"costusroots":"costusroot",
"cosier":"cosy",
"cosies":"cosy",
"cosiest":"cosy",
"cots":"cot",
"cotted":"cot",
"cotting":"cot",
"cotes":"cote",
"coteries":"coterie",
"cothurns":"cothurn",
"cothurni":"cothurnus",
"cotilions":"cotilion",
"cotillions":"cotillion",
"cotingas":"cotinga",
"cotingidaes":"cotingidae",
"cotinuses":"cotinus",
"cotswoldses":"cotswolds",
"cottae":"cotta",
"cottages":"cottage",
"cottagers":"cottager",
"cottars":"cottar",
"cotters":"cotter",
"cottidaes":"cottidae",
"cottiers":"cottier",
"cottoned":"cotton",
"cottoning":"cotton",
"cottons":"cotton",
"cottonmouths":"cottonmouth",
"cottonseeds":"cottonseed",
"cottontails":"cottontail",
"cottonweeds":"cottonweed",
"cottonwicks":"cottonwick",
"cottonwoods":"cottonwood",
"cottuses":"cottus",
"cotulas":"cotula",
"coturnices":"coturnix",
"coturnixes":"coturnix",
"cotyledons":"cotyledon",
"couched":"couch",
"couches":"couch",
"couching":"couch",
"cougars":"cougar",
"coughed":"cough",
"coughing":"cough",
"coughs":"cough",
"coughings":"coughing",
"coulisses":"coulisse",
"coulombs":"coulomb",
"coulters":"coulter",
"coumadins":"coumadin",
"coumarones":"coumarone",
"coumarounas":"coumarouna",
"councils":"council",
"councillors":"councillor",
"councillorships":"councillorship",
"councilmen":"councilman",
"councilors":"councilor",
"councilorships":"councilorship",
"counseled":"counsel",
"counseling":"counsel",
"counselled":"counsel",
"counselling":"counsel",
"counsels":"counsel",
"counselings":"counseling",
"counsellors":"counsellor",
"counsellorships":"counsellorship",
"counselors":"counselor",
"counselor-at-laws":"counselor-at-law",
"counselors-at-law":"counselor-at-law",
"counselorships":"counselorship",
"counted":"count",
"counting":"count",
"counts":"count",
"countenanced":"countenance",
"countenances":"countenance",
"countenancing":"countenance",
"countered":"counter",
"countering":"counter",
"counters":"counter",
"counter-revolutionaries":"counter-revolutionary",
"counteracted":"counteract",
"counteracting":"counteract",
"counteracts":"counteract",
"counteractions":"counteraction",
"counterattacked":"counterattack",
"counterattacking":"counterattack",
"counterattacks":"counterattack",
"counterbalanced":"counterbalance",
"counterbalances":"counterbalance",
"counterbalancing":"counterbalance",
"counterbores":"counterbore",
"counterchanged":"counterchange",
"counterchanges":"counterchange",
"counterchanging":"counterchange",
"countercharged":"countercharge",
"countercharging":"countercharge",
"counterchecked":"countercheck",
"counterchecking":"countercheck",
"counterchecks":"countercheck",
"counterclaimed":"counterclaim",
"counterclaiming":"counterclaim",
"counterfeited":"counterfeit",
"counterfeiting":"counterfeit",
"counterfeits":"counterfeit",
"counterfeiters":"counterfeiter",
"counterfoils":"counterfoil",
"counterglows":"counterglow",
"countermen":"counterman",
"countermanded":"countermand",
"countermanding":"countermand",
"countermands":"countermand",
"countermarched":"countermarch",
"countermarching":"countermarch",
"countermined":"countermine",
"countermines":"countermine",
"countermining":"countermine",
"countermoves":"countermove",
"counterpanes":"counterpane",
"counterparts":"counterpart",
"counterplots":"counterplot",
"counterplotted":"counterplot",
"counterplotting":"counterplot",
"counterpointed":"counterpoint",
"counterpointing":"counterpoint",
"counterpoints":"counterpoint",
"counterpoised":"counterpoise",
"counterpoises":"counterpoise",
"counterpoising":"counterpoise",
"counterpoisons":"counterpoison",
"counterpunches":"counterpunch",
"counterrevolutions":"counterrevolution",
"counterrevolutionaries":"counterrevolutionary",
"counterrevolutionists":"counterrevolutionist",
"countersigned":"countersign",
"countersigning":"countersign",
"countersigns":"countersign",
"countersignatures":"countersignature",
"countersank":"countersink",
"countersinking":"countersink",
"countersinks":"countersink",
"countersunk":"countersink",
"counterspies":"counterspy",
"countertenors":"countertenor",
"countervailed":"countervail",
"countervailing":"countervail",
"countervails":"countervail",
"counterweighed":"counterweigh",
"counterweighing":"counterweigh",
"counterweights":"counterweight",
"countesses":"countess",
"countings":"counting",
"countlessnesses":"countlessness",
"countries":"country",
"country-dances":"country-dance",
"countrymen":"countryman",
"countrywomen":"countrywoman",
"counts/minutes":"counts/minute",
"counties":"county",
"coups":"coup",
"coupes":"coupe",
"coupled":"couple",
"couples":"couple",
"coupling":"couple",
"couplers":"coupler",
"couplets":"couplet",
"couplings":"coupling",
"coupons":"coupon",
"courages":"courage",
"courageousnesses":"courageousness",
"courbarils":"courbaril",
"courgettes":"courgette",
"couriers":"courier",
"courlans":"courlan",
"coursed":"course",
"courses":"course",
"coursing":"course",
"courted":"court",
"courting":"court",
"courts":"court",
"court-martialed":"court-martial",
"court-martialing":"court-martial",
"court-martialled":"court-martial",
"court-martialling":"court-martial",
"court-martials":"court-martial",
"courts-martial":"court-martial",
"courtesans":"courtesan",
"courtesies":"courtesy",
"courthouses":"courthouse",
"courtiers":"courtier",
"courtings":"courting",
"courtlier":"courtly",
"courtliest":"courtly",
"courtrooms":"courtroom",
"courtships":"courtship",
"courtyards":"courtyard",
"courts_martial":"court_martial",
"court_martialsor":"court_martial",
"cousins":"cousin",
"cousin-germen":"cousin-german",
"couteaux":"couteau",
"couturiers":"couturier",
"covalences":"covalence",
"covalencies":"covalency",
"coved":"cove",
"coves":"cove",
"coving":"cove",
"covenanted":"covenant",
"covenanting":"covenant",
"covenants":"covenant",
"covered":"cover",
"covering":"cover",
"covers":"cover",
"coverages":"coverage",
"coverings":"covering",
"coverlets":"coverlet",
"coverts":"covert",
"coveted":"covet",
"coveting":"covet",
"covetousnesses":"covetousness",
"coveys":"covey",
"covilles":"coville",
"cowed":"cow",
"cowing":"cow",
"cows":"cow",
"cowages":"cowage",
"cowards":"coward",
"cowardices":"cowardice",
"cowardlinesses":"cowardliness",
"cowbarns":"cowbarn",
"cowberries":"cowberry",
"cowboys":"cowboy",
"cowcatchers":"cowcatcher",
"cowered":"cower",
"cowering":"cower",
"cowers":"cower",
"cowfishes":"cowfish",
"cowhands":"cowhand",
"cowherbs":"cowherb",
"cowherds":"cowherd",
"cowhided":"cowhide",
"cowhides":"cowhide",
"cowhiding":"cowhide",
"cowhouses":"cowhouse",
"cowled":"cowl",
"cowling":"cowl",
"cowls":"cowl",
"cowlings":"cowling",
"cowmen":"cowman",
"cowpeas":"cowpea",
"cowpenses":"cowpens",
"cowpokes":"cowpoke",
"cowpoxes":"cowpox",
"cowpunchers":"cowpuncher",
"cowries":"cowrie",
"cowses":"cows",
"cowsheds":"cowshed",
"cowskins":"cowskin",
"cowslips":"cowslip",
"coxed":"cox",
"coxes":"cox",
"coxing":"cox",
"coxae":"coxa",
"coxas":"coxa",
"coxcombs":"coxcomb",
"coxcombries":"coxcombry",
"coxsackieviruses":"coxsackievirus",
"coxswains":"coxswain",
"coyed":"coy",
"coyer":"coy",
"coyest":"coy",
"coying":"coy",
"coynesses":"coyness",
"coyols":"coyol",
"coyotes":"coyote",
"coyotillos":"coyotillo",
"coypus":"coypu",
"cozened":"cozen",
"cozening":"cozen",
"cozens":"cozen",
"cozenages":"cozenage",
"cozeys":"cozey",
"cozies":"cozie",
"cozinesses":"coziness",
"cozier":"cozy",
"coziest":"cozy",
"CPAs":"CAP",
"cpis":"cpi",
"cprs":"cpr",
"cpses":"cps",
"cpus":"cpu",
"crs":"cr",
"crabbed":"crab",
"crabbing":"crab",
"crabs":"crab",
"crabbednesses":"crabbedness",
"crabbinesses":"crabbiness",
"crabbier":"crabby",
"crabbiest":"crabby",
"crabgrasses":"crabgrass",
"crabmeats":"crabmeat",
"cracidaes":"cracidae",
"cracked":"crack",
"cracking":"crack",
"cracks":"crack",
"crack-ups":"crack-up",
"crackers":"cracker",
"crackerberries":"crackerberry",
"crackerjacks":"crackerjack",
"crackings":"cracking",
"crackled":"crackle",
"crackles":"crackle",
"crackling":"crackle",
"cracklewares":"crackleware",
"cracklings":"crackling",
"cracklier":"crackly",
"crackliest":"crackly",
"cracknels":"cracknel",
"crackpots":"crackpot",
"cracksmen":"cracksman",
"cracows":"cracow",
"cracticidaes":"cracticidae",
"cracticuses":"cracticus",
"cradled":"cradle",
"cradles":"cradle",
"cradling":"cradle",
"cradlesongs":"cradlesong",
"crafted":"craft",
"crafting":"craft",
"crafts":"craft",
"crafters":"crafter",
"craftinesses":"craftiness",
"craftsmen":"craftsman",
"craftsmanships":"craftsmanship",
"craftswomen":"craftswoman",
"craftier":"crafty",
"craftiest":"crafty",
"crags":"crag",
"craggier":"craggy",
"craggiest":"craggy",
"cragsmen":"cragsman",
"crammed":"cram",
"cramming":"cram",
"crams":"cram",
"crambes":"crambe",
"cramboes":"crambo",
"crammers":"crammer",
"cramped":"cramp",
"cramping":"cramp",
"cramps":"cramp",
"crampbarks":"crampbark",
"crampfishes":"crampfish",
"crampons":"crampon",
"crampoons":"crampoon",
"cranberries":"cranberry",
"craned":"crane",
"cranes":"crane",
"craning":"crane",
"cranesbills":"cranesbill",
"crangons":"crangon",
"crangonidaes":"crangonidae",
"craniatas":"craniata",
"craniates":"craniate",
"craniologists":"craniologist",
"craniotomies":"craniotomy",
"crania":"cranium",
"craniums":"cranium",
"cranked":"crank",
"cranking":"crank",
"cranks":"crank",
"crankinesses":"crankiness",
"crankled":"crankle",
"crankling":"crankle",
"crankier":"cranky",
"crankiest":"cranky",
"crannies":"cranny",
"craps":"crap",
"crapauds":"crapaud",
"craped":"crape",
"crapes":"crape",
"craping":"crape",
"crapettes":"crapette",
"crappers":"crapper",
"crappies":"crappie",
"crapses":"craps",
"crapulences":"crapulence",
"crashed":"crash",
"crashes":"crash",
"crashing":"crash",
"crash-dived":"crash-dive",
"crash-diving":"crash-dive",
"crash-landed":"crash-land",
"crash-landing":"crash-land",
"crashers":"crasher",
"crases":"crasis",
"craspedias":"craspedia",
"crasser":"crass",
"crassest":"crass",
"crassitudes":"crassitude",
"crassnesses":"crassness",
"crassostreas":"crassostrea",
"crassulas":"crassula",
"crassulaceaes":"crassulaceae",
"crataeguses":"crataegus",
"crated":"crate",
"crates":"crate",
"crating":"crate",
"cratefuls":"crateful",
"cratered":"crater",
"cratering":"crater",
"craters":"crater",
"cravats":"cravat",
"craved":"crave",
"craves":"crave",
"craving":"crave",
"cravens":"craven",
"cravings":"craving",
"craws":"craw",
"crawdads":"crawdad",
"crawdaddies":"crawdaddy",
"crawfished":"crawfish",
"crawfishes":"crawfish",
"crawfishing":"crawfish",
"crawled":"crawl",
"crawling":"crawl",
"crawls":"crawl",
"crawlers":"crawler",
"crawlings":"crawling",
"crawlier":"crawly",
"crawliest":"crawly",
"craxes":"crax",
"crayfishes":"crayfish",
"crayoned":"crayon",
"crayoning":"crayon",
"crayons":"crayon",
"crayonists":"crayonist",
"crazed":"craze",
"crazes":"craze",
"crazing":"craze",
"crazinesses":"craziness",
"crazier":"crazy",
"crazies":"crazy",
"craziest":"crazy",
"crazyweeds":"crazyweed",
"creaked":"creak",
"creaking":"creak",
"creaks":"creak",
"creakings":"creaking",
"creakier":"creaky",
"creakiest":"creaky",
"creamed":"cream",
"creaming":"cream",
"creams":"cream",
"creamcupses":"creamcups",
"creamers":"creamer",
"creameries":"creamery",
"creaminesses":"creaminess",
"creamier":"creamy",
"creamiest":"creamy",
"creased":"crease",
"creases":"crease",
"creasing":"crease",
"creashaks":"creashak",
"creasier":"creasy",
"creasiest":"creasy",
"created":"create",
"creates":"create",
"creating":"create",
"creatins":"creatin",
"creatines":"creatine",
"creations":"creation",
"creativenesses":"creativeness",
"creativities":"creativity",
"creators":"creator",
"creatures":"creature",
"creches":"creche",
"crecies":"crecy",
"credences":"credence",
"credenda":"credendum",
"credentials":"credential",
"credentialses":"credentials",
"credenzas":"credenza",
"credibilities":"credibility",
"crediblenesses":"credibleness",
"credited":"credit",
"crediting":"credit",
"credits":"credit",
"credos":"credo",
"credulousnesses":"credulousness",
"crees":"cree",
"creeds":"creed",
"creeks":"creek",
"creeped":"creep",
"creeping":"creep",
"creeps":"creep",
"crept":"creep",
"creepers":"creeper",
"creepings":"creeping",
"creepier":"creepy",
"creepiest":"creepy",
"creepy-crawlier":"creepy-crawly",
"creepy-crawlies":"creepy-crawly",
"creepy-crawliest":"creepy-crawly",
"cremated":"cremate",
"cremating":"cremate",
"crematoria":"crematorium",
"crematoriums":"crematorium",
"crematories":"crematory",
"cremes":"creme",
"crenelations":"crenelation",
"crenellations":"crenellation",
"creole-fishes":"creole-fish",
"creosoted":"creosote",
"creosotes":"creosote",
"creosoting":"creosote",
"creped":"crepe",
"crepes":"crepe",
"creping":"crepe",
"crepises":"crepis",
"crepitated":"crepitate",
"crepitates":"crepitate",
"crepitating":"crepitate",
"crepitations":"crepitation",
"crescendi":"crescendo",
"crescendoed":"crescendo",
"crescendoes":"crescendo",
"crescendoing":"crescendo",
"crescendos":"crescendo",
"crescents":"crescent",
"crescentias":"crescentia",
"cresols":"cresol",
"cresses":"cress",
"crested":"crest",
"cresting":"crest",
"crests":"crest",
"cretaceouses":"cretaceous",
"cretins":"cretin",
"crevices":"crevice",
"crews":"crew",
"crewets":"crewet",
"crewmen":"crewman",
"crexes":"crex",
"cribbed":"crib",
"cribbing":"crib",
"cribs":"crib",
"cribbages":"cribbage",
"cribella":"cribellum",
"cricetidaes":"cricetidae",
"cricetuses":"cricetus",
"cricked":"crick",
"cricking":"crick",
"cricks":"crick",
"cricketed":"cricket",
"cricketing":"cricket",
"crickets":"cricket",
"criers":"crier",
"crimed":"crime",
"crimes":"crime",
"criming":"crime",
"criminals":"criminal",
"criminalisms":"criminalism",
"criminalities":"criminality",
"criminalnesses":"criminalness",
"criminated":"criminate",
"criminates":"criminate",
"criminating":"criminate",
"crimped":"crimp",
"crimping":"crimp",
"crimps":"crimp",
"crimpers":"crimper",
"crimpled":"crimple",
"crimpling":"crimple",
"crimpier":"crimpy",
"crimpiest":"crimpy",
"crimsoned":"crimson",
"crimsoning":"crimson",
"crimsons":"crimson",
"cringed":"cringe",
"cringes":"cringe",
"cringing":"cringe",
"cringles":"cringle",
"crinions":"crinion",
"crinkled":"crinkle",
"crinkles":"crinkle",
"crinkling":"crinkle",
"crinkleroots":"crinkleroot",
"crinklier":"crinkly",
"crinkliest":"crinkly",
"crinoideas":"crinoidea",
"crinolines":"crinoline",
"criollos":"criollo",
"crippled":"cripple",
"cripples":"cripple",
"crippling":"cripple",
"crises":"crisis",
"crisped":"crisp",
"crisper":"crisp",
"crispest":"crisp",
"crisping":"crisp",
"crisps":"crisp",
"crispinesses":"crispiness",
"crispnesses":"crispness",
"crispier":"crispy",
"crispiest":"crispy",
"crisscrossed":"crisscross",
"crisscrosses":"crisscross",
"crisscrossing":"crisscross",
"crissa":"crissum",
"cristae":"crista",
"criteria":"criterion",
"criterions":"criterion",
"critics":"critic",
"criticalities":"criticality",
"criticalnesses":"criticalness",
"criticised":"criticise",
"criticises":"criticise",
"criticising":"criticise",
"criticisms":"criticism",
"criticized":"criticize",
"criticizes":"criticize",
"criticizing":"criticize",
"critiques":"critique",
"cros":"cro",
"croaked":"croak",
"croaking":"croak",
"croaks":"croak",
"croakings":"croaking",
"croats":"croat",
"croatians":"croatian",
"crocethias":"crocethia",
"crocheted":"crochet",
"crocheting":"crochet",
"crochets":"crochet",
"crochetings":"crocheting",
"crocked":"crock",
"crocking":"crock",
"crocks":"crock",
"crockeries":"crockery",
"crocodiles":"crocodile",
"crocodilias":"crocodilia",
"crocodilians":"crocodilian",
"crocodiluses":"crocodilus",
"crocodylias":"crocodylia",
"crocodylidaes":"crocodylidae",
"crocodyluses":"crocodylus",
"crocuses":"crocus",
"crocutas":"crocuta",
"croissants":"croissant",
"cromleches":"cromlech",
"cromornes":"cromorne",
"cromwells":"cromwell",
"cronartiums":"cronartium",
"crones":"crone",
"cronies":"crony",
"crooked":"crook",
"crooking":"crook",
"crooks":"crook",
"crookbacks":"crookback",
"crookednesses":"crookedness",
"crooknecks":"crookneck",
"crooned":"croon",
"crooning":"croon",
"crooners":"crooner",
"cropped":"crop",
"cropping":"crop",
"crops":"crop",
"crop-dustings":"crop-dusting",
"croppers":"cropper",
"croqueted":"croquet",
"croqueting":"croquet",
"croquets":"croquet",
"croquettes":"croquette",
"crosiers":"crosier",
"crossed":"cross",
"crosser":"cross",
"crosses":"cross",
"crossest":"cross",
"crossing":"cross",
"cross-checked":"cross-check",
"cross-checking":"cross-check",
"cross-classifications":"cross-classification",
"cross-divisions":"cross-division",
"cross-dressers":"cross-dresser",
"cross-examined":"cross-examine",
"cross-examining":"cross-examine",
"cross-examiners":"cross-examiner",
"cross-eyes":"cross-eye",
"cross-fertilisations":"cross-fertilisation",
"cross-fertilizations":"cross-fertilization",
"cross-fertilized":"cross-fertilize",
"cross-fertilizes":"cross-fertilize",
"cross-fertilizing":"cross-fertilize",
"cross-filed":"cross-file",
"cross-files":"cross-file",
"cross-filing":"cross-file",
"cross-indexed":"cross-index",
"cross-indexes":"cross-index",
"cross-indexing":"cross-index",
"cross-links":"cross-link",
"cross-linkages":"cross-linkage",
"cross-pollinated":"cross-pollinate",
"cross-pollinates":"cross-pollinate",
"cross-pollinating":"cross-pollinate",
"cross-purposes":"cross-purpose",
"cross-questioned":"cross-question",
"cross-questioning":"cross-question",
"cross-questioners":"cross-questioner",
"cross-referred":"cross-refer",
"cross-referring":"cross-refer",
"cross-referenced":"cross-reference",
"cross-references":"cross-reference",
"cross-referencing":"cross-reference",
"cross-stitched":"cross-stitch",
"cross-stitching":"cross-stitch",
"crossbeams":"crossbeam",
"crossbills":"crossbill",
"crossbows":"crossbow",
"crossbowmen":"crossbowman",
"crossbred":"crossbreed",
"crossbreeding":"crossbreed",
"crossbreeds":"crossbreed",
"crossbreedings":"crossbreeding",
"crosscurrents":"crosscurrent",
"crosscuts":"crosscut",
"crosscutting":"crosscut",
"crosshatched":"crosshatch",
"crosshatches":"crosshatch",
"crosshatching":"crosshatch",
"crossheads":"crosshead",
"crossheadings":"crossheading",
"crossings":"crossing",
"crossjacks":"crossjack",
"crossnesses":"crossness",
"crossopterygians":"crossopterygian",
"crossopterygiis":"crossopterygii",
"crossovers":"crossover",
"crosspatches":"crosspatch",
"crosspieces":"crosspiece",
"crossroads":"crossroad",
"crosstalks":"crosstalk",
"crossties":"crosstie",
"crosswalks":"crosswalk",
"crossways":"crossway",
"crosswords":"crossword",
"crotals":"crotal",
"crotalarias":"crotalaria",
"crotalidaes":"crotalidae",
"crotaluses":"crotalus",
"crotaphytuses":"crotaphytus",
"crotches":"crotch",
"crotchets":"crotchet",
"crotchetinesses":"crotchetiness",
"crotons":"croton",
"crotonbugs":"crotonbug",
"crotophagas":"crotophaga",
"crottals":"crottal",
"crottles":"crottle",
"crouched":"crouch",
"crouches":"crouch",
"crouching":"crouch",
"croups":"croup",
"croupes":"croupe",
"crew":"crow",
"crowed":"crow",
"crowing":"crow",
"crows":"crow",
"crowbars":"crowbar",
"crowberries":"crowberry",
"crowded":"crowd",
"crowding":"crowd",
"crowds":"crowd",
"crowfeet":"crowfoot",
"crowfoots":"crowfoot",
"crowings":"crowing",
"crowned":"crown",
"crowning":"crown",
"crowns":"crown",
"crown-of-the-fields":"crown-of-the-field",
"crownbeards":"crownbeard",
"crownworks":"crownwork",
"croziers":"crozier",
"crts":"crt",
"crucialities":"cruciality",
"crucibles":"crucible",
"crucifers":"crucifer",
"cruciferaes":"cruciferae",
"crucifixes":"crucifix",
"crucifixions":"crucifixion",
"crucified":"crucify",
"crucifies":"crucify",
"crucifying":"crucify",
"cruder":"crude",
"crudes":"crude",
"crudest":"crude",
"crudenesses":"crudeness",
"crudities":"crudity",
"crueler":"cruel",
"cruelest":"cruel",
"crueller":"cruel",
"cruellest":"cruel",
"cruelnesses":"cruelness",
"cruelties":"cruelty",
"cruets":"cruet",
"cruised":"cruise",
"cruises":"cruise",
"cruising":"cruise",
"cruisers":"cruiser",
"crullers":"cruller",
"crumbed":"crumb",
"crumbing":"crumb",
"crumbs":"crumb",
"crumbled":"crumble",
"crumbles":"crumble",
"crumbling":"crumble",
"crumblinesses":"crumbliness",
"crumblier":"crumbly",
"crumbliest":"crumbly",
"crumbier":"crumby",
"crumbiest":"crumby",
"crumhorns":"crumhorn",
"crummier":"crummy",
"crummies":"crummy",
"crummiest":"crummy",
"crumped":"crump",
"crumping":"crump",
"crumps":"crump",
"crumpets":"crumpet",
"crumpled":"crumple",
"crumples":"crumple",
"crumpling":"crumple",
"crunched":"crunch",
"crunches":"crunch",
"crunching":"crunch",
"crura":"crus",
"crusaded":"crusade",
"Crusades":"Crusade",
"crusading":"crusade",
"crusaders":"crusader",
"crusadoes":"crusado",
"crusados":"crusado",
"crushed":"crush",
"crushes":"crush",
"crushing":"crush",
"crushings":"crushing",
"crusted":"crust",
"crusting":"crust",
"crusts":"crust",
"crustaceas":"crustacea",
"crustier":"crusty",
"crustiest":"crusty",
"crutched":"crutch",
"crutches":"crutch",
"crutching":"crutch",
"cruces":"crux",
"cruxes":"crux",
"cruzadoes":"cruzado",
"cruzados":"cruzado",
"cruzeiros":"cruzeiro",
"cried":"cry",
"cries":"cry",
"crying":"cry",
"cryaesthesias":"cryaesthesia",
"crybabies":"crybaby",
"cryesthesias":"cryesthesia",
"cryings":"crying",
"cryoanaesthesias":"cryoanaesthesia",
"cryoanesthesias":"cryoanesthesia",
"cryogenicses":"cryogenics",
"cryogenies":"cryogeny",
"cryolites":"cryolite",
"cryopathies":"cryopathy",
"cryoscopies":"cryoscopy",
"cryptacanthodeses":"cryptacanthodes",
"cryptos":"crypto",
"cryptobranchidaes":"cryptobranchidae",
"cryptobranchuses":"cryptobranchus",
"cryptocercidaes":"cryptocercidae",
"cryptocercuses":"cryptocercus",
"cryptocorynes":"cryptocoryne",
"cryptograms":"cryptogram",
"cryptogrammas":"cryptogramma",
"cryptogrammataceaes":"cryptogrammataceae",
"cryptographs":"cryptograph",
"cryptomerias":"cryptomeria",
"cryptomonads":"cryptomonad",
"cryptophyceaes":"cryptophyceae",
"cryptophytas":"cryptophyta",
"cryptophytes":"cryptophyte",
"cryptoproctas":"cryptoprocta",
"cryptorchidisms":"cryptorchidism",
"cryptorchidies":"cryptorchidy",
"cryptorchisms":"cryptorchism",
"cryptotermeses":"cryptotermes",
"cryptotises":"cryptotis",
"crystals":"crystal",
"crystallisations":"crystallisation",
"crystallizations":"crystallization",
"crystallized":"crystallize",
"crystallizes":"crystallize",
"crystallizing":"crystallize",
"cses":"cs",
"csts":"cst",
"cts":"ct",
"ctenidiia":"ctenidium",
"ctenizidaes":"ctenizidae",
"ctenocephalideses":"ctenocephalides",
"ctenophoras":"ctenophora",
"ctenophores":"ctenophore",
"cus":"cu",
"cubbed":"cub",
"cubbing":"cub",
"cubs":"cub",
"cubbies":"cubby",
"cubbyholes":"cubbyhole",
"cubed":"cube",
"cubes":"cube",
"cubing":"cube",
"cubebs":"cubeb",
"cubicles":"cubicle",
"cubicula":"cubiculum",
"cubits":"cubit",
"cubituses":"cubitus",
"cuckolded":"cuckold",
"cuckolding":"cuckold",
"cuckolds":"cuckold",
"cuckooed":"cuckoo",
"cuckooing":"cuckoo",
"cuckoos":"cuckoo",
"cuckooflowers":"cuckooflower",
"cuckoopints":"cuckoopint",
"cuculidaes":"cuculidae",
"cuculiformeses":"cuculiformes",
"cuculuses":"cuculus",
"cucumbers":"cucumber",
"cucumises":"cucumis",
"cucurbitas":"cucurbita",
"cucurbitaceaes":"cucurbitaceae",
"cuds":"cud",
"cudbears":"cudbear",
"cuddled":"cuddle",
"cuddles":"cuddle",
"cuddling":"cuddle",
"cuddlings":"cuddling",
"cuddies":"cuddy",
"cudgeled":"cudgel",
"cudgeling":"cudgel",
"cudgelled":"cudgel",
"cudgelling":"cudgel",
"cudgels":"cudgel",
"cudweeds":"cudweed",
"cued":"cue",
"cues":"cue",
"cuing":"cue",
"cuffed":"cuff",
"cuffing":"cuff",
"cuffs":"cuff",
"cuffses":"cuffs",
"cuisines":"cuisine",
"cukes":"cuke",
"culs":"cul",
"cul-de-sacs":"cul-de-sac",
"culs-de-sac":"cul-de-sac",
"culcitas":"culcita",
"culexes":"culex",
"culicidaes":"culicidae",
"culled":"cull",
"culling":"cull",
"culls":"cull",
"cullenders":"cullender",
"cullies":"cully",
"culmed":"culm",
"culming":"culm",
"culminated":"culminate",
"culminates":"culminate",
"culminating":"culminate",
"culminations":"culmination",
"culottes":"culotte",
"culotteses":"culottes",
"culpae":"culpa",
"culpabilities":"culpability",
"culpablenesses":"culpableness",
"culprits":"culprit",
"cults":"cult",
"cultivated":"cultivate",
"cultivates":"cultivate",
"cultivating":"cultivate",
"cultivators":"cultivator",
"cultures":"culture",
"culti":"cultus",
"cultuses":"cultus",
"cumarones":"cumarone",
"cumbered":"cumber",
"cumbering":"cumber",
"cumbers":"cumber",
"cumberlands":"cumberland",
"cumbersomenesses":"cumbersomeness",
"cumfreys":"cumfrey",
"cumins":"cumin",
"cuminums":"cuminum",
"cumquats":"cumquat",
"cumulated":"cumulate",
"cumulates":"cumulate",
"cumulating":"cumulate",
"cumulocirri":"cumulocirrus",
"cumulonimbi":"cumulonimbus",
"cumulonimbuses":"cumulonimbus",
"cumulostrati":"cumulostratus",
"cumuli":"cumulus",
"cumuluses":"cumulus",
"cunaxas":"cunaxa",
"cunctations":"cunctation",
"cunctators":"cunctator",
"cuneuses":"cuneus",
"cuniculuses":"cuniculus",
"cunners":"cunner",
"cunnilinctuses":"cunnilinctus",
"cunnilinguses":"cunnilingus",
"cunnings":"cunning",
"cunoniaceaes":"cunoniaceae",
"cunts":"cunt",
"cuons":"cuon",
"cupped":"cup",
"cupping":"cup",
"cups":"cup",
"cupboards":"cupboard",
"cupels":"cupel",
"cupflowers":"cupflower",
"cupfuls":"cupful",
"cupsful":"cupful",
"cupids":"cupid",
"cupidities":"cupidity",
"cupolas":"cupola",
"cuppas":"cuppa",
"cuppers":"cupper",
"cupressaceaes":"cupressaceae",
"cupressuses":"cupressus",
"cupules":"cupule",
"cuquenans":"cuquenan",
"curs":"cur",
"curabilities":"curability",
"curablenesses":"curableness",
"curacaos":"curacao",
"curacoas":"curacoa",
"curacies":"curacy",
"curares":"curare",
"curarized":"curarize",
"curarizes":"curarize",
"curarizing":"curarize",
"curates":"curate",
"curatives":"curative",
"curators":"curator",
"curbed":"curb",
"curbing":"curb",
"curbs":"curb",
"curbstones":"curbstone",
"curculios":"curculio",
"curculionidaes":"curculionidae",
"curcumas":"curcuma",
"curded":"curd",
"curding":"curd",
"curds":"curd",
"curdled":"curdle",
"curdles":"curdle",
"curdling":"curdle",
"curdlings":"curdling",
"curdier":"curdy",
"curdiest":"curdy",
"cured":"cure",
"cures":"cure",
"curing":"cure",
"cure-alls":"cure-all",
"curets":"curet",
"curettages":"curettage",
"curetted":"curette",
"curettes":"curette",
"curetting":"curette",
"curettements":"curettement",
"curiae":"curia",
"curies":"curie",
"curios":"curio",
"curiosities":"curiosity",
"curiousnesses":"curiousness",
"curiums":"curium",
"curled":"curl",
"curling":"curl",
"curls":"curl",
"curlers":"curler",
"curlicues":"curlicue",
"curlier":"curly",
"curliest":"curly",
"curly-headses":"curly-heads",
"currajongs":"currajong",
"currants":"currant",
"currawongs":"currawong",
"currencies":"currency",
"currents":"current",
"currentnesses":"currentness",
"curricula":"curriculum",
"curriculums":"curriculum",
"currieries":"curriery",
"curried":"curry",
"curries":"curry",
"currying":"curry",
"currycombed":"currycomb",
"currycombing":"currycomb",
"currycombs":"currycomb",
"cursed":"curse",
"curses":"curse",
"cursing":"curse",
"curst":"curse",
"cursives":"cursive",
"cursors":"cursor",
"cursoriuses":"cursorius",
"curter":"curt",
"curtest":"curt",
"curtailed":"curtail",
"curtailing":"curtail",
"curtails":"curtail",
"curtailments":"curtailment",
"curtained":"curtain",
"curtaining":"curtain",
"curtains":"curtain",
"curtnesses":"curtness",
"curtseyed":"curtsey",
"curtseying":"curtsey",
"curtseys":"curtsey",
"curtsied":"curtsy",
"curtsies":"curtsy",
"curtsying":"curtsy",
"curvaceousnesses":"curvaceousness",
"curvatures":"curvature",
"curved":"curve",
"curves":"curve",
"curving":"curve",
"curveted":"curvet",
"curveting":"curvet",
"curvets":"curvet",
"curvetted":"curvet",
"curvetting":"curvet",
"curvier":"curvy",
"curviest":"curvy",
"cuscutas":"cuscuta",
"cush-cushes":"cush-cush",
"cushats":"cushat",
"cushaws":"cushaw",
"cushioned":"cushion",
"cushioning":"cushion",
"cushions":"cushion",
"cushionings":"cushioning",
"cushier":"cushy",
"cushiest":"cushy",
"cusks":"cusk",
"cusps":"cusp",
"cuspids":"cuspid",
"cuspidors":"cuspidor",
"cussed":"cuss",
"cusses":"cuss",
"cussing":"cuss",
"cussednesses":"cussedness",
"custards":"custard",
"custodians":"custodian",
"custodies":"custody",
"customs":"custom",
"customaries":"customary",
"customers":"customer",
"customhouses":"customhouse",
"customized":"customize",
"customizes":"customize",
"customizing":"customize",
"customses":"customs",
"customs_duties":"customs_duty",
"custodes":"custos",
"cuts":"cut",
"cutting":"cut",
"cut-and-thrusts":"cut-and-thrust",
"cut-ins":"cut-in",
"cutaways":"cutaway",
"cutches":"cutch",
"cutcherries":"cutcherry",
"cutcheries":"cutchery",
"cutenesses":"cuteness",
"cuterebras":"cuterebra",
"cuterebridaes":"cuterebridae",
"cuticles":"cuticle",
"cuticulae":"cuticula",
"cutinized":"cutinize",
"cutinizes":"cutinize",
"cutinizing":"cutinize",
"cutes":"cutis",
"cutises":"cutis",
"cutlases":"cutlas",
"cutlasses":"cutlass",
"cutlassfishes":"cutlassfish",
"cutlers":"cutler",
"cutleries":"cutlery",
"cutlets":"cutlet",
"cutoffs":"cutoff",
"cutpurses":"cutpurse",
"cutters":"cutter",
"cuttings":"cutting",
"cuttles":"cuttle",
"cuttlefishes":"cuttlefish",
"cutties":"cutty",
"cvas":"cva",
"cwms":"cwm",
"cwts":"cwt",
"cyamopses":"cyamopsis",
"cyamuses":"cyamus",
"cyanamids":"cyanamid",
"cyanamides":"cyanamide",
"cyanided":"cyanide",
"cyanides":"cyanide",
"cyaniding":"cyanide",
"cyanobacterias":"cyanobacteria",
"cyanocittas":"cyanocitta",
"cyanocobalamins":"cyanocobalamin",
"cyanophyceaes":"cyanophyceae",
"cyanophytas":"cyanophyta",
"cyanuramides":"cyanuramide",
"cyatheas":"cyathea",
"cyatheaceaes":"cyatheaceae",
"cybeles":"cybele",
"cyberspaces":"cyberspace",
"cyborgs":"cyborg",
"cycadaceaes":"cycadaceae",
"cycadaleses":"cycadales",
"cycadofilicaleses":"cycadofilicales",
"cycadophytas":"cycadophyta",
"cycadophytinas":"cycadophytina",
"cycadopsidas":"cycadopsida",
"cycases":"cycas",
"cycladeses":"cyclades",
"cyclamens":"cyclamen",
"cycled":"cycle",
"cycles":"cycle",
"cycling":"cycle",
"cycles/seconds":"cycles/second",
"cyclicities":"cyclicity",
"cycliophoras":"cycliophora",
"cyclists":"cyclist",
"cyclolomas":"cycloloma",
"cyclones":"cyclone",
"cyclopaedias":"cyclopaedia",
"cyclopedias":"cyclopedia",
"cyclophoruses":"cyclophorus",
"Cyclopes":"Cyclops",
"Cyclopses":"Cyclops",
"cyclopteridaes":"cyclopteridae",
"cyclopteruses":"cyclopterus",
"cycloramas":"cyclorama",
"cycloses":"cyclosis",
"cyclosoruses":"cyclosorus",
"cyclosporeaes":"cyclosporeae",
"cyclostomatas":"cyclostomata",
"cyclothymias":"cyclothymia",
"cycnocheses":"cycnoches",
"cyders":"cyder",
"cydippeas":"cydippea",
"cydippidas":"cydippida",
"cydippideas":"cydippidea",
"cydonias":"cydonia",
"cygnuses":"cygnus",
"cylinders":"cylinder",
"cylindricalities":"cylindricality",
"cylindricalnesses":"cylindricalness",
"cylices":"cylix",
"cylikes":"cylix",
"cymae":"cyma",
"cymas":"cyma",
"cymatiidaes":"cymatiidae",
"cymatiums":"cymatium",
"cymbals":"cymbal",
"cymbalos":"cymbalo",
"cymbids":"cymbid",
"cymbidiums":"cymbidium",
"cymlings":"cymling",
"cymographs":"cymograph",
"cymrus":"cymru",
"cynaras":"cynara",
"cynics":"cynic",
"cynipidaes":"cynipidae",
"cynipses":"cynips",
"cynocephalidaes":"cynocephalidae",
"cynocephaluses":"cynocephalus",
"cynodons":"cynodon",
"cynodontias":"cynodontia",
"cynoglossidaes":"cynoglossidae",
"cynoglossums":"cynoglossum",
"cynomyses":"cynomys",
"cynopteruses":"cynopterus",
"cynoscephalaes":"cynoscephalae",
"cynoscions":"cynoscion",
"cynthias":"cynthia",
"cyons":"cyon",
"cyperaceaes":"cyperaceae",
"cyperuses":"cyperus",
"cyphered":"cypher",
"cyphering":"cypher",
"cyphers":"cypher",
"cyphomandras":"cyphomandra",
"cypraeas":"cypraea",
"cypraeidaes":"cypraeidae",
"cypres":"cypre",
"cypresses":"cypress",
"cyprians":"cyprian",
"cyprinids":"cyprinid",
"cyprinidaes":"cyprinidae",
"cypriniformeses":"cypriniformes",
"cyprinodontidaes":"cyprinodontidae",
"cyprinuses":"cyprinus",
"Cypriots":"Cypriot",
"cypriotes":"cypriote",
"cypripediums":"cypripedium",
"cyproheptadines":"cyproheptadine",
"cypselae":"cypsela",
"cyrillas":"cyrilla",
"cyrilliaceaes":"cyrilliaceae",
"cyrillics":"cyrillic",
"cyrtomiums":"cyrtomium",
"cysts":"cyst",
"cystectomies":"cystectomy",
"cysticerci":"cysticercus",
"cystoceles":"cystocele",
"cystoliths":"cystolith",
"cystoparalyses":"cystoparalysis",
"cystophoras":"cystophora",
"cystoplegias":"cystoplegia",
"cystopterises":"cystopteris",
"cystotomies":"cystotomy",
"cythereas":"cytherea",
"cytisuses":"cytisus",
"cytoarchitectonicses":"cytoarchitectonics",
"cytoarchitectures":"cytoarchitecture",
"czars":"czar",
"czarevnas":"czarevna",
"czarinas":"czarina",
"czaritzas":"czaritza",
"czeches":"czech",
"czechoslovakians":"czechoslovakian",
"ds":"d",
"d-days":"d-day",
"d-layers":"d-layer",
"DAs":"DA",
"dabbed":"dab",
"dabbing":"dab",
"dabs":"dab",
"dabas":"daba",
"dabbled":"dabble",
"dabbles":"dabble",
"dabbling":"dabble",
"dabblers":"dabbler",
"dabchicks":"dabchick",
"daboecias":"daboecia",
"daccas":"dacca",
"daces":"dace",
"dacelos":"dacelo",
"dachshunds":"dachshund",
"dachsies":"dachsie",
"dacninaes":"dacninae",
"dacoits":"dacoit",
"dacoities":"dacoity",
"dacrons":"dacron",
"dacrycarpuses":"dacrycarpus",
"dacrydiums":"dacrydium",
"dacrymyceses":"dacrymyces",
"dacrymycetaceaes":"dacrymycetaceae",
"dacryocysts":"dacryocyst",
"dactyls":"dactyl",
"dactylises":"dactylis",
"dactylocteniums":"dactyloctenium",
"dactylologies":"dactylology",
"dactylopiidaes":"dactylopiidae",
"dactylopiuses":"dactylopius",
"dactylopteridaes":"dactylopteridae",
"dactylopteruses":"dactylopterus",
"dactylorhizas":"dactylorhiza",
"dactyloscopidaes":"dactyloscopidae",
"dads":"dad",
"dadas":"dada",
"dadaisms":"dadaism",
"daddies":"daddy",
"dadoes":"dado",
"dados":"dado",
"daemons":"daemon",
"daffed":"daff",
"daffing":"daff",
"daffos":"daffo",
"daffodils":"daffodil",
"daffier":"daffy",
"daffiest":"daffy",
"daflas":"dafla",
"dafter":"daft",
"daftest":"daft",
"daftnesses":"daftness",
"dags":"dag",
"dagames":"dagame",
"daggas":"dagga",
"daggered":"dagger",
"daggering":"dagger",
"daggers":"dagger",
"dagoes":"dago",
"dagos":"dago",
"daguerreotyped":"daguerreotype",
"daguerreotyping":"daguerreotype",
"dahs":"dah",
"dahls":"dahl",
"dahlias":"dahlia",
"dahomeys":"dahomey",
"daikons":"daikon",
"dails":"dail",
"dailies":"daily",
"daimios":"daimio",
"daymio":"daimio",
"daymios":"daimio",
"daimons":"daimon",
"daimyos":"daimyo",
"daintinesses":"daintiness",
"daintier":"dainty",
"dainties":"dainty",
"daintiest":"dainty",
"daiquiris":"daiquiri",
"dairies":"dairy",
"dairyings":"dairying",
"dairymaids":"dairymaid",
"dairymen":"dairyman",
"dairywomen":"dairywoman",
"daises":"dais",
"daisies":"daisy",
"daisybushes":"daisybush",
"daks":"dak",
"dakars":"dakar",
"dakoits":"dakoit",
"dakoities":"dakoity",
"Dakotas":"Dakota",
"dals":"dal",
"dalasis":"dalasi",
"dalbergias":"dalbergia",
"dales":"dale",
"daleas":"dalea",
"dalesmen":"dalesman",
"dalliances":"dalliance",
"dalliers":"dallier",
"dallisgrasses":"dallisgrass",
"dallied":"dally",
"dallies":"dally",
"dallying":"dally",
"dalmatians":"dalmatian",
"dalos":"dalo",
"daltons":"dalton",
"daltonisms":"daltonism",
"dammed":"dam",
"damming":"dam",
"dams":"dam",
"damas":"dama",
"damaged":"damage",
"damages":"damage",
"damaging":"damage",
"damageses":"damages",
"damaliscuses":"damaliscus",
"damars":"damar",
"damaras":"damara",
"damascened":"damascene",
"damascening":"damascene",
"damascuses":"damascus",
"damasked":"damask",
"damasking":"damask",
"dames":"dame",
"damgalnunnas":"damgalnunna",
"daminozides":"daminozide",
"damkinas":"damkina",
"dammars":"dammar",
"damned":"damn",
"damning":"damn",
"damns":"damn",
"damnations":"damnation",
"damndest":"damned",
"damneder":"damned",
"damnedest":"damned",
"damnified":"damnify",
"damnifies":"damnify",
"damnifying":"damnify",
"damoiselles":"damoiselle",
"damosels":"damosel",
"damozels":"damozel",
"damped":"damp",
"damper":"damp",
"dampest":"damp",
"damping":"damp",
"damps":"damp",
"dampened":"dampen",
"dampening":"dampen",
"dampens":"dampen",
"dampenings":"dampening",
"dampnesses":"dampness",
"damsels":"damsel",
"damselfishes":"damselfish",
"damselflies":"damselfly",
"damsons":"damson",
"danas":"dana",
"danaeas":"danaea",
"danaids":"danaid",
"danaidaes":"danaidae",
"danauses":"danaus",
"danced":"dance",
"dances":"dance",
"dancing":"dance",
"dancers":"dancer",
"dancings":"dancing",
"dandelions":"dandelion",
"danders":"dander",
"dandified":"dandify",
"dandifies":"dandify",
"dandifying":"dandify",
"dandled":"dandle",
"dandling":"dandle",
"dandier":"dandy",
"dandies":"dandy",
"dandiest":"dandy",
"daneworts":"danewort",
"dangaleats":"dangaleat",
"dangers":"danger",
"danglas":"dangla",
"dangled":"dangle",
"dangles":"dangle",
"dangling":"dangle",
"dangleberries":"dangleberry",
"danglings":"dangling",
"danios":"danio",
"danishes":"danish",
"danker":"dank",
"dankest":"dank",
"danknesses":"dankness",
"danmarks":"danmark",
"dano-norwegians":"dano-norwegian",
"danseurs":"danseur",
"danseuses":"danseuse",
"dantes":"dante",
"danus":"danu",
"danubes":"danube",
"danzigs":"danzig",
"daoisms":"daoism",
"dapped":"dap",
"dapping":"dap",
"daps":"dap",
"daphnias":"daphnia",
"dappernesses":"dapperness",
"dappled":"dapple",
"dapples":"dapple",
"dappling":"dapple",
"dapple-grays":"dapple-gray",
"dapple-greys":"dapple-grey",
"dappled-grays":"dappled-gray",
"dappled-greys":"dappled-grey",
"dapsangs":"dapsang",
"dards":"dard",
"dardanelleses":"dardanelles",
"dardics":"dardic",
"dared":"dare",
"dares":"dare",
"daring":"dare",
"daredevils":"daredevil",
"daredevilries":"daredevilry",
"daredeviltries":"daredeviltry",
"daris":"dari",
"darings":"daring",
"darker":"dark",
"darkest":"dark",
"darks":"dark",
"darkened":"darken",
"darkening":"darken",
"darkens":"darken",
"darkenings":"darkening",
"darkeys":"darkey",
"darkies":"darkie",
"darkled":"darkle",
"darkling":"darkle",
"darknesses":"darkness",
"darlings":"darling",
"darlingtonias":"darlingtonia",
"darmeras":"darmera",
"darned":"darn",
"darning":"darn",
"darns":"darn",
"darnels":"darnel",
"darted":"dart",
"darting":"dart",
"darts":"dart",
"dartboards":"dartboard",
"darters":"darter",
"darvons":"darvon",
"darwins":"darwin",
"dases":"das",
"dashed":"dash",
"dashes":"dash",
"dashing":"dash",
"dashboards":"dashboard",
"dasheens":"dasheen",
"dashikis":"dashiki",
"dassies":"dassie",
"dasyatidaes":"dasyatidae",
"dasyatises":"dasyatis",
"dasypodidaes":"dasypodidae",
"dasyproctas":"dasyprocta",
"dasyproctidaes":"dasyproctidae",
"dasypuses":"dasypus",
"dasyurids":"dasyurid",
"dasyuridaes":"dasyuridae",
"dasyuruses":"dasyurus",
"dats":"dat",
"datas":"data",
"dataries":"datary",
"dated":"date",
"dates":"date",
"dating":"date",
"datelined":"dateline",
"datelines":"dateline",
"datelining":"dateline",
"datives":"dative",
"datos":"dato",
"datrils":"datril",
"data":"datum",
"datums":"datum",
"daturas":"datura",
"daubed":"daub",
"daubing":"daub",
"daubs":"daub",
"daubentonias":"daubentonia",
"daubentoniidaes":"daubentoniidae",
"daubings":"daubing",
"daucuses":"daucus",
"daughters":"daughter",
"daughters-in-law":"daughter-in-law",
"daunted":"daunt",
"daunting":"daunt",
"daunts":"daunt",
"dauntlessnesses":"dauntlessness",
"davalliaceaes":"davalliaceae",
"daviesias":"daviesia",
"daws":"daw",
"dawdled":"dawdle",
"dawdles":"dawdle",
"dawdling":"dawdle",
"dawdlers":"dawdler",
"dawdlings":"dawdling",
"dawned":"dawn",
"dawning":"dawn",
"dawns":"dawn",
"dawnings":"dawning",
"days":"day",
"dayaks":"dayak",
"daybeds":"daybed",
"daybooks":"daybook",
"daybreaks":"daybreak",
"daycares":"daycare",
"daydreamed":"daydream",
"daydreaming":"daydream",
"daydreams":"daydream",
"daydreamers":"daydreamer",
"dayflowers":"dayflower",
"dayflies":"dayfly",
"daylights":"daylight",
"daylilies":"daylily",
"daypros":"daypro",
"dayses":"days",
"daysprings":"dayspring",
"daytimes":"daytime",
"dazed":"daze",
"dazes":"daze",
"dazing":"daze",
"dazzled":"dazzle",
"dazzles":"dazzle",
"dazzling":"dazzle",
"dbs":"db",
"dbmses":"dbms",
"dcs":"dc",
"dds":"dd",
"ddses":"dds",
"de-emphasized":"de-emphasize",
"de-emphasizes":"de-emphasize",
"de-emphasizing":"de-emphasize",
"de-escalated":"de-escalate",
"de-escalates":"de-escalate",
"de-escalating":"de-escalate",
"deaconed":"deacon",
"deaconing":"deacon",
"deacons":"deacon",
"deaconries":"deaconry",
"deactivated":"deactivate",
"deactivates":"deactivate",
"deactivating":"deactivate",
"deactivations":"deactivation",
"deadbeats":"deadbeat",
"deadbolts":"deadbolt",
"deadened":"deaden",
"deadening":"deaden",
"deadens":"deaden",
"deadends":"deadend",
"deadenings":"deadening",
"deadeyes":"deadeye",
"deadlines":"deadline",
"deadlinesses":"deadliness",
"deadlocked":"deadlock",
"deadlocking":"deadlock",
"deadlocks":"deadlock",
"deadlier":"deadly",
"deadliest":"deadly",
"deaerated":"deaerate",
"deaerating":"deaerate",
"deafer":"deaf",
"deafest":"deaf",
"deafs":"deaf",
"deaf-aids":"deaf-aid",
"deaf-mutes":"deaf-mute",
"deaf-mutenesses":"deaf-muteness",
"deaf-mutisms":"deaf-mutism",
"deafened":"deafen",
"deafening":"deafen",
"deafens":"deafen",
"dealing":"deal",
"deals":"deal",
"dealt":"deal",
"dealers":"dealer",
"dealerships":"dealership",
"dealfishes":"dealfish",
"dealings":"dealing",
"dealingses":"dealings",
"deaminated":"deaminate",
"deaminating":"deaminate",
"deaminized":"deaminize",
"deaminizes":"deaminize",
"deaminizing":"deaminize",
"deans":"dean",
"deaneries":"deanery",
"deanships":"deanship",
"dearer":"dear",
"dearest":"dear",
"dears":"dear",
"dearests":"dearest",
"dearies":"dearie",
"dearnesses":"dearness",
"dearths":"dearth",
"deaths":"death",
"deathbeds":"deathbed",
"deathblows":"deathblow",
"deathrates":"deathrate",
"deathwatches":"deathwatch",
"debs":"deb",
"debacles":"debacle",
"debarred":"debar",
"debarring":"debar",
"debars":"debar",
"debarked":"debark",
"debarking":"debark",
"debarks":"debark",
"debarkations":"debarkation",
"debarments":"debarment",
"debarrings":"debarring",
"debased":"debase",
"debases":"debase",
"debasing":"debase",
"debasements":"debasement",
"debated":"debate",
"debates":"debate",
"debating":"debate",
"debaters":"debater",
"debauched":"debauch",
"debauches":"debauch",
"debauching":"debauch",
"debauchees":"debauchee",
"debauchers":"debaucher",
"debaucheries":"debauchery",
"debentures":"debenture",
"debilitated":"debilitate",
"debilitates":"debilitate",
"debilitating":"debilitate",
"debilitations":"debilitation",
"debilities":"debility",
"debited":"debit",
"debiting":"debit",
"debits":"debit",
"debouched":"debouch",
"debouches":"debouch",
"debouching":"debouch",
"debriefed":"debrief",
"debriefing":"debrief",
"debrises":"debris",
"debts":"debt",
"debtors":"debtor",
"debugged":"debug",
"debugging":"debug",
"debugs":"debug",
"debunked":"debunk",
"debunking":"debunk",
"debunks":"debunk",
"debunkings":"debunking",
"debused":"debus",
"debuses":"debus",
"debusing":"debus",
"debussed":"debus",
"debusses":"debus",
"debussing":"debus",
"debuts":"debut",
"debutantes":"debutante",
"decs":"dec",
"decades":"decade",
"decadencies":"decadency",
"decadents":"decadent",
"decadrons":"decadron",
"decafs":"decaf",
"decagrams":"decagram",
"decahedra":"decahedron",
"decahedrons":"decahedron",
"decals":"decal",
"decalcified":"decalcify",
"decalcifies":"decalcify",
"decalcifying":"decalcify",
"decalcomanias":"decalcomania",
"decaliters":"decaliter",
"decalitres":"decalitre",
"decalogues":"decalogue",
"decameters":"decameter",
"decametres":"decametre",
"decamped":"decamp",
"decamping":"decamp",
"decamps":"decamp",
"decampments":"decampment",
"decanted":"decant",
"decanting":"decant",
"decants":"decant",
"decanters":"decanter",
"decapitated":"decapitate",
"decapitates":"decapitate",
"decapitating":"decapitate",
"decapitations":"decapitation",
"decapods":"decapod",
"decapodas":"decapoda",
"decapteruses":"decapterus",
"decarbonated":"decarbonate",
"decarbonating":"decarbonate",
"decarbonized":"decarbonize",
"decarbonizes":"decarbonize",
"decarbonizing":"decarbonize",
"decarburized":"decarburize",
"decarburizes":"decarburize",
"decarburizing":"decarburize",
"decasualized":"decasualize",
"decasualizing":"decasualize",
"decayed":"decay",
"decaying":"decay",
"decays":"decay",
"deceased":"decease",
"deceases":"decease",
"deceasing":"decease",
"deceaseds":"deceased",
"decedents":"decedent",
"deceits":"deceit",
"deceitfulnesses":"deceitfulness",
"deceived":"deceive",
"deceives":"deceive",
"deceiving":"deceive",
"deceivers":"deceiver",
"decelerated":"decelerate",
"decelerates":"decelerate",
"decelerating":"decelerate",
"decelerations":"deceleration",
"Decembers":"December",
"decemviri":"decemvir",
"decemvirs":"decemvir",
"decencies":"decency",
"decennaries":"decennary",
"decenniums":"decennium",
"decentralisations":"decentralisation",
"decentralizations":"decentralization",
"decentralized":"decentralize",
"decentralizes":"decentralize",
"decentralizing":"decentralize",
"deceptions":"deception",
"deceptivenesses":"deceptiveness",
"decibels":"decibel",
"decided":"decide",
"decides":"decide",
"deciding":"decide",
"decidings":"deciding",
"deciduae":"decidua",
"deciduas":"decidua",
"decigrams":"decigram",
"deciliters":"deciliter",
"decilitres":"decilitre",
"decimals":"decimal",
"decimalisations":"decimalisation",
"decimalizations":"decimalization",
"decimalized":"decimalize",
"decimalizes":"decimalize",
"decimalizing":"decimalize",
"decimated":"decimate",
"decimates":"decimate",
"decimating":"decimate",
"decimeters":"decimeter",
"decimetres":"decimetre",
"deciphered":"decipher",
"deciphering":"decipher",
"deciphers":"decipher",
"decipherments":"decipherment",
"decisions":"decision",
"decisivenesses":"decisiveness",
"decked":"deck",
"decking":"deck",
"decks":"deck",
"deckhands":"deckhand",
"deckhouses":"deckhouse",
"deckles":"deckle",
"declaimed":"declaim",
"declaiming":"declaim",
"declaims":"declaim",
"declarations":"declaration",
"declaratives":"declarative",
"declared":"declare",
"declares":"declare",
"declaring":"declare",
"declassed":"declass",
"declassing":"declass",
"declassified":"declassify",
"declassifies":"declassify",
"declassifying":"declassify",
"declinations":"declination",
"declined":"decline",
"declines":"decline",
"declining":"decline",
"declinometers":"declinometer",
"declivities":"declivity",
"decoagulants":"decoagulant",
"decocted":"decoct",
"decocting":"decoct",
"decocts":"decoct",
"decoded":"decode",
"decodes":"decode",
"decoding":"decode",
"decodings":"decoding",
"decollated":"decollate",
"decollating":"decollate",
"decolonisations":"decolonisation",
"decolonizations":"decolonization",
"decolonized":"decolonize",
"decolonizing":"decolonize",
"decolored":"decolor",
"decoloring":"decolor",
"decolors":"decolor",
"decommissioned":"decommission",
"decommissioning":"decommission",
"decomposed":"decompose",
"decomposes":"decompose",
"decomposing":"decompose",
"decompositions":"decomposition",
"decompounded":"decompound",
"decompounding":"decompound",
"decompressed":"decompress",
"decompresses":"decompress",
"decompressing":"decompress",
"decompressings":"decompressing",
"decompressions":"decompression",
"deconcentrated":"deconcentrate",
"deconcentrates":"deconcentrate",
"deconcentrating":"deconcentrate",
"decongested":"decongest",
"decongesting":"decongest",
"deconstructions":"deconstruction",
"deconstructionisms":"deconstructionism",
"decontaminated":"decontaminate",
"decontaminating":"decontaminate",
"decontrolled":"decontrol",
"decontrolling":"decontrol",
"decontrols":"decontrol",
"decors":"decor",
"decorated":"decorate",
"decorates":"decorate",
"decorating":"decorate",
"decorations":"decoration",
"decorators":"decorator",
"decorousnesses":"decorousness",
"decorticated":"decorticate",
"decorticating":"decorticate",
"decorums":"decorum",
"decoupled":"decouple",
"decoupling":"decouple",
"decoyed":"decoy",
"decoying":"decoy",
"decoys":"decoy",
"decreased":"decrease",
"decreases":"decrease",
"decreasing":"decrease",
"decreed":"decree",
"decreeing":"decree",
"decrees":"decree",
"decrements":"decrement",
"decrepitated":"decrepitate",
"decrepitates":"decrepitate",
"decrepitating":"decrepitate",
"decrepitudes":"decrepitude",
"decrescendi":"decrescendo",
"decrescendos":"decrescendo",
"decried":"decry",
"decries":"decry",
"decrying":"decry",
"decrypted":"decrypt",
"decrypting":"decrypt",
"decryptions":"decryption",
"decumarias":"decumaria",
"decumaries":"decumary",
"decuries":"decury",
"decussated":"decussate",
"decussating":"decussate",
"deds":"ded",
"dedicated":"dedicate",
"dedicates":"dedicate",
"dedicating":"dedicate",
"dedications":"dedication",
"dedicators":"dedicator",
"deduced":"deduce",
"deduces":"deduce",
"deducing":"deduce",
"deducted":"deduct",
"deducting":"deduct",
"deducts":"deduct",
"deductibles":"deductible",
"deductions":"deduction",
"deeded":"deed",
"deeding":"deed",
"deeds":"deed",
"deedboxes":"deedbox",
"deedses":"deeds",
"deemed":"deem",
"deeming":"deem",
"deems":"deem",
"deeper":"deep",
"deepest":"deep",
"deeps":"deep",
"deep-fried":"deep-fry",
"deep-fries":"deep-fry",
"deep-frying":"deep-fry",
"deep-kissed":"deep-kiss",
"deep-kissing":"deep-kiss",
"deep-sixed":"deep-six",
"deep-sixes":"deep-six",
"deep-sixing":"deep-six",
"deepened":"deepen",
"deepening":"deepen",
"deepens":"deepen",
"deepfreezed":"deepfreeze",
"deepfreezes":"deepfreeze",
"deepfreezing":"deepfreeze",
"deepfroze":"deepfreeze",
"deepfrozen":"deepfreeze",
"deepnesses":"deepness",
"deers":"deer",
"deerberries":"deerberry",
"deerhounds":"deerhound",
"defaced":"deface",
"defaces":"deface",
"defacing":"deface",
"defacements":"defacement",
"defalcated":"defalcate",
"defalcating":"defalcate",
"defalcations":"defalcation",
"defamations":"defamation",
"defamed":"defame",
"defames":"defame",
"defaming":"defame",
"defamers":"defamer",
"defanged":"defang",
"defanging":"defang",
"defatted":"defat",
"defatting":"defat",
"defaulted":"default",
"defaulting":"default",
"defaults":"default",
"defaulters":"defaulter",
"defeated":"defeat",
"defeating":"defeat",
"defeats":"defeat",
"defeateds":"defeated",
"defeatists":"defeatist",
"defecated":"defecate",
"defecates":"defecate",
"defecating":"defecate",
"defecations":"defecation",
"defected":"defect",
"defecting":"defect",
"defects":"defect",
"defections":"defection",
"defectives":"defective",
"defectivenesses":"defectiveness",
"defectors":"defector",
"defences":"defence",
"defencelessnesses":"defencelessness",
"defended":"defend",
"defending":"defend",
"defends":"defend",
"defendants":"defendant",
"defenders":"defender",
"defensed":"defense",
"defenses":"defense",
"defensing":"defense",
"defenselessnesses":"defenselessness",
"defensives":"defensive",
"deferred":"defer",
"deferring":"defer",
"defers":"defer",
"deferences":"deference",
"deferments":"deferment",
"deferrals":"deferral",
"defiances":"defiance",
"deficiencies":"deficiency",
"deficits":"deficit",
"defiladed":"defilade",
"defilading":"defilade",
"defiled":"defile",
"defiles":"defile",
"defiling":"defile",
"defilements":"defilement",
"defined":"define",
"defines":"define",
"defining":"define",
"definienda":"definiendum",
"definientia":"definiens",
"definings":"defining",
"definitenesses":"definiteness",
"definitions":"definition",
"deflagrated":"deflagrate",
"deflagrating":"deflagrate",
"deflated":"deflate",
"deflates":"deflate",
"deflating":"deflate",
"deflected":"deflect",
"deflecting":"deflect",
"deflects":"deflect",
"deflections":"deflection",
"deflexions":"deflexion",
"deflowered":"deflower",
"deflowering":"deflower",
"deflowers":"deflower",
"defogged":"defog",
"defogging":"defog",
"defoliated":"defoliate",
"defoliates":"defoliate",
"defoliating":"defoliate",
"deforced":"deforce",
"deforcing":"deforce",
"deforested":"deforest",
"deforesting":"deforest",
"deforests":"deforest",
"deforestations":"deforestation",
"deformed":"deform",
"deforming":"deform",
"deforms":"deform",
"deformations":"deformation",
"deformities":"deformity",
"defrauded":"defraud",
"defrauding":"defraud",
"defrauds":"defraud",
"defrayed":"defray",
"defraying":"defray",
"defrayals":"defrayal",
"defrayments":"defrayment",
"defrocked":"defrock",
"defrocking":"defrock",
"defrocks":"defrock",
"defrosted":"defrost",
"defrosting":"defrost",
"defrosts":"defrost",
"defrosters":"defroster",
"defter":"deft",
"deftest":"deft",
"deftnesses":"deftness",
"defunctnesses":"defunctness",
"defused":"defuse",
"defusing":"defuse",
"defusings":"defusing",
"defied":"defy",
"defies":"defy",
"defying":"defy",
"degases":"degas",
"degassed":"degas",
"degasses":"degas",
"degassing":"degas",
"degaussed":"degauss",
"degausses":"degauss",
"degaussing":"degauss",
"degeneracies":"degeneracy",
"degenerated":"degenerate",
"degenerates":"degenerate",
"degenerating":"degenerate",
"degenerations":"degeneration",
"deglutitions":"deglutition",
"degradations":"degradation",
"degraded":"degrade",
"degrades":"degrade",
"degrading":"degrade",
"degreased":"degrease",
"degreasing":"degrease",
"degrees":"degree",
"degummed":"degum",
"degumming":"degum",
"degusted":"degust",
"degusting":"degust",
"dehisced":"dehisce",
"dehiscing":"dehisce",
"dehorned":"dehorn",
"dehorning":"dehorn",
"dehorted":"dehort",
"dehorting":"dehort",
"dehumanisations":"dehumanisation",
"dehumanizations":"dehumanization",
"dehumanized":"dehumanize",
"dehumanizing":"dehumanize",
"dehumidified":"dehumidify",
"dehumidifies":"dehumidify",
"dehumidifying":"dehumidify",
"dehydrated":"dehydrate",
"dehydrates":"dehydrate",
"dehydrating":"dehydrate",
"dehydrations":"dehydration",
"dehydrogenated":"dehydrogenate",
"dehydrogenating":"dehydrogenate",
"dehydrogenized":"dehydrogenize",
"dehydrogenizes":"dehydrogenize",
"dehydrogenizing":"dehydrogenize",
"dehydroretinols":"dehydroretinol",
"deiced":"deice",
"deices":"deice",
"deicing":"deice",
"deicers":"deicer",
"deictics":"deictic",
"deifications":"deification",
"deified":"deify",
"deifies":"deify",
"deifying":"deify",
"deigned":"deign",
"deigning":"deign",
"deigns":"deign",
"deionized":"deionize",
"deionizing":"deionize",
"deisms":"deism",
"deists":"deist",
"deities":"deity",
"dejected":"deject",
"dejecting":"deject",
"dejects":"deject",
"dejections":"dejection",
"dejeuners":"dejeuner",
"dekagrams":"dekagram",
"dekaliters":"dekaliter",
"dekalitres":"dekalitre",
"dekameters":"dekameter",
"dekametres":"dekametre",
"dekkos":"dekko",
"delaireas":"delairea",
"delaminated":"delaminate",
"delaminates":"delaminate",
"delaminating":"delaminate",
"delated":"delate",
"delating":"delate",
"delawares":"delaware",
"Delawareans":"Delawarean",
"delawarians":"delawarian",
"delayed":"delay",
"delaying":"delay",
"delays":"delay",
"deled":"dele",
"deleing":"dele",
"deles":"dele",
"delectabilities":"delectability",
"delectated":"delectate",
"delectating":"delectate",
"delectations":"delectation",
"delegacies":"delegacy",
"delegalized":"delegalize",
"delegalizing":"delegalize",
"delegated":"delegate",
"delegates":"delegate",
"delegating":"delegate",
"delegatings":"delegating",
"delegations":"delegation",
"deleted":"delete",
"deletes":"delete",
"deleting":"delete",
"deletions":"deletion",
"delhis":"delhi",
"delis":"deli",
"deliberated":"deliberate",
"deliberates":"deliberate",
"deliberating":"deliberate",
"deliberatenesses":"deliberateness",
"deliberations":"deliberation",
"delicacies":"delicacy",
"delicatessens":"delicatessen",
"delichons":"delichon",
"deliciousnesses":"deliciousness",
"delighted":"delight",
"delighting":"delight",
"delights":"delight",
"delilahs":"delilah",
"delimited":"delimit",
"delimiting":"delimit",
"delimits":"delimit",
"delimitated":"delimitate",
"delimitates":"delimitate",
"delimitating":"delimitate",
"delimitations":"delimitation",
"delineated":"delineate",
"delineates":"delineate",
"delineating":"delineate",
"delineations":"delineation",
"delinquencies":"delinquency",
"delinquents":"delinquent",
"deliria":"delirium",
"deliriums":"delirium",
"delivered":"deliver",
"delivering":"deliver",
"delivers":"deliver",
"deliverances":"deliverance",
"deliverers":"deliverer",
"deliveries":"delivery",
"deliverymen":"deliveryman",
"dells":"dell",
"delocalized":"delocalize",
"delocalizes":"delocalize",
"delocalizing":"delocalize",
"delonixes":"delonix",
"deloused":"delouse",
"delousing":"delouse",
"delphinapteruses":"delphinapterus",
"delphinidaes":"delphinidae",
"delphiniia":"delphinium",
"delphiniua":"delphinium",
"delphiniums":"delphinium",
"delphinuses":"delphinus",
"deltas":"delta",
"deltoids":"deltoid",
"deluded":"delude",
"deludes":"delude",
"deluding":"delude",
"deluged":"deluge",
"deluges":"deluge",
"deluging":"deluge",
"delusions":"delusion",
"delved":"delve",
"delves":"delve",
"delving":"delve",
"demagnetized":"demagnetize",
"demagnetizes":"demagnetize",
"demagnetizing":"demagnetize",
"demagogs":"demagog",
"demagogues":"demagogue",
"demagogueries":"demagoguery",
"demagogies":"demagogy",
"demanded":"demand",
"demanding":"demand",
"demands":"demand",
"demarcated":"demarcate",
"demarcates":"demarcate",
"demarcating":"demarcate",
"demarcations":"demarcation",
"demarches":"demarche",
"dematerialized":"dematerialize",
"dematerializing":"dematerialize",
"dematiaceaes":"dematiaceae",
"demeaned":"demean",
"demeaning":"demean",
"demeans":"demean",
"demeanors":"demeanor",
"demeanours":"demeanour",
"dementednesses":"dementedness",
"dementias":"dementia",
"demerits":"demerit",
"demerols":"demerol",
"demesnes":"demesne",
"demetriuses":"demetrius",
"demi-glazes":"demi-glaze",
"demiglaces":"demiglace",
"demigods":"demigod",
"demilitarized":"demilitarize",
"demilitarizes":"demilitarize",
"demilitarizing":"demilitarize",
"demineralized":"demineralize",
"demineralizing":"demineralize",
"demised":"demise",
"demises":"demise",
"demising":"demise",
"demisemiquavers":"demisemiquaver",
"demits":"demit",
"demitted":"demit",
"demitting":"demit",
"demitasses":"demitasse",
"demos":"demo",
"demobbed":"demob",
"demobbing":"demob",
"demobs":"demob",
"demobilisations":"demobilisation",
"demobilizations":"demobilization",
"demobilized":"demobilize",
"demobilizes":"demobilize",
"demobilizing":"demobilize",
"demochelyses":"demochelys",
"democracies":"democracy",
"democrats":"democrat",
"democratisations":"democratisation",
"democratizations":"democratization",
"democratized":"democratize",
"democratizing":"democratize",
"demodulated":"demodulate",
"demodulating":"demodulate",
"demodulators":"demodulator",
"demographers":"demographer",
"demographists":"demographist",
"demographies":"demography",
"demoiselles":"demoiselle",
"demolished":"demolish",
"demolishes":"demolish",
"demolishing":"demolish",
"demolishings":"demolishing",
"demolitions":"demolition",
"demons":"demon",
"demonetisations":"demonetisation",
"demonetizations":"demonetization",
"demonetized":"demonetize",
"demonetizing":"demonetize",
"demonisms":"demonism",
"demonolatries":"demonolatry",
"demonstrabilities":"demonstrability",
"demonstrated":"demonstrate",
"demonstrates":"demonstrate",
"demonstrating":"demonstrate",
"demonstrations":"demonstration",
"demonstrationists":"demonstrationist",
"demonstratives":"demonstrative",
"demonstrators":"demonstrator",
"demoralized":"demoralize",
"demoralizes":"demoralize",
"demoralizing":"demoralize",
"demoted":"demote",
"demotes":"demote",
"demoting":"demote",
"demotics":"demotic",
"demounted":"demount",
"demounting":"demount",
"demulsified":"demulsify",
"demulsifies":"demulsify",
"demulsifying":"demulsify",
"demurred":"demur",
"demurring":"demur",
"demurs":"demur",
"demurer":"demure",
"demurest":"demure",
"demurenesses":"demureness",
"demurrals":"demurral",
"demurrers":"demurrer",
"demies":"demy",
"demystified":"demystify",
"demystifies":"demystify",
"demystifying":"demystify",
"demythologisations":"demythologisation",
"demythologizations":"demythologization",
"demythologized":"demythologize",
"demythologizing":"demythologize",
"denned":"den",
"denning":"den",
"dens":"den",
"denarii":"denarius",
"denarnarii":"denarius",
"denationalisations":"denationalisation",
"denationalizations":"denationalization",
"denationalized":"denationalize",
"denationalizing":"denationalize",
"denaturalized":"denaturalize",
"denaturalizing":"denaturalize",
"denatured":"denature",
"denaturing":"denature",
"denazified":"denazify",
"denazifies":"denazify",
"denazifying":"denazify",
"dendranthemas":"dendranthema",
"dendraspises":"dendraspis",
"dendroaspises":"dendroaspis",
"dendrocalamuses":"dendrocalamus",
"dendrocolapteses":"dendrocolaptes",
"dendrocolaptidaes":"dendrocolaptidae",
"dendroctonuses":"dendroctonus",
"dendroicas":"dendroica",
"dendrolaguses":"dendrolagus",
"dendromecons":"dendromecon",
"denervated":"denervate",
"denervating":"denervate",
"dengues":"dengue",
"denials":"denial",
"denigrated":"denigrate",
"denigrates":"denigrate",
"denigrating":"denigrate",
"denigrations":"denigration",
"denims":"denim",
"denisonias":"denisonia",
"denitrified":"denitrify",
"denitrifies":"denitrify",
"denitrifying":"denitrify",
"denizened":"denizen",
"denizening":"denizen",
"denizens":"denizen",
"denmarks":"denmark",
"dennstaedtias":"dennstaedtia",
"dennstaedtiaceaes":"dennstaedtiaceae",
"denominated":"denominate",
"denominates":"denominate",
"denominating":"denominate",
"denominations":"denomination",
"denominationalisms":"denominationalism",
"denotations":"denotation",
"denoted":"denote",
"denotes":"denote",
"denoting":"denote",
"denounced":"denounce",
"denounces":"denounce",
"denouncing":"denounce",
"denouncements":"denouncement",
"denser":"dense",
"densest":"dense",
"densenesses":"denseness",
"densifications":"densification",
"densities":"density",
"dented":"dent",
"denting":"dent",
"dents":"dent",
"dentals":"dental",
"dentalia":"dentalium",
"dentaliums":"dentalium",
"dentarias":"dentaria",
"dentins":"dentin",
"dentines":"dentine",
"dentists":"dentist",
"dentistries":"dentistry",
"dentures":"denture",
"denturists":"denturist",
"denuclearized":"denuclearize",
"denuclearizing":"denuclearize",
"denudated":"denudate",
"denudates":"denudate",
"denudating":"denudate",
"denudations":"denudation",
"denuded":"denude",
"denudes":"denude",
"denuding":"denude",
"denunciated":"denunciate",
"denunciating":"denunciate",
"denunciations":"denunciation",
"denvers":"denver",
"denied":"deny",
"denies":"deny",
"denying":"deny",
"deodars":"deodar",
"deodorized":"deodorize",
"deodorizing":"deodorize",
"deoxidized":"deoxidize",
"deoxidizes":"deoxidize",
"deoxidizing":"deoxidize",
"deoxyephedrines":"deoxyephedrine",
"deoxygenated":"deoxygenate",
"deoxygenating":"deoxygenate",
"deparias":"deparia",
"departed":"depart",
"departing":"depart",
"departs":"depart",
"departeds":"departed",
"departers":"departer",
"departments":"department",
"departmentalized":"departmentalize",
"departmentalizing":"departmentalize",
"departures":"departure",
"depended":"depend",
"depending":"depend",
"dependabilities":"dependability",
"dependablenesses":"dependableness",
"dependances":"dependance",
"dependancies":"dependancy",
"dependants":"dependant",
"dependences":"dependence",
"dependencies":"dependency",
"dependents":"dependent",
"depersonalized":"depersonalize",
"depersonalizing":"depersonalize",
"depicted":"depict",
"depicting":"depict",
"depicts":"depict",
"depictings":"depicting",
"depictions":"depiction",
"depilated":"depilate",
"depilating":"depilate",
"depilatories":"depilatory",
"deplaned":"deplane",
"deplaning":"deplane",
"deplenished":"deplenish",
"deplenishes":"deplenish",
"deplenishing":"deplenish",
"depleted":"deplete",
"depletes":"deplete",
"depleting":"deplete",
"deplored":"deplore",
"deplores":"deplore",
"deploring":"deplore",
"deployed":"deploy",
"deploying":"deploy",
"deplumed":"deplume",
"deplumes":"deplume",
"depluming":"deplume",
"depolarized":"depolarize",
"depolarizing":"depolarize",
"deponed":"depone",
"depones":"depone",
"deponing":"depone",
"deponents":"deponent",
"depopulated":"depopulate",
"depopulates":"depopulate",
"depopulating":"depopulate",
"deported":"deport",
"deporting":"deport",
"deports":"deport",
"deportations":"deportation",
"deportees":"deportee",
"deportments":"deportment",
"deposed":"depose",
"deposes":"depose",
"deposing":"depose",
"deposited":"deposit",
"depositing":"deposit",
"deposits":"deposit",
"depositaries":"depositary",
"depositions":"deposition",
"depositors":"depositor",
"depositories":"depository",
"depots":"depot",
"depraved":"deprave",
"depraves":"deprave",
"depraving":"deprave",
"depravities":"depravity",
"deprecated":"deprecate",
"deprecates":"deprecate",
"deprecating":"deprecate",
"deprecations":"deprecation",
"depreciated":"depreciate",
"depreciates":"depreciate",
"depreciating":"depreciate",
"depreciations":"depreciation",
"depreciators":"depreciator",
"depredated":"depredate",
"depredating":"depredate",
"depredations":"depredation",
"depresses":"depress",
"depressing":"depress",
"depressants":"depressant",
"depressions":"depression",
"depressors":"depressor",
"deprivations":"deprivation",
"deprived":"deprive",
"deprives":"deprive",
"depriving":"deprive",
"depths":"depth",
"deputations":"deputation",
"deputed":"depute",
"deputes":"depute",
"deputing":"depute",
"deputized":"deputize",
"deputizes":"deputize",
"deputizing":"deputize",
"deputies":"deputy",
"deracinated":"deracinate",
"deracinates":"deracinate",
"deracinating":"deracinate",
"derailed":"derail",
"derailing":"derail",
"derails":"derail",
"deranged":"derange",
"deranges":"derange",
"deranging":"derange",
"derangements":"derangement",
"derbies":"derby",
"deregulated":"deregulate",
"deregulating":"deregulate",
"deregulatings":"deregulating",
"deregulations":"deregulation",
"derelicts":"derelict",
"derelictions":"dereliction",
"derided":"deride",
"deriding":"deride",
"derisions":"derision",
"derivations":"derivation",
"derivatives":"derivative",
"derived":"derive",
"derives":"derive",
"deriving":"derive",
"derivings":"deriving",
"dermas":"derma",
"dermacentors":"dermacentor",
"dermapteras":"dermaptera",
"dermatobias":"dermatobia",
"dermatologists":"dermatologist",
"dermatoplasties":"dermatoplasty",
"dermatoses":"dermatosis",
"dermatotoses":"dermatosis",
"dermestidaes":"dermestidae",
"dermises":"dermis",
"dermochelyidaes":"dermochelyidae",
"dermopteras":"dermoptera",
"derogated":"derogate",
"derogates":"derogate",
"derogating":"derogate",
"derogations":"derogation",
"derricks":"derrick",
"derrieres":"derriere",
"dervishes":"dervish",
"deses":"des",
"desalinated":"desalinate",
"desalinates":"desalinate",
"desalinating":"desalinate",
"desalinations":"desalination",
"desalinisations":"desalinisation",
"desalinizations":"desalinization",
"desalinized":"desalinize",
"desalinizes":"desalinize",
"desalinizing":"desalinize",
"desalted":"desalt",
"desalting":"desalt",
"desalts":"desalt",
"descanted":"descant",
"descanting":"descant",
"descants":"descant",
"descarteses":"descartes",
"descended":"descend",
"descending":"descend",
"descends":"descend",
"descendants":"descendant",
"descendantses":"descendants",
"descendents":"descendent",
"descents":"descent",
"described":"describe",
"describes":"describe",
"describing":"describe",
"descriptions":"description",
"descried":"descry",
"descries":"descry",
"descrying":"descry",
"descurainias":"descurainia",
"desecrated":"desecrate",
"desecrates":"desecrate",
"desecrating":"desecrate",
"desecrations":"desecration",
"desegregated":"desegregate",
"desegregates":"desegregate",
"desegregating":"desegregate",
"desegregations":"desegregation",
"desensitisations":"desensitisation",
"desensitizations":"desensitization",
"desensitized":"desensitize",
"desensitizing":"desensitize",
"deserted":"desert",
"deserting":"desert",
"deserts":"desert",
"deserters":"deserter",
"desertions":"desertion",
"deserved":"deserve",
"deserves":"deserve",
"deserving":"deserve",
"deservingnesses":"deservingness",
"desexed":"desex",
"desexes":"desex",
"desexing":"desex",
"desexualized":"desexualize",
"desexualizes":"desexualize",
"desexualizing":"desexualize",
"deshabilles":"deshabille",
"desiccants":"desiccant",
"desiccated":"desiccate",
"desiccating":"desiccate",
"desiderated":"desiderate",
"desiderating":"desiderate",
"desiderata":"desideratum",
"designed":"design",
"designing":"design",
"designs":"design",
"designated":"designate",
"designates":"designate",
"designating":"designate",
"designations":"designation",
"designees":"designee",
"designers":"designer",
"designings":"designing",
"desirabilities":"desirability",
"desirables":"desirable",
"desirablenesses":"desirableness",
"desired":"desire",
"desires":"desire",
"desiring":"desire",
"desisted":"desist",
"desisting":"desist",
"desists":"desist",
"desks":"desk",
"deskmen":"deskman",
"desktops":"desktop",
"desmans":"desman",
"desmanthuses":"desmanthus",
"desmidiaceaes":"desmidiaceae",
"desmidiums":"desmidium",
"desmodiums":"desmodium",
"desmodontidaes":"desmodontidae",
"desmoduses":"desmodus",
"desmograthuses":"desmograthus",
"desolated":"desolate",
"desolates":"desolate",
"desolating":"desolate",
"desolations":"desolation",
"desorbed":"desorb",
"desorbing":"desorb",
"despaired":"despair",
"despairing":"despair",
"despairs":"despair",
"despatched":"despatch",
"despatches":"despatch",
"despatching":"despatch",
"desperadoes":"desperado",
"desperados":"desperado",
"desperations":"desperation",
"despicabilities":"despicability",
"despicablenesses":"despicableness",
"despisals":"despisal",
"despised":"despise",
"despises":"despise",
"despising":"despise",
"despisings":"despising",
"despoiled":"despoil",
"despoiling":"despoil",
"despoils":"despoil",
"despoilers":"despoiler",
"despoilments":"despoilment",
"despoinas":"despoina",
"despoliations":"despoliation",
"desponded":"despond",
"desponding":"despond",
"despondences":"despondence",
"despondencies":"despondency",
"despots":"despot",
"despotisms":"despotism",
"desquamated":"desquamate",
"desquamates":"desquamate",
"desquamating":"desquamate",
"desserts":"dessert",
"dessertspoons":"dessertspoon",
"dessertspoonfuls":"dessertspoonful",
"dessications":"dessication",
"destinations":"destination",
"destined":"destine",
"destines":"destine",
"destining":"destine",
"destinies":"destiny",
"destroyed":"destroy",
"destroying":"destroy",
"destroys":"destroy",
"destroyers":"destroyer",
"destructions":"destruction",
"desulfured":"desulfur",
"desulfuring":"desulfur",
"desulfurized":"desulfurize",
"desulfurizing":"desulfurize",
"desynchronisations":"desynchronisation",
"desynchronizations":"desynchronization",
"desynchronizings":"desynchronizing",
"detached":"detach",
"detaches":"detach",
"detaching":"detach",
"detachments":"detachment",
"detailed":"detail",
"detailing":"detail",
"details":"detail",
"detailings":"detailing",
"detailses":"details",
"detained":"detain",
"detaining":"detain",
"detains":"detain",
"detainees":"detainee",
"detected":"detect",
"detecting":"detect",
"detects":"detect",
"detectings":"detecting",
"detections":"detection",
"detectives":"detective",
"detectors":"detector",
"detents":"detent",
"detentions":"detention",
"deterred":"deter",
"deterring":"deter",
"deters":"deter",
"deterged":"deterge",
"deterging":"deterge",
"detergences":"detergence",
"detergencies":"detergency",
"detergents":"detergent",
"deteriorated":"deteriorate",
"deteriorates":"deteriorate",
"deteriorating":"deteriorate",
"deteriorations":"deterioration",
"determents":"determent",
"determinants":"determinant",
"determinatenesses":"determinateness",
"determinations":"determination",
"determinatives":"determinative",
"determined":"determine",
"determines":"determine",
"determining":"determine",
"determiners":"determiner",
"determinists":"determinist",
"deterrences":"deterrence",
"deterrents":"deterrent",
"detested":"detest",
"detesting":"detest",
"detests":"detest",
"detestations":"detestation",
"dethroned":"dethrone",
"dethroning":"dethrone",
"dethronements":"dethronement",
"detonated":"detonate",
"detonates":"detonate",
"detonating":"detonate",
"detonations":"detonation",
"detonators":"detonator",
"detoured":"detour",
"detouring":"detour",
"detours":"detour",
"detoxicated":"detoxicate",
"detoxicates":"detoxicate",
"detoxicating":"detoxicate",
"detoxified":"detoxify",
"detoxifies":"detoxify",
"detoxifying":"detoxify",
"detracted":"detract",
"detracting":"detract",
"detracts":"detract",
"detractions":"detraction",
"detractors":"detractor",
"detrained":"detrain",
"detraining":"detrain",
"detribalisations":"detribalisation",
"detribalizations":"detribalization",
"detribalized":"detribalize",
"detribalizing":"detribalize",
"detriments":"detriment",
"detritions":"detrition",
"detrituses":"detritus",
"detroits":"detroit",
"deuces":"deuce",
"deuce-aces":"deuce-ace",
"deuteranopias":"deuteranopia",
"deuterated":"deuterate",
"deuterates":"deuterate",
"deuterating":"deuterate",
"deuteriums":"deuterium",
"deuteromyceteses":"deuteromycetes",
"deuteromycotas":"deuteromycota",
"deuteromycotinas":"deuteromycotina",
"deutschlands":"deutschland",
"deutschmarks":"deutschmark",
"devaluated":"devaluate",
"devaluates":"devaluate",
"devaluating":"devaluate",
"devalued":"devalue",
"devalues":"devalue",
"devaluing":"devalue",
"devanagaris":"devanagari",
"devastated":"devastate",
"devastates":"devastate",
"devastating":"devastate",
"devastations":"devastation",
"devastators":"devastator",
"developed":"develop",
"developing":"develop",
"develops":"develop",
"developers":"developer",
"developings":"developing",
"developments":"development",
"devested":"devest",
"devesting":"devest",
"deviances":"deviance",
"deviants":"deviant",
"deviated":"deviate",
"deviates":"deviate",
"deviating":"deviate",
"deviations":"deviation",
"devices":"device",
"deviled":"devil",
"deviling":"devil",
"devilled":"devil",
"devilling":"devil",
"devils":"devil",
"devil-worships":"devil-worship",
"devilfishes":"devilfish",
"devilments":"devilment",
"devilries":"devilry",
"deviltries":"deviltry",
"devilwoods":"devilwood",
"deviousnesses":"deviousness",
"devisals":"devisal",
"devised":"devise",
"devises":"devise",
"devising":"devise",
"devisers":"deviser",
"devisings":"devising",
"devitalisations":"devitalisation",
"devitalizations":"devitalization",
"devitalized":"devitalize",
"devitalizes":"devitalize",
"devitalizing":"devitalize",
"devitrified":"devitrify",
"devitrifies":"devitrify",
"devitrifying":"devitrify",
"devocalized":"devocalize",
"devocalizing":"devocalize",
"devoiced":"devoice",
"devoicing":"devoice",
"devolatilized":"devolatilize",
"devolatilizes":"devolatilize",
"devolatilizing":"devolatilize",
"devolutions":"devolution",
"devolved":"devolve",
"devolves":"devolve",
"devolving":"devolve",
"devolvements":"devolvement",
"devonians":"devonian",
"devoted":"devote",
"devotes":"devote",
"devoting":"devote",
"devotednesses":"devotedness",
"devotees":"devotee",
"devotions":"devotion",
"devoured":"devour",
"devouring":"devour",
"devours":"devour",
"devourers":"devourer",
"devouter":"devout",
"devoutest":"devout",
"devoutnesses":"devoutness",
"dewed":"dew",
"dewing":"dew",
"dewars":"dewar",
"dewatered":"dewater",
"dewatering":"dewater",
"dewberries":"dewberry",
"dewdrops":"dewdrop",
"deweys":"dewey",
"dewier":"dewy",
"dewiest":"dewy",
"dexamethasones":"dexamethasone",
"dexedrines":"dexedrine",
"dexterities":"dexterity",
"dextralities":"dextrality",
"dextroglucoses":"dextroglucose",
"dextroses":"dextrose",
"dgs":"dg",
"dhaks":"dhak",
"dhakas":"dhaka",
"dhals":"dhal",
"dhavas":"dhava",
"dhawas":"dhawa",
"dhegihas":"dhegiha",
"dholes":"dhole",
"dhotis":"dhoti",
"diabetas":"diabeta",
"diabetics":"diabetic",
"diabolatries":"diabolatry",
"diabolisms":"diabolism",
"diabolists":"diabolist",
"diabolized":"diabolize",
"diabolizes":"diabolize",
"diabolizing":"diabolize",
"diabolos":"diabolo",
"diacalpas":"diacalpa",
"diachronies":"diachrony",
"diacritics":"diacritic",
"diademed":"diadem",
"diademing":"diadem",
"diadems":"diadem",
"diadophises":"diadophis",
"diaereses":"diaeresis",
"diaglyphs":"diaglyph",
"diagnosed":"diagnose",
"diagnoses":"diagnose",
"diagnosing":"diagnose",
"diagnosings":"diagnosing",
"diagnosticians":"diagnostician",
"diagnosticses":"diagnostics",
"diagonals":"diagonal",
"diagramed":"diagram",
"diagraming":"diagram",
"diagrammed":"diagram",
"diagramming":"diagram",
"diagrams":"diagram",
"diagrammings":"diagramming",
"dialed":"dial",
"dialing":"dial",
"dialled":"dial",
"dialling":"dial",
"dials":"dial",
"dialects":"dialect",
"dialeurodeses":"dialeurodes",
"dialogs":"dialog",
"dialogues":"dialogue",
"dialyses":"dialyse",
"dialyzed":"dialyze",
"dialyzes":"dialyze",
"dialyzing":"dialyze",
"dialyzers":"dialyzer",
"diams":"diam",
"diameters":"diameter",
"diamonds":"diamond",
"diamondbacks":"diamondback",
"dianthuses":"dianthus",
"diapasons":"diapason",
"diapensiaceaes":"diapensiaceae",
"diapensialeses":"diapensiales",
"diapered":"diaper",
"diapering":"diaper",
"diapers":"diaper",
"diapheromeras":"diapheromera",
"diaphoreses":"diaphoresis",
"diaphragms":"diaphragm",
"diaphyses":"diaphysis",
"diapophyses":"diapophysis",
"diapsids":"diapsid",
"diapsidas":"diapsida",
"diarchies":"diarchy",
"diarists":"diarist",
"diarrheas":"diarrhea",
"diarrhoeas":"diarrhoea",
"diarthroses":"diarthrosis",
"diaries":"diary",
"diaspididaes":"diaspididae",
"diastalses":"diastalsis",
"diastases":"diastasis",
"diastemata":"diastema",
"diathermancies":"diathermancy",
"diatheses":"diathesis",
"diathses":"diathesis",
"diatomites":"diatomite",
"diatomophyceaes":"diatomophyceae",
"diatribes":"diatribe",
"diazepams":"diazepam",
"diazoes":"diazo",
"diazos":"diazo",
"dibbed":"dib",
"dibbing":"dib",
"dibs":"dib",
"dibbers":"dibber",
"dibbled":"dibble",
"dibbles":"dibble",
"dibbling":"dibble",
"dibbuks":"dibbuk",
"dibraches":"dibrach",
"dibranches":"dibranch",
"dibranchias":"dibranchia",
"dibranchiatas":"dibranchiata",
"dibranchiates":"dibranchiate",
"dicamptodons":"dicamptodon",
"dicamptodontids":"dicamptodontid",
"dicamptodontidaes":"dicamptodontidae",
"diced":"dice",
"dices":"dice",
"dicing":"dice",
"dicentras":"dicentra",
"diceroses":"diceros",
"dicier":"dicey",
"diciest":"dicey",
"dichasia":"dichasium",
"dichlorides":"dichloride",
"dichondras":"dichondra",
"dichotomisations":"dichotomisation",
"dichotomizations":"dichotomization",
"dichotomized":"dichotomize",
"dichotomizing":"dichotomize",
"dichotomies":"dichotomy",
"dichromates":"dichromate",
"dicks":"dick",
"dickenses":"dickens",
"dickered":"dicker",
"dickering":"dicker",
"dickers":"dicker",
"dickeys":"dickey",
"dickey-seats":"dickey-seat",
"dickeybirds":"dickeybird",
"dickies":"dickie",
"dickie-seats":"dickie-seat",
"dicksonias":"dicksonia",
"dicksoniaceaes":"dicksoniaceae",
"dicky-seats":"dicky-seat",
"dickybirds":"dickybird",
"dicots":"dicot",
"dicotyledons":"dicotyledon",
"dicotyledonaes":"dicotyledonae",
"dicotyledoneses":"dicotyledones",
"dicranaceaes":"dicranaceae",
"dicranaleses":"dicranales",
"dicranopterises":"dicranopteris",
"dicranums":"dicranum",
"dicrostonyxes":"dicrostonyx",
"dictamnuses":"dictamnus",
"dictated":"dictate",
"dictates":"dictate",
"dictating":"dictate",
"dictations":"dictation",
"dictators":"dictator",
"dictatorships":"dictatorship",
"dictions":"diction",
"dictionaries":"dictionary",
"dicta":"dictum",
"dictums":"dictum",
"dictyopheras":"dictyophera",
"dictyopteras":"dictyoptera",
"dicynodontias":"dicynodontia",
"didakais":"didakai",
"diddicoys":"diddicoy",
"diddled":"diddle",
"diddles":"diddle",
"diddling":"diddle",
"didelphidaes":"didelphidae",
"didelphises":"didelphis",
"didoes":"dido",
"didos":"dido",
"dice":"die",
"died":"die",
"dies":"die",
"dying":"die",
"die-casting":"die-cast",
"die-casts":"die-cast",
"dieffenbachias":"dieffenbachia",
"diehards":"diehard",
"dielectrics":"dielectric",
"diemakers":"diemaker",
"diencephala":"diencephalon",
"diencephalons":"diencephalon",
"diereses":"dieresis",
"diervillas":"diervilla",
"diesels":"diesel",
"dieseses":"dieses",
"diesinkers":"diesinker",
"dieses":"diesis",
"diestrums":"diestrum",
"diestruses":"diestrus",
"dieted":"diet",
"dieting":"diet",
"diets":"diet",
"dietaries":"dietary",
"dietartaries":"dietary",
"diethylmalonylureas":"diethylmalonylurea",
"diethylstilbestrols":"diethylstilbestrol",
"diethylstilboestrols":"diethylstilboestrol",
"dieticians":"dietician",
"dietings":"dieting",
"dietitians":"dietitian",
"differed":"differ",
"differing":"differ",
"differs":"differ",
"differenced":"difference",
"differences":"difference",
"differencing":"difference",
"differentiae":"differentia",
"differentials":"differential",
"differentiated":"differentiate",
"differentiates":"differentiate",
"differentiating":"differentiate",
"differentiations":"differentiation",
"differentiators":"differentiator",
"difficultnesses":"difficultness",
"difficulties":"difficulty",
"diffidences":"diffidence",
"diffracted":"diffract",
"diffracting":"diffract",
"diffused":"diffuse",
"diffuses":"diffuse",
"diffusing":"diffuse",
"diffusers":"diffuser",
"diffusions":"diffusion",
"diffusors":"diffusor",
"diflunisals":"diflunisal",
"digging":"dig",
"digs":"dig",
"dug":"dig",
"digamies":"digamy",
"digeneses":"digenesis",
"digested":"digest",
"digesting":"digest",
"digests":"digest",
"digestibilities":"digestibility",
"digestiblenesses":"digestibleness",
"digestions":"digestion",
"digestives":"digestive",
"diggers":"digger",
"diggings":"digging",
"diggingses":"diggings",
"dighted":"dight",
"dighting":"dight",
"dights":"dight",
"digits":"digit",
"digitalins":"digitalin",
"digitalises":"digitalise",
"digitalisations":"digitalisation",
"digitalizations":"digitalization",
"digitalized":"digitalize",
"digitalizes":"digitalize",
"digitalizing":"digitalize",
"digitarias":"digitaria",
"digitized":"digitize",
"digitizing":"digitize",
"digitizers":"digitizer",
"dignified":"dignify",
"dignifies":"dignify",
"dignifying":"dignify",
"dignitaries":"dignitary",
"dignities":"dignity",
"digressed":"digress",
"digresses":"digress",
"digressing":"digress",
"digressions":"digression",
"digses":"digs",
"dikas":"dika",
"diked":"dike",
"dikes":"dike",
"diking":"dike",
"dilantins":"dilantin",
"dilapidated":"dilapidate",
"dilapidating":"dilapidate",
"dilapidations":"dilapidation",
"dilatations":"dilatation",
"dilated":"dilate",
"dilates":"dilate",
"dilating":"dilate",
"dilations":"dilation",
"dilatorinesses":"dilatoriness",
"dildos":"dildo",
"dildoes":"dildoe",
"dilemmas":"dilemma",
"dilettantes":"dilettante",
"dilettanti":"dilettante",
"diligences":"diligence",
"dills":"dill",
"dilleniaceaes":"dilleniaceae",
"dilleniidaes":"dilleniidae",
"dillies":"dilly",
"dilly-dallied":"dilly-dally",
"dilly-dallies":"dilly-dally",
"dilly-dallying":"dilly-dally",
"dillydalliers":"dillydallier",
"diltiazems":"diltiazem",
"dilutants":"dilutant",
"diluted":"dilute",
"dilutes":"dilute",
"diluting":"dilute",
"dilutings":"diluting",
"dilutions":"dilution",
"diluvia":"diluvium",
"dimmed":"dim",
"dimmer":"dim",
"dimmest":"dim",
"dimming":"dim",
"dims":"dim",
"dimes":"dime",
"dimenhydrinates":"dimenhydrinate",
"dimensioned":"dimension",
"dimensioning":"dimension",
"dimensions":"dimension",
"diminished":"diminish",
"diminishes":"diminish",
"diminishing":"diminish",
"diminuendoes":"diminuendo",
"diminuendos":"diminuendo",
"diminutions":"diminution",
"diminutives":"diminutive",
"diminutivenesses":"diminutiveness",
"dimities":"dimity",
"dimnesses":"dimness",
"dimocarpuses":"dimocarpus",
"dimorphothecas":"dimorphotheca",
"dimouts":"dimout",
"dimpled":"dimple",
"dimples":"dimple",
"dimpling":"dimple",
"dimwits":"dimwit",
"dinned":"din",
"dinning":"din",
"dins":"din",
"dinars":"dinar",
"dindymenes":"dindymene",
"dined":"dine",
"dines":"dine",
"dining":"dine",
"diners":"diner",
"dineros":"dinero",
"dinged":"ding",
"dinging":"ding",
"dings":"ding",
"dingeys":"dingey",
"dinghies":"dinghy",
"dingles":"dingle",
"dingoes":"dingo",
"dinguses":"dingus",
"dingier":"dingy",
"dingies":"dingy",
"dingiest":"dingy",
"diningrooms":"diningroom",
"dinkas":"dinka",
"dinkeys":"dinkey",
"dinkier":"dinky",
"dinkiest":"dinky",
"dinners":"dinner",
"dinnertimes":"dinnertime",
"dinocerases":"dinoceras",
"dinoceratas":"dinocerata",
"dinoflagellatas":"dinoflagellata",
"dinornises":"dinornis",
"dinornithidaes":"dinornithidae",
"dinornithiformeses":"dinornithiformes",
"dinosaurs":"dinosaur",
"dinted":"dint",
"dinting":"dint",
"dints":"dint",
"dioceses":"diocese",
"diodes":"diode",
"diodons":"diodon",
"diodontidaes":"diodontidae",
"diols":"diol",
"diomedeidaes":"diomedeidae",
"dionaeas":"dionaea",
"dionysias":"dionysia",
"dioramas":"diorama",
"dioscoreas":"dioscorea",
"dioscoreaceaes":"dioscoreaceae",
"diospyroses":"diospyros",
"dioxides":"dioxide",
"dipped":"dip",
"dipping":"dip",
"dips":"dip",
"diphenylhydantoins":"diphenylhydantoin",
"diphthongized":"diphthongize",
"diphthongizing":"diphthongize",
"diphyllas":"diphylla",
"dipladenias":"dipladenia",
"diplococci":"diplococcus",
"diplococcocci":"diplococcus",
"diplodocuses":"diplodocus",
"diplomas":"diploma",
"diplomata":"diploma",
"diplomacies":"diplomacy",
"diplomats":"diplomat",
"diplomatists":"diplomatist",
"diplopodas":"diplopoda",
"diplopterygiums":"diplopterygium",
"diplotaxes":"diplotaxis",
"dipnois":"dipnoi",
"dipodidaes":"dipodidae",
"dipodomyses":"dipodomys",
"dipodies":"dipody",
"dipogons":"dipogon",
"dipoles":"dipole",
"dippers":"dipper",
"dipperses":"dippers",
"dippier":"dippy",
"dippiest":"dippy",
"dipsacaceaes":"dipsacaceae",
"dipsacuses":"dipsacus",
"dipsomanias":"dipsomania",
"dipsomaniacs":"dipsomaniac",
"dipsosauruses":"dipsosaurus",
"dipteras":"diptera",
"dipterans":"dipteran",
"dipterocarpaceaes":"dipterocarpaceae",
"dipterons":"dipteron",
"dipteronias":"dipteronia",
"dipteryxes":"dipteryx",
"dipuses":"dipus",
"dipylons":"dipylon",
"dircas":"dirca",
"direr":"dire",
"direst":"dire",
"directed":"direct",
"directing":"direct",
"directs":"direct",
"directions":"direction",
"directionalities":"directionality",
"directivities":"directivity",
"directnesses":"directness",
"directors":"director",
"directors-general":"director-general",
"directorates":"directorate",
"directories":"directory",
"dirges":"dirge",
"dirhams":"dirham",
"dirigibles":"dirigible",
"dirked":"dirk",
"dirking":"dirk",
"dirts":"dirt",
"dirtinesses":"dirtiness",
"dirtied":"dirty",
"dirtier":"dirty",
"dirties":"dirty",
"dirtiest":"dirty",
"dirtying":"dirty",
"dirtyings":"dirtying",
"dises":"dis",
"dissed":"diss",
"dissing":"diss",
"disabilities":"disability",
"disabled":"disable",
"disables":"disable",
"disabling":"disable",
"disablements":"disablement",
"disabused":"disabuse",
"disabusing":"disabuse",
"disaccorded":"disaccord",
"disaccording":"disaccord",
"disaccords":"disaccord",
"disaccustomed":"disaccustom",
"disaccustoming":"disaccustom",
"disadvantaged":"disadvantage",
"disadvantages":"disadvantage",
"disadvantaging":"disadvantage",
"disaffected":"disaffect",
"disaffecting":"disaffect",
"disaffects":"disaffect",
"disaffections":"disaffection",
"disaffiliated":"disaffiliate",
"disaffiliating":"disaffiliate",
"disaffirmed":"disaffirm",
"disaffirming":"disaffirm",
"disagreed":"disagree",
"disagreeing":"disagree",
"disagrees":"disagree",
"disagreements":"disagreement",
"disallowed":"disallow",
"disallowing":"disallow",
"disallows":"disallow",
"disambiguated":"disambiguate",
"disambiguating":"disambiguate",
"disannulled":"disannul",
"disannulling":"disannul",
"disannuls":"disannul",
"disappeared":"disappear",
"disappearing":"disappear",
"disappears":"disappear",
"disappearances":"disappearance",
"disappearings":"disappearing",
"disappointed":"disappoint",
"disappointing":"disappoint",
"disappoints":"disappoint",
"disappointings":"disappointing",
"disappointments":"disappointment",
"disapprobations":"disapprobation",
"disapprovals":"disapproval",
"disapproved":"disapprove",
"disapproves":"disapprove",
"disapproving":"disapprove",
"disarmed":"disarm",
"disarming":"disarm",
"disarms":"disarm",
"disarmaments":"disarmament",
"disarmers":"disarmer",
"disarmings":"disarming",
"disarranged":"disarrange",
"disarranging":"disarrange",
"disarrangements":"disarrangement",
"disarrayed":"disarray",
"disarraying":"disarray",
"disarrays":"disarray",
"disarticulated":"disarticulate",
"disarticulates":"disarticulate",
"disarticulating":"disarticulate",
"disassembled":"disassemble",
"disassembles":"disassemble",
"disassembling":"disassemble",
"disassemblies":"disassembly",
"disassociated":"disassociate",
"disassociating":"disassociate",
"disassociations":"disassociation",
"disasters":"disaster",
"disavowed":"disavow",
"disavowing":"disavow",
"disbanded":"disband",
"disbanding":"disband",
"disbands":"disband",
"disbarred":"disbar",
"disbarring":"disbar",
"disbars":"disbar",
"disbelieves":"disbelief",
"disbelieved":"disbelieve",
"disbelieving":"disbelieve",
"disbelievers":"disbeliever",
"disbudded":"disbud",
"disbudding":"disbud",
"disbuds":"disbud",
"disburdened":"disburden",
"disburdening":"disburden",
"disburdens":"disburden",
"disbursals":"disbursal",
"disbursed":"disburse",
"disburses":"disburse",
"disbursing":"disburse",
"disbursements":"disbursement",
"disbursers":"disburser",
"discs":"disc",
"discants":"discant",
"discarded":"discard",
"discarding":"discard",
"discards":"discard",
"discardings":"discarding",
"discerned":"discern",
"discerning":"discern",
"discerns":"discern",
"discernabilities":"discernability",
"discernments":"discernment",
"discharged":"discharge",
"discharges":"discharge",
"discharging":"discharge",
"disciples":"disciple",
"disciplinarians":"disciplinarian",
"disciplined":"discipline",
"disciplines":"discipline",
"disciplining":"discipline",
"disclaimed":"disclaim",
"disclaiming":"disclaim",
"disclosed":"disclose",
"discloses":"disclose",
"disclosing":"disclose",
"disclosures":"disclosure",
"discos":"disco",
"discoboli":"discobolos",
"discocephalis":"discocephali",
"discoglossidaes":"discoglossidae",
"discographies":"discography",
"discolored":"discolor",
"discoloring":"discolor",
"discolors":"discolor",
"discolorations":"discoloration",
"discoloured":"discolour",
"discolouring":"discolour",
"discolours":"discolour",
"discolourations":"discolouration",
"discombobulated":"discombobulate",
"discombobulates":"discombobulate",
"discombobulating":"discombobulate",
"discombobulations":"discombobulation",
"discomfited":"discomfit",
"discomfiting":"discomfit",
"discomfits":"discomfit",
"discomfiteds":"discomfited",
"discomfitures":"discomfiture",
"discomforted":"discomfort",
"discomforting":"discomfort",
"discomforts":"discomfort",
"discommended":"discommend",
"discommending":"discommend",
"discommends":"discommend",
"discommoded":"discommode",
"discommodes":"discommode",
"discommoding":"discommode",
"discommodities":"discommodity",
"discomposed":"discompose",
"discomposes":"discompose",
"discomposing":"discompose",
"discomposures":"discomposure",
"discomycetes":"discomycete",
"discomyceteses":"discomycetes",
"disconcerted":"disconcert",
"disconcerting":"disconcert",
"disconcerts":"disconcert",
"disconcertions":"disconcertion",
"disconcertments":"disconcertment",
"disconfirmed":"disconfirm",
"disconfirming":"disconfirm",
"disconformities":"disconformity",
"disconnected":"disconnect",
"disconnecting":"disconnect",
"disconnects":"disconnect",
"disconnectednesses":"disconnectedness",
"disconnections":"disconnection",
"disconsolatenesses":"disconsolateness",
"discontented":"discontent",
"discontenting":"discontent",
"discontents":"discontent",
"discontentednesses":"discontentedness",
"discontentments":"discontentment",
"discontinuances":"discontinuance",
"discontinuations":"discontinuation",
"discontinued":"discontinue",
"discontinues":"discontinue",
"discontinuing":"discontinue",
"discontinuities":"discontinuity",
"discorded":"discord",
"discording":"discord",
"discords":"discord",
"discordances":"discordance",
"discotheques":"discotheque",
"discounted":"discount",
"discounting":"discount",
"discounts":"discount",
"discountenanced":"discountenance",
"discountenancing":"discountenance",
"discounters":"discounter",
"discouraged":"discourage",
"discourages":"discourage",
"discouraging":"discourage",
"discouragements":"discouragement",
"discoursed":"discourse",
"discourses":"discourse",
"discoursing":"discourse",
"discourtesies":"discourtesy",
"discovered":"discover",
"discovering":"discover",
"discovers":"discover",
"discoverers":"discoverer",
"discoveries":"discovery",
"discredited":"discredit",
"discrediting":"discredit",
"discredits":"discredit",
"discreetnesses":"discreetness",
"discrepancies":"discrepancy",
"discretenesses":"discreteness",
"discretions":"discretion",
"discriminated":"discriminate",
"discriminates":"discriminate",
"discriminating":"discriminate",
"discriminations":"discrimination",
"discriminators":"discriminator",
"disci":"discus",
"discuses":"discus",
"discussed":"discuss",
"discusses":"discuss",
"discussing":"discuss",
"discussants":"discussant",
"discussions":"discussion",
"disdained":"disdain",
"disdaining":"disdain",
"disdains":"disdain",
"disdainfulnesses":"disdainfulness",
"diseased":"disease",
"diseases":"disease",
"diseasing":"disease",
"diseconomies":"diseconomy",
"disembarked":"disembark",
"disembarking":"disembark",
"disembarks":"disembark",
"disembarkations":"disembarkation",
"disembarkments":"disembarkment",
"disembarrassed":"disembarrass",
"disembarrasses":"disembarrass",
"disembarrassing":"disembarrass",
"disembodied":"disembody",
"disembodies":"disembody",
"disembodying":"disembody",
"disembogued":"disembogue",
"disembogues":"disembogue",
"disemboguing":"disembogue",
"disemboweled":"disembowel",
"disemboweling":"disembowel",
"disembowelled":"disembowel",
"disembowelling":"disembowel",
"disembowels":"disembowel",
"disenchanted":"disenchant",
"disenchanting":"disenchant",
"disenchants":"disenchant",
"disenchantments":"disenchantment",
"disencumbered":"disencumber",
"disencumbering":"disencumber",
"disencumbers":"disencumber",
"disendowed":"disendow",
"disendowing":"disendow",
"disenfranchised":"disenfranchise",
"disenfranchises":"disenfranchise",
"disenfranchising":"disenfranchise",
"disengaged":"disengage",
"disengages":"disengage",
"disengaging":"disengage",
"disengagements":"disengagement",
"disentailed":"disentail",
"disentailing":"disentail",
"disentangled":"disentangle",
"disentangles":"disentangle",
"disentangling":"disentangle",
"disentanglements":"disentanglement",
"disenthralled":"disenthral",
"disenthralling":"disenthral",
"disenthralls":"disenthral",
"disenthrals":"disenthrall",
"disestablished":"disestablish",
"disestablishing":"disestablish",
"disesteemed":"disesteem",
"disesteeming":"disesteem",
"disesteems":"disesteem",
"disfavored":"disfavor",
"disfavoring":"disfavor",
"disfavors":"disfavor",
"disfavours":"disfavour",
"disfeatured":"disfeature",
"disfeaturing":"disfeature",
"disfigured":"disfigure",
"disfigures":"disfigure",
"disfiguring":"disfigure",
"disfigurements":"disfigurement",
"disforestations":"disforestation",
"disfranchised":"disfranchise",
"disfranchises":"disfranchise",
"disfranchising":"disfranchise",
"disfrocked":"disfrock",
"disfrocking":"disfrock",
"disfurnished":"disfurnish",
"disfurnishing":"disfurnish",
"disgorged":"disgorge",
"disgorges":"disgorge",
"disgorging":"disgorge",
"disgorgements":"disgorgement",
"disgraced":"disgrace",
"disgraces":"disgrace",
"disgracing":"disgrace",
"disgracefulnesses":"disgracefulness",
"disgruntled":"disgruntle",
"disgruntling":"disgruntle",
"disguised":"disguise",
"disguises":"disguise",
"disguising":"disguise",
"disgusted":"disgust",
"disgusting":"disgust",
"disgusts":"disgust",
"disgustingnesses":"disgustingness",
"dished":"dish",
"dishes":"dish",
"dishing":"dish",
"dishabilles":"dishabille",
"disharmonized":"disharmonize",
"disharmonizing":"disharmonize",
"disharmonies":"disharmony",
"dishcloths":"dishcloth",
"disheartened":"dishearten",
"disheartening":"dishearten",
"disheartens":"dishearten",
"disheartenments":"disheartenment",
"disheveled":"dishevel",
"disheveling":"dishevel",
"dishevelled":"dishevel",
"dishevelling":"dishevel",
"dishevels":"dishevel",
"dishfuls":"dishful",
"dishonesties":"dishonesty",
"dishonored":"dishonor",
"dishonoring":"dishonor",
"dishonors":"dishonor",
"dishonorablenesses":"dishonorableness",
"dishonours":"dishonour",
"dishonourablenesses":"dishonourableness",
"dishrags":"dishrag",
"dishwares":"dishware",
"dishwashers":"dishwasher",
"dishier":"dishy",
"dishiest":"dishy",
"disillusioned":"disillusion",
"disillusioning":"disillusion",
"disillusions":"disillusion",
"disillusionments":"disillusionment",
"disincentives":"disincentive",
"disinclinations":"disinclination",
"disinclined":"disincline",
"disinclines":"disincline",
"disinclining":"disincline",
"disinfected":"disinfect",
"disinfecting":"disinfect",
"disinfectants":"disinfectant",
"disinfested":"disinfest",
"disinfesting":"disinfest",
"disinherited":"disinherit",
"disinheriting":"disinherit",
"disinherits":"disinherit",
"disintegrated":"disintegrate",
"disintegrates":"disintegrate",
"disintegrating":"disintegrate",
"disintegrations":"disintegration",
"disintegrators":"disintegrator",
"disinterred":"disinter",
"disinterring":"disinter",
"disinters":"disinter",
"disinterested":"disinterest",
"disinteresting":"disinterest",
"disinterests":"disinterest",
"disinterments":"disinterment",
"disjoined":"disjoin",
"disjoining":"disjoin",
"disjoins":"disjoin",
"disjointed":"disjoint",
"disjointing":"disjoint",
"disjoints":"disjoint",
"disjunctions":"disjunction",
"disjunctures":"disjuncture",
"disked":"disk",
"disking":"disk",
"disks":"disk",
"diskettes":"diskette",
"disliked":"dislike",
"dislikes":"dislike",
"disliking":"dislike",
"dislocated":"dislocate",
"dislocates":"dislocate",
"dislocating":"dislocate",
"dislocations":"dislocation",
"dislodged":"dislodge",
"dislodges":"dislodge",
"dislodging":"dislodge",
"dislodgements":"dislodgement",
"dislodgments":"dislodgment",
"disloyalties":"disloyalty",
"dismals":"dismal",
"dismantled":"dismantle",
"dismantles":"dismantle",
"dismantling":"dismantle",
"dismantlements":"dismantlement",
"dismantlings":"dismantling",
"dismasted":"dismast",
"dismasting":"dismast",
"dismayed":"dismay",
"dismaying":"dismay",
"dismays":"dismay",
"dismembered":"dismember",
"dismembering":"dismember",
"dismembers":"dismember",
"dismemberments":"dismemberment",
"dismissed":"dismiss",
"dismisses":"dismiss",
"dismissing":"dismiss",
"dismissals":"dismissal",
"dismounted":"dismount",
"dismounting":"dismount",
"dismounts":"dismount",
"disobediences":"disobedience",
"disobeyed":"disobey",
"disobeying":"disobey",
"disobliged":"disoblige",
"disobliges":"disoblige",
"disobliging":"disoblige",
"disordered":"disorder",
"disordering":"disorder",
"disorders":"disorder",
"disorderlinesses":"disorderliness",
"disorganizations":"disorganization",
"disorganized":"disorganize",
"disorganizing":"disorganize",
"disoriented":"disorient",
"disorienting":"disorient",
"disorients":"disorient",
"disorientations":"disorientation",
"disowned":"disown",
"disowning":"disown",
"disowns":"disown",
"disownings":"disowning",
"disownments":"disownment",
"disparaged":"disparage",
"disparages":"disparage",
"disparaging":"disparage",
"disparagements":"disparagement",
"disparagers":"disparager",
"disparatenesses":"disparateness",
"disparities":"disparity",
"disparted":"dispart",
"disparting":"dispart",
"dispassions":"dispassion",
"dispassionatenesses":"dispassionateness",
"dispatched":"dispatch",
"dispatches":"dispatch",
"dispatching":"dispatch",
"dispatchers":"dispatcher",
"dispelled":"dispel",
"dispelling":"dispel",
"dispels":"dispel",
"dispensabilities":"dispensability",
"dispensablenesses":"dispensableness",
"dispensaries":"dispensary",
"dispensations":"dispensation",
"dispensatories":"dispensatory",
"dispensed":"dispense",
"dispenses":"dispense",
"dispensing":"dispense",
"dispensings":"dispensing",
"dispeopled":"dispeople",
"dispeopling":"dispeople",
"dispersals":"dispersal",
"dispersed":"disperse",
"disperses":"disperse",
"dispersing":"disperse",
"dispersions":"dispersion",
"dispirited":"dispirit",
"dispiriting":"dispirit",
"dispirits":"dispirit",
"dispiritednesses":"dispiritedness",
"displaced":"displace",
"displaces":"displace",
"displacing":"displace",
"displacements":"displacement",
"displayed":"display",
"displaying":"display",
"displays":"display",
"displeased":"displease",
"displeasing":"displease",
"disploded":"displode",
"disploding":"displode",
"disported":"disport",
"disporting":"disport",
"disports":"disport",
"disposals":"disposal",
"disposed":"dispose",
"disposes":"dispose",
"disposing":"dispose",
"dispositions":"disposition",
"dispossessed":"dispossess",
"dispossesses":"dispossess",
"dispossessing":"dispossess",
"dispossessions":"dispossession",
"dispraised":"dispraise",
"dispraises":"dispraise",
"dispraising":"dispraise",
"dispreading":"dispread",
"disprized":"disprize",
"disprizing":"disprize",
"disproofs":"disproof",
"disprooves":"disproof",
"disproportioned":"disproportion",
"disproportioning":"disproportion",
"disproved":"disprove",
"disproves":"disprove",
"disproving":"disprove",
"disprovings":"disproving",
"disputants":"disputant",
"disputations":"disputation",
"disputed":"dispute",
"disputes":"dispute",
"disputing":"dispute",
"disqualifications":"disqualification",
"disqualified":"disqualify",
"disqualifies":"disqualify",
"disqualifying":"disqualify",
"disqualifyings":"disqualifying",
"disquieted":"disquiet",
"disquieting":"disquiet",
"disquiets":"disquiet",
"disquietudes":"disquietude",
"disrated":"disrate",
"disrating":"disrate",
"disregarded":"disregard",
"disregarding":"disregard",
"disregards":"disregard",
"disrelished":"disrelish",
"disrelishing":"disrelish",
"disremembered":"disremember",
"disremembering":"disremember",
"disreputabilities":"disreputability",
"disreputablenesses":"disreputableness",
"disreputes":"disrepute",
"disrespected":"disrespect",
"disrespecting":"disrespect",
"disrespects":"disrespect",
"disrobed":"disrobe",
"disrobes":"disrobe",
"disrobing":"disrobe",
"disrooted":"disroot",
"disrooting":"disroot",
"disrupted":"disrupt",
"disrupting":"disrupt",
"disrupts":"disrupt",
"disruptions":"disruption",
"dissatisfied":"dissatisfy",
"dissatisfies":"dissatisfy",
"dissatisfying":"dissatisfy",
"dissected":"dissect",
"dissecting":"dissect",
"dissects":"dissect",
"dissections":"dissection",
"disseized":"disseize",
"disseizing":"disseize",
"dissembled":"dissemble",
"dissembles":"dissemble",
"dissembling":"dissemble",
"dissemblers":"dissembler",
"dissemblings":"dissembling",
"disseminated":"disseminate",
"disseminates":"disseminate",
"disseminating":"disseminate",
"disseminations":"dissemination",
"disseminators":"disseminator",
"dissensions":"dissension",
"dissented":"dissent",
"dissenting":"dissent",
"dissents":"dissent",
"dissenters":"dissenter",
"disserted":"dissert",
"disserting":"dissert",
"dissertated":"dissertate",
"dissertating":"dissertate",
"dissertations":"dissertation",
"disserved":"disserve",
"disserving":"disserve",
"disservices":"disservice",
"dissevered":"dissever",
"dissevering":"dissever",
"dissevers":"dissever",
"dissidents":"dissident",
"dissimilarities":"dissimilarity",
"dissimilated":"dissimilate",
"dissimilating":"dissimilate",
"dissimilations":"dissimilation",
"dissimilitudes":"dissimilitude",
"dissimulated":"dissimulate",
"dissimulating":"dissimulate",
"dissimulations":"dissimulation",
"dissipated":"dissipate",
"dissipates":"dissipate",
"dissipating":"dissipate",
"dissipations":"dissipation",
"dissociated":"dissociate",
"dissociates":"dissociate",
"dissociating":"dissociate",
"dissociations":"dissociation",
"dissolubilities":"dissolubility",
"dissolutenesses":"dissoluteness",
"dissolutions":"dissolution",
"dissolved":"dissolve",
"dissolves":"dissolve",
"dissolving":"dissolve",
"dissolvents":"dissolvent",
"dissolvers":"dissolver",
"dissonances":"dissonance",
"dissuaded":"dissuade",
"dissuades":"dissuade",
"dissuading":"dissuade",
"dissyllables":"dissyllable",
"dissymmetries":"dissymmetry",
"distaffs":"distaff",
"distained":"distain",
"distaining":"distain",
"distanced":"distance",
"distances":"distance",
"distancing":"distance",
"distasted":"distaste",
"distastes":"distaste",
"distasting":"distaste",
"distastefulnesses":"distastefulness",
"distempered":"distemper",
"distempering":"distemper",
"distempers":"distemper",
"distended":"distend",
"distending":"distend",
"distends":"distend",
"distensions":"distension",
"distentions":"distention",
"distiches":"distich",
"distilled":"distil",
"distilling":"distil",
"distils":"distil",
"distills":"distill",
"distillates":"distillate",
"distillations":"distillation",
"distilleries":"distillery",
"distillments":"distillment",
"distinctions":"distinction",
"distinctivenesses":"distinctiveness",
"distinctnesses":"distinctness",
"distinguished":"distinguish",
"distinguishes":"distinguish",
"distinguishing":"distinguish",
"distorted":"distort",
"distorting":"distort",
"distorts":"distort",
"distortions":"distortion",
"distracted":"distract",
"distracting":"distract",
"distracts":"distract",
"distractions":"distraction",
"distrained":"distrain",
"distraining":"distrain",
"distraints":"distraint",
"distressed":"distress",
"distresses":"distress",
"distressing":"distress",
"distressfulnesses":"distressfulness",
"distributaries":"distributary",
"distributed":"distribute",
"distributes":"distribute",
"distributing":"distribute",
"distributers":"distributer",
"distributions":"distribution",
"distributors":"distributor",
"districted":"district",
"districting":"district",
"districts":"district",
"distrusted":"distrust",
"distrusting":"distrust",
"distrusts":"distrust",
"distrustfulnesses":"distrustfulness",
"disturbed":"disturb",
"disturbing":"disturb",
"disturbs":"disturb",
"disturbances":"disturbance",
"disulfirams":"disulfiram",
"disunited":"disunite",
"disunites":"disunite",
"disuniting":"disunite",
"disunities":"disunity",
"disused":"disuse",
"disuses":"disuse",
"disusing":"disuse",
"disvalued":"disvalue",
"disvaluing":"disvalue",
"disyllables":"disyllable",
"dits":"dit",
"ditas":"dita",
"ditched":"ditch",
"ditches":"ditch",
"ditching":"ditch",
"ditchmosses":"ditchmoss",
"dithered":"dither",
"dithering":"dither",
"dithers":"dither",
"dittanies":"dittany",
"dittoed":"ditto",
"dittoing":"ditto",
"dittos":"ditto",
"dittographies":"dittography",
"ditties":"ditty",
"diuretics":"diuretic",
"diurils":"diuril",
"divas":"diva",
"dive":"diva",
"divagated":"divagate",
"divagates":"divagate",
"divagating":"divagate",
"divagations":"divagation",
"divans":"divan",
"divaricated":"divaricate",
"divaricating":"divaricate",
"dived":"dive",
"dives":"dive",
"diving":"dive",
"dove":"dive",
"divers":"diver",
"diverged":"diverge",
"diverges":"diverge",
"diverging":"diverge",
"divergences":"divergence",
"divergencies":"divergency",
"diversenesses":"diverseness",
"diversified":"diversify",
"diversifies":"diversify",
"diversifying":"diversify",
"diversions":"diversion",
"diversionists":"diversionist",
"diversities":"diversity",
"diverted":"divert",
"diverting":"divert",
"diverts":"divert",
"diverticula":"diverticulum",
"divertimenti":"divertimento",
"divertimentos":"divertimento",
"divested":"divest",
"divesting":"divest",
"divests":"divest",
"divi-divis":"divi-divi",
"divided":"divide",
"divides":"divide",
"dividing":"divide",
"dividends":"dividend",
"dividers":"divider",
"divinations":"divination",
"divined":"divine",
"diviner":"divine",
"divines":"divine",
"divinest":"divine",
"divining":"divine",
"divings":"diving",
"divinities":"divinity",
"divisions":"division",
"divisors":"divisor",
"divorced":"divorce",
"divorces":"divorce",
"divorcing":"divorce",
"divorcees":"divorcee",
"divorcements":"divorcement",
"divulgated":"divulgate",
"divulgating":"divulgate",
"divulged":"divulge",
"divulges":"divulge",
"divulging":"divulge",
"divulgements":"divulgement",
"divulgences":"divulgence",
"divvied":"divvy",
"divvies":"divvy",
"divvying":"divvy",
"diwans":"diwan",
"dixies":"dixie",
"dixiecratses":"dixiecrats",
"dixielands":"dixieland",
"dizened":"dizen",
"dizening":"dizen",
"dizens":"dizen",
"dizzinesses":"dizziness",
"dizzied":"dizzy",
"dizzier":"dizzy",
"dizzies":"dizzy",
"dizziest":"dizzy",
"dizzying":"dizzy",
"djs":"dj",
"djakartas":"djakarta",
"djiboutis":"djibouti",
"djinn":"djinni",
"djinnis":"djinni",
"djinnies":"djinny",
"dkgs":"dkg",
"dkls":"dkl",
"dkms":"dkm",
"dls":"dl",
"dles":"dle",
"dms":"dm",
"dmds":"dmd",
"dmuses":"dmus",
"dnas":"dna",
"did":"do",
"doing":"do",
"done":"do",
"dos":"do",
"do-gooders":"do-gooder",
"do-nothings":"do-nothing",
"dobbins":"dobbin",
"dobbies":"dobby",
"dobermen":"doberman",
"dobros":"dobro",
"dobsons":"dobson",
"dobsonflies":"dobsonfly",
"docs":"doc",
"docked":"dock",
"docking":"dock",
"docks":"dock",
"dock-wallopers":"dock-walloper",
"dockages":"dockage",
"dockers":"docker",
"docketed":"docket",
"docketing":"docket",
"dockets":"docket",
"dockhands":"dockhand",
"dockings":"docking",
"doctored":"doctor",
"doctoring":"doctor",
"doctors":"doctor",
"doctorates":"doctorate",
"doctorfishes":"doctorfish",
"doctrinaires":"doctrinaire",
"doctrines":"doctrine",
"docudramas":"docudrama",
"documented":"document",
"documenting":"document",
"documents":"document",
"documentaries":"documentary",
"documentations":"documentation",
"dods":"dod",
"doddered":"dodder",
"doddering":"dodder",
"dodders":"dodder",
"dodecahedra":"dodecahedron",
"dodecahedrons":"dodecahedron",
"dodged":"dodge",
"dodges":"dodge",
"dodging":"dodge",
"dodgems":"dodgem",
"dodgers":"dodger",
"dodgings":"dodging",
"dodgsons":"dodgson",
"dodgier":"dodgy",
"dodgiest":"dodgy",
"dodoes":"dodo",
"dodos":"dodo",
"does":"do",
"doers":"doer",
"doffed":"doff",
"doffing":"doff",
"doffs":"doff",
"dogged":"dog",
"dogging":"dog",
"dogs":"dog",
"dogeared":"dog-ear",
"dogearing":"dog-ear",
"dogberries":"dogberry",
"dogeys":"dogey",
"digfought":"dogfight",
"dogfighting":"dogfight",
"dogfought":"dogfight",
"dogfishes":"dogfish",
"doggednesses":"doggedness",
"doggerels":"doggerel",
"doggeries":"doggery",
"doggies":"doggie",
"doggoned":"doggone",
"doggoner":"doggone",
"doggonest":"doggone",
"doggoning":"doggone",
"doggier":"doggy",
"doggiest":"doggy",
"doghouses":"doghouse",
"dogies":"dogie",
"dogirons":"dogiron",
"doglegged":"dogleg",
"doglegging":"dogleg",
"doglegs":"dogleg",
"dogmas":"dogma",
"dogmata":"dogma",
"dogmatisms":"dogmatism",
"dogmatists":"dogmatist",
"dogmatized":"dogmatize",
"dogmatizing":"dogmatize",
"dogsbodies":"dogsbody",
"dogshits":"dogshit",
"dogsleds":"dogsled",
"dogteeth":"dogtooth",
"dogwoods":"dogwood",
"dohs":"doh",
"dohas":"doha",
"dohickeys":"dohickey",
"doilies":"doily",
"doings":"doing",
"dojiggers":"dojigger",
"dojos":"dojo",
"doldrumses":"doldrums",
"doled":"dole",
"doles":"dole",
"doling":"dole",
"dolibids":"dolibid",
"dolichonyxes":"dolichonyx",
"dolichoses":"dolichos",
"dolichotises":"dolichotis",
"doliolidaes":"doliolidae",
"dolled":"doll",
"dolling":"doll",
"dolls":"doll",
"dollars":"dollar",
"dollarfishes":"dollarfish",
"dollhouses":"dollhouse",
"dollied":"dolly",
"dollies":"dolly",
"dollying":"dolly",
"dolmans":"dolman",
"dolmen":"dolman",
"dolmases":"dolmas",
"dolmens":"dolmen",
"dolomitized":"dolomitize",
"dolomitizing":"dolomitize",
"dolors":"dolor",
"dolours":"dolour",
"dolphins":"dolphin",
"dolphinfishes":"dolphinfish",
"dolts":"dolt",
"domains":"domain",
"domed":"dome",
"domes":"dome",
"doming":"dome",
"domestics":"domestic",
"domesticated":"domesticate",
"domesticates":"domesticate",
"domesticating":"domesticate",
"domestications":"domestication",
"domesticities":"domesticity",
"domiciled":"domicile",
"domiciles":"domicile",
"domiciling":"domicile",
"domiciliations":"domiciliation",
"dominances":"dominance",
"dominants":"dominant",
"dominated":"dominate",
"dominates":"dominate",
"dominating":"dominate",
"dominations":"domination",
"dominators":"dominator",
"domines":"domine",
"dominees":"dominee",
"domineered":"domineer",
"domineering":"domineer",
"domineers":"domineer",
"domineeringnesses":"domineeringness",
"dominicans":"dominican",
"dominicks":"dominick",
"dominies":"dominie",
"dominions":"dominion",
"dominiques":"dominique",
"diminos":"domino",
"dominoes":"domino",
"dominos":"domino",
"dominoeses":"dominoes",
"dominoses":"dominos",
"dominuses":"dominus",
"donned":"don",
"donning":"don",
"dons":"don",
"donas":"dona",
"donated":"donate",
"donating":"donate",
"donations":"donation",
"donators":"donator",
"donbases":"donbas",
"donbasses":"donbass",
"donees":"donee",
"donetsks":"donetsk",
"donjons":"donjon",
"donkeys":"donkey",
"donkeyworks":"donkeywork",
"donnes":"donne",
"donors":"donor",
"donuts":"donut",
"doobs":"doob",
"doodads":"doodad",
"doodias":"doodia",
"doodled":"doodle",
"doodling":"doodle",
"doodlebugs":"doodlebug",
"doofuses":"doofus",
"doohickeys":"doohickey",
"doomed":"doom",
"dooming":"doom",
"dooms":"doom",
"doomeds":"doomed",
"doomsdays":"doomsday",
"doors":"door",
"doorbells":"doorbell",
"doorcases":"doorcase",
"doorframes":"doorframe",
"doorhandles":"doorhandle",
"doorjambs":"doorjamb",
"doorkeepers":"doorkeeper",
"doorknobs":"doorknob",
"doorknockers":"doorknocker",
"doormen":"doorman",
"doormats":"doormat",
"doorposts":"doorpost",
"doorsills":"doorsill",
"doorsteps":"doorstep",
"doorstops":"doorstop",
"doorstoppers":"doorstopper",
"doorways":"doorway",
"dooryards":"dooryard",
"dopamines":"dopamine",
"dopastats":"dopastat",
"doped":"dope",
"dopes":"dope",
"doping":"dope",
"dopier":"dopey",
"dopiest":"dopey",
"doppelzentners":"doppelzentner",
"dorks":"dork",
"dorms":"dorm",
"dormancies":"dormancy",
"dormers":"dormer",
"dormitories":"dormitory",
"dormice":"dormouse",
"doronicums":"doronicum",
"dorotheanthuses":"dorotheanthus",
"dorsa":"dorsum",
"dorsums":"dorsum",
"dories":"dory",
"dorylinaes":"dorylinae",
"doryopterises":"doryopteris",
"doses":"dos",
"dosages":"dosage",
"dosed":"dose",
"dosing":"dose",
"dosemeters":"dosemeter",
"dosimeters":"dosimeter",
"dossed":"doss",
"dosses":"doss",
"dossing":"doss",
"dossers":"dosser",
"dosshouses":"dosshouse",
"dostoevskis":"dostoevski",
"dostoevskies":"dostoevsky",
"dostoievskis":"dostoievski",
"dostoyevskis":"dostoyevski",
"dostoyevskies":"dostoyevsky",
"dots":"dot",
"dotted":"dot",
"dotting":"dot",
"dotages":"dotage",
"dotards":"dotard",
"doted":"dote",
"doting":"dote",
"dotrels":"dotrel",
"dotterels":"dotterel",
"dottier":"dotty",
"dottiest":"dotty",
"doubled":"double",
"doubles":"double",
"doubling":"double",
"double-crossed":"double-cross",
"double-crossing":"double-cross",
"double-crossers":"double-crosser",
"double-crossings":"double-crossing",
"double-dealers":"double-dealer",
"double-dealings":"double-dealing",
"double-deckers":"double-decker",
"double-props":"double-prop",
"double-quicked":"double-quick",
"double-quicking":"double-quick",
"double-tongued":"double-tongue",
"double-tongues":"double-tongue",
"double-tonguing":"double-tongue",
"doubleheaders":"doubleheader",
"doublets":"doublet",
"doubletons":"doubleton",
"doublings":"doubling",
"doubted":"doubt",
"doubting":"doubt",
"doubts":"doubt",
"doubters":"doubter",
"doubtfulnesses":"doubtfulness",
"douched":"douche",
"douches":"douche",
"douching":"douche",
"doughs":"dough",
"doughnuts":"doughnut",
"doughtier":"doughty",
"doughtiest":"doughty",
"doughier":"doughy",
"doughiest":"doughy",
"douras":"doura",
"dourahs":"dourah",
"douroucoulis":"douroucouli",
"doused":"douse",
"douses":"douse",
"dousing":"douse",
"dowsed":"douse",
"dowsing":"douse",
"dousings":"dousing",
"doves":"dove",
"dovecotes":"dovecote",
"dovekies":"dovekie",
"dovers":"dover",
"dovetailed":"dovetail",
"dovetailing":"dovetail",
"dovetails":"dovetail",
"dovyalises":"dovyalis",
"dought":"dow",
"dowed":"dow",
"dowing":"dow",
"dows":"dow",
"dowagers":"dowager",
"dowdinesses":"dowdiness",
"dowdier":"dowdy",
"dowdies":"dowdy",
"dowdiest":"dowdy",
"doweled":"dowel",
"doweling":"dowel",
"dowelled":"dowel",
"dowelling":"dowel",
"dowels":"dowel",
"dowered":"dower",
"dowering":"dower",
"dowers":"dower",
"doweries":"dowery",
"dowier":"dowie",
"dowiest":"dowie",
"downed":"down",
"downing":"down",
"downs":"down",
"downcasts":"downcast",
"downers":"downer",
"downfalls":"downfall",
"downgraded":"downgrade",
"downgrades":"downgrade",
"downgrading":"downgrade",
"downheartednesses":"downheartedness",
"downhills":"downhill",
"downinesses":"downiness",
"downplayed":"downplay",
"downplaying":"downplay",
"downpours":"downpour",
"downrightnesses":"downrightness",
"downshifted":"downshift",
"downshifting":"downshift",
"downshifts":"downshift",
"downsized":"downsize",
"downsizing":"downsize",
"downsizings":"downsizing",
"downslopes":"downslope",
"downswings":"downswing",
"downtowns":"downtown",
"downturns":"downturn",
"downier":"downy",
"downiest":"downy",
"dowries":"dowry",
"dowsers":"dowser",
"doxepins":"doxepin",
"doxologies":"doxology",
"doxies":"doxy",
"doxycyclines":"doxycycline",
"doyens":"doyen",
"doyleys":"doyley",
"doylies":"doyly",
"dozed":"doze",
"dozes":"doze",
"dozing":"doze",
"dozens":"dozen",
"dozenses":"dozens",
"dozers":"dozer",
"dozier":"dozy",
"doziest":"dozy",
"dps":"dp",
"dphs":"dph",
"drabbed":"drab",
"drabber":"drab",
"drabbest":"drab",
"drabbing":"drab",
"drabs":"drab",
"drabbled":"drabble",
"drabbling":"drabble",
"drabnesses":"drabness",
"dracaenas":"dracaena",
"dracaenaceaes":"dracaenaceae",
"dracenaceaes":"dracenaceae",
"drachms":"drachm",
"drachmae":"drachma",
"drachmas":"drachma",
"dracos":"draco",
"dracocephalums":"dracocephalum",
"draculas":"dracula",
"dracunculidaes":"dracunculidae",
"dracunculuses":"dracunculus",
"drafted":"draft",
"drafting":"draft",
"drafts":"draft",
"draftees":"draftee",
"draftings":"drafting",
"draftsmen":"draftsman",
"draftsmanships":"draftsmanship",
"draftspersons":"draftsperson",
"draftier":"drafty",
"draftiest":"drafty",
"dragged":"drag",
"dragging":"drag",
"drags":"drag",
"draggled":"draggle",
"draggling":"draggle",
"draggier":"draggy",
"draggiest":"draggy",
"dragnets":"dragnet",
"dragomans":"dragoman",
"dragomen":"dragoman",
"dragons":"dragon",
"dragonflies":"dragonfly",
"dragonheads":"dragonhead",
"dragooned":"dragoon",
"dragooning":"dragoon",
"dragoons":"dragoon",
"drained":"drain",
"draining":"drain",
"drains":"drain",
"drainages":"drainage",
"drainboards":"drainboard",
"drainpipes":"drainpipe",
"drakes":"drake",
"drams":"dram",
"dramas":"drama",
"dramamines":"dramamine",
"dramaticses":"dramatics",
"dramatisations":"dramatisation",
"dramatists":"dramatist",
"dramatizations":"dramatization",
"dramatized":"dramatize",
"dramatizes":"dramatize",
"dramatizing":"dramatize",
"dramaturgies":"dramaturgy",
"draped":"drape",
"drapes":"drape",
"draping":"drape",
"draperies":"drapery",
"dratted":"drat",
"dratting":"drat",
"draughted":"draught",
"draughting":"draught",
"draughts":"draught",
"draughtses":"draughts",
"draughtsmen":"draughtsman",
"draughtier":"draughty",
"draughtiest":"draughty",
"dravidians":"dravidian",
"dravidics":"dravidic",
"drawing":"draw",
"drawn":"draw",
"draws":"draw",
"drew":"draw",
"drawbacks":"drawback",
"drawbridges":"drawbridge",
"drawers":"drawer",
"drawerfuls":"drawerful",
"drawerses":"drawers",
"drawings":"drawing",
"drawknives":"drawknife",
"drawled":"drawl",
"drawling":"drawl",
"drawls":"drawl",
"drawshaves":"drawshave",
"drawstrings":"drawstring",
"drayed":"dray",
"draying":"dray",
"drays":"dray",
"drayhorses":"drayhorse",
"dreaded":"dread",
"dreading":"dread",
"dreads":"dread",
"dreadfulnesses":"dreadfulness",
"dreadnaughts":"dreadnaught",
"dreadnoughts":"dreadnought",
"dreamed":"dream",
"dreaming":"dream",
"dreams":"dream",
"dreamt":"dream",
"dreamers":"dreamer",
"dreaminesses":"dreaminess",
"dreamings":"dreaming",
"dreamlands":"dreamland",
"dreamworlds":"dreamworld",
"dreamier":"dreamy",
"dreamiest":"dreamy",
"drearinesses":"dreariness",
"drearier":"dreary",
"dreariest":"dreary",
"dredged":"dredge",
"dredges":"dredge",
"dredging":"dredge",
"dreed":"dree",
"dreeing":"dree",
"drees":"dree",
"dreggier":"dreggy",
"dreggiest":"dreggy",
"dregses":"dregs",
"dreissenas":"dreissena",
"drenched":"drench",
"drenches":"drench",
"drenching":"drench",
"drenchings":"drenching",
"drepanididaes":"drepanididae",
"drepanises":"drepanis",
"dressed":"dress",
"dresses":"dress",
"dressing":"dress",
"dressers":"dresser",
"dressings":"dressing",
"dressmakers":"dressmaker",
"dressier":"dressy",
"dressiest":"dressy",
"dreyfuses":"dreyfus",
"dribbled":"dribble",
"dribbles":"dribble",
"dribbling":"dribble",
"dribblings":"dribbling",
"driblets":"driblet",
"driers":"drier",
"drifted":"drift",
"drifting":"drift",
"drifts":"drift",
"drifters":"drifter",
"drilled":"drill",
"drilling":"drill",
"drills":"drill",
"drillings":"drilling",
"drimyses":"drimys",
"drank":"drink",
"drinking":"drink",
"drinks":"drink",
"drunk":"drink",
"drunken":"drink",
"drinkables":"drinkable",
"drinkers":"drinker",
"drinkings":"drinking",
"dripped":"drip",
"dripping":"drip",
"drips":"drip",
"drip-dried":"drip-dry",
"drip-drying":"drip-dry",
"drippings":"dripping",
"drippingses":"drippings",
"drippier":"drippy",
"drippiest":"drippy",
"driven":"drive",
"drives":"drive",
"driving":"drive",
"drove":"drive",
"driveled":"drivel",
"driveling":"drivel",
"drivelled":"drivel",
"drivelling":"drivel",
"drivels":"drivel",
"drivellers":"driveller",
"drivers":"driver",
"driveways":"driveway",
"drivings":"driving",
"drizzled":"drizzle",
"drizzles":"drizzle",
"drizzling":"drizzle",
"drogues":"drogue",
"droits":"droit",
"drolled":"droll",
"droller":"droll",
"drollest":"droll",
"drolling":"droll",
"drolls":"droll",
"drolleries":"drollery",
"dromaeosauridaes":"dromaeosauridae",
"dromaiuses":"dromaius",
"dromedaries":"dromedary",
"dromoi":"dromos",
"droned":"drone",
"drones":"drone",
"droning":"drone",
"drongos":"drongo",
"dronings":"droning",
"drooled":"drool",
"drooling":"drool",
"drools":"drool",
"drooped":"droop",
"drooping":"droop",
"droops":"droop",
"droopier":"droopy",
"droopiest":"droopy",
"dropped":"drop",
"dropping":"drop",
"drops":"drop",
"drop-offs":"drop-off",
"droplines":"dropline",
"droppers":"dropper",
"droppingses":"droppings",
"dropsies":"dropsy",
"droseras":"drosera",
"droseraceaes":"droseraceae",
"droshkies":"droshky",
"droskies":"drosky",
"drosophilae":"drosophila",
"drosophilas":"drosophila",
"drosophilidaes":"drosophilidae",
"drosophyllums":"drosophyllum",
"drosses":"dross",
"drossier":"drossy",
"drossiest":"drossy",
"droughts":"drought",
"droughtier":"droughty",
"droughtiest":"droughty",
"droves":"drove",
"drovers":"drover",
"drowned":"drown",
"drowning":"drown",
"drowns":"drown",
"drowsed":"drowse",
"drowses":"drowse",
"drowsing":"drowse",
"drowsinesses":"drowsiness",
"drowsier":"drowsy",
"drowsiest":"drowsy",
"drubbed":"drub",
"drubbing":"drub",
"drubs":"drub",
"drubbings":"drubbing",
"drudged":"drudge",
"drudges":"drudge",
"drudging":"drudge",
"drudgeries":"drudgery",
"drugged":"drug",
"drugging":"drug",
"drugs":"drug",
"druggings":"drugging",
"druggists":"druggist",
"drugstores":"drugstore",
"drummed":"drum",
"drumming":"drum",
"drums":"drum",
"drumbeats":"drumbeat",
"drumfires":"drumfire",
"drumfishes":"drumfish",
"drumheads":"drumhead",
"drummers":"drummer",
"drummings":"drumming",
"drumsticks":"drumstick",
"drunker":"drunk",
"drunkest":"drunk",
"drunks":"drunk",
"drunkards":"drunkard",
"drunkennesses":"drunkenness",
"drupes":"drupe",
"drutherses":"druthers",
"dried":"dry",
"drier":"dry",
"dries":"dry",
"driest":"dry",
"drying":"dry",
"dry-cleaned":"dry-clean",
"dry-cleaning":"dry-clean",
"dry-nursed":"dry-nurse",
"dry-nursing":"dry-nurse",
"dryades":"dryad",
"dryads":"dryad",
"dryadellas":"dryadella",
"dryases":"dryas",
"dryers":"dryer",
"drygoodses":"drygoods",
"drymarchons":"drymarchon",
"drymoglossums":"drymoglossum",
"drynarias":"drynaria",
"drynesses":"dryness",
"dryopithecuses":"dryopithecus",
"dryopteridaceaes":"dryopteridaceae",
"dryopterises":"dryopteris",
"dses":"ds",
"duads":"duad",
"duals":"dual",
"dualas":"duala",
"dualities":"duality",
"dubbed":"dub",
"dubbing":"dub",
"dubs":"dub",
"dubieties":"dubiety",
"dubiosities":"dubiosity",
"dubiousnesses":"dubiousness",
"dublins":"dublin",
"duces":"duce",
"duci":"duce",
"duchesses":"duchess",
"duchies":"duchy",
"ducked":"duck",
"ducking":"duck",
"ducks":"duck",
"duckbills":"duckbill",
"duckings":"ducking",
"duckier":"ducky",
"duckies":"ducky",
"duckiest":"ducky",
"ducts":"duct",
"ductules":"ductule",
"ductuluses":"ductulus",
"duds":"dud",
"duded":"dude",
"dudes":"dude",
"duding":"dude",
"dudgeons":"dudgeon",
"dudses":"duds",
"dues":"due",
"dueled":"duel",
"dueling":"duel",
"duelled":"duel",
"duelling":"duel",
"duels":"duel",
"duelers":"dueler",
"duelists":"duelist",
"duellers":"dueller",
"duellists":"duellist",
"duellos":"duello",
"duennas":"duenna",
"duets":"duet",
"duettes":"duette",
"duffels":"duffel",
"duffles":"duffle",
"dugs":"dug",
"dugongs":"dugong",
"dugongidaes":"dugongidae",
"dugouts":"dugout",
"duikers":"duiker",
"dukes":"duke",
"dukedoms":"dukedom",
"dulcified":"dulcify",
"dulcifies":"dulcify",
"dulcifying":"dulcify",
"dulcineas":"dulcinea",
"dulled":"dull",
"duller":"dull",
"dullest":"dull",
"dulling":"dull",
"dullards":"dullard",
"dullnesses":"dullness",
"dulnesses":"dulness",
"dulses":"dulse",
"dumber":"dumb",
"dumbest":"dumb",
"dumbbells":"dumbbell",
"dumbfounded":"dumbfound",
"dumbfounding":"dumbfound",
"dumbfounds":"dumbfound",
"dumbnesses":"dumbness",
"dumbwaiters":"dumbwaiter",
"dumdums":"dumdum",
"dumetellas":"dumetella",
"dumfounded":"dumfound",
"dumfounding":"dumfound",
"dummied":"dummy",
"dummies":"dummy",
"dummying":"dummy",
"dumped":"dump",
"dumping":"dump",
"dumps":"dump",
"dumpers":"dumper",
"dumpinesses":"dumpiness",
"dumplings":"dumpling",
"dumplingses":"dumplings",
"dumpses":"dumps",
"dumpier":"dumpy",
"dumpiest":"dumpy",
"dumuzis":"dumuzi",
"dunned":"dun",
"dunning":"dun",
"duns":"dun",
"dunces":"dunce",
"dunderheads":"dunderhead",
"dunes":"dune",
"dunged":"dung",
"dunging":"dung",
"dungs":"dung",
"dungarees":"dungaree",
"dungeoned":"dungeon",
"dungeoning":"dungeon",
"dungeons":"dungeon",
"dunghills":"dunghill",
"dunked":"dunk",
"dunking":"dunk",
"dunks":"dunk",
"dunkards":"dunkard",
"dunkers":"dunker",
"dunkerques":"dunkerque",
"dunkerses":"dunkers",
"dunkirks":"dunkirk",
"dunlins":"dunlin",
"dunnocks":"dunnock",
"dunnies":"dunny",
"duos":"duo",
"duodecimos":"duodecimo",
"duodena":"duodenum",
"duodenums":"duodenum",
"duona":"duodenum",
"duonas":"duodenum",
"duologues":"duologue",
"duomi":"duomo",
"duomos":"duomo",
"duopolies":"duopoly",
"dupped":"dup",
"dupping":"dup",
"dups":"dup",
"duped":"dupe",
"dupes":"dupe",
"duping":"dupe",
"duperies":"dupery",
"duplexes":"duplex",
"duplicabilities":"duplicability",
"duplicated":"duplicate",
"duplicates":"duplicate",
"duplicating":"duplicate",
"duplicatings":"duplicating",
"duplications":"duplication",
"duplicators":"duplicator",
"duplicities":"duplicity",
"dupondii":"dupondius",
"duppies":"duppy",
"duras":"dura",
"durabilities":"durability",
"durables":"durable",
"durableses":"durables",
"durabolins":"durabolin",
"duramens":"duramen",
"durations":"duration",
"duratives":"durative",
"durhams":"durham",
"durians":"durian",
"durios":"durio",
"durions":"durion",
"durmasts":"durmast",
"duros":"duro",
"durras":"durra",
"durums":"durum",
"dusanbes":"dusanbe",
"dushanbes":"dushanbe",
"dusicyons":"dusicyon",
"dusked":"dusk",
"dusking":"dusk",
"dusks":"dusk",
"duskinesses":"duskiness",
"duskier":"dusky",
"duskiest":"dusky",
"dusted":"dust",
"dusting":"dust",
"dusts":"dust",
"dustbins":"dustbin",
"dustcarts":"dustcart",
"dustcloths":"dustcloth",
"dusters":"duster",
"dustmen":"dustman",
"dustmops":"dustmop",
"dustpans":"dustpan",
"dustpanfuls":"dustpanful",
"dustrags":"dustrag",
"dustups":"dustup",
"dustier":"dusty",
"dustiest":"dusty",
"Dutchmen":"Dutchman",
"duties":"duty",
"duumviri":"duumvir",
"duumvirs":"duumvir",
"duvets":"duvet",
"duxes":"dux",
"dwarfed":"dwarf",
"dwarfing":"dwarf",
"dwarfs":"dwarf",
"dwarves":"dwarf",
"dwarfisms":"dwarfism",
"dweebs":"dweeb",
"dwelled":"dwell",
"dwelling":"dwell",
"dwells":"dwell",
"dwelt":"dwell",
"dwellers":"dweller",
"dwellings":"dwelling",
"dwindled":"dwindle",
"dwindles":"dwindle",
"dwindling":"dwindle",
"dwindlings":"dwindling",
"dyads":"dyad",
"dyaks":"dyak",
"dyarchies":"dyarchy",
"dyauses":"dyaus",
"dyaus-pitars":"dyaus-pitar",
"dybbuks":"dybbuk",
"dyed":"dye",
"dyeing":"dye",
"dyes":"dye",
"dyestuffs":"dyestuff",
"dyeweeds":"dyeweed",
"dyings":"dying",
"dyirbals":"dyirbal",
"dykes":"dyke",
"dynamics":"dynamic",
"dynamicses":"dynamics",
"dynamisms":"dynamism",
"dynamited":"dynamite",
"dynamiting":"dynamite",
"dynamiters":"dynamiter",
"dynamitists":"dynamitist",
"dynamos":"dynamo",
"dynasties":"dynasty",
"dysdercuses":"dysdercus",
"dysgenicses":"dysgenics",
"dyspepsias":"dyspepsia",
"dysprosiums":"dysprosium",
"dytiscidaes":"dytiscidae",
"dyulas":"dyula",
"dyushambes":"dyushambe",
"dziggetais":"dziggetai",
"dzos":"dzo",
"es":"e",
"e-mails":"e-mail",
"eacleses":"eacles",
"eagerer":"eager",
"eagerest":"eager",
"eagers":"eager",
"eagernesses":"eagerness",
"eagles":"eagle",
"eagres":"eagre",
"ealdormen":"ealdorman",
"ears":"ear",
"ear-shells":"ear-shell",
"earaches":"earache",
"eardrops":"eardrop",
"eardrums":"eardrum",
"earflaps":"earflap",
"earfuls":"earful",
"earls":"earl",
"earlaps":"earlap",
"earldoms":"earldom",
"earlier":"early",
"earliest":"early",
"earmarked":"earmark",
"earmarking":"earmark",
"earmarks":"earmark",
"earned":"earn",
"earning":"earn",
"earns":"earn",
"earners":"earner",
"earnestnesses":"earnestness",
"earningses":"earnings",
"earphones":"earphone",
"earpieces":"earpiece",
"earreaches":"earreach",
"earrings":"earring",
"earshots":"earshot",
"earthed":"earth",
"earthing":"earth",
"earths":"earth",
"earth-balls":"earth-ball",
"earth-closets":"earth-closet",
"earthballs":"earthball",
"earthings":"earthing",
"earthlings":"earthling",
"earthlier":"earthly",
"earthliest":"earthly",
"earthmen":"earthman",
"earthnuts":"earthnut",
"earthquakes":"earthquake",
"earthworms":"earthworm",
"earthier":"earthy",
"earthiest":"earthy",
"earwaxes":"earwax",
"earwigged":"earwig",
"earwigging":"earwig",
"eased":"ease",
"eases":"ease",
"easing":"ease",
"easels":"easel",
"easinesses":"easiness",
"easings":"easing",
"easts":"east",
"Easters":"Easter",
"easterlies":"easterly",
"easterns":"eastern",
"easied":"easy",
"easier":"easy",
"easies":"easy",
"easiest":"easy",
"easying":"easy",
"ate":"eat",
"eaten":"eat",
"eating":"eat",
"eats":"eat",
"eatables":"eatable",
"eatages":"eatage",
"eaters":"eater",
"eateries":"eatery",
"eatings":"eating",
"eatses":"eats",
"eavesdropped":"eavesdrop",
"eavesdropping":"eavesdrop",
"eavesdrops":"eavesdrop",
"eavesdroppers":"eavesdropper",
"ebbed":"ebb",
"ebbing":"ebb",
"ebbs":"ebb",
"ebbings":"ebbing",
"ebenaceaes":"ebenaceae",
"ebenaleses":"ebenales",
"ebns":"ebn",
"ebonicses":"ebonics",
"ebonites":"ebonite",
"ebonized":"ebonize",
"ebonizing":"ebonize",
"ebonies":"ebony",
"ebros":"ebro",
"ebses":"ebs",
"ebulliences":"ebullience",
"eburophytons":"eburophyton",
"ecballiums":"ecballium",
"eccs":"ecc",
"eccentrics":"eccentric",
"eccentricities":"eccentricity",
"ecchymoses":"ecchymosis",
"ecclesiae":"ecclesia",
"ecclesiastics":"ecclesiastic",
"eccms":"eccm",
"ecdysiasts":"ecdysiast",
"ecdyses":"ecdysis",
"eceses":"ecesis",
"ECGs":"ECG",
"echeloned":"echelon",
"echeloning":"echelon",
"echeneididaes":"echeneididae",
"echeneises":"echeneis",
"echidnae":"echidna",
"echidnas":"echidna",
"echidnophagas":"echidnophaga",
"echinaceas":"echinacea",
"echinocactuses":"echinocactus",
"echinocereuses":"echinocereus",
"echinochloas":"echinochloa",
"echinodermatas":"echinodermata",
"echinoideas":"echinoidea",
"echinopses":"echinops",
"echini":"echinus",
"echiums":"echium",
"echoed":"echo",
"echoes":"echo",
"echoing":"echo",
"echolocations":"echolocation",
"eclaircissements":"eclaircissement",
"eclats":"eclat",
"eclectics":"eclectic",
"eclecticisms":"eclecticism",
"eclecticists":"eclecticist",
"eclipsed":"eclipse",
"eclipses":"eclipse",
"eclipsing":"eclipse",
"eclogues":"eclogue",
"ecms":"ecm",
"ecologists":"ecologist",
"ecologies":"ecology",
"economicses":"economics",
"economisers":"economiser",
"economists":"economist",
"economized":"economize",
"economizes":"economize",
"economizing":"economize",
"economizers":"economizer",
"economies":"economy",
"ecosocs":"ecosoc",
"ecphoneses":"ecphonesis",
"ecrevisses":"ecrevisse",
"ecrus":"ecru",
"ecstasies":"ecstasy",
"ects":"ect",
"ectoblasts":"ectoblast",
"ectoderms":"ectoderm",
"ectomorphies":"ectomorphy",
"ectoparasites":"ectoparasite",
"ectopisteses":"ectopistes",
"ectoproctas":"ectoprocta",
"ectozoas":"ectozoa",
"ectozoons":"ectozoon",
"ecuadorans":"ecuadoran",
"ecuadorians":"ecuadorian",
"ecumenicalisms":"ecumenicalism",
"ecumenicisms":"ecumenicism",
"ecumenisms":"ecumenism",
"edacities":"edacity",
"edams":"edam",
"edaphosauridaes":"edaphosauridae",
"edds":"edd",
"eddas":"edda",
"eddingtons":"eddington",
"eddoes":"eddo",
"eddied":"eddy",
"eddies":"eddy",
"eddying":"eddy",
"edelweisses":"edelweiss",
"edemas":"edema",
"edemata":"edema",
"edens":"eden",
"edentatas":"edentata",
"edged":"edge",
"edges":"edge",
"edging":"edge",
"edginesses":"edginess",
"edgings":"edging",
"edgier":"edgy",
"edgiest":"edgy",
"edibilities":"edibility",
"edibles":"edible",
"ediblenesses":"edibleness",
"edicts":"edict",
"edifications":"edification",
"edifices":"edifice",
"edified":"edify",
"edifies":"edify",
"edifying":"edify",
"edirnes":"edirne",
"edisons":"edison",
"edited":"edit",
"editing":"edit",
"edits":"edit",
"editings":"editing",
"editions":"edition",
"editors":"editor",
"editorials":"editorial",
"editorialists":"editorialist",
"editorialized":"editorialize",
"editorializing":"editorialize",
"edos":"edo",
"edps":"edp",
"educated":"educate",
"educates":"educate",
"educating":"educate",
"educatees":"educatee",
"educations":"education",
"educationalists":"educationalist",
"educationists":"educationist",
"educators":"educator",
"educed":"educe",
"educes":"educe",
"educing":"educe",
"edwards":"edward",
"ees":"ee",
"eecs":"eec",
"eegs":"eeg",
"eels":"eel",
"eelgrasses":"eelgrass",
"eelpouts":"eelpout",
"eerier":"eerie",
"eeriest":"eerie",
"eerinesses":"eeriness",
"effaced":"efface",
"effaces":"efface",
"effacing":"efface",
"effacements":"effacement",
"effected":"effect",
"effecting":"effect",
"effects":"effect",
"effectives":"effective",
"effectivenesses":"effectiveness",
"effectivities":"effectivity",
"effectses":"effects",
"effectualities":"effectuality",
"effectualnesses":"effectualness",
"effectuated":"effectuate",
"effectuates":"effectuate",
"effectuating":"effectuate",
"effectuations":"effectuation",
"effeminacies":"effeminacy",
"effeminatenesses":"effeminateness",
"effendis":"effendi",
"effervesced":"effervesce",
"effervesces":"effervesce",
"effervescing":"effervesce",
"effervescences":"effervescence",
"efficaciousnesses":"efficaciousness",
"efficacies":"efficacy",
"efficiencies":"efficiency",
"effigies":"effigy",
"effloresced":"effloresce",
"effloresces":"effloresce",
"efflorescing":"effloresce",
"efflorescences":"efflorescence",
"effluences":"effluence",
"effluents":"effluent",
"effluvia":"effluvium",
"effluviums":"effluvium",
"effluxes":"efflux",
"efforts":"effort",
"effronteries":"effrontery",
"effulgences":"effulgence",
"effused":"effuse",
"effuses":"effuse",
"effusing":"effuse",
"effusions":"effusion",
"effusivenesses":"effusiveness",
"efiks":"efik",
"egalitarians":"egalitarian",
"egalitarianisms":"egalitarianism",
"egerias":"egeria",
"egested":"egest",
"egesting":"egest",
"egests":"egest",
"egged":"egg",
"egging":"egg",
"eggs":"egg",
"egg-and-anchors":"egg-and-anchor",
"egg-and-darts":"egg-and-dart",
"egg-and-tongues":"egg-and-tongue",
"eggars":"eggar",
"eggbeaters":"eggbeater",
"eggcups":"eggcup",
"eggers":"egger",
"eggfruits":"eggfruit",
"eggplants":"eggplant",
"eggses":"eggs",
"eggshells":"eggshell",
"eggwhisks":"eggwhisk",
"egises":"egis",
"eglantines":"eglantine",
"egos":"ego",
"ego-tripped":"ego-trip",
"ego-tripping":"ego-trip",
"ego-trips":"ego-trip",
"egocentrics":"egocentric",
"egocentrisms":"egocentrism",
"egoisms":"egoism",
"egoists":"egoist",
"egotisms":"egotism",
"egotists":"egotist",
"egresses":"egress",
"egressions":"egression",
"egrettas":"egretta",
"egypts":"egypt",
"ehfs":"ehf",
"eichhornias":"eichhornia",
"eiders":"eider",
"eiderdowns":"eiderdown",
"eidola":"eidolon",
"eidolons":"eidolon",
"eicies":"eigenfrequency",
"eights":"eight",
"eighteens":"eighteen",
"eighteenmos":"eighteenmo",
"eighteenths":"eighteenth",
"eighters":"eighter",
"eighths":"eighth",
"eightieses":"eighties",
"eightsomes":"eightsome",
"eightvos":"eightvo",
"eighties":"eighty",
"eimerias":"eimeria",
"eimeriidaes":"eimeriidae",
"einsteins":"einstein",
"einsteiniums":"einsteinium",
"eiras":"eira",
"eires":"eire",
"eisegeses":"eisegesis",
"eisenhowers":"eisenhower",
"eisteddfodau":"eisteddfod",
"eisteddfods":"eisteddfod",
"ejaculated":"ejaculate",
"ejaculates":"ejaculate",
"ejaculating":"ejaculate",
"ejaculations":"ejaculation",
"ejected":"eject",
"ejecting":"eject",
"ejects":"eject",
"ejections":"ejection",
"ejectors":"ejector",
"eked":"eke",
"eking":"eke",
"ekgs":"ekg",
"els":"el",
"elaborated":"elaborate",
"elaborates":"elaborate",
"elaborating":"elaborate",
"elaboratenesses":"elaborateness",
"elaborations":"elaboration",
"elaeagnaceaes":"elaeagnaceae",
"elaeagnuses":"elaeagnus",
"elaeises":"elaeis",
"elaeocarpaceaes":"elaeocarpaceae",
"elaeocarpuses":"elaeocarpus",
"elagatises":"elagatis",
"elamites":"elamite",
"elamitics":"elamitic",
"elans":"elan",
"elands":"eland",
"elanoideses":"elanoides",
"elanuses":"elanus",
"elaphes":"elaphe",
"elaphures":"elaphure",
"elaphuruses":"elaphurus",
"elapids":"elapid",
"elapidaes":"elapidae",
"elapsed":"elapse",
"elapses":"elapse",
"elapsing":"elapse",
"elasmobranches":"elasmobranch",
"elasmobranchiis":"elasmobranchii",
"elastances":"elastance",
"elastics":"elastic",
"elasticized":"elasticize",
"elasticizing":"elasticize",
"elated":"elate",
"elates":"elate",
"elating":"elate",
"elaters":"elater",
"elaterids":"elaterid",
"elateridaes":"elateridae",
"elations":"elation",
"elavils":"elavil",
"elbes":"elbe",
"elbowed":"elbow",
"elbowing":"elbow",
"elbows":"elbow",
"elders":"elder",
"elderberries":"elderberry",
"eldests":"eldest",
"eldorados":"eldorado",
"elecampanes":"elecampane",
"elected":"elect",
"electing":"elect",
"elects":"elect",
"elections":"election",
"electioneered":"electioneer",
"electioneering":"electioneer",
"electioneerings":"electioneering",
"electors":"elector",
"electorates":"electorate",
"electrics":"electric",
"electricians":"electrician",
"electricities":"electricity",
"electrified":"electrify",
"electrifies":"electrify",
"electrifying":"electrify",
"electros":"electro",
"electrocardiograms":"electrocardiogram",
"electrocardiographs":"electrocardiograph",
"electrocardiographies":"electrocardiography",
"electrocauteries":"electrocautery",
"electrocuted":"electrocute",
"electrocutes":"electrocute",
"electrocuting":"electrocute",
"electrocutions":"electrocution",
"electrodeposited":"electrodeposit",
"electrodepositing":"electrodeposit",
"electrodialyses":"electrodialysis",
"electroencephalograms":"electroencephalogram",
"electroformed":"electroform",
"electroforming":"electroform",
"electrolytics":"electrolytic",
"electrolyzed":"electrolyze",
"electrolyzing":"electrolyze",
"electromagneticses":"electromagnetics",
"electromagnetisms":"electromagnetism",
"electrons":"electron",
"electrophoreses":"electrophoresis",
"electrophoridaes":"electrophoridae",
"electrophori":"electrophorus",
"electrophoruses":"electrophorus",
"electroplated":"electroplate",
"electroplating":"electroplate",
"electroshocks":"electroshock",
"electrotyped":"electrotype",
"electrotyping":"electrotype",
"electuaries":"electuary",
"elegances":"elegance",
"elegancies":"elegancy",
"elegized":"elegize",
"elegizing":"elegize",
"elegies":"elegy",
"elements":"element",
"elementals":"elemental",
"elemis":"elemi",
"elenchi":"elenchus",
"eleocharises":"eleocharis",
"eleotridaes":"eleotridae",
"elephants":"elephant",
"elephant-tusks":"elephant-tusk",
"elephantidaes":"elephantidae",
"elephantopuses":"elephantopus",
"elephases":"elephas",
"elettarias":"elettaria",
"eleusines":"eleusine",
"eleutherodactyluses":"eleutherodactylus",
"elevated":"elevate",
"elevates":"elevate",
"elevating":"elevate",
"elevations":"elevation",
"elevators":"elevator",
"elevens":"eleven",
"eleven-pluses":"eleven-plus",
"elevenths":"eleventh",
"elves":"elf",
"elicited":"elicit",
"eliciting":"elicit",
"elicits":"elicit",
"elicitations":"elicitation",
"elided":"elide",
"elides":"elide",
"eliding":"elide",
"eliminated":"eliminate",
"eliminates":"eliminate",
"eliminating":"eliminate",
"eliminations":"elimination",
"elints":"elint",
"elinvars":"elinvar",
"eliomyses":"eliomys",
"elizabeths":"elizabeth",
"elks":"elk",
"elkhounds":"elkhound",
"elkwoods":"elkwood",
"ellases":"ellas",
"ellipses":"ellipse",
"ellipticities":"ellipticity",
"elluls":"ellul",
"elms":"elm",
"elmwoods":"elmwood",
"elodeas":"elodea",
"eloigned":"eloign",
"eloigning":"eloign",
"elongated":"elongate",
"elongates":"elongate",
"elongating":"elongate",
"elongations":"elongation",
"eloped":"elope",
"elopes":"elope",
"eloping":"elope",
"elopements":"elopement",
"elopidaes":"elopidae",
"elopses":"elops",
"eloquences":"eloquence",
"elsasses":"elsass",
"elucidated":"elucidate",
"elucidates":"elucidate",
"elucidating":"elucidate",
"elucidations":"elucidation",
"eluded":"elude",
"eludes":"elude",
"eluding":"elude",
"eludings":"eluding",
"eluls":"elul",
"elusions":"elusion",
"eluviated":"eluviate",
"eluviates":"eluviate",
"eluviating":"eluviate",
"eluvia":"eluvium",
"elymuses":"elymus",
"elysiums":"elysium",
"elytra":"elytron",
"elytrons":"elytron",
"ems":"em",
"emaciated":"emaciate",
"emaciates":"emaciate",
"emaciating":"emaciate",
"emaciations":"emaciation",
"emails":"email",
"emanated":"emanate",
"emanates":"emanate",
"emanating":"emanate",
"emanations":"emanation",
"emancipated":"emancipate",
"emancipates":"emancipate",
"emancipating":"emancipate",
"emancipations":"emancipation",
"emancipationists":"emancipationist",
"emancipators":"emancipator",
"emasculated":"emasculate",
"emasculates":"emasculate",
"emasculating":"emasculate",
"emasculations":"emasculation",
"embalmed":"embalm",
"embalming":"embalm",
"embanked":"embank",
"embanking":"embank",
"embankments":"embankment",
"embargoed":"embargo",
"embargoes":"embargo",
"embargoing":"embargo",
"embarked":"embark",
"embarking":"embark",
"embarks":"embark",
"embarkations":"embarkation",
"embarkments":"embarkment",
"embarrassed":"embarrass",
"embarrasses":"embarrass",
"embarrassing":"embarrass",
"embarrassments":"embarrassment",
"embassadors":"embassador",
"embassies":"embassy",
"embattled":"embattle",
"embattling":"embattle",
"embayed":"embay",
"embaying":"embay",
"embedded":"embed",
"embedding":"embed",
"embeds":"embed",
"embellished":"embellish",
"embellishes":"embellish",
"embellishing":"embellish",
"embellishments":"embellishment",
"embers":"ember",
"emberizas":"emberiza",
"emberizidaes":"emberizidae",
"embezzled":"embezzle",
"embezzles":"embezzle",
"embezzling":"embezzle",
"embezzlements":"embezzlement",
"embezzlers":"embezzler",
"embiodeas":"embiodea",
"embiopteras":"embioptera",
"embiotocidaes":"embiotocidae",
"embittered":"embitter",
"embittering":"embitter",
"embitters":"embitter",
"emblazed":"emblaze",
"emblazing":"emblaze",
"emblazoned":"emblazon",
"emblazoning":"emblazon",
"emblazons":"emblazon",
"emblemed":"emblem",
"embleming":"emblem",
"emblems":"emblem",
"emblematized":"emblematize",
"emblematizing":"emblematize",
"embodiments":"embodiment",
"embodied":"embody",
"embodies":"embody",
"embodying":"embody",
"emboldened":"embolden",
"emboldening":"embolden",
"emboldens":"embolden",
"embolectomies":"embolectomy",
"embolisms":"embolism",
"emboli":"embolus",
"embolies":"emboly",
"embonpoints":"embonpoint",
"embosomed":"embosom",
"embosoming":"embosom",
"embossed":"emboss",
"embosses":"emboss",
"embossing":"emboss",
"embossments":"embossment",
"embothriums":"embothrium",
"embouchures":"embouchure",
"emboweled":"embowel",
"emboweling":"embowel",
"embowelled":"embowel",
"embowelling":"embowel",
"embowered":"embower",
"embowering":"embower",
"embowers":"embower",
"embraced":"embrace",
"embraces":"embrace",
"embracing":"embrace",
"embraceries":"embracery",
"embracings":"embracing",
"embrangled":"embrangle",
"embrangles":"embrangle",
"embrangling":"embrangle",
"embrasures":"embrasure",
"embrectomies":"embrectomy",
"embrittled":"embrittle",
"embrittling":"embrittle",
"embrocated":"embrocate",
"embrocating":"embrocate",
"embrocations":"embrocation",
"embroidered":"embroider",
"embroidering":"embroider",
"embroiders":"embroider",
"embroideries":"embroidery",
"embroiled":"embroil",
"embroiling":"embroil",
"embroils":"embroil",
"embroilments":"embroilment",
"embrowned":"embrown",
"embrowning":"embrown",
"embrued":"embrue",
"embrues":"embrue",
"embruing":"embrue",
"embryectomies":"embryectomy",
"embryos":"embryo",
"embryologies":"embryology",
"embused":"embus",
"embuses":"embus",
"embusing":"embus",
"embussed":"embus",
"embusses":"embus",
"embussing":"embus",
"embusques":"embusque",
"emceed":"emcee",
"emceeing":"emcee",
"emcees":"emcee",
"emeers":"emeer",
"emended":"emend",
"emending":"emend",
"emendated":"emendate",
"emendating":"emendate",
"emeralds":"emerald",
"emerged":"emerge",
"emerges":"emerge",
"emerging":"emerge",
"emergences":"emergence",
"emergencies":"emergency",
"emersions":"emersion",
"emesides":"emeside",
"emetics":"emetic",
"emfs":"emf",
"emigrants":"emigrant",
"emigrated":"emigrate",
"emigrating":"emigrate",
"emigrations":"emigration",
"emigres":"emigre",
"emigrees":"emigree",
"emilias":"emilia",
"eminences":"eminence",
"eminencies":"eminency",
"emirs":"emir",
"emissaries":"emissary",
"emissions":"emission",
"emits":"emit",
"emitted":"emit",
"emitting":"emit",
"emitters":"emitter",
"emmanthes":"emmanthe",
"emmentals":"emmental",
"emmentalers":"emmentaler",
"emmenthals":"emmenthal",
"emmenthalers":"emmenthaler",
"emmers":"emmer",
"emmets":"emmet",
"emmies":"emmy",
"emmys":"emmy",
"emollients":"emollient",
"emoted":"emote",
"emoting":"emote",
"emotions":"emotion",
"emotionalisms":"emotionalism",
"emotionalities":"emotionality",
"emotionalized":"emotionalize",
"emotionalizing":"emotionalize",
"emotionlessnesses":"emotionlessness",
"empaneled":"empanel",
"empaneling":"empanel",
"empanelled":"empanel",
"empanelling":"empanel",
"empanels":"empanel",
"empathized":"empathize",
"empathizes":"empathize",
"empathizing":"empathize",
"empennages":"empennage",
"emperors":"emperor",
"empetraceaes":"empetraceae",
"empetrums":"empetrum",
"emphases":"emphasis",
"emphasized":"emphasize",
"emphasizes":"emphasize",
"emphasizing":"emphasize",
"emphasizings":"emphasizing",
"emphysemas":"emphysema",
"empires":"empire",
"empiricisms":"empiricism",
"empirins":"empirin",
"emplaced":"emplace",
"emplacing":"emplace",
"emplacements":"emplacement",
"emplaned":"emplane",
"emplanes":"emplane",
"emplaning":"emplane",
"employed":"employ",
"employing":"employ",
"employs":"employ",
"employees":"employee",
"employers":"employer",
"employments":"employment",
"empoisoned":"empoison",
"empoisoning":"empoison",
"emporia":"emporium",
"emporiums":"emporium",
"empowered":"empower",
"empowering":"empower",
"empowers":"empower",
"empowerments":"empowerment",
"empresses":"empress",
"empressements":"empressement",
"emptinesses":"emptiness",
"emptors":"emptor",
"emptied":"empty",
"emptier":"empty",
"empties":"empty",
"emptiest":"empty",
"emptying":"empty",
"emptyings":"emptying",
"empurpled":"empurple",
"empurples":"empurple",
"empurpling":"empurple",
"empurpleds":"empurpled",
"empyreans":"empyrean",
"emus":"emu",
"emulated":"emulate",
"emulates":"emulate",
"emulating":"emulate",
"emulsified":"emulsify",
"emulsifies":"emulsify",
"emulsifying":"emulsify",
"emulsions":"emulsion",
"emunctories":"emunctory",
"emydidaes":"emydidae",
"ens":"en",
"en-lils":"en-lil",
"enabled":"enable",
"enabling":"enable",
"enacted":"enact",
"enacting":"enact",
"enacts":"enact",
"enactments":"enactment",
"enameled":"enamel",
"enameling":"enamel",
"enamelled":"enamel",
"enamelling":"enamel",
"enamels":"enamel",
"enamored":"enamor",
"enamoring":"enamor",
"enamors":"enamor",
"enamorednesses":"enamoredness",
"enantiomers":"enantiomer",
"enantiomorphs":"enantiomorph",
"enantiomorphisms":"enantiomorphism",
"enarthroses":"enarthrosis",
"enates":"enate",
"enations":"enation",
"encaged":"encage",
"encaging":"encage",
"encamped":"encamp",
"encamping":"encamp",
"encamps":"encamp",
"encampments":"encampment",
"encapsulated":"encapsulate",
"encapsulating":"encapsulate",
"encapsuled":"encapsule",
"encapsuling":"encapsule",
"encased":"encase",
"encases":"encase",
"encasing":"encase",
"encasements":"encasement",
"encelias":"encelia",
"enceliopses":"enceliopsis",
"encephalograms":"encephalogram",
"encephalomas":"encephaloma",
"encephalomata":"encephaloma",
"encephala":"encephalon",
"encephalons":"encephalon",
"enchained":"enchain",
"enchaining":"enchain",
"enchanted":"enchant",
"enchanting":"enchant",
"enchants":"enchant",
"enchantments":"enchantment",
"enchantresses":"enchantress",
"enchased":"enchase",
"enchasing":"enchase",
"enchiladas":"enchilada",
"enchiridia":"enchiridion",
"enchiridions":"enchiridion",
"enchondromas":"enchondroma",
"enchondromata":"enchondroma",
"encinas":"encina",
"enciphered":"encipher",
"enciphering":"encipher",
"enciphers":"encipher",
"encircled":"encircle",
"encircles":"encircle",
"encircling":"encircle",
"encirclements":"encirclement",
"enclasped":"enclasp",
"enclasping":"enclasp",
"enclosed":"enclose",
"encloses":"enclose",
"enclosing":"enclose",
"enclosings":"enclosing",
"enclosures":"enclosure",
"encoded":"encode",
"encodes":"encode",
"encoding":"encode",
"encodings":"encoding",
"encomia":"encomium",
"encomiums":"encomium",
"encompassed":"encompass",
"encompasses":"encompass",
"encompassing":"encompass",
"encored":"encore",
"encores":"encore",
"encoring":"encore",
"encountered":"encounter",
"encountering":"encounter",
"encounters":"encounter",
"encouraged":"encourage",
"encourages":"encourage",
"encouraging":"encourage",
"encouragements":"encouragement",
"encrimsoned":"encrimson",
"encrimsoning":"encrimson",
"encroached":"encroach",
"encroaches":"encroach",
"encroaching":"encroach",
"encroachers":"encroacher",
"encroachments":"encroachment",
"encrusted":"encrust",
"encrusting":"encrust",
"encrusts":"encrust",
"encrustations":"encrustation",
"encrypted":"encrypt",
"encrypting":"encrypt",
"encrypts":"encrypt",
"encryptions":"encryption",
"enculturated":"enculturate",
"enculturating":"enculturate",
"encumbered":"encumber",
"encumbering":"encumber",
"encumbers":"encumber",
"encumbrances":"encumbrance",
"encyclias":"encyclia",
"encyclicals":"encyclical",
"encyclopaedias":"encyclopaedia",
"encyclopedias":"encyclopedia",
"encyclopedists":"encyclopedist",
"encysted":"encyst",
"encysting":"encyst",
"ended":"end",
"ending":"end",
"ends":"end",
"endaemonisms":"endaemonism",
"endamaged":"endamage",
"endamaging":"endamage",
"endamebae":"endameba",
"endamebas":"endameba",
"endamoebas":"endamoeba",
"endamoebidaes":"endamoebidae",
"endangered":"endanger",
"endangering":"endanger",
"endangers":"endanger",
"endeared":"endear",
"endearing":"endear",
"endearments":"endearment",
"endeavored":"endeavor",
"endeavoring":"endeavor",
"endeavors":"endeavor",
"endeavoured":"endeavour",
"endeavouring":"endeavour",
"endeavours":"endeavour",
"endemisms":"endemism",
"endings":"ending",
"endives":"endive",
"endoblasts":"endoblast",
"endocardia":"endocardium",
"endocrania":"endocranium",
"endoderms":"endoderm",
"endodontias":"endodontia",
"endodonticses":"endodontics",
"endogamies":"endogamy",
"endometrioses":"endometriosis",
"endometritises":"endometritis",
"endometria":"endometrium",
"endometritria":"endometrium",
"endomorphies":"endomorphy",
"endomycetaleses":"endomycetales",
"endoparasites":"endoparasite",
"endoproctas":"endoprocta",
"endorsed":"endorse",
"endorses":"endorse",
"endorsing":"endorse",
"endorsements":"endorsement",
"endorsers":"endorser",
"endostea":"endosteum",
"endostoses":"endostosis",
"endothecia":"endothecium",
"endothecicia":"endothecium",
"endotheliomata":"endothelioma",
"endothelia":"endothelium",
"endothelilia":"endothelium",
"endowed":"endow",
"endowing":"endow",
"endows":"endow",
"endowments":"endowment",
"endozoas":"endozoa",
"endozoans":"endozoan",
"endpoints":"endpoint",
"endued":"endue",
"endues":"endue",
"enduing":"endue",
"endurances":"endurance",
"endured":"endure",
"endures":"endure",
"enduring":"endure",
"enduringnesses":"enduringness",
"enes":"ene",
"enemas":"enema",
"enemata":"enema",
"enemies":"enemy",
"energids":"energid",
"energized":"energize",
"energizes":"energize",
"energizing":"energize",
"energizings":"energizing",
"energies":"energy",
"enervated":"enervate",
"enervates":"enervate",
"enervating":"enervate",
"enervations":"enervation",
"enetses":"enets",
"enfaced":"enface",
"enfacing":"enface",
"enfeebled":"enfeeble",
"enfeebles":"enfeeble",
"enfeebling":"enfeeble",
"enfeeblements":"enfeeblement",
"enfeoffed":"enfeoff",
"enfeoffing":"enfeoff",
"enfettered":"enfetter",
"enfettering":"enfetter",
"enfiladed":"enfilade",
"enfilading":"enfilade",
"enfluranes":"enflurane",
"enfolded":"enfold",
"enfolding":"enfold",
"enfolds":"enfold",
"enfoldings":"enfolding",
"enforced":"enforce",
"enforces":"enforce",
"enforcing":"enforce",
"enforcers":"enforcer",
"enfranchised":"enfranchise",
"enfranchises":"enfranchise",
"enfranchising":"enfranchise",
"enfranchisements":"enfranchisement",
"engaged":"engage",
"engages":"engage",
"engaging":"engage",
"engagements":"engagement",
"engarlanded":"engarland",
"engarlanding":"engarland",
"engarlands":"engarland",
"engelses":"engels",
"engendered":"engender",
"engendering":"engender",
"engenders":"engender",
"engines":"engine",
"engineered":"engineer",
"engineering":"engineer",
"engineers":"engineer",
"engineerings":"engineering",
"engineries":"enginery",
"engirded":"engird",
"engirding":"engird",
"engirt":"engird",
"engirdled":"engirdle",
"engirdles":"engirdle",
"engirdling":"engirdle",
"englishes":"english",
"english-gothics":"english-gothic",
"english-weeds":"english-weed",
"Englishmen":"Englishman",
"Englishwomen":"Englishwoman",
"engluts":"englut",
"englutted":"englut",
"englutting":"englut",
"engorged":"engorge",
"engorges":"engorge",
"engorging":"engorge",
"engrafted":"engraft",
"engrafting":"engraft",
"engrafts":"engraft",
"engrailed":"engrail",
"engrailing":"engrail",
"engrained":"engrain",
"engraining":"engrain",
"engrams":"engram",
"engraulidaes":"engraulidae",
"engraulises":"engraulis",
"engraved":"engrave",
"engraves":"engrave",
"engraving":"engrave",
"engravers":"engraver",
"engravings":"engraving",
"engrossed":"engross",
"engrosses":"engross",
"engrossing":"engross",
"engrossments":"engrossment",
"engulfed":"engulf",
"engulfing":"engulf",
"engulfs":"engulf",
"enhanced":"enhance",
"enhances":"enhance",
"enhancing":"enhance",
"enhancements":"enhancement",
"enhydras":"enhydra",
"enigmas":"enigma",
"enigmata":"enigma",
"enisled":"enisle",
"enisling":"enisle",
"enjambments":"enjambment",
"enjoined":"enjoin",
"enjoining":"enjoin",
"enjoins":"enjoin",
"enjoinings":"enjoining",
"enjoinments":"enjoinment",
"enjoyed":"enjoy",
"enjoying":"enjoy",
"enjoys":"enjoy",
"enjoyers":"enjoyer",
"enjoyments":"enjoyment",
"enkindled":"enkindle",
"enkindles":"enkindle",
"enkindling":"enkindle",
"enlaced":"enlace",
"enlaces":"enlace",
"enlacing":"enlace",
"enlarged":"enlarge",
"enlarges":"enlarge",
"enlarging":"enlarge",
"enlargements":"enlargement",
"enlargers":"enlarger",
"enlightened":"enlighten",
"enlightening":"enlighten",
"enlightens":"enlighten",
"enlighteneds":"enlightened",
"enlightenments":"enlightenment",
"enlils":"enlil",
"enlisted":"enlist",
"enlisting":"enlist",
"enlists":"enlist",
"enlistees":"enlistee",
"enlistings":"enlisting",
"enlistments":"enlistment",
"enlivened":"enliven",
"enlivening":"enliven",
"enlivens":"enliven",
"enmeshed":"enmesh",
"enmeshes":"enmesh",
"enmeshing":"enmesh",
"enmities":"enmity",
"enneads":"ennead",
"enneahedra":"enneahedron",
"enneahedrons":"enneahedron",
"ennobled":"ennoble",
"ennobles":"ennoble",
"ennobling":"ennoble",
"ennuis":"ennui",
"enologists":"enologist",
"enologies":"enology",
"enormities":"enormity",
"enormousnesses":"enormousness",
"enoughs":"enough",
"enounced":"enounce",
"enounces":"enounce",
"enouncing":"enounce",
"enplaned":"enplane",
"enplanes":"enplane",
"enplaning":"enplane",
"enquired":"enquire",
"enquires":"enquire",
"enquiring":"enquire",
"enquirers":"enquirer",
"enquiries":"enquiry",
"enraged":"enrage",
"enraging":"enrage",
"enragements":"enragement",
"enraptured":"enrapture",
"enraptures":"enrapture",
"enrapturing":"enrapture",
"enregistered":"enregister",
"enregistering":"enregister",
"enriched":"enrich",
"enriching":"enrich",
"enrichments":"enrichment",
"enrobed":"enrobe",
"enrobing":"enrobe",
"enrolled":"enrol",
"enrolling":"enrol",
"enrols":"enrol",
"enrolls":"enroll",
"enrollments":"enrollment",
"enrolments":"enrolment",
"enrooted":"enroot",
"enrooting":"enroot",
"entia":"ens",
"ensconced":"ensconce",
"ensconces":"ensconce",
"ensconcing":"ensconce",
"ensembles":"ensemble",
"ensetes":"ensete",
"enshrined":"enshrine",
"enshrines":"enshrine",
"enshrining":"enshrine",
"enshrouded":"enshroud",
"enshrouding":"enshroud",
"enshrouds":"enshroud",
"ensigns":"ensign",
"ensilaged":"ensilage",
"ensilages":"ensilage",
"ensilaging":"ensilage",
"ensiled":"ensile",
"ensiling":"ensile",
"enses":"ensis",
"enskied":"ensky",
"enskyed":"ensky",
"enskying":"ensky",
"enslaved":"enslave",
"enslaving":"enslave",
"enslavements":"enslavement",
"enslavings":"enslaving",
"ensnared":"ensnare",
"ensnares":"ensnare",
"ensnaring":"ensnare",
"ensorceled":"ensorcel",
"ensorceling":"ensorcel",
"ensouled":"ensoul",
"ensouling":"ensoul",
"ensphered":"ensphere",
"ensphering":"ensphere",
"ensued":"ensue",
"ensues":"ensue",
"ensuing":"ensue",
"ensured":"ensure",
"ensures":"ensure",
"ensuring":"ensure",
"entailed":"entail",
"entailing":"entail",
"entails":"entail",
"entailments":"entailment",
"entamebae":"entameba",
"entamebas":"entameba",
"entamoebae":"entamoeba",
"entamoebas":"entamoeba",
"entandrophragmas":"entandrophragma",
"entangled":"entangle",
"entangles":"entangle",
"entangling":"entangle",
"entanglements":"entanglement",
"entases":"entasis",
"entelechies":"entelechy",
"entelluses":"entellus",
"ententes":"entente",
"entered":"enter",
"entering":"enter",
"enters":"enter",
"entericses":"enterics",
"enterings":"entering",
"enterobacterias":"enterobacteria",
"enterobacteriaceaes":"enterobacteriaceae",
"enterobiuses":"enterobius",
"enterolobiums":"enterolobium",
"entertera":"enteron",
"enterostomies":"enterostomy",
"enterotomies":"enterotomy",
"enteroviviruses":"enterovirus",
"enterprises":"enterprise",
"enterprisers":"enterpriser",
"enterprisingnesses":"enterprisingness",
"entertained":"entertain",
"entertaining":"entertain",
"entertains":"entertain",
"entertainments":"entertainment",
"enthalpies":"enthalpy",
"enthralled":"enthral",
"enthralling":"enthral",
"enthrals":"enthral",
"enthralls":"enthrall",
"enthrallments":"enthrallment",
"enthroned":"enthrone",
"enthrones":"enthrone",
"enthroning":"enthrone",
"enthronements":"enthronement",
"enthronizations":"enthronization",
"enthused":"enthuse",
"enthusing":"enthuse",
"enthusiasms":"enthusiasm",
"enthusiasts":"enthusiast",
"enticed":"entice",
"entices":"entice",
"enticing":"entice",
"enticements":"enticement",
"entires":"entire",
"entirenesses":"entireness",
"entireties":"entirety",
"entitled":"entitle",
"entitles":"entitle",
"entitling":"entitle",
"entities":"entity",
"entoblasts":"entoblast",
"entoderms":"entoderm",
"entoiled":"entoil",
"entoiling":"entoil",
"entolomas":"entoloma",
"entolomataceaes":"entolomataceae",
"entombed":"entomb",
"entombing":"entomb",
"entombs":"entomb",
"entombments":"entombment",
"entomologists":"entomologist",
"entomophthoras":"entomophthora",
"entomophthoraceaes":"entomophthoraceae",
"entomophthoraleses":"entomophthorales",
"entomostracas":"entomostraca",
"entoparasites":"entoparasite",
"entoproctas":"entoprocta",
"entourages":"entourage",
"entozoas":"entozoa",
"entozoans":"entozoan",
"entozozoa":"entozoan",
"entozoons":"entozoon",
"entrailses":"entrails",
"entrained":"entrain",
"entraining":"entrain",
"entrains":"entrain",
"entrammelled":"entrammel",
"entrammelling":"entrammel",
"entrammels":"entrammel",
"entranced":"entrance",
"entrances":"entrance",
"entrancing":"entrance",
"entrancements":"entrancement",
"entranceways":"entranceway",
"entrants":"entrant",
"entrapped":"entrap",
"entrapping":"entrap",
"entraps":"entrap",
"entreated":"entreat",
"entreating":"entreat",
"entreats":"entreat",
"entreaties":"entreaty",
"entrechats":"entrechat",
"entrees":"entree",
"entrenched":"entrench",
"entrenches":"entrench",
"entrenching":"entrench",
"entrenchments":"entrenchment",
"entrepots":"entrepot",
"entrepreneurs":"entrepreneur",
"entropies":"entropy",
"entrusted":"entrust",
"entrusting":"entrust",
"entrusts":"entrust",
"entries":"entry",
"entryways":"entryway",
"entsis":"entsi",
"entsies":"entsy",
"entwined":"entwine",
"entwines":"entwine",
"entwining":"entwine",
"entwisted":"entwist",
"entwisting":"entwist",
"enucleated":"enucleate",
"enucleating":"enucleate",
"enukis":"enuki",
"enumerated":"enumerate",
"enumerates":"enumerate",
"enumerating":"enumerate",
"enumerations":"enumeration",
"enunciated":"enunciate",
"enunciates":"enunciate",
"enunciating":"enunciate",
"enunciations":"enunciation",
"enured":"enure",
"enuring":"enure",
"enureses":"enuresis",
"enveloped":"envelop",
"enveloping":"envelop",
"envelops":"envelop",
"envelopes":"envelope",
"envelopings":"enveloping",
"envelopments":"envelopment",
"envenomed":"envenom",
"envenoming":"envenom",
"envenoms":"envenom",
"enviousnesses":"enviousness",
"environed":"environ",
"environing":"environ",
"environs":"environ",
"environments":"environment",
"environmentalists":"environmentalist",
"environses":"environs",
"envisaged":"envisage",
"envisages":"envisage",
"envisaging":"envisage",
"envisioned":"envision",
"envisioning":"envision",
"envisions":"envision",
"envisionings":"envisioning",
"envois":"envoi",
"envoys":"envoy",
"envied":"envy",
"envies":"envy",
"envying":"envy",
"enwinding":"enwind",
"enwinds":"enwind",
"enwound":"enwind",
"enwombed":"enwomb",
"enwombing":"enwomb",
"enwrapped":"enwrap",
"enwrapping":"enwrap",
"enwraps":"enwrap",
"enwreathed":"enwreathe",
"enwreathing":"enwreathe",
"eocenes":"eocene",
"eohippuses":"eohippus",
"eolians":"eolian",
"eolics":"eolic",
"eons":"eon",
"eosins":"eosin",
"eosinophils":"eosinophil",
"eosinophiles":"eosinophile",
"epas":"epa",
"epacridaceaes":"epacridaceae",
"epanaphoras":"epanaphora",
"eparchates":"eparchate",
"eparchies":"eparchy",
"epaulets":"epaulet",
"epaulettes":"epaulette",
"epencephala":"epencephalon",
"epentheses":"epenthesis",
"epexegeses":"epexegesis",
"ephas":"epha",
"ephahs":"ephah",
"ephebi":"ephebus",
"ephedras":"ephedra",
"ephedraceaes":"ephedraceae",
"ephemerae":"ephemera",
"ephemeras":"ephemera",
"ephemeralities":"ephemerality",
"ephemeralnesses":"ephemeralness",
"ephemerids":"ephemerid",
"ephemeridas":"ephemerida",
"ephemeridaes":"ephemeridae",
"ephemerides":"ephemeris",
"ephemera":"ephemeron",
"ephemerera":"ephemeron",
"ephemererons":"ephemeron",
"ephemerons":"ephemeron",
"ephemeropteras":"ephemeroptera",
"ephemeropterans":"ephemeropteran",
"ephestias":"ephestia",
"ephippidaes":"ephippidae",
"ephippiorhynchuses":"ephippiorhynchus",
"ephori":"ephor",
"ephors":"ephor",
"epibolies":"epiboly",
"epics":"epic",
"epicalyxes":"epicalyx",
"epicanthi":"epicanthus",
"epicardia":"epicardium",
"epicarps":"epicarp",
"epicedidia":"epicedium",
"epicenters":"epicenter",
"epicentres":"epicentre",
"epicines":"epicine",
"epicleses":"epiclesis",
"epicrania":"epicranium",
"epicures":"epicure",
"epicureans":"epicurean",
"epidemics":"epidemic",
"epidendrums":"epidendrum",
"epidermises":"epidermis",
"epididydidymides":"epididymis",
"epididymides":"epididymis",
"epidurals":"epidural",
"epigaeas":"epigaea",
"epigastria":"epigastrium",
"epiglottides":"epiglottis",
"epiglottises":"epiglottis",
"epigons":"epigon",
"epigones":"epigone",
"epigrams":"epigram",
"epigrammatized":"epigrammatize",
"epigrammatizing":"epigrammatize",
"epilachnas":"epilachna",
"epilated":"epilate",
"epilates":"epilate",
"epilating":"epilate",
"epilimnia":"epilimnion",
"epilobiums":"epilobium",
"epilogs":"epilog",
"epilogues":"epilogue",
"epimediums":"epimedium",
"epimysia":"epimysium",
"epinasties":"epinasty",
"epinepheluses":"epinephelus",
"epinephrins":"epinephrin",
"epinephrines":"epinephrine",
"epineuria":"epineurium",
"epipactises":"epipactis",
"epiphanies":"epiphany",
"epiphenomena":"epiphenomenon",
"epiphenomna":"epiphenomenon",
"epiphoras":"epiphora",
"epiphyllums":"epiphyllum",
"epiphyses":"epiphysis",
"epiphytes":"epiphyte",
"epipremnums":"epipremnum",
"episcopacies":"episcopacy",
"episiotomies":"episiotomy",
"episodes":"episode",
"episperms":"episperm",
"epistases":"epistasis",
"epistaxes":"epistaxis",
"episterna":"episternum",
"epistles":"epistle",
"epistrophes":"epistrophe",
"epitaphs":"epitaph",
"epitases":"epitasis",
"epitaxies":"epitaxy",
"epithalamia":"epithalamium",
"epithalamiums":"epithalamium",
"epitheliomas":"epithelioma",
"epitheliomata":"epithelioma",
"epithelia":"epithelium",
"epithelilia":"epithelium",
"epitheliliums":"epithelium",
"epitheliums":"epithelium",
"epithets":"epithet",
"epitomes":"epitome",
"epitomized":"epitomize",
"epitomizes":"epitomize",
"epitomizing":"epitomize",
"epitrichiums":"epitrichium",
"epizoas":"epizoa",
"epizoa":"epizoon",
"epizoons":"epizoon",
"epoches":"epoch",
"eposes":"epos",
"epoxies":"epoxy",
"eproms":"eprom",
"eptesicuses":"eptesicus",
"epyllilia":"epyllion",
"eqs":"eq",
"equaled":"equal",
"equaling":"equal",
"equalled":"equal",
"equalling":"equal",
"equals":"equal",
"equalisers":"equaliser",
"equalitarians":"equalitarian",
"equalitarianisms":"equalitarianism",
"equalities":"equality",
"equalizations":"equalization",
"equalized":"equalize",
"equalizes":"equalize",
"equalizing":"equalize",
"equalizers":"equalizer",
"equanils":"equanil",
"equanimities":"equanimity",
"equated":"equate",
"equates":"equate",
"equating":"equate",
"equatings":"equating",
"equations":"equation",
"equerries":"equerry",
"equestrians":"equestrian",
"equetuses":"equetus",
"equids":"equid",
"equidaes":"equidae",
"equilibrated":"equilibrate",
"equilibrates":"equilibrate",
"equilibrating":"equilibrate",
"equilibriums":"equilibrium",
"equilisations":"equilisation",
"equines":"equine",
"equinoctials":"equinoctial",
"equinoxes":"equinox",
"equipped":"equip",
"equipping":"equip",
"equips":"equip",
"equipages":"equipage",
"equipoised":"equipoise",
"equipoises":"equipoise",
"equipoising":"equipoise",
"equiponderated":"equiponderate",
"equiponderating":"equiponderate",
"equippings":"equipping",
"equisetaceaes":"equisetaceae",
"equisetaleses":"equisetales",
"equisetataes":"equisetatae",
"equiseta":"equisetum",
"equisetums":"equisetum",
"equitations":"equitation",
"equities":"equity",
"equivalences":"equivalence",
"equivalents":"equivalent",
"equivocalnesses":"equivocalness",
"equivocated":"equivocate",
"equivocates":"equivocate",
"equivocating":"equivocate",
"equivocations":"equivocation",
"equuses":"equus",
"ers":"er",
"eras":"era",
"eradiated":"eradiate",
"eradiating":"eradiate",
"eradicated":"eradicate",
"eradicates":"eradicate",
"eradicating":"eradicate",
"eradications":"eradication",
"eradicators":"eradicator",
"eragrostises":"eragrostis",
"eranthises":"eranthis",
"erased":"erase",
"erases":"erase",
"erasing":"erase",
"erasers":"eraser",
"erasmuses":"erasmus",
"erastianisms":"erastianism",
"erasures":"erasure",
"erbiums":"erbium",
"erected":"erect",
"erecting":"erect",
"erects":"erect",
"erectings":"erecting",
"erections":"erection",
"erectnesses":"erectness",
"erectors":"erector",
"eresh-kigals":"eresh-kigal",
"ereshkigals":"ereshkigal",
"ereshkigels":"ereshkigel",
"erethizons":"erethizon",
"erethizontidaes":"erethizontidae",
"eretmochelyses":"eretmochelys",
"areg":"erg",
"ergs":"erg",
"ergatocracies":"ergatocracy",
"ergocalciferols":"ergocalciferol",
"ergonomicses":"ergonomics",
"ergots":"ergot",
"erianthuses":"erianthus",
"ericas":"erica",
"ericaceaes":"ericaceae",
"ericaleses":"ericales",
"eries":"erie",
"erigerons":"erigeron",
"erignathuses":"erignathus",
"erinaceidaes":"erinaceidae",
"erinaceuses":"erinaceus",
"eringos":"eringo",
"erinyeses":"erinyes",
"eriobotryas":"eriobotrya",
"eriocaulaceaes":"eriocaulaceae",
"eriocaulons":"eriocaulon",
"eriodictyons":"eriodictyon",
"eriophorums":"eriophorum",
"eriophyllums":"eriophyllum",
"eriosomas":"eriosoma",
"erithacuses":"erithacus",
"erivans":"erivan",
"ermines":"ermine",
"erns":"ern",
"ernes":"erne",
"eroded":"erode",
"erodes":"erode",
"eroding":"erode",
"erodings":"eroding",
"erodiums":"erodium",
"erolias":"erolia",
"erosions":"erosion",
"eroticisms":"eroticism",
"eroticized":"eroticize",
"eroticizing":"eroticize",
"erotisms":"erotism",
"erred":"err",
"erring":"err",
"errs":"err",
"errancies":"errancy",
"errands":"errand",
"errantries":"errantry",
"errata":"erratum",
"erroneousnesses":"erroneousness",
"errors":"error",
"erses":"erse",
"erts":"ert",
"erucas":"eruca",
"eructed":"eruct",
"eructing":"eruct",
"eructs":"eruct",
"eructated":"eructate",
"eructating":"eructate",
"eructations":"eructation",
"eruditenesses":"eruditeness",
"eruditions":"erudition",
"erupted":"erupt",
"erupting":"erupt",
"erupts":"erupt",
"eruptions":"eruption",
"eryngiums":"eryngium",
"eryngos":"eryngo",
"erysimums":"erysimum",
"erysiphaceaes":"erysiphaceae",
"erysiphaleses":"erysiphales",
"erysiphes":"erysiphe",
"erythrinas":"erythrina",
"erythrocebuses":"erythrocebus",
"erythrocytes":"erythrocyte",
"erythrocytolysins":"erythrocytolysin",
"erythrolysins":"erythrolysin",
"erythroniums":"erythronium",
"erythroxylaceaes":"erythroxylaceae",
"erythroxylons":"erythroxylon",
"erythroxylums":"erythroxylum",
"eses":"es",
"escaladed":"escalade",
"escalading":"escalade",
"escalated":"escalate",
"escalates":"escalate",
"escalating":"escalate",
"escalations":"escalation",
"escalators":"escalator",
"escalloped":"escallop",
"escalloping":"escallop",
"escapades":"escapade",
"escaped":"escape",
"escapes":"escape",
"escaping":"escape",
"escapisms":"escapism",
"escapists":"escapist",
"escapologists":"escapologist",
"escargots":"escargot",
"escaroles":"escarole",
"escarps":"escarp",
"escarpments":"escarpment",
"eschalots":"eschalot",
"escheated":"escheat",
"escheating":"escheat",
"eschewed":"eschew",
"eschewing":"eschew",
"eschews":"eschew",
"eschrichtiidaes":"eschrichtiidae",
"eschrichtiuses":"eschrichtius",
"eschscholtzias":"eschscholtzia",
"escolars":"escolar",
"escorted":"escort",
"escorting":"escort",
"escorts":"escort",
"escritoires":"escritoire",
"escudos":"escudo",
"escutcheons":"escutcheon",
"esidrixes":"esidrix",
"Eskimos":"Eskimo",
"eskimo-aleuts":"eskimo-aleut",
"eskies":"esky",
"esms":"esm",
"esocidaes":"esocidae",
"esops":"esop",
"esophagi":"esophagus",
"esophaguses":"esophagus",
"oesophagi":"esophagus",
"esoxes":"esox",
"esps":"esp",
"espanas":"espana",
"espanoles":"espanole",
"esparcets":"esparcet",
"espartos":"esparto",
"grass":"esparto",
"espials":"espial",
"espousals":"espousal",
"espoused":"espouse",
"espouses":"espouse",
"espousing":"espouse",
"espressos":"espresso",
"espied":"espy",
"espies":"espy",
"espying":"espy",
"esqs":"esq",
"esquimaus":"esquimau",
"esquired":"esquire",
"esquires":"esquire",
"esquiring":"esquire",
"esrs":"esr",
"essayed":"essay",
"essaying":"essay",
"essays":"essay",
"essayists":"essayist",
"essences":"essence",
"essentials":"essential",
"essentialities":"essentiality",
"essentialized":"essentialize",
"essentializing":"essentialize",
"essentialnesses":"essentialness",
"essonites":"essonite",
"ests":"est",
"established":"establish",
"establishes":"establish",
"establishing":"establish",
"establishments":"establishment",
"establishmentarians":"establishmentarian",
"estaminets":"estaminet",
"estancias":"estancia",
"estates":"estate",
"esteemed":"esteem",
"esteeming":"esteem",
"esteems":"esteem",
"esterified":"esterify",
"esterifies":"esterify",
"esterifying":"esterify",
"esthetes":"esthete",
"esthetics":"esthetic",
"estheticians":"esthetician",
"estheticses":"esthetics",
"esthonias":"esthonia",
"esthonians":"esthonian",
"estimated":"estimate",
"estimates":"estimate",
"estimating":"estimate",
"estimations":"estimation",
"estimators":"estimator",
"estivated":"estivate",
"estivates":"estivate",
"estivating":"estivate",
"estivations":"estivation",
"estonias":"estonia",
"Estonians":"Estonian",
"estopped":"estop",
"estopping":"estop",
"estops":"estop",
"estragons":"estragon",
"estranged":"estrange",
"estranges":"estrange",
"estranging":"estrange",
"estrangements":"estrangement",
"estrildas":"estrilda",
"estrogens":"estrogen",
"estrones":"estrone",
"estruses":"estrus",
"estuaries":"estuary",
"esuriences":"esurience",
"etamins":"etamin",
"etamines":"etamine",
"etched":"etch",
"etching":"etch",
"etchings":"etching",
"eternalized":"eternalize",
"eternalizes":"eternalize",
"eternalizing":"eternalize",
"eternities":"eternity",
"eternized":"eternize",
"eternizes":"eternize",
"eternizing":"eternize",
"ethanamides":"ethanamide",
"ethanediols":"ethanediol",
"ethanols":"ethanol",
"ethenes":"ethene",
"ethers":"ether",
"etherealized":"etherealize",
"etherealizing":"etherealize",
"etherified":"etherify",
"etherifies":"etherify",
"etherifying":"etherify",
"etherized":"etherize",
"etherizing":"etherize",
"ethics":"ethic",
"ethicses":"ethics",
"ethiopias":"ethiopia",
"ethnographies":"ethnography",
"ethnoses":"ethnos",
"ethosuximides":"ethosuximide",
"ethoxyethanes":"ethoxyethane",
"ethranes":"ethrane",
"ethyls":"ethyl",
"ethylated":"ethylate",
"ethylating":"ethylate",
"ethylenes":"ethylene",
"ethynes":"ethyne",
"etiolated":"etiolate",
"etiolating":"etiolate",
"etiologists":"etiologist",
"etiologies":"etiology",
"etnas":"etna",
"etodolacs":"etodolac",
"etropuses":"etropus",
"etuis":"etui",
"etymologized":"etymologize",
"etymologizing":"etymologize",
"etymologizings":"etymologizing",
"etymologies":"etymology",
"etyma":"etymon",
"etymons":"etymon",
"eus":"eu",
"euarctoses":"euarctos",
"euascomyceteses":"euascomycetes",
"eubacterias":"eubacteria",
"eubacterialeses":"eubacteriales",
"eubacteriums":"eubacterium",
"eubryaleses":"eubryales",
"eucalypts":"eucalypt",
"eucalypti":"eucalyptus",
"eucalyptuses":"eucalyptus",
"eucaryas":"eucarya",
"eucaryotes":"eucaryote",
"eucharists":"eucharist",
"euchred":"euchre",
"euchres":"euchre",
"euchring":"euchre",
"eucinostomuses":"eucinostomus",
"eudaemons":"eudaemon",
"eudemons":"eudemon",
"eudemonisms":"eudemonism",
"eudermas":"euderma",
"eudypteses":"eudyptes",
"eugenias":"eugenia",
"euglenas":"euglena",
"euglenaceaes":"euglenaceae",
"euglenids":"euglenid",
"euglenoids":"euglenoid",
"euglenophyceaes":"euglenophyceae",
"euglenophytas":"euglenophyta",
"euglenophytes":"euglenophyte",
"eukaryotes":"eukaryote",
"eulachans":"eulachan",
"eulachons":"eulachon",
"eulogists":"eulogist",
"eulogia":"eulogium",
"eulogiums":"eulogium",
"eulogized":"eulogize",
"eulogizes":"eulogize",
"eulogizing":"eulogize",
"eulogies":"eulogy",
"eumeceses":"eumeces",
"eumeneses":"eumenes",
"eumenideses":"eumenides",
"eumetopiases":"eumetopias",
"eumopses":"eumops",
"eumyceteses":"eumycetes",
"eumycotas":"eumycota",
"eunecteses":"eunectes",
"eunuches":"eunuch",
"euonymuses":"euonymus",
"eupatoriums":"eupatorium",
"eupatridae":"eupatrid",
"eupatrids":"eupatrid",
"euphaguses":"euphagus",
"euphausiaceas":"euphausiacea",
"euphemized":"euphemize",
"euphemizing":"euphemize",
"euphonies":"euphony",
"euphorbias":"euphorbia",
"euphorbiaceaes":"euphorbiaceae",
"euphorbiums":"euphorbium",
"euphractuses":"euphractus",
"euphrasies":"euphrasy",
"euphrateses":"euphrates",
"euplectellas":"euplectella",
"euproctises":"euproctis",
"eurekas":"eureka",
"eurhythmicses":"eurhythmics",
"euripi":"euripus",
"euros":"euro",
"euronithopods":"euronithopod",
"euronithopodas":"euronithopoda",
"europeanized":"europeanize",
"europeanizing":"europeanize",
"europiums":"europium",
"eurotialeses":"eurotiales",
"eurotiums":"eurotium",
"euryales":"euryale",
"euryalidas":"euryalida",
"eurylaimis":"eurylaimi",
"eurylaimidaes":"eurylaimidae",
"eurypteridas":"eurypterida",
"eurythmicses":"eurythmics",
"eustomas":"eustoma",
"eutamiases":"eutamias",
"euterpes":"euterpe",
"euthanasias":"euthanasia",
"eutherias":"eutheria",
"eutherians":"eutherian",
"euthynnuses":"euthynnus",
"evs":"ev",
"evacuated":"evacuate",
"evacuates":"evacuate",
"evacuating":"evacuate",
"evacuations":"evacuation",
"evaded":"evade",
"evades":"evade",
"evading":"evade",
"evaginated":"evaginate",
"evaginating":"evaginate",
"evaluated":"evaluate",
"evaluates":"evaluate",
"evaluating":"evaluate",
"evaluations":"evaluation",
"evaluators":"evaluator",
"evanesced":"evanesce",
"evanesces":"evanesce",
"evanescing":"evanesce",
"evanescences":"evanescence",
"evangels":"evangel",
"evangelicals":"evangelical",
"evangelisms":"evangelism",
"evangelists":"evangelist",
"evangelized":"evangelize",
"evangelizing":"evangelize",
"evaporated":"evaporate",
"evaporates":"evaporate",
"evaporating":"evaporate",
"evaporations":"evaporation",
"evaporometers":"evaporometer",
"evasions":"evasion",
"evasivenesses":"evasiveness",
"eves":"eve",
"evened":"even",
"evening":"even",
"evens":"even",
"evenfalls":"evenfall",
"evenings":"evening",
"evening-snows":"evening-snow",
"eveningwears":"eveningwear",
"evenks":"evenk",
"evenkis":"evenki",
"evennesses":"evenness",
"evensongs":"evensong",
"events":"event",
"eventides":"eventide",
"eventualities":"eventuality",
"eventuated":"eventuate",
"eventuating":"eventuate",
"everests":"everest",
"evergreens":"evergreen",
"everlastings":"everlasting",
"eversions":"eversion",
"everted":"evert",
"everting":"evert",
"evertings":"everting",
"everydaynesses":"everydayness",
"evicted":"evict",
"evicting":"evict",
"evicts":"evict",
"evictions":"eviction",
"evidenced":"evidence",
"evidences":"evidence",
"evidencing":"evidence",
"eviler":"evil",
"evilest":"evil",
"evils":"evil",
"evildoers":"evildoer",
"evildoings":"evildoing",
"evilnesses":"evilness",
"evinced":"evince",
"evinces":"evince",
"evincing":"evince",
"eviscerated":"eviscerate",
"eviscerates":"eviscerate",
"eviscerating":"eviscerate",
"evocations":"evocation",
"evoked":"evoke",
"evokes":"evoke",
"evoking":"evoke",
"evolutions":"evolution",
"evolutionists":"evolutionist",
"evolved":"evolve",
"evolves":"evolve",
"evolving":"evolve",
"ews":"ew",
"ewes":"ewe",
"ewenkis":"ewenki",
"ewers":"ewer",
"exes":"ex",
"ex-husbands":"ex-husband",
"ex-servicemen":"ex-serviceman",
"exacerbated":"exacerbate",
"exacerbates":"exacerbate",
"exacerbating":"exacerbate",
"exacerbations":"exacerbation",
"exacted":"exact",
"exacting":"exact",
"exacts":"exact",
"exactas":"exacta",
"exactitudes":"exactitude",
"exactnesses":"exactness",
"exacums":"exacum",
"exaeretodons":"exaeretodon",
"exaggerated":"exaggerate",
"exaggerates":"exaggerate",
"exaggerating":"exaggerate",
"exaggerations":"exaggeration",
"exaggerators":"exaggerator",
"exalted":"exalt",
"exalting":"exalt",
"exalts":"exalt",
"exaltations":"exaltation",
"exams":"exam",
"examens":"examen",
"examinations":"examination",
"examined":"examine",
"examines":"examine",
"examining":"examine",
"examinees":"examinee",
"examiners":"examiner",
"examples":"example",
"exanthems":"exanthem",
"exanthemas":"exanthema",
"exanthemata":"exanthema",
"exarchates":"exarchate",
"exarchies":"exarchy",
"exasperated":"exasperate",
"exasperates":"exasperate",
"exasperating":"exasperate",
"exasperations":"exasperation",
"excavated":"excavate",
"excavates":"excavate",
"excavating":"excavate",
"excavations":"excavation",
"excavators":"excavator",
"exceeded":"exceed",
"exceeding":"exceed",
"exceeds":"exceed",
"excelled":"excel",
"excelling":"excel",
"excels":"excel",
"excellences":"excellence",
"excellencies":"excellency",
"excelsiors":"excelsior",
"excepted":"except",
"excepting":"except",
"excepts":"except",
"exceptions":"exception",
"excerpted":"excerpt",
"excerpting":"excerpt",
"excerpts":"excerpt",
"excesses":"excess",
"excessivenesses":"excessiveness",
"exchanged":"exchange",
"exchanges":"exchange",
"exchanging":"exchange",
"exchangeabilities":"exchangeability",
"exchangers":"exchanger",
"exchequers":"exchequer",
"excided":"excide",
"exciding":"excide",
"excised":"excise",
"excises":"excise",
"excising":"excise",
"excisemen":"exciseman",
"excisions":"excision",
"excitabilities":"excitability",
"excitablenesses":"excitableness",
"excitations":"excitation",
"excited":"excite",
"excites":"excite",
"exciting":"excite",
"excitements":"excitement",
"exclaimed":"exclaim",
"exclaiming":"exclaim",
"exclaims":"exclaim",
"exclaimings":"exclaiming",
"exclamations":"exclamation",
"excluded":"exclude",
"excludes":"exclude",
"excluding":"exclude",
"exclusions":"exclusion",
"exclusives":"exclusive",
"exclusivenesses":"exclusiveness",
"excogitated":"excogitate",
"excogitates":"excogitate",
"excogitating":"excogitate",
"excogitations":"excogitation",
"excommunicated":"excommunicate",
"excommunicates":"excommunicate",
"excommunicating":"excommunicate",
"excommunications":"excommunication",
"excoriated":"excoriate",
"excoriates":"excoriate",
"excoriating":"excoriate",
"excoriations":"excoriation",
"excrements":"excrement",
"excrescences":"excrescence",
"excrescencies":"excrescency",
"excretas":"excreta",
"excreted":"excrete",
"excretes":"excrete",
"excreting":"excrete",
"excretings":"excreting",
"excretions":"excretion",
"excruciated":"excruciate",
"excruciates":"excruciate",
"excruciating":"excruciate",
"excruciations":"excruciation",
"exculpated":"exculpate",
"exculpates":"exculpate",
"exculpating":"exculpate",
"excursions":"excursion",
"excursionists":"excursionist",
"excursuses":"excursus",
"excused":"excuse",
"excuses":"excuse",
"excusing":"excuse",
"execrated":"execrate",
"execrates":"execrate",
"execrating":"execrate",
"execrations":"execration",
"executed":"execute",
"executes":"execute",
"executing":"execute",
"executings":"executing",
"executions":"execution",
"executioners":"executioner",
"executives":"executive",
"executors":"executor",
"executrices":"executrix",
"executrixes":"executrix",
"exegeses":"exegesis",
"exemplars":"exemplar",
"exemplifications":"exemplification",
"exemplified":"exemplify",
"exemplifies":"exemplify",
"exemplifying":"exemplify",
"exempla":"exemplum",
"exempted":"exempt",
"exempting":"exempt",
"exempts":"exempt",
"exemptions":"exemption",
"exenterated":"exenterate",
"exenterating":"exenterate",
"exercised":"exercise",
"exercises":"exercise",
"exercising":"exercise",
"exercisers":"exerciser",
"exercisings":"exercising",
"exercycles":"exercycle",
"exerted":"exert",
"exerting":"exert",
"exerts":"exert",
"exertions":"exertion",
"exfoliated":"exfoliate",
"exfoliating":"exfoliate",
"exhalations":"exhalation",
"exhaled":"exhale",
"exhales":"exhale",
"exhaling":"exhale",
"exhausted":"exhaust",
"exhausting":"exhaust",
"exhausts":"exhaust",
"exhaustions":"exhaustion",
"exhibited":"exhibit",
"exhibiting":"exhibit",
"exhibits":"exhibit",
"exhibitions":"exhibition",
"exhibitioners":"exhibitioner",
"exhibitionisms":"exhibitionism",
"exhibitionists":"exhibitionist",
"exhibitors":"exhibitor",
"exhilarated":"exhilarate",
"exhilarates":"exhilarate",
"exhilarating":"exhilarate",
"exhilarations":"exhilaration",
"exhorted":"exhort",
"exhorting":"exhort",
"exhorts":"exhort",
"exhortations":"exhortation",
"exhumations":"exhumation",
"exhumed":"exhume",
"exhumes":"exhume",
"exhuming":"exhume",
"exigences":"exigence",
"exigencies":"exigency",
"exiguities":"exiguity",
"exiled":"exile",
"exiles":"exile",
"exiling":"exile",
"existed":"exist",
"existing":"exist",
"exists":"exist",
"existences":"existence",
"existentialisms":"existentialism",
"exited":"exit",
"exiting":"exit",
"exits":"exit",
"exocarps":"exocarp",
"exocoetidaes":"exocoetidae",
"exocycloidas":"exocycloida",
"exodontias":"exodontia",
"exodonticses":"exodontics",
"exoduses":"exodus",
"exogamies":"exogamy",
"exonerated":"exonerate",
"exonerates":"exonerate",
"exonerating":"exonerate",
"exonerations":"exoneration",
"exopterygotas":"exopterygota",
"exorbitances":"exorbitance",
"exorcised":"exorcise",
"exorcises":"exorcise",
"exorcising":"exorcise",
"exorcisers":"exorciser",
"exorcists":"exorcist",
"exorcized":"exorcize",
"exorcizes":"exorcize",
"exorcizing":"exorcize",
"exordia":"exordium",
"exordiums":"exordium",
"exostoses":"exostosis",
"exoticisms":"exoticism",
"exoticnesses":"exoticness",
"exotisms":"exotism",
"expanded":"expand",
"expanding":"expand",
"expands":"expand",
"expanders":"expander",
"expanses":"expanse",
"expansions":"expansion",
"expansivenesses":"expansiveness",
"expansivities":"expansivity",
"expatiated":"expatiate",
"expatiates":"expatiate",
"expatiating":"expatiate",
"expatriated":"expatriate",
"expatriates":"expatriate",
"expatriating":"expatriate",
"expatriations":"expatriation",
"expected":"expect",
"expecting":"expect",
"expects":"expect",
"expectancies":"expectancy",
"expectants":"expectant",
"expectations":"expectation",
"expectednesses":"expectedness",
"expectorated":"expectorate",
"expectorates":"expectorate",
"expectorating":"expectorate",
"expectorations":"expectoration",
"expediences":"expedience",
"expediencies":"expediency",
"expedients":"expedient",
"expedited":"expedite",
"expedites":"expedite",
"expediting":"expedite",
"expeditions":"expedition",
"expeditiousnesses":"expeditiousness",
"expelled":"expel",
"expelling":"expel",
"expels":"expel",
"expellings":"expelling",
"expended":"expend",
"expending":"expend",
"expends":"expend",
"expenders":"expender",
"expendings":"expending",
"expenditures":"expenditure",
"expenses":"expense",
"experienced":"experience",
"experiences":"experience",
"experiencing":"experience",
"experimented":"experiment",
"experimenting":"experiment",
"experiments":"experiment",
"experimentalists":"experimentalist",
"experimentations":"experimentation",
"experimenters":"experimenter",
"experts":"expert",
"expertises":"expertise",
"expertized":"expertize",
"expertizing":"expertize",
"expertnesses":"expertness",
"expiated":"expiate",
"expiates":"expiate",
"expiating":"expiate",
"expiations":"expiation",
"expirations":"expiration",
"expired":"expire",
"expires":"expire",
"expiring":"expire",
"expiries":"expiry",
"explained":"explain",
"explaining":"explain",
"explains":"explain",
"explananda":"explanandum",
"explanations":"explanation",
"explanted":"explant",
"explanting":"explant",
"explants":"explant",
"expletives":"expletive",
"explicated":"explicate",
"explicates":"explicate",
"explicating":"explicate",
"exploded":"explode",
"explodes":"explode",
"exploding":"explode",
"exploited":"exploit",
"exploiting":"exploit",
"exploits":"exploit",
"exploitations":"exploitation",
"exploiters":"exploiter",
"explorations":"exploration",
"explored":"explore",
"explores":"explore",
"exploring":"explore",
"explorers":"explorer",
"explosions":"explosion",
"explosives":"explosive",
"expos":"expo",
"exponents":"exponent",
"exponentials":"exponential",
"exponentiations":"exponentiation",
"exported":"export",
"exporting":"export",
"exports":"export",
"exportations":"exportation",
"exporters":"exporter",
"exportings":"exporting",
"exposed":"expose",
"exposes":"expose",
"exposing":"expose",
"expositions":"exposition",
"expositors":"expositor",
"expostulated":"expostulate",
"expostulating":"expostulate",
"expostulations":"expostulation",
"exposures":"exposure",
"expounded":"expound",
"expounding":"expound",
"expounds":"expound",
"expoundings":"expounding",
"expressed":"express",
"expresses":"express",
"expressing":"express",
"expressages":"expressage",
"expressions":"expression",
"expressmen":"expressman",
"expressways":"expressway",
"expropriated":"expropriate",
"expropriates":"expropriate",
"expropriating":"expropriate",
"expulsions":"expulsion",
"expunctions":"expunction",
"expunged":"expunge",
"expunges":"expunge",
"expunging":"expunge",
"expungings":"expunging",
"expurgated":"expurgate",
"expurgates":"expurgate",
"expurgating":"expurgate",
"expurgations":"expurgation",
"exquisites":"exquisite",
"exsanguinated":"exsanguinate",
"exsanguinating":"exsanguinate",
"exscinded":"exscind",
"exscinding":"exscind",
"exserted":"exsert",
"exserting":"exsert",
"exsiccated":"exsiccate",
"exsiccating":"exsiccate",
"extemporisations":"extemporisation",
"extemporizations":"extemporization",
"extemporized":"extemporize",
"extemporizes":"extemporize",
"extemporizing":"extemporize",
"extended":"extend",
"extending":"extend",
"extends":"extend",
"extensions":"extension",
"extensors":"extensor",
"extents":"extent",
"extenuated":"extenuate",
"extenuates":"extenuate",
"extenuating":"extenuate",
"extenuations":"extenuation",
"exteriors":"exterior",
"exteriorisations":"exteriorisation",
"exteriorizations":"exteriorization",
"exteriorized":"exteriorize",
"exteriorizes":"exteriorize",
"exteriorizing":"exteriorize",
"exterminated":"exterminate",
"exterminates":"exterminate",
"exterminating":"exterminate",
"exterminations":"extermination",
"exterminators":"exterminator",
"externs":"extern",
"externals":"external",
"externalisations":"externalisation",
"externalities":"externality",
"externalizations":"externalization",
"externalized":"externalize",
"externalizes":"externalize",
"externalizing":"externalize",
"extinctions":"extinction",
"extinguished":"extinguish",
"extinguishes":"extinguish",
"extinguishing":"extinguish",
"extinguishers":"extinguisher",
"extinguishings":"extinguishing",
"extirpated":"extirpate",
"extirpates":"extirpate",
"extirpating":"extirpate",
"extirpations":"extirpation",
"extolled":"extol",
"extolling":"extol",
"extols":"extol",
"extolls":"extoll",
"extollers":"extoller",
"extorted":"extort",
"extorting":"extort",
"extorts":"extort",
"extortions":"extortion",
"extortioners":"extortioner",
"extortionists":"extortionist",
"extras":"extra",
"extracted":"extract",
"extracting":"extract",
"extracts":"extract",
"extractions":"extraction",
"extractors":"extractor",
"extradited":"extradite",
"extradites":"extradite",
"extraditing":"extradite",
"extradoses":"extrados",
"extrapolated":"extrapolate",
"extrapolates":"extrapolate",
"extrapolating":"extrapolate",
"extrasystoles":"extrasystole",
"extraterrestrials":"extraterrestrial",
"extravagances":"extravagance",
"extravaganzas":"extravaganza",
"extravagated":"extravagate",
"extravagating":"extravagate",
"extravasated":"extravasate",
"extravasating":"extravasate",
"extraverts":"extravert",
"extremer":"extreme",
"extremes":"extreme",
"extremest":"extreme",
"extremists":"extremist",
"extremities":"extremity",
"extremums":"extremum",
"extricated":"extricate",
"extricates":"extricate",
"extricating":"extricate",
"extrications":"extrication",
"extroverts":"extrovert",
"extruded":"extrude",
"extrudes":"extrude",
"extruding":"extrude",
"extrusions":"extrusion",
"exuberances":"exuberance",
"exuberated":"exuberate",
"exuberating":"exuberate",
"exudations":"exudation",
"exuded":"exude",
"exudes":"exude",
"exuding":"exude",
"exulted":"exult",
"exulting":"exult",
"exults":"exult",
"exultations":"exultation",
"exwives":"exwife",
"eyed":"eye",
"eyeing":"eye",
"eyes":"eye",
"eying":"eye",
"eye-lotions":"eye-lotion",
"eyeballed":"eyeball",
"eyeballing":"eyeball",
"eyeballs":"eyeball",
"eyebaths":"eyebath",
"eyebrows":"eyebrow",
"eyecups":"eyecup",
"eyefuls":"eyeful",
"eyeglasses":"eyeglass",
"eyeglasseses":"eyeglasses",
"eyelashes":"eyelash",
"eyelets":"eyelet",
"eyelids":"eyelid",
"eyepatches":"eyepatch",
"eyepieces":"eyepiece",
"eyeshades":"eyeshade",
"eyeshots":"eyeshot",
"eyesights":"eyesight",
"eyesores":"eyesore",
"eyespots":"eyespot",
"eyestrains":"eyestrain",
"eyeteeth":"eyetooth",
"eyetooths":"eyetooth",
"eyewashes":"eyewash",
"eyras":"eyra",
"eyries":"eyrie",
"eyrirs":"eyrir",
"ezos":"ezo",
"ezo-yama-hagis":"ezo-yama-hagi",
"fs":"f",
"fabaceaes":"fabaceae",
"fabianas":"fabiana",
"fabled":"fable",
"fables":"fable",
"fabling":"fable",
"fabliaux":"fabliau",
"fabrics":"fabric",
"fabricated":"fabricate",
"fabricates":"fabricate",
"fabricating":"fabricate",
"fabrications":"fabrication",
"fabricators":"fabricator",
"facades":"facade",
"faced":"face",
"faces":"face",
"facing":"face",
"face-cloths":"face-cloth",
"face-hardened":"face-harden",
"face-hardening":"face-harden",
"face-lifted":"face-lift",
"face-lifting":"face-lift",
"face-lifts":"face-lift",
"facecloths":"facecloth",
"faceted":"facet",
"faceting":"facet",
"facets":"facet",
"facetted":"facet",
"facetting":"facet",
"facias":"facia",
"facials":"facial",
"facilitated":"facilitate",
"facilitates":"facilitate",
"facilitating":"facilitate",
"facilities":"facility",
"facings":"facing",
"facsimiled":"facsimile",
"facsimiles":"facsimile",
"facsimiling":"facsimile",
"facts":"fact",
"factions":"faction",
"factored":"factor",
"factoring":"factor",
"factors":"factor",
"factorings":"factoring",
"factorisations":"factorisation",
"factorizations":"factorization",
"factories":"factory",
"factualities":"factuality",
"factualnesses":"factualness",
"faculae":"facula",
"faculties":"faculty",
"fads":"fad",
"faded":"fade",
"fades":"fade",
"fading":"fade",
"fadeouts":"fadeout",
"fadings":"fading",
"fados":"fado",
"faeceses":"faeces",
"faeries":"faery",
"faeroeses":"faeroes",
"fagged":"fag",
"fagging":"fag",
"fags":"fag",
"fagaceaes":"fagaceae",
"fagaleses":"fagales",
"faggoted":"faggot",
"faggoting":"faggot",
"faggots":"faggot",
"fagopyrums":"fagopyrum",
"fagoted":"fagot",
"fagoting":"fagot",
"fagots":"fagot",
"faguses":"fagus",
"failed":"fail",
"failing":"fail",
"fails":"fail",
"failings":"failing",
"failures":"failure",
"faineances":"faineance",
"faineants":"faineant",
"fainted":"faint",
"fainter":"faint",
"faintest":"faint",
"fainting":"faint",
"faints":"faint",
"faintnesses":"faintness",
"fairer":"fair",
"fairest":"fair",
"fairs":"fair",
"fair-maids-of-frances":"fair-maids-of-france",
"fair-mindednesses":"fair-mindedness",
"fair-traded":"fair-trade",
"fair-trading":"fair-trade",
"fairnesses":"fairness",
"fairies":"fairy",
"fairy-slippers":"fairy-slipper",
"fairylands":"fairyland",
"fairytales":"fairytale",
"faiths":"faith",
"faithfuls":"faithful",
"faithfulnesses":"faithfulness",
"faithlessnesses":"faithlessness",
"faked":"fake",
"fakes":"fake",
"faking":"fake",
"fakeers":"fakeer",
"fakers":"faker",
"fakeries":"fakery",
"fakirs":"fakir",
"falafels":"falafel",
"falcatifoliums":"falcatifolium",
"falcos":"falco",
"falcons":"falcon",
"falcon-gentils":"falcon-gentil",
"falcon-gentles":"falcon-gentle",
"falconers":"falconer",
"falconidaes":"falconidae",
"falconiformeses":"falconiformes",
"falderals":"falderal",
"fallen":"fall",
"falling":"fall",
"falls":"fall",
"fell":"fall",
"fallacies":"fallacy",
"fallals":"fallal",
"fallbacks":"fallback",
"fallfishes":"fallfish",
"fallings":"falling",
"falling-outs":"falling-out",
"fallings-out":"falling-out",
"falloffs":"falloff",
"fallouts":"fallout",
"fallses":"falls",
"falser":"false",
"falsest":"false",
"falsehoods":"falsehood",
"falsenesses":"falseness",
"falsettos":"falsetto",
"falsifications":"falsification",
"falsified":"falsify",
"falsifies":"falsify",
"falsifying":"falsify",
"falsifyings":"falsifying",
"falsities":"falsity",
"falstaffs":"falstaff",
"faltered":"falter",
"faltering":"falter",
"falters":"falter",
"falterings":"faltering",
"famed":"fame",
"fames":"fame",
"faming":"fame",
"familiars":"familiar",
"familiarities":"familiarity",
"familiarized":"familiarize",
"familiarizes":"familiarize",
"familiarizing":"familiarize",
"families":"family",
"famines":"famine",
"famished":"famish",
"famishing":"famish",
"famishments":"famishment",
"famotidines":"famotidine",
"famuli":"famulus",
"fanned":"fan",
"fanning":"fan",
"fans":"fan",
"fanalokas":"fanaloka",
"fanatics":"fanatic",
"fanaticisms":"fanaticism",
"fanaticized":"fanaticize",
"fanaticizing":"fanaticize",
"fanciers":"fancier",
"fancified":"fancify",
"fancifying":"fancify",
"fancied":"fancy",
"fancier":"fancy",
"fancies":"fancy",
"fanciest":"fancy",
"fancying":"fancy",
"fancyworks":"fancywork",
"fandangos":"fandango",
"fanes":"fane",
"fanfares":"fanfare",
"fangs":"fang",
"fanlights":"fanlight",
"fannies":"fanny",
"fantans":"fantan",
"fantasias":"fantasia",
"fantasized":"fantasize",
"fantasizing":"fantasize",
"fantasts":"fantast",
"fantasticals":"fantastical",
"fantasticated":"fantasticate",
"fantasticating":"fantasticate",
"fantasies":"fantasy",
"fantis":"fanti",
"fanweeds":"fanweed",
"fanworts":"fanwort",
"faos":"fao",
"faqirs":"faqir",
"faquirs":"faquir",
"farther":"far",
"farthest":"far",
"further":"far",
"furthest":"far",
"farads":"farad",
"faradays":"faraday",
"farawaynesses":"farawayness",
"farced":"farce",
"farces":"farce",
"farcing":"farce",
"farcies":"farcy",
"farded":"fard",
"farding":"fard",
"fared":"fare",
"fares":"fare",
"faring":"fare",
"farewells":"farewell",
"farkleberries":"farkleberry",
"farmed":"farm",
"farming":"farm",
"farms":"farm",
"farmers":"farmer",
"farmers-general":"farmer-general",
"farmhands":"farmhand",
"farmhouses":"farmhouse",
"farmings":"farming",
"farmlands":"farmland",
"farmplaces":"farmplace",
"farmsteads":"farmstead",
"farmyards":"farmyard",
"farnesses":"farness",
"faroeses":"faroes",
"farragoes":"farrago",
"farriers":"farrier",
"farrieries":"farriery",
"farrowed":"farrow",
"farrowing":"farrow",
"farrows":"farrow",
"farrowings":"farrowing",
"farsis":"farsi",
"farsightednesses":"farsightedness",
"farted":"fart",
"farting":"fart",
"farts":"fart",
"far":"far",
"farthings":"farthing",
"fartings":"farting",
"fasciae":"fascia",
"fascias":"fascia",
"fascicles":"fascicle",
"fascicules":"fascicule",
"fasciculi":"fasciculus",
"fascinated":"fascinate",
"fascinates":"fascinate",
"fascinating":"fascinate",
"fascinations":"fascination",
"fasciolas":"fasciola",
"fasciolidaes":"fasciolidae",
"fascisti":"fascista",
"fashioned":"fashion",
"fashioning":"fashion",
"fashions":"fashion",
"fashionings":"fashioning",
"fashionmongers":"fashionmonger",
"fasiculuses":"fasiculus",
"faster":"fast",
"fastest":"fast",
"fasts":"fast",
"fast-talked":"fast-talk",
"fast-talking":"fast-talk",
"fastballs":"fastball",
"fastened":"fasten",
"fastening":"fasten",
"fastens":"fasten",
"fasteners":"fastener",
"fastenings":"fastening",
"fastigia":"fastigium",
"fastigiums":"fastigium",
"fastings":"fasting",
"fastnesses":"fastness",
"fats":"fat",
"fatted":"fat",
"fatter":"fat",
"fattest":"fat",
"fatting":"fat",
"fatalists":"fatalist",
"fatalities":"fatality",
"fated":"fate",
"fates":"fate",
"fating":"fate",
"fateses":"fates",
"fatheads":"fathead",
"fathered":"father",
"fathering":"father",
"fathers":"father",
"father-gods":"father-god",
"fathers-in-law":"father-in-law",
"fatherhoods":"fatherhood",
"fatherlands":"fatherland",
"fatherlinesses":"fatherliness",
"fathomed":"fathom",
"fathoming":"fathom",
"fathoms":"fathom",
"fathometers":"fathometer",
"fatigued":"fatigue",
"fatigues":"fatigue",
"fatiguing":"fatigue",
"fatisms":"fatism",
"fatnesses":"fatness",
"fatsoes":"fatso",
"fatsos":"fatso",
"fattened":"fatten",
"fattening":"fatten",
"fattens":"fatten",
"fattinesses":"fattiness",
"fattisms":"fattism",
"fattier":"fatty",
"fatties":"fatty",
"fattiest":"fatty",
"fatuities":"fatuity",
"fatuousnesses":"fatuousness",
"faucets":"faucet",
"faulkners":"faulkner",
"faulted":"fault",
"faulting":"fault",
"faults":"fault",
"faultfinders":"faultfinder",
"faultfindings":"faultfinding",
"faultinesses":"faultiness",
"faultier":"faulty",
"faultiest":"faulty",
"faunae":"fauna",
"faunas":"fauna",
"fausts":"faust",
"faustuses":"faustus",
"fauteuils":"fauteuil",
"favelas":"favela",
"favored":"favor",
"favoring":"favor",
"favors":"favor",
"favorablenesses":"favorableness",
"favorites":"favorite",
"favoritisms":"favoritism",
"favoured":"favour",
"favouring":"favour",
"favours":"favour",
"favourablenesses":"favourableness",
"favourites":"favourite",
"favouritisms":"favouritism",
"favuses":"favus",
"fawned":"fawn",
"fawning":"fawn",
"fawns":"fawn",
"fawners":"fawner",
"faxes":"fax",
"fazed":"faze",
"fazes":"faze",
"fazing":"faze",
"fbis":"fbi",
"fdics":"fdic",
"fdrs":"fdr",
"fes":"fe",
"fealties":"fealty",
"feared":"fear",
"fearing":"fear",
"fears":"fear",
"fearfulnesses":"fearfulness",
"fearlessnesses":"fearlessness",
"feasibilities":"feasibility",
"feasiblenesses":"feasibleness",
"feasted":"feast",
"feasting":"feast",
"feasts":"feast",
"feastings":"feasting",
"feats":"feat",
"feathered":"feather",
"feathering":"feather",
"feathers":"feather",
"featherbeds":"featherbed",
"featheredged":"featheredge",
"featheredging":"featheredge",
"featherinesses":"featheriness",
"featherings":"feathering",
"featherstitched":"featherstitch",
"featherstitching":"featherstitch",
"feathertops":"feathertop",
"featured":"feature",
"features":"feature",
"featuring":"feature",
"febs":"feb",
"febricities":"febricity",
"febrifuges":"febrifuge",
"Februaries":"February",
"feceses":"feces",
"feculae":"fecula",
"fecundated":"fecundate",
"fecundating":"fecundate",
"fecundations":"fecundation",
"fecundities":"fecundity",
"feds":"fed",
"fedayeen":"fedayee",
"federacies":"federacy",
"federals":"federal",
"federalisations":"federalisation",
"federalists":"federalist",
"federalizations":"federalization",
"federalized":"federalize",
"federalizes":"federalize",
"federalizing":"federalize",
"federated":"federate",
"federates":"federate",
"federating":"federate",
"federations":"federation",
"federitas":"federita",
"fedoras":"fedora",
"feed":"fee",
"feeing":"fee",
"fees":"fee",
"feebler":"feeble",
"feeblest":"feeble",
"feeblenesses":"feebleness",
"fed":"feed",
"feeding":"feed",
"feeds":"feed",
"feedbags":"feedbag",
"feeders":"feeder",
"feedings":"feeding",
"feeling":"feel",
"feels":"feel",
"felt":"feel",
"feelers":"feeler",
"feelings":"feeling",
"feigned":"feign",
"feigning":"feign",
"feigns":"feign",
"feignings":"feigning",
"feijoas":"feijoa",
"feinted":"feint",
"feinting":"feint",
"feistier":"feisty",
"feistiest":"feisty",
"felafels":"felafel",
"feldenes":"feldene",
"feldspars":"feldspar",
"felicias":"felicia",
"felicitated":"felicitate",
"felicitates":"felicitate",
"felicitating":"felicitate",
"felicitations":"felicitation",
"felicitousnesses":"felicitousness",
"felicities":"felicity",
"felids":"felid",
"felidaes":"felidae",
"felines":"feline",
"felises":"felis",
"felled":"fell",
"felling":"fell",
"fells":"fell",
"fellas":"fella",
"fellaheen":"fellah",
"fellahin":"fellah",
"fellahs":"fellah",
"fellatios":"fellatio",
"fellations":"fellation",
"felloes":"felloe",
"fellows":"fellow",
"fellowmen":"fellowman",
"fellowships":"fellowship",
"fellies":"felly",
"felo-de-ses":"felo-de-se",
"felones-de-se":"felo-de-se",
"felons":"felon",
"felonries":"felonry",
"felonies":"felony",
"felones_de_se":"felo_de_se",
"felos_de_se":"felo_de_se",
"felspars":"felspar",
"felted":"felt",
"felting":"felt",
"felts":"felt",
"feluccas":"felucca",
"felworts":"felwort",
"females":"female",
"femalenesses":"femaleness",
"femininenesses":"feminineness",
"feminisms":"feminism",
"feminists":"feminist",
"feminized":"feminize",
"feminizing":"feminize",
"femorises":"femoris",
"femtometers":"femtometer",
"femtometres":"femtometre",
"femora":"femur",
"femurs":"femur",
"fens":"fen",
"fenced":"fence",
"fences":"fence",
"fencing":"fence",
"fencers":"fencer",
"fencings":"fencing",
"fended":"fend",
"fending":"fend",
"fenders":"fender",
"fenestellas":"fenestella",
"fenestrae":"fenestra",
"fengtiens":"fengtien",
"fennels":"fennel",
"fennics":"fennic",
"fennier":"fenny",
"fenniest":"fenny",
"fenugreeks":"fenugreek",
"fenusas":"fenusa",
"feoffed":"feoff",
"feoffing":"feoff",
"feoffs":"feoff",
"fer-de-lances":"fer-de-lance",
"feretories":"feretory",
"feriae":"feria",
"ferias":"feria",
"ferities":"ferity",
"fermats":"fermat",
"fermatas":"fermata",
"fermate":"fermata",
"fermented":"ferment",
"fermenting":"ferment",
"ferments":"ferment",
"fermentations":"fermentation",
"fermentings":"fermenting",
"fermentologists":"fermentologist",
"fermis":"fermi",
"fermiums":"fermium",
"ferns":"fern",
"ferneries":"fernery",
"ferocactuses":"ferocactus",
"ferociousnesses":"ferociousness",
"ferocities":"ferocity",
"ferreted":"ferret",
"ferreting":"ferret",
"ferrets":"ferret",
"ferroconcretes":"ferroconcrete",
"ferruled":"ferrule",
"ferrules":"ferrule",
"ferruling":"ferrule",
"ferried":"ferry",
"ferries":"ferry",
"ferrying":"ferry",
"ferryboats":"ferryboat",
"ferryings":"ferrying",
"ferrymen":"ferryman",
"fertilisations":"fertilisation",
"fertilities":"fertility",
"fertilizations":"fertilization",
"fertilized":"fertilize",
"fertilizes":"fertilize",
"fertilizing":"fertilize",
"ferulae":"ferula",
"ferulas":"ferula",
"feruled":"ferule",
"feruling":"ferule",
"fervencies":"fervency",
"fervidnesses":"fervidness",
"fervors":"fervor",
"fervours":"fervour",
"fescues":"fescue",
"fesses":"fess",
"festered":"fester",
"festering":"fester",
"festers":"fester",
"festerings":"festering",
"festinated":"festinate",
"festinating":"festinate",
"festivals":"festival",
"festivities":"festivity",
"festooned":"festoon",
"festooning":"festoon",
"festoons":"festoon",
"festschriften":"festschrift",
"festschrifts":"festschrift",
"festucas":"festuca",
"fetched":"fetch",
"fetches":"fetch",
"fetching":"fetch",
"feted":"fete",
"fetes":"fete",
"feting":"fete",
"feteritas":"feterita",
"fetiales":"fetial",
"fetiches":"fetich",
"fetichisms":"fetichism",
"feticides":"feticide",
"fetishes":"fetish",
"fetishisms":"fetishism",
"fetishized":"fetishize",
"fetishizing":"fetishize",
"fetlocks":"fetlock",
"fetors":"fetor",
"fettered":"fetter",
"fettering":"fetter",
"fetters":"fetter",
"fetterbushes":"fetterbush",
"fettuccines":"fettuccine",
"fettuccinis":"fettuccini",
"fetuses":"fetus",
"feuded":"feud",
"feuding":"feud",
"feuds":"feud",
"feudalisms":"feudalism",
"feudalists":"feudalist",
"feudalities":"feudality",
"feudalized":"feudalize",
"feudalizing":"feudalize",
"feudatories":"feudatory",
"feuilletons":"feuilleton",
"fevered":"fever",
"fevering":"fever",
"fevers":"fever",
"feverfews":"feverfew",
"feverishnesses":"feverishness",
"feverroots":"feverroot",
"fewer":"few",
"fewest":"few",
"fezs":"fez",
"fezzes":"fez",
"fhas":"fha",
"fhlmcs":"fhlmc",
"fiances":"fiance",
"fiancees":"fiancee",
"fiascoes":"fiasco",
"fiascos":"fiasco",
"fiats":"fiat",
"fibbed":"fib",
"fibbing":"fib",
"fibs":"fib",
"fibbers":"fibber",
"fibbings":"fibbing",
"fibers":"fiber",
"fiberboards":"fiberboard",
"fiberglasses":"fiberglass",
"fibres":"fibre",
"fibreboards":"fibreboard",
"fibreglasses":"fibreglass",
"fibrils":"fibril",
"fibrillae":"fibrilla",
"fibrinases":"fibrinase",
"fibrinolysins":"fibrinolysin",
"fibrinolyses":"fibrinolysis",
"fibroadenomas":"fibroadenoma",
"fibroadenomata":"fibroadenoma",
"fibromas":"fibroma",
"fibromata":"fibroma",
"fibulae":"fibula",
"fibulas":"fibula",
"ficklenesses":"fickleness",
"ficoes":"fico",
"fictions":"fiction",
"fictionalisations":"fictionalisation",
"fictionalizations":"fictionalization",
"fictionalized":"fictionalize",
"fictionalizes":"fictionalize",
"fictionalizing":"fictionalize",
"ficuses":"ficus",
"fiddled":"fiddle",
"fiddles":"fiddle",
"fiddling":"fiddle",
"fiddle-faddled":"fiddle-faddle",
"fiddle-faddles":"fiddle-faddle",
"fiddle-faddling":"fiddle-faddle",
"fiddleheads":"fiddlehead",
"fiddlenecks":"fiddleneck",
"fiddlers":"fiddler",
"fiddlesticks":"fiddlestick",
"fiddlier":"fiddly",
"fiddliest":"fiddly",
"fideicommissaries":"fideicommissary",
"fideicommissa":"fideicommissum",
"fedelities":"fidelity",
"fidelities":"fidelity",
"fidgeted":"fidget",
"fidgeting":"fidget",
"fidgets":"fidget",
"fidgetinesses":"fidgetiness",
"fiduciaries":"fiduciary",
"fiefs":"fief",
"fieves":"fief",
"fielded":"field",
"fielding":"field",
"fields":"field",
"field-stripped":"field-strip",
"field-stripping":"field-strip",
"field-stript":"field-strip",
"field-tested":"field-test",
"field-testing":"field-test",
"fielders":"fielder",
"fieldfares":"fieldfare",
"fieldhands":"fieldhand",
"fieldmice":"fieldmouse",
"fieldsmen":"fieldsman",
"fiends":"fiend",
"fiercer":"fierce",
"fiercest":"fierce",
"fiercenesses":"fierceness",
"fierinesses":"fieriness",
"fierier":"fiery",
"fieriest":"fiery",
"fiestas":"fiesta",
"fifed":"fife",
"fifes":"fife",
"fifing":"fife",
"fifers":"fifer",
"fifteens":"fifteen",
"fifteenths":"fifteenth",
"fifths":"fifth",
"fiftieses":"fifties",
"fifties":"fifty",
"figged":"fig",
"figging":"fig",
"figs":"fig",
"figs.":"fig.",
"figeaters":"figeater",
"fighting":"fight",
"fights":"fight",
"fought":"fight",
"fighters":"fighter",
"fightings":"fighting",
"figured":"figure",
"figures":"figure",
"figuring":"figure",
"figureheads":"figurehead",
"figurers":"figurer",
"figurines":"figurine",
"figurings":"figuring",
"fijises":"fijis",
"fils":"fil",
"filagos":"filago",
"filagreed":"filagree",
"filagreeing":"filagree",
"filagrees":"filagree",
"filaments":"filament",
"filarees":"filaree",
"filariae":"filaria",
"filarias":"filaria",
"filariidaes":"filariidae",
"filberts":"filbert",
"filched":"filch",
"filches":"filch",
"filching":"filch",
"filed":"file",
"files":"file",
"filing":"file",
"filefishes":"filefish",
"filers":"filer",
"filets":"filet",
"filiations":"filiation",
"filibustered":"filibuster",
"filibustering":"filibuster",
"filibusters":"filibuster",
"filibusterers":"filibusterer",
"filicaleses":"filicales",
"filicinaes":"filicinae",
"filicopsidas":"filicopsida",
"filigreed":"filigree",
"filigreeing":"filigree",
"filigrees":"filigree",
"filings":"filing",
"Filipinos":"Filipino",
"filled":"fill",
"filling":"fill",
"fills":"fill",
"fill-ins":"fill-in",
"fillagrees":"fillagree",
"filles":"fille",
"fillers":"filler",
"filleted":"fillet",
"filleting":"fillet",
"fillets":"fillet",
"fillings":"filling",
"filliped":"fillip",
"filliping":"fillip",
"fillips":"fillip",
"fillmores":"fillmore",
"fillies":"filly",
"filled_up":"fill_up",
"filmed":"film",
"filming":"film",
"films":"film",
"filmings":"filming",
"filmier":"filmy",
"filmiest":"filmy",
"filtered":"filter",
"filtering":"filter",
"filters":"filter",
"filths":"filth",
"filthinesses":"filthiness",
"filthier":"filthy",
"filthiest":"filthy",
"filtrated":"filtrate",
"filtrates":"filtrate",
"filtrating":"filtrate",
"fila":"filum",
"filums":"filum",
"fimbriae":"fimbria",
"finned":"fin",
"finning":"fin",
"fins":"fin",
"finagled":"finagle",
"finagles":"finagle",
"finagling":"finagle",
"finals":"final",
"finales":"finale",
"finalisations":"finalisation",
"finalities":"finality",
"finalizations":"finalization",
"finalized":"finalize",
"finalizes":"finalize",
"finalizing":"finalize",
"financed":"finance",
"finances":"finance",
"financing":"finance",
"financeses":"finances",
"financiers":"financier",
"financings":"financing",
"finbacks":"finback",
"finding":"find",
"finds":"find",
"found":"find",
"finders":"finder",
"findings":"finding",
"fined":"fine",
"finer":"fine",
"fines":"fine",
"finest":"fine",
"fining":"fine",
"fine-drawing":"fine-draw",
"fine-drawn":"fine-draw",
"fine-draws":"fine-draw",
"fine-drew":"fine-draw",
"fine-tuned":"fine-tune",
"fine-tunes":"fine-tune",
"fine-tuning":"fine-tune",
"finenesses":"fineness",
"fineries":"finery",
"finessed":"finesse",
"finesses":"finesse",
"finessing":"finesse",
"finfoots":"finfoot",
"fingered":"finger",
"fingering":"finger",
"fingers":"finger",
"fingerboards":"fingerboard",
"fingerbreadths":"fingerbreadth",
"fingerflowers":"fingerflower",
"fingermarks":"fingermark",
"fingernails":"fingernail",
"fingerposts":"fingerpost",
"fingerprinted":"fingerprint",
"fingerprinting":"fingerprint",
"fingerprints":"fingerprint",
"fingerroots":"fingerroot",
"fingerstalls":"fingerstall",
"fingertips":"fingertip",
"fingos":"fingo",
"finickier":"finicky",
"finickiest":"finicky",
"finings":"fining",
"finises":"finis",
"finished":"finish",
"finishes":"finish",
"finishing":"finish",
"finishers":"finisher",
"finishings":"finishing",
"finitenesses":"finiteness",
"finitudes":"finitude",
"finks":"fink",
"finlands":"finland",
"finnans":"finnan",
"finnics":"finnic",
"finnishes":"finnish",
"finno-ugrians":"finno-ugrian",
"finno-ugrics":"finno-ugric",
"finnier":"finny",
"finniest":"finny",
"finocchios":"finocchio",
"finochios":"finochio",
"finses":"fins",
"fiords":"fiord",
"fioriture":"fioritura",
"firs":"fir",
"fired":"fire",
"fires":"fire",
"firing":"fire",
"fire-cured":"fire-cure",
"fire-curing":"fire-cure",
"fire-eaters":"fire-eater",
"fire-on-the-mountains":"fire-on-the-mountain",
"fire-raisings":"fire-raising",
"fire-swallowers":"fire-swallower",
"fire-worships":"fire-worship",
"firearms":"firearm",
"fireballs":"fireball",
"firebirds":"firebird",
"firebrands":"firebrand",
"firebrats":"firebrat",
"firebreaks":"firebreak",
"firebugs":"firebug",
"firebushes":"firebush",
"firecrackers":"firecracker",
"firedogs":"firedog",
"firedrakes":"firedrake",
"fireflies":"firefly",
"fireguards":"fireguard",
"firehouses":"firehouse",
"firelocks":"firelock",
"firemen":"fireman",
"firenzes":"firenze",
"fireplaces":"fireplace",
"fireplugs":"fireplug",
"fireproofed":"fireproof",
"fireproofing":"fireproof",
"firerooms":"fireroom",
"firesides":"fireside",
"firethorns":"firethorn",
"firetraps":"firetrap",
"fireweeds":"fireweed",
"firewheels":"firewheel",
"fireworks":"firework",
"firings":"firing",
"firmed":"firm",
"firmer":"firm",
"firmest":"firm",
"firming":"firm",
"firms":"firm",
"firmaments":"firmament",
"firmans":"firman",
"firmianas":"firmiana",
"firmnesses":"firmness",
"firrier":"firry",
"firriest":"firry",
"firsts":"first",
"firstborns":"firstborn",
"fished":"fish",
"fishes":"fish",
"fishing":"fish",
"fish-worships":"fish-worship",
"fishers":"fisher",
"fishermen":"fisherman",
"fisheries":"fishery",
"fishgigs":"fishgig",
"fishmongers":"fishmonger",
"fishnets":"fishnet",
"fishtailed":"fishtail",
"fishtailing":"fishtail",
"fishwives":"fishwife",
"fishworms":"fishworm",
"fishier":"fishy",
"fishiest":"fishy",
"fissions":"fission",
"fissipeds":"fissiped",
"fissures":"fissure",
"fissurellas":"fissurella",
"fissurellidaes":"fissurellidae",
"fisted":"fist",
"fisting":"fist",
"fists":"fist",
"fistfights":"fistfight",
"fistfuls":"fistful",
"fisticuffs":"fisticuff",
"fisticuffses":"fisticuffs",
"fistulae":"fistula",
"fistulas":"fistula",
"fistularias":"fistularia",
"fistulariidaes":"fistulariidae",
"fistulinas":"fistulina",
"fistulinaceaes":"fistulinaceae",
"fits":"fit",
"fitted":"fit",
"fitter":"fit",
"fittest":"fit",
"fitting":"fit",
"fitches":"fitch",
"fitfulnesses":"fitfulness",
"fitnesses":"fitness",
"fittings":"fitting",
"fittingnesses":"fittingness",
"fives":"five",
"five-fingers":"five-finger",
"five-hitters":"five-hitter",
"five-spots":"five-spot",
"fivers":"fiver",
"fivesomes":"fivesome",
"fixed":"fix",
"fixes":"fix",
"fixing":"fix",
"fixated":"fixate",
"fixates":"fixate",
"fixating":"fixate",
"fixations":"fixation",
"fixednesses":"fixedness",
"fixers":"fixer",
"fixings":"fixing",
"fixities":"fixity",
"fixtures":"fixture",
"fizgigs":"fizgig",
"fizzed":"fizz",
"fizzing":"fizz",
"fizzs":"fizz",
"fizzled":"fizzle",
"fizzles":"fizzle",
"fizzling":"fizzle",
"fizzier":"fizzy",
"fizziest":"fizzy",
"fjords":"fjord",
"flabbergasted":"flabbergast",
"flabbergasting":"flabbergast",
"flabbergasts":"flabbergast",
"flabbinesses":"flabbiness",
"flabbier":"flabby",
"flabbiest":"flabby",
"flabella":"flabellum",
"flaccidities":"flaccidity",
"flacourtias":"flacourtia",
"flacourtiaceaes":"flacourtiaceae",
"flagged":"flag",
"flagging":"flag",
"flags":"flag",
"flag-wavers":"flag-waver",
"flagellatas":"flagellata",
"flagellated":"flagellate",
"flagellates":"flagellate",
"flagellating":"flagellate",
"flagellations":"flagellation",
"flagella":"flagellum",
"flagellums":"flagellum",
"flageolets":"flageolet",
"flagfishes":"flagfish",
"flaggier":"flaggy",
"flaggiest":"flaggy",
"flagmen":"flagman",
"flagons":"flagon",
"flagpoles":"flagpole",
"flagroots":"flagroot",
"flagstaffs":"flagstaff",
"flagstaves":"flagstaff",
"flagstones":"flagstone",
"flailed":"flail",
"flailing":"flail",
"flails":"flail",
"flairs":"flair",
"flaks":"flak",
"flaked":"flake",
"flakes":"flake",
"flaking":"flake",
"flakinesses":"flakiness",
"flakier":"flaky",
"flakiest":"flaky",
"flammed":"flam",
"flamming":"flam",
"flams":"flam",
"flambed":"flambe",
"flambeed":"flambe",
"flambees":"flambe",
"flambes":"flambe",
"flambing":"flambe",
"flambeaus":"flambeau",
"flambeaux":"flambeau",
"flamboyances":"flamboyance",
"flamboyants":"flamboyant",
"flamed":"flame",
"flames":"flame",
"flaming":"flame",
"flamefishes":"flamefish",
"flameflowers":"flameflower",
"flamens":"flamen",
"flamines":"flamen",
"flamencos":"flamenco",
"flamings":"flaming",
"flamingoes":"flamingo",
"flamingos":"flamingo",
"flaminiuses":"flaminius",
"flammulinas":"flammulina",
"flamier":"flamy",
"flamiest":"flamy",
"flanges":"flange",
"flanked":"flank",
"flanking":"flank",
"flanks":"flank",
"flanneled":"flannel",
"flanneling":"flannel",
"flannelled":"flannel",
"flannelling":"flannel",
"flannels":"flannel",
"flannelbushes":"flannelbush",
"flannelcakes":"flannelcake",
"flapped":"flap",
"flapping":"flap",
"flaps":"flap",
"flapcakes":"flapcake",
"flapjacks":"flapjack",
"flappings":"flapping",
"flapses":"flaps",
"flared":"flare",
"flares":"flare",
"flaring":"flare",
"flare-ups":"flare-up",
"flashed":"flash",
"flashes":"flash",
"flashing":"flash",
"flashbulbs":"flashbulb",
"flashers":"flasher",
"flashguns":"flashgun",
"flashinesses":"flashiness",
"flashings":"flashing",
"flashlights":"flashlight",
"flashier":"flashy",
"flashiest":"flashy",
"flasks":"flask",
"flaskfuls":"flaskful",
"flats":"flat",
"flatted":"flat",
"flatter":"flat",
"flattest":"flat",
"flatting":"flat",
"flatboats":"flatboat",
"flatcars":"flatcar",
"flatfishes":"flatfish",
"flatfeet":"flatfoot",
"flatfoots":"flatfoot",
"flatheads":"flathead",
"flatnesses":"flatness",
"flattened":"flatten",
"flattening":"flatten",
"flattens":"flatten",
"flattered":"flatter",
"flattering":"flatter",
"flatters":"flatter",
"flatterers":"flatterer",
"flatteries":"flattery",
"flattops":"flattop",
"flatulences":"flatulence",
"flatulencies":"flatulency",
"flatuses":"flatus",
"flatwares":"flatware",
"flatworks":"flatwork",
"flatworms":"flatworm",
"flaunted":"flaunt",
"flaunting":"flaunt",
"flaunts":"flaunt",
"flauntings":"flaunting",
"flauntier":"flaunty",
"flauntiest":"flaunty",
"flautists":"flautist",
"flavored":"flavor",
"flavoring":"flavor",
"flavors":"flavor",
"flavorers":"flavorer",
"flavorings":"flavoring",
"flavorlessnesses":"flavorlessness",
"flavorsomenesses":"flavorsomeness",
"flavoured":"flavour",
"flavouring":"flavour",
"flavours":"flavour",
"flavourers":"flavourer",
"flavourings":"flavouring",
"flawed":"flaw",
"flawing":"flaw",
"flaws":"flaw",
"flawlessnesses":"flawlessness",
"flaxseeds":"flaxseed",
"flayed":"flay",
"flaying":"flay",
"fleas":"flea",
"fleabanes":"fleabane",
"fleaworts":"fleawort",
"flecks":"fleck",
"flections":"flection",
"fledged":"fledge",
"fledges":"fledge",
"fledging":"fledge",
"fledgelings":"fledgeling",
"fledglings":"fledgling",
"fledgier":"fledgy",
"fledgiest":"fledgy",
"fled":"flee",
"fleeing":"flee",
"flees":"flee",
"fleeced":"fleece",
"fleeces":"fleece",
"fleecing":"fleece",
"fleecier":"fleecy",
"fleeciest":"fleecy",
"fleered":"fleer",
"fleering":"fleer",
"fleeted":"fleet",
"fleeter":"fleet",
"fleetest":"fleet",
"fleeting":"fleet",
"fleets":"fleet",
"fleetingnesses":"fleetingness",
"flemishes":"flemish",
"flenched":"flench",
"flenches":"flench",
"flenching":"flench",
"flensed":"flense",
"flenses":"flense",
"flensing":"flense",
"fleshed":"flesh",
"fleshes":"flesh",
"fleshing":"flesh",
"fleshinesses":"fleshiness",
"fleshlier":"fleshly",
"fleshliest":"fleshly",
"fleshier":"fleshy",
"fleshiest":"fleshy",
"fletched":"fletch",
"fletching":"fletch",
"fleur-de-lises":"fleur-de-lis",
"fleurs-de-lis":"fleur-de-lis",
"fleur-de-lyses":"fleur-de-lys",
"flexed":"flex",
"flexes":"flex",
"flexing":"flex",
"flexibilities":"flexibility",
"flexiblenesses":"flexibleness",
"flexions":"flexion",
"flexors":"flexor",
"flexures":"flexure",
"flibbertigibbets":"flibbertigibbet",
"flics":"flic",
"flicked":"flick",
"flicking":"flick",
"flicks":"flick",
"flickered":"flicker",
"flickering":"flicker",
"flickers":"flicker",
"flickertails":"flickertail",
"fliers":"flier",
"flighted":"flight",
"flighting":"flight",
"flights":"flight",
"flight-tested":"flight-test",
"flight-testing":"flight-test",
"flightinesses":"flightiness",
"flightier":"flighty",
"flightiest":"flighty",
"flights_of_stairs":"flight_of_stairs",
"flimflammed":"flimflam",
"flimflamming":"flimflam",
"flimflams":"flimflam",
"flimsinesses":"flimsiness",
"flimsier":"flimsy",
"flimsies":"flimsy",
"flimsiest":"flimsy",
"flinched":"flinch",
"flinches":"flinch",
"flinching":"flinch",
"flinderses":"flinders",
"flindersias":"flindersia",
"flindosas":"flindosa",
"flindosies":"flindosy",
"flinging":"fling",
"flings":"fling",
"flung":"fling",
"flints":"flint",
"flintlocks":"flintlock",
"flintier":"flinty",
"flintiest":"flinty",
"flipped":"flip",
"flipper":"flip",
"flippest":"flip",
"flipping":"flip",
"flips":"flip",
"flip-flopped":"flip-flop",
"flip-flopping":"flip-flop",
"flip-flops":"flip-flop",
"flippancies":"flippancy",
"flippers":"flipper",
"flipperses":"flippers",
"flirted":"flirt",
"flirting":"flirt",
"flirts":"flirt",
"flirtations":"flirtation",
"flirtings":"flirting",
"flits":"flit",
"flitted":"flit",
"flitting":"flit",
"flitches":"flitch",
"flittered":"flitter",
"flittering":"flitter",
"flitters":"flitter",
"flittermice":"flittermouse",
"floated":"float",
"floating":"float",
"floats":"float",
"floatations":"floatation",
"floaters":"floater",
"floating-mosses":"floating-moss",
"floatplanes":"floatplane",
"floatier":"floaty",
"floatiest":"floaty",
"flocs":"floc",
"flocculated":"flocculate",
"flocculating":"flocculate",
"floccules":"floccule",
"flocculi":"flocculus",
"flocci":"floccus",
"flocked":"flock",
"flocking":"flock",
"flocks":"flock",
"flockier":"flocky",
"flockiest":"flocky",
"floddens":"flodden",
"floes":"floe",
"flogged":"flog",
"flogging":"flog",
"flogs":"flog",
"floggings":"flogging",
"flooded":"flood",
"flooding":"flood",
"floods":"flood",
"floodgates":"floodgate",
"floodings":"flooding",
"floodlighted":"floodlight",
"floodlighting":"floodlight",
"floodlights":"floodlight",
"floodlit":"floodlight",
"floored":"floor",
"flooring":"floor",
"floors":"floor",
"floorboards":"floorboard",
"floorcovers":"floorcover",
"floorings":"flooring",
"floorshows":"floorshow",
"floorwalkers":"floorwalker",
"floosies":"floosie",
"floozies":"floozy",
"flopped":"flop",
"flopping":"flop",
"flops":"flop",
"flophouses":"flophouse",
"floppings":"flopping",
"floppier":"floppy",
"floppies":"floppy",
"floppiest":"floppy",
"florae":"flora",
"floras":"flora",
"floreant.":"floreat",
"florences":"florence",
"floricultures":"floriculture",
"floridas":"florida",
"floridnesses":"floridness",
"florilegia":"florilegium",
"florilegiums":"florilegium",
"florins":"florin",
"florists":"florist",
"flossed":"floss",
"flosses":"floss",
"flossing":"floss",
"flossier":"flossy",
"flossiest":"flossy",
"flotations":"flotation",
"flotsams":"flotsam",
"flounced":"flounce",
"flounces":"flounce",
"flouncing":"flounce",
"floundered":"flounder",
"floundering":"flounder",
"flounders":"flounder",
"floured":"flour",
"flouring":"flour",
"flourished":"flourish",
"flourishes":"flourish",
"flourishing":"flourish",
"flouted":"flout",
"flouting":"flout",
"flouts":"flout",
"flowed":"flow",
"flowing":"flow",
"flows":"flow",
"flowered":"flower",
"flowering":"flower",
"flowers":"flower",
"flowers-de-luce":"flower-de-luce",
"flower-of-an-hours":"flower-of-an-hour",
"flowerbeds":"flowerbed",
"flowerings":"flowering",
"flowerpots":"flowerpot",
"flowers-of-an-hours":"flowers-of-an-hour",
"flowerier":"flowery",
"floweriest":"flowery",
"flowings":"flowing",
"flus":"flu",
"flubbed":"flub",
"flubbing":"flub",
"flubs":"flub",
"fluctuated":"fluctuate",
"fluctuates":"fluctuate",
"fluctuating":"fluctuate",
"fluctuations":"fluctuation",
"flues":"flue",
"fluegelhorns":"fluegelhorn",
"fluencies":"fluency",
"fluffed":"fluff",
"fluffing":"fluff",
"fluffs":"fluff",
"fluffinesses":"fluffiness",
"fluffier":"fluffy",
"fluffiest":"fluffy",
"flugelhorns":"flugelhorn",
"fluids":"fluid",
"fluidities":"fluidity",
"fluidized":"fluidize",
"fluidizing":"fluidize",
"fluidnesses":"fluidness",
"fluidounces":"fluidounce",
"fluidrams":"fluidram",
"flukes":"fluke",
"flukier":"fluky",
"flukiest":"fluky",
"flumes":"flume",
"flummeries":"flummery",
"flummoxed":"flummox",
"flummoxes":"flummox",
"flummoxing":"flummox",
"flumped":"flump",
"flumping":"flump",
"flumps":"flump",
"flunked":"flunk",
"flunking":"flunk",
"flunks":"flunk",
"flunkeys":"flunkey",
"flunkies":"flunky",
"fluors":"fluor",
"fluoresced":"fluoresce",
"fluorescing":"fluoresce",
"fluoresceins":"fluorescein",
"fluoresceines":"fluoresceine",
"fluoridated":"fluoridate",
"fluoridates":"fluoridate",
"fluoridating":"fluoridate",
"fluoridations":"fluoridation",
"fluoridizations":"fluoridization",
"fluoridized":"fluoridize",
"fluoridizes":"fluoridize",
"fluoridizing":"fluoridize",
"fluorinated":"fluorinate",
"fluorinating":"fluorinate",
"fluorines":"fluorine",
"fluorites":"fluorite",
"fluoroscopes":"fluoroscope",
"fluorspars":"fluorspar",
"fluoxetines":"fluoxetine",
"flurbiprofens":"flurbiprofen",
"flurried":"flurry",
"flurries":"flurry",
"flurrying":"flurry",
"flushed":"flush",
"flusher":"flush",
"flushes":"flush",
"flushest":"flush",
"flushing":"flush",
"flustered":"fluster",
"flustering":"fluster",
"flusters":"fluster",
"fluted":"flute",
"flutes":"flute",
"fluting":"flute",
"flutings":"fluting",
"flutists":"flutist",
"fluttered":"flutter",
"fluttering":"flutter",
"flutters":"flutter",
"flutterings":"fluttering",
"flutier":"fluty",
"flutiest":"fluty",
"fluxed":"flux",
"fluxes":"flux",
"fluxing":"flux",
"fluxions":"fluxion",
"flew":"fly",
"flies":"fly",
"flown":"fly",
"flying":"fly",
"fly-fished":"fly-fish",
"fly-fishing":"fly-fish",
"flyblew":"flyblow",
"flyblowing":"flyblow",
"flyblown":"flyblow",
"flyblows":"flyblow",
"flybridges":"flybridge",
"flybies":"flyby",
"flybys":"flyby",
"flycatchers":"flycatcher",
"flyers":"flyer",
"flyings":"flying",
"flyleaves":"flyleaf",
"flymen":"flyman",
"flyovers":"flyover",
"flypasts":"flypast",
"flyspecked":"flyspeck",
"flyspecking":"flyspeck",
"flyswats":"flyswat",
"flyswatters":"flyswatter",
"flyways":"flyway",
"fms":"fm",
"fnmas":"fnma",
"foaled":"foal",
"foaling":"foal",
"foamed":"foam",
"foaming":"foam",
"foams":"foam",
"foamflowers":"foamflower",
"foamier":"foamy",
"foamiest":"foamy",
"fobs":"fob",
"focalisations":"focalisation",
"focalizations":"focalization",
"focalized":"focalize",
"focalizing":"focalize",
"foci":"focus",
"focused":"focus",
"focuses":"focus",
"focusing":"focus",
"focussed":"focus",
"focussing":"focus",
"focusings":"focusing",
"focussings":"focussing",
"foes":"foe",
"foehns":"foehn",
"foemen":"foeman",
"foeniculums":"foeniculum",
"foetors":"foetor",
"foetuses":"foetus",
"fogged":"fog",
"fogging":"fog",
"fogs":"fog",
"fogeys":"fogey",
"fogginesses":"fogginess",
"foggier":"foggy",
"foggiest":"foggy",
"foghorns":"foghorn",
"fogsignals":"fogsignal",
"fogies":"fogy",
"fohns":"fohn",
"foibles":"foible",
"foiled":"foil",
"foiling":"foil",
"foils":"foil",
"foilings":"foiling",
"foilsmen":"foilsman",
"foined":"foin",
"foining":"foin",
"foisted":"foist",
"foisting":"foist",
"folacins":"folacin",
"folates":"folate",
"folded":"fold",
"folding":"fold",
"folds":"fold",
"folders":"folder",
"folderols":"folderol",
"foldings":"folding",
"foliages":"foliage",
"foliated":"foliate",
"foliates":"foliate",
"foliating":"foliate",
"foliations":"foliation",
"folios":"folio",
"folia":"folium",
"foliums":"folium",
"folks":"folk",
"folksier":"folksy",
"folksiest":"folksy",
"folkier":"folky",
"folkiest":"folky",
"followed":"follow",
"following":"follow",
"follows":"follow",
"follow-ups":"follow-up",
"followers":"follower",
"followerses":"followers",
"followings":"following",
"follies":"folly",
"fomented":"foment",
"fomenting":"foment",
"foments":"foment",
"fomentations":"fomentation",
"fomenters":"fomenter",
"fomeses":"fomes",
"fomors":"fomor",
"fomorians":"fomorian",
"fonder":"fond",
"fondest":"fond",
"fondled":"fondle",
"fondles":"fondle",
"fondling":"fondle",
"fondlings":"fondling",
"fondnesses":"fondness",
"fondus":"fondu",
"fondues":"fondue",
"fonts":"font",
"fontanels":"fontanel",
"fontanelles":"fontanelle",
"fontenoys":"fontenoy",
"foods":"food",
"foodstuffs":"foodstuff",
"fooled":"fool",
"fooling":"fool",
"fools":"fool",
"fooleries":"foolery",
"foolhardinesses":"foolhardiness",
"foolhardier":"foolhardy",
"foolhardiest":"foolhardy",
"foolishnesses":"foolishness",
"feet":"foot",
"footed":"foot",
"footing":"foot",
"foot-lamberts":"foot-lambert",
"footballs":"football",
"footballers":"footballer",
"footbridges":"footbridge",
"footcloths":"footcloth",
"footers":"footer",
"footfalls":"footfall",
"footgears":"footgear",
"foothills":"foothill",
"footholds":"foothold",
"footings":"footing",
"footled":"footle",
"footles":"footle",
"footling":"footle",
"footlights":"footlight",
"footlightses":"footlights",
"footlockers":"footlocker",
"footmen":"footman",
"footmarks":"footmark",
"footnoted":"footnote",
"footnotes":"footnote",
"footnoting":"footnote",
"footpaths":"footpath",
"footprints":"footprint",
"footraces":"footrace",
"footrests":"footrest",
"footslogged":"footslog",
"footslogging":"footslog",
"footslogs":"footslog",
"footsloggers":"footslogger",
"footstalls":"footstall",
"footsteps":"footstep",
"footsteps-of-springs":"footsteps-of-spring",
"footstools":"footstool",
"footwears":"footwear",
"foozled":"foozle",
"foozling":"foozle",
"fops":"fop",
"fopperies":"foppery",
"foraged":"forage",
"forages":"forage",
"foraging":"forage",
"foragings":"foraging",
"forams":"foram",
"foramens":"foramen",
"foramina":"foramen",
"foraramens":"foramen",
"foraramina":"foramen",
"foraminifers":"foraminifer",
"foraminiferas":"foraminifera",
"forayed":"foray",
"foraying":"foray",
"forays":"foray",
"forbearing":"forbear",
"forbears":"forbear",
"forbore":"forbear",
"forborne":"forbear",
"forbearances":"forbearance",
"forbad":"forbid",
"forbade":"forbid",
"forbidden":"forbid",
"forbidding":"forbid",
"forbids":"forbid",
"forbiddances":"forbiddance",
"forbiddings":"forbidding",
"forced":"force",
"forces":"force",
"forcing":"force",
"force-fed":"force-feed",
"force-feeding":"force-feed",
"force-feeds":"force-feed",
"forcefulnesses":"forcefulness",
"forcemeats":"forcemeat",
"forcipes":"forceps",
"forded":"ford",
"fording":"ford",
"fords":"ford",
"fordings":"fording",
"fordid":"fordo",
"fordoes":"fordo",
"fordoing":"fordo",
"fordone":"fordo",
"fores":"fore",
"forearmed":"forearm",
"forearming":"forearm",
"forearms":"forearm",
"forebears":"forebear",
"foreboded":"forebode",
"forebodes":"forebode",
"foreboding":"forebode",
"forebodings":"foreboding",
"forebrains":"forebrain",
"forecasted":"forecast",
"forecasting":"forecast",
"forecasts":"forecast",
"forecasters":"forecaster",
"forecastings":"forecasting",
"forecastles":"forecastle",
"foreclosed":"foreclose",
"forecloses":"foreclose",
"foreclosing":"foreclose",
"foredid":"foredo",
"foredoes":"foredo",
"foredoing":"foredo",
"foredone":"foredo",
"foredoomed":"foredoom",
"foredooming":"foredoom",
"forefathers":"forefather",
"forefeeling":"forefeel",
"forefelt":"forefeel",
"forefighters":"forefighter",
"forefingers":"forefinger",
"forefeet":"forefoot",
"forefronts":"forefront",
"foregathered":"foregather",
"foregathering":"foregather",
"foregathers":"foregather",
"foregoes":"forego",
"foregoing":"forego",
"foregone":"forego",
"forewent":"forego",
"foregrounded":"foreground",
"foregrounding":"foreground",
"foregrounds":"foreground",
"foregroundings":"foregrounding",
"forehands":"forehand",
"foreheads":"forehead",
"foreigners":"foreigner",
"foreignnesses":"foreignness",
"forejudged":"forejudge",
"forejudging":"forejudge",
"foreknew":"foreknow",
"foreknowing":"foreknow",
"foreknown":"foreknow",
"foreknows":"foreknow",
"foreknowledges":"foreknowledge",
"foreladies":"forelady",
"forelands":"foreland",
"forelocks":"forelock",
"foremen":"foreman",
"foremilks":"foremilk",
"forenames":"forename",
"forenoons":"forenoon",
"foreordained":"foreordain",
"foreordaining":"foreordain",
"foreordains":"foreordain",
"foreordinations":"foreordination",
"foreparts":"forepart",
"foreplays":"foreplay",
"forereached":"forereach",
"forereaching":"forereach",
"foreran":"forerun",
"forerunning":"forerun",
"foreruns":"forerun",
"forerunners":"forerunner",
"foresaw":"foresee",
"foreseeing":"foresee",
"foreseen":"foresee",
"foresees":"foresee",
"foreshadowed":"foreshadow",
"foreshadowing":"foreshadow",
"foreshadows":"foreshadow",
"foreshadowings":"foreshadowing",
"foreshortened":"foreshorten",
"foreshortening":"foreshorten",
"foreshortens":"foreshorten",
"foreshowed":"foreshow",
"foreshowing":"foreshow",
"foreshown":"foreshow",
"foreshows":"foreshow",
"foresights":"foresight",
"foresightednesses":"foresightedness",
"foresightfulnesses":"foresightfulness",
"foreskins":"foreskin",
"forespeaking":"forespeak",
"forespeaks":"forespeak",
"forespoke":"forespeak",
"forespoken":"forespeak",
"forested":"forest",
"foresting":"forest",
"forests":"forest",
"forestages":"forestage",
"forestalled":"forestall",
"forestalling":"forestall",
"forestalls":"forestall",
"forestallings":"forestalling",
"foresters":"forester",
"foretasted":"foretaste",
"foretasting":"foretaste",
"foretelling":"foretell",
"foretells":"foretell",
"foretold":"foretell",
"foretellings":"foretelling",
"forethoughts":"forethought",
"foretokened":"foretoken",
"foretokening":"foretoken",
"foreteeth":"foretooth",
"foretops":"foretop",
"forevers":"forever",
"forewarned":"forewarn",
"forewarning":"forewarn",
"forewarnings":"forewarning",
"forewomen":"forewoman",
"forewords":"foreword",
"forfeited":"forfeit",
"forfeiting":"forfeit",
"forfeits":"forfeit",
"forfeiters":"forfeiter",
"forfeitures":"forfeiture",
"forfended":"forfend",
"forfending":"forfend",
"forficulas":"forficula",
"forficulidaes":"forficulidae",
"forgathered":"forgather",
"forgathering":"forgather",
"forgathers":"forgather",
"forged":"forge",
"forges":"forge",
"forging":"forge",
"forgers":"forger",
"forgeries":"forgery",
"forgets":"forget",
"forgetting":"forget",
"forgot":"forget",
"forgotten":"forget",
"forget-me-nots":"forget-me-not",
"forgave":"forgive",
"forgiven":"forgive",
"forgives":"forgive",
"forgiving":"forgive",
"forgivenesses":"forgiveness",
"forgivingnesses":"forgivingness",
"forgoes":"forgo",
"forgoing":"forgo",
"forgone":"forgo",
"forwent":"forgo",
"forgoings":"forgoing",
"forked":"fork",
"forking":"fork",
"forks":"fork",
"forkfuls":"forkful",
"forksful":"forkful",
"forkings":"forking",
"forkier":"forky",
"forkiest":"forky",
"forlornnesses":"forlornness",
"formed":"form",
"forming":"form",
"forms":"form",
"formaldehydes":"formaldehyde",
"formalins":"formalin",
"formalisations":"formalisation",
"formalitieses":"formalities",
"formalities":"formality",
"formalizations":"formalization",
"formalized":"formalize",
"formalizes":"formalize",
"formalizing":"formalize",
"formalnesses":"formalness",
"formalwears":"formalwear",
"formats":"format",
"formations":"formation",
"formattings":"formatting",
"formicas":"formica",
"formicariidaes":"formicariidae",
"formicaria":"formicarium",
"formicariuses":"formicarius",
"formicaries":"formicary",
"formicidaes":"formicidae",
"formidabilities":"formidability",
"formols":"formol",
"formosas":"formosa",
"formulae":"formula",
"formulas":"formula",
"formularisings":"formularising",
"formularized":"formularize",
"formularizes":"formularize",
"formularizing":"formularize",
"formularizings":"formularizing",
"formularies":"formulary",
"formulated":"formulate",
"formulates":"formulate",
"formulating":"formulate",
"formulations":"formulation",
"formulized":"formulize",
"formulizing":"formulize",
"fornicated":"fornicate",
"fornicating":"fornicate",
"fornications":"fornication",
"fornicators":"fornicator",
"fornicatresses":"fornicatress",
"fornices":"fornix",
"forsaken":"forsake",
"forsakes":"forsake",
"forsaking":"forsake",
"forsook":"forsake",
"forsakings":"forsaking",
"forspeaking":"forspeak",
"forspeaks":"forspeak",
"forspoke":"forspeak",
"forspoken":"forspeak",
"forswearing":"forswear",
"forswears":"forswear",
"forswore":"forswear",
"forsworn":"forswear",
"forswearings":"forswearing",
"forsythias":"forsythia",
"forted":"fort",
"forting":"fort",
"forts":"fort",
"fort-lamies":"fort-lamy",
"fortazs":"fortaz",
"fortes":"forte",
"forte-pianos":"forte-piano",
"forthcomingnesses":"forthcomingness",
"forthrights":"forthright",
"forthrightnesses":"forthrightness",
"fortieses":"forties",
"fortifications":"fortification",
"fortifiers":"fortifier",
"fortified":"fortify",
"fortifies":"fortify",
"fortifying":"fortify",
"fortissimi":"fortissimo",
"fortissimos":"fortissimo",
"fortnights":"fortnight",
"fortnightlies":"fortnightly",
"fortresses":"fortress",
"fortuities":"fortuity",
"fortuned":"fortune",
"fortunes":"fortune",
"fortuning":"fortune",
"fortunellas":"fortunella",
"forties":"forty",
"forums":"forum",
"forwarded":"forward",
"forwarding":"forward",
"forwards":"forward",
"forwardings":"forwarding",
"forwardnesses":"forwardness",
"fossae":"fossa",
"fossas":"fossa",
"fosses":"fosse",
"fossicked":"fossick",
"fossicking":"fossick",
"fossils":"fossil",
"fossilists":"fossilist",
"fossilized":"fossilize",
"fossilizing":"fossilize",
"fossilologies":"fossilology",
"fostered":"foster",
"fostering":"foster",
"fosters":"foster",
"fosterages":"fosterage",
"fosterings":"fostering",
"fothergillas":"fothergilla",
"fotses":"fots",
"fouled":"foul",
"fouler":"foul",
"foulest":"foul",
"fouling":"foul",
"fouls":"foul",
"foul-ups":"foul-up",
"foulmarts":"foulmart",
"foulnesses":"foulness",
"foumarts":"foumart",
"founded":"found",
"founding":"found",
"founds":"found",
"foundations":"foundation",
"foundered":"founder",
"foundering":"founder",
"founders":"founder",
"founderings":"foundering",
"foundings":"founding",
"foundlings":"foundling",
"foundries":"foundry",
"founts":"fount",
"fountains":"fountain",
"fountainheads":"fountainhead",
"fountainpens":"fountainpen",
"fouquierias":"fouquieria",
"fouquieriaceaes":"fouquieriaceae",
"fours":"four",
"four-flushed":"four-flush",
"four-flushing":"four-flush",
"four-hitters":"four-hitter",
"four-in-hands":"four-in-hand",
"fourpences":"fourpence",
"fourscores":"fourscore",
"foursomes":"foursome",
"foursquares":"foursquare",
"fourteens":"fourteen",
"fourteenths":"fourteenth",
"fourths":"fourth",
"foveae":"fovea",
"foveas":"fovea",
"foveolae":"foveola",
"fowled":"fowl",
"fowling":"fowl",
"fowls":"fowl",
"foxed":"fox",
"foxes":"fox",
"foxing":"fox",
"fox-trotted":"fox-trot",
"fox-trotting":"fox-trot",
"foxberries":"foxberry",
"foxgloves":"foxglove",
"foxholes":"foxhole",
"foxhunts":"foxhunt",
"foxinesses":"foxiness",
"foxtails":"foxtail",
"foxtrots":"foxtrot",
"foxtrotted":"foxtrot",
"foxtrotting":"foxtrot",
"foxier":"foxy",
"foxiest":"foxy",
"foyers":"foyer",
"frs":"fr",
"fracases":"fracas",
"fractioned":"fraction",
"fractioning":"fraction",
"fractions":"fraction",
"fractionalized":"fractionalize",
"fractionalizing":"fractionalize",
"fractionated":"fractionate",
"fractionating":"fractionate",
"fractionations":"fractionation",
"fractiousnesses":"fractiousness",
"fractocumuli":"fractocumulus",
"fractostrati":"fractostratus",
"fractured":"fracture",
"fractures":"fracture",
"fracturing":"fracture",
"fradicins":"fradicin",
"fraena":"fraenum",
"fraenums":"fraenum",
"fragged":"frag",
"fragging":"frag",
"frags":"frag",
"fragarias":"fragaria",
"fragilities":"fragility",
"fragmented":"fragment",
"fragmenting":"fragment",
"fragments":"fragment",
"fragmentations":"fragmentation",
"fragmentized":"fragmentize",
"fragmentizes":"fragmentize",
"fragmentizing":"fragmentize",
"fragrances":"fragrance",
"fragrancies":"fragrancy",
"frailer":"frail",
"frailest":"frail",
"frails":"frail",
"frailnesses":"frailness",
"frailties":"frailty",
"frambesias":"frambesia",
"framboesias":"framboesia",
"framboises":"framboise",
"framed":"frame",
"frames":"frame",
"framing":"frame",
"frame-ups":"frame-up",
"frameworks":"framework",
"framings":"framing",
"francs":"franc",
"franchised":"franchise",
"franchises":"franchise",
"franchising":"franchise",
"Franciscans":"Franciscan",
"franciums":"francium",
"francoas":"francoa",
"francophils":"francophil",
"francophiles":"francophile",
"frangipanis":"frangipani",
"frangipannis":"frangipanni",
"franked":"frank",
"franker":"frank",
"frankest":"frank",
"franking":"frank",
"franks":"frank",
"frankforts":"frankfort",
"frankfurts":"frankfurt",
"frankfurters":"frankfurter",
"frankincenses":"frankincense",
"frankliniellas":"frankliniella",
"franknesses":"frankness",
"frapped":"frap",
"frapping":"frap",
"fraps":"frap",
"frappes":"frappe",
"fraseras":"frasera",
"frats":"frat",
"fratchier":"fratchy",
"fratchiest":"fratchy",
"fraterculas":"fratercula",
"fraternisations":"fraternisation",
"fraternities":"fraternity",
"fraternizations":"fraternization",
"fraternized":"fraternize",
"fraternizing":"fraternize",
"frauen":"frau",
"fraus":"frau",
"frauds":"fraud",
"fraudulences":"fraudulence",
"frauleins":"fraulein",
"fraxinellas":"fraxinella",
"fraxinuses":"fraxinus",
"frayed":"fray",
"fraying":"fray",
"frays":"fray",
"frazzled":"frazzle",
"frazzles":"frazzle",
"frazzling":"frazzle",
"freaked":"freak",
"freaking":"freak",
"freaks":"freak",
"freakishnesses":"freakishness",
"freakier":"freaky",
"freakiest":"freaky",
"freckled":"freckle",
"freckles":"freckle",
"freckling":"freckle",
"frecklier":"freckly",
"freckliest":"freckly",
"fredericksburgs":"fredericksburg",
"freed":"free",
"freeing":"free",
"freer":"free",
"frees":"free",
"freest":"free",
"free-for-alls":"free-for-all",
"free-lanced":"free-lance",
"free-lancing":"free-lance",
"freebooted":"freeboot",
"freebooting":"freeboot",
"freebooters":"freebooter",
"freedmen":"freedman",
"freedoms":"freedom",
"freedwomen":"freedwoman",
"freeings":"freeing",
"freelances":"freelance",
"freeloaders":"freeloader",
"freemen":"freeman",
"freemasons":"freemason",
"freemasonries":"freemasonry",
"freesias":"freesia",
"freetails":"freetail",
"freethinkers":"freethinker",
"freethinkings":"freethinking",
"freetowns":"freetown",
"freeways":"freeway",
"freewheeled":"freewheel",
"freewheeling":"freewheel",
"freewheels":"freewheel",
"freewheelers":"freewheeler",
"freewomen":"freewoman",
"freezes":"freeze",
"freezing":"freeze",
"froze":"freeze",
"frozen":"freeze",
"freeze-dried":"freeze-dry",
"freeze-dries":"freeze-dry",
"freeze-drying":"freeze-dry",
"freezers":"freezer",
"freezings":"freezing",
"fregatas":"fregata",
"fregatidaes":"fregatidae",
"freighted":"freight",
"freighting":"freight",
"freights":"freight",
"freightages":"freightage",
"freighters":"freighter",
"fremontias":"fremontia",
"fremontodendrons":"fremontodendron",
"frenches":"french",
"french-fried":"french-fry",
"french-fries":"french-fry",
"french-frying":"french-fry",
"french-kissed":"french-kiss",
"french-kissing":"french-kiss",
"Frenchified":"Frenchify",
"Frenchifies":"Frenchify",
"Frenchifying":"Frenchify",
"Frenchmen":"Frenchman",
"Frenchwomen":"Frenchwoman",
"frenchier":"frenchy",
"frenchies":"frenchy",
"frenchiest":"frenchy",
"frenula":"frenulum",
"frena":"frenum",
"frenums":"frenum",
"frenzied":"frenzy",
"frenzies":"frenzy",
"frenzying":"frenzy",
"frequences":"frequence",
"frequencies":"frequency",
"frequented":"frequent",
"frequenting":"frequent",
"frequents":"frequent",
"frequenters":"frequenter",
"frescoes":"fresco",
"frescos":"fresco",
"fresher":"fresh",
"freshest":"fresh",
"freshened":"freshen",
"freshening":"freshen",
"freshens":"freshen",
"freshers":"fresher",
"freshets":"freshet",
"freshmen":"freshman",
"freshnesses":"freshness",
"fressed":"fress",
"fresses":"fress",
"fressing":"fress",
"frets":"fret",
"fretted":"fret",
"fretting":"fret",
"fretfulnesses":"fretfulness",
"fretsaws":"fretsaw",
"frettier":"fretty",
"frettiest":"fretty",
"fretworks":"fretwork",
"freuds":"freud",
"freys":"frey",
"freyas":"freya",
"freyjas":"freyja",
"freyrs":"freyr",
"frgs":"frg",
"fris":"fri",
"friabilities":"friability",
"friars":"friar",
"friaries":"friary",
"fribbled":"fribble",
"fribbling":"fribble",
"fricandeaus":"fricandeau",
"fricandeaux":"fricandeau",
"fricandoes":"fricando",
"fricasseed":"fricassee",
"fricasseeing":"fricassee",
"fricassees":"fricassee",
"fricatives":"fricative",
"frictions":"friction",
"Fridays":"Friday",
"fridges":"fridge",
"friended":"friend",
"friending":"friend",
"friends":"friend",
"friendlier":"friendly",
"friendlies":"friendly",
"friendliest":"friendly",
"friendships":"friendship",
"friers":"frier",
"frieses":"fries",
"friesians":"friesian",
"friezes":"frieze",
"frigged":"frig",
"frigging":"frig",
"frigs":"frig",
"frigates":"frigate",
"friggs":"frigg",
"friggas":"frigga",
"frighted":"fright",
"frighting":"fright",
"frights":"fright",
"frightened":"frighten",
"frightening":"frighten",
"frightens":"frighten",
"frightenings":"frightening",
"frigidities":"frigidity",
"frigories":"frigorie",
"frijoles":"frijol",
"frijols":"frijol",
"frijolillos":"frijolillo",
"frijolitos":"frijolito",
"frills":"frill",
"frillses":"frills",
"fringed":"fringe",
"fringes":"fringe",
"fringing":"fringe",
"fringepods":"fringepod",
"fringillas":"fringilla",
"fringillidaes":"fringillidae",
"fripperies":"frippery",
"frisked":"frisk",
"frisking":"frisk",
"frisks":"frisk",
"friskinesses":"friskiness",
"friskings":"frisking",
"friskier":"frisky",
"friskiest":"frisky",
"frissons":"frisson",
"frits":"frit",
"fritted":"frit",
"fritting":"frit",
"fritillarias":"fritillaria",
"fritillaries":"fritillary",
"fritts":"fritt",
"frittered":"fritter",
"frittering":"fritter",
"fritters":"fritter",
"frivoled":"frivol",
"frivoling":"frivol",
"frivolled":"frivol",
"frivolling":"frivol",
"frivols":"frivol",
"frivolities":"frivolity",
"frivolousnesses":"frivolousness",
"frizzed":"frizz",
"frizzing":"frizz",
"frizzs":"frizz",
"frizzled":"frizzle",
"frizzles":"frizzle",
"frizzling":"frizzle",
"frizzlier":"frizzly",
"frizzliest":"frizzly",
"frizzier":"frizzy",
"frizziest":"frizzy",
"frocks":"frock",
"froelichias":"froelichia",
"frogs":"frog",
"frogbits":"frogbit",
"frogeyes":"frogeye",
"frogfishes":"frogfish",
"froggies":"froggy",
"frogmen":"frogman",
"frogses":"frogs",
"frolicked":"frolic",
"frolicking":"frolic",
"frolics":"frolic",
"frolicsomenesses":"frolicsomeness",
"frontes":"frons",
"fronted":"front",
"fronting":"front",
"fronts":"front",
"front-runners":"front-runner",
"frontages":"frontage",
"frontals":"frontal",
"frontiers":"frontier",
"frontiersmen":"frontiersman",
"frontlets":"frontlet",
"frontstalls":"frontstall",
"frosted":"frost",
"frosting":"frost",
"frosts":"frost",
"frostbit":"frostbite",
"frostbites":"frostbite",
"frostbiting":"frostbite",
"frostbitten":"frostbite",
"frostinesses":"frostiness",
"frostings":"frosting",
"frostweeds":"frostweed",
"frostworts":"frostwort",
"frostier":"frosty",
"frostiest":"frosty",
"frothed":"froth",
"frothing":"froth",
"froths":"froth",
"frothinesses":"frothiness",
"frothier":"frothy",
"frothiest":"frothy",
"frouzier":"frouzy",
"frouziest":"frouzy",
"frowned":"frown",
"frowning":"frown",
"frowns":"frown",
"frowstier":"frowsty",
"frowstiest":"frowsty",
"frowsier":"frowsy",
"frowsiest":"frowsy",
"frowzier":"frowzy",
"frowziest":"frowzy",
"fructified":"fructify",
"fructifies":"fructify",
"fructifying":"fructify",
"fructoses":"fructose",
"frugalities":"frugality",
"frugalnesses":"frugalness",
"fruited":"fruit",
"fruiting":"fruit",
"fruits":"fruit",
"fruitcakes":"fruitcake",
"fruitfulnesses":"fruitfulness",
"fruitions":"fruition",
"fruitlessnesses":"fruitlessness",
"fruitier":"fruity",
"fruitiest":"fruity",
"frumps":"frump",
"frumpier":"frumpy",
"frumpiest":"frumpy",
"frunzes":"frunze",
"frustrated":"frustrate",
"frustrates":"frustrate",
"frustrating":"frustrate",
"frustratings":"frustrating",
"frustrations":"frustration",
"frusta":"frustum",
"frustums":"frustum",
"fried":"fry",
"fries":"fry",
"frying":"fry",
"fryers":"fryer",
"fryings":"frying",
"frypans":"frypan",
"fsbs":"fsb",
"fshes":"fsh",
"fts":"ft",
"ft-ls":"ft-l",
"fthms":"fthm",
"ftps":"ftp",
"fubsier":"fubsy",
"fubsiest":"fubsy",
"fucaceaes":"fucaceae",
"fucaleses":"fucales",
"fuchsias":"fuchsia",
"fucked":"fuck",
"fucking":"fuck",
"fucks":"fuck",
"fuckheads":"fuckhead",
"fuckings":"fucking",
"fuckups":"fuckup",
"fucoids":"fucoid",
"fuci":"fucus",
"fucuses":"fucus",
"fuddled":"fuddle",
"fuddles":"fuddle",
"fuddling":"fuddle",
"fuddy-duddies":"fuddy-duddy",
"fudged":"fudge",
"fudges":"fudge",
"fudging":"fudge",
"fueled":"fuel",
"fueling":"fuel",
"fuelled":"fuel",
"fuelling":"fuel",
"fuels":"fuel",
"fuelings":"fueling",
"fugged":"fug",
"fugging":"fug",
"fugaciousnesses":"fugaciousness",
"fugacities":"fugacity",
"fugios":"fugio",
"fugitives":"fugitive",
"fugled":"fugle",
"fugling":"fugle",
"fuglemen":"fugleman",
"fugus":"fugu",
"fujis":"fuji",
"fuji-sans":"fuji-san",
"fujiyamas":"fujiyama",
"fukiens":"fukien",
"fukkianeses":"fukkianese",
"fulas":"fula",
"fulahs":"fulah",
"fulanis":"fulani",
"fulcra":"fulcrum",
"fulcrums":"fulcrum",
"fulfilled":"fulfil",
"fulfilling":"fulfil",
"fulfils":"fulfil",
"fulfills":"fulfill",
"fulfillments":"fulfillment",
"fulfilments":"fulfilment",
"fulgoridaes":"fulgoridae",
"fulgurated":"fulgurate",
"fulgurating":"fulgurate",
"fulicas":"fulica",
"fulled":"full",
"fuller":"full",
"fullest":"full",
"fulling":"full",
"full-of-the-moons":"full-of-the-moon",
"fullnesses":"fullness",
"fulmars":"fulmar",
"fulmaruses":"fulmarus",
"fulminated":"fulminate",
"fulminates":"fulminate",
"fulminating":"fulminate",
"fulminations":"fulmination",
"fulsomenesses":"fulsomeness",
"fultons":"fulton",
"fumarias":"fumaria",
"fumariaceaes":"fumariaceae",
"fumatoria":"fumatorium",
"fumatoriums":"fumatorium",
"fumatories":"fumatory",
"fumbled":"fumble",
"fumbles":"fumble",
"fumbling":"fumble",
"fumblers":"fumbler",
"fumed":"fume",
"fumes":"fume",
"fuming":"fume",
"fumeroots":"fumeroot",
"fumeses":"fumes",
"fumeworts":"fumewort",
"fumigated":"fumigate",
"fumigates":"fumigate",
"fumigating":"fumigate",
"fumitories":"fumitory",
"fumier":"fumy",
"fumiest":"fumy",
"funned":"fun",
"funner":"fun",
"funnest":"fun",
"funning":"fun",
"funs":"fun",
"functioned":"function",
"functioning":"function",
"functions":"function",
"functionaries":"functionary",
"functionings":"functioning",
"funded":"fund",
"funding":"fund",
"funds":"fund",
"fundaments":"fundament",
"fundamentals":"fundamental",
"fundamentalses":"fundamentals",
"fundings":"funding",
"fundses":"funds",
"funduluses":"fundulus",
"fundi":"fundus",
"funerals":"funeral",
"funeral-residences":"funeral-residence",
"funfairs":"funfair",
"fungis":"fungi",
"fungias":"fungia",
"fungoes":"fungo",
"fungi":"fungus",
"funguses":"fungus",
"funicles":"funicle",
"funiculars":"funicular",
"funiculuses":"funiculus",
"funked":"funk",
"funking":"funk",
"funks":"funk",
"funkas":"funka",
"funkaceaes":"funkaceae",
"funkier":"funky",
"funkiest":"funky",
"funneled":"funnel",
"funneling":"funnel",
"funnelled":"funnel",
"funnelling":"funnel",
"funnels":"funnel",
"funninesses":"funniness",
"funnier":"funny",
"funnies":"funny",
"funniest":"funny",
"funnymen":"funnyman",
"furred":"fur",
"furring":"fur",
"furs":"fur",
"furans":"furan",
"furanes":"furane",
"furbelowed":"furbelow",
"furbelowing":"furbelow",
"furbelows":"furbelow",
"furbished":"furbish",
"furbishes":"furbish",
"furbishing":"furbish",
"furcated":"furcate",
"furcating":"furcate",
"furcations":"furcation",
"furculae":"furcula",
"furcula":"furculum",
"furfures":"furfur",
"furfurals":"furfural",
"furfuraldehydes":"furfuraldehyde",
"furfurans":"furfuran",
"furieses":"furies",
"furiousnesses":"furiousness",
"furled":"furl",
"furling":"furl",
"furls":"furl",
"furlongs":"furlong",
"furloughed":"furlough",
"furloughing":"furlough",
"furloughs":"furlough",
"furnaces":"furnace",
"furnariidaes":"furnariidae",
"furnariuses":"furnarius",
"furnished":"furnish",
"furnishes":"furnish",
"furnishing":"furnish",
"furnishingses":"furnishings",
"furnitures":"furniture",
"furors":"furor",
"furores":"furore",
"furriers":"furrier",
"furrieries":"furriery",
"furrings":"furring",
"furrowed":"furrow",
"furrowing":"furrow",
"furrows":"furrow",
"furrier":"furry",
"furriest":"furry",
"furthered":"further",
"furthering":"further",
"furthers":"further",
"furtherances":"furtherance",
"furtivenesses":"furtiveness",
"furuncles":"furuncle",
"furies":"fury",
"furzes":"furze",
"fusains":"fusain",
"fusanuses":"fusanus",
"fuscoboletinuses":"fuscoboletinus",
"fused":"fuse",
"fuses":"fuse",
"fusing":"fuse",
"fusees":"fusee",
"fusilladed":"fusillade",
"fusillades":"fusillade",
"fusillading":"fusillade",
"fusions":"fusion",
"fusionists":"fusionist",
"fussed":"fuss",
"fusses":"fuss",
"fussing":"fuss",
"fuss-budgets":"fuss-budget",
"fussinesses":"fussiness",
"fusspots":"fusspot",
"fussier":"fussy",
"fussiest":"fussy",
"fustians":"fustian",
"fustigated":"fustigate",
"fustigating":"fustigate",
"fustier":"fusty",
"fustiest":"fusty",
"futilities":"futility",
"futures":"future",
"futurists":"futurist",
"futurities":"futurity",
"fuzes":"fuze",
"fuzees":"fuzee",
"fuzzed":"fuzz",
"fuzzes":"fuzz",
"fuzzing":"fuzz",
"fuzzs":"fuzz",
"fuzzinesses":"fuzziness",
"fuzzier":"fuzzy",
"fuzziest":"fuzzy",
"fuzzy-wuzzies":"fuzzy-wuzzy",
"gs":"g",
"g-jos":"g-jo",
"g-men":"g-man",
"g-strings":"g-string",
"gabbed":"gab",
"gabbing":"gab",
"gabs":"gab",
"gabas":"gaba",
"gabardines":"gabardine",
"gabbled":"gabble",
"gabbles":"gabble",
"gabbling":"gabble",
"gabbros":"gabbro",
"gabbier":"gabby",
"gabbiest":"gabby",
"gaberdines":"gaberdine",
"gabfests":"gabfest",
"gables":"gable",
"gabons":"gabon",
"gaborones":"gaborone",
"gabuns":"gabun",
"gabies":"gaby",
"gadded":"gad",
"gadding":"gad",
"gads":"gad",
"gadabouts":"gadabout",
"gadflies":"gadfly",
"gadgets":"gadget",
"gadidaes":"gadidae",
"gadiformeses":"gadiformes",
"gadoids":"gadoid",
"gadolinites":"gadolinite",
"gadoliniums":"gadolinium",
"gaduses":"gadus",
"gadwalls":"gadwall",
"gaeas":"gaea",
"gaelics":"gaelic",
"gaffed":"gaff",
"gaffing":"gaff",
"gaffes":"gaffe",
"gaffers":"gaffer",
"gaffsails":"gaffsail",
"gagged":"gag",
"gagging":"gag",
"gags":"gag",
"gaged":"gage",
"gages":"gage",
"gaging":"gage",
"gaggled":"gaggle",
"gaggling":"gaggle",
"gagmen":"gagman",
"gagsters":"gagster",
"gagwriters":"gagwriter",
"gaias":"gaia",
"gaieties":"gaiety",
"gained":"gain",
"gaining":"gain",
"gains":"gain",
"gainers":"gainer",
"gainsaid":"gainsay",
"gainsaying":"gainsay",
"gainsays":"gainsay",
"gainsboroughs":"gainsborough",
"gaits":"gait",
"gaiters":"gaiter",
"gals":"gal",
"galas":"gala",
"galactoses":"galactose",
"galagos":"galago",
"galahads":"galahad",
"galangals":"galangal",
"galapagoses":"galapagos",
"galavanted":"galavant",
"galavanting":"galavant",
"galaxes":"galax",
"galaxies":"galaxy",
"galbanums":"galbanum",
"galbulidaes":"galbulidae",
"gales":"gale",
"galeae":"galea",
"galegas":"galega",
"galeocerdos":"galeocerdo",
"galeopses":"galeopsis",
"galeorhinuses":"galeorhinus",
"galerases":"galeras",
"galeres":"galere",
"galibis":"galibi",
"galileans":"galilean",
"galileos":"galileo",
"galingales":"galingale",
"galiums":"galium",
"galled":"gall",
"galling":"gall",
"galls":"gall",
"gallas":"galla",
"gallanted":"gallant",
"gallanting":"gallant",
"gallants":"gallant",
"gallantries":"gallantry",
"gallberries":"gallberry",
"gallerias":"galleria",
"galleries":"gallery",
"galleys":"galley",
"gallflies":"gallfly",
"gallias":"gallia",
"gallicized":"gallicize",
"gallicizing":"gallicize",
"galliformeses":"galliformes",
"gallimaufries":"gallimaufry",
"gallinas":"gallina",
"gallinaceons":"gallinaceon",
"gallinagos":"gallinago",
"gallinulas":"gallinula",
"gallinules":"gallinule",
"galliralluses":"gallirallus",
"galliums":"gallium",
"gallivanted":"gallivant",
"gallivanting":"gallivant",
"gallivants":"gallivant",
"gallons":"gallon",
"galloped":"gallop",
"galloping":"gallop",
"gallops":"gallop",
"gallouses":"gallous",
"gallowses":"gallows",
"gallowstrees":"gallowstree",
"gallstones":"gallstone",
"galluses":"gallus",
"gallied":"gally",
"gallying":"gally",
"galoped":"galop",
"galoping":"galop",
"galops":"galop",
"galoshes":"galosh",
"galumphed":"galumph",
"galumphing":"galumph",
"galvanisms":"galvanism",
"galvanized":"galvanize",
"galvanizes":"galvanize",
"galvanizing":"galvanize",
"galvanizings":"galvanizing",
"galvos":"galvo",
"gammed":"gam",
"gamming":"gam",
"gams":"gam",
"gambades":"gambade",
"gambadoes":"gambado",
"gambados":"gambado",
"gambelias":"gambelia",
"gambias":"gambia",
"gambits":"gambit",
"gambled":"gamble",
"gambles":"gamble",
"gambling":"gamble",
"gamblers":"gambler",
"gamblings":"gambling",
"gamboges":"gamboge",
"gamboled":"gambol",
"gamboling":"gambol",
"gambolled":"gambol",
"gambolling":"gambol",
"gambols":"gambol",
"gambrels":"gambrel",
"gambusias":"gambusia",
"gamed":"game",
"gamer":"game",
"games":"game",
"gamest":"game",
"gaming":"game",
"gameboards":"gameboard",
"gamecocks":"gamecock",
"gamekeepers":"gamekeeper",
"gamenesses":"gameness",
"games-masters":"games-master",
"games-mistresses":"games-mistress",
"gametangia":"gametangium",
"gamins":"gamin",
"gaminesses":"gaminess",
"gamings":"gaming",
"gammas":"gamma",
"gammadidia":"gammadion",
"gammons":"gammon",
"gammier":"gammy",
"gammiest":"gammy",
"gamps":"gamp",
"gamier":"gamy",
"gamiest":"gamy",
"ganned":"gan",
"ganning":"gan",
"gans":"gan",
"ganapatis":"ganapati",
"gandas":"ganda",
"ganders":"gander",
"gandhis":"gandhi",
"ganesas":"ganesa",
"ganeshes":"ganesh",
"ganeshas":"ganesha",
"ganged":"gang",
"ganging":"gang",
"gangs":"gang",
"gangboards":"gangboard",
"gangdoms":"gangdom",
"gangeses":"ganges",
"ganglands":"gangland",
"gangled":"gangle",
"gangling":"gangle",
"ganglia":"ganglion",
"gangliglia":"ganglion",
"gangliglions":"ganglion",
"ganglions":"ganglion",
"ganglier":"gangly",
"gangliest":"gangly",
"gangplanks":"gangplank",
"gangrened":"gangrene",
"gangrenes":"gangrene",
"gangrening":"gangrene",
"gangsters":"gangster",
"gangways":"gangway",
"ganjas":"ganja",
"ganoids":"ganoid",
"ganoideis":"ganoidei",
"ganoins":"ganoin",
"ganoines":"ganoine",
"gansus":"gansu",
"gantries":"gantry",
"gaoled":"gaol",
"gaoling":"gaol",
"gaols":"gaol",
"gaolbirds":"gaolbird",
"gaolbreaks":"gaolbreak",
"gaolers":"gaoler",
"gapped":"gap",
"gapping":"gap",
"gaps":"gap",
"gaped":"gape",
"gapes":"gape",
"gaping":"gape",
"gars":"gar",
"garaged":"garage",
"garages":"garage",
"garaging":"garage",
"garagemen":"garageman",
"garambullas":"garambulla",
"garands":"garand",
"garbed":"garb",
"garbing":"garb",
"garbs":"garb",
"garbages":"garbage",
"garbagemen":"garbageman",
"garbanzos":"garbanzo",
"garbled":"garble",
"garbles":"garble",
"garbling":"garble",
"garbos":"garbo",
"garboards":"garboard",
"garboils":"garboil",
"garcinias":"garcinia",
"garcons":"garcon",
"gardened":"garden",
"gardening":"garden",
"gardens":"garden",
"gardeners":"gardener",
"gardenias":"gardenia",
"gardenings":"gardening",
"garfields":"garfield",
"garfishes":"garfish",
"garganeys":"garganey",
"gargets":"garget",
"gargled":"gargle",
"gargles":"gargle",
"gargling":"gargle",
"garis":"gari",
"garibaldis":"garibaldi",
"garishnesses":"garishness",
"garlanded":"garland",
"garlanding":"garland",
"garlands":"garland",
"garlics":"garlic",
"garmented":"garment",
"garmenting":"garment",
"garments":"garment",
"garmentmakers":"garmentmaker",
"garmentworkers":"garmentworker",
"garnered":"garner",
"garnering":"garner",
"garners":"garner",
"garnets":"garnet",
"garnished":"garnish",
"garnishes":"garnish",
"garnishing":"garnish",
"garnisheed":"garnishee",
"garnisheeing":"garnishee",
"garnishees":"garnishee",
"garnishments":"garnishment",
"garottes":"garotte",
"garpikes":"garpike",
"garrets":"garret",
"garrisoned":"garrison",
"garrisoning":"garrison",
"garrisons":"garrison",
"garrotes":"garrote",
"garroters":"garroter",
"garrottes":"garrotte",
"garrotters":"garrotter",
"garrulinaes":"garrulinae",
"garrulities":"garrulity",
"garrulousnesses":"garrulousness",
"garruluses":"garrulus",
"garters":"garter",
"gases":"gas",
"gassed":"gas",
"gassing":"gas",
"gasbags":"gasbag",
"gascognes":"gascogne",
"gasconaded":"gasconade",
"gasconades":"gasconade",
"gasconading":"gasconade",
"gasconies":"gascony",
"gashed":"gash",
"gashes":"gash",
"gashing":"gash",
"gashouses":"gashouse",
"gasified":"gasify",
"gasifies":"gasify",
"gasifying":"gasify",
"gasmen":"gasman",
"gasmasks":"gasmask",
"gasolenes":"gasolene",
"gasolines":"gasoline",
"gasometers":"gasometer",
"gasped":"gasp",
"gasping":"gasp",
"gasps":"gasp",
"gassier":"gassy",
"gassiest":"gassy",
"gasted":"gast",
"gasting":"gast",
"gasteromycetes":"gasteromycete",
"gasteromyceteses":"gasteromycetes",
"gasterophilidaes":"gasterophilidae",
"gasterophiluses":"gasterophilus",
"gasteropodas":"gasteropoda",
"gasterosteidaes":"gasterosteidae",
"gasterosteuses":"gasterosteus",
"gastralgias":"gastralgia",
"gastrectomies":"gastrectomy",
"gastroboletuses":"gastroboletus",
"gastrocnemiuses":"gastrocnemius",
"gastrocybes":"gastrocybe",
"gastroenteritises":"gastroenteritis",
"gastroenterostomies":"gastroenterostomy",
"gastrolobiums":"gastrolobium",
"gastromycetes":"gastromycete",
"gastromyceteses":"gastromycetes",
"gastronomes":"gastronome",
"gastrophrynes":"gastrophryne",
"gastropods":"gastropod",
"gastropodas":"gastropoda",
"gastroscopies":"gastroscopy",
"gastrostomies":"gastrostomy",
"gastrotomies":"gastrotomy",
"gastrulae":"gastrula",
"gastrulas":"gastrula",
"gats":"gat",
"gated":"gate",
"gates":"gate",
"gating":"gate",
"gateaux":"gateau",
"gatecrashers":"gatecrasher",
"gatehouses":"gatehouse",
"gatekeepers":"gatekeeper",
"gateways":"gateway",
"gathered":"gather",
"gathering":"gather",
"gathers":"gather",
"gatherers":"gatherer",
"gatherings":"gathering",
"gatts":"gatt",
"gauchenesses":"gaucheness",
"gaucheries":"gaucherie",
"gauchos":"gaucho",
"gauds":"gaud",
"gauderies":"gaudery",
"gaudinesses":"gaudiness",
"gaudier":"gaudy",
"gaudies":"gaudy",
"gaudiest":"gaudy",
"gauffers":"gauffer",
"gauged":"gauge",
"gauges":"gauge",
"gauging":"gauge",
"gauguins":"gauguin",
"gauls":"gaul",
"gaultherias":"gaultheria",
"gaunter":"gaunt",
"gauntest":"gaunt",
"gauntlets":"gauntlet",
"gauntletses":"gauntlets",
"gauntnesses":"gauntness",
"gauntries":"gauntry",
"gaurs":"gaur",
"gausses":"gauss",
"gaussmeters":"gaussmeter",
"gautamas":"gautama",
"gauzes":"gauze",
"gauzier":"gauzy",
"gauziest":"gauzy",
"gavels":"gavel",
"gavias":"gavia",
"gavials":"gavial",
"gavialidaes":"gavialidae",
"gavialises":"gavialis",
"gavidaes":"gavidae",
"gaviiformeses":"gaviiformes",
"gawains":"gawain",
"gawked":"gawk",
"gawking":"gawk",
"gawks":"gawk",
"gawkinesses":"gawkiness",
"gawkier":"gawky",
"gawkiest":"gawky",
"gawped":"gawp",
"gawping":"gawp",
"gawps":"gawp",
"gayer":"gay",
"gayest":"gay",
"gays":"gay",
"gayals":"gayal",
"gayeties":"gayety",
"gayfeathers":"gayfeather",
"gaylussacias":"gaylussacia",
"gaynesses":"gayness",
"gaywingses":"gaywings",
"gazed":"gaze",
"gazes":"gaze",
"gazing":"gaze",
"gazeboes":"gazebo",
"gazebos":"gazebo",
"gazellas":"gazella",
"gazelles":"gazelle",
"gazers":"gazer",
"gazetted":"gazette",
"gazetting":"gazette",
"gbs":"gb",
"gcs":"gc",
"gds":"gd",
"gdansks":"gdansk",
"gdps":"gdp",
"ges":"ge",
"geans":"gean",
"geared":"gear",
"gearing":"gear",
"gears":"gear",
"gearboxes":"gearbox",
"gearings":"gearing",
"gearses":"gears",
"gearshifts":"gearshift",
"gearsticks":"gearstick",
"geartrains":"geartrain",
"geastraceaes":"geastraceae",
"geastrums":"geastrum",
"gebs":"geb",
"geckoes":"gecko",
"geckos":"gecko",
"gees":"gee",
"geeks":"geek",
"geezers":"geezer",
"gegenscheins":"gegenschein",
"gehennas":"gehenna",
"geigers":"geiger",
"geishas":"geisha",
"gekkonidaes":"gekkonidae",
"gelled":"gel",
"gelling":"gel",
"gels":"gel",
"gelatins":"gelatin",
"gelatines":"gelatine",
"gelatinousnesses":"gelatinousness",
"gelded":"geld",
"gelding":"geld",
"gelds":"geld",
"gelt":"geld",
"gelechias":"gelechia",
"gelechiids":"gelechiid",
"gelechiidaes":"gelechiidae",
"gelidities":"gelidity",
"gelignites":"gelignite",
"gellies":"gelly",
"gelsemiums":"gelsemium",
"gelts":"gelt",
"gemmed":"gem",
"gemming":"gem",
"gems":"gem",
"gemeinschaften":"gemeinschaft",
"geminated":"geminate",
"geminating":"geminate",
"Geminis":"Gemini",
"gemmae":"gemma",
"gemmated":"gemmate",
"gemmating":"gemmate",
"gemmier":"gemmy",
"gemmiest":"gemmy",
"gemonils":"gemonil",
"gempylidaes":"gempylidae",
"gempyluses":"gempylus",
"gemsboks":"gemsbok",
"gemsbucks":"gemsbuck",
"gemstones":"gemstone",
"genned-up":"gen-up",
"genning-up":"gen-up",
"gens-up":"gen-up",
"gendarmes":"gendarme",
"gendarmeries":"gendarmerie",
"gendered":"gender",
"gendering":"gender",
"genders":"gender",
"gene-splicings":"gene-splicing",
"genealogies":"genealogy",
"generals":"general",
"generalissimos":"generalissimo",
"generalists":"generalist",
"generalities":"generality",
"generalizations":"generalization",
"generalized":"generalize",
"generalizes":"generalize",
"generalizing":"generalize",
"generated":"generate",
"generates":"generate",
"generating":"generate",
"generations":"generation",
"generators":"generator",
"generatrices":"generatrix",
"generosities":"generosity",
"generousnesses":"generousness",
"geneses":"genesis",
"genesises":"genesis",
"genets":"genet",
"geneticses":"genetics",
"genettas":"genetta",
"genevas":"geneva",
"genevans":"genevan",
"geneves":"geneve",
"genialities":"geniality",
"genii":"genie",
"genips":"genip",
"genipaps":"genipap",
"genistas":"genista",
"genitalias":"genitalia",
"genitalses":"genitals",
"genitives":"genitive",
"geniuses":"genius",
"genoas":"genoa",
"genocides":"genocide",
"genotypes":"genotype",
"genovas":"genova",
"genres":"genre",
"genros":"genro",
"genses":"gens",
"gentes":"gens",
"gents":"gent",
"genteelnesses":"genteelness",
"gentianas":"gentiana",
"gentianaceaes":"gentianaceae",
"gentianaleses":"gentianales",
"gentianellas":"gentianella",
"gentianopses":"gentianopsis",
"Gentiles":"Gentile",
"gentilities":"gentility",
"gentled":"gentle",
"gentler":"gentle",
"gentles":"gentle",
"gentlest":"gentle",
"gentling":"gentle",
"gentlemen":"gentleman",
"gentlemen-at-arms":"gentleman-at-arms",
"gentlemen-farmers":"gentleman-farmer",
"gentlenesses":"gentleness",
"gentlewomen":"gentlewoman",
"gentries":"gentry",
"genua":"genu",
"genus":"genu",
"genuflected":"genuflect",
"genuflecting":"genuflect",
"genuflects":"genuflect",
"genuflections":"genuflection",
"genuflexions":"genuflexion",
"genuinenesses":"genuineness",
"genera":"genus",
"genuses":"genus",
"genus-fenusas":"genus-fenusa",
"genus-megapodiuses":"genus-megapodius",
"genus-milvuses":"genus-milvus",
"genyonemuses":"genyonemus",
"geochelones":"geochelone",
"geococcyxes":"geococcyx",
"geodesics":"geodesic",
"geoffroeas":"geoffroea",
"geoglossaceaes":"geoglossaceae",
"geoglossums":"geoglossum",
"geographicses":"geographics",
"geographies":"geography",
"geologists":"geologist",
"geologized":"geologize",
"geologizing":"geologize",
"geologies":"geology",
"geometers":"geometer",
"geometricians":"geometrician",
"geometrids":"geometrid",
"geometridaes":"geometridae",
"geometrized":"geometrize",
"geometrizing":"geometrize",
"geomorphologies":"geomorphology",
"geomyidaes":"geomyidae",
"geomyses":"geomys",
"geophilidaes":"geophilidae",
"geophilomorphas":"geophilomorpha",
"geophiluses":"geophilus",
"geophysicists":"geophysicist",
"geophysicses":"geophysics",
"georges":"george",
"georgetowns":"georgetown",
"georgias":"georgia",
"geospheres":"geosphere",
"geothlypises":"geothlypis",
"geraniaceaes":"geraniaceae",
"geranialeses":"geraniales",
"geraniums":"geranium",
"gerberas":"gerbera",
"gerbils":"gerbil",
"gerbilles":"gerbille",
"gerbillinaes":"gerbillinae",
"gerbilluses":"gerbillus",
"gereas":"gerea",
"gerenuks":"gerenuk",
"gerfalcons":"gerfalcon",
"geriatricians":"geriatrician",
"geriatricses":"geriatrics",
"germed":"germ",
"germing":"germ",
"germs":"germ",
"germen":"german",
"germanics":"germanic",
"germaniums":"germanium",
"germanized":"germanize",
"germanizing":"germanize",
"germanies":"germany",
"germens":"germen",
"germina":"germen",
"germicides":"germicide",
"germinated":"germinate",
"germinates":"germinate",
"germinating":"germinate",
"germinations":"germination",
"germier":"germy",
"germiest":"germy",
"gerontocracies":"gerontocracy",
"gerontologists":"gerontologist",
"gerontologies":"gerontology",
"gerreidaes":"gerreidae",
"gerreses":"gerres",
"gerrhonotuses":"gerrhonotus",
"gerridaes":"gerridae",
"gerrididaes":"gerrididae",
"gerrises":"gerris",
"gerrymandered":"gerrymander",
"gerrymandering":"gerrymander",
"gerunds":"gerund",
"gesellschaften":"gesellschaft",
"gesneriaceaes":"gesneriaceae",
"gessoes":"gesso",
"gestalten":"gestalt",
"gestalts":"gestalt",
"gestated":"gestate",
"gestates":"gestate",
"gestating":"gestate",
"gestations":"gestation",
"gesticulated":"gesticulate",
"gesticulates":"gesticulate",
"gesticulating":"gesticulate",
"gesticulations":"gesticulation",
"gestured":"gesture",
"gestures":"gesture",
"gesturing":"gesture",
"gets":"get",
"getting":"get",
"got":"get",
"gotten":"get",
"get-up-and-gos":"get-up-and-go",
"getas":"geta",
"getaways":"getaway",
"gettings":"getting",
"gettysburgs":"gettysburg",
"getups":"getup",
"gets_lost":"get_lost",
"getting_lost":"get_lost",
"gotten_lost":"get_lost",
"got_lost":"get_lost",
"gets_started":"get_started",
"getting_started":"get_started",
"got_started":"get_started",
"geums":"geum",
"gewgaws":"gewgaw",
"ghanas":"ghana",
"gharries":"gharri",
"ghastlinesses":"ghastliness",
"ghastlier":"ghastly",
"ghastliest":"ghastly",
"ghattis":"ghatti",
"ghazis":"ghazi",
"ghegs":"gheg",
"ghettoes":"ghetto",
"ghettos":"ghetto",
"ghettoized":"ghettoize",
"ghettoizing":"ghettoize",
"ghillies":"ghillie",
"ghosted":"ghost",
"ghosting":"ghost",
"ghosts":"ghost",
"ghostfishes":"ghostfish",
"ghostlinesses":"ghostliness",
"ghostlier":"ghostly",
"ghostliest":"ghostly",
"ghostwrites":"ghostwrite",
"ghostwriting":"ghostwrite",
"ghostwritten":"ghostwrite",
"ghostwrote":"ghostwrite",
"ghostwriters":"ghostwriter",
"ghouls":"ghoul",
"ghqs":"ghq",
"ghzs":"ghz",
"GIs":"GI",
"giants":"giant",
"giantisms":"giantism",
"gibbed":"gib",
"gibbing":"gib",
"gibs":"gib",
"gibbered":"gibber",
"gibbering":"gibber",
"gibbers":"gibber",
"gibberishes":"gibberish",
"gibbeted":"gibbet",
"gibbeting":"gibbet",
"gibbets":"gibbet",
"gibbons":"gibbon",
"gibbosities":"gibbosity",
"gibbousnesses":"gibbousness",
"gibed":"gibe",
"gibes":"gibe",
"gibing":"gibe",
"giblets":"giblet",
"gibletses":"giblets",
"gibraltars":"gibraltar",
"giddinesses":"giddiness",
"giddied":"giddy",
"giddier":"giddy",
"giddies":"giddy",
"giddiest":"giddy",
"giddying":"giddy",
"gidgees":"gidgee",
"gifted":"gift",
"gifting":"gift",
"gifts":"gift",
"gift-wrapped":"gift-wrap",
"gift-wrapping":"gift-wrap",
"giftwrapped":"giftwrap",
"giftwrapping":"giftwrap",
"giftwraps":"giftwrap",
"gigged":"gig",
"gigging":"gig",
"gigs":"gig",
"gigabytes":"gigabyte",
"gigacycles":"gigacycle",
"gigahertzs":"gigahertz",
"gigantisms":"gigantism",
"gigantomachias":"gigantomachia",
"gigantomachies":"gigantomachy",
"gigartinaceaes":"gigartinaceae",
"giggled":"giggle",
"giggles":"giggle",
"giggling":"giggle",
"gigolos":"gigolo",
"gigots":"gigot",
"gilas":"gila",
"gilberts":"gilbert",
"gilded":"gild",
"gilding":"gild",
"gilds":"gild",
"gilt":"gild",
"gildings":"gilding",
"gildsmen":"gildsman",
"gildswomen":"gildswoman",
"gilled":"gill",
"gilling":"gill",
"gills":"gill",
"gill-over-the-grounds":"gill-over-the-ground",
"gillies":"gillie",
"gillyflowers":"gillyflower",
"gilts":"gilt",
"gimcrackeries":"gimcrackery",
"gimcrackses":"gimcracks",
"gimleted":"gimlet",
"gimleting":"gimlet",
"gimlets":"gimlet",
"gimmicks":"gimmick",
"gimps":"gimp",
"gimpinesses":"gimpiness",
"ginned":"gin",
"ginning":"gin",
"gins":"gin",
"gineps":"ginep",
"gingered":"ginger",
"gingering":"ginger",
"gingers":"ginger",
"gingerroots":"gingerroot",
"gingivae":"gingiva",
"gingivas":"gingiva",
"gingkoes":"gingko",
"ginglymostomas":"ginglymostoma",
"ginglymi":"ginglymus",
"ginglymuses":"ginglymus",
"ginkgoes":"ginkgo",
"ginkgos":"ginkgo",
"ginkgoaceaes":"ginkgoaceae",
"ginkgoaleses":"ginkgoales",
"ginkgophytas":"ginkgophyta",
"ginkgophytinas":"ginkgophytina",
"ginkgopsidas":"ginkgopsida",
"ginmills":"ginmill",
"ginsengs":"ginseng",
"ginzoes":"ginzo",
"gipped":"gip",
"gipping":"gip",
"gips":"gip",
"gippoes":"gippo",
"gippies":"gippy",
"gipsies":"gipsy",
"gipsyworts":"gipsywort",
"giraffas":"giraffa",
"giraffes":"giraffe",
"giraffidaes":"giraffidae",
"girandolas":"girandola",
"girandoles":"girandole",
"girasols":"girasol",
"girded":"gird",
"girding":"gird",
"girds":"gird",
"girt":"gird",
"girders":"girder",
"girdled":"girdle",
"girdles":"girdle",
"girdling":"girdle",
"girls":"girl",
"girlfriends":"girlfriend",
"girlhoods":"girlhood",
"giros":"giro",
"girthed":"girth",
"girthing":"girth",
"girths":"girth",
"gismos":"gismo",
"gists":"gist",
"gave":"give",
"given":"give",
"gives":"give",
"giving":"give",
"give-and-takes":"give-and-take",
"giveaways":"giveaway",
"givens":"given",
"givers":"giver",
"givings":"giving",
"gizas":"giza",
"gizmos":"gizmo",
"gizzards":"gizzard",
"glabellae":"glabella",
"glaceed":"glace",
"glaceing":"glace",
"glaces":"glace",
"glaciated":"glaciate",
"glaciating":"glaciate",
"glaciers":"glacier",
"glacises":"glacis",
"gladded":"glad",
"gladder":"glad",
"gladdest":"glad",
"gladding":"glad",
"glad-handed":"glad-hand",
"glad-handing":"glad-hand",
"gladdened":"gladden",
"gladdening":"gladden",
"gladdens":"gladden",
"gladdons":"gladdon",
"glades":"glade",
"gladfulnesses":"gladfulness",
"gladiators":"gladiator",
"gladiolas":"gladiola",
"gladioli":"gladiolus",
"gladioluses":"gladiolus",
"gladnesses":"gladness",
"gladsomenesses":"gladsomeness",
"gladstones":"gladstone",
"glaired":"glair",
"glairing":"glair",
"glairier":"glairy",
"glairiest":"glairy",
"glamors":"glamor",
"glamorized":"glamorize",
"glamorizes":"glamorize",
"glamorizing":"glamorize",
"glamoured":"glamour",
"glamouring":"glamour",
"glamours":"glamour",
"glanced":"glance",
"glances":"glance",
"glancing":"glance",
"glands":"gland",
"glandes":"glans",
"glared":"glare",
"glares":"glare",
"glaring":"glare",
"glareolas":"glareola",
"glareoles":"glareole",
"glareolidaes":"glareolidae",
"glarier":"glary",
"glariest":"glary",
"glassed":"glass",
"glasses":"glass",
"glassing":"glass",
"glasscutters":"glasscutter",
"glassfuls":"glassful",
"glasshouses":"glasshouse",
"glassmen":"glassman",
"glasswares":"glassware",
"glassworks":"glasswork",
"glassworkers":"glassworker",
"glassworts":"glasswort",
"glassier":"glassy",
"glassiest":"glassy",
"glauciums":"glaucium",
"glaucomyses":"glaucomys",
"glauxes":"glaux",
"glazed":"glaze",
"glazes":"glaze",
"glazing":"glaze",
"glazers":"glazer",
"glaziers":"glazier",
"gleamed":"gleam",
"gleaming":"gleam",
"gleams":"gleam",
"gleamings":"gleaming",
"gleamier":"gleamy",
"gleamiest":"gleamy",
"gleaned":"glean",
"gleaning":"glean",
"gleans":"glean",
"glebae":"gleba",
"glechomas":"glechoma",
"gleditsias":"gleditsia",
"glees":"glee",
"gleefulnesses":"gleefulness",
"gleemen":"gleeman",
"gleeted":"gleet",
"gleeting":"gleet",
"gleets":"gleet",
"gleichenias":"gleichenia",
"gleicheniaceaes":"gleicheniaceae",
"glens":"glen",
"glengarries":"glengarry",
"glenns":"glenn",
"glias":"glia",
"glibber":"glib",
"glibbest":"glib",
"glibnesses":"glibness",
"glided":"glide",
"glides":"glide",
"gliding":"glide",
"gliders":"glider",
"glidings":"gliding",
"glimmered":"glimmer",
"glimmering":"glimmer",
"glimmers":"glimmer",
"glimpsed":"glimpse",
"glimpses":"glimpse",
"glimpsing":"glimpse",
"glinted":"glint",
"glinting":"glint",
"glints":"glint",
"gliomas":"glioma",
"gliomata":"glioma",
"gliridaes":"gliridae",
"glises":"glis",
"glissaded":"glissade",
"glissading":"glissade",
"glissandi":"glissando",
"glissandos":"glissando",
"glistened":"glisten",
"glistening":"glisten",
"glistens":"glisten",
"glistered":"glister",
"glistering":"glister",
"glisters":"glister",
"glitches":"glitch",
"glittered":"glitter",
"glittering":"glitter",
"glitters":"glitter",
"glitzs":"glitz",
"gloamings":"gloaming",
"gloated":"gloat",
"gloating":"gloat",
"gloats":"gloat",
"gloatings":"gloating",
"globs":"glob",
"globalized":"globalize",
"globalizing":"globalize",
"globed":"globe",
"globes":"globe",
"globing":"globe",
"globefishes":"globefish",
"globeflowers":"globeflower",
"globetrots":"globetrot",
"globetrotted":"globetrot",
"globetrotting":"globetrot",
"globetrotters":"globetrotter",
"globicephalas":"globicephala",
"globigerinae":"globigerina",
"globigerinas":"globigerina",
"globigerinidaes":"globigerinidae",
"globosities":"globosity",
"globularnesses":"globularness",
"glochidchidia":"glochidium",
"glockenspiels":"glockenspiel",
"glommed":"glom",
"glomming":"glom",
"gloms":"glom",
"glomeruli":"glomerulus",
"gloomed":"gloom",
"glooming":"gloom",
"glooms":"gloom",
"gloominesses":"gloominess",
"gloomier":"gloomy",
"gloomiest":"gloomy",
"glopped":"glop",
"glopping":"glop",
"glops":"glop",
"glorifications":"glorification",
"glorified":"glorify",
"glorifies":"glorify",
"glorifying":"glorify",
"gloriosas":"gloriosa",
"gloried":"glory",
"glories":"glory",
"glorying":"glory",
"glossed":"gloss",
"glosses":"gloss",
"glossing":"gloss",
"glossae":"glossa",
"glossas":"glossa",
"glossaries":"glossary",
"glossectomies":"glossectomy",
"glossinas":"glossina",
"glossinesses":"glossiness",
"glossinidaes":"glossinidae",
"glossodias":"glossodia",
"glossopsittas":"glossopsitta",
"glossier":"glossy",
"glossies":"glossy",
"glossiest":"glossy",
"glottides":"glottis",
"glottises":"glottis",
"gloved":"glove",
"gloves":"glove",
"gloving":"glove",
"gloveses":"gloves",
"glowed":"glow",
"glowing":"glow",
"glows":"glow",
"glowered":"glower",
"glowering":"glower",
"glowers":"glower",
"glowings":"glowing",
"glozed":"gloze",
"glozing":"gloze",
"gluciniums":"glucinium",
"glued":"glue",
"glues":"glue",
"gluing":"glue",
"gluier":"gluey",
"gluiest":"gluey",
"glueynesses":"glueyness",
"gluinesses":"gluiness",
"glummer":"glum",
"glummest":"glum",
"glumnesses":"glumness",
"gluts":"glut",
"glutted":"glut",
"glutting":"glut",
"glutaei":"glutaeus",
"glutei":"gluteus",
"gluteuses":"gluteus",
"glutinosities":"glutinosity",
"glutinousnesses":"glutinousness",
"gluttons":"glutton",
"gluttonies":"gluttony",
"glyburides":"glyburide",
"glyceraldehydes":"glyceraldehyde",
"glycerias":"glyceria",
"glycerins":"glycerin",
"glycerines":"glycerine",
"glycerites":"glycerite",
"glycerogels":"glycerogel",
"glycerogelatins":"glycerogelatin",
"glycerols":"glycerol",
"glyceroles":"glycerole",
"glycines":"glycine",
"glycogens":"glycogen",
"glycols":"glycol",
"glycyrrhizas":"glycyrrhiza",
"glyoxalines":"glyoxaline",
"glypticses":"glyptics",
"glyptographies":"glyptography",
"gms":"gm",
"gmts":"gmt",
"gnaphaliums":"gnaphalium",
"gnarred":"gnar",
"gnarring":"gnar",
"gnarls":"gnarl",
"gnashed":"gnash",
"gnashing":"gnash",
"gnats":"gnat",
"gnathostomatas":"gnathostomata",
"gnawed":"gnaw",
"gnawing":"gnaw",
"gnawn":"gnaw",
"gnaws":"gnaw",
"gnawers":"gnawer",
"gnawings":"gnawing",
"gnetaceaes":"gnetaceae",
"gnetaleses":"gnetales",
"gnetophytas":"gnetophyta",
"gnetophytinas":"gnetophytina",
"gnetopsidas":"gnetopsida",
"gnetums":"gnetum",
"gnomes":"gnome",
"gnoses":"gnosis",
"gnps":"gnp",
"gnus":"gnu",
"goes":"go",
"going":"go",
"gone":"go",
"gos":"go",
"went":"go",
"go-aheads":"go-ahead",
"go-arounds":"go-around",
"go-betweens":"go-between",
"go-carts":"go-cart",
"go-getters":"go-getter",
"goaded":"goad",
"goading":"goad",
"goads":"goad",
"goadings":"goading",
"goaled":"goal",
"goaling":"goal",
"goals":"goal",
"goalies":"goalie",
"goalkeepers":"goalkeeper",
"goaltenders":"goaltender",
"goats":"goat",
"goatfishes":"goatfish",
"goatherds":"goatherd",
"goatherders":"goatherder",
"goatsbeards":"goatsbeard",
"goatsfeet":"goatsfoot",
"goatsuckers":"goatsucker",
"gobs":"gob",
"gobbled":"gobble",
"gobbles":"gobble",
"gobbling":"gobble",
"gobblers":"gobbler",
"gobis":"gobi",
"gobiesocidaes":"gobiesocidae",
"gobiesoxes":"gobiesox",
"gobiidaes":"gobiidae",
"gobios":"gobio",
"goblets":"goblet",
"goblins":"goblin",
"goboes":"gobo",
"gobos":"gobo",
"gobses":"gobs",
"gobies":"goby",
"gods":"god",
"godchildren":"godchild",
"goddesses":"goddess",
"godfathers":"godfather",
"godheads":"godhead",
"godivas":"godiva",
"godlessnesses":"godlessness",
"godlier":"godly",
"godliest":"godly",
"godmothers":"godmother",
"godsends":"godsend",
"goers":"goer",
"goeteborgs":"goeteborg",
"goethes":"goethe",
"goethites":"goethite",
"goffered":"goffer",
"goffering":"goffer",
"goffers":"goffer",
"goggled":"goggle",
"goggles":"goggle",
"goggling":"goggle",
"goggle-eyes":"goggle-eye",
"goidelics":"goidelic",
"goings":"going",
"going-overs":"going-over",
"goings-over":"going-over",
"goiters":"goiter",
"goitres":"goitre",
"golds":"gold",
"goldbricked":"goldbrick",
"goldbricking":"goldbrick",
"goldbricks":"goldbrick",
"goldbrickings":"goldbricking",
"goldcrests":"goldcrest",
"goldcups":"goldcup",
"goldeneyes":"goldeneye",
"goldenseals":"goldenseal",
"goldeyes":"goldeye",
"goldfieldses":"goldfields",
"goldfinches":"goldfinch",
"goldfishes":"goldfish",
"goldilockses":"goldilocks",
"goldmines":"goldmine",
"goldsmiths":"goldsmith",
"goldthreads":"goldthread",
"goldworkers":"goldworker",
"golems":"golem",
"golfed":"golf",
"golfing":"golf",
"golfs":"golf",
"golfcarts":"golfcart",
"golfclubs":"golfclub",
"golfers":"golfer",
"golgothas":"golgotha",
"Goliaths":"Goliath",
"golliwogs":"golliwog",
"golliwoggs":"golliwogg",
"gollied":"golly",
"gollies":"golly",
"gollying":"golly",
"goloshes":"golosh",
"gombos":"gombo",
"gomorrahs":"gomorrah",
"gomorrhas":"gomorrha",
"gomphoses":"gomphosis",
"gomphotheriidaes":"gomphotheriidae",
"gomphotheriums":"gomphotherium",
"gomphrenas":"gomphrena",
"gomutis":"gomuti",
"gonads":"gonad",
"gonadotropins":"gonadotropin",
"gondolas":"gondola",
"gondoliers":"gondolier",
"gondolieres":"gondoliere",
"gongs":"gong",
"gonidiia":"gonidium",
"goninia":"gonion",
"goniopterises":"goniopteris",
"gonococci":"gonococcus",
"gonococcuses":"gonococcus",
"gonorhynchidaes":"gonorhynchidae",
"gonorhynchuses":"gonorhynchus",
"gonorrheas":"gonorrhea",
"gonorrhoeas":"gonorrhoea",
"goos":"goo",
"goobers":"goober",
"best":"good",
"better":"good",
"goods":"goods",
"good-bies":"good-by",
"good-bys":"good-by",
"good-byes":"good-bye",
"good-for-naughts":"good-for-naught",
"good-for-nothings":"good-for-nothing",
"good-humorednesses":"good-humoredness",
"good-king-henries":"good-king-henry",
"good-neighborlinesses":"good-neighborliness",
"good-neighbourlinesses":"good-neighbourliness",
"good-temperednesses":"good-temperedness",
"goodbies":"goodby",
"goodbyes":"goodbye",
"goodlier":"goodly",
"goodliest":"goodly",
"goodmen":"goodman",
"goodnesses":"goodness",
"goodwives":"goodwife",
"goodwills":"goodwill",
"goodies":"goody",
"goody-goodies":"goody-goody",
"goodyeras":"goodyera",
"gooier":"gooey",
"gooiest":"gooey",
"goofed":"goof",
"goofing":"goof",
"goofs":"goof",
"gooves":"goof",
"goof-offs":"goof-off",
"goofier":"goofy",
"goofiest":"goofy",
"googlies":"googly",
"gooks":"gook",
"goons":"goon",
"gooneys":"gooney",
"goonies":"goonie",
"goosanders":"goosander",
"geese":"goose",
"gooses":"goose",
"goose-stepped":"goose-step",
"goose-stepping":"goose-step",
"goose-steps":"goose-step",
"goose-tansies":"goose-tansy",
"gooseberries":"gooseberry",
"goosefishes":"goosefish",
"goosefleshes":"gooseflesh",
"goosefoots":"goosefoot",
"goosier":"goosy",
"goosiest":"goosy",
"gops":"gop",
"gophers":"gopher",
"gopheruses":"gopherus",
"gopherwoods":"gopherwood",
"gorals":"goral",
"gored":"gore",
"gores":"gore",
"goring":"gore",
"gorged":"gorge",
"gorges":"gorge",
"gorging":"gorge",
"gorgerins":"gorgerin",
"gorgonaceas":"gorgonacea",
"gorgoneineia":"gorgoneion",
"gorgoniaceas":"gorgoniacea",
"gorgonians":"gorgonian",
"gorgonized":"gorgonize",
"gorgonizing":"gorgonize",
"gorgonocephaluses":"gorgonocephalus",
"gorillas":"gorilla",
"gorkis":"gorki",
"gorkiys":"gorkiy",
"gorkies":"gorky",
"gormandized":"gormandize",
"gormandizes":"gormandize",
"gormandizing":"gormandize",
"gorses":"gorse",
"gorier":"gory",
"goriest":"gory",
"gosan-chikus":"gosan-chiku",
"goshawks":"goshawk",
"gosmores":"gosmore",
"gospels":"gospel",
"gospelers":"gospeler",
"gospellers":"gospeller",
"gospelses":"gospels",
"gospopoda":"gospodin",
"gossamers":"gossamer",
"gossiped":"gossip",
"gossiping":"gossip",
"gossips":"gossip",
"gossipers":"gossiper",
"gossipings":"gossiping",
"gossipmongerings":"gossipmongering",
"gossypiums":"gossypium",
"goteborgs":"goteborg",
"goths":"goth",
"gothenburgs":"gothenburg",
"gothics":"gothic",
"gothites":"gothite",
"gotterdammerungs":"gotterdammerung",
"goudas":"gouda",
"gouged":"gouge",
"gouges":"gouge",
"gouging":"gouge",
"gougers":"gouger",
"goujons":"goujon",
"goulashes":"goulash",
"gouramis":"gourami",
"gourds":"gourd",
"gourdes":"gourde",
"gourmands":"gourmand",
"gourmets":"gourmet",
"gouts":"gout",
"governed":"govern",
"governing":"govern",
"governs":"govern",
"governances":"governance",
"governesses":"governess",
"governings":"governing",
"governments":"government",
"governors":"governor",
"governors_general":"governor_general",
"governor_generals":"governor_general",
"gowned":"gown",
"gowning":"gown",
"gowns":"gown",
"gownsmen":"gownsman",
"goyim":"goy",
"goys":"goy",
"goes_deep":"go_deep",
"going_deep":"go_deep",
"gone_deep":"go_deep",
"went_deep":"go_deep",
"gps":"gp",
"grabbed":"grab",
"grabbing":"grab",
"grabs":"grab",
"grabbers":"grabber",
"grabbled":"grabble",
"grabbling":"grabble",
"grabbier":"grabby",
"grabbiest":"grabby",
"graced":"grace",
"graces":"grace",
"gracing":"grace",
"gracelessnesses":"gracelessness",
"gracilariids":"gracilariid",
"gracilariidaes":"gracilariidae",
"gracilities":"gracility",
"gracillariidaes":"gracillariidae",
"graciosos":"gracioso",
"graciousnesses":"graciousness",
"grackles":"grackle",
"graculas":"gracula",
"grads":"grad",
"gradated":"gradate",
"gradating":"gradate",
"gradations":"gradation",
"graded":"grade",
"grades":"grade",
"grading":"grade",
"gradelier":"gradely",
"gradeliest":"gradely",
"gradients":"gradient",
"gradings":"grading",
"gradualities":"graduality",
"gradualnesses":"gradualness",
"graduated":"graduate",
"graduates":"graduate",
"graduating":"graduate",
"graduations":"graduation",
"graduses":"gradus",
"graecophiles":"graecophile",
"grafen":"graf",
"graffitis":"graffiti",
"graffiti":"graffito",
"grafted":"graft",
"grafting":"graft",
"grafts":"graft",
"graftings":"grafting",
"grahams":"graham",
"grails":"grail",
"grained":"grain",
"graining":"grain",
"grains":"grain",
"graininesses":"graininess",
"grainings":"graining",
"grainier":"grainy",
"grainiest":"grainy",
"grams":"gram",
"gramas":"grama",
"graminaceaes":"graminaceae",
"graminaleses":"graminales",
"gramineaes":"gramineae",
"grammas":"gramma",
"grammars":"grammar",
"grammarians":"grammarian",
"grammatolatries":"grammatolatry",
"grammatophyllums":"grammatophyllum",
"grammes":"gramme",
"Grammies":"Grammy",
"Grammys":"Grammy",
"gramophones":"gramophone",
"grampses":"gramps",
"grampuses":"grampus",
"granadillas":"granadilla",
"granadillos":"granadillo",
"granaries":"granary",
"grander":"grand",
"grandest":"grand",
"grands":"grand",
"grandads":"grandad",
"grandaunts":"grandaunt",
"grandchildren":"grandchild",
"granddads":"granddad",
"granddaddies":"granddaddy",
"granddaughters":"granddaughter",
"grandees":"grandee",
"grandeurs":"grandeur",
"grandfathered":"grandfather",
"grandfathering":"grandfather",
"grandfathers":"grandfather",
"grandiloquences":"grandiloquence",
"grandiosities":"grandiosity",
"grandmas":"grandma",
"grandmothers":"grandmother",
"grandnephews":"grandnephew",
"grandnesses":"grandness",
"grandnieces":"grandniece",
"grandpas":"grandpa",
"grandparents":"grandparent",
"grandsons":"grandson",
"grandstanded":"grandstand",
"grandstanding":"grandstand",
"grandstands":"grandstand",
"granduncles":"granduncle",
"granges":"grange",
"grangers":"granger",
"granicuses":"granicus",
"grannies":"granny",
"granted":"grant",
"granting":"grant",
"grants":"grant",
"grants-in-aid":"grant-in-aid",
"granularities":"granularity",
"granulated":"granulate",
"granulates":"granulate",
"granulating":"granulate",
"granulations":"granulation",
"granulocytopenias":"granulocytopenia",
"granulomas":"granuloma",
"granulomata":"granuloma",
"grana":"granum",
"grapes":"grape",
"grapefruits":"grapefruit",
"grapevines":"grapevine",
"graphed":"graph",
"graphing":"graph",
"graphs":"graph",
"graphemes":"grapheme",
"graphicses":"graphics",
"graphites":"graphite",
"graphologists":"graphologist",
"grapnels":"grapnel",
"grappled":"grapple",
"grapples":"grapple",
"grappling":"grapple",
"grapplers":"grappler",
"grapplings":"grappling",
"graptophyllums":"graptophyllum",
"grasped":"grasp",
"grasping":"grasp",
"grasps":"grasp",
"graspings":"grasping",
"grassed":"grass",
"grasses":"grass",
"grassing":"grass",
"grass-of-parnassuses":"grass-of-parnassus",
"grassfinches":"grassfinch",
"grasshoppered":"grasshopper",
"grasshoppering":"grasshopper",
"grasshoppers":"grasshopper",
"grassier":"grassy",
"grassiest":"grassy",
"grated":"grate",
"grates":"grate",
"grating":"grate",
"gratefulnesses":"gratefulness",
"graters":"grater",
"graticules":"graticule",
"gratifications":"gratification",
"gratified":"gratify",
"gratifies":"gratify",
"gratifying":"gratify",
"gratings":"grating",
"gratuities":"gratuity",
"gratulated":"gratulate",
"gratulating":"gratulate",
"gravamina":"gravamen",
"gravavamina":"gravamen",
"graved":"grave",
"graven":"grave",
"graver":"grave",
"graves":"grave",
"gravest":"grave",
"graving":"grave",
"graveled":"gravel",
"graveling":"gravel",
"gravelled":"gravel",
"gravelling":"gravel",
"gravels":"gravel",
"gravelweeds":"gravelweed",
"gravenesses":"graveness",
"graverobbers":"graverobber",
"gravestones":"gravestone",
"graveyards":"graveyard",
"gravidae":"gravida",
"gravidas":"gravida",
"gravidities":"gravidity",
"gravidnesses":"gravidness",
"gravimeters":"gravimeter",
"gravimetries":"gravimetry",
"gravitated":"gravitate",
"gravitating":"gravitate",
"gravitations":"gravitation",
"gravities":"gravity",
"gravures":"gravure",
"gravies":"gravy",
"grayed":"gray",
"grayer":"gray",
"grayest":"gray",
"graying":"gray",
"grays":"gray",
"graybacks":"grayback",
"graybeards":"graybeard",
"grayhens":"grayhen",
"graylags":"graylag",
"graylings":"grayling",
"graynesses":"grayness",
"grazed":"graze",
"grazes":"graze",
"grazing":"graze",
"grazers":"grazer",
"grazings":"grazing",
"greased":"grease",
"greases":"grease",
"greasing":"grease",
"grease-guns":"grease-gun",
"greaseballs":"greaseball",
"greasers":"greaser",
"greasewoods":"greasewood",
"greasinesses":"greasiness",
"greasier":"greasy",
"greasiest":"greasy",
"greater":"great",
"greatest":"great",
"greats":"great",
"great-aunts":"great-aunt",
"great-grandchildren":"great-grandchild",
"great-nephews":"great-nephew",
"great-nieces":"great-niece",
"great-uncles":"great-uncle",
"greatcoats":"greatcoat",
"greatened":"greaten",
"greatening":"greaten",
"greatnesses":"greatness",
"greaves":"greave",
"greaveses":"greaves",
"greed":"gree",
"greeing":"gree",
"grees":"gree",
"greeces":"greece",
"greeds":"greed",
"greedinesses":"greediness",
"greedier":"greedy",
"greediest":"greedy",
"greegrees":"greegree",
"Greeks":"Greek",
"greened":"green",
"greener":"green",
"greenest":"green",
"greening":"green",
"greens":"green",
"green-blindnesses":"green-blindness",
"greenbacks":"greenback",
"greenbelts":"greenbelt",
"greenbottles":"greenbottle",
"greenbriers":"greenbrier",
"greeneries":"greenery",
"greenflies":"greenfly",
"greengages":"greengage",
"greengrocers":"greengrocer",
"greengroceries":"greengrocery",
"greenhoods":"greenhood",
"greenhorns":"greenhorn",
"greenhouses":"greenhouse",
"greenings":"greening",
"greenlands":"greenland",
"greenmarkets":"greenmarket",
"greennesses":"greenness",
"greenockites":"greenockite",
"greenses":"greens",
"greenshanks":"greenshank",
"greensicknesses":"greensickness",
"greenswards":"greensward",
"greenways":"greenway",
"greenweeds":"greenweed",
"greenwings":"greenwing",
"greeted":"greet",
"greeting":"greet",
"greets":"greet",
"greetings":"greeting",
"gregarinidas":"gregarinida",
"gregories":"gregory",
"gremlins":"gremlin",
"grenadiers":"grenadier",
"gres-grises":"gres-gris",
"grewias":"grewia",
"greyed":"grey",
"greyer":"grey",
"greyest":"grey",
"greying":"grey",
"greys":"grey",
"greybeards":"greybeard",
"greyhounds":"greyhound",
"greylags":"greylag",
"greynesses":"greyness",
"gri-gris":"gri-gri",
"griases":"grias",
"grids":"grid",
"griddled":"griddle",
"griddling":"griddle",
"griddlecakes":"griddlecake",
"grided":"gride",
"griding":"gride",
"gridirons":"gridiron",
"griefs":"grief",
"grieves":"grief",
"grievances":"grievance",
"grieved":"grieve",
"grieving":"grieve",
"grievers":"griever",
"griffins":"griffin",
"griffons":"griffon",
"grifted":"grift",
"grifting":"grift",
"grigris":"grigri",
"grikwas":"grikwa",
"grilled":"grill",
"grilling":"grill",
"grills":"grill",
"grilles":"grille",
"grillings":"grilling",
"grillrooms":"grillroom",
"grillworks":"grillwork",
"grilses":"grilse",
"grimmer":"grim",
"grimmest":"grim",
"grimaced":"grimace",
"grimaces":"grimace",
"grimacing":"grimace",
"grimed":"grime",
"grimes":"grime",
"griming":"grime",
"griminesses":"griminess",
"grimms":"grimm",
"grimnesses":"grimness",
"grimier":"grimy",
"grimiest":"grimy",
"grinned":"grin",
"grinning":"grin",
"grins":"grin",
"grinding":"grind",
"grinds":"grind",
"ground":"grind",
"grounds":"grind",
"grindelias":"grindelia",
"grinders":"grinder",
"grinderies":"grindery",
"grindings":"grinding",
"grindles":"grindle",
"grindstones":"grindstone",
"gringos":"gringo",
"grinnings":"grinning",
"gripped":"grip",
"gripping":"grip",
"grips":"grip",
"griped":"gripe",
"gripes":"gripe",
"griping":"gripe",
"grippes":"grippe",
"griquas":"griqua",
"grig-gris":"gris-gris",
"griselinias":"griselinia",
"grislier":"grisly",
"grislies":"grisly",
"grisliest":"grisly",
"grisons":"grison",
"gristles":"gristle",
"gristlier":"gristly",
"gristliest":"gristly",
"grits":"grit",
"gritted":"grit",
"gritting":"grit",
"gritrocks":"gritrock",
"gritses":"grits",
"gritstones":"gritstone",
"grittier":"gritty",
"grittiest":"gritty",
"grivets":"grivet",
"grizzled":"grizzle",
"grizzles":"grizzle",
"grizzling":"grizzle",
"grizzlier":"grizzly",
"grizzlies":"grizzly",
"grizzliest":"grizzly",
"groaned":"groan",
"groaning":"groan",
"groans":"groan",
"groats":"groat",
"groceries":"grocery",
"groenlandias":"groenlandia",
"grogginesses":"grogginess",
"groggier":"groggy",
"groggiest":"groggy",
"groined":"groin",
"groining":"groin",
"groins":"groin",
"grommets":"grommet",
"gromwells":"gromwell",
"groomed":"groom",
"grooming":"groom",
"grooms":"groom",
"groom-to-bes":"groom-to-be",
"groomings":"grooming",
"groomsmen":"groomsman",
"grooved":"groove",
"grooves":"groove",
"grooving":"groove",
"groovings":"grooving",
"groovier":"groovy",
"grooviest":"groovy",
"groped":"grope",
"gropes":"grope",
"groping":"grope",
"gropiuses":"gropius",
"grosbeaks":"grosbeak",
"grossed":"gross",
"grosser":"gross",
"grosses":"gross",
"grossest":"gross",
"grossing":"gross",
"grossbeaks":"grossbeak",
"grossnesses":"grossness",
"grossulariaceaes":"grossulariaceae",
"groszy":"grosz",
"grots":"grot",
"grotesques":"grotesque",
"grotesquenesses":"grotesqueness",
"grotesqueries":"grotesquerie",
"grottoes":"grotto",
"grottos":"grotto",
"grottier":"grotty",
"grottiest":"grotty",
"grouched":"grouch",
"grouches":"grouch",
"grouching":"grouch",
"grouchier":"grouchy",
"grouchiest":"grouchy",
"grounded":"ground",
"grounding":"ground",
"ground-shakers":"ground-shaker",
"groundberries":"groundberry",
"groundbreakings":"groundbreaking",
"groundcovers":"groundcover",
"grounders":"grounder",
"groundfishes":"groundfish",
"groundhogs":"groundhog",
"groundings":"grounding",
"groundnuts":"groundnut",
"groundses":"grounds",
"groundsels":"groundsel",
"groundsheets":"groundsheet",
"groundskeepers":"groundskeeper",
"groundsmen":"groundsman",
"groundworks":"groundwork",
"grouped":"group",
"grouping":"group",
"groups":"group",
"groupers":"grouper",
"groupings":"grouping",
"groused":"grouse",
"grouses":"grouse",
"grousing":"grouse",
"grouseberries":"grouseberry",
"grouted":"grout",
"grouting":"grout",
"groutier":"grouty",
"groutiest":"grouty",
"groves":"grove",
"groveled":"grovel",
"groveling":"grovel",
"grovelled":"grovel",
"grovelling":"grovel",
"grovels":"grovel",
"grovellers":"groveller",
"grew":"grow",
"growing":"grow",
"grown":"grow",
"grows":"grow",
"growers":"grower",
"growings":"growing",
"growled":"growl",
"growling":"growl",
"growls":"growl",
"growlings":"growling",
"grown-ups":"grown-up",
"grownups":"grownup",
"growths":"growth",
"groynes":"groyne",
"grubbed":"grub",
"grubbing":"grub",
"grubs":"grub",
"grubbinesses":"grubbiness",
"grubbier":"grubby",
"grubbies":"grubby",
"grubbiest":"grubby",
"grubstaked":"grubstake",
"grubstaking":"grubstake",
"grudged":"grudge",
"grudges":"grudge",
"grudging":"grudge",
"gruesomenesses":"gruesomeness",
"gruffer":"gruff",
"gruffest":"gruff",
"gruffnesses":"gruffness",
"grugrus":"grugru",
"gruidaes":"gruidae",
"gruiformeses":"gruiformes",
"grumbled":"grumble",
"grumbles":"grumble",
"grumbling":"grumble",
"grumblers":"grumbler",
"grumblings":"grumbling",
"grumped":"grump",
"grumping":"grump",
"grumps":"grump",
"grumpinesses":"grumpiness",
"grumpier":"grumpy",
"grumpiest":"grumpy",
"grundyisms":"grundyism",
"grunted":"grunt",
"grunting":"grunt",
"grunts":"grunt",
"gruses":"grus",
"gryllidaes":"gryllidae",
"gryoplanes":"gryoplane",
"gryphons":"gryphon",
"guacharos":"guacharo",
"guacos":"guaco",
"guadalcanals":"guadalcanal",
"guaiacs":"guaiac",
"guaiacums":"guaiacum",
"guairas":"guaira",
"guamas":"guama",
"guanabanas":"guanabana",
"guanacos":"guanaco",
"guangzhous":"guangzhou",
"guanos":"guano",
"guars":"guar",
"guaranis":"guarani",
"guaranteed":"guarantee",
"guaranteeing":"guarantee",
"guarantees":"guarantee",
"guarantors":"guarantor",
"guarantied":"guaranty",
"guaranties":"guaranty",
"guarantying":"guaranty",
"guarded":"guard",
"guarding":"guard",
"guards":"guard",
"guardhouses":"guardhouse",
"guardians":"guardian",
"guardianships":"guardianship",
"guardings":"guarding",
"guardrails":"guardrail",
"guardsmen":"guardsman",
"guavas":"guava",
"guayules":"guayule",
"gubbinses":"gubbins",
"gucks":"guck",
"gudgeons":"gudgeon",
"gueneveres":"guenevere",
"guenons":"guenon",
"guerdoned":"guerdon",
"guerdoning":"guerdon",
"guerezas":"guereza",
"guerillas":"guerilla",
"guernseys":"guernsey",
"guerrillas":"guerrilla",
"guessed":"guess",
"guesses":"guess",
"guessing":"guess",
"guessings":"guessing",
"guesstimated":"guesstimate",
"guesstimates":"guesstimate",
"guesstimating":"guesstimate",
"guessworks":"guesswork",
"guested":"guest",
"guesting":"guest",
"guests":"guest",
"guesthouses":"guesthouse",
"guestimates":"guestimate",
"guevinas":"guevina",
"guffs":"guff",
"guffawed":"guffaw",
"guffawing":"guffaw",
"guffaws":"guffaw",
"guggled":"guggle",
"guggles":"guggle",
"guggling":"guggle",
"guis":"gui",
"guibs":"guib",
"guidances":"guidance",
"guided":"guide",
"guides":"guide",
"guiding":"guide",
"guidebooks":"guidebook",
"guidelines":"guideline",
"guideposts":"guidepost",
"guidings":"guiding",
"guilds":"guild",
"guilder":"guilde",
"guilders":"guilde",
"guildsmen":"guildsman",
"guiles":"guile",
"guillotined":"guillotine",
"guillotines":"guillotine",
"guillotining":"guillotine",
"guilts":"guilt",
"guiltinesses":"guiltiness",
"guiltlessnesses":"guiltlessness",
"guiltier":"guilty",
"guiltiest":"guilty",
"guine-bissaus":"guine-bissau",
"guineas":"guinea",
"guinea-bissaus":"guinea-bissau",
"guineveres":"guinevere",
"guipures":"guipure",
"guises":"guise",
"guitars":"guitar",
"guitarfishes":"guitarfish",
"guitarists":"guitarist",
"gujarats":"gujarat",
"gujaratis":"gujarati",
"gujerats":"gujerat",
"gujeratis":"gujerati",
"gulas":"gula",
"gulches":"gulch",
"guldens":"gulden",
"gulfed":"gulf",
"gulfing":"gulf",
"gulfs":"gulf",
"gulfweeds":"gulfweed",
"gulled":"gull",
"gulling":"gull",
"gulls":"gull",
"gullahs":"gullah",
"gullets":"gullet",
"gullibilities":"gullibility",
"gullied":"gully",
"gullies":"gully",
"gullying":"gully",
"gulos":"gulo",
"gulped":"gulp",
"gulping":"gulp",
"gulps":"gulp",
"gulpings":"gulping",
"gulyases":"gulyas",
"gummed":"gum",
"gumming":"gum",
"gums":"gum",
"gumbos":"gumbo",
"gumbo-limbos":"gumbo-limbo",
"gummas":"gumma",
"gummata":"gumma",
"gumminesses":"gumminess",
"gummings":"gumming",
"gummoses":"gummosis",
"gummier":"gummy",
"gummiest":"gummy",
"gumptions":"gumption",
"gumshields":"gumshield",
"gumshoed":"gumshoe",
"gumshoeing":"gumshoe",
"gumshoes":"gumshoe",
"gumweeds":"gumweed",
"gumwoods":"gumwood",
"gunned":"gun",
"gunning":"gun",
"guns":"gun",
"gunboats":"gunboat",
"gunfights":"gunfight",
"gunfires":"gunfire",
"gunks":"gunk",
"gunlocks":"gunlock",
"gunmen":"gunman",
"gunnels":"gunnel",
"gunners":"gunner",
"gunnies":"gunny",
"gunnysacks":"gunnysack",
"gunplays":"gunplay",
"gunpoints":"gunpoint",
"gunpowders":"gunpowder",
"gunrunners":"gunrunner",
"gunshots":"gunshot",
"gunslingers":"gunslinger",
"gunstocks":"gunstock",
"gunwales":"gunwale",
"guppies":"guppy",
"gurs":"gur",
"gurgled":"gurgle",
"gurgles":"gurgle",
"gurgling":"gurgle",
"Gurkhas":"Gurkha",
"gurnard":"gurnar",
"gurnards":"gurnard",
"gurnets":"gurnet",
"gurus":"guru",
"gushed":"gush",
"gushes":"gush",
"gushing":"gush",
"gushers":"gusher",
"gushier":"gushy",
"gushiest":"gushy",
"gussets":"gusset",
"gussied":"gussy",
"gussying":"gussy",
"gusted":"gust",
"gusting":"gust",
"gusts":"gust",
"gustations":"gustation",
"gustoes":"gusto",
"gustier":"gusty",
"gustiest":"gusty",
"guts":"gut",
"gutted":"gut",
"gutting":"gut",
"gutierrezias":"gutierrezia",
"gutses":"guts",
"gutsinesses":"gutsiness",
"gutsier":"gutsy",
"gutsiest":"gutsy",
"guttae":"gutta",
"guttered":"gutter",
"guttering":"gutter",
"gutters":"gutter",
"guttersnipes":"guttersnipe",
"guttiferaes":"guttiferae",
"guttiferaleses":"guttiferales",
"gutturals":"guttural",
"gutturalized":"gutturalize",
"gutturalizing":"gutturalize",
"guttier":"gutty",
"gutties":"gutty",
"guttiest":"gutty",
"guyed":"guy",
"guying":"guy",
"guys":"guy",
"guyanas":"guyana",
"guzzled":"guzzle",
"guzzling":"guzzle",
"guzzlings":"guzzling",
"gyms":"gym",
"gymkhanas":"gymkhana",
"gymnadenias":"gymnadenia",
"gymnadeniopses":"gymnadeniopsis",
"gymnasia":"gymnasium",
"gymnasiums":"gymnasium",
"gymnelises":"gymnelis",
"gymnocalyciums":"gymnocalycium",
"gymnocarpiums":"gymnocarpium",
"gymnocladuses":"gymnocladus",
"gymnogypses":"gymnogyps",
"gymnomycotas":"gymnomycota",
"gymnophionas":"gymnophiona",
"gymnopiluses":"gymnopilus",
"gymnorhinas":"gymnorhina",
"gymnospermaes":"gymnospermae",
"gymnospermophytas":"gymnospermophyta",
"gymnosporangiums":"gymnosporangium",
"gymnuras":"gymnura",
"gynaecea":"gynaeceum",
"gynaecia":"gynaecium",
"gynaecocracies":"gynaecocracy",
"gynaecologists":"gynaecologist",
"gynaecologies":"gynaecology",
"gynaeolatries":"gynaeolatry",
"gynandromorphs":"gynandromorph",
"gynarchies":"gynarchy",
"gynecea":"gynecium",
"gynecia":"gynecium",
"gynecocracies":"gynecocracy",
"gynecologists":"gynecologist",
"gynecologies":"gynecology",
"gyneolatries":"gyneolatry",
"gynoecia":"gynoecium",
"gynoeciums":"gynoecium",
"gynuras":"gynura",
"gypped":"gyp",
"gypping":"gyp",
"gyps":"gyp",
"gypaetuses":"gypaetus",
"gypses":"gyps",
"gypsophilas":"gypsophila",
"gypsies":"gypsy",
"gypsyweeds":"gypsyweed",
"gypsyworts":"gypsywort",
"gyrated":"gyrate",
"gyrates":"gyrate",
"gyrating":"gyrate",
"gyrations":"gyration",
"gyres":"gyre",
"gyrfalcons":"gyrfalcon",
"gyrinidaes":"gyrinidae",
"gyros":"gyro",
"gyroscopes":"gyroscope",
"gyri":"gyrus",
"gyruses":"gyrus",
"gyved":"gyve",
"gyving":"gyve",
"hs":"h",
"h-bombs":"h-bomb",
"h2os":"h2o",
"has":"have",
"ha'pennies":"ha'penny",
"ha-has":"ha-ha",
"haastias":"haastia",
"habaneras":"habanera",
"habaneros":"habanero",
"habenarias":"habenaria",
"haberdashers":"haberdasher",
"haberdasheries":"haberdashery",
"habiliments":"habiliment",
"habilitated":"habilitate",
"habilitates":"habilitate",
"habilitating":"habilitate",
"habits":"habit",
"habitants":"habitant",
"habitats":"habitat",
"habitations":"habitation",
"habituated":"habituate",
"habituates":"habituate",
"habituating":"habituate",
"habitues":"habitue",
"habsburgs":"habsburg",
"haceks":"hacek",
"hachures":"hachure",
"haciendas":"hacienda",
"hacked":"hack",
"hacking":"hack",
"hacks":"hack",
"hackamores":"hackamore",
"hackberries":"hackberry",
"hackbuts":"hackbut",
"hackdrivers":"hackdriver",
"hackees":"hackee",
"hackelias":"hackelia",
"hackers":"hacker",
"hackled":"hackle",
"hackles":"hackle",
"hackling":"hackle",
"hackleses":"hackles",
"hackmen":"hackman",
"hackmatacks":"hackmatack",
"hackneyed":"hackney",
"hackneying":"hackney",
"hackneys":"hackney",
"hacksaws":"hacksaw",
"haddocks":"haddock",
"hadeses":"hades",
"hadjs":"hadj",
"hadjis":"hadji",
"hadrosaurs":"hadrosaur",
"hadrosauridaes":"hadrosauridae",
"hadrosauruses":"hadrosaurus",
"haecceities":"haecceity",
"haems":"haem",
"haemangiomas":"haemangioma",
"haemanthuses":"haemanthus",
"haematites":"haematite",
"haematobias":"haematobia",
"haematologists":"haematologist",
"haematologies":"haematology",
"haematolyses":"haematolysis",
"haematomas":"haematoma",
"haematopodidaes":"haematopodidae",
"haematopuses":"haematopus",
"haematoxylons":"haematoxylon",
"haematoxylums":"haematoxylum",
"haematozozoa":"haematozoon",
"haemodialyses":"haemodialysis",
"haemodoraceaes":"haemodoraceae",
"haemodorums":"haemodorum",
"haemoglobins":"haemoglobin",
"haemoglobinopathies":"haemoglobinopathy",
"haemolyses":"haemolysis",
"haemophiles":"haemophile",
"haemophilias":"haemophilia",
"haemophiliacs":"haemophiliac",
"haemopises":"haemopis",
"haemoproteidaes":"haemoproteidae",
"haemoproteuses":"haemoproteus",
"haemoptyses":"haemoptysis",
"haemorrhages":"haemorrhage",
"haemorrhoidectomies":"haemorrhoidectomy",
"haemosporidias":"haemosporidia",
"haemostats":"haemostat",
"haemulidaes":"haemulidae",
"haemulons":"haemulon",
"haeredes":"haeres",
"hafniums":"hafnium",
"hafted":"haft",
"hafting":"haft",
"hafts":"haft",
"haftarahs":"haftarah",
"haftaroth":"haftarah",
"hags":"hag",
"hagbuts":"hagbut",
"hagfishes":"hagfish",
"haggadas":"haggada",
"haggadoth":"haggada",
"haggadahs":"haggadah",
"haggards":"haggard",
"haggled":"haggle",
"haggles":"haggle",
"haggling":"haggle",
"hagglings":"haggling",
"hagiarchies":"hagiarchy",
"hagiocracies":"hagiocracy",
"hagiographas":"hagiographa",
"hagiographies":"hagiography",
"hagiolatries":"hagiolatry",
"hagiologies":"hagiology",
"hahniums":"hahnium",
"haidas":"haida",
"hailed":"hail",
"hailing":"hail",
"hails":"hail",
"hailstones":"hailstone",
"hairs":"hair",
"hairballs":"hairball",
"hairbreadths":"hairbreadth",
"haircloths":"haircloth",
"hairdos":"hairdo",
"hairdressers":"hairdresser",
"hairdressings":"hairdressing",
"hairlessnesses":"hairlessness",
"hairpieces":"hairpiece",
"hairsplittings":"hairsplitting",
"hairstreaks":"hairstreak",
"hairstylists":"hairstylist",
"hairtails":"hairtail",
"hairtonics":"hairtonic",
"hairier":"hairy",
"hairiest":"hairy",
"haitis":"haiti",
"hajs":"haj",
"hajis":"haji",
"hajjs":"hajj",
"hajjis":"hajji",
"hakes":"hake",
"hakeas":"hakea",
"hakkas":"hakka",
"halalled":"halal",
"halalling":"halal",
"halals":"halal",
"haldeas":"haldea",
"haled":"hale",
"haler":"hale",
"halest":"hale",
"haling":"hale",
"halenesses":"haleness",
"halenias":"halenia",
"halers":"haler",
"haleru":"haler",
"halesias":"halesia",
"halves":"half",
"half-breeds":"half-breed",
"half-brothers":"half-brother",
"half-hours":"half-hour",
"half-lives":"half-life",
"half-masted":"half-mast",
"half-masting":"half-mast",
"half-moons":"half-moon",
"half-pints":"half-pint",
"half-slips":"half-slip",
"half-soled":"half-sole",
"half-soles":"half-sole",
"half-soling":"half-sole",
"half-truths":"half-truth",
"half-wits":"half-wit",
"halfbacks":"halfback",
"halfpence":"halfpenny",
"halfpennies":"halfpenny",
"halfpennyworths":"halfpennyworth",
"halftones":"halftone",
"halfways":"halfway",
"haliaeetuses":"haliaeetus",
"halibuts":"halibut",
"halicoereses":"halicoeres",
"halictidaes":"halictidae",
"halimodendrons":"halimodendron",
"haliotidaes":"haliotidae",
"haliotises":"haliotis",
"halites":"halite",
"halls":"hall",
"hallahs":"hallah",
"halliards":"halliard",
"hallmarked":"hallmark",
"hallmarking":"hallmark",
"hallmarks":"hallmark",
"halloed":"hallo",
"halloing":"hallo",
"hallos":"hallo",
"halloaed":"halloa",
"halloaing":"halloa",
"halloas":"halloa",
"hallooed":"halloo",
"hallooing":"halloo",
"halloos":"halloo",
"hallowed":"hallow",
"hallowing":"hallow",
"hallows":"hallow",
"halloweens":"halloween",
"hallowmases":"hallowmas",
"hallowmasses":"hallowmass",
"hallucinated":"hallucinate",
"hallucinating":"hallucinate",
"hallucinogens":"hallucinogen",
"halluces":"hallux",
"hallways":"hallway",
"halms":"halm",
"haloed":"halo",
"haloes":"halo",
"haloing":"halo",
"halos":"halo",
"halobacters":"halobacter",
"halobacterias":"halobacteria",
"halobacteriums":"halobacterium",
"halocarpuses":"halocarpus",
"halogenated":"halogenate",
"halogenates":"halogenate",
"halogenating":"halogenate",
"halogetons":"halogeton",
"haloragaceaes":"haloragaceae",
"haloragidaceaes":"haloragidaceae",
"halted":"halt",
"halting":"halt",
"halts":"halt",
"haltered":"halter",
"halteres":"halter",
"haltering":"halter",
"halters":"halter",
"halved":"halve",
"halving":"halve",
"halyards":"halyard",
"hammed":"ham",
"hamming":"ham",
"hams":"ham",
"hamadryades":"hamadryad",
"hamadryads":"hamadryad",
"hamamelidaceaes":"hamamelidaceae",
"hamamelidaes":"hamamelidae",
"hamamelidanthums":"hamamelidanthum",
"hamamelidoxylons":"hamamelidoxylon",
"hamamelises":"hamamelis",
"hamameliteses":"hamamelites",
"hamates":"hamate",
"hamburgers":"hamburger",
"haminoeas":"haminoea",
"hamitics":"hamitic",
"hamito-semitics":"hamito-semitic",
"hamlets":"hamlet",
"hammered":"hammer",
"hammering":"hammer",
"hammers":"hammer",
"hammerheads":"hammerhead",
"hammerings":"hammering",
"hammings":"hamming",
"hammocks":"hammock",
"hammier":"hammy",
"hammiest":"hammy",
"hampered":"hamper",
"hampering":"hamper",
"hampers":"hamper",
"hampshires":"hampshire",
"hamstringing":"hamstring",
"hamstrings":"hamstring",
"hamstrung":"hamstring",
"hamuli":"hamulus",
"handed":"hand",
"handing":"hand",
"hands":"hand",
"hand-knits":"hand-knit",
"hand-knitted":"hand-knit",
"hand-knitting":"hand-knit",
"handbags":"handbag",
"handbasins":"handbasin",
"handbaskets":"handbasket",
"handbills":"handbill",
"handbooks":"handbook",
"handbreaths":"handbreath",
"handcarts":"handcart",
"handclasps":"handclasp",
"handcrafted":"handcraft",
"handcrafting":"handcraft",
"handcrafts":"handcraft",
"handcuffed":"handcuff",
"handcuffing":"handcuff",
"handcuffs":"handcuff",
"handcuffses":"handcuffs",
"handednesses":"handedness",
"handels":"handel",
"handfed":"handfeed",
"handfeeding":"handfeed",
"handfeeds":"handfeed",
"handfuls":"handful",
"handgrips":"handgrip",
"handguns":"handgun",
"handicapped":"handicap",
"handicapping":"handicap",
"handicaps":"handicap",
"handicrafts":"handicraft",
"handicraftsmen":"handicraftsman",
"handinesses":"handiness",
"handiworks":"handiwork",
"handkerchiefs":"handkerchief",
"handkerchieves":"handkerchief",
"handled":"handle",
"handles":"handle",
"handling":"handle",
"handle-barses":"handle-bars",
"handlebars":"handlebar",
"handlers":"handler",
"handlines":"handline",
"handlings":"handling",
"handlocks":"handlock",
"handmaids":"handmaid",
"handmaidens":"handmaiden",
"handouts":"handout",
"handpicked":"handpick",
"handpicking":"handpick",
"handpicks":"handpick",
"handrails":"handrail",
"handses":"hands",
"handsaws":"handsaw",
"handsbreadths":"handsbreadth",
"handseled":"handsel",
"handseling":"handsel",
"handselled":"handsel",
"handselling":"handsel",
"handsels":"handsel",
"handsets":"handset",
"handshakes":"handshake",
"handshakings":"handshaking",
"handsomer":"handsome",
"handsomest":"handsome",
"handsomenesses":"handsomeness",
"handstamps":"handstamp",
"handworks":"handwork",
"handwritings":"handwriting",
"handier":"handy",
"handiest":"handy",
"handymen":"handyman",
"hanged":"hang",
"hanging":"hang",
"hangs":"hang",
"hung":"hang",
"hang-ups":"hang-up",
"hangars":"hangar",
"hangbirds":"hangbird",
"hangchows":"hangchow",
"hanger-ons":"hanger-on",
"hangers-on":"hanger-on",
"hangings":"hanging",
"hangmen":"hangman",
"hangnails":"hangnail",
"hangouts":"hangout",
"hangovers":"hangover",
"hangzhous":"hangzhou",
"hanis":"hani",
"hankered":"hanker",
"hankering":"hanker",
"hankers":"hanker",
"hankerings":"hankering",
"hankeys":"hankey",
"hankies":"hanky",
"hannovers":"hannover",
"hanois":"hanoi",
"hanovers":"hanover",
"hanseled":"hansel",
"hanseling":"hansel",
"hanselled":"hansel",
"hanselling":"hansel",
"hansels":"hansel",
"hansoms":"hansom",
"hanukahs":"hanukah",
"hanukkahs":"hanukkah",
"hanumen":"hanuman",
"haoles":"haole",
"haomas":"haoma",
"happed":"hap",
"happing":"hap",
"haps":"hap",
"haphazardnesses":"haphazardness",
"haphtarahs":"haphtarah",
"haphtarot":"haphtarah",
"haphtaroth":"haphtarah",
"haphtatarahs":"haphtarah",
"haphtataroth":"haphtarah",
"haplographies":"haplography",
"haplopappuses":"haplopappus",
"haplosporidias":"haplosporidia",
"happened":"happen",
"happening":"happen",
"happens":"happen",
"happenings":"happening",
"happenstances":"happenstance",
"happinesses":"happiness",
"happier":"happy",
"happiest":"happy",
"hapsburgs":"hapsburg",
"harakiris":"harakiri",
"harangued":"harangue",
"harangues":"harangue",
"haranguing":"harangue",
"harares":"harare",
"harassed":"harass",
"harasses":"harass",
"harassing":"harass",
"harassments":"harassment",
"harbingered":"harbinger",
"harbingering":"harbinger",
"harbingers":"harbinger",
"harbored":"harbor",
"harboring":"harbor",
"harbors":"harbor",
"harborages":"harborage",
"harboured":"harbour",
"harbouring":"harbour",
"harbours":"harbour",
"harbourages":"harbourage",
"harder":"hard",
"hardest":"hard",
"hard-ons":"hard-on",
"hardbacks":"hardback",
"hardboards":"hardboard",
"hardcovers":"hardcover",
"hardened":"harden",
"hardening":"harden",
"hardens":"harden",
"hardenbergias":"hardenbergia",
"hardenings":"hardening",
"hardheadses":"hardheads",
"hardheartednesses":"hardheartedness",
"hardihoods":"hardihood",
"hardinesses":"hardiness",
"hardings":"harding",
"hardinggrasses":"hardinggrass",
"hardnesses":"hardness",
"hardpans":"hardpan",
"hardships":"hardship",
"hardtacks":"hardtack",
"hardwares":"hardware",
"hardwaremen":"hardwareman",
"hardwoods":"hardwood",
"hardier":"hardy",
"hardies":"hardy",
"hardiest":"hardy",
"hares":"hare",
"harebells":"harebell",
"hareems":"hareem",
"harelips":"harelip",
"harems":"harem",
"haricots":"haricot",
"harikaris":"harikari",
"harked":"hark",
"harking":"hark",
"harks":"hark",
"harkened":"harken",
"harkening":"harken",
"harkens":"harken",
"harlequin-snakes":"harlequin-snake",
"harlequinades":"harlequinade",
"harlots":"harlot",
"harlotries":"harlotry",
"harmed":"harm",
"harming":"harm",
"harms":"harm",
"harmfulnesses":"harmfulness",
"harmonicas":"harmonica",
"harmoniousnesses":"harmoniousness",
"harmonisations":"harmonisation",
"harmoniums":"harmonium",
"harmonizations":"harmonization",
"harmonized":"harmonize",
"harmonizes":"harmonize",
"harmonizing":"harmonize",
"harmonies":"harmony",
"harnessed":"harness",
"harnesses":"harness",
"harnessing":"harness",
"harped":"harp",
"harping":"harp",
"harps":"harp",
"harpers":"harper",
"harpias":"harpia",
"harpists":"harpist",
"harpooned":"harpoon",
"harpooning":"harpoon",
"harpooneers":"harpooneer",
"harpooners":"harpooner",
"harpullas":"harpulla",
"harpies":"harpy",
"harquebuses":"harquebus",
"harrisburgs":"harrisburg",
"harrisias":"harrisia",
"harrisons":"harrison",
"harrowed":"harrow",
"harrowing":"harrow",
"harrows":"harrow",
"harrumphed":"harrumph",
"hurrumphing":"harrumph",
"harried":"harry",
"harries":"harry",
"harrying":"harry",
"harsher":"harsh",
"harshest":"harsh",
"harshened":"harshen",
"harshening":"harshen",
"harshnesses":"harshness",
"harts":"hart",
"hartebeests":"hartebeest",
"hartfords":"hartford",
"harum-scarums":"harum-scarum",
"haruspices":"haruspex",
"harvards":"harvard",
"harvested":"harvest",
"harvesting":"harvest",
"harvests":"harvest",
"harvest-lices":"harvest-lice",
"harvesters":"harvester",
"harvestfishes":"harvestfish",
"harvestings":"harvesting",
"harvestmen":"harvestman",
"has-beens":"has-been",
"hashed":"hash",
"hashes":"hash",
"hashing":"hash",
"hashishes":"hashish",
"hashmarks":"hashmark",
"hasped":"hasp",
"hasping":"hasp",
"hassles":"hassle",
"hassocks":"hassock",
"hasted":"haste",
"hastes":"haste",
"hasting":"haste",
"hastened":"hasten",
"hastening":"hasten",
"hastens":"hasten",
"hastenings":"hastening",
"hastinesses":"hastiness",
"hastingses":"hastings",
"hastier":"hasty",
"hastiest":"hasty",
"hats":"hat",
"hatted":"hat",
"hatting":"hat",
"hatched":"hatch",
"hatches":"hatch",
"hatching":"hatch",
"hatcheled":"hatchel",
"hatcheling":"hatchel",
"hatchelled":"hatchel",
"hatchelling":"hatchel",
"hatchels":"hatchel",
"hatcheries":"hatchery",
"hatchets":"hatchet",
"hatchings":"hatching",
"hatchways":"hatchway",
"hated":"hate",
"hates":"hate",
"hating":"hate",
"hatefulnesses":"hatefulness",
"hatfuls":"hatful",
"hatioras":"hatiora",
"hatmakers":"hatmaker",
"hatracks":"hatrack",
"hatreds":"hatred",
"hatters":"hatter",
"hauberks":"hauberk",
"haughtinesses":"haughtiness",
"haughtier":"haughty",
"haughtiest":"haughty",
"hauled":"haul",
"hauling":"haul",
"hauls":"haul",
"haulages":"haulage",
"haulers":"hauler",
"hauliers":"haulier",
"haulings":"hauling",
"haulms":"haulm",
"haunches":"haunch",
"haunted":"haunt",
"haunting":"haunt",
"haunts":"haunt",
"hausas":"hausa",
"hausens":"hausen",
"haussas":"haussa",
"haustella":"haustellum",
"haustoria":"haustorium",
"hautboises":"hautbois",
"hautboys":"hautboy",
"haute-normandies":"haute-normandie",
"havanas":"havana",
"had":"have",
"having":"have",
"‘ve":"have",
"have-nots":"have-not",
"havened":"haven",
"havening":"haven",
"havens":"haven",
"havered":"haver",
"havering":"haver",
"haversacks":"haversack",
"had_a_feeling":"have_a_feeling",
"has_a_feeling":"have_a_feeling",
"having_a_feeling":"have_a_feeling",
"had_left":"have_left",
"has_left":"have_left",
"having_left":"have_left",
"had_the_feeling":"have_the_feeling",
"has_the_feeling":"have_the_feeling",
"having_the_feeling":"have_the_feeling",
"havocs":"havoc",
"hawed":"haw",
"hawing":"haw",
"haws":"haw",
"haw-haws":"haw-haw",
"hawaiis":"hawaii",
"hawfinches":"hawfinch",
"hawked":"hawk",
"hawking":"hawk",
"hawks":"hawk",
"hawkbills":"hawkbill",
"hawkers":"hawker",
"hawkings":"hawking",
"hawkmoths":"hawkmoth",
"hawksbills":"hawksbill",
"hawkshaws":"hawkshaw",
"hawses":"hawse",
"hawseholes":"hawsehole",
"hawsepipes":"hawsepipe",
"hawthorns":"hawthorn",
"hayed":"hay",
"haying":"hay",
"hay-scenteds":"hay-scented",
"hayastans":"hayastan",
"haydns":"haydn",
"hayeses":"hayes",
"hayfields":"hayfield",
"hayings":"haying",
"haylofts":"hayloft",
"haymakers":"haymaker",
"hayracks":"hayrack",
"hayricks":"hayrick",
"hayrigs":"hayrig",
"hayseeds":"hayseed",
"haystacks":"haystack",
"haytis":"hayti",
"hazans":"hazan",
"hazarded":"hazard",
"hazarding":"hazard",
"hazards":"hazard",
"hazardias":"hazardia",
"hazardings":"hazarding",
"hazardousnesses":"hazardousness",
"hazed":"haze",
"hazes":"haze",
"hazing":"haze",
"hazels":"hazel",
"hazelnuts":"hazelnut",
"hazelwoods":"hazelwood",
"hazinesses":"haziness",
"hazier":"hazy",
"haziest":"hazy",
"hazzanim":"hazzan",
"hazzans":"hazzan",
"hdls":"hdl",
"hes":"he",
"he-goats":"he-goat",
"he-huckleberries":"he-huckleberry",
"he-men":"he-man",
"headed":"head",
"heading":"head",
"heads":"head",
"head-shrinkers":"head-shrinker",
"headaches":"headache",
"headcounts":"headcount",
"headcounters":"headcounter",
"headdresses":"headdress",
"headers":"header",
"headfishes":"headfish",
"headgears":"headgear",
"headhunters":"headhunter",
"headings":"heading",
"headlamps":"headlamp",
"headlands":"headland",
"headlights":"headlight",
"headlined":"headline",
"headlines":"headline",
"headlining":"headline",
"headliners":"headliner",
"headmen":"headman",
"headmasters":"headmaster",
"headphones":"headphone",
"headpieces":"headpiece",
"headpins":"headpin",
"headrests":"headrest",
"headrooms":"headroom",
"headshakes":"headshake",
"headshakings":"headshaking",
"headsmen":"headsman",
"headsprings":"headspring",
"headstalls":"headstall",
"headstones":"headstone",
"headways":"headway",
"headier":"heady",
"headiest":"heady",
"healed":"heal",
"healing":"heal",
"heals":"heal",
"healers":"healer",
"healthinesses":"healthiness",
"healthier":"healthy",
"healthiest":"healthy",
"heaped":"heap",
"heaping":"heap",
"heaps":"heap",
"heapses":"heaps",
"heard":"hear",
"hearing":"hear",
"hears":"hear",
"hearers":"hearer",
"hearings":"hearing",
"hearkened":"hearken",
"hearkening":"hearken",
"hearkens":"hearken",
"hearsays":"hearsay",
"hearts":"heart",
"heartaches":"heartache",
"heartbeats":"heartbeat",
"heartbreaks":"heartbreak",
"heartburns":"heartburn",
"heartened":"hearten",
"heartening":"hearten",
"heartens":"hearten",
"hearths":"hearth",
"hearthstones":"hearthstone",
"heartinesses":"heartiness",
"heartleaves":"heartleaf",
"heartlessnesses":"heartlessness",
"heartses":"hearts",
"heartseases":"heartsease",
"heartseeds":"heartseed",
"heartsicknesses":"heartsickness",
"heartwoods":"heartwood",
"heartier":"hearty",
"hearties":"hearty",
"heartiest":"hearty",
"heated":"heat",
"heating":"heat",
"heats":"heat",
"heaters":"heater",
"heaths":"heath",
"heathberries":"heathberry",
"heathens":"heathen",
"heathenisms":"heathenism",
"heathers":"heather",
"heathfowls":"heathfowl",
"heathlands":"heathland",
"heatings":"heating",
"heaved":"heave",
"heaves":"heave",
"heaving":"heave",
"hove":"heave",
"heave-hos":"heave-ho",
"heavens":"heaven",
"heavenses":"heavens",
"heaveses":"heaves",
"heavinesses":"heaviness",
"heavings":"heaving",
"heavier":"heavy",
"heavies":"heavy",
"heaviest":"heavy",
"heavyweights":"heavyweight",
"hebdomads":"hebdomad",
"hebephrenias":"hebephrenia",
"hebetated":"hebetate",
"hebetating":"hebetate",
"hebraisms":"hebraism",
"hebraized":"hebraize",
"hebraizing":"hebraize",
"Hebrews":"Hebrew",
"hebrewses":"hebrews",
"hebrideses":"hebrides",
"heckelphones":"heckelphone",
"heckled":"heckle",
"heckles":"heckle",
"heckling":"heckle",
"hecklers":"heckler",
"hecklings":"heckling",
"hectocotyli":"hectocotylus",
"hectograms":"hectogram",
"hectographed":"hectograph",
"hectographing":"hectograph",
"hectographs":"hectograph",
"hectoliters":"hectoliter",
"hectolitres":"hectolitre",
"hectometers":"hectometer",
"hectometres":"hectometre",
"hectored":"hector",
"hectoring":"hector",
"hectors":"hector",
"hedeomas":"hedeoma",
"hadarim":"heder",
"hederas":"hedera",
"hedged":"hedge",
"hedges":"hedge",
"hedging":"hedge",
"hedgehogs":"hedgehog",
"hedgehopped":"hedgehop",
"hedgehopping":"hedgehop",
"hedgehops":"hedgehop",
"hedgerows":"hedgerow",
"hedgings":"hedging",
"hedgier":"hedgy",
"hedgiest":"hedgy",
"hediondillas":"hediondilla",
"hedonists":"hedonist",
"hedysarums":"hedysarum",
"hee-haws":"hee-haw",
"heeded":"heed",
"heeding":"heed",
"heeds":"heed",
"heedfulnesses":"heedfulness",
"heedlessnesses":"heedlessness",
"heehawed":"heehaw",
"heehawing":"heehaw",
"heeled":"heel",
"heeling":"heel",
"heels":"heel",
"heelbones":"heelbone",
"hefted":"heft",
"hefting":"heft",
"hefts":"heft",
"heftinesses":"heftiness",
"heftier":"hefty",
"heftiest":"hefty",
"hegels":"hegel",
"hegemonies":"hegemony",
"hegiras":"hegira",
"heifers":"heifer",
"heights":"height",
"heightened":"heighten",
"heightening":"heighten",
"heightens":"heighten",
"heightses":"heights",
"heimdals":"heimdal",
"heimdalls":"heimdall",
"heimdallrs":"heimdallr",
"heinousnesses":"heinousness",
"heirs":"heir",
"heirs-at-law":"heir-at-law",
"heiresses":"heiress",
"heirlooms":"heirloom",
"heisted":"heist",
"heisting":"heist",
"heists":"heist",
"hejiras":"hejira",
"hels":"hel",
"helas":"hela",
"heldentetenore":"heldentenor",
"helens":"helen",
"helenas":"helena",
"heleniums":"helenium",
"heleodyteses":"heleodytes",
"heliamphoras":"heliamphora",
"helianthemums":"helianthemum",
"helianthuses":"helianthus",
"helichrysums":"helichrysum",
"helicidaes":"helicidae",
"helicons":"helicon",
"helicoptered":"helicopter",
"helicoptering":"helicopter",
"helicopters":"helicopter",
"helictereses":"helicteres",
"helilifted":"helilift",
"helilifting":"helilift",
"heliographed":"heliograph",
"heliographing":"heliograph",
"heliogravures":"heliogravure",
"heliolatries":"heliolatry",
"heliopses":"heliopsis",
"heliothises":"heliothis",
"heliotropes":"heliotrope",
"heliotypes":"heliotype",
"heliozoas":"heliozoa",
"helipterums":"helipterum",
"heliums":"helium",
"helices":"helix",
"helixes":"helix",
"hells":"hell",
"hell-kites":"hell-kite",
"hell-roosters":"hell-rooster",
"hellbenders":"hellbender",
"hellcats":"hellcat",
"hellebores":"hellebore",
"helleborines":"helleborine",
"helleboruses":"helleborus",
"Hellenes":"Hellene",
"hellenics":"hellenic",
"hellers":"heller",
"helleris":"helleri",
"hellesponts":"hellespont",
"hellfires":"hellfire",
"hellgrammiates":"hellgrammiate",
"hellions":"hellion",
"helloed":"hello",
"helloing":"hello",
"hellos":"hello",
"helmed":"helm",
"helming":"helm",
"helms":"helm",
"helmets":"helmet",
"helmetflowers":"helmetflower",
"helmholtzs":"helmholtz",
"helminths":"helminth",
"helminthics":"helminthic",
"helminthostachyses":"helminthostachys",
"helmsmen":"helmsman",
"helodermas":"heloderma",
"helodermatidaes":"helodermatidae",
"helots":"helot",
"helotiaceaes":"helotiaceae",
"helotialeses":"helotiales",
"helotiums":"helotium",
"helped":"help",
"helping":"help",
"helps":"help",
"helpers":"helper",
"helpfulnesses":"helpfulness",
"helpings":"helping",
"helplessnesses":"helplessness",
"helpmates":"helpmate",
"helpmeets":"helpmeet",
"helsingforses":"helsingfors",
"helsinkis":"helsinki",
"helves":"helve",
"helvellaceaes":"helvellaceae",
"helveticas":"helvetica",
"helxines":"helxine",
"hemmed":"hem",
"hemming":"hem",
"hems":"hem",
"hemachatuses":"hemachatus",
"hemagglutinated":"hemagglutinate",
"hemagglutinating":"hemagglutinate",
"hemangiomas":"hemangioma",
"hemangiomata":"hemangioma",
"hematites":"hematite",
"hematocysts":"hematocyst",
"hematologists":"hematologist",
"hematologies":"hematology",
"hematolyses":"hematolysis",
"hematomas":"hematoma",
"hematomata":"hematoma",
"hematozozoa":"hematozoon",
"hemes":"heme",
"hemelytra":"hemelytron",
"hemeralopias":"hemeralopia",
"hemerobiids":"hemerobiid",
"hemerobiidaes":"hemerobiidae",
"hemerocallidaceaes":"hemerocallidaceae",
"hemerocallises":"hemerocallis",
"hemiascomyceteses":"hemiascomycetes",
"hemicranias":"hemicrania",
"hemicycles":"hemicycle",
"hemidemisemiquavers":"hemidemisemiquaver",
"hemielytra":"hemielytron",
"hemiepiphytes":"hemiepiphyte",
"hemigaluses":"hemigalus",
"hemigrammuses":"hemigrammus",
"hemimetabolas":"hemimetabola",
"hemimorphites":"hemimorphite",
"hemingways":"hemingway",
"hemipodes":"hemipode",
"hemiprocnidaes":"hemiprocnidae",
"hemipteras":"hemiptera",
"hemipterans":"hemipteran",
"hemipterons":"hemipteron",
"hemipteronatuses":"hemipteronatus",
"hemiramphidaes":"hemiramphidae",
"hemisected":"hemisect",
"hemisecting":"hemisect",
"hemispheres":"hemisphere",
"hemitripteruses":"hemitripterus",
"hemlocks":"hemlock",
"hemodialyses":"hemodialysis",
"hemodialyzers":"hemodialyzer",
"hemoglobins":"hemoglobin",
"hemoglobinopathies":"hemoglobinopathy",
"hemolysins":"hemolysin",
"hemolyses":"hemolysis",
"hemophiles":"hemophile",
"hemophilias":"hemophilia",
"hemophiliacs":"hemophiliac",
"hemoptyses":"hemoptysis",
"hemorrhages":"hemorrhage",
"hemorrhoids":"hemorrhoid",
"hemorrhoidectomies":"hemorrhoidectomy",
"hemostats":"hemostat",
"hemps":"hemp",
"hemstitched":"hemstitch",
"hemstitches":"hemstitch",
"hemstitching":"hemstitch",
"hemstitchings":"hemstitching",
"hens":"hen",
"hens-and-chickens":"hen-and-chickens",
"hen-of-the-woodses":"hen-of-the-woods",
"henbanes":"henbane",
"henbits":"henbit",
"henchmen":"henchman",
"hencoops":"hencoop",
"hendecahedra":"hendecahedron",
"hendecahedrons":"hendecahedron",
"henhouses":"henhouse",
"hennas":"henna",
"henneries":"hennery",
"henpecked":"henpeck",
"henpecking":"henpeck",
"henries":"henry",
"henrys":"henry",
"henting":"hent",
"henyards":"henyard",
"hepper":"hep",
"heppest":"hep",
"hepatectomies":"hepatectomy",
"hepaticas":"hepatica",
"hepaticaes":"hepaticae",
"hepaticopsidas":"hepaticopsida",
"hepatoflavins":"hepatoflavin",
"hephaestuses":"hephaestus",
"hephaistoses":"hephaistos",
"heptads":"heptad",
"heptarchies":"heptarchy",
"heras":"hera",
"heracleses":"heracles",
"heracleums":"heracleum",
"heraclidae":"heraclid",
"herakleses":"herakles",
"heraklidae":"heraklid",
"heralded":"herald",
"heralding":"herald",
"heralds":"herald",
"heraldries":"heraldry",
"herbs":"herb",
"herbages":"herbage",
"herbalists":"herbalist",
"herbariia":"herbarium",
"herbariumia":"herbarium",
"herbariums":"herbarium",
"herbicides":"herbicide",
"herbier":"herby",
"herbiest":"herby",
"herculeses":"hercules",
"hercules-clubs":"hercules-club",
"herded":"herd",
"herding":"herd",
"herds":"herd",
"herders":"herder",
"herdsmen":"herdsman",
"heres":"here",
"hereafters":"hereafter",
"heredities":"heredity",
"herefords":"hereford",
"heros":"herero",
"heredes":"heres",
"heresies":"heresy",
"heretics":"heretic",
"heritages":"heritage",
"heritieras":"heritiera",
"heritors":"heritor",
"herms":"herm",
"hermae":"herma",
"hermai":"herma",
"hermanns":"hermann",
"hermannias":"hermannia",
"hermaphrodites":"hermaphrodite",
"hermaphroditisms":"hermaphroditism",
"hermissendas":"hermissenda",
"hermits":"hermit",
"hermitages":"hermitage",
"hernarias":"hernaria",
"herniae":"hernia",
"hernias":"hernia",
"herniated":"herniate",
"herniating":"herniate",
"herniations":"herniation",
"herniorrhaphies":"herniorrhaphy",
"heroes":"hero",
"hero-worshiped":"hero-worship",
"hero-worshiping":"hero-worship",
"hero-worships":"hero-worship",
"herods":"herod",
"heroins":"heroin",
"heroines":"heroine",
"heroisms":"heroism",
"herons":"heron",
"heronries":"heronry",
"herpeses":"herpes",
"herpesteses":"herpestes",
"Herren":"Herr",
"herrenvolks":"herrenvolk",
"herrerasaurs":"herrerasaur",
"herrerasauruses":"herrerasaurus",
"herrings":"herring",
"herthas":"hertha",
"hertzs":"hertz",
"hesitances":"hesitance",
"hesitancies":"hesitancy",
"hesitated":"hesitate",
"hesitates":"hesitate",
"hesitating":"hesitate",
"hesitaters":"hesitater",
"hesitations":"hesitation",
"hesitators":"hesitator",
"hesperideses":"hesperides",
"hesperidia":"hesperidium",
"hesperiphonas":"hesperiphona",
"hesperises":"hesperis",
"hessians":"hessian",
"hessonites":"hessonite",
"hetaerae":"hetaera",
"hetairai":"hetaira",
"heterantheras":"heteranthera",
"heterobasidiomyceteses":"heterobasidiomycetes",
"heterocephaluses":"heterocephalus",
"heterodons":"heterodon",
"heterodoxies":"heterodoxy",
"heterogeneities":"heterogeneity",
"heterogeneousnesses":"heterogeneousness",
"heterogeneses":"heterogenesis",
"heterografts":"heterograft",
"heterokontaes":"heterokontae",
"heterokontophytas":"heterokontophyta",
"heteromeleses":"heteromeles",
"heteromyidaes":"heteromyidae",
"heteroplasties":"heteroplasty",
"heteropteras":"heteroptera",
"heterosceluses":"heteroscelus",
"heterosexuals":"heterosexual",
"heterosexualisms":"heterosexualism",
"heterosexualities":"heterosexuality",
"heterosomatas":"heterosomata",
"heterostracis":"heterostraci",
"heterothecas":"heterotheca",
"heterotrichaleses":"heterotrichales",
"hetmans":"hetman",
"heucheras":"heuchera",
"heuristics":"heuristic",
"heveas":"hevea",
"hewed":"hew",
"hewing":"hew",
"hewn":"hew",
"hews":"hew",
"hexed":"hex",
"hexes":"hex",
"hexing":"hex",
"hexads":"hexad",
"hexagrammidaes":"hexagrammidae",
"hexagrammoses":"hexagrammos",
"hexahedra":"hexahedron",
"hexahedrons":"hexahedron",
"hexalectrises":"hexalectris",
"hexamitas":"hexamita",
"hexanchidaes":"hexanchidae",
"hexanchuses":"hexanchus",
"hexaplas":"hexapla",
"hexapodas":"hexapoda",
"hexapodies":"hexapody",
"hexenbesens":"hexenbesen",
"heydays":"heyday",
"hfs":"hf",
"hgs":"hg",
"bevvied":"bevvy",
"hi-fis":"hi-fi",
"hiatuses":"hiatus",
"hibachis":"hibachi",
"hibbertias":"hibbertia",
"hibernacles":"hibernacle",
"hibernacula":"hibernaculum",
"hibernated":"hibernate",
"hibernates":"hibernate",
"hibernating":"hibernate",
"hibernias":"hibernia",
"hibiscuses":"hibiscus",
"hiccoughed":"hiccough",
"hiccoughing":"hiccough",
"hiccoughs":"hiccough",
"hicccupped":"hiccup",
"hiccuped":"hiccup",
"hiccuping":"hiccup",
"hiccupped":"hiccup",
"hiccupping":"hiccup",
"hiccups":"hiccup",
"hicks":"hick",
"hickeys":"hickey",
"hickories":"hickory",
"hidalgos":"hidalgo",
"hidatsas":"hidatsa",
"hid":"hide",
"hidden":"hide",
"hides":"hide",
"hiding":"hide",
"hide-and-seeks":"hide-and-seek",
"hideaways":"hideaway",
"hideouts":"hideout",
"hidings":"hiding",
"hidroses":"hidrosis",
"hied":"hie",
"hieing":"hie",
"hying":"hie",
"hieraciums":"hieracium",
"hieracosphinges":"hieracosphinx",
"hieracosphinxes":"hieracosphinx",
"hierarches":"hierarch",
"hierarchies":"hierarchy",
"hieratics":"hieratic",
"hierocracies":"hierocracy",
"hieroglyphs":"hieroglyph",
"hieroglyphics":"hieroglyphic",
"hierolatries":"hierolatry",
"hierologies":"hierology",
"hiera":"hieron",
"hierurgies":"hierurgy",
"higgled":"higgle",
"higgles":"higgle",
"higgling":"higgle",
"higher":"high",
"highest":"high",
"highs":"high",
"high-hats":"high-hat",
"high-hatted":"high-hat",
"high-hatting":"high-hat",
"high-low-jacks":"high-low-jack",
"high-mindednesses":"high-mindedness",
"high-muck-a-mucks":"high-muck-a-muck",
"high-pressured":"high-pressure",
"high-pressuring":"high-pressure",
"high-rises":"high-rise",
"high-spiritednesses":"high-spiritedness",
"high-teches":"high-tech",
"high-ups":"high-up",
"highboys":"highboy",
"highchairs":"highchair",
"higher-ups":"higher-up",
"highfliers":"highflier",
"highflyers":"highflyer",
"highjacked":"highjack",
"highjacking":"highjack",
"highjacks":"highjack",
"highjackers":"highjacker",
"highjackings":"highjacking",
"highlands":"highland",
"highlighted":"highlight",
"highlighting":"highlight",
"highlights":"highlight",
"highlightings":"highlighting",
"highnesses":"highness",
"highroads":"highroad",
"highschools":"highschool",
"hightailed":"hightail",
"hightailing":"hightail",
"highwaters":"highwater",
"highways":"highway",
"highwaymen":"highwayman",
"higis":"higi",
"hijacked":"hijack",
"hijacking":"hijack",
"hijacks":"hijack",
"hijackers":"hijacker",
"hijackings":"hijacking",
"hijinkses":"hijinks",
"hiked":"hike",
"hikes":"hike",
"hiking":"hike",
"hilarities":"hilarity",
"hilled":"hill",
"hilling":"hill",
"hills":"hill",
"hillbillies":"hillbilly",
"hillocks":"hillock",
"hillsides":"hillside",
"hilltops":"hilltop",
"hillier":"hilly",
"hilliest":"hilly",
"hilts":"hilt",
"hila":"hilum",
"hilums":"hilum",
"hiluses":"hilus",
"himalayases":"himalayas",
"himantoglossums":"himantoglossum",
"himantopuses":"himantopus",
"himatia":"himation",
"hinder":"hind",
"hinds":"hind",
"hindbrains":"hindbrain",
"hindered":"hinder",
"hindering":"hinder",
"hinders":"hinder",
"hindoos":"hindoo",
"hindooisms":"hindooism",
"hindoostanis":"hindoostani",
"hindostanis":"hindostani",
"hindquarterses":"hindquarters",
"hindrances":"hindrance",
"Hindus":"Hindu",
"hinduisms":"hinduism",
"hindustanis":"hindustani",
"hinged":"hinge",
"hinges":"hinge",
"hinging":"hinge",
"hinnied":"hinny",
"hinnies":"hinny",
"hinnying":"hinny",
"hinted":"hint",
"hinting":"hint",
"hints":"hint",
"hinterlands":"hinterland",
"hipped":"hip",
"hipping":"hip",
"hips":"hip",
"hipbones":"hipbone",
"hipflasks":"hipflask",
"hippeastrums":"hippeastrum",
"hippies":"hippie",
"hippos":"hippo",
"hippoboscas":"hippobosca",
"hippoboscids":"hippoboscid",
"hippoboscidaes":"hippoboscidae",
"hippocampi":"hippocampus",
"hippocampuses":"hippocampus",
"hippocastanaceaes":"hippocastanaceae",
"hippocrepises":"hippocrepis",
"hippodamias":"hippodamia",
"hippoglossoideses":"hippoglossoides",
"hippoglossuses":"hippoglossus",
"hippopotamidaes":"hippopotamidae",
"hippopotami":"hippopotamus",
"hippopotamuses":"hippopotamus",
"hipposideridaes":"hipposideridae",
"hipposideroses":"hipposideros",
"hippotraguses":"hippotragus",
"hipsuruses":"hipsurus",
"hired":"hire",
"hires":"hire",
"hiring":"hire",
"hire-purchases":"hire-purchase",
"hirelings":"hireling",
"hirers":"hirer",
"hirings":"hiring",
"hirsutenesses":"hirsuteness",
"hirsutisms":"hirsutism",
"hirudineas":"hirudinea",
"hirudineans":"hirudinean",
"hirudinidaes":"hirudinidae",
"hirudos":"hirudo",
"hirundinidaes":"hirundinidae",
"hirundos":"hirundo",
"Hispanics":"Hispanic",
"hispanicized":"hispanicize",
"hispanicizing":"hispanicize",
"hispaniolas":"hispaniola",
"hissed":"hiss",
"hisses":"hiss",
"hissing":"hiss",
"hissings":"hissing",
"historians":"historian",
"historiographers":"historiographer",
"historiographies":"historiography",
"histories":"history",
"histrions":"histrion",
"histrionicses":"histrionics",
"hits":"hit",
"hitted":"hit",
"hitting":"hit",
"hitched":"hitch",
"hitches":"hitch",
"hitching":"hitch",
"hitchhiked":"hitchhike",
"hitchhikes":"hitchhike",
"hitchhiking":"hitchhike",
"hitchracks":"hitchrack",
"hitlers":"hitler",
"hitters":"hitter",
"hittings":"hitting",
"hivs":"hiv",
"hived":"hive",
"hives":"hive",
"hiving":"hive",
"hiveses":"hives",
"hls":"hl",
"hms":"hm",
"hmos":"hmo",
"hns":"hn",
"hos":"ho",
"hoactzins":"hoactzin",
"hoagies":"hoagie",
"hoars":"hoar",
"hoarded":"hoard",
"hoarding":"hoard",
"hoards":"hoard",
"hoarders":"hoarder",
"hoardings":"hoarding",
"hoarfrosts":"hoarfrost",
"hoarinesses":"hoariness",
"hoarser":"hoarse",
"hoarsest":"hoarse",
"hoarsened":"hoarsen",
"hoarsening":"hoarsen",
"hoarsenesses":"hoarseness",
"hoarier":"hoary",
"hoariest":"hoary",
"hoatzins":"hoatzin",
"hoaxed":"hoax",
"hoaxes":"hoax",
"hoaxing":"hoax",
"hoaxers":"hoaxer",
"hobs":"hob",
"hobbled":"hobble",
"hobbles":"hobble",
"hobbling":"hobble",
"hobbies":"hobby",
"hobbyhorses":"hobbyhorse",
"hobgoblins":"hobgoblin",
"hobnobbed":"hobnob",
"hobnobbing":"hobnob",
"hobnobs":"hobnob",
"hoboes":"hobo",
"hobos":"hobo",
"hocked":"hock",
"hocking":"hock",
"hocks":"hock",
"hockeys":"hockey",
"hocused":"hocus",
"hocuses":"hocus",
"hocusing":"hocus",
"hocussed":"hocus",
"hocussing":"hocus",
"hocus-pocused":"hocus-pocus",
"hocus-pocuses":"hocus-pocus",
"hocus-pocusing":"hocus-pocus",
"hocus-pocussed":"hocus-pocus",
"hocus-pocussing":"hocus-pocus",
"hoders":"hoder",
"hodgepodges":"hodgepodge",
"hodmen":"hodman",
"hodometers":"hodometer",
"hodrs":"hodr",
"hoed":"hoe",
"hoeing":"hoe",
"hoes":"hoe",
"hogged":"hog",
"hogging":"hog",
"hogs":"hog",
"hogchokers":"hogchoker",
"hogfishes":"hogfish",
"hoggs":"hogg",
"hoggets":"hogget",
"hoggishnesses":"hoggishness",
"hogtied":"hogtie",
"hogties":"hogtie",
"hogtying":"hogtie",
"hogwashes":"hogwash",
"hogweeds":"hogweed",
"hohenlindens":"hohenlinden",
"hoherias":"hoheria",
"hoisted":"hoist",
"hoisting":"hoist",
"hoists":"hoist",
"hokas":"hoka",
"hokans":"hokan",
"hokkaidos":"hokkaido",
"hokkianeses":"hokkianese",
"holarrhenas":"holarrhena",
"holbrookias":"holbrookia",
"holcuses":"holcus",
"held":"hold",
"holding":"hold",
"holds":"hold",
"holdalls":"holdall",
"holders":"holder",
"holdfasts":"holdfast",
"holdings":"holding",
"holdovers":"holdover",
"holdups":"holdup",
"holed":"hole",
"holes":"hole",
"holing":"hole",
"holibuts":"holibut",
"holidayed":"holiday",
"holidaying":"holiday",
"holidays":"holiday",
"holidaymakers":"holidaymaker",
"holinesses":"holiness",
"hollas":"holla",
"hollands":"holland",
"hollanders":"hollander",
"hollandses":"hollands",
"hollered":"holler",
"hollering":"holler",
"hollers":"holler",
"hollerings":"hollering",
"hollos":"hollo",
"holloas":"holloa",
"hollowed":"hollow",
"hollower":"hollow",
"hollowest":"hollow",
"hollowing":"hollow",
"hollows":"hollow",
"hollow-backs":"hollow-back",
"hollowares":"holloware",
"hollowwares":"hollowware",
"hollies":"holly",
"hollygrapes":"hollygrape",
"hollyhocks":"hollyhock",
"hollywoods":"hollywood",
"holmeses":"holmes",
"holmiums":"holmium",
"holocenes":"holocene",
"holocentridaes":"holocentridae",
"holocentruses":"holocentrus",
"holocephalis":"holocephali",
"holographs":"holograph",
"holonyms":"holonym",
"holonymies":"holonymy",
"holothurias":"holothuria",
"holothurians":"holothurian",
"holothuridaes":"holothuridae",
"holothuroideas":"holothuroidea",
"holotypes":"holotype",
"holsteins":"holstein",
"holstein-friesians":"holstein-friesian",
"holsters":"holster",
"holier":"holy",
"holies":"holy",
"holiest":"holy",
"holystoned":"holystone",
"holystones":"holystone",
"holystoning":"holystone",
"homages":"homage",
"homaridaes":"homaridae",
"homaruses":"homarus",
"hombres":"hombre",
"homburgs":"homburg",
"homed":"home",
"homes":"home",
"homing":"home",
"homebodies":"homebody",
"homebuilders":"homebuilder",
"homecomings":"homecoming",
"homelands":"homeland",
"homelesses":"homeless",
"homelinesses":"homeliness",
"homelier":"homely",
"homeliest":"homely",
"homemakers":"homemaker",
"homeopaths":"homeopath",
"homeopathies":"homeopathy",
"homeowners":"homeowner",
"homers":"homer",
"homesteads":"homestead",
"homesteaders":"homesteader",
"homeworks":"homework",
"homeier":"homey",
"homeiest":"homey",
"homicides":"homicide",
"homilies":"homily",
"hominidaes":"hominidae",
"hominoideas":"hominoidea",
"homos":"homo",
"homobasidiomyceteses":"homobasidiomycetes",
"homoeopaths":"homoeopath",
"homoeopathies":"homoeopathy",
"homoeroticisms":"homoeroticism",
"homogeneities":"homogeneity",
"homogeneousnesses":"homogeneousness",
"homogenisations":"homogenisation",
"homogenizations":"homogenization",
"homogenized":"homogenize",
"homogenizing":"homogenize",
"homografts":"homograft",
"homogynes":"homogyne",
"homologized":"homologize",
"homologizing":"homologize",
"homologies":"homology",
"homonas":"homona",
"homopteras":"homoptera",
"homopterans":"homopteran",
"homosexuals":"homosexual",
"homosexualisms":"homosexualism",
"homosexualities":"homosexuality",
"homunculi":"homunculus",
"homier":"homy",
"homiest":"homy",
"honchos":"honcho",
"hondos":"hondo",
"honed":"hone",
"hones":"hone",
"honing":"hone",
"honestnesses":"honestness",
"honesties":"honesty",
"honeyed":"honey",
"honeying":"honey",
"honeys":"honey",
"honied":"honey",
"honeybees":"honeybee",
"honeybellses":"honeybells",
"honeycombed":"honeycomb",
"honeycombing":"honeycomb",
"honeycombs":"honeycomb",
"honeycreepers":"honeycreeper",
"honeydews":"honeydew",
"honeyflowers":"honeyflower",
"honeymooned":"honeymoon",
"honeymooning":"honeymoon",
"honeymoons":"honeymoon",
"honeymooners":"honeymooner",
"honeypots":"honeypot",
"honeysuckers":"honeysucker",
"honeysuckles":"honeysuckle",
"honked":"honk",
"honking":"honk",
"honks":"honk",
"honkers":"honker",
"honkies":"honky",
"honky-tonks":"honky-tonk",
"honkytonks":"honkytonk",
"honolulus":"honolulu",
"honored":"honor",
"honoring":"honor",
"honors":"honor",
"honorablenesses":"honorableness",
"honoraria":"honorarium",
"honorariia":"honorarium",
"honorariums":"honorarium",
"honorings":"honoring",
"honoured":"honour",
"honouring":"honour",
"honours":"honour",
"honourablenesses":"honourableness",
"honourses":"honours",
"honshus":"honshu",
"hoo-has":"hoo-ha",
"hooches":"hooch",
"hooded":"hood",
"hooding":"hood",
"hoods":"hood",
"hoodlums":"hoodlum",
"hoodooed":"hoodoo",
"hoodooing":"hoodoo",
"hoodoos":"hoodoo",
"hoodooisms":"hoodooism",
"hoodwinked":"hoodwink",
"hoodwinking":"hoodwink",
"hoodwinks":"hoodwink",
"hooeys":"hooey",
"hoofed":"hoof",
"hoofing":"hoof",
"hoofs":"hoof",
"hooves":"hoof",
"hoofings":"hoofing",
"hoofmarks":"hoofmark",
"hoofprints":"hoofprint",
"hooked":"hook",
"hooking":"hook",
"hooks":"hook",
"hookahs":"hookah",
"hookers":"hooker",
"hooknoses":"hooknose",
"hookups":"hookup",
"hookies":"hooky",
"hooligans":"hooligan",
"hooliganisms":"hooliganism",
"hooped":"hoop",
"hooping":"hoop",
"hoops":"hoop",
"hooplas":"hoopla",
"hoopoes":"hoopoe",
"hoopoos":"hoopoo",
"hoopskirts":"hoopskirt",
"hoorayed":"hooray",
"hooraying":"hooray",
"hoosegows":"hoosegow",
"hoosgows":"hoosgow",
"hoosiers":"hoosier",
"hooted":"hoot",
"hooting":"hoot",
"hoots":"hoot",
"hootches":"hootch",
"hootchy-kootchies":"hootchy-kootchy",
"hootenannies":"hootenanny",
"hooters":"hooter",
"hootnannies":"hootnanny",
"hoovers":"hoover",
"hopped":"hop",
"hopping":"hop",
"hops":"hop",
"hop-pickers":"hop-picker",
"hoped":"hope",
"hopes":"hope",
"hoping":"hope",
"hopefuls":"hopeful",
"Hopis":"Hopi",
"hoppers":"hopper",
"hoppled":"hopple",
"hoppling":"hopple",
"hopses":"hops",
"hopsacks":"hopsack",
"hopsackings":"hopsacking",
"hordes":"horde",
"hordeola":"hordeolum",
"hordeolums":"hordeolum",
"hordeums":"hordeum",
"horizons":"horizon",
"hormones":"hormone",
"horned":"horn",
"horning":"horn",
"horns":"horn",
"horneophytons":"horneophyton",
"hornets":"hornet",
"hornfelses":"hornfels",
"horninesses":"horniness",
"hornpipes":"hornpipe",
"hornpouts":"hornpout",
"hornstones":"hornstone",
"hornswoggled":"hornswoggle",
"hornswoggling":"hornswoggle",
"hornier":"horny",
"horniest":"horny",
"horologers":"horologer",
"horologists":"horologist",
"horologia":"horologium",
"horoscopes":"horoscope",
"horoscopies":"horoscopy",
"horridnesses":"horridness",
"horrified":"horrify",
"horrifies":"horrify",
"horrifying":"horrify",
"horrors":"horror",
"horsed":"horse",
"horses":"horse",
"horsing":"horse",
"horsebacks":"horseback",
"horsebeans":"horsebean",
"horsebriers":"horsebrier",
"horsefishes":"horsefish",
"horsefleshes":"horseflesh",
"horseflies":"horsefly",
"horseheads":"horsehead",
"horselaughs":"horselaugh",
"horsemen":"horseman",
"horsemeats":"horsemeat",
"horsemints":"horsemint",
"horsepowers":"horsepower",
"horseradishes":"horseradish",
"horseshits":"horseshit",
"horseshoed":"horseshoe",
"horseshoeing":"horseshoe",
"horseshoes":"horseshoe",
"horseshoers":"horseshoer",
"horseshoeses":"horseshoes",
"horseweeds":"horseweed",
"horsewhipped":"horsewhip",
"horsewhipping":"horsewhip",
"horsewhips":"horsewhip",
"horsewomen":"horsewoman",
"horsier":"horsey",
"horsiest":"horsey",
"hors_d'oeuvres":"hors_d'oeuvre",
"hortensias":"hortensia",
"horticultures":"horticulture",
"hosannas":"hosanna",
"hosed":"hose",
"hoses":"hose",
"hosing":"hose",
"hosepipes":"hosepipe",
"hospitals":"hospital",
"hospitalisations":"hospitalisation",
"hospitalities":"hospitality",
"hospitalizations":"hospitalization",
"hospitalized":"hospitalize",
"hospitalizing":"hospitalize",
"hosted":"host",
"hosting":"host",
"hosts":"host",
"hostas":"hosta",
"hostaceaes":"hostaceae",
"hostages":"hostage",
"hostels":"hostel",
"hostellers":"hosteller",
"hostelries":"hostelry",
"hostessed":"hostess",
"hostesses":"hostess",
"hostessing":"hostess",
"hostilities":"hostility",
"hostlers":"hostler",
"hotted":"hot",
"hotter":"hot",
"hottest":"hot",
"hotting":"hot",
"hotbeds":"hotbed",
"hotcakes":"hotcake",
"hotchpotches":"hotchpotch",
"hotdogs":"hotdog",
"hotei-chikus":"hotei-chiku",
"hotels":"hotel",
"hotel-casinos":"hotel-casino",
"hoteliers":"hotelier",
"hotelkeepers":"hotelkeeper",
"hotelmen":"hotelman",
"hotfooted":"hotfoot",
"hotfooting":"hotfoot",
"hotfoots":"hotfoot",
"hoths":"hoth",
"hotheads":"hothead",
"hothouses":"hothouse",
"hothrs":"hothr",
"hotnesses":"hotness",
"hotplates":"hotplate",
"hotshots":"hotshot",
"Hottentots":"Hottentot",
"hottonias":"hottonia",
"houheres":"houhere",
"hounded":"hound",
"hounding":"hound",
"hounds":"hound",
"hours":"hour",
"hourglasses":"hourglass",
"houris":"houri",
"housed":"house",
"houses":"house",
"housing":"house",
"housebreaking":"housebreak",
"housebroke":"housebreak",
"housebroken":"housebreak",
"housebreakers":"housebreaker",
"housebreakings":"housebreaking",
"housebuilders":"housebuilder",
"housecleaned":"houseclean",
"housecleaning":"houseclean",
"housecleans":"houseclean",
"housecoats":"housecoat",
"houseflies":"housefly",
"housefuls":"houseful",
"houseguests":"houseguest",
"households":"household",
"householders":"householder",
"housekeeping":"housekeep",
"housekept":"housekeep",
"housekeepers":"housekeeper",
"housekeepings":"housekeeping",
"houseled":"housel",
"houseling":"housel",
"houselled":"housel",
"houselling":"housel",
"housels":"housel",
"housemaids":"housemaid",
"housemen":"houseman",
"housetops":"housetop",
"housewives":"housewife",
"houseworks":"housework",
"housewreckers":"housewrecker",
"housings":"housing",
"housingses":"housings",
"houttuynias":"houttuynia",
"hoveas":"hovea",
"hovels":"hovel",
"hovered":"hover",
"hovering":"hover",
"hovers":"hover",
"hows":"how",
"how-do-you-dos":"how-do-you-do",
"howdies":"howdy",
"howitzers":"howitzer",
"howled":"howl",
"howling":"howl",
"howls":"howl",
"howlers":"howler",
"howlings":"howling",
"hoys":"hoy",
"hoydens":"hoyden",
"hoydenisms":"hoydenism",
"hps":"hp",
"hqs":"hq",
"hrs":"hr",
"hs1s":"hs1",
"hs2s":"hs2",
"hsians":"hsian",
"htlv-1s":"htlv-1",
"htmls":"html",
"https":"http",
"hualapais":"hualapai",
"hualpais":"hualpai",
"huamachils":"huamachil",
"huaraches":"huarache",
"huaracheses":"huaraches",
"hubs":"hub",
"hubble-bubbles":"hubble-bubble",
"hubbubs":"hubbub",
"hubbies":"hubby",
"hucks":"huck",
"huckabacks":"huckaback",
"huckleberries":"huckleberry",
"huckstered":"huckster",
"huckstering":"huckster",
"hucksters":"huckster",
"huds":"hud",
"huddled":"huddle",
"huddles":"huddle",
"huddling":"huddle",
"hudsons":"hudson",
"hudsonias":"hudsonia",
"hued":"hue",
"hueing":"hue",
"hues":"hue",
"huffed":"huff",
"huffing":"huff",
"huffs":"huff",
"huffings":"huffing",
"huffishnesses":"huffishness",
"huffier":"huffy",
"huffiest":"huffy",
"hugged":"hug",
"hugging":"hug",
"hugs":"hug",
"huger":"huge",
"hugest":"huge",
"hugger-muggered":"hugger-mugger",
"hugger-muggering":"hugger-mugger",
"hugger-muggers":"hugger-mugger",
"huggermuggered":"huggermugger",
"huggermuggering":"huggermugger",
"huggermuggers":"huggermugger",
"huggings":"hugging",
"hugos":"hugo",
"hugueninias":"hugueninia",
"huisaches":"huisache",
"huitres":"huitre",
"hulas":"hula",
"hula-hulas":"hula-hula",
"hulked":"hulk",
"hulking":"hulk",
"hulks":"hulk",
"hulled":"hull",
"hulling":"hull",
"hulls":"hull",
"hullaballoos":"hullaballoo",
"hullabaloos":"hullabaloo",
"hullos":"hullo",
"hulseas":"hulsea",
"hummed":"hum",
"humming":"hum",
"hums":"hum",
"humans":"human",
"realised":"realise",
"humanisations":"humanisation",
"humanisms":"humanism",
"humanitarians":"humanitarian",
"humanitarianisms":"humanitarianism",
"humanitieses":"humanities",
"humanities":"humanity",
"humanizations":"humanization",
"humanized":"humanize",
"humanizes":"humanize",
"humanizing":"humanize",
"humankinds":"humankind",
"humannesses":"humanness",
"humanoids":"humanoid",
"humbled":"humble",
"humbler":"humble",
"humblest":"humble",
"humbling":"humble",
"humblebees":"humblebee",
"humblenesses":"humbleness",
"humblings":"humbling",
"humbugged":"humbug",
"humbugging":"humbug",
"humbugs":"humbug",
"humeri":"humerus",
"humermeri":"humerus",
"humidified":"humidify",
"humidifies":"humidify",
"humidifying":"humidify",
"humidities":"humidity",
"humidnesses":"humidness",
"humiliated":"humiliate",
"humiliates":"humiliate",
"humiliating":"humiliate",
"humiliations":"humiliation",
"humilities":"humility",
"hummers":"hummer",
"hummings":"humming",
"hummocks":"hummock",
"humored":"humor",
"humoring":"humor",
"humors":"humor",
"humorings":"humoring",
"humorists":"humorist",
"humorousnesses":"humorousness",
"humoured":"humour",
"humouring":"humour",
"humours":"humour",
"humourists":"humourist",
"humped":"hump",
"humping":"hump",
"humps":"hump",
"humpbacks":"humpback",
"humphed":"humph",
"humphing":"humph",
"humpier":"humpy",
"humpies":"humpy",
"humpiest":"humpy",
"humuluses":"humulus",
"huns":"hun",
"hunched":"hunch",
"hunches":"hunch",
"hunching":"hunch",
"hunchbacks":"hunchback",
"hundreds":"hundred",
"hundred-percenters":"hundred-percenter",
"hundredths":"hundredth",
"hundredweights":"hundredweight",
"Hungarians":"Hungarian",
"hungaries":"hungary",
"hungered":"hunger",
"hungering":"hunger",
"hungers":"hunger",
"hungrinesses":"hungriness",
"hungrier":"hungry",
"hungriest":"hungry",
"hunks":"hunk",
"hunkered":"hunker",
"hunkering":"hunker",
"hunnemannias":"hunnemannia",
"hunted":"hunt",
"hunting":"hunt",
"hunts":"hunt",
"hunters":"hunter",
"huntings":"hunting",
"huntsmen":"huntsman",
"hurdled":"hurdle",
"hurdles":"hurdle",
"hurdling":"hurdle",
"hurdlers":"hurdler",
"hurdleses":"hurdles",
"hurdlings":"hurdling",
"hurdy-gurdies":"hurdy-gurdy",
"hurled":"hurl",
"hurling":"hurl",
"hurls":"hurl",
"hurlers":"hurler",
"hurleys":"hurley",
"hurly-burlies":"hurly-burly",
"hurons":"huron",
"hurrahed":"hurrah",
"hurrahing":"hurrah",
"hurrahs":"hurrah",
"hurrayed":"hurray",
"hurraying":"hurray",
"hurrays":"hurray",
"hurricanes":"hurricane",
"hurriednesses":"hurriedness",
"hurried":"hurry",
"hurries":"hurry",
"hurrying":"hurry",
"hurry-skurried":"hurry-skurry",
"hurry-skurries":"hurry-skurry",
"hurry-skurrying":"hurry-skurry",
"hurryings":"hurrying",
"hurted":"hurt",
"hurting":"hurt",
"hurts":"hurt",
"hurtings":"hurting",
"hurtled":"hurtle",
"hurtles":"hurtle",
"hurtling":"hurtle",
"husbanded":"husband",
"husbanding":"husband",
"husbands":"husband",
"husbandmen":"husbandman",
"husbandries":"husbandry",
"hushed":"hush",
"hushes":"hush",
"hushing":"hush",
"husked":"husk",
"husking":"husk",
"husks":"husk",
"huskinesses":"huskiness",
"huskings":"husking",
"huskier":"husky",
"huskies":"husky",
"huskiest":"husky",
"hussies":"hussy",
"hustled":"hustle",
"hustles":"hustle",
"hustling":"hustle",
"hustlers":"hustler",
"huts":"hut",
"hutted":"hut",
"hutting":"hut",
"hutches":"hutch",
"hutus":"hutu",
"hutzpas":"hutzpa",
"huxleys":"huxley",
"hyacinths":"hyacinth",
"hyacinthaceaes":"hyacinthaceae",
"hyacinthoideses":"hyacinthoides",
"hyaenas":"hyaena",
"hyaenidaes":"hyaenidae",
"hyalins":"hyalin",
"hyalines":"hyaline",
"hyalinized":"hyalinize",
"hyalinizing":"hyalinize",
"hyalophoras":"hyalophora",
"hyalospermas":"hyalosperma",
"hyalospongiaes":"hyalospongiae",
"hybrids":"hybrid",
"hybridisations":"hybridisation",
"hybridists":"hybridist",
"hybridizations":"hybridization",
"hybridized":"hybridize",
"hybridizes":"hybridize",
"hybridizing":"hybridize",
"hybridizings":"hybridizing",
"hydnaceaes":"hydnaceae",
"hydnocarpuses":"hydnocarpus",
"hydnums":"hydnum",
"hydrae":"hydra",
"hydras":"hydra",
"hydrangeas":"hydrangea",
"hydrangeaceaes":"hydrangeaceae",
"hydrants":"hydrant",
"hydrastises":"hydrastis",
"hydrated":"hydrate",
"hydrating":"hydrate",
"hydraulicses":"hydraulics",
"hydrillas":"hydrilla",
"hydros":"hydro",
"hydrobateses":"hydrobates",
"hydrobatidaes":"hydrobatidae",
"hydrocephaluses":"hydrocephalus",
"hydrocephalies":"hydrocephaly",
"hydrocharidaceaes":"hydrocharidaceae",
"hydrocharises":"hydrocharis",
"hydrocharitaceaes":"hydrocharitaceae",
"hydrochlorothiazides":"hydrochlorothiazide",
"hydrochoeridaes":"hydrochoeridae",
"hydrochoeruses":"hydrochoerus",
"hydrocortisones":"hydrocortisone",
"hydrodamalises":"hydrodamalis",
"hydrodiurils":"hydrodiuril",
"hydrodynamicses":"hydrodynamics",
"hydrofoils":"hydrofoil",
"hydrogens":"hydrogen",
"hydrogenated":"hydrogenate",
"hydrogenating":"hydrogenate",
"hydroids":"hydroid",
"hydrokineticses":"hydrokinetics",
"hydroliths":"hydrolith",
"hydrolyses":"hydrolysis",
"hydrolyzed":"hydrolyze",
"hydrolyzes":"hydrolyze",
"hydrolyzing":"hydrolyze",
"hydromanteses":"hydromantes",
"hydromedusae":"hydromedusa",
"hydromedusas":"hydromedusa",
"hydrometers":"hydrometer",
"hydrometries":"hydrometry",
"hydromyinaes":"hydromyinae",
"hydromyses":"hydromys",
"hydropathies":"hydropathy",
"hydrophidaes":"hydrophidae",
"hydrophobias":"hydrophobia",
"hydrophyllaceaes":"hydrophyllaceae",
"hydrophyllums":"hydrophyllum",
"hydrophytes":"hydrophyte",
"hydroplanes":"hydroplane",
"hydroponicses":"hydroponics",
"hydrotherapies":"hydrotherapy",
"hydroxides":"hydroxide",
"hydroxybenzenes":"hydroxybenzene",
"hydroxyls":"hydroxyl",
"hydroxytetracyclines":"hydroxytetracycline",
"hydrozoas":"hydrozoa",
"hydrozoans":"hydrozoan",
"hyemoschuses":"hyemoschus",
"hyenas":"hyena",
"hygienes":"hygiene",
"hygienicses":"hygienics",
"hygrocybes":"hygrocybe",
"hygrophoraceaes":"hygrophoraceae",
"hygrophoruses":"hygrophorus",
"hygrotramas":"hygrotrama",
"hylas":"hyla",
"hylactophrynes":"hylactophryne",
"hylidaes":"hylidae",
"hylobateses":"hylobates",
"hylobatidaes":"hylobatidae",
"hylocereuses":"hylocereus",
"hylocichlas":"hylocichla",
"hylophylaxes":"hylophylax",
"hymens":"hymen",
"hymenaeas":"hymenaea",
"hymenia":"hymenium",
"hynia":"hymenium",
"hyniums":"hymenium",
"hymenogastraleses":"hymenogastrales",
"hymenomyceteses":"hymenomycetes",
"hymenophyllaceaes":"hymenophyllaceae",
"hymenophyllums":"hymenophyllum",
"hymenopteras":"hymenoptera",
"hymenopterans":"hymenopteran",
"hymenopterons":"hymenopteron",
"hymned":"hymn",
"hymning":"hymn",
"hymns":"hymn",
"hymnals":"hymnal",
"hymnaries":"hymnary",
"hymnbooks":"hymnbook",
"hymnenopters":"hymnenopter",
"hymnodies":"hymnody",
"hynerpetons":"hynerpeton",
"hyoids":"hyoid",
"hyoscines":"hyoscine",
"hyoscyamuses":"hyoscyamus",
"hypanthia":"hypanthium",
"hyped":"hype",
"hypes":"hype",
"hyping":"hype",
"hypenteliums":"hypentelium",
"hyperadrenalisms":"hyperadrenalism",
"hyperadrenocorticisms":"hyperadrenocorticism",
"hyperaemias":"hyperaemia",
"hyperaldosteronisms":"hyperaldosteronism",
"hyperbolas":"hyperbola",
"hyperboles":"hyperbole",
"hyperbolized":"hyperbolize",
"hyperbolizes":"hyperbolize",
"hyperbolizing":"hyperbolize",
"hypercapnias":"hypercapnia",
"hypercarbias":"hypercarbia",
"hyperemias":"hyperemia",
"hypericaceaes":"hypericaceae",
"hypericaleses":"hypericales",
"hypericums":"hypericum",
"hyperlipaemias":"hyperlipaemia",
"hyperlipemias":"hyperlipemia",
"hyperlipidaemias":"hyperlipidaemia",
"hyperlipidemias":"hyperlipidemia",
"hypermastiginas":"hypermastigina",
"hypermedias":"hypermedia",
"hypermenorrheas":"hypermenorrhea",
"hypermetropias":"hypermetropia",
"hypermetropies":"hypermetropy",
"hypernyms":"hypernym",
"hypernymies":"hypernymy",
"hyperoartias":"hyperoartia",
"hyperodontidaes":"hyperodontidae",
"hyperoglyphes":"hyperoglyphe",
"hyperoodons":"hyperoodon",
"hyperopias":"hyperopia",
"hyperostoses":"hyperostosis",
"hyperotretas":"hyperotreta",
"hyperpiesias":"hyperpiesia",
"hyperpieses":"hyperpiesis",
"hypertensins":"hypertensin",
"hypertensions":"hypertension",
"hyperthermias":"hyperthermia",
"hyperthermies":"hyperthermy",
"hyperthyroidisms":"hyperthyroidism",
"hypertrophied":"hypertrophy",
"hypertrophies":"hypertrophy",
"hypertrophying":"hypertrophy",
"hypervelocities":"hypervelocity",
"hyphae":"hypha",
"hyphantrias":"hyphantria",
"hyphened":"hyphen",
"hyphening":"hyphen",
"hyphens":"hyphen",
"hyphenated":"hyphenate",
"hyphenates":"hyphenate",
"hyphenating":"hyphenate",
"hyphenations":"hyphenation",
"hypnoses":"hypnosis",
"hypnotics":"hypnotic",
"hypnotisms":"hypnotism",
"hypnotists":"hypnotist",
"hypnotized":"hypnotize",
"hypnotizes":"hypnotize",
"hypnotizing":"hypnotize",
"hypnotizers":"hypnotizer",
"hypos":"hypo",
"hypoadrenalisms":"hypoadrenalism",
"hypoadrenocorticisms":"hypoadrenocorticism",
"hypoblasts":"hypoblast",
"hypocapnias":"hypocapnia",
"hypochaerises":"hypochaeris",
"hypochoerises":"hypochoeris",
"hypochondrias":"hypochondria",
"hypochondriases":"hypochondriasis",
"hypochondria":"hypochondrium",
"hypocreaceaes":"hypocreaceae",
"hypocrealeses":"hypocreales",
"hypocrisies":"hypocrisy",
"hypocrites":"hypocrite",
"hypodermas":"hypoderma",
"hypodermatidaes":"hypodermatidae",
"hypodermics":"hypodermic",
"hypogastria":"hypogastrium",
"hypogea":"hypogeum",
"hypoglossals":"hypoglossal",
"hyponyms":"hyponym",
"hyponymies":"hyponymy",
"hypopachuses":"hypopachus",
"hypophysectomies":"hypophysectomy",
"hypophyses":"hypophysis",
"hypopityses":"hypopitys",
"hyposensitized":"hyposensitize",
"hyposensitizing":"hyposensitize",
"hypostases":"hypostasis",
"hypostasized":"hypostasize",
"hypostasizing":"hypostasize",
"hypostatisations":"hypostatisation",
"hypostatizations":"hypostatization",
"hypothalami":"hypothalamus",
"hypothecated":"hypothecate",
"hypothecates":"hypothecate",
"hypothecating":"hypothecate",
"hypotheses":"hypothesis",
"hypothesized":"hypothesize",
"hypothesizes":"hypothesize",
"hypothesizing":"hypothesize",
"hypovitaminoses":"hypovitaminosis",
"hypoxidaceaes":"hypoxidaceae",
"hypoxes":"hypoxis",
"hypsiglenas":"hypsiglena",
"hypsiprymnodons":"hypsiprymnodon",
"hyracoideas":"hyracoidea",
"hyracotheriums":"hyracotherium",
"hyraces":"hyrax",
"hyraxes":"hyrax",
"hyssops":"hyssop",
"hyssopuses":"hyssopus",
"hysterectomized":"hysterectomize",
"hysterectomizing":"hysterectomize",
"hysterectomies":"hysterectomy",
"hysterias":"hysteria",
"hysterics":"hysteric",
"hysterotomies":"hysterotomy",
"hystricidaes":"hystricidae",
"hystricomorphas":"hystricomorpha",
"hzs":"hz",
"ious":"i.o.u.",
"iaas":"iaa",
"iaeas":"iaea",
"iambs":"iamb",
"iambi":"iambus",
"iambuses":"iambus",
"iberias":"iberia",
"iberises":"iberis",
"ibexes":"ibex",
"ibices":"ibex",
"ibibios":"ibibio",
"ibises":"ibis",
"ibos":"ibo",
"ibrds":"ibrd",
"ibsens":"ibsen",
"ibuprofens":"ibuprofen",
"icacos":"icaco",
"icaos":"icao",
"ICBMs":"ICBM",
"iced":"ice",
"ices":"ice",
"icing":"ice",
"icebergs":"iceberg",
"iceboats":"iceboat",
"iceboxes":"icebox",
"icebreakers":"icebreaker",
"icecreams":"icecream",
"icehouses":"icehouse",
"icemen":"iceman",
"icepicks":"icepick",
"ichneumons":"ichneumon",
"ichneumonidaes":"ichneumonidae",
"ichors":"ichor",
"ichthyolatries":"ichthyolatry",
"ichthyosaurs":"ichthyosaur",
"ichthyosauruses":"ichthyosaur",
"ichthyosaurias":"ichthyosauria",
"ichthyosauridaes":"ichthyosauridae",
"ichthyosauri":"ichthyosaurus",
"icicles":"icicle",
"icinesses":"iciness",
"icings":"icing",
"ickier":"icky",
"ickiest":"icky",
"icons":"icon",
"iconoclasts":"iconoclast",
"iconographies":"iconography",
"iconostases":"iconostasis",
"icosahedra":"icosahedron",
"icosahedrons":"icosahedron",
"ictaluruses":"ictalurus",
"icterias":"icteria",
"icteridaes":"icteridae",
"icteruses":"icterus",
"ictiobuses":"ictiobus",
"ictodosaurias":"ictodosauria",
"ictonyxes":"ictonyx",
"ictuses":"ictus",
"icier":"icy",
"iciest":"icy",
"IDs":"ID",
"idas":"ida",
"idahos":"idaho",
"ideas":"idea",
"ideals":"ideal",
"idealisations":"idealisation",
"idealisms":"idealism",
"idealists":"idealist",
"idealities":"ideality",
"idealizations":"idealization",
"idealized":"idealize",
"idealizes":"idealize",
"idealizing":"idealize",
"ideated":"ideate",
"ideates":"ideate",
"ideating":"ideate",
"ideata":"ideatum",
"ideesfixes":"ideefixe",
"identicalnesses":"identicalness",
"identifications":"identification",
"identified":"identify",
"identifies":"identify",
"identifying":"identify",
"identikits":"identikit",
"identities":"identity",
"ideograms":"ideogram",
"ideographs":"ideograph",
"ideologists":"ideologist",
"ideologues":"ideologue",
"ideologies":"ideology",
"idesias":"idesia",
"idiocies":"idiocy",
"idiolatries":"idiolatry",
"idioms":"idiom",
"idiopathies":"idiopathy",
"idiosyncrasies":"idiosyncrasy",
"idiots":"idiot",
"idled":"idle",
"idler":"idle",
"idlest":"idle",
"idling":"idle",
"idlenesses":"idleness",
"idlers":"idler",
"idlings":"idling",
"idocrases":"idocrase",
"idols":"idol",
"idolaters":"idolater",
"idolatries":"idolatry",
"idolisations":"idolisation",
"idolizations":"idolization",
"idolized":"idolize",
"idolizes":"idolize",
"idolizing":"idolize",
"idps":"idp",
"iduns":"idun",
"idyls":"idyl",
"idylls":"idyll",
"ifs":"if",
"ifcs":"ifc",
"iffier":"iffy",
"iffiest":"iffy",
"igs":"ig",
"ibo":"igbo",
"igbos":"igbo",
"igloos":"igloo",
"iglus":"iglu",
"ignited":"ignite",
"ignites":"ignite",
"igniting":"ignite",
"igniters":"igniter",
"ignitions":"ignition",
"ignitors":"ignitor",
"ignominiousnesses":"ignominiousness",
"ignominies":"ignominy",
"ignoramuses":"ignoramus",
"ignorantnesses":"ignorantness",
"ignored":"ignore",
"ignores":"ignore",
"ignoring":"ignore",
"igorots":"igorot",
"igorrorote":"igorrote",
"igorrotes":"igorrote",
"iguanas":"iguana",
"iguanias":"iguania",
"iguanids":"iguanid",
"iguanidaes":"iguanidae",
"iguanodontidaes":"iguanodontidae",
"iguassus":"iguassu",
"iguazus":"iguazu",
"iis":"ii",
"iiis":"iii",
"ikes":"ike",
"ikons":"ikon",
"ilamas":"ilama",
"ilang-ilangs":"ilang-ilang",
"ileostomies":"ileostomy",
"ilea":"ileum",
"ilexes":"ilex",
"iliamnas":"iliamna",
"ilions":"ilion",
"ilia":"ilium",
"iliums":"ilium",
"ills":"ill",
"ill-breedings":"ill-breeding",
"ill-treated":"ill-treat",
"ill-treating":"ill-treat",
"ill-treats":"ill-treat",
"ill-treatments":"ill-treatment",
"ill-usages":"ill-usage",
"ill-used":"ill-use",
"ill-uses":"ill-use",
"ill-using":"ill-use",
"illations":"illation",
"illecebrums":"illecebrum",
"illegals":"illegal",
"illegalities":"illegality",
"illegalized":"illegalize",
"illegalizes":"illegalize",
"illegalizing":"illegalize",
"illegitimacies":"illegitimacy",
"illegitimates":"illegitimate",
"illiciums":"illicium",
"illinoises":"illinois",
"illiteracies":"illiteracy",
"illiterates":"illiterate",
"illnesses":"illness",
"illogics":"illogic",
"illogicalities":"illogicality",
"illogicalnesses":"illogicalness",
"illumed":"illume",
"illumes":"illume",
"illuming":"illume",
"illuminances":"illuminance",
"illuminated":"illuminate",
"illuminates":"illuminate",
"illuminating":"illuminate",
"illuminations":"illumination",
"illumined":"illumine",
"illumines":"illumine",
"illumining":"illumine",
"illusions":"illusion",
"illusionists":"illusionist",
"illustrated":"illustrate",
"illustrates":"illustrate",
"illustrating":"illustrate",
"illustrations":"illustration",
"illustrators":"illustrator",
"illuviated":"illuviate",
"illuviating":"illuviate",
"ilos":"ilo",
"ilocanos":"ilocano",
"imaged":"image",
"images":"image",
"imaging":"image",
"imageries":"imagery",
"imaginations":"imagination",
"imaginativenesses":"imaginativeness",
"imagined":"imagine",
"imagines":"imagine",
"imagining":"imagine",
"imagings":"imaging",
"imagoes":"imago",
"imagos":"imago",
"imams":"imam",
"imaums":"imaum",
"imavates":"imavate",
"imbalances":"imbalance",
"imbaubas":"imbauba",
"imbeciles":"imbecile",
"imbecilities":"imbecility",
"imbedded":"imbed",
"imbedding":"imbed",
"imbeds":"imbed",
"imbibed":"imbibe",
"imbibes":"imbibe",
"imbibing":"imbibe",
"imbibers":"imbiber",
"imbibings":"imbibing",
"imbibitions":"imbibition",
"imbrications":"imbrication",
"imbroglios":"imbroglio",
"imbrued":"imbrue",
"imbrues":"imbrue",
"imbruing":"imbrue",
"imbruted":"imbrute",
"imbruting":"imbrute",
"imbued":"imbue",
"imbues":"imbue",
"imbuing":"imbue",
"imfs":"imf",
"imidazoles":"imidazole",
"iminazoles":"iminazole",
"imipramines":"imipramine",
"imitated":"imitate",
"imitates":"imitate",
"imitating":"imitate",
"imitations":"imitation",
"imitators":"imitator",
"immaculatenesses":"immaculateness",
"immanences":"immanence",
"immanencies":"immanency",
"immaterialities":"immateriality",
"immaterialized":"immaterialize",
"immaterializes":"immaterialize",
"immaterializing":"immaterialize",
"immaturenesses":"immatureness",
"immaturities":"immaturity",
"immediacies":"immediacy",
"immediatenesses":"immediateness",
"immensenesses":"immenseness",
"immensities":"immensity",
"immerged":"immerge",
"immerging":"immerge",
"immersed":"immerse",
"immerses":"immerse",
"immersing":"immerse",
"immersions":"immersion",
"immigrants":"immigrant",
"immigrated":"immigrate",
"immigrating":"immigrate",
"immigrations":"immigration",
"imminences":"imminence",
"imminencies":"imminency",
"immingled":"immingle",
"immingles":"immingle",
"immingling":"immingle",
"immixed":"immix",
"immixing":"immix",
"immixt":"immix",
"immobilisations":"immobilisation",
"immobilities":"immobility",
"immobilizations":"immobilization",
"immobilized":"immobilize",
"immobilizes":"immobilize",
"immobilizing":"immobilize",
"immobilizings":"immobilizing",
"immoderatenesses":"immoderateness",
"immoderations":"immoderation",
"immodesties":"immodesty",
"immolated":"immolate",
"immolating":"immolate",
"immoralities":"immorality",
"immoralized":"immoralize",
"immoralizing":"immoralize",
"immortals":"immortal",
"immortalized":"immortalize",
"immortalizes":"immortalize",
"immortalizing":"immortalize",
"immortelles":"immortelle",
"immovabilities":"immovability",
"immovables":"immovable",
"immovablenesses":"immovableness",
"immunisations":"immunisation",
"immunities":"immunity",
"immunizations":"immunization",
"immunized":"immunize",
"immunizes":"immunize",
"immunizing":"immunize",
"immunochemistries":"immunochemistry",
"immunoglobulins":"immunoglobulin",
"immunologists":"immunologist",
"immunologies":"immunology",
"immunosuppressants":"immunosuppressant",
"immured":"immure",
"immures":"immure",
"immuring":"immure",
"immurements":"immurement",
"immutabilities":"immutability",
"immutablenesses":"immutableness",
"imos":"imo",
"imped":"imp",
"imping":"imp",
"imps":"imp",
"impacted":"impact",
"impacting":"impact",
"impacts":"impact",
"impactions":"impaction",
"impaired":"impair",
"impairing":"impair",
"impairs":"impair",
"impairments":"impairment",
"impalas":"impala",
"impaled":"impale",
"impales":"impale",
"impaling":"impale",
"impalpabilities":"impalpability",
"impaneled":"impanel",
"impaneling":"impanel",
"impanelled":"impanel",
"impanelling":"impanel",
"impanells":"impanel",
"impanels":"impanel",
"imparadised":"imparadise",
"imparadising":"imparadise",
"imparities":"imparity",
"imparted":"impart",
"imparting":"impart",
"imparts":"impart",
"impartations":"impartation",
"impartialities":"impartiality",
"impartings":"imparting",
"impasses":"impasse",
"impassioned":"impassion",
"impassioning":"impassion",
"impassivenesses":"impassiveness",
"impassivities":"impassivity",
"impasted":"impaste",
"impastes":"impaste",
"impasting":"impaste",
"impatiences":"impatience",
"impawned":"impawn",
"impawning":"impawn",
"impeached":"impeach",
"impeaches":"impeach",
"impeaching":"impeach",
"impeachabilities":"impeachability",
"impeachments":"impeachment",
"impearled":"impearl",
"impearling":"impearl",
"impecuniousnesses":"impecuniousness",
"impedances":"impedance",
"impeded":"impede",
"impedes":"impede",
"impeding":"impede",
"impedimenta":"impediment",
"impediments":"impediment",
"impedimentas":"impedimenta",
"impelled":"impel",
"impelling":"impel",
"impels":"impel",
"impellers":"impeller",
"impended":"impend",
"impending":"impend",
"impendences":"impendence",
"impendencies":"impendency",
"impenetrabilities":"impenetrability",
"impenetrablenesses":"impenetrableness",
"impenitences":"impenitence",
"impenitencies":"impenitency",
"imperatives":"imperative",
"imperativenesses":"imperativeness",
"imperfects":"imperfect",
"imperfectabilities":"imperfectability",
"imperfectibilities":"imperfectibility",
"imperfections":"imperfection",
"imperfectives":"imperfective",
"imperfectnesses":"imperfectness",
"imperials":"imperial",
"imperiled":"imperil",
"imperiling":"imperil",
"imperilled":"imperil",
"imperilling":"imperil",
"imperiousnesses":"imperiousness",
"imperishabilities":"imperishability",
"imperishingnesses":"imperishingness",
"imperia":"imperium",
"imperiria":"imperium",
"imperiums":"imperium",
"impermanences":"impermanence",
"impermanencies":"impermanency",
"impermeabilities":"impermeability",
"impermeablenesses":"impermeableness",
"impersonals":"impersonal",
"impersonalized":"impersonalize",
"impersonalizing":"impersonalize",
"impersonated":"impersonate",
"impersonates":"impersonate",
"impersonating":"impersonate",
"impersonations":"impersonation",
"impersonators":"impersonator",
"impertinences":"impertinence",
"impertinencies":"impertinency",
"imperturbabilities":"imperturbability",
"imperturbablenesses":"imperturbableness",
"imperviousnesses":"imperviousness",
"impetrated":"impetrate",
"impetrating":"impetrate",
"impetuosities":"impetuosity",
"impetuousnesses":"impetuousness",
"impetuses":"impetus",
"impies":"impi",
"impieties":"impiety",
"impinged":"impinge",
"impinges":"impinge",
"impinging":"impinge",
"impingements":"impingement",
"impingings":"impinging",
"impiousnesses":"impiousness",
"impishnesses":"impishness",
"implanted":"implant",
"implanting":"implant",
"implants":"implant",
"implausibilities":"implausibility",
"implausiblenesses":"implausibleness",
"impleaded":"implead",
"impleading":"implead",
"impled":"implead",
"implemented":"implement",
"implementing":"implement",
"implements":"implement",
"implementations":"implementation",
"implicated":"implicate",
"implicates":"implicate",
"implicating":"implicate",
"implicatings":"implicating",
"implications":"implication",
"imploded":"implode",
"implodes":"implode",
"imploding":"implode",
"implored":"implore",
"implores":"implore",
"imploring":"implore",
"implied":"imply",
"implies":"imply",
"implying":"imply",
"impolicies":"impolicy",
"imponed":"impone",
"imponing":"impone",
"imported":"import",
"importing":"import",
"imports":"import",
"importances":"importance",
"importations":"importation",
"importings":"importing",
"importuned":"importune",
"importunes":"importune",
"importuning":"importune",
"importunities":"importunity",
"imposed":"impose",
"imposes":"impose",
"imposing":"impose",
"impositions":"imposition",
"impossibilities":"impossibility",
"impossiblenesses":"impossibleness",
"imposts":"impost",
"imposters":"imposter",
"impostors":"impostor",
"impostures":"imposture",
"impotences":"impotence",
"impotencies":"impotency",
"impounded":"impound",
"impounding":"impound",
"impounds":"impound",
"impoundings":"impounding",
"impoundments":"impoundment",
"impoverished":"impoverish",
"impoverishes":"impoverish",
"impoverishing":"impoverish",
"impoverishments":"impoverishment",
"impracticabilities":"impracticability",
"impracticablenesses":"impracticableness",
"imprecated":"imprecate",
"imprecates":"imprecate",
"imprecating":"imprecate",
"imprecations":"imprecation",
"imprecisenesses":"impreciseness",
"imprecisions":"imprecision",
"impregnabilities":"impregnability",
"impregnated":"impregnate",
"impregnates":"impregnate",
"impregnating":"impregnate",
"impregnations":"impregnation",
"impresas":"impresa",
"imprese":"impresa",
"impresarios":"impresario",
"impressed":"impress",
"impresses":"impress",
"impressing":"impress",
"impressions":"impression",
"impressivenesses":"impressiveness",
"impressments":"impressment",
"imprimaturs":"imprimatur",
"imprinted":"imprint",
"imprinting":"imprint",
"imprints":"imprint",
"imprisoned":"imprison",
"imprisoning":"imprison",
"imprisons":"imprison",
"imprisonments":"imprisonment",
"improbabilities":"improbability",
"improbablenesses":"improbableness",
"improbities":"improbity",
"impromptus":"impromptu",
"impropernesses":"improperness",
"improprieties":"impropriety",
"improved":"improve",
"improves":"improve",
"improving":"improve",
"improvements":"improvement",
"improvers":"improver",
"improvidences":"improvidence",
"improvisations":"improvisation",
"improvised":"improvise",
"improvises":"improvise",
"improvising":"improvise",
"imprudences":"imprudence",
"impudences":"impudence",
"impugned":"impugn",
"impugning":"impugn",
"impuissances":"impuissance",
"impulses":"impulse",
"impulsions":"impulsion",
"impunities":"impunity",
"impurenesses":"impureness",
"impurities":"impurity",
"imputed":"impute",
"imputes":"impute",
"imputing":"impute",
"imurans":"imuran",
"ins":"in",
"in-baskets":"in-basket",
"in-laws":"in-law",
"in-migrated":"in-migrate",
"in-migrating":"in-migrate",
"in-migrations":"in-migration",
"in-trays":"in-tray",
"inabilities":"inability",
"inaccessibilities":"inaccessibility",
"inaccuracies":"inaccuracy",
"inachises":"inachis",
"inactions":"inaction",
"inactivated":"inactivate",
"inactivates":"inactivate",
"inactivating":"inactivate",
"inactivations":"inactivation",
"inactivenesses":"inactiveness",
"inactivities":"inactivity",
"inadequacies":"inadequacy",
"inadequatenesses":"inadequateness",
"inadvertences":"inadvertence",
"inadvertencies":"inadvertency",
"inamoratas":"inamorata",
"inamoratos":"inamorato",
"inanimatenesses":"inanimateness",
"inanitions":"inanition",
"inanities":"inanity",
"inappositenesses":"inappositeness",
"inappropriatenesses":"inappropriateness",
"inaptnesses":"inaptness",
"inarched":"inarch",
"inarching":"inarch",
"inattentivenesses":"inattentiveness",
"inaudibilities":"inaudibility",
"inaudiblenesses":"inaudibleness",
"inaugurals":"inaugural",
"inaugurated":"inaugurate",
"inaugurates":"inaugurate",
"inaugurating":"inaugurate",
"inaugurations":"inauguration",
"inauspiciousnesses":"inauspiciousness",
"inbreathed":"inbreathe",
"inbreathing":"inbreathe",
"inbred":"inbreed",
"inbreeding":"inbreed",
"inbreeds":"inbreed",
"Incas":"Inca",
"incalescences":"incalescence",
"incandesced":"incandesce",
"incandescing":"incandesce",
"incandescences":"incandescence",
"incapabilities":"incapability",
"incapablenesses":"incapableness",
"incapacitated":"incapacitate",
"incapacitates":"incapacitate",
"incapacitating":"incapacitate",
"incapacities":"incapacity",
"incarcerated":"incarcerate",
"incarcerates":"incarcerate",
"incarcerating":"incarcerate",
"incarcerations":"incarceration",
"incarnadined":"incarnadine",
"incarnadining":"incarnadine",
"incarnated":"incarnate",
"incarnates":"incarnate",
"incarnating":"incarnate",
"incarnations":"incarnation",
"incased":"incase",
"incasing":"incase",
"incasements":"incasement",
"incautions":"incaution",
"incautiousnesses":"incautiousness",
"incendiarisms":"incendiarism",
"incendiaries":"incendiary",
"incensed":"incense",
"incenses":"incense",
"incensing":"incense",
"incensories":"incensory",
"incentives":"incentive",
"incepted":"incept",
"incepting":"incept",
"inceptions":"inception",
"incertitudes":"incertitude",
"incessancies":"incessancy",
"incessantnesses":"incessantness",
"inched":"inch",
"inches":"inch",
"inching":"inch",
"inchworms":"inchworm",
"incidences":"incidence",
"incidents":"incident",
"incidentals":"incidental",
"inciensos":"incienso",
"incinerated":"incinerate",
"incinerates":"incinerate",
"incinerating":"incinerate",
"incipiences":"incipience",
"incipiencies":"incipiency",
"incised":"incise",
"incising":"incise",
"incisions":"incision",
"incisivenesses":"incisiveness",
"incitations":"incitation",
"incited":"incite",
"incites":"incite",
"inciting":"incite",
"incitements":"incitement",
"inciters":"inciter",
"incivilities":"incivility",
"inclemencies":"inclemency",
"inclementnesses":"inclementness",
"inclinations":"inclination",
"inclined":"incline",
"inclines":"incline",
"inclining":"incline",
"inclinings":"inclining",
"inclinometers":"inclinometer",
"inclosed":"inclose",
"incloses":"inclose",
"inclosing":"inclose",
"inclosures":"inclosure",
"included":"include",
"includes":"include",
"including":"include",
"inclusions":"inclusion",
"incognitas":"incognita",
"incognitos":"incognito",
"incoherences":"incoherence",
"incoherencies":"incoherency",
"incomes":"income",
"incomings":"incoming",
"incommoded":"incommode",
"incommodes":"incommode",
"incommoding":"incommode",
"incommodiousnesses":"incommodiousness",
"incommodities":"incommodity",
"incompatibilities":"incompatibility",
"incompatibles":"incompatible",
"incompetences":"incompetence",
"incompetencies":"incompetency",
"incompetents":"incompetent",
"inconceivabilities":"inconceivability",
"inconceivablenesses":"inconceivableness",
"incongruities":"incongruity",
"incongruousnesses":"incongruousness",
"inconsideratenesses":"inconsiderateness",
"inconsiderations":"inconsideration",
"inconsistencies":"inconsistency",
"inconstancies":"inconstancy",
"incontinences":"incontinence",
"incontinencies":"incontinency",
"incontrovertibilities":"incontrovertibility",
"incontrovertiblenesses":"incontrovertibleness",
"inconvenienced":"inconvenience",
"inconveniences":"inconvenience",
"inconveniencing":"inconvenience",
"incorporated":"incorporate",
"incorporates":"incorporate",
"incorporating":"incorporate",
"incorporations":"incorporation",
"incorporealities":"incorporeality",
"incorrectnesses":"incorrectness",
"incorruptions":"incorruption",
"incorruptnesses":"incorruptness",
"increased":"increase",
"increases":"increase",
"increasing":"increase",
"increasers":"increaser",
"incredibilities":"incredibility",
"incrediblenesses":"incredibleness",
"incredulities":"incredulity",
"increments":"increment",
"incriminated":"incriminate",
"incriminates":"incriminate",
"incriminating":"incriminate",
"incriminations":"incrimination",
"incrusted":"incrust",
"incrusting":"incrust",
"incrustations":"incrustation",
"incubated":"incubate",
"incubates":"incubate",
"incubating":"incubate",
"incubations":"incubation",
"incubators":"incubator",
"incubi":"incubus",
"incubuses":"incubus",
"inculcated":"inculcate",
"inculcates":"inculcate",
"inculcating":"inculcate",
"inculcations":"inculcation",
"inculpabilities":"inculpability",
"inculpablenesses":"inculpableness",
"inculpated":"inculpate",
"inculpates":"inculpate",
"inculpating":"inculpate",
"inculpations":"inculpation",
"incumbencies":"incumbency",
"incumbents":"incumbent",
"incumbered":"incumber",
"incumbering":"incumber",
"incumbrances":"incumbrance",
"incurred":"incur",
"incurring":"incur",
"incurs":"incur",
"incurabilities":"incurability",
"incurables":"incurable",
"incurablenesses":"incurableness",
"incursions":"incursion",
"incurvated":"incurvate",
"incurvating":"incurvate",
"incudes":"incus",
"incuses":"incus",
"indabas":"indaba",
"indebtednesses":"indebtedness",
"indecencies":"indecency",
"indecisions":"indecision",
"indecisivenesses":"indecisiveness",
"indecorousnesses":"indecorousness",
"indecorums":"indecorum",
"indefatigabilities":"indefatigability",
"indefatigablenesses":"indefatigableness",
"indefinitenesses":"indefiniteness",
"indefinities":"indefinity",
"indelicacies":"indelicacy",
"indemnifications":"indemnification",
"indemnified":"indemnify",
"indemnifies":"indemnify",
"indemnifying":"indemnify",
"indemnities":"indemnity",
"indented":"indent",
"indenting":"indent",
"indents":"indent",
"indentations":"indentation",
"indentured":"indenture",
"indentures":"indenture",
"indenturing":"indenture",
"independences":"independence",
"independencies":"independency",
"independents":"independent",
"inderals":"inderal",
"indeterminancies":"indeterminancy",
"indeterminatenesses":"indeterminateness",
"indeterminations":"indetermination",
"indexed":"index",
"indexes":"index",
"indexing":"index",
"indices":"index",
"indias":"india",
"indiamen":"indiaman",
"Indians":"Indian",
"indianas":"indiana",
"indianans":"indianan",
"indianapolises":"indianapolis",
"indics":"indic",
"indicants":"indicant",
"indicated":"indicate",
"indicates":"indicate",
"indicating":"indicate",
"indicatings":"indicating",
"indications":"indication",
"indicatives":"indicative",
"indicators":"indicator",
"indicatoridaes":"indicatoridae",
"indicted":"indict",
"indicting":"indict",
"indictabilities":"indictability",
"indictments":"indictment",
"indifferences":"indifference",
"indigences":"indigence",
"indigenousnesses":"indigenousness",
"indigestibilities":"indigestibility",
"indigestiblenesses":"indigestibleness",
"indigestions":"indigestion",
"indignations":"indignation",
"indignities":"indignity",
"indigoes":"indigo",
"indigos":"indigo",
"indigoferas":"indigofera",
"indigotins":"indigotin",
"indisciplines":"indiscipline",
"indiscreetnesses":"indiscreetness",
"indiscretions":"indiscretion",
"indispensabilities":"indispensability",
"indispensables":"indispensable",
"indispensablenesses":"indispensableness",
"indisposed":"indispose",
"indisposes":"indispose",
"indisposing":"indispose",
"indispositions":"indisposition",
"indisputabilities":"indisputability",
"indistinctnesses":"indistinctness",
"indistinguishabilities":"indistinguishability",
"indited":"indite",
"indites":"indite",
"inditing":"indite",
"indiums":"indium",
"individuals":"individual",
"individualisms":"individualism",
"individualities":"individuality",
"individualizations":"individualization",
"individualized":"individualize",
"individualizes":"individualize",
"individualizing":"individualize",
"individuated":"individuate",
"individuating":"individuate",
"individuations":"individuation",
"indo-aryans":"indo-aryan",
"indo-europeans":"indo-european",
"indo-hittites":"indo-hittite",
"indo-iranians":"indo-iranian",
"indocins":"indocin",
"indoctrinated":"indoctrinate",
"indoctrinating":"indoctrinate",
"indolences":"indolence",
"indomethacins":"indomethacin",
"indomitabilities":"indomitability",
"indonesias":"indonesia",
"Indonesians":"Indonesian",
"indorsed":"indorse",
"indorses":"indorse",
"indorsing":"indorse",
"indris":"indri",
"indriidaes":"indriidae",
"indrises":"indris",
"indubitabilities":"indubitability",
"induced":"induce",
"induces":"induce",
"inducing":"induce",
"inducements":"inducement",
"inducers":"inducer",
"inducings":"inducing",
"inducted":"induct",
"inducting":"induct",
"inducts":"induct",
"inductances":"inductance",
"inductions":"induction",
"indued":"indue",
"indues":"indue",
"induing":"indue",
"indulged":"indulge",
"indulges":"indulge",
"indulging":"indulge",
"indulgences":"indulgence",
"indulgencies":"indulgency",
"indulgings":"indulging",
"indurated":"indurate",
"indurating":"indurate",
"indurations":"induration",
"induses":"indus",
"indusia":"indusium",
"industrials":"industrial",
"industrialisations":"industrialisation",
"industrialists":"industrialist",
"industrializations":"industrialization",
"industrialized":"industrialize",
"industrializes":"industrialize",
"industrializing":"industrialize",
"industriousnesses":"industriousness",
"industries":"industry",
"indwelling":"indwell",
"indwells":"indwell",
"indwelt":"indwell",
"inebriants":"inebriant",
"inebriated":"inebriate",
"inebriates":"inebriate",
"inebriating":"inebriate",
"inebriations":"inebriation",
"inebrieties":"inebriety",
"ineffectivenesses":"ineffectiveness",
"ineffectualities":"ineffectuality",
"ineffectualnesses":"ineffectualness",
"inefficaciousnesses":"inefficaciousness",
"inefficacies":"inefficacy",
"inefficiencies":"inefficiency",
"ineptitudes":"ineptitude",
"ineptnesses":"ineptness",
"inequalities":"inequality",
"inequities":"inequity",
"inertias":"inertia",
"inessentials":"inessential",
"inevitabilities":"inevitability",
"inevitablenesses":"inevitableness",
"inexactitudes":"inexactitude",
"inexactnesses":"inexactness",
"inexorabilities":"inexorability",
"inexorablenesses":"inexorableness",
"inexpediences":"inexpedience",
"inexpediencies":"inexpediency",
"infallibles":"infallible",
"infamies":"infamy",
"infancies":"infancy",
"infants":"infant",
"infantas":"infanta",
"infantes":"infante",
"infantries":"infantry",
"infantrymen":"infantryman",
"infarcts":"infarct",
"infarctions":"infarction",
"infatuated":"infatuate",
"infatuating":"infatuate",
"infatuations":"infatuation",
"infeasibilities":"infeasibility",
"infected":"infect",
"infecting":"infect",
"infects":"infect",
"infections":"infection",
"infelicities":"infelicity",
"inferred":"infer",
"inferring":"infer",
"infers":"infer",
"inferences":"inference",
"inferiors":"inferior",
"inferiorities":"inferiority",
"infernos":"inferno",
"infertilities":"infertility",
"infested":"infest",
"infesting":"infest",
"infests":"infest",
"infestations":"infestation",
"infidels":"infidel",
"infidelities":"infidelity",
"infields":"infield",
"infiltrated":"infiltrate",
"infiltrates":"infiltrate",
"infiltrating":"infiltrate",
"infinitenesses":"infiniteness",
"infinitesimals":"infinitesimal",
"infinitives":"infinitive",
"infinitudes":"infinitude",
"infinities":"infinity",
"infirmaries":"infirmary",
"infirmities":"infirmity",
"infixed":"infix",
"infixes":"infix",
"infixing":"infix",
"inflamed":"inflame",
"inflames":"inflame",
"inflaming":"inflame",
"inflamings":"inflaming",
"inflammables":"inflammable",
"inflammations":"inflammation",
"inflated":"inflate",
"inflates":"inflate",
"inflating":"inflate",
"inflaters":"inflater",
"inflations":"inflation",
"inflators":"inflator",
"inflected":"inflect",
"inflecting":"inflect",
"inflects":"inflect",
"inflections":"inflection",
"inflexibilities":"inflexibility",
"inflexiblenesses":"inflexibleness",
"inflexions":"inflexion",
"inflicted":"inflict",
"inflicting":"inflict",
"inflicts":"inflict",
"inflictions":"infliction",
"inflorescences":"inflorescence",
"inflows":"inflow",
"influenced":"influence",
"influences":"influence",
"influencing":"influence",
"influenzas":"influenza",
"influxes":"influx",
"infos":"info",
"infolded":"infold",
"infolding":"infold",
"infoldings":"infolding",
"informed":"inform",
"informing":"inform",
"informalities":"informality",
"informants":"informant",
"informations":"information",
"informers":"informer",
"informings":"informing",
"infotainments":"infotainment",
"infracted":"infract",
"infracting":"infract",
"infracts":"infract",
"infractions":"infraction",
"infrareds":"infrared",
"infrastructures":"infrastructure",
"infrequencies":"infrequency",
"infrigidations":"infrigidation",
"infringed":"infringe",
"infringes":"infringe",
"infringing":"infringe",
"infringements":"infringement",
"infundibula":"infundibulum",
"infuriated":"infuriate",
"infuriates":"infuriate",
"infuriating":"infuriate",
"infuriations":"infuriation",
"infused":"infuse",
"infuses":"infuse",
"infusing":"infuse",
"infusions":"infusion",
"infusorias":"infusoria",
"ingathered":"ingather",
"ingathering":"ingather",
"ingathers":"ingather",
"ingatherings":"ingathering",
"ingeniousnesses":"ingeniousness",
"ingenuities":"ingenuity",
"ingenuousnesses":"ingenuousness",
"ingers":"inger",
"ingermen":"ingerman",
"ingested":"ingest",
"ingesting":"ingest",
"ingests":"ingest",
"ingestions":"ingestion",
"inglenooks":"inglenook",
"ingots":"ingot",
"ingrafted":"ingraft",
"ingrafting":"ingraft",
"ingrafts":"ingraft",
"ingrained":"ingrain",
"ingraining":"ingrain",
"ingrains":"ingrain",
"ingrainings":"ingraining",
"ingrates":"ingrate",
"ingratiated":"ingratiate",
"ingratiating":"ingratiate",
"ingratitudes":"ingratitude",
"ingredients":"ingredient",
"ingresses":"ingress",
"ingrians":"ingrian",
"ingroups":"ingroup",
"ingulfed":"ingulf",
"ingulfing":"ingulf",
"ingulfs":"ingulf",
"ingurgitated":"ingurgitate",
"ingurgitates":"ingurgitate",
"ingurgitating":"ingurgitate",
"ingushes":"ingush",
"inhabited":"inhabit",
"inhabiting":"inhabit",
"inhabits":"inhabit",
"inhabitancies":"inhabitancy",
"inhabitants":"inhabitant",
"inhabitations":"inhabitation",
"inhalations":"inhalation",
"inhalators":"inhalator",
"inhaled":"inhale",
"inhales":"inhale",
"inhaling":"inhale",
"inhalers":"inhaler",
"inharmoniousnesses":"inharmoniousness",
"inhered":"inhere",
"inhering":"inhere",
"inherences":"inherence",
"inherencies":"inherency",
"inherited":"inherit",
"inheriting":"inherit",
"inherits":"inherit",
"inheritances":"inheritance",
"inheritors":"inheritor",
"inheritresses":"inheritress",
"inheritrixes":"inheritrix",
"inhibited":"inhibit",
"inhibiting":"inhibit",
"inhibits":"inhibit",
"inhibitions":"inhibition",
"inhumanenesses":"inhumaneness",
"inhumanities":"inhumanity",
"inhumations":"inhumation",
"inhumed":"inhume",
"inhuming":"inhume",
"iniquities":"iniquity",
"initialed":"initial",
"initialing":"initial",
"initialled":"initial",
"initialling":"initial",
"initials":"initial",
"initializations":"initialization",
"initiated":"initiate",
"initiates":"initiate",
"initiating":"initiate",
"initiations":"initiation",
"initiatives":"initiative",
"initiators":"initiator",
"injected":"inject",
"injecting":"inject",
"injects":"inject",
"injectants":"injectant",
"injections":"injection",
"injudiciousnesses":"injudiciousness",
"injuns":"injun",
"injunctions":"injunction",
"injured":"injure",
"injures":"injure",
"injuring":"injure",
"injuriousnesses":"injuriousness",
"injuries":"injury",
"injustices":"injustice",
"inked":"ink",
"inking":"ink",
"inkberries":"inkberry",
"inklings":"inkling",
"inkpads":"inkpad",
"inkpots":"inkpot",
"inkier":"inky",
"inkiest":"inky",
"inlanders":"inlander",
"inlaid":"inlay",
"inlaying":"inlay",
"inlays":"inlay",
"inlets":"inlet",
"inletting":"inlet",
"inmarriages":"inmarriage",
"inmates":"inmate",
"inns":"inn",
"innardses":"innards",
"innersoles":"innersole",
"innervated":"innervate",
"innervating":"innervate",
"innerved":"innerve",
"innerving":"innerve",
"innings":"inning",
"innkeepers":"innkeeper",
"innocences":"innocence",
"innocencies":"innocency",
"innocenses":"innocense",
"innocents":"innocent",
"innovated":"innovate",
"innovates":"innovate",
"innovating":"innovate",
"innovations":"innovation",
"innovators":"innovator",
"innuendoes":"innuendo",
"innuendos":"innuendo",
"innumerablenesses":"innumerableness",
"inocors":"inocor",
"inoculants":"inoculant",
"inoculated":"inoculate",
"inoculates":"inoculate",
"inoculating":"inoculate",
"inoculatings":"inoculating",
"inoculations":"inoculation",
"inocula":"inoculum",
"inopportunenesses":"inopportuneness",
"inordinatenesses":"inordinateness",
"inosculated":"inosculate",
"inosculating":"inosculate",
"inosculations":"inosculation",
"inpatients":"inpatient",
"inpoured":"inpour",
"inpouring":"inpour",
"inpours":"inpour",
"inpourings":"inpouring",
"inputs":"input",
"inputted":"input",
"inputting":"input",
"inquests":"inquest",
"inquietudes":"inquietude",
"inquired":"inquire",
"inquires":"inquire",
"inquiring":"inquire",
"inquirers":"inquirer",
"inquirings":"inquiring",
"inquiries":"inquiry",
"inquisitions":"inquisition",
"inquisitivenesses":"inquisitiveness",
"inquisitors":"inquisitor",
"inquisitors-general":"inquisitor-general",
"inroads":"inroad",
"inrushes":"inrush",
"insalubriousnesses":"insalubriousness",
"insalubrities":"insalubrity",
"insanenesses":"insaneness",
"insanities":"insanity",
"inscribed":"inscribe",
"inscribes":"inscribe",
"inscribing":"inscribe",
"inscriptions":"inscription",
"inscrutabilities":"inscrutability",
"insects":"insect",
"insectas":"insecta",
"insectaria":"insectarium",
"insectariums":"insectarium",
"insectaries":"insectary",
"insecticides":"insecticide",
"insectifuges":"insectifuge",
"insectivoras":"insectivora",
"insecurities":"insecurity",
"inseminated":"inseminate",
"inseminates":"inseminate",
"inseminating":"inseminate",
"insensibilities":"insensibility",
"insensitivenesses":"insensitiveness",
"insensitivities":"insensitivity",
"inseparables":"inseparable",
"inserted":"insert",
"inserting":"insert",
"inserts":"insert",
"insertions":"insertion",
"insets":"inset",
"insetting":"inset",
"insides":"inside",
"insights":"insight",
"insightfulnesses":"insightfulness",
"insignias":"insignia",
"insignificancies":"insignificancy",
"insincerities":"insincerity",
"insinuated":"insinuate",
"insinuates":"insinuate",
"insinuating":"insinuate",
"insinuations":"insinuation",
"insipidities":"insipidity",
"insipidnesses":"insipidness",
"insisted":"insist",
"insisting":"insist",
"insists":"insist",
"insistences":"insistence",
"insistencies":"insistency",
"insistings":"insisting",
"insnared":"insnare",
"insnares":"insnare",
"insnaring":"insnare",
"insolated":"insolate",
"insolating":"insolate",
"insolations":"insolation",
"insoles":"insole",
"insolences":"insolence",
"insolubilized":"insolubilize",
"insolubilizing":"insolubilize",
"insolvents":"insolvent",
"insomniacs":"insomniac",
"insouciances":"insouciance",
"inspanned":"inspan",
"inspanning":"inspan",
"inspans":"inspan",
"inspected":"inspect",
"inspecting":"inspect",
"inspects":"inspect",
"inspections":"inspection",
"inspectors":"inspector",
"inspirations":"inspiration",
"inspired":"inspire",
"inspires":"inspire",
"inspiring":"inspire",
"inspirited":"inspirit",
"inspiriting":"inspirit",
"inspirits":"inspirit",
"inspissated":"inspissate",
"inspissating":"inspissate",
"inspissations":"inspissation",
"instabilities":"instability",
"installed":"install",
"installing":"install",
"instals":"instal",
"installs":"install",
"installations":"installation",
"installings":"installing",
"installments":"installment",
"instalments":"instalment",
"instanced":"instance",
"instances":"instance",
"instancing":"instance",
"instancies":"instancy",
"instants":"instant",
"instantaneousnesses":"instantaneousness",
"instantized":"instantize",
"instantizing":"instantize",
"instarred":"instar",
"instarring":"instar",
"instated":"instate",
"instating":"instate",
"instaurations":"instauration",
"instigants":"instigant",
"instigated":"instigate",
"instigates":"instigate",
"instigating":"instigate",
"instigations":"instigation",
"instigators":"instigator",
"instilled":"instil",
"instilling":"instil",
"instils":"instil",
"instillations":"instillation",
"instillings":"instilling",
"instillments":"instillment",
"instilments":"instilment",
"instincts":"instinct",
"instituted":"institute",
"institutes":"institute",
"instituting":"institute",
"institutions":"institution",
"institutionalized":"institutionalize",
"institutionalizes":"institutionalize",
"institutionalizing":"institutionalize",
"instructed":"instruct",
"instructing":"instruct",
"instructs":"instruct",
"instructions":"instruction",
"instructionses":"instructions",
"instructors":"instructor",
"instrumented":"instrument",
"instrumenting":"instrument",
"instruments":"instrument",
"instrumentals":"instrumental",
"instrumentalists":"instrumentalist",
"instrumentalities":"instrumentality",
"instrumentations":"instrumentation",
"insubordinations":"insubordination",
"insufficiencies":"insufficiency",
"insufflated":"insufflate",
"insufflating":"insufflate",
"insuffllated":"insufflate",
"insulae":"insula",
"insulants":"insulant",
"insularisms":"insularism",
"insularities":"insularity",
"insulated":"insulate",
"insulates":"insulate",
"insulating":"insulate",
"insulations":"insulation",
"insulators":"insulator",
"insulted":"insult",
"insulting":"insult",
"insults":"insult",
"insurances":"insurance",
"insured":"insure",
"insures":"insure",
"insuring":"insure",
"insurers":"insurer",
"insurgencies":"insurgency",
"insurgents":"insurgent",
"insurrections":"insurrection",
"insurrectionaries":"insurrectionary",
"insurrectionists":"insurrectionist",
"intagli":"intaglio",
"intaglioed":"intaglio",
"intaglioing":"intaglio",
"intaglios":"intaglio",
"intakes":"intake",
"intangibilities":"intangibility",
"intangibles":"intangible",
"intangiblenesses":"intangibleness",
"integers":"integer",
"integrals":"integral",
"integrated":"integrate",
"integrates":"integrate",
"integrating":"integrate",
"integratings":"integrating",
"integrations":"integration",
"integrators":"integrator",
"integrities":"integrity",
"intellects":"intellect",
"intellections":"intellection",
"intellectuals":"intellectual",
"intellectualized":"intellectualize",
"intellectualizing":"intellectualize",
"intelligences":"intelligence",
"intelligentsias":"intelligentsia",
"intelligibilities":"intelligibility",
"intemperances":"intemperance",
"intemperatenesses":"intemperateness",
"intended":"intend",
"intending":"intend",
"intends":"intend",
"intendancies":"intendancy",
"intenerated":"intenerate",
"intenerating":"intenerate",
"intensifiers":"intensifier",
"intensified":"intensify",
"intensifies":"intensify",
"intensifying":"intensify",
"intensions":"intension",
"intensities":"intensity",
"intensives":"intensive",
"intensivenesses":"intensiveness",
"intents":"intent",
"intentions":"intention",
"intentnesses":"intentness",
"interred":"inter",
"interring":"inter",
"inters":"inter",
"interacted":"interact",
"interacting":"interact",
"interactions":"interaction",
"interbrains":"interbrain",
"interbred":"interbreed",
"interbreeding":"interbreed",
"interbreeds":"interbreed",
"interbreedings":"interbreeding",
"intercalated":"intercalate",
"intercalating":"intercalate",
"intercalations":"intercalation",
"interceded":"intercede",
"intercedes":"intercede",
"interceding":"intercede",
"intercepted":"intercept",
"intercepting":"intercept",
"intercepts":"intercept",
"intercessions":"intercession",
"interchanged":"interchange",
"interchanges":"interchange",
"interchanging":"interchange",
"interchangeabilities":"interchangeability",
"interchangeablenesses":"interchangeableness",
"intercoms":"intercom",
"intercommunicated":"intercommunicate",
"intercommunicates":"intercommunicate",
"intercommunicating":"intercommunicate",
"intercommunities":"intercommunity",
"interconnected":"interconnect",
"interconnecting":"interconnect",
"interconnects":"interconnect",
"interconnectednesses":"interconnectedness",
"interconnections":"interconnection",
"intercostals":"intercostal",
"intercourses":"intercourse",
"intercropped":"intercrop",
"intercropping":"intercrop",
"intercrops":"intercrop",
"intercrossed":"intercross",
"intercrossing":"intercross",
"intercuts":"intercut",
"intercutting":"intercut",
"interdependences":"interdependence",
"interdependencies":"interdependency",
"interdicted":"interdict",
"interdicting":"interdict",
"interdicts":"interdict",
"interdictions":"interdiction",
"interdigitated":"interdigitate",
"interdigitating":"interdigitate",
"interested":"interest",
"interesting":"interest",
"interests":"interest",
"interestingnesses":"interestingness",
"interfaces":"interface",
"interfered":"interfere",
"interferes":"interfere",
"interfering":"interfere",
"interferences":"interference",
"interferings":"interfering",
"interfolded":"interfold",
"interfolding":"interfold",
"interfused":"interfuse",
"interfusing":"interfuse",
"intergraded":"intergrade",
"intergrading":"intergrade",
"interims":"interim",
"interiors":"interior",
"interiorized":"interiorize",
"interiorizes":"interiorize",
"interiorizing":"interiorize",
"interjected":"interject",
"interjecting":"interject",
"interjects":"interject",
"interjections":"interjection",
"interknitted":"interknit",
"interknitting":"interknit",
"interlaced":"interlace",
"interlaces":"interlace",
"interlacing":"interlace",
"interlaminated":"interlaminate",
"interlaminating":"interlaminate",
"interlanguages":"interlanguage",
"interlapped":"interlap",
"interlapping":"interlap",
"interlaps":"interlap",
"interlarded":"interlard",
"interlarding":"interlard",
"interlards":"interlard",
"interlaid":"interlay",
"interlaying":"interlay",
"interlays":"interlay",
"interleaves":"interleaf",
"interleaved":"interleave",
"interleaving":"interleave",
"interlined":"interline",
"interlining":"interline",
"interlinguas":"interlingua",
"interlinked":"interlink",
"interlinking":"interlink",
"interlinks":"interlink",
"interlocked":"interlock",
"interlocking":"interlock",
"interlocks":"interlock",
"interlockings":"interlocking",
"interlocutors":"interlocutor",
"interloped":"interlope",
"interloping":"interlope",
"interlopers":"interloper",
"interludes":"interlude",
"intermarriages":"intermarriage",
"intermarried":"intermarry",
"intermarries":"intermarry",
"intermarrying":"intermarry",
"intermeddled":"intermeddle",
"intermeddling":"intermeddle",
"intermediaries":"intermediary",
"intermediated":"intermediate",
"intermediates":"intermediate",
"intermediating":"intermediate",
"intermediations":"intermediation",
"intermediators":"intermediator",
"interments":"interment",
"intermezzi":"intermezzo",
"intermezzos":"intermezzo",
"intermingled":"intermingle",
"intermingles":"intermingle",
"intermingling":"intermingle",
"intermissions":"intermission",
"intermits":"intermit",
"intermitted":"intermit",
"intermitting":"intermit",
"intermittences":"intermittence",
"intermittencies":"intermittency",
"intermixed":"intermix",
"intermixes":"intermix",
"intermixing":"intermix",
"intermixtures":"intermixture",
"interned":"intern",
"interning":"intern",
"interns":"intern",
"internals":"internal",
"internalizations":"internalization",
"internalized":"internalize",
"internalizes":"internalize",
"internalizing":"internalize",
"internationals":"international",
"internationalisations":"internationalisation",
"internationalisms":"internationalism",
"internationalities":"internationality",
"internationalizations":"internationalization",
"internationalized":"internationalize",
"internationalizes":"internationalize",
"internationalizing":"internationalize",
"internes":"interne",
"internets":"internet",
"internists":"internist",
"internments":"internment",
"internuncios":"internuncio",
"interpellated":"interpellate",
"interpellating":"interpellate",
"interpenetrated":"interpenetrate",
"interpenetrates":"interpenetrate",
"interpenetrating":"interpenetrate",
"interplayed":"interplay",
"interplaying":"interplay",
"interpleaded":"interplead",
"interpleading":"interplead",
"interpleads":"interplead",
"interpled":"interplead",
"interpolated":"interpolate",
"interpolates":"interpolate",
"interpolating":"interpolate",
"interpolations":"interpolation",
"interposed":"interpose",
"interposes":"interpose",
"interposing":"interpose",
"interpositions":"interposition",
"interpreted":"interpret",
"interpreting":"interpret",
"interprets":"interpret",
"interpretations":"interpretation",
"interpreters":"interpreter",
"interpretings":"interpreting",
"interregna":"interregnum",
"interregnums":"interregnum",
"interrelated":"interrelate",
"interrelates":"interrelate",
"interrelating":"interrelate",
"interrelatednesses":"interrelatedness",
"interrelations":"interrelation",
"interrelationships":"interrelationship",
"interreges":"interrex",
"interrogated":"interrogate",
"interrogates":"interrogate",
"interrogating":"interrogate",
"interrogations":"interrogation",
"interrogatives":"interrogative",
"interrogators":"interrogator",
"interrogatories":"interrogatory",
"interrupted":"interrupt",
"interrupting":"interrupt",
"interrupts":"interrupt",
"interruptions":"interruption",
"intersected":"intersect",
"intersecting":"intersect",
"intersects":"intersect",
"intersections":"intersection",
"interspaced":"interspace",
"interspacing":"interspace",
"interspersals":"interspersal",
"interspersed":"intersperse",
"intersperses":"intersperse",
"interspersing":"intersperse",
"interspersions":"interspersion",
"interstates":"interstate",
"interstices":"interstice",
"interstratified":"interstratify",
"interstratifies":"interstratify",
"interstratifying":"interstratify",
"intertangled":"intertangle",
"intertangling":"intertangle",
"intertwined":"intertwine",
"intertwines":"intertwine",
"intertwining":"intertwine",
"intertwisted":"intertwist",
"intertwisting":"intertwist",
"intervals":"interval",
"intervened":"intervene",
"intervenes":"intervene",
"intervening":"intervene",
"interventions":"intervention",
"interventionists":"interventionist",
"interviewed":"interview",
"interviewing":"interview",
"interviews":"interview",
"intervolved":"intervolve",
"intervolving":"intervolve",
"interweaved":"interweave",
"interweaves":"interweave",
"interweaving":"interweave",
"interwove":"interweave",
"interwoven":"interweave",
"interworked":"interwork",
"interworking":"interwork",
"interwrought":"interwork",
"intestines":"intestine",
"intimae":"intima",
"intimacies":"intimacy",
"intimated":"intimate",
"intimates":"intimate",
"intimating":"intimate",
"intimations":"intimation",
"intimidated":"intimidate",
"intimidates":"intimidate",
"intimidating":"intimidate",
"intimidations":"intimidation",
"intonated":"intonate",
"intonates":"intonate",
"intonating":"intonate",
"intonations":"intonation",
"intoned":"intone",
"intones":"intone",
"intoning":"intone",
"intoxicants":"intoxicant",
"intoxicated":"intoxicate",
"intoxicates":"intoxicate",
"intoxicating":"intoxicate",
"intoxications":"intoxication",
"intractabilities":"intractability",
"intractablenesses":"intractableness",
"intradoses":"intrados",
"intransigences":"intransigence",
"intransigencies":"intransigency",
"intransitivenesses":"intransitiveness",
"intransitivities":"intransitivity",
"intrenched":"intrench",
"intrenches":"intrench",
"intrenching":"intrench",
"intrenchments":"intrenchment",
"intrepidities":"intrepidity",
"intricacies":"intricacy",
"intrigued":"intrigue",
"intrigues":"intrigue",
"intriguing":"intrigue",
"intros":"intro",
"introduced":"introduce",
"introduces":"introduce",
"introducing":"introduce",
"introducers":"introducer",
"introductions":"introduction",
"intromissions":"intromission",
"intromits":"intromit",
"intromitted":"intromit",
"intromitting":"intromit",
"intropins":"intropin",
"introspected":"introspect",
"introspecting":"introspect",
"introspections":"introspection",
"introverted":"introvert",
"introverting":"introvert",
"introverts":"introvert",
"intruded":"intrude",
"intrudes":"intrude",
"intruding":"intrude",
"intruders":"intruder",
"intrusions":"intrusion",
"intrusivenesses":"intrusiveness",
"intrusted":"intrust",
"intrusting":"intrust",
"intrusts":"intrust",
"intubated":"intubate",
"intubating":"intubate",
"intuited":"intuit",
"intuiting":"intuit",
"intuitions":"intuition",
"intumesced":"intumesce",
"intumescing":"intumesce",
"intumescences":"intumescence",
"intumescencies":"intumescency",
"intussuscepted":"intussuscept",
"intussuscepting":"intussuscept",
"intussusceptions":"intussusception",
"Inuits":"Inuit",
"inunctions":"inunction",
"inundated":"inundate",
"inundates":"inundate",
"inundating":"inundate",
"inundations":"inundation",
"inured":"inure",
"inures":"inure",
"inuring":"inure",
"inurned":"inurn",
"inurning":"inurn",
"inurns":"inurn",
"inutilities":"inutility",
"invaded":"invade",
"invades":"invade",
"invading":"invade",
"invaders":"invader",
"invaginated":"invaginate",
"invaginates":"invaginate",
"invaginating":"invaginate",
"invaginations":"invagination",
"invalided":"invalid",
"invaliding":"invalid",
"invalids":"invalid",
"invalidated":"invalidate",
"invalidates":"invalidate",
"invalidating":"invalidate",
"invalidations":"invalidation",
"invalidities":"invalidity",
"invalidnesses":"invalidness",
"invaluablenesses":"invaluableness",
"invariabilities":"invariability",
"invariables":"invariable",
"invariablenesses":"invariableness",
"invariances":"invariance",
"invasions":"invasion",
"invectives":"invective",
"inveighed":"inveigh",
"inveighing":"inveigh",
"inveighs":"inveigh",
"inveigled":"inveigle",
"inveigles":"inveigle",
"inveigling":"inveigle",
"invented":"invent",
"inventing":"invent",
"invents":"invent",
"inventions":"invention",
"inventivenesses":"inventiveness",
"inventors":"inventor",
"inventoried":"inventory",
"inventories":"inventory",
"inventorying":"inventory",
"inventoryings":"inventorying",
"inveracities":"inveracity",
"inverses":"inverse",
"inversions":"inversion",
"inverted":"invert",
"inverting":"invert",
"inverts":"invert",
"invested":"invest",
"investing":"invest",
"invests":"invest",
"investigated":"investigate",
"investigates":"investigate",
"investigating":"investigate",
"investigatings":"investigating",
"investigations":"investigation",
"investigators":"investigator",
"investings":"investing",
"investitures":"investiture",
"investments":"investment",
"investors":"investor",
"invidias":"invidia",
"invigorated":"invigorate",
"invigorates":"invigorate",
"invigorating":"invigorate",
"invigorations":"invigoration",
"invincibilities":"invincibility",
"invisibilities":"invisibility",
"invisibles":"invisible",
"invisiblenesses":"invisibleness",
"invitations":"invitation",
"invited":"invite",
"invites":"invite",
"inviting":"invite",
"invitees":"invitee",
"invocated":"invocate",
"invocating":"invocate",
"invocations":"invocation",
"invoiced":"invoice",
"invoices":"invoice",
"invoicing":"invoice",
"invoked":"invoke",
"invokes":"invoke",
"invoking":"invoke",
"involucels":"involucel",
"involucella":"involucellum",
"involucres":"involucre",
"involucra":"involucrum",
"involutions":"involution",
"involved":"involve",
"involves":"involve",
"involving":"involve",
"involvements":"involvement",
"invulnerabilities":"invulnerability",
"inwards":"inward",
"inwardnesses":"inwardness",
"inweaved":"inweave",
"inweaves":"inweave",
"inweaving":"inweave",
"inwove":"inweave",
"inwoven":"inweave",
"inwrapped":"inwrap",
"inwrapping":"inwrap",
"inwraps":"inwrap",
"iodins":"iodin",
"iodines":"iodine",
"iodized":"iodize",
"iodizes":"iodize",
"iodizing":"iodize",
"iodoforms":"iodoform",
"iodoproteins":"iodoprotein",
"ionized":"ionize",
"ionizing":"ionize",
"iotas":"iota",
"iowas":"iowa",
"ioways":"ioway",
"ipidaes":"ipidae",
"ipos":"ipo",
"ipomoeas":"ipomoea",
"ipsuses":"ipsus",
"IQs":"IQ",
"irs":"ir",
"iras":"ira",
"iraks":"irak",
"irakis":"iraki",
"irans":"iran",
"iranis":"irani",
"Iranians":"Iranian",
"iraqs":"iraq",
"iraqis":"iraqi",
"irascibilities":"irascibility",
"ires":"ire",
"irelands":"ireland",
"irelanders":"irelander",
"irenas":"irena",
"irenidaes":"irenidae",
"iresines":"iresine",
"iridaceaes":"iridaceae",
"iridectomies":"iridectomy",
"iridescences":"iridescence",
"iridiums":"iridium",
"iridoprocnes":"iridoprocne",
"iridotomies":"iridotomy",
"irides":"iris",
"irises":"iris",
"irishes":"irish",
"Irishmen":"Irishman",
"Irishwomen":"Irishwoman",
"irked":"irk",
"irking":"irk",
"irks":"irk",
"ironed":"iron",
"ironing":"iron",
"irons":"iron",
"iron-grays":"iron-gray",
"iron-greys":"iron-grey",
"ironists":"ironist",
"ironmongers":"ironmonger",
"ironmongeries":"ironmongery",
"ironses":"irons",
"irontrees":"irontree",
"ironwares":"ironware",
"ironweeds":"ironweed",
"ironwoods":"ironwood",
"ironies":"irony",
"iroquoians":"iroquoian",
"iroquoises":"iroquois",
"irradiated":"irradiate",
"irradiates":"irradiate",
"irradiating":"irradiate",
"irradiations":"irradiation",
"irrationalities":"irrationality",
"irrealities":"irreality",
"irreconcilables":"irreconcilable",
"irredentas":"irredenta",
"irredentisms":"irredentism",
"irredentists":"irredentist",
"irregulars":"irregular",
"irregularities":"irregularity",
"irrelevances":"irrelevance",
"irrelevancies":"irrelevancy",
"irreligions":"irreligion",
"irreligionists":"irreligionist",
"irreligiousnesses":"irreligiousness",
"irrepressibilities":"irrepressibility",
"irresolutenesses":"irresoluteness",
"irresolutions":"irresolution",
"irresponsibilities":"irresponsibility",
"irresponsibles":"irresponsible",
"irresponsiblenesses":"irresponsibleness",
"irreverences":"irreverence",
"irridentas":"irridenta",
"irridentisms":"irridentism",
"irridentists":"irridentist",
"irrigated":"irrigate",
"irrigates":"irrigate",
"irrigating":"irrigate",
"irritabilities":"irritability",
"irritants":"irritant",
"irritated":"irritate",
"irritates":"irritate",
"irritating":"irritate",
"irritations":"irritation",
"irrupted":"irrupt",
"irrupting":"irrupt",
"irrupts":"irrupt",
"irses":"irs",
"irtishes":"irtish",
"irtyshes":"irtysh",
"irvingias":"irvingia",
"isarithms":"isarithm",
"isatises":"isatis",
"ischigualastias":"ischigualastia",
"ischia":"ischium",
"ischiums":"ischium",
"iseres":"isere",
"ishtars":"ishtar",
"isinglasses":"isinglass",
"iskcons":"iskcon",
"islams":"islam",
"islamabads":"islamabad",
"islamisms":"islamism",
"Islamized":"Islamize",
"Islamizing":"Islamize",
"islanded":"island",
"islanding":"island",
"islands":"island",
"island-dwellers":"island-dweller",
"islanders":"islander",
"islays":"islay",
"isles":"isle",
"islets":"islet",
"isms":"ism",
"isocarboxazids":"isocarboxazid",
"isocracies":"isocracy",
"isoetaceaes":"isoetaceae",
"isoetaleses":"isoetales",
"isoeteses":"isoetes",
"isogones":"isogone",
"isograms":"isogram",
"isolated":"isolate",
"isolates":"isolate",
"isolating":"isolate",
"isolations":"isolation",
"isolationists":"isolationist",
"isopleths":"isopleth",
"isopodas":"isopoda",
"isopropanols":"isopropanol",
"isopteras":"isoptera",
"isoptins":"isoptin",
"isopyrums":"isopyrum",
"isospondylis":"isospondyli",
"israels":"israel",
"Israelis":"Israeli",
"israeliteses":"israelites",
"isseis":"issei",
"issuances":"issuance",
"issued":"issue",
"issues":"issue",
"issuing":"issue",
"issuers":"issuer",
"issuings":"issuing",
"issuses":"issus",
"istanbuls":"istanbul",
"isthmi":"isthmus",
"isthmuses":"isthmus",
"istiophoridaes":"istiophoridae",
"istiophoruses":"istiophorus",
"isuridaes":"isuridae",
"isuruses":"isurus",
"italias":"italia",
"italianized":"italianize",
"italianizing":"italianize",
"italics":"italic",
"italicized":"italicize",
"italicizing":"italicize",
"italies":"italy",
"itched":"itch",
"itches":"itch",
"itching":"itch",
"itchings":"itching",
"itchier":"itchy",
"itchiest":"itchy",
"items":"item",
"itemisations":"itemisation",
"itemizations":"itemization",
"itemized":"itemize",
"itemizes":"itemize",
"itemizing":"itemize",
"iterated":"iterate",
"iterates":"iterate",
"iterating":"iterate",
"iterations":"iteration",
"ithunns":"ithunn",
"itinerants":"itinerant",
"itineraries":"itinerary",
"itinerated":"itinerate",
"itinerating":"itinerate",
"ivs":"iv",
"ivas":"iva",
"ivories":"ivory",
"ivorybills":"ivorybill",
"ivries":"ivry",
"ivies":"ivy",
"iwos":"iwo",
"ixes":"ix",
"ixias":"ixia",
"ixobrychuses":"ixobrychus",
"ixodeses":"ixodes",
"ixodids":"ixodid",
"ixodidaes":"ixodidae",
"iyars":"iyar",
"iyyars":"iyyar",
"js":"j",
"jabbed":"jab",
"jabbing":"jab",
"jabs":"jab",
"jabbered":"jabber",
"jabbering":"jabber",
"jabbers":"jabber",
"jabberers":"jabberer",
"jabberings":"jabbering",
"jabberwockies":"jabberwocky",
"jabbings":"jabbing",
"jabirus":"jabiru",
"jaboncillos":"jaboncillo",
"jaborandis":"jaborandi",
"jaboticabas":"jaboticaba",
"jacales":"jacal",
"jacals":"jacal",
"jacanas":"jacana",
"jacarandas":"jacaranda",
"jacinths":"jacinth",
"jacked":"jack",
"jacking":"jack",
"jacks":"jack",
"jack-a-lanterns":"jack-a-lantern",
"jack-by-the-hedges":"jack-by-the-hedge",
"jack-in-a-boxes":"jack-in-a-box",
"jack-in-the-boxes":"jack-in-the-box",
"jacks-in-the-box":"jack-in-the-box",
"jack-in-the-pulpits":"jack-in-the-pulpit",
"jack-o-lanterns":"jack-o-lantern",
"jacks-of-all-trades":"jack-of-all-trades",
"jack-tars":"jack-tar",
"jackals":"jackal",
"jackanapeses":"jackanapes",
"jackeroos":"jackaroo",
"jackasses":"jackass",
"jackboots":"jackboot",
"jackdaws":"jackdaw",
"jacketed":"jacket",
"jacketing":"jacket",
"jackets":"jacket",
"jackfishes":"jackfish",
"jackfruits":"jackfruit",
"jackhammers":"jackhammer",
"jackknifed":"jackknife",
"jackknifing":"jackknife",
"jackknives":"jackknife",
"jackknife-fishes":"jackknife-fish",
"jackpots":"jackpot",
"jackses":"jacks",
"jackscrews":"jackscrew",
"jacksmelts":"jacksmelt",
"jacksnipes":"jacksnipe",
"jacksons":"jackson",
"jacksonias":"jacksonia",
"jackstoneses":"jackstones",
"jackstraws":"jackstraw",
"jackstrawses":"jackstraws",
"jacobuses":"jacobus",
"jacquinias":"jacquinia",
"jactations":"jactation",
"jactitations":"jactitation",
"jaculuses":"jaculus",
"jaded":"jade",
"jades":"jade",
"jading":"jade",
"jadestones":"jadestone",
"jaffas":"jaffa",
"jagged":"jag",
"jagging":"jag",
"jags":"jag",
"jagannaths":"jagannath",
"jagannathas":"jagannatha",
"jagatais":"jagatai",
"jagganaths":"jagganath",
"jaggaries":"jaggary",
"jaggeries":"jaggery",
"jaggheries":"jagghery",
"jaggier":"jaggy",
"jaggiest":"jaggy",
"jaghatais":"jaghatai",
"jaguas":"jagua",
"jaguars":"jaguar",
"jaguarondis":"jaguarondi",
"jaguarundis":"jaguarundi",
"jahveys":"jahvey",
"jahwehs":"jahweh",
"jailed":"jail",
"jailing":"jail",
"jails":"jail",
"jailbirds":"jailbird",
"jailbreaks":"jailbreak",
"jailers":"jailer",
"jailhouses":"jailhouse",
"jailings":"jailing",
"jailors":"jailor",
"jaks":"jak",
"jakartas":"jakarta",
"jakeses":"jakes",
"jalapenos":"jalapeno",
"jaloppies":"jaloppy",
"jalopies":"jalopy",
"jalousies":"jalousie",
"jammed":"jam",
"jamming":"jam",
"jams":"jam",
"jam-packed":"jam-pack",
"jam-packing":"jam-pack",
"jambarts":"jambart",
"jambeaus":"jambeau",
"jambeaux":"jambeau",
"jambers":"jamber",
"jamberries":"jamberry",
"jambons":"jambon",
"jamborees":"jamboree",
"jamboses":"jambos",
"jambosas":"jambosa",
"jameses":"james",
"jamesonias":"jamesonia",
"jamjars":"jamjar",
"jammings":"jamming",
"jammier":"jammy",
"jammiest":"jammy",
"jampots":"jampot",
"jans":"jan",
"jangled":"jangle",
"jangles":"jangle",
"jangling":"jangle",
"janissaries":"janissary",
"janitors":"janitor",
"janizaries":"janizary",
"jansens":"jansen",
"januaries":"january",
"Japs":"Jap",
"japanned":"japan",
"japanning":"japan",
"japans":"japan",
"japaneses":"japanese",
"japed":"jape",
"japes":"jape",
"japing":"jape",
"japonicas":"japonica",
"jarred":"jar",
"jarring":"jar",
"jars":"jar",
"jarfuls":"jarful",
"jargoned":"jargon",
"jargoning":"jargon",
"jargons":"jargon",
"jargonized":"jargonize",
"jargonizing":"jargonize",
"jargoons":"jargoon",
"jasminums":"jasminum",
"jassidaes":"jassidae",
"jats":"jat",
"jatos":"jato",
"jatrophas":"jatropha",
"jaundiced":"jaundice",
"jaundices":"jaundice",
"jaundicing":"jaundice",
"jaunted":"jaunt",
"jaunting":"jaunt",
"jaunts":"jaunt",
"jauntinesses":"jauntiness",
"jauntier":"jaunty",
"jauntiest":"jaunty",
"javas":"java",
"javanthropuses":"javanthropus",
"javelins":"javelin",
"javelinas":"javelina",
"jawed":"jaw",
"jawing":"jaw",
"jaws":"jaw",
"jawbones":"jawbone",
"jawses":"jaws",
"jays":"jay",
"jaybirds":"jaybird",
"jaywalked":"jaywalk",
"jaywalking":"jaywalk",
"jazzed":"jazz",
"jazzing":"jazz",
"jazzs":"jazz",
"jazzmen":"jazzman",
"jazzier":"jazzy",
"jazziest":"jazzy",
"jealousies":"jealousy",
"jeans":"jean",
"Jeeps":"Jeep",
"jeered":"jeer",
"jeering":"jeer",
"jeers":"jeer",
"jeerings":"jeering",
"jeffersons":"jefferson",
"jehads":"jehad",
"jehovahs":"jehovah",
"jehus":"jehu",
"jejunenesses":"jejuneness",
"jejunities":"jejunity",
"jelled":"jell",
"jelling":"jell",
"jells":"jell",
"jellified":"jellify",
"jellifies":"jellify",
"jellifying":"jellify",
"jellied":"jelly",
"jellies":"jelly",
"jellying":"jelly",
"jellyfishes":"jellyfish",
"jellyleaves":"jellyleaf",
"jemmies":"jemmy",
"jenas":"jena",
"jennets":"jennet",
"jennies":"jenny",
"jeoparded":"jeopard",
"jeoparding":"jeopard",
"jeopardized":"jeopardize",
"jeopardizes":"jeopardize",
"jeopardizing":"jeopardize",
"jeopardies":"jeopardy",
"jequerities":"jequerity",
"jequirities":"jequirity",
"jerboas":"jerboa",
"jerevans":"jerevan",
"jerezs":"jerez",
"jerked":"jerk",
"jerking":"jerk",
"jerks":"jerk",
"jerkins":"jerkin",
"jerkinesses":"jerkiness",
"jerkings":"jerking",
"jerkier":"jerky",
"jerkies":"jerky",
"jerkiest":"jerky",
"jerries":"jerry",
"jerry-building":"jerry-build",
"jerry-builds":"jerry-build",
"jerry-built":"jerry-build",
"jerseys":"jersey",
"jerusalems":"jerusalem",
"jessamines":"jessamine",
"jested":"jest",
"jesting":"jest",
"jests":"jest",
"jesters":"jester",
"jesuitisms":"jesuitism",
"jesuitries":"jesuitry",
"jesuses":"jesus",
"jets":"jet",
"jetted":"jet",
"jetting":"jet",
"jetses":"jets",
"jetsams":"jetsam",
"jettisoned":"jettison",
"jettisoning":"jettison",
"jetties":"jetty",
"jewed":"jew",
"jewing":"jew",
"Jews":"Jew",
"jew-baiters":"jew-baiter",
"jewbushes":"jewbush",
"jeweled":"jewel",
"jeweling":"jewel",
"jewelled":"jewel",
"jewelling":"jewel",
"jewels":"jewel",
"jewelers":"jeweler",
"jewelfishes":"jewelfish",
"jewellers":"jeweller",
"jewelleries":"jewellery",
"jewelries":"jewelry",
"jewels-of-opars":"jewels-of-opar",
"jewelweeds":"jewelweed",
"jewfishes":"jewfish",
"jewries":"jewry",
"jibbed":"jib",
"jibbing":"jib",
"jibs":"jib",
"jibed":"jibe",
"jibes":"jibe",
"jibing":"jibe",
"jiffs":"jiff",
"jiffies":"jiffy",
"jigged":"jig",
"jigging":"jig",
"jigs":"jig",
"jigaboos":"jigaboo",
"jiggered":"jigger",
"jiggering":"jigger",
"jiggers":"jigger",
"jiggermasts":"jiggermast",
"jiggery-pokeries":"jiggery-pokery",
"jiggled":"jiggle",
"jiggles":"jiggle",
"jiggling":"jiggle",
"jigsaws":"jigsaw",
"jihads":"jihad",
"jillions":"jillion",
"jillionses":"jillions",
"jilted":"jilt",
"jilting":"jilt",
"jim-crowed":"jim-crow",
"jim-crowing":"jim-crow",
"jimdandies":"jimdandy",
"jimhickeys":"jimhickey",
"jimmieses":"jimmies",
"jimmied":"jimmy",
"jimmies":"jimmy",
"jimmying":"jimmy",
"jimpsonweeds":"jimpsonweed",
"jimsonweeds":"jimsonweed",
"jinghpaws":"jinghpaw",
"jinghpos":"jinghpo",
"jingled":"jingle",
"jingles":"jingle",
"jingling":"jingle",
"jingoes":"jingo",
"jingoisms":"jingoism",
"jingoists":"jingoist",
"jinked":"jink",
"jinking":"jink",
"jinkses":"jinks",
"jinnees":"jinnee",
"jinn":"jinni",
"jinnis":"jinni",
"jinrikishas":"jinrikisha",
"jinxes":"jinx",
"jipijapas":"jipijapa",
"jiquis":"jiqui",
"jirrbals":"jirrbal",
"jitneys":"jitney",
"jittered":"jitter",
"jittering":"jitter",
"jitters":"jitter",
"jitterbugged":"jitterbug",
"jitterbugging":"jitterbug",
"jitterbugs":"jitterbug",
"jitterinesses":"jitteriness",
"jitterses":"jitters",
"jitterier":"jittery",
"jitteriest":"jittery",
"jiujitsus":"jiujitsu",
"jivaros":"jivaro",
"jived":"jive",
"jives":"jive",
"jiving":"jive",
"jnrs":"jnr",
"joes":"jo",
"jobbed":"job",
"jobbing":"job",
"jobs":"job",
"job-hopped":"job-hop",
"job-hopping":"job-hop",
"job-hops":"job-hop",
"jobbers":"jobber",
"jocks":"jock",
"jockeyed":"jockey",
"jockeying":"jockey",
"jockeys":"jockey",
"jockos":"jocko",
"jockstraps":"jockstrap",
"jocosenesses":"jocoseness",
"jocosities":"jocosity",
"jocotes":"jocote",
"jocularities":"jocularity",
"jocundities":"jocundity",
"jodphurs":"jodphur",
"joewoods":"joewood",
"joeys":"joey",
"jogged":"jog",
"jogging":"jog",
"jogs":"jog",
"jog-trots":"jog-trot",
"jog-trotted":"jog-trot",
"jog-trotting":"jog-trot",
"joggled":"joggle",
"joggles":"joggle",
"joggling":"joggle",
"johns":"john",
"johnnies":"johnny",
"johnny-jump-ups":"johnny-jump-up",
"johnnycakes":"johnnycake",
"johnsons":"johnson",
"joined":"join",
"joining":"join",
"joins":"join",
"joineries":"joinery",
"joinings":"joining",
"jointed":"joint",
"jointing":"joint",
"joints":"joint",
"jointers":"jointer",
"jointworms":"jointworm",
"joined_batted":"join_battle",
"joining_battle":"join_battle",
"joins_battle":"join_battle",
"joked":"joke",
"jokes":"joke",
"joking":"joke",
"jokers":"joker",
"jokesters":"jokester",
"jollifications":"jollification",
"jollified":"jollify",
"jollifies":"jollify",
"jollifying":"jollify",
"jollities":"jollity",
"jollied":"jolly",
"jollier":"jolly",
"jollies":"jolly",
"jolliest":"jolly",
"jollying":"jolly",
"jolted":"jolt",
"jolting":"jolt",
"jolts":"jolt",
"joltier":"jolty",
"joltiest":"jolty",
"jonahs":"jonah",
"jongleurs":"jongleur",
"jonquils":"jonquil",
"joppas":"joppa",
"jordans":"jordan",
"jordanellas":"jordanella",
"joshed":"josh",
"joshing":"josh",
"joshuas":"joshua",
"jostled":"jostle",
"jostles":"jostle",
"jostling":"jostle",
"jostlings":"jostling",
"josues":"josue",
"jots":"jot",
"jotted":"jot",
"jotting":"jot",
"jotters":"jotter",
"jottings":"jotting",
"jotuns":"jotun",
"jotunns":"jotunn",
"joules":"joule",
"jounced":"jounce",
"jounces":"jounce",
"jouncing":"jounce",
"jouncier":"jouncy",
"jounciest":"jouncy",
"journals":"journal",
"journalisms":"journalism",
"journalists":"journalist",
"journalized":"journalize",
"journalizing":"journalize",
"journeyed":"journey",
"journeying":"journey",
"journeys":"journey",
"journeyers":"journeyer",
"journeyings":"journeying",
"journeymen":"journeyman",
"journos":"journo",
"jousted":"joust",
"jousting":"joust",
"jousts":"joust",
"joves":"jove",
"jovialities":"joviality",
"jowls":"jowl",
"jowlier":"jowly",
"jowliest":"jowly",
"joyed":"joy",
"joying":"joy",
"joys":"joy",
"joy-ridden":"joy-ride",
"joy-rides":"joy-ride",
"joy-riding":"joy-ride",
"joy-rode":"joy-ride",
"joyfulnesses":"joyfulness",
"joyousnesses":"joyousness",
"joypopped":"joypop",
"joypopping":"joypop",
"joypops":"joypop",
"joysticks":"joystick",
"jrs":"jr",
"juarezs":"juarez",
"jubilances":"jubilance",
"jubilancies":"jubilancy",
"jubilated":"jubilate",
"jubilates":"jubilate",
"jubilating":"jubilate",
"jubilations":"jubilation",
"jubilees":"jubilee",
"judaisms":"judaism",
"judaized":"judaize",
"judaizes":"judaize",
"judaizing":"judaize",
"Judases":"Judas",
"juddered":"judder",
"juddering":"judder",
"judders":"judder",
"judged":"judge",
"judges":"judge",
"judging":"judge",
"judgements":"judgement",
"judgeships":"judgeship",
"judge_advocates_general":"judge_advocate_general",
"judge_advocate_generals":"judge_advocate_general",
"judgings":"judging",
"judgments":"judgment",
"judgships":"judgship",
"judicatories":"judicatory",
"judicatures":"judicature",
"judiciaries":"judiciary",
"judiciousnesses":"judiciousness",
"judos":"judo",
"judies":"judy",
"jugged":"jug",
"jugging":"jug",
"jugs":"jug",
"jugfuls":"jugful",
"juggernauts":"juggernaut",
"juggled":"juggle",
"juggles":"juggle",
"juggling":"juggle",
"jugglings":"juggling",
"juglandaceaes":"juglandaceae",
"juglandaleses":"juglandales",
"juglanses":"juglans",
"jugoslavs":"jugoslav",
"jugoslavias":"jugoslavia",
"jugoslavians":"jugoslavian",
"jugulars":"jugular",
"juiced":"juice",
"juices":"juice",
"juicing":"juice",
"juicers":"juicer",
"juicinesses":"juiciness",
"juicier":"juicy",
"juiciest":"juicy",
"jujitsus":"jujitsu",
"jujus":"juju",
"jujubes":"jujube",
"jukeboxes":"jukebox",
"juleps":"julep",
"julies":"july",
"jumbals":"jumbal",
"jumbled":"jumble",
"jumbles":"jumble",
"jumbling":"jumble",
"jumbos":"jumbo",
"juments":"jument",
"jumped":"jump",
"jumping":"jump",
"jumps":"jump",
"jump-started":"jump-start",
"jump-starting":"jump-start",
"jumpers":"jumper",
"jumpinesses":"jumpiness",
"jumpings":"jumping",
"jumpsuits":"jumpsuit",
"jumpier":"jumpy",
"jumpiest":"jumpy",
"jumped_off":"jump_off",
"jumping_off":"jump_off",
"jumps_off":"jump_off",
"juncaceaes":"juncaceae",
"juncaginaceaes":"juncaginaceae",
"juncoes":"junco",
"juncos":"junco",
"junctions":"junction",
"junctures":"juncture",
"juncuses":"juncus",
"juneaus":"juneau",
"juneberries":"juneberry",
"jungs":"jung",
"jungermanniaceaes":"jungermanniaceae",
"jungermannialeses":"jungermanniales",
"jungles":"jungle",
"juniors":"junior",
"junipers":"juniper",
"juniperuses":"juniperus",
"junked":"junk",
"junking":"junk",
"junks":"junk",
"junketed":"junket",
"junketing":"junket",
"junkets":"junket",
"junkies":"junkie",
"junkmen":"junkman",
"junkier":"junky",
"junkiest":"junky",
"juntas":"junta",
"juntos":"junto",
"jupatis":"jupati",
"jupaties":"jupaty",
"jupiters":"jupiter",
"jurassics":"jurassic",
"jurisdictions":"jurisdiction",
"jurisprudences":"jurisprudence",
"jurists":"jurist",
"jurors":"juror",
"juries":"jury",
"jurymen":"juryman",
"jurywomen":"jurywoman",
"jura":"jus",
"justices":"justice",
"justiciars":"justiciar",
"justiciaries":"justiciary",
"justifiers":"justifier",
"justified":"justify",
"justifies":"justify",
"justifying":"justify",
"justled":"justle",
"justling":"justle",
"justnesses":"justness",
"juts":"jut",
"jutted":"jut",
"jutting":"jut",
"jutishes":"jutish",
"juttings":"jutting",
"juttied":"jutty",
"jutties":"jutty",
"juttying":"jutty",
"juveniles":"juvenile",
"juvenilities":"juvenility",
"juxtaposed":"juxtapose",
"juxtaposing":"juxtapose",
"jynxes":"jynx",
"ks":"k",
"k-mesons":"k-meson",
"kabalas":"kabala",
"kabbalas":"kabbala",
"kabbalahs":"kabbalah",
"kabobs":"kabob",
"kabolins":"kabolin",
"kabuls":"kabul",
"kabyles":"kabyle",
"kachins":"kachin",
"kachinics":"kachinic",
"kadais":"kadai",
"kaddishim":"kaddish",
"kadis":"kadi",
"kaffirs":"kaffir",
"kafirs":"kafir",
"kafkas":"kafka",
"kaftans":"kaftan",
"kahikateas":"kahikatea",
"kahoolawes":"kahoolawe",
"kails":"kail",
"kainogeneses":"kainogenesis",
"kakas":"kaka",
"kakapos":"kakapo",
"kakatoes":"kakatoe",
"kakemonos":"kakemono",
"kakis":"kaki",
"kala-azars":"kala-azar",
"kalaharis":"kalahari",
"kalantases":"kalantas",
"kalapooias":"kalapooia",
"kalapooians":"kalapooian",
"kalapuyas":"kalapuya",
"kalapuyans":"kalapuyan",
"kales":"kale",
"kalis":"kali",
"kalians":"kalian",
"kalifs":"kalif",
"kalimantans":"kalimantan",
"kaliphs":"kaliph",
"kalkas":"kalka",
"kalmuck":"kalmuc",
"kalmucks":"kalmuc",
"kalmyks":"kalmyk",
"kalotermeses":"kalotermes",
"kalotermitidaes":"kalotermitidae",
"kalumpangs":"kalumpang",
"kam-tais":"kam-tai",
"kamalas":"kamala",
"kampalas":"kampala",
"kampongs":"kampong",
"kampucheas":"kampuchea",
"kampucheans":"kampuchean",
"kanas":"kana",
"kanafs":"kanaf",
"kanareses":"kanarese",
"kanawhas":"kanawha",
"kanchanjangas":"kanchanjanga",
"kanchenjungas":"kanchenjunga",
"kanchils":"kanchil",
"kangaroos":"kangaroo",
"kanjis":"kanji",
"kannadas":"kannada",
"kansas":"kansa",
"kansases":"kansas",
"kansus":"kansu",
"kants":"kant",
"kanuris":"kanuri",
"kaolins":"kaolin",
"kaolines":"kaoline",
"kaolinized":"kaolinize",
"kaolinizes":"kaolinize",
"kaolinizing":"kaolinize",
"kaons":"kaon",
"kapellmeisters":"kapellmeister",
"kapoks":"kapok",
"kappas":"kappa",
"kappa-mesons":"kappa-meson",
"kapsikis":"kapsiki",
"kapukas":"kapuka",
"kara-kalpaks":"kara-kalpak",
"karabiners":"karabiner",
"karakorams":"karakoram",
"karakuls":"karakul",
"karats":"karat",
"karelians":"karelian",
"karens":"karen",
"karenics":"karenic",
"karoos":"karoo",
"karroos":"karroo",
"kartikeyas":"kartikeya",
"karttikeyas":"karttikeya",
"karyoplasms":"karyoplasm",
"kashmirs":"kashmir",
"kashmiris":"kashmiri",
"kassites":"kassite",
"katabases":"katabasis",
"katabolisms":"katabolism",
"katars":"katar",
"kataris":"katari",
"katharses":"katharsis",
"kathmandus":"kathmandu",
"katmandus":"katmandu",
"katsuwonidaes":"katsuwonidae",
"katsuwonuses":"katsuwonus",
"kauais":"kauai",
"kaunases":"kaunas",
"kauris":"kauri",
"kauries":"kaury",
"kavas":"kava",
"kavakavas":"kavakava",
"kawakas":"kawaka",
"kayoed":"kayo",
"kayoing":"kayo",
"kayos":"kayo",
"kazaks":"kazak",
"kazakhs":"kazakh",
"kazakhstans":"kazakhstan",
"kazakstans":"kazakstan",
"kazoos":"kazoo",
"kbs":"kb",
"kcs":"kc",
"keas":"kea",
"kebs":"keb",
"kebabs":"kebab",
"kecked":"keck",
"kecking":"keck",
"kedged":"kedge",
"kedging":"kedge",
"keeked":"keek",
"keeking":"keek",
"keeled":"keel",
"keeling":"keel",
"keels":"keel",
"keelhauled":"keelhaul",
"keelhauling":"keelhaul",
"keened":"keen",
"keener":"keen",
"keenest":"keen",
"keening":"keen",
"keennesses":"keenness",
"keeping":"keep",
"keeps":"keep",
"kept":"keep",
"keepers":"keeper",
"keepings":"keeping",
"keepsakes":"keepsake",
"keeshonden":"keeshond",
"keeshonds":"keeshond",
"keflexes":"keflex",
"keftabs":"keftab",
"kegs":"keg",
"kegfuls":"kegful",
"keisters":"keister",
"kelpies":"kelpie",
"kelpworts":"kelpwort",
"kelts":"kelt",
"kelvins":"kelvin",
"kenned":"ken",
"kenning":"ken",
"kens":"ken",
"kent":"ken",
"kenafs":"kenaf",
"kennedias":"kennedia",
"kennedies":"kennedy",
"kennedyas":"kennedya",
"kenneled":"kennel",
"kenneling":"kennel",
"kennelled":"kennel",
"kennelling":"kennel",
"kennels":"kennel",
"kenos":"keno",
"kenogeneses":"kenogenesis",
"kentans":"kentan",
"kentishes":"kentish",
"kentuckies":"kentucky",
"kenyapithecuses":"kenyapithecus",
"kepis":"kepi",
"keplers":"kepler",
"keratectomies":"keratectomy",
"keratins":"keratin",
"keratinized":"keratinize",
"keratinizing":"keratinize",
"keratoplasties":"keratoplasty",
"keratoses":"keratosis",
"kerbs":"kerb",
"kerbstones":"kerbstone",
"kerchiefs":"kerchief",
"kerchieves":"kerchief",
"kerned":"kern",
"kerning":"kern",
"kerns":"kern",
"kerneled":"kernel",
"kerneling":"kernel",
"kernelled":"kernel",
"kernelling":"kernel",
"kernels":"kernel",
"kerosenes":"kerosene",
"kerosines":"kerosine",
"kerries":"kerry",
"kerugmas":"kerugma",
"kerygmas":"kerygma",
"kestrels":"kestrel",
"ketchups":"ketchup",
"ketembillas":"ketembilla",
"ketoacidurias":"ketoaciduria",
"ketonemias":"ketonemia",
"ketonurias":"ketonuria",
"ketoprofens":"ketoprofen",
"ketorolacs":"ketorolac",
"ketoses":"ketosis",
"kettles":"kettle",
"kettledrums":"kettledrum",
"kettlefuls":"kettleful",
"keurbooms":"keurboom",
"keyed":"key",
"keying":"key",
"keys":"key",
"keyboarded":"keyboard",
"keyboarding":"keyboard",
"keyboards":"keyboard",
"keyneses":"keynes",
"keynoted":"keynote",
"keynotes":"keynote",
"keynoting":"keynote",
"keypunched":"keypunch",
"keypunching":"keypunch",
"keystones":"keystone",
"kgs":"kg",
"khakis":"khaki",
"khalifs":"khalif",
"khalkas":"khalka",
"khalkhas":"khalkha",
"khans":"khan",
"khanties":"khanty",
"khartoums":"khartoum",
"khayas":"khaya",
"khesaris":"khesari",
"khirghizs":"khirghiz",
"khmers":"khmer",
"khoikhois":"khoikhoi",
"khoikhoins":"khoikhoin",
"khoisans":"khoisan",
"khzs":"khz",
"kiaats":"kiaat",
"kiangs":"kiang",
"kibbled":"kibble",
"kibbles":"kibble",
"kibbling":"kibble",
"kibbutzim":"kibbutz",
"kebei":"kibei",
"kebeis":"kibei",
"kibitzed":"kibitz",
"kibitzing":"kibitz",
"kibitzs":"kibitz",
"kibitzers":"kibitzer",
"kichagas":"kichaga",
"kicked":"kick",
"kicking":"kick",
"kicks":"kick",
"kickapoos":"kickapoo",
"kickings":"kicking",
"kickoffs":"kickoff",
"kickshaws":"kickshaw",
"kicksorters":"kicksorter",
"kidded":"kid",
"kidding":"kid",
"kids":"kid",
"kidds":"kidd",
"kiddies":"kiddie",
"kiddoes":"kiddo",
"kidnaped":"kidnap",
"kidnaping":"kidnap",
"kidnapped":"kidnap",
"kidnapping":"kidnap",
"kidnaps":"kidnap",
"kidnapers":"kidnaper",
"kidnappers":"kidnapper",
"kidneys":"kidney",
"kidskins":"kidskin",
"kieselguhrs":"kieselguhr",
"kievs":"kiev",
"kigalis":"kigali",
"kiggelarias":"kiggelaria",
"kikuyus":"kikuyu",
"kildeers":"kildeer",
"kileys":"kiley",
"kilimanjaros":"kilimanjaro",
"kiliwas":"kiliwa",
"kiliwis":"kiliwi",
"killed":"kill",
"killing":"kill",
"kills":"kill",
"killdeers":"killdeer",
"killers":"killer",
"killifishes":"killifish",
"killings":"killing",
"killjoys":"killjoy",
"kilned":"kiln",
"kilning":"kiln",
"kilns":"kiln",
"kilos":"kilo",
"kilobytes":"kilobyte",
"kilocalories":"kilocalorie",
"kilocycles":"kilocycle",
"kilograms":"kilogram",
"kilohertzes":"kilohertz",
"kilohertzs":"kilohertz",
"kiloliters":"kiloliter",
"kilolitres":"kilolitre",
"kilometers":"kilometer",
"kilometres":"kilometre",
"kilovolts":"kilovolt",
"kilowatts":"kilowatt",
"kilted":"kilt",
"kilting":"kilt",
"kimonos":"kimono",
"kins":"kin",
"kinaesthesias":"kinaesthesia",
"kinaestheses":"kinaesthesis",
"kinchinjungas":"kinchinjunga",
"kinder":"kind",
"kindest":"kind",
"kinds":"kind",
"kindergartens":"kindergarten",
"kindled":"kindle",
"kindles":"kindle",
"kindling":"kindle",
"kindlinesses":"kindliness",
"kindlings":"kindling",
"kindlier":"kindly",
"kindliest":"kindly",
"kindnesses":"kindness",
"kindreds":"kindred",
"kines":"kine",
"kinescopes":"kinescope",
"kinesthesias":"kinesthesia",
"kinestheses":"kinesthesis",
"kinestheticses":"kinesthetics",
"kineticses":"kinetics",
"kinfolks":"kinfolk",
"kinged":"king",
"kinging":"king",
"kings":"king",
"kings-of-arms":"king-of-arms",
"kingbirds":"kingbird",
"kingbolts":"kingbolt",
"kingcups":"kingcup",
"kingdoms":"kingdom",
"kingfishes":"kingfish",
"kingfishers":"kingfisher",
"kinglier":"kingly",
"kingliest":"kingly",
"kingpins":"kingpin",
"kingsnakes":"kingsnake",
"kingstons":"kingston",
"kingwoods":"kingwood",
"kinked":"kink",
"kinking":"kink",
"kinks":"kink",
"kinkajous":"kinkajou",
"kinkier":"kinky",
"kinkiest":"kinky",
"kinos":"kino",
"kinosternidaes":"kinosternidae",
"kinosternons":"kinosternon",
"kinsfolks":"kinsfolk",
"kinshasas":"kinshasa",
"kinships":"kinship",
"kinsmen":"kinsman",
"kinspersons":"kinsperson",
"kinswomen":"kinswoman",
"kiosks":"kiosk",
"kiowas":"kiowa",
"kipped":"kip",
"kipping":"kip",
"kips":"kip",
"kiplings":"kipling",
"kippered":"kipper",
"kippering":"kipper",
"kippers":"kipper",
"kirghizes":"kirghiz",
"kirghizs":"kirghiz",
"kirghizias":"kirghizia",
"kirghizstans":"kirghizstan",
"kirgizs":"kirgiz",
"kirgizias":"kirgizia",
"kirgizstans":"kirgizstan",
"kirks":"kirk",
"kirkias":"kirkia",
"kirkmen":"kirkman",
"kishinevs":"kishinev",
"kishkes":"kishke",
"kislevs":"kislev",
"kismats":"kismat",
"kismets":"kismet",
"kissed":"kiss",
"kisses":"kiss",
"kissing":"kiss",
"kiss-me-over-the-garden-gates":"kiss-me-over-the-garden-gate",
"kissers":"kisser",
"kissings":"kissing",
"kits":"kit",
"kitted":"kit",
"kitting":"kit",
"kitambillas":"kitambilla",
"kitbags":"kitbag",
"kitchens":"kitchen",
"kited":"kite",
"kites":"kite",
"kiting":"kite",
"kitembillas":"kitembilla",
"kittened":"kitten",
"kittening":"kitten",
"kittens":"kitten",
"kittler":"kittle",
"kittlest":"kittle",
"kittuls":"kittul",
"kitties":"kitty",
"kitty-cats":"kitty-cat",
"kituls":"kitul",
"kiwis":"kiwi",
"kkks":"kkk",
"klamaths":"klamath",
"klans":"klan",
"klansmen":"klansman",
"klaviers":"klavier",
"klaxons":"klaxon",
"kleenexes":"kleenex",
"klicks":"klick",
"klootchmans":"klootchman",
"klootchmen":"klootchman",
"klutzs":"klutz",
"kms":"km",
"km/hs":"km/h",
"knacks":"knack",
"knackwursts":"knackwurst",
"knapped":"knap",
"knapping":"knap",
"knaps":"knap",
"knapsacks":"knapsack",
"knaves":"knave",
"knaveries":"knavery",
"knawes":"knawe",
"knawels":"knawel",
"kneaded":"knead",
"kneading":"knead",
"kneads":"knead",
"kneed":"knee",
"kneeing":"knee",
"knees":"knee",
"kneecaps":"kneecap",
"kneeled":"kneel",
"kneeling":"kneel",
"kneels":"kneel",
"knelt":"kneel",
"kneelings":"kneeling",
"kneepans":"kneepan",
"knelled":"knell",
"knelling":"knell",
"knells":"knell",
"knessets":"knesset",
"knesseths":"knesseth",
"knickerbockerses":"knickerbockers",
"knickerses":"knickers",
"knickknacks":"knickknack",
"knickknackeries":"knickknackery",
"knickknackses":"knickknacks",
"knifed":"knife",
"knifing":"knife",
"knives":"knife",
"knighted":"knight",
"knighting":"knight",
"knights":"knight",
"knights-errant":"knight-errant",
"knight-errantries":"knight-errantry",
"knighthoods":"knighthood",
"knightias":"knightia",
"knightlier":"knightly",
"knightliest":"knightly",
"knights_bachelor":"knight_bachelor",
"knights_bachelors":"knight_bachelor",
"knights_templar":"knight_templar",
"knights_templars":"knight_templar",
"kniphofias":"kniphofia",
"knits":"knit",
"knitted":"knit",
"knitting":"knit",
"knittings":"knitting",
"knitworks":"knitwork",
"knobs":"knob",
"knobbier":"knobby",
"knobbiest":"knobby",
"knobkerries":"knobkerrie",
"knocked":"knock",
"knocking":"knock",
"knocks":"knock",
"knock-knees":"knock-knee",
"knockers":"knocker",
"knockings":"knocking",
"knockouts":"knockout",
"knockwursts":"knockwurst",
"knolled":"knoll",
"knolling":"knoll",
"knolls":"knoll",
"knots":"knot",
"knotted":"knot",
"knotting":"knot",
"knotgrasses":"knotgrass",
"knottinesses":"knottiness",
"knottier":"knotty",
"knottiest":"knotty",
"knouted":"knout",
"knouting":"knout",
"knew":"know",
"knowing":"know",
"known":"know",
"knows":"know",
"know-alls":"know-all",
"know-it-alls":"know-it-all",
"knowingnesses":"knowingness",
"knowledges":"knowledge",
"knuckled":"knuckle",
"knuckles":"knuckle",
"knuckling":"knuckle",
"knuckleballs":"knuckleball",
"knuckleboneses":"knucklebones",
"knuckleheads":"knucklehead",
"knucklers":"knuckler",
"knuckleses":"knuckles",
"knuckses":"knucks",
"knurlier":"knurly",
"knurliest":"knurly",
"kos":"ko",
"koalas":"koala",
"koans":"koan",
"kobs":"kob",
"kobenhavns":"kobenhavn",
"kobos":"kobo",
"kobuses":"kobus",
"kochias":"kochia",
"kodiaks":"kodiak",
"koellias":"koellia",
"kogias":"kogia",
"kohlrabies":"kohlrabi",
"kohlrabis":"kohlrabi",
"koines":"koine",
"kok-saghyzs":"kok-saghyz",
"kok-sagyzs":"kok-sagyz",
"kokkas":"kokka",
"kolas":"kola",
"kolinskies":"kolinsky",
"kolkhozes":"kolkhoz",
"kolkhozy":"kolkhoz",
"kolkwitzias":"kolkwitzia",
"kolns":"koln",
"kolos":"kolo",
"komis":"komi",
"konakris":"konakri",
"kondos":"kondo",
"kongos":"kongo",
"koninis":"konini",
"koodoos":"koodoo",
"kooks":"kook",
"kookaburras":"kookaburra",
"kookier":"kooky",
"kookiest":"kooky",
"kopecks":"kopeck",
"kopeks":"kopek",
"kopjes":"kopje",
"koppies":"koppie",
"kors":"kor",
"korans":"koran",
"kores":"kore",
"koreas":"korea",
"korinthoses":"korinthos",
"korun":"koruna",
"korunas":"koruna",
"koses":"kos",
"kosteletzyas":"kosteletzya",
"kotas":"kota",
"kotars":"kotar",
"kotos":"koto",
"kotows":"kotow",
"koudous":"koudou",
"koumisses":"koumiss",
"kovnas":"kovna",
"kovnos":"kovno",
"koweits":"koweit",
"kowhais":"kowhai",
"kowtowed":"kowtow",
"kowtowing":"kowtow",
"kowtows":"kowtow",
"kphs":"kph",
"krs":"kr",
"kraaled":"kraal",
"kraaling":"kraal",
"krafts":"kraft",
"krakataos":"krakatao",
"krakataus":"krakatau",
"krakatoas":"krakatoa",
"krakaus":"krakau",
"krakows":"krakow",
"krauts":"kraut",
"krautheads":"krauthead",
"krios":"krio",
"kronas":"krona",
"kronor":"krona",
"kroner":"krone",
"krones":"krone",
"krooni":"kroon",
"kroons":"kroon",
"krubis":"krubi",
"krummhorns":"krummhorn",
"krypterophanerons":"krypterophaneron",
"kryptons":"krypton",
"kus":"ku",
"ku-chikus":"ku-chiku",
"kuangchous":"kuangchou",
"kucheans":"kuchean",
"kudoses":"kudos",
"kudus":"kudu",
"kudzus":"kudzu",
"kuenluns":"kuenlun",
"kukenaams":"kukenaam",
"kukis":"kuki",
"kuki-chins":"kuki-chin",
"kukris":"kukri",
"kumises":"kumis",
"kumquats":"kumquat",
"kunluns":"kunlun",
"kuras":"kura",
"kurakkans":"kurakkan",
"kurchatoviums":"kurchatovium",
"kurchees":"kurchee",
"kurchis":"kurchi",
"kuri-chikus":"kuri-chiku",
"kuroshios":"kuroshio",
"kurrajongs":"kurrajong",
"kurrats":"kurrat",
"kurus":"kuru",
"kutches":"kutch",
"kuwaits":"kuwait",
"kvs":"kv",
"kvetched":"kvetch",
"kvetches":"kvetch",
"kvetching":"kvetch",
"kws":"kw",
"kw-hrs":"kw-hr",
"kwachas":"kwacha",
"kwais":"kwai",
"kwakiutls":"kwakiutl",
"kwan-yins":"kwan-yin",
"kwangchows":"kwangchow",
"kwanzas":"kwanza",
"kwanzaas":"kwanzaa",
"kweeks":"kweek",
"kylies":"kylie",
"kylikes":"kylix",
"kymographs":"kymograph",
"kyo-chikus":"kyo-chiku",
"kyphosidaes":"kyphosidae",
"kyphoses":"kyphosis",
"kyphosuses":"kyphosus",
"kyrgystans":"kyrgystan",
"ls":"l",
"l-ps":"l-p",
"las":"la",
"laagered":"laager",
"laagering":"laager",
"laagers":"laager",
"labs":"lab",
"labara":"labarum",
"labdanums":"labdanum",
"labeled":"label",
"labeling":"label",
"labelled":"label",
"labelling":"label",
"labels":"label",
"labella":"labellum",
"labials":"labial",
"labialized":"labialize",
"labializes":"labialize",
"labializing":"labialize",
"labiataes":"labiatae",
"labia":"labium",
"lablabs":"lablab",
"labored":"labor",
"laboring":"labor",
"labors":"labor",
"laboratories":"laboratory",
"laborers":"laborer",
"laboriousnesses":"laboriousness",
"laboured":"labour",
"labouring":"labour",
"labours":"labour",
"labourers":"labourer",
"labridaes":"labridae",
"labrocytes":"labrocyte",
"labra":"labrum",
"laburnums":"laburnum",
"labyrinths":"labyrinth",
"labyrinthitises":"labyrinthitis",
"labyrinthodontas":"labyrinthodonta",
"labyrinthodontias":"labyrinthodontia",
"laccopetalums":"laccopetalum",
"laced":"lace",
"laces":"lace",
"lacing":"lace",
"lacebarks":"lacebark",
"lacepods":"lacepod",
"lacerated":"lacerate",
"lacerating":"lacerate",
"lacertas":"lacerta",
"lacertids":"lacertid",
"lacertidaes":"lacertidae",
"lacertilias":"lacertilia",
"lacewings":"lacewing",
"lacewoods":"lacewood",
"lachnolaimuses":"lachnolaimus",
"lachrymations":"lachrymation",
"lachrymatories":"lachrymatory",
"lacings":"lacing",
"lacked":"lack",
"lacking":"lack",
"lacks":"lack",
"lackeys":"lackey",
"laconicisms":"laconicism",
"laconisms":"laconism",
"lacquered":"lacquer",
"lacquering":"lacquer",
"lacrimations":"lacrimation",
"lacrimators":"lacrimator",
"lactariuses":"lactarius",
"lactated":"lactate",
"lactates":"lactate",
"lactating":"lactate",
"lactobacillaceaes":"lactobacillaceae",
"lactobacilli":"lactobacillus",
"lactobacteriaceaes":"lactobacteriaceae",
"lactoflavins":"lactoflavin",
"lactophryses":"lactophrys",
"lactoses":"lactose",
"lactucas":"lactuca",
"lacunae":"lacuna",
"lacunas":"lacuna",
"lacunaria":"lacunar",
"lacunars":"lacunar",
"lacier":"lacy",
"laciest":"lacy",
"lads":"lad",
"ladanums":"ladanum",
"laddered":"ladder",
"laddering":"ladder",
"ladders":"ladder",
"ladder-backs":"ladder-back",
"laddies":"laddie",
"laded":"lade",
"laden":"lade",
"lades":"lade",
"lading":"lade",
"ladyfied":"ladify",
"ladyfies":"ladify",
"ladyfying":"ladify",
"ladings":"lading",
"ladinos":"ladino",
"ladled":"ladle",
"ladles":"ladle",
"ladling":"ladle",
"ladies":"lady",
"ladies-in-waiting":"lady-in-waiting",
"lady-of-the-nights":"lady-of-the-night",
"lady-slippers":"lady-slipper",
"ladybeetles":"ladybeetle",
"ladybirds":"ladybird",
"ladybugs":"ladybug",
"ladyfishes":"ladyfish",
"ladyships":"ladyship",
"laevuloses":"laevulose",
"lagged":"lag",
"lagging":"lag",
"lags":"lag",
"lagans":"lagan",
"lagarostrobuses":"lagarostrobus",
"lagenarias":"lagenaria",
"lagends":"lagend",
"lagenopheras":"lagenophera",
"lagers":"lager",
"lagerstroemias":"lagerstroemia",
"laggards":"laggard",
"lagidiums":"lagidium",
"lagodons":"lagodon",
"lagomorphs":"lagomorph",
"lagomorphas":"lagomorpha",
"lagoons":"lagoon",
"lagopuses":"lagopus",
"lagorchesteses":"lagorchestes",
"lagoses":"lagos",
"lagostomuses":"lagostomus",
"lagothrixes":"lagothrix",
"lagunas":"laguna",
"laguncularias":"laguncularia",
"lagunes":"lagune",
"lahs":"lah",
"laicized":"laicize",
"laicizes":"laicize",
"laicizing":"laicize",
"laired":"lair",
"lairing":"lair",
"lairs":"lair",
"lairier":"lairy",
"lairiest":"lairy",
"laities":"laity",
"lakes":"lake",
"lakelets":"lakelet",
"lakeshores":"lakeshore",
"lakesides":"lakeside",
"lakhs":"lakh",
"lakier":"laky",
"lakiest":"laky",
"lallanses":"lallans",
"lallies":"lally",
"lallygagged":"lallygag",
"lallygagging":"lallygag",
"lallygags":"lallygag",
"lammed":"lam",
"lamming":"lam",
"lams":"lam",
"lamas":"lama",
"lamarcks":"lamarck",
"lamaseries":"lamasery",
"lambed":"lamb",
"lambing":"lamb",
"lambs":"lamb",
"lambasted":"lambaste",
"lambastes":"lambaste",
"lambasting":"lambaste",
"lambdas":"lambda",
"lambencies":"lambency",
"lamberts":"lambert",
"lambertias":"lambertia",
"lambises":"lambis",
"lambkills":"lambkill",
"lambskins":"lambskin",
"lamed":"lame",
"lamer":"lame",
"lamest":"lame",
"laming":"lame",
"lamellae":"lamella",
"lamellas":"lamella",
"lamellibranches":"lamellibranch",
"lamellibranchias":"lamellibranchia",
"lamellicornias":"lamellicornia",
"lamenesses":"lameness",
"lamented":"lament",
"lamenting":"lament",
"laments":"lament",
"lamentations":"lamentation",
"lamenters":"lamenter",
"lamiae":"lamia",
"lamias":"lamia",
"lamiaceaes":"lamiaceae",
"laminae":"lamina",
"laminas":"lamina",
"laminarias":"laminaria",
"laminariaceaes":"laminariaceae",
"laminarialeses":"laminariales",
"laminated":"laminate",
"laminating":"laminate",
"laminectomies":"laminectomy",
"laminitises":"laminitis",
"lamiums":"lamium",
"lammases":"lammas",
"lammergeiers":"lammergeier",
"lammergeyers":"lammergeyer",
"lamnas":"lamna",
"lamnidaes":"lamnidae",
"lamps":"lamp",
"lampblacks":"lampblack",
"lampooned":"lampoon",
"lampooning":"lampoon",
"lampoons":"lampoon",
"lampooners":"lampooner",
"lampreys":"lamprey",
"lampridaes":"lampridae",
"lamprises":"lampris",
"lampropeltises":"lampropeltis",
"lampshades":"lampshade",
"lampshells":"lampshell",
"lampyridaes":"lampyridae",
"lans":"lan",
"lanais":"lanai",
"lancasters":"lancaster",
"lanced":"lance",
"lances":"lance",
"lancing":"lance",
"lancelets":"lancelet",
"lancelots":"lancelot",
"lancets":"lancet",
"lancetfishes":"lancetfish",
"lancewoods":"lancewood",
"lanchous":"lanchou",
"lanchows":"lanchow",
"lancinated":"lancinate",
"lancinating":"lancinate",
"landed":"land",
"landing":"land",
"lands":"land",
"landholders":"landholder",
"landings":"landing",
"landladies":"landlady",
"landlords":"landlord",
"landlubbers":"landlubber",
"landmen":"landman",
"landmarks":"landmark",
"landowners":"landowner",
"landrovers":"landrover",
"landscaped":"landscape",
"landscapes":"landscape",
"landscaping":"landscape",
"landscapings":"landscaping",
"landslides":"landslide",
"landslips":"landslip",
"landsmals":"landsmal",
"landsmen":"landsman",
"lanes":"lane",
"langobards":"langobard",
"langoustes":"langouste",
"langoustines":"langoustine",
"langsats":"langsat",
"langsets":"langset",
"langsides":"langside",
"langsynes":"langsyne",
"languages":"language",
"languished":"languish",
"languishes":"languish",
"languishing":"languish",
"languors":"languor",
"laniards":"laniard",
"laniaries":"laniary",
"laniidaes":"laniidae",
"laniuses":"lanius",
"lanker":"lank",
"lankest":"lank",
"lankier":"lanky",
"lankiest":"lanky",
"lanolins":"lanolin",
"lansas":"lansa",
"lansats":"lansat",
"lansehs":"lanseh",
"lansets":"lanset",
"lansings":"lansing",
"lanterns":"lantern",
"lanternflies":"lanternfly",
"lanthanides":"lanthanide",
"lanthanons":"lanthanon",
"lanthanotidaes":"lanthanotidae",
"lanthanotuses":"lanthanotus",
"lanthanums":"lanthanum",
"lanugos":"lanugo",
"lanyards":"lanyard",
"lanzhous":"lanzhou",
"laos":"lao",
"lao-tses":"lao-tse",
"lao-tzus":"lao-tzu",
"laotians":"laotian",
"laozis":"laozi",
"lapped":"lap",
"lapping":"lap",
"laps":"lap",
"laparotomies":"laparotomy",
"lapfuls":"lapful",
"lapidarists":"lapidarist",
"lapidaries":"lapidary",
"lapidated":"lapidate",
"lapidates":"lapidate",
"lapidating":"lapidate",
"lapidified":"lapidify",
"lapidifies":"lapidify",
"lapidifying":"lapidify",
"lapidists":"lapidist",
"lapilli":"lapillus",
"lapins":"lapin",
"lapithae":"lapith",
"lapiths":"lapith",
"laplands":"lapland",
"laporteas":"laportea",
"lapps":"lapp",
"lappets":"lappet",
"lappics":"lappic",
"lappings":"lapping",
"lappishes":"lappish",
"lapplands":"lappland",
"lapplanders":"lapplander",
"lappulas":"lappula",
"lapsed":"lapse",
"lapses":"lapse",
"lapsing":"lapse",
"lapsings":"lapsing",
"laptops":"laptop",
"lapwings":"lapwing",
"lares":"lar",
"larboards":"larboard",
"larceners":"larcener",
"larcenists":"larcenist",
"larcenouses":"larcenous",
"larcenies":"larceny",
"larches":"larch",
"larded":"lard",
"larding":"lard",
"lards":"lard",
"larders":"larder",
"lardizabalas":"lardizabala",
"lardizabalaceaes":"lardizabalaceae",
"lardier":"lardy",
"lardiest":"lardy",
"larger":"large",
"largest":"large",
"largemouths":"largemouth",
"largenesses":"largeness",
"largesses":"largess",
"larghettos":"larghetto",
"largos":"largo",
"laris":"lari",
"lariats":"lariat",
"laricariidaes":"laricariidae",
"laridaes":"laridae",
"larixes":"larix",
"larked":"lark",
"larking":"lark",
"larks":"lark",
"larreas":"larrea",
"larruped":"larrup",
"larruping":"larrup",
"larrups":"larrup",
"laruses":"larus",
"larvae":"larva",
"larvas":"larva",
"larvaceas":"larvacea",
"laryngectomies":"laryngectomy",
"laryngotomies":"laryngotomy",
"larynges":"larynx",
"larynxes":"larynx",
"lasagnas":"lasagna",
"lasagnes":"lasagne",
"lasciviousnesses":"lasciviousness",
"lased":"lase",
"lasing":"lase",
"lasers":"laser",
"lashed":"lash",
"lashes":"lash",
"lashing":"lash",
"lash-ups":"lash-up",
"lashings":"lashing",
"lashingses":"lashings",
"lasiocampas":"lasiocampa",
"lasiocampids":"lasiocampid",
"lasiocampidaes":"lasiocampidae",
"lasiuruses":"lasiurus",
"lasses":"lass",
"lassas":"lassa",
"lassies":"lassie",
"lassitudes":"lassitude",
"lassoed":"lasso",
"lassoes":"lasso",
"lassoing":"lasso",
"lassos":"lasso",
"lasted":"last",
"lasting":"last",
"lasts":"last",
"lasthenias":"lasthenia",
"lastingnesses":"lastingness",
"lastreopses":"lastreopsis",
"lats":"lat",
"latched":"latch",
"latches":"latch",
"latching":"latch",
"latchkeys":"latchkey",
"leaves":"leave",
"later":"late",
"latest":"late",
"latter":"late",
"lateens":"lateen",
"latened":"laten",
"latening":"laten",
"latencies":"latency",
"lateraled":"lateral",
"lateraling":"lateral",
"laterals":"lateral",
"lateralities":"laterality",
"latexes":"latex",
"latices":"latex",
"lathed":"lath",
"lathing":"lath",
"laths":"lath",
"lathes":"lathe",
"lathees":"lathee",
"lathered":"lather",
"lathering":"lather",
"lathers":"lather",
"lathis":"lathi",
"lathier":"lathy",
"lathiest":"lathy",
"lathyruses":"lathyrus",
"latifundia":"latifundium",
"latigoes":"latigo",
"latigos":"latigo",
"latimerias":"latimeria",
"latimeridaes":"latimeridae",
"latinos":"latino",
"latitudes":"latitude",
"latiums":"latium",
"latkes":"latke",
"latonas":"latona",
"latrias":"latria",
"latrodectuses":"latrodectus",
"latticed":"lattice",
"lattices":"lattice",
"latticing":"lattice",
"latticeworks":"latticework",
"Latvians":"Latvian",
"lauded":"laud",
"lauding":"laud",
"lauds":"laud",
"laudanums":"laudanum",
"laudators":"laudator",
"lauders":"lauder",
"laughed":"laugh",
"laughing":"laugh",
"laughs":"laugh",
"laughers":"laugher",
"laughingstocks":"laughingstock",
"laughters":"laughter",
"lauhalas":"lauhala",
"launces":"launce",
"launched":"launch",
"launches":"launch",
"launching":"launch",
"launchers":"launcher",
"launchings":"launching",
"launchpads":"launchpad",
"laundered":"launder",
"laundering":"launder",
"launders":"launder",
"laundresses":"laundress",
"laundries":"laundry",
"laundrymen":"laundryman",
"laundrywomen":"laundrywoman",
"lauraceaes":"lauraceae",
"laureled":"laurel",
"laureling":"laurel",
"laurelled":"laurel",
"laurelling":"laurel",
"laurels":"laurel",
"laurel-trees":"laurel-tree",
"laurelses":"laurels",
"laurelwoods":"laurelwood",
"lauruses":"laurus",
"lavs":"lav",
"lavaboes":"lavabo",
"lavaliers":"lavalier",
"lavalieres":"lavaliere",
"lavallieres":"lavalliere",
"lavandulas":"lavandula",
"lavateras":"lavatera",
"lavations":"lavation",
"lavatories":"lavatory",
"laved":"lave",
"laves":"lave",
"laving":"lave",
"lavendered":"lavender",
"lavendering":"lavender",
"lavers":"laver",
"lavished":"lavish",
"lavishes":"lavish",
"lavishing":"lavish",
"lavishnesses":"lavishness",
"laws":"law",
"law-breakings":"law-breaking",
"law-makerses":"law-makers",
"lawbreakers":"lawbreaker",
"lawgivers":"lawgiver",
"lawlessnesses":"lawlessness",
"lawmakers":"lawmaker",
"lawmakings":"lawmaking",
"lawmen":"lawman",
"lawns":"lawn",
"lawrenciums":"lawrencium",
"lawses":"laws",
"lawsuits":"lawsuit",
"lawyers":"lawyer",
"lawyerbushes":"lawyerbush",
"laxer":"lax",
"laxest":"lax",
"laxatives":"laxative",
"laxities":"laxity",
"laxnesses":"laxness",
"laid":"lay",
"laying":"lay",
"lays":"lay",
"layabouts":"layabout",
"laybies":"layby",
"layered":"layer",
"layering":"layer",
"layers":"layer",
"layias":"layia",
"layings":"laying",
"laymen":"layman",
"layouts":"layout",
"layovers":"layover",
"laypersons":"layperson",
"laywomen":"laywoman",
"lazars":"lazar",
"lazarets":"lazaret",
"lazarettes":"lazarette",
"lazarettos":"lazaretto",
"lazed":"laze",
"lazes":"laze",
"lazing":"laze",
"lazinesses":"laziness",
"lazios":"lazio",
"lazulis":"lazuli",
"lazulines":"lazuline",
"lazier":"lazy",
"laziest":"lazy",
"lbs":"lb",
"LCDs":"LCD",
"lcms":"lcm",
"ldls":"ldl",
"les":"le",
"leas":"lea",
"leached":"leach",
"leaches":"leach",
"leaching":"leach",
"leachings":"leaching",
"leading":"lead",
"leads":"lead",
"led":"lead",
"lead-ins":"lead-in",
"leaders":"leader",
"leaderses":"leaders",
"leaderships":"leadership",
"leadings":"leading",
"leadplants":"leadplant",
"leadsmen":"leadsman",
"leadworts":"leadwort",
"leadier":"leady",
"leadiest":"leady",
"leafed":"leaf",
"leafing":"leaf",
"leafs":"leaf",
"leaves":"leaf",
"leaf-cutters":"leaf-cutter",
"leafages":"leafage",
"leafings":"leafing",
"leafleted":"leaflet",
"leafleting":"leaflet",
"leaflets":"leaflet",
"leafletted":"leaflet",
"leafletting":"leaflet",
"leafminers":"leafminer",
"leafrollers":"leafroller",
"leafstalks":"leafstalk",
"leafier":"leafy",
"leafiest":"leafy",
"leagued":"league",
"leagues":"league",
"leaguing":"league",
"leaguered":"leaguer",
"leaguering":"leaguer",
"leaked":"leak",
"leaking":"leak",
"leaks":"leak",
"leakages":"leakage",
"leakeys":"leakey",
"leakier":"leaky",
"leakiest":"leaky",
"leaned":"lean",
"leaner":"lean",
"leanest":"lean",
"leaning":"lean",
"leans":"lean",
"leant":"lean",
"lean-tos":"lean-to",
"leanings":"leaning",
"leannesses":"leanness",
"leaped":"leap",
"leaping":"leap",
"leaps":"leap",
"leapt":"leap",
"leapfrogged":"leapfrog",
"leapfrogging":"leapfrog",
"leapfrogs":"leapfrog",
"leapings":"leaping",
"lears":"lear",
"learned":"learn",
"learning":"learn",
"learns":"learn",
"learnt":"learn",
"learnednesses":"learnedness",
"learners":"learner",
"learnings":"learning",
"learier":"leary",
"leariest":"leary",
"leased":"lease",
"leases":"lease",
"leasing":"lease",
"lease-lends":"lease-lend",
"leaseholders":"leaseholder",
"leashed":"leash",
"leashes":"leash",
"leashing":"leash",
"leathered":"leather",
"leathering":"leather",
"leathers":"leather",
"leatherbacks":"leatherback",
"leatherettes":"leatherette",
"leatherfishes":"leatherfish",
"leatherjacks":"leatherjack",
"leatherjackets":"leatherjacket",
"leatherleaves":"leatherleaf",
"leathernecks":"leatherneck",
"leatherwoods":"leatherwood",
"leaving":"leave",
"left":"leave",
"leave-takings":"leave-taking",
"leavened":"leaven",
"leavening":"leaven",
"leavens":"leaven",
"leavenings":"leavening",
"leavers":"leaver",
"leaves_undone":"leave_undone",
"leaving_undone":"leave_undone",
"left_undone":"leave_undone",
"leavings":"leaving",
"leavier":"leavy",
"leaviest":"leavy",
"lebensraums":"lebensraum",
"lebisteses":"lebistes",
"lecanoraceaes":"lecanoraceae",
"leccinums":"leccinum",
"leched":"lech",
"leching":"lech",
"lechanoraleses":"lechanorales",
"lechatelierites":"lechatelierite",
"lechers":"lecher",
"lecherousnesses":"lecherousness",
"lecheries":"lechery",
"lechwes":"lechwe",
"lecterns":"lectern",
"lectionaries":"lectionary",
"lectors":"lector",
"lectured":"lecture",
"lectures":"lecture",
"lecturing":"lecture",
"lecturers":"lecturer",
"lecturings":"lecturing",
"lecythidaceaes":"lecythidaceae",
"lecythi":"lecythus",
"leds":"led",
"ledges":"ledge",
"ledgemen":"ledgeman",
"ledgers":"ledger",
"ledums":"ledum",
"lees":"lee",
"leeched":"leech",
"leeches":"leech",
"leeching":"leech",
"leechees":"leechee",
"leeks":"leek",
"leered":"leer",
"leering":"leer",
"leers":"leer",
"leerier":"leery",
"leeriest":"leery",
"leewards":"leeward",
"leeways":"leeway",
"lefter":"left",
"leftest":"left",
"lefts":"left",
"left-handednesses":"left-handedness",
"left-handers":"left-hander",
"left-wingers":"left-winger",
"leftfields":"leftfield",
"leftists":"leftist",
"leftovers":"leftover",
"lefties":"lefty",
"legged":"leg",
"legging":"leg",
"legs":"leg",
"leg-pulls":"leg-pull",
"leg-pullings":"leg-pulling",
"legacies":"legacy",
"legalisations":"legalisation",
"legalists":"legalist",
"legalities":"legality",
"legalizations":"legalization",
"legalized":"legalize",
"legalizes":"legalize",
"legalizing":"legalize",
"legates":"legate",
"legateships":"legateship",
"legations":"legation",
"legatos":"legato",
"legends":"legend",
"legendaries":"legendary",
"legendized":"legendize",
"legendizing":"legendize",
"legers":"leger",
"legerdemains":"legerdemain",
"legerities":"legerity",
"leggings":"legging",
"leggier":"leggy",
"leggiest":"leggy",
"leghorns":"leghorn",
"legibilities":"legibility",
"legins":"legin",
"legions":"legion",
"legionaries":"legionary",
"legionnaires":"legionnaire",
"legislated":"legislate",
"legislates":"legislate",
"legislating":"legislate",
"legislatings":"legislating",
"legislations":"legislation",
"legislatives":"legislative",
"legislators":"legislator",
"legislatures":"legislature",
"legitimacies":"legitimacy",
"legitimated":"legitimate",
"legitimates":"legitimate",
"legitimating":"legitimate",
"legitimatized":"legitimatize",
"legitimatizes":"legitimatize",
"legitimatizing":"legitimatize",
"legitimized":"legitimize",
"legitimizes":"legitimize",
"legitimizing":"legitimize",
"legmen":"legman",
"legumes":"legume",
"leguminosaes":"leguminosae",
"lehuas":"lehua",
"leis":"lei",
"leibnitzs":"leibnitz",
"leibnizs":"leibniz",
"leicesters":"leicester",
"leicestershires":"leicestershire",
"leidens":"leiden",
"leiopelmas":"leiopelma",
"leiopelmatidaes":"leiopelmatidae",
"leiophyllums":"leiophyllum",
"leipoas":"leipoa",
"leistered":"leister",
"leistering":"leister",
"leisures":"leisure",
"leitmotives":"leitmotif",
"leitmotivs":"leitmotiv",
"leitnerias":"leitneria",
"leitneriaceaes":"leitneriaceae",
"leke":"lek",
"leks":"lek",
"lems":"lem",
"lemaireocereuses":"lemaireocereus",
"lemanderins":"lemanderin",
"lemmas":"lemma",
"lemmata":"lemma",
"lemmuses":"lemmus",
"lemnas":"lemna",
"lemnaceaes":"lemnaceae",
"lemnisci":"lemniscus",
"lemniscuses":"lemniscus",
"lemnoses":"lemnos",
"lemons":"lemon",
"lemonwoods":"lemonwood",
"lempiras":"lempira",
"lemuridaes":"lemuridae",
"lemuroideas":"lemuroidea",
"lenas":"lena",
"lending":"lend",
"lends":"lend",
"lent":"lend",
"lend-leased":"lend-lease",
"lend-leases":"lend-lease",
"lend-leasing":"lend-lease",
"lenders":"lender",
"lengths":"length",
"lengthened":"lengthen",
"lengthening":"lengthen",
"lengthenings":"lengthening",
"lengthinesses":"lengthiness",
"lengthmen":"lengthman",
"lengthier":"lengthy",
"lengthiest":"lengthy",
"leniences":"lenience",
"leniencies":"leniency",
"lenins":"lenin",
"leningrads":"leningrad",
"leninisms":"leninism",
"lenes":"lenis",
"lenities":"lenity",
"lennoaceaes":"lennoaceae",
"lenos":"leno",
"lensed":"lens",
"lenses":"lens",
"lensing":"lens",
"lents":"lent",
"lententides":"lententide",
"lentibulariaceaes":"lentibulariaceae",
"lentigines":"lentigo",
"lentils":"lentil",
"lentinuses":"lentinus",
"lentos":"lento",
"leos":"leo",
"leonardos":"leonardo",
"leoncitas":"leoncita",
"leonides":"leonid",
"leonids":"leonid",
"leonotises":"leonotis",
"leontocebuses":"leontocebus",
"leontodons":"leontodon",
"leontopodiums":"leontopodium",
"leonuruses":"leonurus",
"leopards":"leopard",
"leopardbanes":"leopardbane",
"leopoldvilles":"leopoldville",
"lepadidaes":"lepadidae",
"lepantos":"lepanto",
"lepases":"lepas",
"lepchas":"lepcha",
"lepechinias":"lepechinia",
"lepers":"leper",
"lepidiums":"lepidium",
"lepidobotryaceaes":"lepidobotryaceae",
"lepidochelyses":"lepidochelys",
"lepidocybiums":"lepidocybium",
"lepidodendraceaes":"lepidodendraceae",
"lepidodendraleses":"lepidodendrales",
"lepidopteras":"lepidoptera",
"lepidopterans":"lepidopteran",
"lepidopterists":"lepidopterist",
"lepidoptera":"lepidopteron",
"lepidopterons":"lepidopteron",
"lepidosaurias":"lepidosauria",
"lepidothamnuses":"lepidothamnus",
"lepiotaceaes":"lepiotaceae",
"lepismas":"lepisma",
"lepismatidaes":"lepismatidae",
"lepisosteidaes":"lepisosteidae",
"lepisosteuses":"lepisosteus",
"lepomises":"lepomis",
"leporids":"leporid",
"leporidaes":"leporidae",
"leporides":"leporide",
"leppies":"leppy",
"leprosaria":"leprosarium",
"leprosies":"leprosy",
"leptarrhenas":"leptarrhena",
"leptinotarsas":"leptinotarsa",
"leptocephali":"leptocephalus",
"leptodactylids":"leptodactylid",
"leptodactylidaes":"leptodactylidae",
"leptodactyluses":"leptodactylus",
"leptoglossuses":"leptoglossus",
"lepta":"lepton",
"leptopterises":"leptopteris",
"leptoptiluses":"leptoptilus",
"leptospiroses":"leptospirosis",
"leptotyphlopidaes":"leptotyphlopidae",
"leptotyphlopses":"leptotyphlops",
"lepuses":"lepus",
"lers":"ler",
"lesbians":"lesbian",
"lesbianisms":"lesbianism",
"lesboses":"lesbos",
"lesions":"lesion",
"lesothos":"lesotho",
"lespedezas":"lespedeza",
"lesquerellas":"lesquerella",
"lessees":"lessee",
"lessened":"lessen",
"lessening":"lessen",
"lessens":"lessen",
"lessenings":"lessening",
"lessoned":"lesson",
"lessoning":"lesson",
"lessons":"lesson",
"lessors":"lessor",
"lesvoses":"lesvos",
"lets":"let",
"letting":"let",
"letdowns":"letdown",
"lethalities":"lethality",
"lethargies":"lethargy",
"lethes":"lethe",
"letos":"leto",
"lettered":"letter",
"lettering":"letter",
"letters":"letter",
"letterheads":"letterhead",
"letterings":"lettering",
"lettermen":"letterman",
"letterpresses":"letterpress",
"lettings":"letting",
"lettishes":"lettish",
"lettuces":"lettuce",
"letups":"letup",
"lei":"leu",
"leucadendrons":"leucadendron",
"leucaenas":"leucaena",
"leucanthemums":"leucanthemum",
"leuciscuses":"leuciscus",
"leucocytes":"leucocyte",
"leucocytozoans":"leucocytozoan",
"leucocytozoons":"leucocytozoon",
"leucogeneses":"leucogenes",
"leucopenias":"leucopenia",
"leucorrheas":"leucorrhea",
"leuctras":"leuctra",
"leukaemias":"leukaemia",
"leukemias":"leukemia",
"leukerans":"leukeran",
"leukocytes":"leukocyte",
"leukopenias":"leukopenia",
"leukorrheas":"leukorrhea",
"leukoses":"leukosis",
"leva":"lev",
"levanted":"levant",
"levanting":"levant",
"leveed":"levee",
"leveeing":"levee",
"levees":"levee",
"leveled":"level",
"leveling":"level",
"levelled":"level",
"levelling":"level",
"levels":"level",
"levelers":"leveler",
"levelings":"leveling",
"levellers":"leveller",
"levered":"lever",
"levering":"lever",
"levers":"lever",
"leverages":"leverage",
"leveragings":"leveraging",
"levis":"levi",
"levigated":"levigate",
"levigating":"levigate",
"levises":"levis",
"levisticums":"levisticum",
"levitated":"levitate",
"levitates":"levitate",
"levitating":"levitate",
"levities":"levity",
"levuloses":"levulose",
"levied":"levy",
"levies":"levy",
"levying":"levy",
"lewder":"lewd",
"lewdest":"lewd",
"lewdnesses":"lewdness",
"lewisias":"lewisia",
"leges":"lex",
"lexicographers":"lexicographer",
"lexicologists":"lexicologist",
"lexica":"lexicon",
"lexicons":"lexicon",
"lexingtons":"lexington",
"leys":"ley",
"leycesterias":"leycesteria",
"leydens":"leyden",
"leymuses":"leymus",
"leytes":"leyte",
"lfs":"lf",
"lhs":"lh",
"lhasas":"lhasa",
"lis":"li",
"liabilities":"liability",
"liaised":"liaise",
"liaises":"liaise",
"liaising":"liaise",
"liaisons":"liaison",
"liakouras":"liakoura",
"liars":"liar",
"liatrises":"liatris",
"libbers":"libber",
"libeled":"libel",
"libeling":"libel",
"libelled":"libel",
"libelling":"libel",
"libels":"libel",
"libelers":"libeler",
"liberals":"liberal",
"liberalisations":"liberalisation",
"liberalities":"liberality",
"liberalizations":"liberalization",
"liberalized":"liberalize",
"liberalizing":"liberalize",
"liberalnesses":"liberalness",
"liberated":"liberate",
"liberates":"liberate",
"liberating":"liberate",
"liberations":"liberation",
"liberators":"liberator",
"libertines":"libertine",
"liberties":"liberty",
"libidos":"libido",
"libocedruses":"libocedrus",
"librae":"libra",
"Libras":"Libra",
"librarians":"librarian",
"libraries":"library",
"libretti":"libretto",
"librettos":"libretto",
"librevilles":"libreville",
"libriums":"librium",
"licenced":"licence",
"licences":"licence",
"licencing":"licence",
"licencees":"licencee",
"licensed":"license",
"licenses":"license",
"licensing":"license",
"licensees":"licensee",
"licentiousnesses":"licentiousness",
"lichanuras":"lichanura",
"lichees":"lichee",
"lichened":"lichen",
"lichening":"lichen",
"lichenaleses":"lichenales",
"licheneses":"lichenes",
"lichgates":"lichgate",
"lichis":"lichi",
"licked":"lick",
"licking":"lick",
"licks":"lick",
"lickings":"licking",
"licorices":"licorice",
"lids":"lid",
"lidos":"lido",
"lidocaines":"lidocaine",
"lain":"lie",
"lay":"lie",
"lied":"lie",
"lies":"lie",
"lying":"lie",
"lie-abeds":"lie-abed",
"lieder":"lied",
"lieges":"liege",
"liegemen":"liegeman",
"liens":"lien",
"lietuvas":"lietuva",
"lieus":"lieu",
"lieutenants":"lieutenant",
"lives":"life",
"life-of-men":"life-of-man",
"life-styles":"life-style",
"lifeboats":"lifeboat",
"lifeguarded":"lifeguard",
"lifeguarding":"lifeguard",
"lifeguards":"lifeguard",
"lifelessnesses":"lifelessness",
"lifelines":"lifeline",
"lifesavers":"lifesaver",
"lifespans":"lifespan",
"lifestyles":"lifestyle",
"lifetimes":"lifetime",
"lifted":"lift",
"lifting":"lift",
"lifts":"lift",
"liftboys":"liftboy",
"lifters":"lifter",
"liftmen":"liftman",
"ligans":"ligan",
"ligated":"ligate",
"ligating":"ligate",
"ligatured":"ligature",
"ligatures":"ligature",
"ligaturing":"ligature",
"lighted":"light",
"lighter":"light",
"lightest":"light",
"lighting":"light",
"lights":"light",
"lit":"light",
"light-horsemen":"light-horseman",
"light-mindednesses":"light-mindedness",
"light-of-loves":"light-of-love",
"lightbulbs":"lightbulb",
"lightened":"lighten",
"lightening":"lighten",
"lightens":"lighten",
"lightenings":"lightening",
"lightered":"lighter",
"lightering":"lighter",
"lighters":"lighter",
"lightermen":"lighterman",
"lightheadednesses":"lightheadedness",
"lightheartednesses":"lightheartedness",
"lighthouses":"lighthouse",
"lightings":"lighting",
"lightlessnesses":"lightlessness",
"lightnesses":"lightness",
"lightninged":"lightning",
"lights-outs":"lights-out",
"lightsomenesses":"lightsomeness",
"lightweights":"lightweight",
"lightwoods":"lightwood",
"lignified":"lignify",
"lignifies":"lignify",
"lignifying":"lignify",
"lignites":"lignite",
"ligulae":"ligula",
"ligulas":"ligula",
"ligularias":"ligularia",
"ligustrums":"ligustrum",
"liked":"like",
"liker":"like",
"likes":"like",
"likest":"like",
"liking":"like",
"likelihoods":"likelihood",
"likelinesses":"likeliness",
"likened":"liken",
"likening":"liken",
"likens":"liken",
"likenesses":"likeness",
"makuta":"likuta",
"lilacs":"lilac",
"emalangeni":"lilangeni",
"liliaceaes":"liliaceae",
"lilialeses":"liliales",
"liliidaes":"liliidae",
"liliopsids":"liliopsid",
"liliopsidas":"liliopsida",
"liliums":"lilium",
"lilos":"lilo",
"lilted":"lilt",
"lilting":"lilt",
"lilts":"lilt",
"lilies":"lily",
"liliesofthevalley":"lilyofthevalley",
"lilyturfs":"lilyturf",
"lilyturves":"lilyturf",
"limas":"lima",
"limacidaes":"limacidae",
"limandas":"limanda",
"limaxes":"limax",
"limbed":"limb",
"limbing":"limb",
"limbs":"limb",
"limbered":"limber",
"limbering":"limber",
"limbers":"limber",
"limbos":"limbo",
"limbi":"limbus",
"limbui":"limbus",
"limed":"lime",
"limes":"lime",
"liming":"lime",
"limelighted":"limelight",
"limelighting":"limelight",
"limelights":"limelight",
"limelit":"limelight",
"limens":"limen",
"limina":"limen",
"limenitises":"limenitis",
"limericks":"limerick",
"limites":"limes",
"limeys":"limey",
"limicolaes":"limicolae",
"limited":"limit",
"limiting":"limit",
"limits":"limit",
"limitations":"limitation",
"limiteds":"limited",
"limiters":"limiter",
"limitings":"limiting",
"limitlessnesses":"limitlessness",
"limned":"limn",
"limning":"limn",
"limns":"limn",
"limners":"limner",
"limnings":"limning",
"limnobiums":"limnobium",
"limnocrypteses":"limnocryptes",
"limnodromuses":"limnodromus",
"limnoses":"limnos",
"limos":"limo",
"limoniums":"limonium",
"limosas":"limosa",
"limousines":"limousine",
"limped":"limp",
"limping":"limp",
"limps":"limp",
"limpidities":"limpidity",
"limpings":"limping",
"limpkins":"limpkin",
"limpnesses":"limpness",
"limpopos":"limpopo",
"limulidaes":"limulidae",
"limuluses":"limulus",
"limier":"limy",
"limiest":"limy",
"linacs":"linac",
"linaceaes":"linaceae",
"linages":"linage",
"linanthuses":"linanthus",
"linarias":"linaria",
"linchpins":"linchpin",
"lincolns":"lincoln",
"linctuses":"linctus",
"lindens":"linden",
"linderas":"lindera",
"lindheimeras":"lindheimera",
"lindies":"lindy",
"lined":"line",
"lines":"line",
"lining":"line",
"line-shooters":"line-shooter",
"line-shootings":"line-shooting",
"lineages":"lineage",
"lineaments":"lineament",
"linearities":"linearity",
"linebackers":"linebacker",
"linecuts":"linecut",
"linemen":"lineman",
"linens":"linen",
"liners":"liner",
"linesmen":"linesman",
"lineups":"lineup",
"lings":"ling",
"ling-paos":"ling-pao",
"lingberries":"lingberry",
"lingcods":"lingcod",
"lingenberries":"lingenberry",
"lingered":"linger",
"lingering":"linger",
"lingers":"linger",
"lingerers":"lingerer",
"lingerings":"lingering",
"lingoes":"lingo",
"lingonberries":"lingonberry",
"linguae":"lingua",
"linguas":"lingua",
"linguae_francae":"lingua_franca",
"lingua_francas":"lingua_franca",
"linguines":"linguine",
"linguinis":"linguini",
"linguists":"linguist",
"linguisticses":"linguistics",
"liniments":"liniment",
"linings":"lining",
"linked":"link",
"linking":"link",
"links":"link",
"linkboys":"linkboy",
"linkmen":"linkman",
"linkses":"links",
"linksmen":"linksman",
"linkups":"linkup",
"linnaeas":"linnaea",
"linnaeuses":"linnaeus",
"linnets":"linnet",
"linos":"lino",
"linoleums":"linoleum",
"linotyped":"linotype",
"linotyping":"linotype",
"linseeds":"linseed",
"lintels":"lintel",
"linters":"linter",
"lintier":"linty",
"lintiest":"linty",
"linier":"liny",
"liniest":"liny",
"liomyses":"liomys",
"lions":"lion",
"lionesses":"lioness",
"lionfishes":"lionfish",
"lionized":"lionize",
"lionizes":"lionize",
"lionizing":"lionize",
"liopelmas":"liopelma",
"liopelmidaes":"liopelmidae",
"lipped":"lip",
"lipping":"lip",
"lips":"lip",
"lip-reading":"lip-read",
"lip-reads":"lip-read",
"lip-synced":"lip-sync",
"lip-syncing":"lip-sync",
"lip-syncs":"lip-sync",
"liparidaes":"liparidae",
"liparididaes":"liparididae",
"liparises":"liparis",
"lipectomies":"lipectomy",
"lipferns":"lipfern",
"lipids":"lipid",
"lipides":"lipide",
"lipoids":"lipoid",
"lipomas":"lipoma",
"lipomata":"lipoma",
"liposcelises":"liposcelis",
"lipotyphlas":"lipotyphla",
"lippier":"lippy",
"lippiest":"lippy",
"lipsticks":"lipstick",
"liquated":"liquate",
"liquating":"liquate",
"liquefied":"liquefy",
"liquefies":"liquefy",
"liquefying":"liquefy",
"liqueurs":"liqueur",
"liquids":"liquid",
"liquidambars":"liquidambar",
"liquidated":"liquidate",
"liquidates":"liquidate",
"liquidating":"liquidate",
"liquidations":"liquidation",
"liquidators":"liquidator",
"liquidities":"liquidity",
"liquidized":"liquidize",
"liquidizes":"liquidize",
"liquidizing":"liquidize",
"liquidizers":"liquidizer",
"liquidnesses":"liquidness",
"liquified":"liquify",
"liquifies":"liquify",
"liquifying":"liquify",
"liquored":"liquor",
"liquoring":"liquor",
"liquors":"liquor",
"liquorices":"liquorice",
"lirs":"lir",
"liras":"lira",
"lire":"lira",
"liriodendrons":"liriodendron",
"liriopes":"liriope",
"lisboas":"lisboa",
"lisbons":"lisbon",
"lisinoprils":"lisinopril",
"lisped":"lisp",
"lisping":"lisp",
"lisps":"lisp",
"lissomenesses":"lissomeness",
"listed":"list",
"listing":"list",
"lists":"list",
"listened":"listen",
"listening":"listen",
"listens":"listen",
"listeners":"listener",
"listenings":"listening",
"listers":"lister",
"listeras":"listera",
"listings":"listing",
"listlessnesses":"listlessness",
"litai":"lit",
"lits":"lit",
"litanies":"litany",
"litu":"litas",
"litchees":"litchee",
"litchis":"litchi",
"liters":"liter",
"literals":"literal",
"literalists":"literalist",
"literalities":"literality",
"literalized":"literalize",
"literalizing":"literalize",
"literates":"literate",
"literatures":"literature",
"lithanes":"lithane",
"lither":"lithe",
"lithest":"lithe",
"lithenesses":"litheness",
"lithiases":"lithiasis",
"lithified":"lithify",
"lithifying":"lithify",
"lithiums":"lithium",
"lithos":"litho",
"lithocarpuses":"lithocarpus",
"lithodidaes":"lithodidae",
"lithoglypticses":"lithoglyptics",
"lithographed":"lithograph",
"lithographing":"lithograph",
"lithographs":"lithograph",
"lithonates":"lithonate",
"lithophragmas":"lithophragma",
"lithophytes":"lithophyte",
"lithopses":"lithops",
"lithospermums":"lithospermum",
"lithospheres":"lithosphere",
"lithotomies":"lithotomy",
"lithotrities":"lithotrity",
"lithuanias":"lithuania",
"litigants":"litigant",
"litigated":"litigate",
"litigates":"litigate",
"litigating":"litigate",
"litigators":"litigator",
"litmuses":"litmus",
"litocraniuses":"litocranius",
"litorals":"litoral",
"litoteses":"litotes",
"litres":"litre",
"littered":"litter",
"littering":"litter",
"litters":"litter",
"litter-bearers":"litter-bearer",
"litterateurs":"litterateur",
"litterbaskets":"litterbasket",
"litterbins":"litterbin",
"litterbugs":"litterbug",
"litterers":"litterer",
"least":"little",
"less":"little",
"lesser":"little",
"littler":"little",
"littlest":"little",
"littlenecks":"littleneck",
"littlenesses":"littleness",
"littorals":"littoral",
"littorinas":"littorina",
"littorinidaes":"littorinidae",
"liturgies":"liturgy",
"lived":"live",
"liver":"live",
"livest":"live",
"living":"live",
"live-and-dies":"live-and-die",
"live-bearers":"live-bearer",
"live-forevers":"live-forever",
"livelihoods":"livelihood",
"livelinesses":"liveliness",
"livelongs":"livelong",
"livelier":"lively",
"liveliest":"lively",
"livened":"liven",
"livening":"liven",
"livens":"liven",
"livenesses":"liveness",
"livers":"liver",
"liverleaves":"liverleaf",
"liverwursts":"liverwurst",
"liveries":"livery",
"liverymen":"liveryman",
"livestocks":"livestock",
"lividities":"lividity",
"lividnesses":"lividness",
"livings":"living",
"livingrooms":"livingroom",
"livistonas":"livistona",
"lixiviated":"lixiviate",
"lixiviating":"lixiviate",
"lixiviia":"lixivium",
"lixiviums":"lixivium",
"lizas":"liza",
"lizards":"lizard",
"lizardfishes":"lizardfish",
"llamas":"llama",
"llanos":"llano",
"llbs":"llb",
"llds":"lld",
"llms":"llm",
"lms":"lm",
"loaded":"load",
"loading":"load",
"loads":"load",
"loaders":"loader",
"loadings":"loading",
"chain-smokes":"chain-smoke",
"loadstones":"loadstone",
"loafed":"loaf",
"loafing":"loaf",
"loaves":"loaf",
"loafers":"loafer",
"loafings":"loafing",
"loamed":"loam",
"loaming":"loam",
"loaned":"loan",
"loaning":"loan",
"loans":"loan",
"loanblends":"loanblend",
"loaners":"loaner",
"loanwords":"loanword",
"loasaceaes":"loasaceae",
"loathed":"loathe",
"loathes":"loathe",
"loathing":"loathe",
"loathings":"loathing",
"loathsomenesses":"loathsomeness",
"lobbed":"lob",
"lobbing":"lob",
"lobs":"lob",
"lobatas":"lobata",
"lobbied":"lobby",
"lobbies":"lobby",
"lobbying":"lobby",
"lobes":"lobe",
"lobectomies":"lobectomy",
"lobefins":"lobefin",
"lobelias":"lobelia",
"lobeliaceaes":"lobeliaceae",
"lobipeses":"lobipes",
"loblollies":"loblolly",
"lobos":"lobo",
"loboteses":"lobotes",
"lobotidaes":"lobotidae",
"lobotomized":"lobotomize",
"lobotomizing":"lobotomize",
"lobotomies":"lobotomy",
"lobscouses":"lobscouse",
"lobscuses":"lobscuse",
"lobstered":"lobster",
"lobstering":"lobster",
"lobsters":"lobster",
"lobsterbacks":"lobsterback",
"lobstermen":"lobsterman",
"lobularias":"lobularia",
"lobworms":"lobworm",
"locals":"local",
"locales":"locale",
"localisations":"localisation",
"localisms":"localism",
"localities":"locality",
"localizations":"localization",
"localized":"localize",
"localizes":"localize",
"localizing":"localize",
"located":"locate",
"locates":"locate",
"locating":"locate",
"locatings":"locating",
"locations":"location",
"locatives":"locative",
"loches":"loch",
"locked":"lock",
"locking":"lock",
"locks":"lock",
"lockboxes":"lockbox",
"lockes":"locke",
"lockers":"locker",
"lockings":"locking",
"lockjaws":"lockjaw",
"lockkeepers":"lockkeeper",
"lockmen":"lockman",
"lockmasters":"lockmaster",
"lockrings":"lockring",
"lockups":"lockup",
"locoed":"loco",
"locoing":"loco",
"locos":"loco",
"locofocos":"locofoco",
"locoisms":"locoism",
"locomen":"locoman",
"locomoted":"locomote",
"locomotes":"locomote",
"locomoting":"locomote",
"locomotions":"locomotion",
"locomotives":"locomotive",
"locoweeds":"locoweed",
"locules":"locule",
"loculi":"loculus",
"locums":"locum",
"loci":"locus",
"locuses":"locus",
"locusts":"locust",
"locustas":"locusta",
"locustidaes":"locustidae",
"locutions":"locution",
"lodes":"lode",
"lodestars":"lodestar",
"lodestones":"lodestone",
"lodged":"lodge",
"lodges":"lodge",
"lodging":"lodge",
"lodgements":"lodgement",
"lodgepoles":"lodgepole",
"lodgers":"lodger",
"lodgings":"lodging",
"lodgingses":"lodgings",
"lodgments":"lodgment",
"lodines":"lodine",
"lofortyxes":"lofortyx",
"lofted":"loft",
"lofting":"loft",
"lofts":"loft",
"loftinesses":"loftiness",
"loftier":"lofty",
"loftiest":"lofty",
"logged":"log",
"logging":"log",
"logs":"log",
"logagraphias":"logagraphia",
"logans":"logan",
"loganberries":"loganberry",
"loganias":"logania",
"loganiaceaes":"loganiaceae",
"logarithms":"logarithm",
"loges":"loge",
"loggerheads":"loggerhead",
"loggias":"loggia",
"loggie":"loggia",
"logginesses":"logginess",
"logics":"logic",
"logicalities":"logicality",
"logicalnesses":"logicalness",
"logicians":"logician",
"loginesses":"loginess",
"logia":"logion",
"logions":"logion",
"logisticians":"logistician",
"logos":"logo",
"logograms":"logogram",
"logographs":"logograph",
"logomaches":"logomach",
"logomachists":"logomachist",
"logomachies":"logomachy",
"logomanias":"logomania",
"logorrheas":"logorrhea",
"logoses":"logos",
"logotypes":"logotype",
"logrolled":"logroll",
"logrolling":"logroll",
"logrollings":"logrolling",
"logwoods":"logwood",
"logier":"logy",
"logiest":"logy",
"lohans":"lohan",
"loins":"loin",
"loincloths":"loincloth",
"loinses":"loins",
"loirs":"loir",
"loires":"loire",
"loiseleurias":"loiseleuria",
"loitered":"loiter",
"loitering":"loiter",
"loiters":"loiter",
"loiterers":"loiterer",
"loliums":"lolium",
"lolled":"loll",
"lolling":"loll",
"lolls":"loll",
"lollipops":"lollipop",
"lolloped":"lollop",
"lolloping":"lollop",
"lollies":"lolly",
"lollygagged":"lollygag",
"lollygagging":"lollygag",
"lollygags":"lollygag",
"lolos":"lolo",
"lolo-burmeses":"lolo-burmese",
"lomariopsidaceaes":"lomariopsidaceae",
"lombards":"lombard",
"lombardias":"lombardia",
"lombardies":"lombardy",
"lomes":"lome",
"loments":"loment",
"lomenmenta":"lomentum",
"lomogrammas":"lomogramma",
"lonases":"lonas",
"lonchocarpuses":"lonchocarpus",
"londons":"london",
"lonelinesses":"loneliness",
"lonelier":"lonely",
"loneliest":"lonely",
"loners":"loner",
"lonesomenesses":"lonesomeness",
"longed":"long",
"longer":"long",
"longest":"long",
"longing":"long",
"longs":"long",
"long-distances":"long-distance",
"long-sufferances":"long-sufferance",
"long-sufferings":"long-suffering",
"long-windednesses":"long-windedness",
"longans":"longan",
"longanberries":"longanberry",
"longanimities":"longanimity",
"longbeards":"longbeard",
"longeing":"longe",
"longevities":"longevity",
"longfellows":"longfellow",
"longhands":"longhand",
"longhorns":"longhorn",
"longicorns":"longicorn",
"longings":"longing",
"longitudes":"longitude",
"longlegses":"longlegs",
"longobardi":"longobard",
"longobards":"longobard",
"longroots":"longroot",
"longshoremen":"longshoreman",
"longsightednesses":"longsightedness",
"longueurs":"longueur",
"longwayses":"longways",
"longyis":"longyi",
"loniceras":"lonicera",
"lonitens":"loniten",
"lontars":"lontar",
"loos":"loo",
"loobies":"looby",
"loofas":"loofa",
"loofahs":"loofah",
"looked":"look",
"looking":"look",
"looks":"look",
"look-overs":"look-over",
"lookdowns":"lookdown",
"lookers":"looker",
"looker-ons":"looker-on",
"lookers-on":"looker-on",
"lookings":"looking",
"lookingglasses":"lookingglass",
"lookouts":"lookout",
"lookups":"lookup",
"looked_towards":"look_towards",
"looking_towards":"look_towards",
"looks_towards":"look_towards",
"loomed":"loom",
"looming":"loom",
"looms":"loom",
"loons":"loon",
"looneys":"looney",
"loonier":"loony",
"loonies":"loony",
"looniest":"loony",
"looped":"loop",
"looping":"loop",
"loops":"loop",
"loopers":"looper",
"loopholes":"loophole",
"loopier":"loopy",
"loopiest":"loopy",
"loosed":"loose",
"looser":"loose",
"loosest":"loose",
"loosing":"loose",
"loosened":"loosen",
"loosening":"loosen",
"loosens":"loosen",
"loosenesses":"looseness",
"loosenings":"loosening",
"looted":"loot",
"looting":"loot",
"loots":"loot",
"looters":"looter",
"lootings":"looting",
"lopped":"lop",
"lopping":"lop",
"lops":"lop",
"loped":"lope",
"lopes":"lope",
"loping":"lope",
"lophiidaes":"lophiidae",
"lophiuses":"lophius",
"lophodyteses":"lophodytes",
"lopholatiluses":"lopholatilus",
"lophophoras":"lophophora",
"lophophoruses":"lophophorus",
"lophosorias":"lophosoria",
"lophosoriaceaes":"lophosoriaceae",
"loppier":"loppy",
"loppiest":"loppy",
"lopressors":"lopressor",
"lopsidednesses":"lopsidedness",
"loquaciousnesses":"loquaciousness",
"loquacities":"loquacity",
"loquats":"loquat",
"loranthaceaes":"loranthaceae",
"loranthuses":"loranthus",
"lorded":"lord",
"lording":"lord",
"lords":"lord",
"lordlinesses":"lordliness",
"lordlier":"lordly",
"lordliest":"lordly",
"lordoses":"lordosis",
"lords-and-ladieses":"lords-and-ladies",
"lordships":"lordship",
"lores":"lore",
"lorgnons":"lorgnon",
"loricae":"lorica",
"loricatas":"loricata",
"loriinaes":"loriinae",
"lorises":"loris",
"lorisidaes":"lorisidae",
"lorraines":"lorraine",
"lorries":"lorry",
"lories":"lory",
"loses":"lose",
"losing":"lose",
"lost":"lose",
"losers":"loser",
"losingses":"losings",
"losses":"loss",
"losseses":"losses",
"losts":"lost",
"lots":"lot",
"lotted":"lot",
"lotting":"lot",
"lotas":"lota",
"lotharios":"lothario",
"lothringens":"lothringen",
"maloti":"loti",
"lotions":"lotion",
"lotses":"lots",
"lottes":"lotte",
"lotteries":"lottery",
"lottos":"lotto",
"lotuses":"lotus",
"louder":"loud",
"loudest":"loud",
"loud-hailers":"loud-hailer",
"loudened":"louden",
"loudening":"louden",
"loudmouths":"loudmouth",
"loudnesses":"loudness",
"loudspeakers":"loudspeaker",
"loughs":"lough",
"louisianas":"louisiana",
"louisianans":"louisianan",
"louisianians":"louisianian",
"lounged":"lounge",
"lounges":"lounge",
"lounging":"lounge",
"loungers":"lounger",
"louped":"loup",
"louping":"loup",
"loups-garous":"loup-garou",
"loupes":"loupe",
"loured":"lour",
"louring":"lour",
"lours":"lour",
"lice":"louse",
"loused":"louse",
"louses":"louse",
"lousing":"louse",
"lousinesses":"lousiness",
"lousier":"lousy",
"lousiest":"lousy",
"louted":"lout",
"louting":"lout",
"louts":"lout",
"louvars":"louvar",
"louvers":"louver",
"louvres":"louvre",
"lovages":"lovage",
"lovastatins":"lovastatin",
"loved":"love",
"loves":"love",
"loving":"love",
"love-in-a-mists":"love-in-a-mist",
"love-in-idlenesses":"love-in-idleness",
"love-in-winters":"love-in-winter",
"love-lies-bleedings":"love-lies-bleeding",
"love-philters":"love-philter",
"love-philtres":"love-philtre",
"love-potions":"love-potion",
"lovebirds":"lovebird",
"lovelinesses":"loveliness",
"lovelier":"lovely",
"lovelies":"lovely",
"loveliest":"lovely",
"lovemakings":"lovemaking",
"lovers":"lover",
"lovingnesses":"lovingness",
"lovoas":"lovoa",
"lowed":"low",
"lower":"low",
"lowest":"low",
"lowing":"low",
"lows":"low",
"low-downs":"low-down",
"low-spiritednesses":"low-spiritedness",
"lowans":"lowan",
"lowbrows":"lowbrow",
"lowered":"lower",
"lowering":"lower",
"lowers":"lower",
"lower-normandies":"lower-normandy",
"lowercased":"lowercase",
"lowercases":"lowercase",
"lowercasing":"lowercase",
"lowerclassmen":"lowerclassman",
"lowerings":"lowering",
"lowlands":"lowland",
"lowlanders":"lowlander",
"lowlifes":"lowlife",
"lowlives":"lowlife",
"lowlier":"lowly",
"lowliest":"lowly",
"loxes":"lox",
"loxias":"loxia",
"loxodontas":"loxodonta",
"loxodromes":"loxodrome",
"loxomas":"loxoma",
"loxomataceaes":"loxomataceae",
"loxosteges":"loxostege",
"loyalists":"loyalist",
"loyalties":"loyalty",
"loyangs":"loyang",
"lozenges":"lozenge",
"lps":"lp",
"lpns":"lpn",
"lsds":"lsd",
"ltms":"ltm",
"lus":"lu",
"luandas":"luanda",
"luaus":"luau",
"luba.":"luba",
"lubbers":"lubber",
"lubricants":"lubricant",
"lubricated":"lubricate",
"lubricates":"lubricate",
"lubricating":"lubricate",
"lubricators":"lubricator",
"lubricities":"lubricity",
"lubritoria":"lubritorium",
"lucanias":"lucania",
"lucanidaes":"lucanidae",
"lucernes":"lucerne",
"lucidities":"lucidity",
"lucifers":"lucifer",
"lucilias":"lucilia",
"lucites":"lucite",
"lucked":"luck",
"lucking":"luck",
"lucks":"luck",
"luckier":"lucky",
"luckiest":"lucky",
"lucres":"lucre",
"lucubrated":"lucubrate",
"lucubrating":"lucubrate",
"lufengpithecuses":"lufengpithecus",
"luffed":"luff",
"luffing":"luff",
"luffs":"luff",
"luffas":"luffa",
"lugged":"lug",
"lugging":"lug",
"lugs":"lug",
"lugers":"luger",
"luggages":"luggage",
"lugsails":"lugsail",
"lugubriousnesses":"lugubriousness",
"lugworms":"lugworm",
"lukes":"luke",
"lukewarmnesses":"lukewarmness",
"lulled":"lull",
"lulling":"lull",
"lulls":"lull",
"lullabied":"lullaby",
"lullabies":"lullaby",
"lullabying":"lullaby",
"lulus":"lulu",
"lumbagos":"lumbago",
"lumbered":"lumber",
"lumbering":"lumber",
"lumbers":"lumber",
"lumberjacks":"lumberjack",
"lumbermen":"lumberman",
"lumbermills":"lumbermill",
"lumberyards":"lumberyard",
"lumens":"lumen",
"lumina":"lumen",
"luminals":"luminal",
"luminances":"luminance",
"luminaries":"luminary",
"luminesced":"luminesce",
"luminescing":"luminesce",
"luminescences":"luminescence",
"luminosities":"luminosity",
"luminousnesses":"luminousness",
"lummoxes":"lummox",
"lumped":"lump",
"lumping":"lump",
"lumps":"lump",
"lumpenuses":"lumpenus",
"lumpers":"lumper",
"lumpfishes":"lumpfish",
"lumpier":"lumpy",
"lumpiest":"lumpy",
"lunacies":"lunacy",
"lunarias":"lunaria",
"lunatics":"lunatic",
"lunations":"lunation",
"lunched":"lunch",
"lunches":"lunch",
"lunching":"lunch",
"luncheons":"luncheon",
"lunchrooms":"lunchroom",
"lundas":"lunda",
"lunettes":"lunette",
"lungs":"lung",
"lunged":"lunge",
"lunges":"lunge",
"lunging":"lunge",
"lungens":"lungen",
"lungers":"lunger",
"lungfishes":"lungfish",
"lungis":"lungi",
"lungyis":"lungyi",
"lunkheads":"lunkhead",
"lunulae":"lunula",
"lunulas":"lunula",
"lunules":"lunule",
"lunier":"luny",
"lunies":"luny",
"luniest":"luny",
"luoyangs":"luoyang",
"lupercalias":"lupercalia",
"lupins":"lupin",
"lupines":"lupine",
"lupinuses":"lupinus",
"lurched":"lurch",
"lurches":"lurch",
"lurching":"lurch",
"lurchers":"lurcher",
"lured":"lure",
"lures":"lure",
"luring":"lure",
"luridnesses":"luridness",
"lurked":"lurk",
"lurking":"lurk",
"lurks":"lurk",
"lurkers":"lurker",
"lusakas":"lusaka",
"lusatians":"lusatian",
"luscinias":"luscinia",
"lusciousnesses":"lusciousness",
"lushed":"lush",
"lusher":"lush",
"lushes":"lush",
"lushest":"lush",
"lushing":"lush",
"lushnesses":"lushness",
"lusted":"lust",
"lusting":"lust",
"lusts":"lust",
"lustered":"luster",
"lustering":"luster",
"lusters":"luster",
"lusterlessnesses":"lusterlessness",
"lustfulnesses":"lustfulness",
"lustinesses":"lustiness",
"lustrated":"lustrate",
"lustrating":"lustrate",
"lustres":"lustre",
"lustra":"lustrum",
"lustrums":"lustrum",
"lustier":"lusty",
"lustiest":"lusty",
"lutanists":"lutanist",
"luted":"lute",
"lutes":"lute",
"luting":"lute",
"luteciums":"lutecium",
"lutefisks":"lutefisk",
"luteins":"lutein",
"luteinized":"luteinize",
"luteinizing":"luteinize",
"lutenists":"lutenist",
"lutetiums":"lutetium",
"lutfisks":"lutfisk",
"luthers":"luther",
"lutings":"luting",
"lutists":"lutist",
"lutjanidaes":"lutjanidae",
"lutjanuses":"lutjanus",
"lutras":"lutra",
"lutrinaes":"lutrinae",
"lutzens":"lutzen",
"luvaridaes":"luvaridae",
"luvaruses":"luvarus",
"luvians":"luvian",
"luwians":"luwian",
"luces":"lux",
"luxes":"lux",
"luxated":"luxate",
"luxating":"luxate",
"luxembourgs":"luxembourg",
"luxembourgers":"luxembourger",
"luxemburgs":"luxemburg",
"luxemburgers":"luxemburger",
"luxurias":"luxuria",
"luxuriances":"luxuriance",
"luxuriated":"luxuriate",
"luxuriates":"luxuriate",
"luxuriating":"luxuriate",
"luxuriousnesses":"luxuriousness",
"luxuries":"luxury",
"lws":"lw",
"lweis":"lwei",
"lxes":"lx",
"lxxes":"lxx",
"lxxxes":"lxxx",
"lycaenas":"lycaena",
"lycaenids":"lycaenid",
"lycaenidaes":"lycaenidae",
"lycaeons":"lycaeon",
"lycanthropes":"lycanthrope",
"lycees":"lycee",
"lyceums":"lyceum",
"lychees":"lychee",
"lychgates":"lychgate",
"lychnises":"lychnis",
"lyciums":"lycium",
"lycoperdaceaes":"lycoperdaceae",
"lycoperdaleses":"lycoperdales",
"lycoperdons":"lycoperdon",
"lycopersicons":"lycopersicon",
"lycopersicums":"lycopersicum",
"lycopods":"lycopod",
"lycopodiaceaes":"lycopodiaceae",
"lycopodialeses":"lycopodiales",
"lycopodiates":"lycopodiate",
"lycopodineaes":"lycopodineae",
"lycopodiums":"lycopodium",
"lycopsidas":"lycopsida",
"lycopuses":"lycopus",
"lycosas":"lycosa",
"lycosidaes":"lycosidae",
"lygaeids":"lygaeid",
"lygaeidaes":"lygaeidae",
"lyginopteridaleses":"lyginopteridales",
"lyginopterises":"lyginopteris",
"lygodiums":"lygodium",
"lyguses":"lygus",
"lyings":"lying",
"lying-ins":"lying-in",
"lyings-in":"lying-in",
"lymantrias":"lymantria",
"lymantriids":"lymantriid",
"lymantriidaes":"lymantriidae",
"lymphangiomas":"lymphangioma",
"lymphangiomata":"lymphangioma",
"lymphangitides":"lymphangitis",
"lymphocytes":"lymphocyte",
"lymphogranulomas":"lymphogranuloma",
"lymphogranulomata":"lymphogranuloma",
"lymphomas":"lymphoma",
"lymphomata":"lymphoma",
"lymphomatosises":"lymphomatosis",
"lymphopoieses":"lymphopoiesis",
"lynched":"lynch",
"lynching":"lynch",
"lynchpins":"lynchpin",
"lynxes":"lynx",
"lyons":"lyon",
"lyonias":"lyonia",
"lyonses":"lyons",
"lyophilized":"lyophilize",
"lyophilizes":"lyophilize",
"lyophilizing":"lyophilize",
"lyrae":"lyra",
"lyres":"lyre",
"lyreflowers":"lyreflower",
"lyrics":"lyric",
"lyricalities":"lyricality",
"lyricisms":"lyricism",
"lyricized":"lyricize",
"lyricizes":"lyricize",
"lyricizing":"lyricize",
"lyruruses":"lyrurus",
"lysed":"lyse",
"lyses":"lyse",
"lysing":"lyse",
"lysichitons":"lysichiton",
"lysichitums":"lysichitum",
"lysilomas":"lysiloma",
"lysimachias":"lysimachia",
"lythraceaes":"lythraceae",
"lythrums":"lythrum",
"lyttae":"lytta",
"lyttas":"lytta",
"ms":"m",
"m-1s":"m-1",
"mas":"ma",
"maare":"maar",
"maars":"maar",
"macs":"mac",
"macacas":"macaca",
"macacos":"macaco",
"macadams":"macadam",
"macadamias":"macadamia",
"macadamized":"macadamize",
"macadamizes":"macadamize",
"macadamizing":"macadamize",
"macambas":"macamba",
"macaos":"macao",
"macaronies":"macaroni",
"macaronis":"macaroni",
"macaronics":"macaronic",
"macaus":"macau",
"maccaronies":"maccaroni",
"maccaronis":"maccaroni",
"maces":"mace",
"macebearers":"macebearer",
"macedons":"macedon",
"macedonias":"macedonia",
"macers":"macer",
"macerated":"macerate",
"macerates":"macerate",
"macerating":"macerate",
"macerations":"maceration",
"machaerantheras":"machaeranthera",
"machetes":"machete",
"machiavellis":"machiavelli",
"machicolated":"machicolate",
"machicolates":"machicolate",
"machicolating":"machicolate",
"machilids":"machilid",
"machilidaes":"machilidae",
"machinated":"machinate",
"machinating":"machinate",
"machinations":"machination",
"machinators":"machinator",
"machined":"machine",
"machines":"machine",
"machining":"machine",
"machine-gunned":"machine-gun",
"machine-gunning":"machine-gun",
"machine-guns":"machine-gun",
"machineries":"machinery",
"machinists":"machinist",
"machos":"macho",
"macho-men":"macho-man",
"machzorim":"machzor",
"macintoshes":"macintosh",
"macks":"mack",
"mackenzies":"mackenzie",
"mackerels":"mackerel",
"mackinaws":"mackinaw",
"mackintoshes":"mackintosh",
"macleayas":"macleaya",
"macluras":"maclura",
"macons":"macon",
"maconnaises":"maconnais",
"macowaniteses":"macowanites",
"macros":"macro",
"macrocephalons":"macrocephalon",
"macrocephalies":"macrocephaly",
"macrocheiras":"macrocheira",
"macroclemyses":"macroclemys",
"macrocosms":"macrocosm",
"macrocytes":"macrocyte",
"macrodactyluses":"macrodactylus",
"macrodantins":"macrodantin",
"macroglias":"macroglia",
"macromolecules":"macromolecule",
"macronecteses":"macronectes",
"macronuclei":"macronucleus",
"macropodidaes":"macropodidae",
"macropuses":"macropus",
"macrorhamphosidaes":"macrorhamphosidae",
"macrosporangia":"macrosporangium",
"macrothelypterises":"macrothelypteris",
"macrotises":"macrotis",
"macrotuses":"macrotus",
"macrotylomas":"macrotyloma",
"macrouridaes":"macrouridae",
"macrozoarceses":"macrozoarces",
"macruridaes":"macruridae",
"maculae":"macula",
"maculas":"macula",
"maculations":"maculation",
"macules":"macule",
"madded":"mad",
"madder":"mad",
"maddest":"mad",
"madding":"mad",
"mads":"mad",
"madakes":"madake",
"madams":"madam",
"mesdames":"madam",
"madames":"madame",
"madcaps":"madcap",
"maddened":"madden",
"maddening":"madden",
"maddens":"madden",
"madders":"madder",
"madderworts":"madderwort",
"madeiras":"madeira",
"mademoiselles":"mademoiselle",
"mesdemoiselles":"mademoiselle",
"madhouses":"madhouse",
"madias":"madia",
"madisons":"madison",
"madmen":"madman",
"madneps":"madnep",
"madnesses":"madness",
"madonnas":"madonna",
"madreporarias":"madreporaria",
"madrepores":"madrepore",
"madrids":"madrid",
"madronas":"madrona",
"madrones":"madrone",
"madronos":"madrono",
"maduros":"maduro",
"madwomen":"madwoman",
"madworts":"madwort",
"maeandras":"maeandra",
"maelstroms":"maelstrom",
"maestri":"maestro",
"maestros":"maestro",
"mafas":"mafa",
"maffias":"maffia",
"mafficked":"maffick",
"mafficking":"maffick",
"mafias":"mafia",
"mafiosi":"mafioso",
"mafiosos":"mafioso",
"mags":"mag",
"magazines":"magazine",
"magellans":"magellan",
"magentas":"magenta",
"maggots":"maggot",
"magis":"magi",
"magics":"magic",
"magicians":"magician",
"magicicadas":"magicicada",
"magisteries":"magistery",
"magistracies":"magistracy",
"magistrates":"magistrate",
"magistratures":"magistrature",
"magmas":"magma",
"magmata":"magma",
"magnanimities":"magnanimity",
"magnanimousnesses":"magnanimousness",
"magnates":"magnate",
"magnesias":"magnesia",
"magnesiums":"magnesium",
"magnets":"magnet",
"magneticses":"magnetics",
"magnetisations":"magnetisation",
"magnetisms":"magnetism",
"magnetites":"magnetite",
"magnetizations":"magnetization",
"magnetized":"magnetize",
"magnetizes":"magnetize",
"magnetizing":"magnetize",
"magnetos":"magneto",
"magnetometers":"magnetometer",
"magnifications":"magnification",
"magnificences":"magnificence",
"magnificoes":"magnifico",
"magnified":"magnify",
"magnifies":"magnify",
"magnifying":"magnify",
"magniloquences":"magniloquence",
"magnitudes":"magnitude",
"magnolias":"magnolia",
"magnoliaceaes":"magnoliaceae",
"magnoliidaes":"magnoliidae",
"magnoliophytas":"magnoliophyta",
"magnoliopsids":"magnoliopsid",
"magnoliopsidas":"magnoliopsida",
"magnums":"magnum",
"magpies":"magpie",
"magueys":"maguey",
"magi":"magus",
"magyars":"magyar",
"magyarorszags":"magyarorszag",
"mah-jonggs":"mah-jongg",
"mahas":"maha",
"mahabharatas":"mahabharata",
"mahabharatams":"mahabharatam",
"mahabharatums":"mahabharatum",
"mahaguas":"mahagua",
"maharajas":"maharaja",
"maharajahs":"maharajah",
"maharanees":"maharanee",
"maharanis":"maharani",
"mahatmas":"mahatma",
"mahdis":"mahdi",
"mahicans":"mahican",
"mahimahis":"mahimahi",
"mahjongs":"mahjong",
"mahlsticks":"mahlstick",
"mahoes":"mahoe",
"mahoganies":"mahogany",
"mahomets":"mahomet",
"mahonias":"mahonia",
"mahounds":"mahound",
"mahrattas":"mahratta",
"mahrattis":"mahratti",
"mahuangs":"mahuang",
"mahzorim":"mahzor",
"maias":"maia",
"maianthemums":"maianthemum",
"maids":"maid",
"maidens":"maiden",
"maidenhairs":"maidenhair",
"maidenheads":"maidenhead",
"maidenhoods":"maidenhood",
"maidhoods":"maidhood",
"maidservants":"maidservant",
"maidus":"maidu",
"maigers":"maiger",
"maigres":"maigre",
"maikoas":"maikoa",
"mailed":"mail",
"mailing":"mail",
"mails":"mail",
"mailbags":"mailbag",
"mailboats":"mailboat",
"mailboxes":"mailbox",
"mailings":"mailing",
"mailing-cards":"mailing-card",
"maillots":"maillot",
"mailmen":"mailman",
"maimed":"maim",
"maiming":"maim",
"maimeds":"maimed",
"maimings":"maiming",
"mains":"main",
"maines":"maine",
"mainers":"mainer",
"mainframes":"mainframe",
"mainlanders":"mainlander",
"mainlined":"mainline",
"mainlining":"mainline",
"mainsheets":"mainsheet",
"mainstays":"mainstay",
"maintained":"maintain",
"maintaining":"maintain",
"maintains":"maintain",
"maintenances":"maintenance",
"maiolicas":"maiolica",
"maizes":"maize",
"majas":"maja",
"majaguas":"majagua",
"majesties":"majesty",
"majidaes":"majidae",
"majolicas":"majolica",
"majored":"major",
"majoring":"major",
"majors":"major",
"major-domos":"major-domo",
"majoranas":"majorana",
"majorities":"majority",
"majorses":"majors",
"major-axes":"major_axis",
"major_axes":"major_axis",
"makairas":"makaira",
"made":"make",
"makes":"make",
"making":"make",
"make-believes":"make-believe",
"make-dos":"make-do",
"make-peaces":"make-peace",
"make-ups":"make-up",
"make-works":"make-work",
"makers":"maker",
"makeshifts":"makeshift",
"makeups":"makeup",
"makeweights":"makeweight",
"makins":"makin",
"makings":"making",
"makos":"mako",
"makomakos":"makomako",
"malas":"mala",
"malacanthidaes":"malacanthidae",
"malaccas":"malacca",
"malaclemyses":"malaclemys",
"malaconotinaes":"malaconotinae",
"malacopterygians":"malacopterygian",
"malacopterygiis":"malacopterygii",
"malacosomas":"malacosoma",
"malacostracas":"malacostraca",
"malacothamnuses":"malacothamnus",
"maladministered":"maladminister",
"maladministering":"maladminister",
"maladroitnesses":"maladroitness",
"maladies":"malady",
"malagasies":"malagasy",
"malaises":"malaise",
"malamutes":"malamute",
"malangas":"malanga",
"malaprops":"malaprop",
"malapropisms":"malapropism",
"malawis":"malawi",
"malaxes":"malaxis",
"malaxis-unifolias":"malaxis-unifolia",
"malays":"malay",
"malayas":"malaya",
"malayans":"malayan",
"malaysias":"malaysia",
"malaysians":"malaysian",
"malcolmias":"malcolmia",
"maldivans":"maldivan",
"maldivians":"maldivian",
"maldons":"maldon",
"males":"male",
"maleberries":"maleberry",
"malecites":"malecite",
"maledictions":"malediction",
"malefactors":"malefactor",
"maleficences":"maleficence",
"malemutes":"malemute",
"malenesses":"maleness",
"maleos":"maleo",
"maleseets":"maleseet",
"malevolences":"malevolence",
"malevolencies":"malevolency",
"malfeasances":"malfeasance",
"malformations":"malformation",
"malfunctioned":"malfunction",
"malfunctioning":"malfunction",
"malfunctions":"malfunction",
"malis":"mali",
"malices":"malice",
"maliciousnesses":"maliciousness",
"maligned":"malign",
"maligning":"malign",
"maligns":"malign",
"malignances":"malignance",
"malignancies":"malignancy",
"malignants":"malignant",
"maligners":"maligner",
"malignities":"malignity",
"malignments":"malignment",
"malihinis":"malihini",
"malingered":"malinger",
"malingering":"malinger",
"malingers":"malinger",
"malingerers":"malingerer",
"malingerings":"malingering",
"malinkes":"malinke",
"malls":"mall",
"mallards":"mallard",
"malleabilities":"malleability",
"malleoli":"malleolus",
"mallets":"mallet",
"mallei":"malleus",
"malleuses":"malleus",
"mallophagas":"mallophaga",
"mallotuses":"mallotus",
"malnourishments":"malnourishment",
"malodors":"malodor",
"malodorousnesses":"malodorousness",
"malodours":"malodour",
"malodourousnesses":"malodourousness",
"malonylureas":"malonylurea",
"malopes":"malope",
"malopteruruses":"malopterurus",
"malosmas":"malosma",
"malpighias":"malpighia",
"malpighiaceaes":"malpighiaceae",
"malpositions":"malposition",
"malpractices":"malpractice",
"malses":"mals",
"malted":"malt",
"malting":"malt",
"malts":"malt",
"malteds":"malted",
"malteses":"maltese",
"matlese":"maltese",
"malthas":"maltha",
"malthuses":"malthus",
"malthusianisms":"malthusianism",
"maltmen":"maltman",
"maltoses":"maltose",
"maltreated":"maltreat",
"maltreating":"maltreat",
"maltreats":"maltreat",
"maltreatments":"maltreatment",
"maltsters":"maltster",
"maltier":"malty",
"maltiest":"malty",
"maluses":"malus",
"malvas":"malva",
"malvaceaes":"malvaceae",
"malvaleses":"malvales",
"malvastrums":"malvastrum",
"malvaviscuses":"malvaviscus",
"mamas":"mama",
"mambas":"mamba",
"mamboed":"mambo",
"mamboing":"mambo",
"mambos":"mambo",
"mameys":"mamey",
"mamillae":"mamilla",
"mamillas":"mamilla",
"mammas":"mamma",
"mammals":"mammal",
"mammalias":"mammalia",
"mammeas":"mammea",
"mammees":"mammee",
"mammillas":"mammilla",
"mammocked":"mammock",
"mammocking":"mammock",
"mammoths":"mammoth",
"mammuts":"mammut",
"mammuthuses":"mammuthus",
"mammutidaes":"mammutidae",
"mammies":"mammy",
"mamoncillos":"mamoncillo",
"manned":"man",
"manning":"man",
"men":"man",
"man-about-towns":"man-about-town",
"men-at-arms":"man-at-arms",
"man-children":"man-child",
"men-children":"man-child",
"man-days":"man-day",
"man-eaters":"man-eater",
"man-of-the-earths":"man-of-the-earth",
"man-of-wars":"man-of-war",
"men-of-war":"man-of-war",
"man-on-a-horses":"man-on-a-horse",
"manacled":"manacle",
"manacles":"manacle",
"manacling":"manacle",
"managed":"manage",
"manages":"manage",
"managing":"manage",
"manageabilities":"manageability",
"manageablenesses":"manageableness",
"managements":"management",
"managers":"manager",
"managings":"managing",
"managuas":"managua",
"manakins":"manakin",
"manamas":"manama",
"manatees":"manatee",
"manawydans":"manawydan",
"manawyddans":"manawyddan",
"manchus":"manchu",
"mandalas":"mandala",
"mandamuses":"mandamus",
"mandans":"mandan",
"mandaras":"mandara",
"mandarins":"mandarin",
"mandataries":"mandatary",
"mandated":"mandate",
"mandates":"mandate",
"mandating":"mandate",
"mandatories":"mandatory",
"mandes":"mande",
"mandelamines":"mandelamine",
"mandevillas":"mandevilla",
"mandibles":"mandible",
"mandibulas":"mandibula",
"mandingoes":"mandingo",
"mandingos":"mandingo",
"mandiocs":"mandioc",
"mandiocas":"mandioca",
"mandragoras":"mandragora",
"mandrakes":"mandrake",
"mandrels":"mandrel",
"mandrils":"mandril",
"mandrills":"mandrill",
"mandrilluses":"mandrillus",
"manducas":"manduca",
"manes":"mane",
"maneuvered":"maneuver",
"maneuvering":"maneuver",
"maneuvers":"maneuver",
"maneuverabilities":"maneuverability",
"maneuverers":"maneuverer",
"maneuverings":"maneuvering",
"manfulnesses":"manfulness",
"manganeses":"manganese",
"mangel-wurzels":"mangel-wurzel",
"mangers":"manger",
"mangiferas":"mangifera",
"manginesses":"manginess",
"mangled":"mangle",
"mangles":"mangle",
"mangling":"mangle",
"manglers":"mangler",
"mangoes":"mango",
"mangos":"mango",
"mangolds":"mangold",
"mangold-wurzels":"mangold-wurzel",
"mangosteens":"mangosteen",
"mangroves":"mangrove",
"mangier":"mangy",
"mangiest":"mangy",
"manhandled":"manhandle",
"manhandling":"manhandle",
"manias":"mania",
"maniacs":"maniac",
"manicured":"manicure",
"manicures":"manicure",
"manicuring":"manicure",
"manidaes":"manidae",
"manifested":"manifest",
"manifesting":"manifest",
"manifests":"manifest",
"manifestations":"manifestation",
"manifestoes":"manifesto",
"manifestos":"manifesto",
"manifolded":"manifold",
"manifolding":"manifold",
"manifolds":"manifold",
"manihots":"manihot",
"manikins":"manikin",
"manilas":"manila",
"manilkaras":"manilkara",
"manillas":"manilla",
"maninkes":"maninke",
"maniocs":"manioc",
"maniocas":"manioca",
"manipulated":"manipulate",
"manipulates":"manipulate",
"manipulating":"manipulate",
"manipulations":"manipulation",
"manipulators":"manipulator",
"maniraptoras":"maniraptora",
"manises":"manis",
"manitos":"manito",
"manitous":"manitou",
"manitus":"manitu",
"mankinds":"mankind",
"mankier":"manky",
"mankiest":"manky",
"manlinesses":"manliness",
"manlier":"manly",
"manliest":"manly",
"mannas":"manna",
"mannequins":"mannequin",
"manners":"manner",
"mannerisms":"mannerism",
"mannikins":"mannikin",
"mannitols":"mannitol",
"manoeuverabilities":"manoeuverability",
"manoeuverers":"manoeuverer",
"manoeuverings":"manoeuvering",
"manoeuvred":"manoeuvre",
"manoeuvres":"manoeuvre",
"manoeuvring":"manoeuvre",
"manors":"manor",
"manpowers":"manpower",
"manroots":"manroot",
"mansards":"mansard",
"manses":"manse",
"menservants":"manservant",
"mansis":"mansi",
"mansions":"mansion",
"mantas":"manta",
"manteaus":"manteau",
"manteaux":"manteau",
"manteidaes":"manteidae",
"mantels":"mantel",
"mantelets":"mantelet",
"mantelpieces":"mantelpiece",
"mantelshelves":"mantelshelf",
"manteodeas":"manteodea",
"mantichoras":"mantichora",
"manticoras":"manticora",
"manticores":"manticore",
"mantids":"mantis",
"mantidaes":"mantidae",
"mantigers":"mantiger",
"mantillas":"mantilla",
"mantineas":"mantinea",
"mantineias":"mantineia",
"mantes":"mantis",
"mantises":"mantis",
"mantispidaes":"mantispidae",
"mantissas":"mantissa",
"mantled":"mantle",
"mantles":"mantle",
"mantling":"mantle",
"mantlepieces":"mantlepiece",
"mantlets":"mantlet",
"mantraps":"mantrap",
"mantuas":"mantua",
"manuals":"manual",
"manubria":"manubrium",
"manubriums":"manubrium",
"manufactories":"manufactory",
"manufactured":"manufacture",
"manufactures":"manufacture",
"manufacturing":"manufacture",
"manufacturers":"manufacturer",
"manufacturings":"manufacturing",
"manuls":"manul",
"manumits":"manumit",
"manumitted":"manumit",
"manumitting":"manumit",
"manumitters":"manumitter",
"manured":"manure",
"manures":"manure",
"manuring":"manure",
"manuses":"manus",
"manuscripts":"manuscript",
"manxmen":"manxman",
"many-sidedness":"many-sideness",
"manzanitas":"manzanita",
"men_of_letters":"man_of_letters",
"maos":"mao",
"maois":"maoi",
"Maoris":"Maori",
"mapped":"map",
"mapping":"map",
"maps":"map",
"maples":"maple",
"mapmakings":"mapmaking",
"mappers":"mapper",
"mappings":"mapping",
"maputos":"maputo",
"marred":"mar",
"marring":"mar",
"mars":"mar",
"maras":"mara",
"marabous":"marabou",
"marabouts":"marabout",
"maracas":"maraca",
"maracos":"maraco",
"marangs":"marang",
"marantaceaes":"marantaceae",
"marascas":"marasca",
"maraschinos":"maraschino",
"marasmiuses":"marasmius",
"marathas":"maratha",
"marathis":"marathi",
"marathons":"marathon",
"marathoners":"marathoner",
"marattias":"marattia",
"marattiaceaes":"marattiaceae",
"marattialeses":"marattiales",
"marauded":"maraud",
"marauding":"maraud",
"marauds":"maraud",
"marauders":"marauder",
"maraudings":"marauding",
"maravedis":"maravedi",
"maravillas":"maravilla",
"marbled":"marble",
"marbles":"marble",
"marbling":"marble",
"marblewoods":"marblewood",
"marcelled":"marcel",
"marcelling":"marcel",
"marcels":"marcel",
"marched":"march",
"marches":"march",
"marching":"march",
"marchantias":"marchantia",
"marchantiaceaes":"marchantiaceae",
"marchantialeses":"marchantiales",
"marchers":"marcher",
"marcheses":"marches",
"marchese":"marchesa",
"marchesi":"marchese",
"marchings":"marching",
"marchionesses":"marchioness",
"marchlands":"marchland",
"marchpanes":"marchpane",
"marduks":"marduk",
"mares":"mare",
"maria":"mare",
"maremme":"maremma",
"margarins":"margarin",
"margarines":"margarine",
"margaritas":"margarita",
"margates":"margate",
"margays":"margay",
"marges":"marge",
"margined":"margin",
"margining":"margin",
"margins":"margin",
"marginated":"marginate",
"marginating":"marginate",
"marginocephalias":"marginocephalia",
"marginocephalians":"marginocephalian",
"margosas":"margosa",
"marguerites":"marguerite",
"maris":"mari",
"marias":"maria",
"marianases":"marianas",
"marigolds":"marigold",
"marihuanas":"marihuana",
"marijuanas":"marijuana",
"marimbas":"marimba",
"marinas":"marina",
"marinaded":"marinade",
"marinades":"marinade",
"marinading":"marinade",
"marinated":"marinate",
"marinates":"marinate",
"marinating":"marinate",
"marines":"marine",
"mariners":"mariner",
"marionettes":"marionette",
"mariposas":"mariposa",
"mariposans":"mariposan",
"maritimeses":"maritimes",
"marjorams":"marjoram",
"marked":"mark",
"marking":"mark",
"marks":"mark",
"markers":"marker",
"marketed":"market",
"marketing":"market",
"markets":"market",
"marketings":"marketing",
"marketplaces":"marketplace",
"markhoors":"markhoor",
"markhors":"markhor",
"markings":"marking",
"markkaa":"markka",
"marksmen":"marksman",
"markweeds":"markweed",
"marled":"marl",
"marling":"marl",
"marlberries":"marlberry",
"marlins":"marlin",
"marlinespikes":"marlinespike",
"marlingspikes":"marlingspike",
"marlinspikes":"marlinspike",
"marmaras":"marmara",
"marmoras":"marmora",
"marmots":"marmot",
"marmotas":"marmota",
"marocs":"maroc",
"marocains":"marocain",
"marooned":"maroon",
"marooning":"maroon",
"maroons":"maroon",
"marplans":"marplan",
"marques":"marque",
"marquees":"marquee",
"marquesses":"marquess",
"marqueteries":"marqueterie",
"marquetries":"marquetry",
"marquises":"marquis",
"marranos":"marrano",
"marris":"marri",
"marriages":"marriage",
"marrieds":"married",
"marrows":"marrow",
"marrubiums":"marrubium",
"marruecoses":"marruecos",
"married":"marry",
"marries":"marry",
"marrying":"marry",
"marses":"mars",
"marshes":"marsh",
"marshaled":"marshal",
"marshaling":"marshal",
"marshalled":"marshal",
"marshalling":"marshal",
"marshals":"marshal",
"marshalings":"marshaling",
"marshalls":"marshall",
"marshlands":"marshland",
"marshier":"marshy",
"marshiest":"marshy",
"marsileas":"marsilea",
"marsileaceaes":"marsileaceae",
"marsupials":"marsupial",
"marsupialias":"marsupialia",
"marsupia":"marsupium",
"marts":"mart",
"martagons":"martagon",
"martens":"marten",
"marteses":"martes",
"martinets":"martinet",
"martingales":"martingale",
"martinis":"martini",
"martinmases":"martinmas",
"martynias":"martynia",
"martyniaceaes":"martyniaceae",
"martyred":"martyr",
"martyring":"martyr",
"martyrs":"martyr",
"martyrdoms":"martyrdom",
"martyrologies":"martyrology",
"martyries":"martyry",
"marums":"marum",
"marumis":"marumi",
"marupas":"marupa",
"marveled":"marvel",
"marveling":"marvel",
"marvelled":"marvel",
"marvelling":"marvel",
"marvels":"marvel",
"marvel-of-perus":"marvel-of-peru",
"marxes":"marx",
"marxisms":"marxism",
"marxism-leninisms":"marxism-leninism",
"marxists":"marxist",
"maries":"mary",
"mary-janes":"mary-jane",
"marylands":"maryland",
"marzipans":"marzipan",
"masais":"masai",
"mascaraed":"mascara",
"mascaraing":"mascara",
"mascots":"mascot",
"masculines":"masculine",
"masculinities":"masculinity",
"masculinizations":"masculinization",
"masculinized":"masculinize",
"masculinizing":"masculinize",
"maserus":"maseru",
"mashed":"mash",
"mashes":"mash",
"mashing":"mash",
"mashers":"masher",
"mashhads":"mashhad",
"mashies":"mashie",
"mashonas":"mashona",
"masjids":"masjid",
"masked":"mask",
"masking":"mask",
"masks":"mask",
"maskalonges":"maskalonge",
"maskanonges":"maskanonge",
"maskings":"masking",
"masoned":"mason",
"masoning":"mason",
"masons":"mason",
"masonries":"masonry",
"masqats":"masqat",
"masques":"masque",
"masqueraded":"masquerade",
"masquerades":"masquerade",
"masquerading":"masquerade",
"massed":"mass",
"masses":"mass",
"massing":"mass",
"mass-produced":"mass-produce",
"mass-producing":"mass-produce",
"Massachusets":"Massachuset",
"massachusettses":"massachusetts",
"massacred":"massacre",
"massacres":"massacre",
"massacring":"massacre",
"massaged":"massage",
"massages":"massage",
"massaging":"massage",
"massagists":"massagist",
"massasaugas":"massasauga",
"masseses":"masses",
"masseurs":"masseur",
"masseuses":"masseuse",
"massivenesses":"massiveness",
"massier":"massy",
"massiest":"massy",
"masted":"mast",
"masting":"mast",
"masts":"mast",
"mastectomies":"mastectomy",
"mastered":"master",
"mastering":"master",
"masters":"master",
"masters-at-arms":"master-at-arms",
"masterminded":"mastermind",
"masterminding":"mastermind",
"masterminds":"mastermind",
"masterpieces":"masterpiece",
"masteries":"mastery",
"masticated":"masticate",
"masticates":"masticate",
"masticating":"masticate",
"mastications":"mastication",
"masticatories":"masticatory",
"masticophises":"masticophis",
"mastigomycotas":"mastigomycota",
"mastigomycotinas":"mastigomycotina",
"mastigophoras":"mastigophora",
"mastigophorans":"mastigophoran",
"mastigophores":"mastigophore",
"mastigoproctuses":"mastigoproctus",
"mastitides":"mastitis",
"mastocytes":"mastocyte",
"mastodons":"mastodon",
"mastodonts":"mastodont",
"mastoids":"mastoid",
"mastoidectomies":"mastoidectomy",
"mastotermeses":"mastotermes",
"mastotermitidaes":"mastotermitidae",
"masturbated":"masturbate",
"masturbates":"masturbate",
"masturbating":"masturbate",
"masturbations":"masturbation",
"masturbators":"masturbator",
"mats":"mat",
"matted":"mat",
"matting":"mat",
"matabeles":"matabele",
"matais":"matai",
"matakams":"matakam",
"matched":"match",
"matches":"match",
"matching":"match",
"matchbushes":"matchbush",
"matchets":"matchet",
"matchmakers":"matchmaker",
"matchweeds":"matchweed",
"matchwoods":"matchwood",
"mated":"mate",
"mates":"mate",
"mating":"mate",
"maters":"mater",
"matres":"mater",
"materials":"material",
"materialisations":"materialisation",
"materialisms":"materialism",
"materialists":"materialist",
"materialities":"materiality",
"materializations":"materialization",
"materialized":"materialize",
"materializes":"materialize",
"materializing":"materialize",
"materiels":"materiel",
"maternities":"maternity",
"mateses":"mates",
"maths":"math",
"mathematicians":"mathematician",
"mathematicses":"mathematics",
"mathses":"maths",
"matinees":"matinee",
"matings":"mating",
"matinses":"matins",
"matmen":"matman",
"matoakas":"matoaka",
"matriarches":"matriarch",
"matriarchates":"matriarchate",
"matriarchies":"matriarchy",
"matrics":"matric",
"matricarias":"matricaria",
"matriculated":"matriculate",
"matriculating":"matriculate",
"matriculations":"matriculation",
"matrikins":"matrikin",
"matrilineages":"matrilineage",
"matrilinies":"matriliny",
"matrimonies":"matrimony",
"matrisibs":"matrisib",
"matrices":"matrix",
"matrixes":"matrix",
"matrons":"matron",
"matronymics":"matronymic",
"matts":"matt",
"mattes":"matte",
"mattered":"matter",
"mattering":"matter",
"matters":"matter",
"matteuccias":"matteuccia",
"matthews":"matthew",
"matthiolas":"matthiola",
"mattings":"matting",
"mattresses":"mattress",
"maturated":"maturate",
"maturates":"maturate",
"maturating":"maturate",
"maturations":"maturation",
"matured":"mature",
"maturer":"mature",
"maturest":"mature",
"maturing":"mature",
"maturements":"maturement",
"maturenesses":"matureness",
"maturings":"maturing",
"maturities":"maturity",
"matzas":"matza",
"matzahs":"matzah",
"matzos":"matzo",
"matzot":"matzo",
"matzoth":"matzo",
"matzohs":"matzoh",
"mau-maus":"mau-mau",
"maubies":"mauby",
"mauis":"maui",
"mauled":"maul",
"mauling":"maul",
"mauls":"maul",
"maulers":"mauler",
"maulsticks":"maulstick",
"maundered":"maunder",
"maundering":"maunder",
"maunders":"maunder",
"maundies":"maundy",
"maungier":"maungy",
"maungiest":"maungy",
"mauritanias":"mauritania",
"mauritanies":"mauritanie",
"mausolea":"mausoleum",
"mausoleums":"mausoleum",
"mavens":"maven",
"mavericks":"maverick",
"mavises":"mavis",
"maws":"maw",
"mawkishnesses":"mawkishness",
"maxis":"maxi",
"maxillae":"maxilla",
"maxillas":"maxilla",
"maxillaries":"maxillary",
"maxims":"maxim",
"maximisations":"maximisation",
"maximizations":"maximization",
"maximized":"maximize",
"maximizing":"maximize",
"maxima":"maximum",
"maximums":"maximum",
"maxostomas":"maxostoma",
"maxwells":"maxwell",
"mays":"may",
"might":"may",
"mayas":"maya",
"mayacas":"mayaca",
"mayacaceaes":"mayacaceae",
"mayans":"mayan",
"mayapples":"mayapple",
"mayengs":"mayeng",
"mayetiolas":"mayetiola",
"mayfishes":"mayfish",
"mayflowers":"mayflower",
"mayflies":"mayfly",
"mayhaws":"mayhaw",
"mayhems":"mayhem",
"mayonnaises":"mayonnaise",
"mayors":"mayor",
"mayoralties":"mayoralty",
"maypops":"maypop",
"mayweeds":"mayweed",
"mazamas":"mazama",
"mazdaisms":"mazdaism",
"mazed":"maze",
"mazes":"maze",
"mazing":"maze",
"mazurkas":"mazurka",
"mazier":"mazy",
"maziest":"mazy",
"mazzards":"mazzard",
"mbs":"mb",
"mbas":"mba",
"mbabanes":"mbabane",
"mcs":"mc",
"mcgs":"mcg",
"mckinleys":"mckinley",
"MDs":"MD",
"mdivs":"mdiv",
"mdmas":"mdma",
"meadows":"meadow",
"meadowgrasses":"meadowgrass",
"meadowlarks":"meadowlark",
"meagernesses":"meagerness",
"meagrenesses":"meagreness",
"meals":"meal",
"mealberries":"mealberry",
"mealier":"mealy",
"mealiest":"mealy",
"mealybugs":"mealybug",
"meaner":"mean",
"meanest":"mean",
"meaning":"mean",
"means":"mean",
"meant":"mean",
"meandered":"meander",
"meandering":"meander",
"meanders":"meander",
"meanies":"meany",
"meanings":"meaning",
"meaninglessnesses":"meaninglessness",
"meannesses":"meanness",
"mearstones":"mearstone",
"measleses":"measles",
"measlier":"measly",
"measliest":"measly",
"measurabilities":"measurability",
"measured":"measure",
"measures":"measure",
"measuring":"measure",
"measurements":"measurement",
"measurings":"measuring",
"meats":"meat",
"meatloaves":"meatloaf",
"meatmen":"meatman",
"meatuses":"meatus",
"meatier":"meaty",
"meatiest":"meaty",
"mebarals":"mebaral",
"mechanics":"mechanic",
"mechanicses":"mechanics",
"mechanisations":"mechanisation",
"mechanisms":"mechanism",
"mechanizations":"mechanization",
"mechanized":"mechanize",
"mechanizes":"mechanize",
"mechanizing":"mechanize",
"mecholyls":"mecholyl",
"meclizines":"meclizine",
"meclofenamates":"meclofenamate",
"meclomens":"meclomen",
"meconopses":"meconopsis",
"meds":"med",
"medals":"medal",
"medalists":"medalist",
"medallions":"medallion",
"medallists":"medallist",
"meddled":"meddle",
"meddles":"meddle",
"meddling":"meddle",
"meddlesomenesses":"meddlesomeness",
"meddlings":"meddling",
"medflies":"medfly",
"medias":"media",
"mediacies":"mediacy",
"medians":"median",
"mediastina":"mediastinum",
"mediated":"mediate",
"mediates":"mediate",
"mediating":"mediate",
"mediatenesses":"mediateness",
"mediations":"mediation",
"mediators":"mediator",
"medics":"medic",
"medicagos":"medicago",
"medicals":"medical",
"medicaments":"medicament",
"medicated":"medicate",
"medicates":"medicate",
"medicating":"medicate",
"medications":"medication",
"medicined":"medicine",
"medicines":"medicine",
"medicining":"medicine",
"medicks":"medick",
"medicoes":"medico",
"medicos":"medico",
"medieties":"mediety",
"medinillas":"medinilla",
"mediocrities":"mediocrity",
"meditated":"meditate",
"meditates":"meditate",
"meditating":"meditate",
"meditations":"meditation",
"meditativenesses":"meditativeness",
"meditators":"meditator",
"mediterraneans":"mediterranean",
"media":"medium",
"mediums":"medium",
"medlars":"medlar",
"medleys":"medley",
"medroxyprogesterones":"medroxyprogesterone",
"medullae":"medulla",
"medullas":"medulla",
"medullae_oblongatae":"medulla_oblongata",
"medulla_oblongatas":"medulla_oblongata",
"medusas":"medusa",
"medusans":"medusan",
"meeker":"meek",
"meekest":"meek",
"meerestones":"meerestone",
"meerkats":"meerkat",
"meerschaums":"meerschaum",
"meeting":"meet",
"meets":"meet",
"met":"meet",
"meetings":"meeting",
"meetinghouses":"meetinghouse",
"mefoxins":"mefoxin",
"megs":"meg",
"megabats":"megabat",
"megabytes":"megabyte",
"megacardias":"megacardia",
"megacephalies":"megacephaly",
"megachiles":"megachile",
"megachilidaes":"megachilidae",
"megachiropteras":"megachiroptera",
"megacycles":"megacycle",
"megadermas":"megaderma",
"megadermatidaes":"megadermatidae",
"megaflopses":"megaflops",
"megahertzs":"megahertz",
"megaliths":"megalith",
"megalobatrachuses":"megalobatrachus",
"megalocardias":"megalocardia",
"megalocephalies":"megalocephaly",
"megalocytes":"megalocyte",
"megalonychidaes":"megalonychidae",
"megalopteras":"megaloptera",
"megalosaurs":"megalosaur",
"megalosauridaes":"megalosauridae",
"megalosauruses":"megalosaurus",
"megalps":"megalp",
"megaphoned":"megaphone",
"megaphoning":"megaphone",
"megapodes":"megapode",
"megapodiidaes":"megapodiidae",
"megapodiuses":"megapodius",
"megapteras":"megaptera",
"megara":"megaron",
"megasporangia":"megasporangium",
"megatheres":"megathere",
"megatherians":"megatherian",
"megatheriids":"megatheriid",
"megatheriidaes":"megatheriidae",
"megatheriums":"megatherium",
"megillahs":"megillah",
"megilloth":"megillah",
"megilps":"megilp",
"megrims":"megrim",
"megrimses":"megrims",
"meis":"mei",
"meinies":"meiny",
"meioses":"meiosis",
"meistersingers":"meistersinger",
"mekongs":"mekong",
"melaenas":"melaena",
"melamines":"melamine",
"melampodiums":"melampodium",
"melampsoras":"melampsora",
"melampsoraceaes":"melampsoraceae",
"melancholiacs":"melancholiac",
"melancholics":"melancholic",
"melancholies":"melancholy",
"melanerpeses":"melanerpes",
"melanges":"melange",
"melanisms":"melanism",
"melanittas":"melanitta",
"melanogrammuses":"melanogrammus",
"melanomas":"melanoma",
"melanopluses":"melanoplus",
"melanoses":"melanosis",
"melanotises":"melanotis",
"melanthiaceaes":"melanthiaceae",
"melasmas":"melasma",
"melastomas":"melastoma",
"melastomaceaes":"melastomaceae",
"melastomataceaes":"melastomataceae",
"melded":"meld",
"melding":"meld",
"melds":"meld",
"meleagrididaes":"meleagrididae",
"meleagrises":"meleagris",
"melees":"melee",
"melenas":"melena",
"meleses":"meles",
"melias":"melia",
"meliaceaes":"meliaceae",
"melicoccas":"melicocca",
"melicoccuses":"melicoccus",
"melilots":"melilot",
"melilotuses":"melilotus",
"melinaes":"melinae",
"meliorated":"meliorate",
"meliorates":"meliorate",
"meliorating":"meliorate",
"meliorations":"melioration",
"meliorists":"meliorist",
"meliphagidaes":"meliphagidae",
"melismas":"melisma",
"melismata":"melisma",
"melissas":"melissa",
"mellarils":"mellaril",
"mellivoras":"mellivora",
"mellowed":"mellow",
"mellower":"mellow",
"mellowest":"mellow",
"mellowing":"mellow",
"mellowings":"mellowing",
"mellownesses":"mellowness",
"melocactuses":"melocactus",
"melodiousnesses":"melodiousness",
"melodized":"melodize",
"melodizing":"melodize",
"melodramas":"melodrama",
"melodramatized":"melodramatize",
"melodramatizing":"melodramatize",
"melodies":"melody",
"melogales":"melogale",
"meloids":"meloid",
"meloidaes":"meloidae",
"melolonthas":"melolontha",
"melolonthidaes":"melolonthidae",
"melons":"melon",
"melophaguses":"melophagus",
"melopsittacuses":"melopsittacus",
"melosas":"melosa",
"melospizas":"melospiza",
"melphalans":"melphalan",
"melted":"melt",
"melting":"melt",
"melts":"melt",
"meltings":"melting",
"melursuses":"melursus",
"melvilles":"melville",
"members":"member",
"memberships":"membership",
"membracidaes":"membracidae",
"membranes":"membrane",
"membranophones":"membranophone",
"mementoes":"memento",
"mementos":"memento",
"memos":"memo",
"memoirs":"memoir",
"memorabilities":"memorability",
"memorandas":"memoranda",
"memoranda":"memorandum",
"memorandums":"memorandum",
"memorials":"memorial",
"memorialisations":"memorialisation",
"memorializations":"memorialization",
"memorialized":"memorialize",
"memorializes":"memorialize",
"memorializing":"memorialize",
"memorized":"memorize",
"memorizes":"memorize",
"memorizing":"memorize",
"memories":"memory",
"mens":"men",
"menaced":"menace",
"menaces":"menace",
"menacing":"menace",
"menadiones":"menadione",
"menages":"menage",
"menageries":"menagerie",
"mended":"mend",
"mending":"mend",
"mends":"mend",
"mendacities":"mendacity",
"mendels":"mendel",
"mendeleevs":"mendeleev",
"mendeleviums":"mendelevium",
"mendeleyevs":"mendeleyev",
"mendelianisms":"mendelianism",
"mendelisms":"mendelism",
"menders":"mender",
"mendicancies":"mendicancy",
"mendicants":"mendicant",
"mendings":"mending",
"menhadens":"menhaden",
"menials":"menial",
"meningeses":"meninges",
"meningitides":"meningitis",
"meningococci":"meningococcus",
"meninges":"meninx",
"meninxes":"meninx",
"menippes":"menippe",
"menisciums":"meniscium",
"menisci":"meniscus",
"meniscuses":"meniscus",
"menispermaceaes":"menispermaceae",
"menispermums":"menispermum",
"menologies":"menology",
"menominees":"menominee",
"menominis":"menomini",
"menopauses":"menopause",
"menopons":"menopon",
"menorrhagias":"menorrhagia",
"menorrheas":"menorrhea",
"menotyphlas":"menotyphla",
"menseses":"menses",
"mensheviki":"menshevik",
"mensheviks":"menshevik",
"menstruated":"menstruate",
"menstruates":"menstruate",
"menstruating":"menstruate",
"menstruations":"menstruation",
"menstrua":"menstruum",
"menstruums":"menstruum",
"mensurations":"mensuration",
"mentalities":"mentality",
"mentations":"mentation",
"menthas":"mentha",
"menticirrhuses":"menticirrhus",
"mentioned":"mention",
"mentioning":"mention",
"mentions":"mention",
"mentors":"mentor",
"mentums":"mentum",
"mentzelias":"mentzelia",
"menus":"menu",
"menuras":"menura",
"menuraes":"menurae",
"menuridaes":"menuridae",
"menyanthaceaes":"menyanthaceae",
"menyantheses":"menyanthes",
"menziesias":"menziesia",
"meowed":"meow",
"meowing":"meow",
"meows":"meow",
"mepacrines":"mepacrine",
"meperidines":"meperidine",
"mephenytoins":"mephenytoin",
"mephitinaes":"mephitinae",
"mephitises":"mephitis",
"mephobarbitals":"mephobarbital",
"meprins":"meprin",
"meprobamates":"meprobamate",
"meqs":"meq",
"merbromines":"merbromine",
"mercantilisms":"mercantilism",
"mercaptopurines":"mercaptopurine",
"mercenarias":"mercenaria",
"mercenaries":"mercenary",
"mercerized":"mercerize",
"mercerizing":"mercerize",
"merceries":"mercery",
"merchandised":"merchandise",
"merchandises":"merchandise",
"merchandising":"merchandise",
"merchandisers":"merchandiser",
"merchandisings":"merchandising",
"merchants":"merchant",
"merchantmen":"merchantman",
"mercifulnesses":"mercifulness",
"mercilessnesses":"mercilessness",
"mercurated":"mercurate",
"mercurating":"mercurate",
"mercurialises":"mercurialise",
"mercurochromes":"mercurochrome",
"mercuries":"mercury",
"mercies":"mercy",
"meres":"mere",
"merestones":"merestone",
"meretriciousnesses":"meretriciousness",
"mergansers":"merganser",
"merged":"merge",
"merges":"merge",
"merging":"merge",
"mergers":"merger",
"merginaes":"merginae",
"mergings":"merging",
"merguses":"mergus",
"meridians":"meridian",
"merinos":"merino",
"merioneses":"meriones",
"merited":"merit",
"meriting":"merit",
"merits":"merit",
"meritocracies":"meritocracy",
"meritoriousnesses":"meritoriousness",
"merls":"merl",
"merlanguses":"merlangus",
"merles":"merle",
"merlins":"merlin",
"merlucciuses":"merluccius",
"mermaids":"mermaid",
"mermen":"merman",
"merodaches":"merodach",
"meronyms":"meronym",
"meronymies":"meronymy",
"meropidaes":"meropidae",
"meropses":"merops",
"merostomatas":"merostomata",
"merriments":"merriment",
"merrinesses":"merriness",
"merrier":"merry",
"merriest":"merry",
"merry-go-rounds":"merry-go-round",
"merrymakers":"merrymaker",
"merrymakings":"merrymaking",
"mertensias":"mertensia",
"merthiolates":"merthiolate",
"merytas":"meryta",
"mesas":"mesa",
"mesantoins":"mesantoin",
"mescals":"mescal",
"mescalines":"mescaline",
"mesembryanthemums":"mesembryanthemum",
"mesencephala":"mesencephalon",
"mesencephalons":"mesencephalon",
"mesentera":"mesenteron",
"mesentertera":"mesenteron",
"mesenteries":"mesentery",
"meshed":"mesh",
"meshes":"mesh",
"meshing":"mesh",
"mesheds":"meshed",
"meshings":"meshing",
"meshworks":"meshwork",
"meshier":"meshy",
"meshiest":"meshy",
"mesmerisms":"mesmerism",
"mesmerists":"mesmerist",
"mesmerized":"mesmerize",
"mesmerizes":"mesmerize",
"mesmerizing":"mesmerize",
"mesnalties":"mesnalty",
"mesoblasts":"mesoblast",
"mesocricetuses":"mesocricetus",
"mesoderms":"mesoderm",
"mesomorphies":"mesomorphy",
"mesons":"meson",
"mesonephroi":"mesonephros",
"mesophytes":"mesophyte",
"mesothelia":"mesothelium",
"mesothoraces":"mesothorax",
"mesothoraxes":"mesothorax",
"mesotrons":"mesotron",
"mesozoics":"mesozoic",
"mespiluses":"mespilus",
"mesquits":"mesquit",
"mesquites":"mesquite",
"messed":"mess",
"messes":"mess",
"messing":"mess",
"mess-ups":"mess-up",
"messages":"message",
"messengers":"messenger",
"messiahs":"messiah",
"messinesses":"messiness",
"messier":"messy",
"messiest":"messy",
"mestizas":"mestiza",
"mestizoes":"mestizo",
"mestizos":"mestizo",
"mesuas":"mesua",
"metabolisms":"metabolism",
"metabolized":"metabolize",
"metabolizing":"metabolize",
"metacarpals":"metacarpal",
"metacarpi":"metacarpus",
"metagalaxies":"metagalaxy",
"metageneses":"metagenesis",
"metaled":"metal",
"metaling":"metal",
"metalled":"metal",
"metalling":"metal",
"metals":"metal",
"metalized":"metalize",
"metalizing":"metalize",
"metallurgists":"metallurgist",
"metalworks":"metalwork",
"metalworkers":"metalworker",
"metalworkings":"metalworking",
"metalworkses":"metalworks",
"metameres":"metamere",
"metamorphosed":"metamorphose",
"metamorphoses":"metamorphose",
"metamorphosing":"metamorphose",
"metanephroi":"metanephros",
"metaproterenols":"metaproterenol",
"metasequoias":"metasequoia",
"metastases":"metastasis",
"metastasized":"metastasize",
"metastasizing":"metastasize",
"metatarsi":"metatarsus",
"metatherias":"metatheria",
"metatheses":"metathesis",
"metathesized":"metathesize",
"metathesizing":"metathesize",
"metathoraces":"metathorax",
"metathoraxes":"metathorax",
"metazoas":"metazoa",
"meted":"mete",
"meting":"mete",
"metempsychoses":"metempsychosis",
"metencephala":"metencephalon",
"metencephalons":"metencephalon",
"meteors":"meteor",
"meteorites":"meteorite",
"meteorologies":"meteorology",
"metered":"meter",
"metering":"meter",
"meters":"meter",
"meths":"meth",
"methacholines":"methacholine",
"methadons":"methadon",
"methadones":"methadone",
"methamphetamines":"methamphetamine",
"methanals":"methanal",
"methanols":"methanol",
"methaqualones":"methaqualone",
"metharbitals":"metharbital",
"methedrines":"methedrine",
"methenamines":"methenamine",
"methought":"methinks",
"methocarbamols":"methocarbamol",
"methods":"method",
"methodicalnesses":"methodicalness",
"methodistses":"methodists",
"methodized":"methodize",
"methodizing":"methodize",
"methodologies":"methodology",
"methyls":"methyl",
"methylated":"methylate",
"methylating":"methylate",
"methylbenzenes":"methylbenzene",
"methyldopas":"methyldopa",
"methylenedioxymethamphetamines":"methylenedioxymethamphetamine",
"methylphenidates":"methylphenidate",
"meticulosities":"meticulosity",
"meticulousnesses":"meticulousness",
"metiers":"metier",
"metifs":"metif",
"metonymies":"metonymy",
"metoprolols":"metoprolol",
"metrazols":"metrazol",
"metres":"metre",
"metricated":"metricate",
"metricating":"metricate",
"metrications":"metrication",
"metricized":"metricize",
"metricizing":"metricize",
"metrifications":"metrification",
"metrified":"metrify",
"metrifies":"metrify",
"metrifying":"metrify",
"metritises":"metritis",
"metros":"metro",
"metrologies":"metrology",
"metronymics":"metronymic",
"metropolises":"metropolis",
"metropolitans":"metropolitan",
"metroxylons":"metroxylon",
"mettles":"mettle",
"metycaines":"metycaine",
"meuses":"meuse",
"meuse-argonnes":"meuse-argonne",
"mevacors":"mevacor",
"mewed":"mew",
"mewing":"mew",
"mews":"mew",
"mewled":"mewl",
"mewling":"mewl",
"mewls":"mewl",
"mexiletines":"mexiletine",
"mexitils":"mexitil",
"mezcals":"mezcal",
"mezereons":"mezereon",
"mezuzahs":"mezuzah",
"mezuzoth":"mezuzah",
"mezzanines":"mezzanine",
"mezzos":"mezzo",
"mezzo-relievos":"mezzo-relievo",
"mezzo-rilievos":"mezzo-rilievo",
"mezzo-soprani":"mezzo-soprano",
"mezzo-sopranos":"mezzo-soprano",
"mezzotinted":"mezzotint",
"mezzotinting":"mezzotint",
"mfs":"mf",
"mfas":"mfa",
"mflopses":"mflops",
"mgs":"mg",
"mhos":"mho",
"mhzs":"mhz",
"mis":"mi",
"miaous":"miaou",
"miaows":"miaow",
"miasmas":"miasma",
"miasmata":"miasma",
"micas":"mica",
"michaelmases":"michaelmas",
"michigans":"michigan",
"michiganders":"michigander",
"micks":"mick",
"meckeys":"mickey",
"mickeys":"mickey",
"mickles":"mickle",
"micmacs":"micmac",
"microanalyses":"microanalysis",
"microbars":"microbar",
"microbats":"microbat",
"microbes":"microbe",
"microcentrums":"microcentrum",
"microcephaluses":"microcephalus",
"microcephalies":"microcephaly",
"microchips":"microchip",
"microchiropteras":"microchiroptera",
"microcircuits":"microcircuit",
"micrococcaceaes":"micrococcaceae",
"micrococci":"micrococcus",
"micrococcuses":"micrococcus",
"microcomputers":"microcomputer",
"microcopies":"microcopy",
"microdesmidaes":"microdesmidae",
"microdipodopses":"microdipodops",
"microfaunae":"microfauna",
"microfaunas":"microfauna",
"microfiches":"microfiche",
"microfilmed":"microfilm",
"microfilming":"microfilm",
"microflorae":"microflora",
"microfloras":"microflora",
"micrograms":"microgram",
"microgrammas":"microgramma",
"microgramma-piloselloideses":"microgramma-piloselloides",
"microhylidaes":"microhylidae",
"micromerias":"micromeria",
"micrometers":"micrometer",
"micrometres":"micrometre",
"micromicrons":"micromicron",
"micromillimeters":"micromillimeter",
"micromillimetres":"micromillimetre",
"microminis":"micromini",
"microminiaturized":"microminiaturize",
"microminiaturizing":"microminiaturize",
"micromyxes":"micromyx",
"micra":"micron",
"microns":"micron",
"micronases":"micronase",
"micronuclei":"micronucleus",
"micronucleuses":"micronucleus",
"microphones":"microphone",
"micropogoniases":"micropogonias",
"micropteruses":"micropterus",
"microscopes":"microscope",
"microseisms":"microseism",
"microsoriums":"microsorium",
"microsoporangia":"microsporangium",
"microsporangia":"microsporangium",
"microsporums":"microsporum",
"microstomuses":"microstomus",
"microstroboses":"microstrobos",
"microtomies":"microtomy",
"microtuses":"microtus",
"microwaves":"microwave",
"micruroideses":"micruroides",
"micruruses":"micrurus",
"micterias":"micteria",
"micturated":"micturate",
"micturates":"micturate",
"micturating":"micturate",
"micturitions":"micturition",
"mid-eightieses":"mid-eighties",
"mid-fiftieses":"mid-fifties",
"mid-fortieses":"mid-forties",
"mid-ninetieses":"mid-nineties",
"mid-seventieses":"mid-seventies",
"mid-sixtieses":"mid-sixties",
"mid-thirtieses":"mid-thirties",
"mid-twentieses":"mid-twenties",
"midbrains":"midbrain",
"middays":"midday",
"middens":"midden",
"middled":"middle",
"middles":"middle",
"middling":"middle",
"middlebreakers":"middlebreaker",
"middleclasses":"middleclass",
"middlemen":"middleman",
"middies":"middy",
"midgets":"midget",
"midis":"midi",
"midinettes":"midinette",
"midirons":"midiron",
"midlands":"midland",
"midlines":"midline",
"midplanes":"midplane",
"midpoints":"midpoint",
"midrashim":"midrash",
"midriffs":"midriff",
"midsections":"midsection",
"midshipmen":"midshipman",
"midsts":"midst",
"midsummers":"midsummer",
"midsummer-mens":"midsummer-men",
"midterms":"midterm",
"midwatches":"midwatch",
"midways":"midway",
"midwests":"midwest",
"midwives":"midwife",
"midwiferies":"midwifery",
"miens":"mien",
"mierkats":"mierkat",
"miffed":"miff",
"miffing":"miff",
"miffs":"miff",
"miffier":"miffy",
"miffiest":"miffy",
"mights":"might",
"mightinesses":"mightiness",
"mightier":"mighty",
"mightiest":"mighty",
"mignonettes":"mignonette",
"migraines":"migraine",
"migrated":"migrate",
"migrating":"migrate",
"migrations":"migration",
"mikados":"mikado",
"mikanias":"mikania",
"miked":"mike",
"mikes":"mike",
"miking":"mike",
"mils":"mil",
"miladies":"milady",
"milages":"milage",
"milans":"milan",
"milanos":"milano",
"milchers":"milcher",
"milder":"mild",
"mildest":"mild",
"mildewed":"mildew",
"mildewing":"mildew",
"mildews":"mildew",
"mildnesses":"mildness",
"miles":"mile",
"mileages":"mileage",
"mileometers":"mileometer",
"mileposts":"milepost",
"milestones":"milestone",
"milfoils":"milfoil",
"milieus":"milieu",
"milieux":"milieu",
"militating_against":"militage_against",
"militances":"militance",
"militancies":"militancy",
"militants":"militant",
"militarisations":"militarisation",
"militarists":"militarist",
"militarizations":"militarization",
"militarized":"militarize",
"militarizing":"militarize",
"militaries":"military",
"militated":"militate",
"militating":"militate",
"militated_against":"militate_against",
"militates_against":"militate_against",
"militias":"militia",
"militiamen":"militiaman",
"milia":"milium",
"miliums":"milium",
"milked":"milk",
"milking":"milk",
"milks":"milk",
"milkcaps":"milkcap",
"milkers":"milker",
"milkfishes":"milkfish",
"milkmaids":"milkmaid",
"milkmen":"milkman",
"milkshakes":"milkshake",
"milksops":"milksop",
"milkvetches":"milkvetch",
"milkweeds":"milkweed",
"milkier":"milky",
"milkiest":"milky",
"milled":"mill",
"milling":"mill",
"mills":"mill",
"mill-hands":"mill-hand",
"millenarians":"millenarian",
"millenarists":"millenarist",
"millenaries":"millenary",
"millennia":"millennium",
"millenniums":"millennium",
"millepedes":"millepede",
"millers":"miller",
"millets":"millet",
"milliamperes":"milliampere",
"millicuries":"millicurie",
"milliequivalents":"milliequivalent",
"milligrams":"milligram",
"milliliters":"milliliter",
"millilitres":"millilitre",
"millimeters":"millimeter",
"millimetres":"millimetre",
"millimicra":"millimicron",
"millimicrons":"millimicron",
"milliners":"milliner",
"millineries":"millinery",
"millions":"million",
"millionaires":"millionaire",
"millionses":"millions",
"millionths":"millionth",
"millipeds":"milliped",
"millipedes":"millipede",
"milliseconds":"millisecond",
"millivolts":"millivolt",
"millraces":"millrace",
"millruns":"millrun",
"millstones":"millstone",
"milos":"milo",
"milometers":"milometer",
"milquetoasts":"milquetoast",
"milts":"milt",
"miltomates":"miltomate",
"miltonias":"miltonia",
"miltowns":"miltown",
"milvuses":"milvus",
"mimed":"mime",
"mimes":"mime",
"miming":"mime",
"mimeos":"mimeo",
"mimeographed":"mimeograph",
"mimeographing":"mimeograph",
"mimeographs":"mimeograph",
"mimers":"mimer",
"mimicked":"mimic",
"mimicking":"mimic",
"mimics":"mimic",
"mimickers":"mimicker",
"mimicries":"mimicry",
"mimidaes":"mimidae",
"mimosas":"mimosa",
"mimosaceaes":"mimosaceae",
"mimosoideaes":"mimosoideae",
"mimuses":"mimus",
"mins":"min",
"minas":"mina",
"minahs":"minah",
"minced":"mince",
"minces":"mince",
"mincing":"mince",
"mincers":"mincer",
"minded":"mind",
"minding":"mind",
"minds":"mind",
"mindens":"minden",
"minders":"minder",
"mindfulnesses":"mindfulness",
"mindlessnesses":"mindlessness",
"mined":"mine",
"mines":"mine",
"mining":"mine",
"minelayings":"minelaying",
"miners":"miner",
"minerals":"mineral",
"mineralized":"mineralize",
"mineralizing":"mineralize",
"minestrones":"minestrone",
"mineworkers":"mineworker",
"minginesses":"minginess",
"mingled":"mingle",
"mingles":"mingle",
"mingling":"mingle",
"mingle-mangles":"mingle-mangle",
"mingier":"mingy",
"mingiest":"mingy",
"minis":"mini",
"miniatured":"miniature",
"miniatures":"miniature",
"miniaturing":"miniature",
"miniaturisations":"miniaturisation",
"miniaturizations":"miniaturization",
"miniaturized":"miniaturize",
"miniaturizes":"miniaturize",
"miniaturizing":"miniaturize",
"minibars":"minibar",
"minibikes":"minibike",
"minified":"minify",
"minifies":"minify",
"minifying":"minify",
"minims":"minim",
"minimisations":"minimisation",
"minimizations":"minimization",
"minimized":"minimize",
"minimizes":"minimize",
"minimizing":"minimize",
"minimizers":"minimizer",
"minima":"minimum",
"minimums":"minimum",
"minings":"mining",
"minions":"minion",
"miniskirts":"miniskirt",
"ministered":"minister",
"ministering":"minister",
"ministers":"minister",
"ministeria":"ministerium",
"ministrations":"ministration",
"ministries":"ministry",
"miniums":"minium",
"minks":"mink",
"minnesotas":"minnesota",
"minniebushes":"minniebush",
"minnows":"minnow",
"minocins":"minocin",
"minocyclines":"minocycline",
"minored":"minor",
"minoring":"minor",
"minors":"minor",
"minorities":"minority",
"minorses":"minors",
"minoxidils":"minoxidil",
"minsks":"minsk",
"minsters":"minster",
"minstrels":"minstrel",
"minstrelsies":"minstrelsy",
"minted":"mint",
"minting":"mint",
"mints":"mint",
"mintages":"mintage",
"minters":"minter",
"mintier":"minty",
"mintiest":"minty",
"minuartias":"minuartia",
"minuses":"minus",
"minuted":"minute",
"minutes":"minute",
"minuting":"minute",
"minutemen":"minuteman",
"minutenesses":"minuteness",
"minuteses":"minutes",
"minutiae":"minutia",
"minxes":"minx",
"minyanim":"minyan",
"minyans":"minyan",
"miocenes":"miocene",
"mioses":"miosis",
"mipses":"mips",
"miri":"mir",
"mirabilises":"mirabilis",
"miracidiia":"miracidium",
"miracles":"miracle",
"miracle-worships":"miracle-worship",
"mirasols":"mirasol",
"mired":"mire",
"mires":"mire",
"miring":"mire",
"miris":"miri",
"mirids":"mirid",
"miridaes":"miridae",
"mirishes":"mirish",
"mirkier":"mirky",
"mirkiest":"mirky",
"miros":"miro",
"miroungas":"mirounga",
"mirrored":"mirror",
"mirroring":"mirror",
"mirrors":"mirror",
"mirths":"mirth",
"mirthfulnesses":"mirthfulness",
"misadventures":"misadventure",
"misallied":"misally",
"misallying":"misally",
"misapplications":"misapplication",
"misapplied":"misapply",
"misapplies":"misapply",
"misapplying":"misapply",
"misapprehended":"misapprehend",
"misapprehending":"misapprehend",
"misapprehends":"misapprehend",
"misapprehensions":"misapprehension",
"misappopriated":"misappropriate",
"misappropriated":"misappropriate",
"misappropriating":"misappropriate",
"misappropriations":"misappropriation",
"misbecame":"misbecome",
"misbecomes":"misbecome",
"misbecoming":"misbecome",
"misbehaved":"misbehave",
"misbehaves":"misbehave",
"misbehaving":"misbehave",
"misbehaviors":"misbehavior",
"misbehaviours":"misbehaviour",
"misbelievers":"misbeliever",
"miscalculations":"miscalculation",
"miscalled":"miscall",
"miscalling":"miscall",
"miscalls":"miscall",
"miscarriages":"miscarriage",
"miscarried":"miscarry",
"miscarries":"miscarry",
"miscarrying":"miscarry",
"miscasting":"miscast",
"miscasts":"miscast",
"miscegenations":"miscegenation",
"miscellaneas":"miscellanea",
"miscellanies":"miscellany",
"mischances":"mischance",
"mischiefs":"mischief",
"mischieves":"mischief",
"mischief-makers":"mischief-maker",
"mischief-makings":"mischief-making",
"mischievousnesses":"mischievousness",
"misconceived":"misconceive",
"misconceives":"misconceive",
"misconceiving":"misconceive",
"misconducted":"misconduct",
"misconducting":"misconduct",
"misconducts":"misconduct",
"misconstruals":"misconstrual",
"misconstructions":"misconstruction",
"misconstrued":"misconstrue",
"misconstrues":"misconstrue",
"misconstruing":"misconstrue",
"miscounted":"miscount",
"miscounting":"miscount",
"miscreants":"miscreant",
"miscreated":"miscreate",
"miscreating":"miscreate",
"miscreations":"miscreation",
"miscued":"miscue",
"miscues":"miscue",
"miscuing":"miscue",
"misdatings":"misdating",
"misdealing":"misdeal",
"misdeals":"misdeal",
"misdealt":"misdeal",
"misdeeds":"misdeed",
"misdemeanors":"misdemeanor",
"misdemeanours":"misdemeanour",
"misdirected":"misdirect",
"misdirecting":"misdirect",
"misdirects":"misdirect",
"misdid":"misdo",
"misdoing":"misdo",
"misdone":"misdo",
"misdoings":"misdoing",
"misdoubted":"misdoubt",
"misdoubting":"misdoubt",
"misemployed":"misemploy",
"misemploying":"misemploy",
"misers":"miser",
"miseries":"misery",
"misestimations":"misestimation",
"misfired":"misfire",
"misfires":"misfire",
"misfiring":"misfire",
"misfits":"misfit",
"misfitted":"misfit",
"misfitting":"misfit",
"misfortunes":"misfortune",
"misgave":"misgive",
"misgiven":"misgive",
"misgives":"misgive",
"misgiving":"misgive",
"misgivings":"misgiving",
"misgovernments":"misgovernment",
"misguided":"misguide",
"misguides":"misguide",
"misguiding":"misguide",
"mishandled":"mishandle",
"mishandles":"mishandle",
"mishandling":"mishandle",
"mishaps":"mishap",
"misheard":"mishear",
"mishearing":"mishear",
"mishears":"mishear",
"mishits":"mishit",
"mishitting":"mishit",
"mishnayoth":"mishna",
"misinformed":"misinform",
"misinforming":"misinform",
"misinforms":"misinform",
"misinterpreted":"misinterpret",
"misinterpreting":"misinterpret",
"misinterprets":"misinterpret",
"misinterpretations":"misinterpretation",
"misjuded":"misjudge",
"misjudged":"misjudge",
"misjudging":"misjudge",
"misknew":"misknow",
"misknowing":"misknow",
"misknown":"misknow",
"mislaid":"mislay",
"mislaying":"mislay",
"mislays":"mislay",
"misleading":"mislead",
"misleads":"mislead",
"misled":"mislead",
"misliked":"mislike",
"misliking":"mislike",
"mismanaged":"mismanage",
"mismanages":"mismanage",
"mismanaging":"mismanage",
"mismatched":"mismatch",
"mismatching":"mismatch",
"misogamists":"misogamist",
"misogynisms":"misogynism",
"misogynists":"misogynist",
"misogynies":"misogyny",
"misoriented":"misorient",
"misorienting":"misorient",
"mispickels":"mispickel",
"misplaced":"misplace",
"misplaces":"misplace",
"misplacing":"misplace",
"misplacements":"misplacement",
"misplayed":"misplay",
"misplaying":"misplay",
"misplays":"misplay",
"mispleaded":"misplead",
"mispleading":"misplead",
"mispleads":"misplead",
"mispled":"misplead",
"misprinted":"misprint",
"misprinting":"misprint",
"misprints":"misprint",
"misprized":"misprize",
"misprizing":"misprize",
"mispronounced":"mispronounce",
"mispronouncing":"mispronounce",
"misquoted":"misquote",
"misquoting":"misquote",
"misreading":"misread",
"misreads":"misread",
"misreckonings":"misreckoning",
"misremembered":"misremember",
"misremembering":"misremember",
"misreported":"misreport",
"misreporting":"misreport",
"misrepresented":"misrepresent",
"misrepresenting":"misrepresent",
"misrepresents":"misrepresent",
"misrepresentations":"misrepresentation",
"misruled":"misrule",
"misrules":"misrule",
"misruling":"misrule",
"missed":"miss",
"misses":"miss",
"missing":"miss",
"missaid":"missay",
"missaying":"missay",
"missending":"missend",
"missent":"missend",
"missfires":"missfire",
"misshaped":"misshape",
"misshapen":"misshape",
"misshaping":"misshape",
"misshapennesses":"misshapenness",
"missiles":"missile",
"missilemen":"missileman",
"missioned":"mission",
"missioning":"mission",
"missions":"mission",
"missionaries":"missionary",
"missioners":"missioner",
"missionized":"missionize",
"missionizing":"missionize",
"mississippis":"mississippi",
"mississippians":"mississippian",
"missives":"missive",
"missouris":"missouri",
"misspelled":"misspell",
"misspelling":"misspell",
"misspells":"misspell",
"misspelt":"misspell",
"misspending":"misspend",
"misspends":"misspend",
"misspent":"misspend",
"misstated":"misstate",
"misstating":"misstate",
"missteps":"misstep",
"missuses":"missus",
"missies":"missy",
"misted":"mist",
"misting":"mist",
"mists":"mist",
"mistaken":"mistake",
"mistakes":"mistake",
"mistaking":"mistake",
"mistook":"mistake",
"mistakings":"mistaking",
"mistered":"mister",
"mistering":"mister",
"misters":"mister",
"mistflowers":"mistflower",
"misthinking":"misthink",
"misthought":"misthink",
"mistimings":"mistiming",
"mistinesses":"mistiness",
"mistletoes":"mistletoe",
"mistreated":"mistreat",
"mistreating":"mistreat",
"mistreats":"mistreat",
"mistresses":"mistress",
"mistrusted":"mistrust",
"mistrusting":"mistrust",
"mistrusts":"mistrust",
"mistier":"misty",
"mistiest":"misty",
"misunderstanding":"misunderstand",
"misunderstands":"misunderstand",
"misunderstood":"misunderstand",
"misunderstandings":"misunderstanding",
"misused":"misuse",
"misuses":"misuse",
"misusing":"misuse",
"misworded":"misword",
"miswording":"misword",
"mitchellas":"mitchella",
"mites":"mite",
"mitellas":"mitella",
"mitered":"miter",
"mitering":"miter",
"miters":"miter",
"miterworts":"miterwort",
"mithans":"mithan",
"mithras":"mithra",
"mithracins":"mithracin",
"mithraicisms":"mithraicism",
"mithraisms":"mithraism",
"mithramycins":"mithramycin",
"mithrases":"mithras",
"mithridateses":"mithridates",
"mitigated":"mitigate",
"mitigates":"mitigate",
"mitigating":"mitigate",
"mitigations":"mitigation",
"mitigators":"mitigator",
"mitochondria":"mitochondrion",
"mitochondrions":"mitochondrion",
"mitres":"mitre",
"mitreworts":"mitrewort",
"mitts":"mitt",
"mittens":"mitten",
"mittenses":"mittens",
"mittimuses":"mittimus",
"mitzvahs":"mitzvah",
"mitzvoth":"mitzvah",
"miwoks":"miwok",
"mixed":"mix",
"mixes":"mix",
"mixing":"mix",
"mix-ups":"mix-up",
"mixers":"mixer",
"mixings":"mixing",
"mixologists":"mixologist",
"mixtecs":"mixtec",
"mixtures":"mixture",
"mizens":"mizen",
"mizenmasts":"mizenmast",
"mizzens":"mizzen",
"mizzenmasts":"mizzenmast",
"mizzled":"mizzle",
"mizzles":"mizzle",
"mizzling":"mizzle",
"mls":"ml",
"mlitts":"mlitt",
"mlles":"mlle",
"mlses":"mls",
"mms":"mm",
"mns":"mn",
"mniaceaes":"mniaceae",
"mniums":"mnium",
"mos":"mo",
"moas":"moa",
"moaned":"moan",
"moaning":"moan",
"moans":"moan",
"moaners":"moaner",
"moated":"moat",
"moating":"moat",
"moats":"moat",
"mobbed":"mob",
"mobbing":"mob",
"mobs":"mob",
"mobiles":"mobile",
"mobilisations":"mobilisation",
"mobilizations":"mobilization",
"mobilized":"mobilize",
"mobilizes":"mobilize",
"mobilizing":"mobilize",
"mobocracies":"mobocracy",
"mobsters":"mobster",
"mobulas":"mobula",
"mobulidaes":"mobulidae",
"mocambiques":"mocambique",
"mocassins":"mocassin",
"moccasins":"moccasin",
"moccasinses":"moccasins",
"mocked":"mock",
"mocking":"mock",
"mocks":"mock",
"mockers":"mocker",
"mockernuts":"mockernut",
"mockeries":"mockery",
"mockingbirds":"mockingbird",
"modalities":"modality",
"modes":"mode",
"modeled":"model",
"modeling":"model",
"modelled":"model",
"modelling":"model",
"models":"model",
"modelers":"modeler",
"modelings":"modeling",
"modellers":"modeller",
"modellings":"modelling",
"moderated":"moderate",
"moderates":"moderate",
"moderating":"moderate",
"moderatenesses":"moderateness",
"moderations":"moderation",
"moderationists":"moderationist",
"moderns":"modern",
"modernisations":"modernisation",
"modernisms":"modernism",
"modernities":"modernity",
"modernizations":"modernization",
"modernized":"modernize",
"modernizes":"modernize",
"modernizing":"modernize",
"modernizings":"modernizing",
"modernnesses":"modernness",
"modestnesses":"modestness",
"modesties":"modesty",
"modica":"modicum",
"modicums":"modicum",
"modifications":"modification",
"modifiers":"modifier",
"modified":"modify",
"modifies":"modify",
"modifying":"modify",
"modioli":"modiolus",
"modishnesses":"modishness",
"modistes":"modiste",
"modulated":"modulate",
"modulates":"modulate",
"modulating":"modulate",
"modulations":"modulation",
"modules":"module",
"moduli":"modulus",
"modului":"modulus",
"modi":"modus",
"moehringias":"moehringia",
"mogadiscios":"mogadiscio",
"moghuls":"moghul",
"moguls":"mogul",
"mohammadanisms":"mohammadanism",
"mohammeds":"mohammed",
"mohammedans":"mohammedan",
"mohammedanisms":"mohammedanism",
"mohaves":"mohave",
"mohawks":"mohawk",
"mohicans":"mohican",
"mohrias":"mohria",
"moieties":"moiety",
"moiled":"moil",
"moiling":"moil",
"moils":"moil",
"moiraes":"moirae",
"moirais":"moirai",
"moires":"moire",
"moister":"moist",
"moistest":"moist",
"moistened":"moisten",
"moistening":"moisten",
"moistens":"moisten",
"moistenings":"moistening",
"moistnesses":"moistness",
"moistures":"moisture",
"moisturized":"moisturize",
"moisturizes":"moisturize",
"moisturizing":"moisturize",
"mojaves":"mojave",
"mols":"mol",
"molas":"mola",
"molalities":"molality",
"molars":"molar",
"molarities":"molarity",
"molded":"mold",
"molding":"mold",
"molds":"mold",
"moldavias":"moldavia",
"moldboards":"moldboard",
"moldered":"molder",
"moldering":"molder",
"molders":"molder",
"moldinesses":"moldiness",
"moldings":"molding",
"moldovas":"moldova",
"moldier":"moldy",
"moldiest":"moldy",
"moles":"mole",
"moleches":"molech",
"molecules":"molecule",
"molested":"molest",
"molesting":"molest",
"molests":"molest",
"molestations":"molestation",
"molidaes":"molidae",
"molls":"moll",
"mollahs":"mollah",
"molles":"molle",
"mollies":"molly",
"mollienesias":"mollienesia",
"mollifications":"mollification",
"mollified":"mollify",
"mollifies":"mollify",
"mollifying":"mollify",
"mollugas":"molluga",
"molluscs":"mollusc",
"molluscas":"mollusca",
"mollusks":"mollusk",
"mollycoddled":"mollycoddle",
"mollycoddles":"mollycoddle",
"mollycoddling":"mollycoddle",
"moloches":"moloch",
"molokais":"molokai",
"molossidaes":"molossidae",
"molothruses":"molothrus",
"molotovs":"molotov",
"molted":"molt",
"molting":"molt",
"molts":"molt",
"moltings":"molting",
"molucellas":"molucella",
"molvas":"molva",
"molies":"moly",
"molybdenums":"molybdenum",
"moms":"mom",
"mombins":"mombin",
"moments":"moment",
"momenta":"momentum",
"momentums":"momentum",
"momisms":"momism",
"mommas":"momma",
"mommies":"mommy",
"momordicas":"momordica",
"momoses":"momos",
"momots":"momot",
"momotidaes":"momotidae",
"momotuses":"momotus",
"momi":"momus",
"momuses":"momus",
"mons":"mon",
"monades":"monad",
"monads":"monad",
"monals":"monal",
"monarches":"monarch",
"monarchists":"monarchist",
"monarchies":"monarchy",
"monardas":"monarda",
"monardellas":"monardella",
"monases":"monas",
"monasteries":"monastery",
"monastics":"monastic",
"monauls":"monaul",
"mondays":"monday",
"moneras":"monera",
"monerans":"moneran",
"monerons":"moneron",
"moneseses":"moneses",
"monetisations":"monetisation",
"monetizations":"monetization",
"monetized":"monetize",
"monetizing":"monetize",
"moneys":"money",
"monies":"money",
"money-spinners":"money-spinner",
"moneylenders":"moneylender",
"moneymakers":"moneymaker",
"moneymen":"moneyman",
"moneyworts":"moneywort",
"mongers":"monger",
"mongos":"mongo",
"mongoes":"mongoe",
"Mongols":"Mongol",
"mongolias":"mongolia",
"Mongolians":"Mongolian",
"mongolianisms":"mongolianism",
"mongolics":"mongolic",
"mongolisms":"mongolism",
"mongeese":"mongoose",
"mongooses":"mongoose",
"mongrels":"mongrel",
"mongrelized":"mongrelize",
"mongrelizing":"mongrelize",
"monikers":"moniker",
"moniliaceaes":"moniliaceae",
"monilialeses":"moniliales",
"moniliases":"moniliasis",
"monitions":"monition",
"monitored":"monitor",
"monitoring":"monitor",
"monitors":"monitor",
"monitories":"monitory",
"monks":"monk",
"monkeries":"monkery",
"monkeyed":"monkey",
"monkeying":"monkey",
"monkeys":"monkey",
"monkeypods":"monkeypod",
"monkeywrenches":"monkeywrench",
"monkfishes":"monkfish",
"monkshoods":"monkshood",
"monos":"mono",
"monocanthidaes":"monocanthidae",
"monocanthuses":"monocanthus",
"monocarps":"monocarp",
"monochamuses":"monochamus",
"monochasia":"monochasium",
"monochromes":"monochrome",
"monocles":"monocle",
"monocots":"monocot",
"monocotyledons":"monocotyledon",
"monocotyledonaes":"monocotyledonae",
"monocotyledoneses":"monocotyledones",
"monocracies":"monocracy",
"monocycles":"monocycle",
"monodons":"monodon",
"monodontidaes":"monodontidae",
"monodramas":"monodrama",
"monodies":"monody",
"monogamists":"monogamist",
"monogamousnesses":"monogamousness",
"monogamies":"monogamy",
"monogeneses":"monogenesis",
"monogrammed":"monogram",
"monogramming":"monogram",
"monograms":"monogram",
"monogynists":"monogynist",
"monogynies":"monogyny",
"monologues":"monologue",
"monomanias":"monomania",
"monomoriums":"monomorium",
"mononucleoses":"mononucleosis",
"monophobias":"monophobia",
"monophonies":"monophony",
"monophthalmoses":"monophthalmos",
"monopodia":"monopodium",
"monopolisations":"monopolisation",
"monopolists":"monopolist",
"monopolizations":"monopolization",
"monopolized":"monopolize",
"monopolizing":"monopolize",
"monopolizers":"monopolizer",
"monopolies":"monopoly",
"monopsonies":"monopsony",
"monoptera":"monopteron",
"monopteroi":"monopteros",
"monosaccharides":"monosaccharide",
"monosaccharoses":"monosaccharose",
"monosyllables":"monosyllable",
"monotones":"monotone",
"monotonies":"monotony",
"monotrematas":"monotremata",
"monotremes":"monotreme",
"monotropas":"monotropa",
"monotropaceaes":"monotropaceae",
"monroes":"monroe",
"monrovias":"monrovia",
"monses":"mons",
"messeigneurs":"monseigneur",
"messieurs":"monsieur",
"monsignori":"monsignor",
"monsignors":"monsignor",
"monsters":"monster",
"monsteras":"monstera",
"monstrosities":"monstrosity",
"monts-de-piete":"mont-de-piete",
"montages":"montage",
"montagnards":"montagnard",
"montanas":"montana",
"montes":"monte",
"monteros":"montero",
"montevideos":"montevideo",
"montforts":"montfort",
"montgomeries":"montgomery",
"months":"month",
"monthlies":"monthly",
"montias":"montia",
"montpeliers":"montpelier",
"monuments":"monument",
"monumentalized":"monumentalize",
"monumentalizing":"monumentalize",
"mooed":"moo",
"mooing":"moo",
"moos":"moo",
"moo-cows":"moo-cow",
"mooched":"mooch",
"mooches":"mooch",
"mooching":"mooch",
"moochers":"moocher",
"moods":"mood",
"moodier":"moody",
"moodiest":"moody",
"moolahs":"moolah",
"mooned":"moon",
"mooning":"moon",
"moons":"moon",
"moon-worships":"moon-worship",
"moonbeams":"moonbeam",
"mooncalves":"mooncalf",
"mooncursers":"mooncurser",
"mooneyes":"mooneye",
"moonfishes":"moonfish",
"moonflowers":"moonflower",
"moonlighted":"moonlight",
"moonlighting":"moonlight",
"moonlights":"moonlight",
"moonrays":"moonray",
"moonshines":"moonshine",
"moonshiners":"moonshiner",
"moonworts":"moonwort",
"moonier":"moony",
"mooniest":"moony",
"moored":"moor",
"mooring":"moor",
"moors":"moor",
"moorages":"moorage",
"moorberries":"moorberry",
"moorbirds":"moorbird",
"moorfowls":"moorfowl",
"moorgames":"moorgame",
"moorhens":"moorhen",
"moorings":"mooring",
"moorishes":"moorish",
"moorlands":"moorland",
"moorworts":"moorwort",
"mooses":"moose",
"moosewoods":"moosewood",
"mopped":"mop",
"mopping":"mop",
"mops":"mop",
"mopboards":"mopboard",
"moped":"mope",
"mopes":"mope",
"moping":"mope",
"moperies":"mopery",
"mopeses":"mopes",
"moppings":"mopping",
"mopier":"mopy",
"mopiest":"mopy",
"moquelumnans":"moquelumnan",
"morae":"mora",
"moras":"mora",
"moraceaes":"moraceae",
"morals":"moral",
"morales":"morale",
"moralists":"moralist",
"moralities":"morality",
"moralized":"moralize",
"moralizes":"moralize",
"moralizing":"moralize",
"moralses":"morals",
"morasses":"morass",
"moratoria":"moratorium",
"moratoriums":"moratorium",
"morays":"moray",
"morbidities":"morbidity",
"morbidnesses":"morbidness",
"morbillis":"morbilli",
"morceaux":"morceau",
"morchellas":"morchella",
"morchellaceaes":"morchellaceae",
"mordanted":"mordant",
"mordanting":"mordant",
"mordvas":"mordva",
"mordvins":"mordvin",
"mordvinians":"mordvinian",
"morellos":"morello",
"morescoes":"moresco",
"morescos":"moresco",
"morgans":"morgan",
"morgues":"morgue",
"morions":"morion",
"moriscoes":"morisco",
"moriscos":"morisco",
"Mormons":"Mormon",
"mormonses":"mormons",
"morns":"morn",
"mornings":"morning",
"morning-glories":"morning-glory",
"moros":"moro",
"moroccos":"morocco",
"morons":"moron",
"morones":"morone",
"moronities":"moronity",
"morosenesses":"moroseness",
"morphallaxes":"morphallaxis",
"morphallaxlaxes":"morphallaxis",
"morphias":"morphia",
"morphines":"morphine",
"morphologies":"morphology",
"morphoses":"morphosis",
"morrigans":"morrigan",
"morrigus":"morrigu",
"morros":"morro",
"morses":"morse",
"morsels":"morsel",
"mortals":"mortal",
"mortalities":"mortality",
"mortared":"mortar",
"mortaring":"mortar",
"mortars":"mortar",
"mortgaged":"mortgage",
"mortgages":"mortgage",
"mortgaging":"mortgage",
"morticed":"mortice",
"mortices":"mortice",
"morticing":"mortice",
"morticians":"mortician",
"mortifications":"mortification",
"mortified":"mortify",
"mortifies":"mortify",
"mortifying":"mortify",
"mortised":"mortise",
"mortises":"mortise",
"mortising":"mortise",
"mortmains":"mortmain",
"mortuaries":"mortuary",
"morulae":"morula",
"morulas":"morula",
"moruses":"morus",
"mosaicked":"mosaic",
"mosaicking":"mosaic",
"mosaics":"mosaic",
"mosasaurs":"mosasaur",
"mosasauri":"mosasaurus",
"moschuses":"moschus",
"moscows":"moscow",
"moseyed":"mosey",
"moseying":"mosey",
"moseys":"mosey",
"moshavim":"moshav",
"moslems":"moslem",
"mosothos":"mosotho",
"mosques":"mosque",
"mosquitoes":"mosquito",
"mosquitos":"mosquito",
"mosquitofishes":"mosquitofish",
"mossed":"moss",
"mosses":"moss",
"mossing":"moss",
"mossbacks":"mossback",
"mossis":"mossi",
"mossier":"mossy",
"mossiest":"mossy",
"motacillas":"motacilla",
"motacillidaes":"motacillidae",
"motes":"mote",
"motels":"motel",
"moths":"moth",
"mothballed":"mothball",
"mothballing":"mothball",
"mothballs":"mothball",
"mothered":"mother",
"mothering":"mother",
"mothers":"mother",
"mothers-in-law":"mother-in-law",
"mother-of-pearls":"mother-of-pearl",
"mother-of-thousandses":"mother-of-thousands",
"motherfuckers":"motherfucker",
"motherhoods":"motherhood",
"motherlands":"motherland",
"motherlinesses":"motherliness",
"motherworts":"motherwort",
"mothers_superior":"mother_superior",
"mother_superiors":"mother_superior",
"mothproofed":"mothproof",
"mothproofing":"mothproof",
"mothier":"mothy",
"mothiest":"mothy",
"motifs":"motif",
"motives":"motive",
"motioned":"motion",
"motioning":"motion",
"motions":"motion",
"motionlessnesses":"motionlessness",
"motivated":"motivate",
"motivates":"motivate",
"motivating":"motivate",
"motivations":"motivation",
"motived":"motive",
"motiving":"motive",
"motivities":"motivity",
"motleys":"motley",
"motmots":"motmot",
"motored":"motor",
"motoring":"motor",
"motors":"motor",
"motorbikes":"motorbike",
"motorboats":"motorboat",
"motorbuses":"motorbus",
"motorbusses":"motorbus",
"motorcars":"motorcar",
"motorcoaches":"motorcoach",
"motorcycled":"motorcycle",
"motorcycles":"motorcycle",
"motorcycling":"motorcycle",
"motorcyclists":"motorcyclist",
"motorings":"motoring",
"motorisations":"motorisation",
"motorists":"motorist",
"motorizations":"motorization",
"motorized":"motorize",
"motorizes":"motorize",
"motorizing":"motorize",
"motormen":"motorman",
"motortrucks":"motortruck",
"motorways":"motorway",
"motowns":"motown",
"motrins":"motrin",
"mottled":"mottle",
"mottles":"mottle",
"mottling":"mottle",
"mottoes":"motto",
"mottos":"motto",
"motus":"motu",
"moues":"moue",
"moufflons":"moufflon",
"mouflons":"mouflon",
"moujiks":"moujik",
"moukdens":"moukden",
"moulds":"mould",
"mouldboards":"mouldboard",
"mouldings":"moulding",
"mouldier":"mouldy",
"mouldiest":"mouldy",
"moulted":"moult",
"moulting":"moult",
"moults":"moult",
"moultings":"moulting",
"mounded":"mound",
"mounding":"mound",
"mounds":"mound",
"moundbirds":"moundbird",
"mounted":"mount",
"mounting":"mount",
"mounts":"mount",
"mountains":"mountain",
"mountaineered":"mountaineer",
"mountaineering":"mountaineer",
"mountaineers":"mountaineer",
"mountaineerings":"mountaineering",
"mountebanks":"mountebank",
"mounties":"mountie",
"mountings":"mounting",
"mourned":"mourn",
"mourning":"mourn",
"mourners":"mourner",
"mournfulnesses":"mournfulness",
"mournings":"mourning",
"mice":"mouse",
"moused":"mouse",
"mousing":"mouse",
"mousetrapped":"mousetrap",
"mousetrapping":"mousetrap",
"mousetraps":"mousetrap",
"mousier":"mousy",
"mousiest":"mousy",
"mousses":"mousse",
"moustaches":"moustache",
"moustachios":"moustachio",
"mouthed":"mouth",
"mouthing":"mouth",
"mouths":"mouth",
"mouthfuls":"mouthful",
"mouthpieces":"mouthpiece",
"mouthwashes":"mouthwash",
"mouthier":"mouthy",
"mouthiest":"mouthy",
"moutons":"mouton",
"movabilities":"movability",
"movables":"movable",
"movablenesses":"movableness",
"moved":"move",
"moves":"move",
"moving":"move",
"moveables":"moveable",
"movements":"movement",
"movers":"mover",
"movies":"movie",
"moviegoers":"moviegoer",
"movings":"moving",
"mowed":"mow",
"mowing":"mow",
"mown":"mow",
"mows":"mow",
"mowers":"mower",
"mozambiques":"mozambique",
"mozarts":"mozart",
"mps":"mp",
"mphs":"mph",
"mrs":"mr",
"messrs.":"mr.",
"mrds":"mrd",
"mris":"mri",
"mrnas":"mrna",
"mmes.":"mrs.",
"mses":"ms",
"ms-doses":"ms-dos",
"mses.":"ms.",
"msasas":"msasa",
"msbs":"msb",
"msecs":"msec",
"msgs":"msg",
"mshes":"msh",
"msts":"mst",
"mts":"mt",
"mu-mesons":"mu-meson",
"muazzins":"muazzin",
"mucilages":"mucilage",
"mucked":"muck",
"mucking":"muck",
"mucks":"muck",
"muckheaps":"muckheap",
"muckhills":"muckhill",
"muckles":"muckle",
"muckraked":"muckrake",
"muckraking":"muckrake",
"muckrakers":"muckraker",
"muckrakings":"muckraking",
"muckier":"mucky",
"muckiest":"mucky",
"mucoraceaes":"mucoraceae",
"mucoraleses":"mucorales",
"mucosae":"mucosa",
"mucosas":"mucosa",
"mucovioscidoses":"mucovioscidosis",
"mucrones":"mucro",
"mucuses":"mucus",
"muds":"mud",
"mudcats":"mudcat",
"muddinesses":"muddiness",
"muddled":"muddle",
"muddles":"muddle",
"muddling":"muddle",
"muddlers":"muddler",
"muddied":"muddy",
"muddier":"muddy",
"muddies":"muddy",
"muddiest":"muddy",
"muddying":"muddy",
"mudejares":"mudejar",
"mudfishes":"mudfish",
"mudguards":"mudguard",
"mudras":"mudra",
"mudskippers":"mudskipper",
"mudslingers":"mudslinger",
"mudspringers":"mudspringer",
"muenchens":"muenchen",
"muezzins":"muezzin",
"muffed":"muff",
"muffing":"muff",
"muffs":"muff",
"muffins":"muffin",
"muffled":"muffle",
"muffles":"muffle",
"muffling":"muffle",
"mufflers":"muffler",
"muftis":"mufti",
"mugged":"mug",
"mugging":"mug",
"mugs":"mug",
"mugfuls":"mugful",
"muggers":"mugger",
"mugginses":"muggins",
"muggier":"muggy",
"muggiest":"muggy",
"mugils":"mugil",
"mugilidaes":"mugilidae",
"mugiloideas":"mugiloidea",
"mugwumps":"mugwump",
"muhammads":"muhammad",
"muhammadans":"muhammadan",
"muhammadanisms":"muhammadanism",
"muhammedans":"muhammedan",
"muhlenbergias":"muhlenbergia",
"mujiks":"mujik",
"mukdens":"mukden",
"mulattoes":"mulatto",
"mulattos":"mulatto",
"mulberries":"mulberry",
"mulched":"mulch",
"mulching":"mulch",
"mulcted":"mulct",
"mulcting":"mulct",
"mulcts":"mulct",
"mulctings":"mulcting",
"mules":"mule",
"muleses":"mules",
"muletas":"muleta",
"muleteers":"muleteer",
"mulishnesses":"mulishness",
"mulled":"mull",
"mulling":"mull",
"mulls":"mull",
"mullas":"mulla",
"mullahs":"mullah",
"mulleins":"mullein",
"mullets":"mullet",
"mullidaes":"mullidae",
"mulligans":"mulligan",
"mulloidichthyses":"mulloidichthys",
"mulloways":"mulloway",
"mulluses":"mullus",
"multifariousnesses":"multifariousness",
"multifloras":"multiflora",
"multimedias":"multimedia",
"multiparae":"multipara",
"multiparas":"multipara",
"multiples":"multiple",
"multiplexed":"multiplex",
"multiplexing":"multiplex",
"multiplications":"multiplication",
"multiplicities":"multiplicity",
"multipliers":"multiplier",
"multiplied":"multiply",
"multiplies":"multiply",
"multiplying":"multiply",
"multiprocessings":"multiprocessing",
"multiprogrammings":"multiprogramming",
"multitudes":"multitude",
"multiversities":"multiversity",
"mulwis":"mulwi",
"mums":"mum",
"mumbled":"mumble",
"mumbles":"mumble",
"mumbling":"mumble",
"mumblers":"mumbler",
"mumblings":"mumbling",
"mummers":"mummer",
"mummeries":"mummery",
"mummichogs":"mummichog",
"mummified":"mummify",
"mummifies":"mummify",
"mummifying":"mummify",
"mummies":"mummy",
"mumpses":"mumps",
"munched":"munch",
"munches":"munch",
"munching":"munch",
"munchings":"munching",
"mundas":"munda",
"munda-mon-khmers":"munda-mon-khmer",
"mungs":"mung",
"mungos":"mungo",
"muniches":"munich",
"municipalities":"municipality",
"municipalized":"municipalize",
"municipalizing":"municipalize",
"munificences":"munificence",
"munitioned":"munition",
"munitioning":"munition",
"munitions":"munition",
"munitionses":"munitions",
"munjs":"munj",
"munjas":"munja",
"munjeets":"munjeet",
"munjuks":"munjuk",
"muntiacuses":"muntiacus",
"muntingias":"muntingia",
"muntjacs":"muntjac",
"muons":"muon",
"muraenidaes":"muraenidae",
"murals":"mural",
"murdered":"murder",
"murdering":"murder",
"murders":"murder",
"murderers":"murderer",
"murderousnesses":"murderousness",
"murexes":"murex",
"murices":"murex",
"muridaes":"muridae",
"muritaniyas":"muritaniya",
"murks":"murk",
"murkinesses":"murkiness",
"murkier":"murky",
"murkiest":"murky",
"murmured":"murmur",
"murmuring":"murmur",
"murmurs":"murmur",
"murmurations":"murmuration",
"murmurings":"murmuring",
"muroideas":"muroidea",
"murphies":"murphy",
"murrays":"murray",
"muses":"muse",
"musas":"musa",
"musaceaes":"musaceae",
"musaleses":"musales",
"muscas":"musca",
"muscadels":"muscadel",
"muscadelles":"muscadelle",
"muscadines":"muscadine",
"muscardinuses":"muscardinus",
"muscaris":"muscari",
"muscats":"muscat",
"muscatels":"muscatel",
"muscis":"musci",
"muscicapas":"muscicapa",
"muscicapidaes":"muscicapidae",
"muscidaes":"muscidae",
"muscivoras":"muscivora",
"muscivora-forficatas":"muscivora-forficata",
"muscled":"muscle",
"muscles":"muscle",
"muscling":"muscle",
"musclebuilders":"musclebuilder",
"musclebuildings":"musclebuilding",
"musclemen":"muscleman",
"muscoideas":"muscoidea",
"musculatures":"musculature",
"musculuses":"musculus",
"musds":"musd",
"mused":"muse",
"musing":"muse",
"musettes":"musette",
"museums":"museum",
"musgois":"musgoi",
"musgus":"musgu",
"mushed":"mush",
"mushes":"mush",
"mushing":"mush",
"mushinesses":"mushiness",
"mushroomed":"mushroom",
"mushrooming":"mushroom",
"mushrooms":"mushroom",
"mushier":"mushy",
"mushiest":"mushy",
"musics":"music",
"musicals":"musical",
"musicalities":"musicality",
"musicalized":"musicalize",
"musicalizing":"musicalize",
"musicalnesses":"musicalness",
"musicians":"musician",
"musings":"musing",
"musjids":"musjid",
"musks":"musk",
"muskats":"muskat",
"muskellunges":"muskellunge",
"muskets":"musket",
"muskhogeans":"muskhogean",
"muskmelons":"muskmelon",
"muskogeans":"muskogean",
"muskrats":"muskrat",
"muskwoods":"muskwood",
"muskier":"musky",
"muskies":"musky",
"muskiest":"musky",
"muslims":"muslim",
"muslimisms":"muslimism",
"musophagas":"musophaga",
"musophagidaes":"musophagidae",
"musquashes":"musquash",
"mussed":"muss",
"musses":"muss",
"mussing":"muss",
"mussalmans":"mussalman",
"mussels":"mussel",
"mussinesses":"mussiness",
"mussolinis":"mussolini",
"mussulmans":"mussulman",
"mussier":"mussy",
"mussiest":"mussy",
"mustaches":"mustache",
"mustachios":"mustachio",
"mustaghs":"mustagh",
"mustards":"mustard",
"mustelas":"mustela",
"mustelids":"mustelid",
"mustelidaes":"mustelidae",
"mustelines":"musteline",
"musteluses":"mustelus",
"mustered":"muster",
"mustering":"muster",
"musters":"muster",
"mustinesses":"mustiness",
"mustier":"musty",
"mustiest":"musty",
"muts":"mut",
"mutabilities":"mutability",
"mutablenesses":"mutableness",
"mutants":"mutant",
"mutated":"mutate",
"mutating":"mutate",
"mutations":"mutation",
"muted":"mute",
"muter":"mute",
"mutes":"mute",
"mutest":"mute",
"muting":"mute",
"mutenesses":"muteness",
"mutilated":"mutilate",
"mutilates":"mutilate",
"mutilating":"mutilate",
"mutilations":"mutilation",
"mutineers":"mutineer",
"mutinuses":"mutinus",
"mutinied":"mutiny",
"mutinies":"mutiny",
"mutinying":"mutiny",
"mutts":"mutt",
"muttered":"mutter",
"muttering":"mutter",
"mutters":"mutter",
"mutterers":"mutterer",
"mutterings":"muttering",
"muttons":"mutton",
"muttonfishes":"muttonfish",
"muttonheads":"muttonhead",
"mutualities":"mutuality",
"mutualnesses":"mutualness",
"muumuus":"muumuu",
"muzhiks":"muzhik",
"muzjiks":"muzjik",
"muzzled":"muzzle",
"muzzles":"muzzle",
"muzzling":"muzzle",
"muzzier":"muzzy",
"muzziest":"muzzy",
"mvs":"mv",
"MVPs":"MVP",
"mxes":"mx",
"myas":"mya",
"myaceaes":"myaceae",
"myacidaes":"myacidae",
"myadesteses":"myadestes",
"myalgias":"myalgia",
"myanmars":"myanmar",
"mycelia":"mycelium",
"mycelilia":"mycelium",
"mycetomas":"mycetoma",
"mycetomata":"mycetoma",
"mycetophilidaes":"mycetophilidae",
"mycobacterias":"mycobacteria",
"mycobacteriacaeas":"mycobacteriacaea",
"mycobacteriums":"mycobacterium",
"mycoplasmas":"mycoplasma",
"mycoplasmata":"mycoplasma",
"mycoplasmatacaeas":"mycoplasmatacaea",
"mycoplasmataleses":"mycoplasmatales",
"mycorhizas":"mycorhiza",
"mycorrhizae":"mycorrhiza",
"mycorrhizas":"mycorrhiza",
"mycoses":"mycosis",
"mycostatins":"mycostatin",
"mycrosporidias":"mycrosporidia",
"mycteropercas":"mycteroperca",
"myctophidaes":"myctophidae",
"myelencephala":"myelencephalon",
"myelencephalons":"myelencephalon",
"mylencephala":"myelencephalon",
"myelins":"myelin",
"myelines":"myeline",
"myelomas":"myeloma",
"myelomata":"myeloma",
"mygs":"myg",
"myiases":"myiasis",
"mylars":"mylar",
"myliobatidaes":"myliobatidae",
"mylittas":"mylitta",
"mylodontidaes":"mylodontidae",
"myms":"mym",
"mynas":"myna",
"mynahs":"mynah",
"myocarditises":"myocarditis",
"myocardia":"myocardium",
"myocastors":"myocastor",
"myodynias":"myodynia",
"myofibrils":"myofibril",
"myofibrillas":"myofibrilla",
"myomas":"myoma",
"myomata":"myoma",
"myomorphas":"myomorpha",
"myopathies":"myopathy",
"myopias":"myopia",
"myopuses":"myopus",
"myoses":"myosis",
"myosotises":"myosotis",
"myotises":"myotis",
"myrcias":"myrcia",
"myrciarias":"myrciaria",
"myriads":"myriad",
"myriagrams":"myriagram",
"myriameters":"myriameter",
"myriametres":"myriametre",
"myriapodas":"myriapoda",
"myricas":"myrica",
"myricaceaes":"myricaceae",
"myricaleses":"myricales",
"myricarias":"myricaria",
"myriophyllums":"myriophyllum",
"myristicas":"myristica",
"myristicaceaes":"myristicaceae",
"myrmecias":"myrmecia",
"myrmecobiuses":"myrmecobius",
"myrmecophagas":"myrmecophaga",
"myrmecophagidaes":"myrmecophagidae",
"myrmeleons":"myrmeleon",
"myrmeleontidaes":"myrmeleontidae",
"myrmidones":"myrmidon",
"myrmidons":"myrmidon",
"myrobalans":"myrobalan",
"myroxylons":"myroxylon",
"myrrhs":"myrrh",
"myrrhises":"myrrhis",
"myrsinaceaes":"myrsinaceae",
"myrsines":"myrsine",
"myrtaceaes":"myrtaceae",
"myrtaleses":"myrtales",
"myrtillocactuses":"myrtillocactus",
"myrtles":"myrtle",
"myrtuses":"myrtus",
"mysidaceas":"mysidacea",
"mysidaes":"mysidae",
"myses":"mysis",
"mysteries":"mystery",
"mystics":"mystic",
"mysticetis":"mysticeti",
"mysticisms":"mysticism",
"mystifications":"mystification",
"mystified":"mystify",
"mystifies":"mystify",
"mystifying":"mystify",
"myths":"myth",
"mythicized":"mythicize",
"mythicizing":"mythicize",
"mythographies":"mythography",
"mythologisations":"mythologisation",
"mythologizations":"mythologization",
"mythologized":"mythologize",
"mythologizing":"mythologize",
"mythologies":"mythology",
"mythoi":"mythos",
"mytilids":"mytilid",
"mytilidaes":"mytilidae",
"mytiluses":"mytilus",
"myxines":"myxine",
"myxinidaes":"myxinidae",
"myxiniformeses":"myxiniformes",
"myxinikelas":"myxinikela",
"myxinoideas":"myxinoidea",
"myxinoideis":"myxinoidei",
"myxobacters":"myxobacter",
"myxobacteraleses":"myxobacterales",
"myxobacterias":"myxobacteria",
"myxobacteriaceaes":"myxobacteriaceae",
"myxobacterialeses":"myxobacteriales",
"myxobacteriums":"myxobacterium",
"myxocephaluses":"myxocephalus",
"myxomas":"myxoma",
"myxomata":"myxoma",
"myxomycetes":"myxomycete",
"myxomyceteses":"myxomycetes",
"myxomycotas":"myxomycota",
"myxophyceaes":"myxophyceae",
"myxosporidias":"myxosporidia",
"myxoviruses":"myxovirus",
"ns":"n",
"nas":"na",
"nabbed":"nab",
"nabbing":"nab",
"nabs":"nab",
"nabaluses":"nabalus",
"nabes":"nabe",
"nabooms":"naboom",
"nabus":"nabu",
"nabumetones":"nabumetone",
"nacres":"nacre",
"nads":"nad",
"nadas":"nada",
"nadirs":"nadir",
"nadolols":"nadolol",
"naemorheduses":"naemorhedus",
"naevi":"naevus",
"nagged":"nag",
"nagging":"nag",
"nags":"nag",
"nagas":"naga",
"nagamis":"nagami",
"nagaris":"nagari",
"nageias":"nageia",
"naggers":"nagger",
"nagis":"nagi",
"nahuatls":"nahuatl",
"naiades":"naiad",
"naiads":"naiad",
"naiadaceaes":"naiadaceae",
"naiadaleses":"naiadales",
"naiases":"naias",
"nailed":"nail",
"nailing":"nail",
"nails":"nail",
"nailrods":"nailrod",
"nairobis":"nairobi",
"naiver":"naive",
"naivest":"naive",
"naivenesses":"naiveness",
"naivetes":"naivete",
"naiveties":"naivety",
"najas":"naja",
"najadaceaes":"najadaceae",
"najases":"najas",
"nakednesses":"nakedness",
"nakedwoods":"nakedwood",
"nalfons":"nalfon",
"namas":"nama",
"namaquas":"namaqua",
"namby-pambies":"namby-pamby",
"named":"name",
"names":"name",
"naming":"name",
"namekos":"nameko",
"namelessnesses":"namelessness",
"nameses":"names",
"namesakes":"namesake",
"namings":"naming",
"nammads":"nammad",
"namtars":"namtar",
"namtarus":"namtaru",
"nandrolones":"nandrolone",
"nandus":"nandu",
"nanisms":"nanism",
"nanjings":"nanjing",
"nankings":"nanking",
"nannies":"nanny",
"nanny-goats":"nanny-goat",
"nanocephalies":"nanocephaly",
"nanometers":"nanometer",
"nanometres":"nanometre",
"nantuas":"nantua",
"naomis":"naomi",
"naoi":"naos",
"napped":"nap",
"napping":"nap",
"naps":"nap",
"napas":"napa",
"napaeas":"napaea",
"napes":"nape",
"napeas":"napea",
"naperies":"napery",
"naphthalized":"naphthalize",
"naphthalizing":"naphthalize",
"naphthoquinones":"naphthoquinone",
"napiers":"napier",
"napkins":"napkin",
"napoleons":"napoleon",
"nappier":"nappy",
"nappies":"nappy",
"nappiest":"nappy",
"naprosyns":"naprosyn",
"naproxens":"naproxen",
"napus":"napu",
"naranjillas":"naranjilla",
"narcs":"narc",
"narcisms":"narcism",
"narcissisms":"narcissism",
"narcissists":"narcissist",
"narciscissi":"narcissus",
"narciscissuses":"narcissus",
"narcissi":"narcissus",
"narcissuses":"narcissus",
"narcists":"narcist",
"narcomas":"narcoma",
"narcomata":"narcoma",
"narcotics":"narcotic",
"narcotized":"narcotize",
"narcotizing":"narcotize",
"nards":"nard",
"nardos":"nardo",
"nardoos":"nardoo",
"narghiles":"narghile",
"narks":"nark",
"narragansets":"narraganset",
"narragansetts":"narragansett",
"narrated":"narrate",
"narrates":"narrate",
"narrating":"narrate",
"narrations":"narration",
"narratives":"narrative",
"narrators":"narrator",
"narrowed":"narrow",
"narrower":"narrow",
"narrowest":"narrow",
"narrowing":"narrow",
"narrows":"narrow",
"nartheciums":"narthecium",
"narwals":"narwal",
"narwhals":"narwhal",
"narwhales":"narwhale",
"nasas":"nasa",
"nasals":"nasal",
"nasalises":"nasalise",
"nasalized":"nasalize",
"nasalizes":"nasalize",
"nasalizing":"nasalize",
"nascences":"nascence",
"nascencies":"nascency",
"naseberries":"naseberry",
"nasebies":"naseby",
"nashvilles":"nashville",
"nasopharynges":"nasopharynx",
"nasopharynxes":"nasopharynx",
"nassaus":"nassau",
"nassers":"nasser",
"nasts":"nast",
"nastinesses":"nastiness",
"nasturtiums":"nasturtium",
"nastier":"nasty",
"nasties":"nasty",
"nastiest":"nasty",
"nasuas":"nasua",
"natalities":"natality",
"natantias":"natantia",
"natators":"natator",
"natatoria":"natatorium",
"natatoriums":"natatorium",
"naticidaes":"naticidae",
"nations":"nation",
"nationals":"national",
"nationalisations":"nationalisation",
"nationalisms":"nationalism",
"nationalists":"nationalist",
"nationalities":"nationality",
"nationalizations":"nationalization",
"nationalized":"nationalize",
"nationalizing":"nationalize",
"natives":"native",
"nativities":"nativity",
"natos":"nato",
"natrixes":"natrix",
"nattered":"natter",
"nattering":"natter",
"natters":"natter",
"natterjacks":"natterjack",
"nattinesses":"nattiness",
"nattier":"natty",
"nattiest":"natty",
"naturals":"natural",
"naturalisations":"naturalisation",
"naturalisms":"naturalism",
"naturalists":"naturalist",
"naturalizations":"naturalization",
"naturalized":"naturalize",
"naturalizes":"naturalize",
"naturalizing":"naturalize",
"naturalnesses":"naturalness",
"natures":"nature",
"naturisms":"naturism",
"naturists":"naturist",
"nauches":"nauch",
"naucleas":"nauclea",
"naucrateses":"naucrates",
"naughts":"naught",
"naughtinesses":"naughtiness",
"naughtier":"naughty",
"naughtiest":"naughty",
"naumachiae":"naumachia",
"naumachias":"naumachia",
"naumachies":"naumachy",
"naupathias":"naupathia",
"nauplii":"nauplius",
"nauseas":"nausea",
"nauseants":"nauseant",
"nauseated":"nauseate",
"nauseates":"nauseate",
"nauseating":"nauseate",
"nauseatingnesses":"nauseatingness",
"nautches":"nautch",
"nautilidaes":"nautilidae",
"nautili":"nautilus",
"nautiluses":"nautilus",
"navahoes":"navaho",
"navahos":"navaho",
"navajoes":"navajo",
"navajos":"navajo",
"navarinos":"navarino",
"naves":"nave",
"navels":"navel",
"naviculars":"navicular",
"navigated":"navigate",
"navigates":"navigate",
"navigating":"navigate",
"navigations":"navigation",
"navigators":"navigator",
"navvies":"navvy",
"navies":"navy",
"nays":"nay",
"naysaid":"naysay",
"naysaying":"naysay",
"Nazis":"Nazi",
"naziisms":"naziism",
"nazisms":"nazism",
"nbs":"nb",
"nbes":"nbe",
"nbws":"nbw",
"nds":"nd",
"ndebeles":"ndebele",
"ndjamenas":"ndjamena",
"nes":"ne",
"neanderthals":"neanderthal",
"neaps":"neap",
"nearer":"near",
"nearest":"near",
"nears":"near",
"nearnesses":"nearness",
"nearsightednesses":"nearsightedness",
"neater":"neat",
"neatest":"neat",
"neatened":"neaten",
"neatening":"neaten",
"neatens":"neaten",
"neatnesses":"neatness",
"nebs":"neb",
"nebes":"nebe",
"nebns":"nebn",
"nebos":"nebo",
"nebraskas":"nebraska",
"nebraskans":"nebraskan",
"nebulae":"nebula",
"nebulas":"nebula",
"nebulized":"nebulize",
"nebulizing":"nebulize",
"nebulosities":"nebulosity",
"necessaries":"necessary",
"necessitated":"necessitate",
"necessitates":"necessitate",
"necessitating":"necessitate",
"necessities":"necessity",
"necked":"neck",
"necking":"neck",
"necks":"neck",
"neck-reined":"neck-rein",
"neck-reining":"neck-rein",
"neckars":"neckar",
"neckbands":"neckband",
"neckcloths":"neckcloth",
"neckings":"necking",
"necklaces":"necklace",
"neckties":"necktie",
"necrologies":"necrology",
"necromancers":"necromancer",
"necromanias":"necromania",
"necrophagias":"necrophagia",
"necrophagies":"necrophagy",
"necrophilias":"necrophilia",
"necrophilisms":"necrophilism",
"necropoleis":"necropolis",
"necropoli":"necropolis",
"necropolises":"necropolis",
"necropsies":"necropsy",
"necroscopies":"necroscopy",
"necrosed":"necrose",
"necroses":"necrose",
"necrosing":"necrose",
"necrotomies":"necrotomy",
"nectars":"nectar",
"nectarines":"nectarine",
"nectaries":"nectary",
"necturuses":"necturus",
"neddies":"neddy",
"needed":"need",
"needing":"need",
"needs":"need",
"needled":"needle",
"needles":"needle",
"needling":"needle",
"needlebushes":"needlebush",
"needlecrafts":"needlecraft",
"needlefishes":"needlefish",
"needlepoints":"needlepoint",
"needlewomen":"needlewoman",
"needlewoods":"needlewood",
"needleworks":"needlework",
"needier":"needy",
"neediest":"needy",
"neems":"neem",
"neencephalons":"neencephalon",
"nefariousnesses":"nefariousness",
"negaprions":"negaprion",
"negated":"negate",
"negates":"negate",
"negating":"negate",
"negatings":"negating",
"negations":"negation",
"negatived":"negative",
"negatives":"negative",
"negativing":"negative",
"negativisms":"negativism",
"negativists":"negativist",
"negativities":"negativity",
"negevs":"negev",
"neglected":"neglect",
"neglecting":"neglect",
"neglects":"neglect",
"neglectfulnesses":"neglectfulness",
"negliges":"neglige",
"negligees":"negligee",
"negligences":"negligence",
"negotiants":"negotiant",
"negotiated":"negotiate",
"negotiates":"negotiate",
"negotiating":"negotiate",
"negotiations":"negotiation",
"negotiators":"negotiator",
"negotiatresses":"negotiatress",
"negotiatrixes":"negotiatrix",
"negrilloes":"negrillo",
"negrillos":"negrillo",
"negritoes":"negrito",
"negritos":"negrito",
"Negroes":"Negro",
"negroids":"negroid",
"neguses":"negus",
"nehrus":"nehru",
"neighed":"neigh",
"neighing":"neigh",
"neighs":"neigh",
"neighbored":"neighbor",
"neighboring":"neighbor",
"neighbors":"neighbor",
"neighborhoods":"neighborhood",
"neighborlinesses":"neighborliness",
"neighboured":"neighbour",
"neighbouring":"neighbour",
"neighbours":"neighbour",
"neighbourhoods":"neighbourhood",
"neighbourlinesses":"neighbourliness",
"nelumbos":"nelumbo",
"nelumbonaceaes":"nelumbonaceae",
"nematoceras":"nematocera",
"nematodas":"nematoda",
"nematodes":"nematode",
"nembutals":"nembutal",
"nemerteas":"nemertea",
"nemerteans":"nemertean",
"nemertinas":"nemertina",
"nemertines":"nemertine",
"nemeses":"nemesis",
"nenetses":"nenets",
"nentsis":"nentsi",
"nentsies":"nentsy",
"neo-latins":"neo-latin",
"neo-nazis":"neo-nazi",
"neoceratoduses":"neoceratodus",
"neocortexes":"neocortex",
"neodymiums":"neodymium",
"neoencephalons":"neoencephalon",
"neofibers":"neofiber",
"neohygrophoruses":"neohygrophorus",
"neolentinuses":"neolentinus",
"neologisms":"neologism",
"neologized":"neologize",
"neologizing":"neologize",
"neologies":"neology",
"neomycins":"neomycin",
"neomyses":"neomys",
"neons":"neon",
"neonates":"neonate",
"neopalliums":"neopallium",
"neophrons":"neophron",
"neophytes":"neophyte",
"neoplasms":"neoplasm",
"neoshos":"neosho",
"neotomas":"neotoma",
"nepas":"nepa",
"nepaleses":"nepalese",
"nepalis":"nepali",
"nepenthaceaes":"nepenthaceae",
"nepentheses":"nepenthes",
"nepetas":"nepeta",
"nepheliums":"nephelium",
"nephews":"nephew",
"nephrectomies":"nephrectomy",
"nephridia":"nephridium",
"nephridiia":"nephridium",
"nephritises":"nephritis",
"nephrolepises":"nephrolepis",
"nephroliths":"nephrolith",
"nephrons":"nephron",
"nephropses":"nephrops",
"nephropsidaes":"nephropsidae",
"nephrotomies":"nephrotomy",
"nepidaes":"nepidae",
"neptuniums":"neptunium",
"nerds":"nerd",
"nereids":"nereid",
"neritids":"neritid",
"neritidaes":"neritidae",
"neriums":"nerium",
"nerodias":"nerodia",
"nerthuses":"nerthus",
"nerved":"nerve",
"nerves":"nerve",
"nerving":"nerve",
"nervelessnesses":"nervelessness",
"nerveroots":"nerveroot",
"nerveses":"nerves",
"nervousnesses":"nervousness",
"nervures":"nervure",
"nervuses":"nervus",
"nervier":"nervy",
"nerviest":"nervy",
"nesciences":"nescience",
"nesokias":"nesokia",
"nesses":"ness",
"nessies":"nessie",
"nested":"nest",
"nesting":"nest",
"nests":"nest",
"nesters":"nester",
"nestled":"nestle",
"nestles":"nestle",
"nestling":"nestle",
"nestlings":"nestling",
"nestors":"nestor",
"nets":"net",
"netted":"net",
"netting":"net",
"netherlanders":"netherlander",
"netherlandses":"netherlands",
"netherworlds":"netherworld",
"netkeepers":"netkeeper",
"netsukes":"netsuke",
"nettings":"netting",
"nettled":"nettle",
"nettles":"nettle",
"nettling":"nettle",
"netties":"netty",
"networked":"network",
"networking":"network",
"networks":"network",
"neuralgias":"neuralgia",
"neuralgies":"neuralgy",
"neurectomies":"neurectomy",
"neurilemmas":"neurilemma",
"neuroanatomies":"neuroanatomy",
"neurofibromas":"neurofibroma",
"neurofibromata":"neurofibroma",
"neuroglias":"neuroglia",
"neurogliacytes":"neurogliacyte",
"neurohypophyses":"neurohypophysis",
"neurologists":"neurologist",
"neurologies":"neurology",
"neuromas":"neuroma",
"neuromata":"neuroma",
"neurons":"neuron",
"neuropsychologies":"neuropsychology",
"neuropteras":"neuroptera",
"neuropterans":"neuropteran",
"neuropterons":"neuropteron",
"neurosarcomas":"neurosarcoma",
"neuroses":"neurosis",
"neurosporas":"neurospora",
"neurosurgeons":"neurosurgeon",
"neurotics":"neurotic",
"neuroticisms":"neuroticism",
"neurotomies":"neurotomy",
"neurotrichuses":"neurotrichus",
"neurulae":"neurula",
"neurulas":"neurula",
"neuterings":"neutering",
"neutrals":"neutral",
"neutralisations":"neutralisation",
"neutralities":"neutrality",
"neutralizations":"neutralization",
"neutralized":"neutralize",
"neutralizes":"neutralize",
"neutralizing":"neutralize",
"neutrettos":"neutretto",
"neutrinos":"neutrino",
"nevadas":"nevada",
"neves":"neve",
"nevi":"nevus",
"nevuses":"nevus",
"newer":"new",
"newest":"new",
"newborns":"newborn",
"newcastles":"newcastle",
"newcastle-upon-tynes":"newcastle-upon-tyne",
"newcomers":"newcomer",
"newels":"newel",
"newlyweds":"newlywed",
"newmarkets":"newmarket",
"newses":"news",
"newsagents":"newsagent",
"newsboys":"newsboy",
"newsdealers":"newsdealer",
"newsflashes":"newsflash",
"newsletters":"newsletter",
"newsmen":"newsman",
"newsmongers":"newsmonger",
"newspapered":"newspaper",
"newspapering":"newspaper",
"newspapers":"newspaper",
"newspapermen":"newspaperman",
"newspaperwomen":"newspaperwoman",
"newspersons":"newsperson",
"newsprints":"newsprint",
"newssheets":"newssheet",
"newsvendors":"newsvendor",
"newsworthinesses":"newsworthiness",
"newswriters":"newswriter",
"newsier":"newsy",
"newsies":"newsy",
"newsiest":"newsy",
"newts":"newt",
"newtons":"newton",
"nexuses":"nexus",
"nis":"ni",
"ni-hards":"ni-hard",
"ni-resists":"ni-resist",
"niacins":"niacin",
"niagaras":"niagara",
"niameys":"niamey",
"nibs":"nib",
"nibbled":"nibble",
"nibbles":"nibble",
"nibbling":"nibble",
"nibblings":"nibbling",
"nibelungen":"nibelung",
"nibelungs":"nibelung",
"niblicks":"niblick",
"nicads":"nicad",
"nicandras":"nicandra",
"nicer":"nice",
"nicest":"nice",
"nicenesses":"niceness",
"niceties":"nicety",
"niched":"niche",
"niches":"niche",
"niching":"niche",
"nicked":"nick",
"nicking":"nick",
"nicks":"nick",
"nickeled":"nickel",
"nickeling":"nickel",
"nickelled":"nickel",
"nickelling":"nickel",
"nickels":"nickel",
"nickelodeons":"nickelodeon",
"nickered":"nicker",
"nickering":"nicker",
"nickers":"nicker",
"nicknacks":"nicknack",
"nicknamed":"nickname",
"nicknames":"nickname",
"nicknaming":"nickname",
"nicosias":"nicosia",
"nicotianas":"nicotiana",
"nictitated":"nictitate",
"nictitates":"nictitate",
"nictitating":"nictitate",
"nid-nodded":"nid-nod",
"nid-nodding":"nid-nod",
"nid-nods":"nid-nod",
"nidaroses":"nidaros",
"nidified":"nidify",
"nidifies":"nidify",
"nidifying":"nidify",
"nidularias":"nidularia",
"nidulariaceaes":"nidulariaceae",
"nidularialeses":"nidulariales",
"nidi":"nidus",
"niduses":"nidus",
"nieces":"niece",
"nielli":"niello",
"nielloed":"niello",
"nielloing":"niello",
"niellos":"niello",
"nierembergias":"nierembergia",
"niftier":"nifty",
"nifties":"nifty",
"niftiest":"nifty",
"nigers":"niger",
"niger-kordofanians":"niger-kordofanian",
"niggards":"niggard",
"niggardlinesses":"niggardliness",
"niggardnesses":"niggardness",
"niggers":"nigger",
"niggled":"niggle",
"niggles":"niggle",
"niggling":"niggle",
"nigher":"nigh",
"nighest":"nigh",
"nights":"night",
"night-robes":"night-robe",
"night-sights":"night-sight",
"nightbirds":"nightbird",
"nightcaps":"nightcap",
"nightclotheses":"nightclothes",
"nightclubbed":"nightclub",
"nightclubbing":"nightclub",
"nightclubs":"nightclub",
"nightcrawlers":"nightcrawler",
"nightdresses":"nightdress",
"nightfalls":"nightfall",
"nightgowns":"nightgown",
"nighthawks":"nighthawk",
"nighties":"nightie",
"nightingales":"nightingale",
"nightjars":"nightjar",
"nightmares":"nightmare",
"nightriders":"nightrider",
"nightsticks":"nightstick",
"nighttimes":"nighttime",
"nightwalkers":"nightwalker",
"nightwears":"nightwear",
"nigras":"nigra",
"nigrified":"nigrify",
"nigrifies":"nigrify",
"nigrifying":"nigrify",
"nigroporuses":"nigroporus",
"nihaus":"nihau",
"nihils":"nihil",
"nihilists":"nihilist",
"nihons":"nihon",
"nils":"nil",
"niles":"nile",
"nilgais":"nilgai",
"ghaus":"nilghau",
"nilghaus":"nilghau",
"nilled":"nill",
"nilling":"nill",
"nilo-saharans":"nilo-saharan",
"nilotics":"nilotic",
"nimmed":"nim",
"nimming":"nim",
"nimbler":"nimble",
"nimblest":"nimble",
"nimblenesses":"nimbleness",
"nimblewills":"nimblewill",
"nimbostrati":"nimbostratus",
"nimbi":"nimbus",
"nimbuses":"nimbus",
"nimieties":"nimiety",
"nimravuses":"nimravus",
"nin-sins":"nin-sin",
"nincompoops":"nincompoop",
"nines":"nine",
"ninepins":"ninepin",
"ninepinses":"ninepins",
"niners":"niner",
"nineteens":"nineteen",
"nineteenths":"nineteenth",
"ninetieses":"nineties",
"nineties":"ninety",
"ninhursags":"ninhursag",
"ninibs":"ninib",
"ninigis":"ninigi",
"ninigino-mikotos":"ninigino-mikoto",
"ninkharsags":"ninkharsag",
"ninkhursags":"ninkhursag",
"ninnies":"ninny",
"ninths":"ninth",
"nintoos":"nintoo",
"nintus":"nintu",
"ninurtas":"ninurta",
"niobites":"niobite",
"niobiums":"niobium",
"niobraras":"niobrara",
"nipped":"nip",
"nipping":"nip",
"nips":"nip",
"nipas":"nipa",
"nippers":"nipper",
"nipples":"nipple",
"nippons":"nippon",
"nipponeses":"nipponese",
"nippier":"nippy",
"nippiest":"nippy",
"nirvanas":"nirvana",
"nisans":"nisan",
"nissans":"nissan",
"nisuses":"nisus",
"nit-picked":"nit-pick",
"nit-picking":"nit-pick",
"nitellas":"nitella",
"niters":"niter",
"nitrated":"nitrate",
"nitrates":"nitrate",
"nitrating":"nitrate",
"nitres":"nitre",
"nitrified":"nitrify",
"nitrifies":"nitrify",
"nitrifying":"nitrify",
"nitriles":"nitrile",
"nitrobacters":"nitrobacter",
"nitrobacterias":"nitrobacteria",
"nitrobacteriaceaes":"nitrobacteriaceae",
"nitrocelluloses":"nitrocellulose",
"nitrocottons":"nitrocotton",
"nitrofurantoins":"nitrofurantoin",
"nitrogens":"nitrogen",
"nitroglycerins":"nitroglycerin",
"nitroglycerines":"nitroglycerine",
"nitrosobacterias":"nitrosobacteria",
"nitrosomonases":"nitrosomonas",
"nitrospans":"nitrospan",
"nitrostats":"nitrostat",
"nittier":"nitty",
"nittiest":"nitty",
"nitty-gritties":"nitty-gritty",
"nitweeds":"nitweed",
"nitwits":"nitwit",
"nixes":"nix",
"nixons":"nixon",
"njords":"njord",
"njorths":"njorth",
"nnes":"nne",
"nnws":"nnw",
"noes":"no",
"no-hitters":"no-hitter",
"no-nos":"no-no",
"no-see-ums":"no-see-um",
"no-shows":"no-show",
"nos":"no.",
"nobs":"nob",
"nobbled":"nobble",
"nobbles":"nobble",
"nobbling":"nobble",
"nobbier":"nobby",
"nobbiest":"nobby",
"nobelists":"nobelist",
"nobeliums":"nobelium",
"nobilities":"nobility",
"nobler":"noble",
"nobles":"noble",
"noblest":"noble",
"noble-mindednesses":"noble-mindedness",
"noblemen":"nobleman",
"noblesses":"noblesse",
"noblewomen":"noblewoman",
"nobodies":"nobody",
"nocked":"nock",
"nocking":"nock",
"nocks":"nock",
"noctambulisms":"noctambulism",
"noctambulists":"noctambulist",
"noctilucas":"noctiluca",
"noctuas":"noctua",
"noctuids":"noctuid",
"noctuidaes":"noctuidae",
"nodded":"nod",
"nodding":"nod",
"nods":"nod",
"noddies":"noddy",
"nodes":"node",
"nodules":"nodule",
"nodi":"nodus",
"noels":"noel",
"noemis":"noemi",
"nogs":"nog",
"noggins":"noggin",
"noised":"noise",
"noises":"noise",
"noising":"noise",
"noisettes":"noisette",
"noisinesses":"noisiness",
"noisomenesses":"noisomeness",
"noisier":"noisy",
"noisiest":"noisy",
"nolinas":"nolina",
"nomas":"noma",
"nomads":"nomad",
"nomarchies":"nomarchy",
"nomina":"nomen",
"nomenclatures":"nomenclature",
"nomias":"nomia",
"nominals":"nominal",
"nominalized":"nominalize",
"nominalizing":"nominalize",
"nominated":"nominate",
"nominates":"nominate",
"nominating":"nominate",
"nominatings":"nominating",
"nominations":"nomination",
"nominatives":"nominative",
"nominees":"nominee",
"nomocracries":"nomocracy",
"nomograms":"nomogram",
"nomographs":"nomograph",
"nomographies":"nomography",
"non-engagements":"non-engagement",
"non-involvements":"non-involvement",
"non-issues":"non-issue",
"non-jews":"non-jew",
"non-prossed":"non-pros",
"non-prosses":"non-pros",
"non-prossing":"non-pros",
"non-resistants":"non-resistant",
"non-ugrics":"non-ugric",
"nonacceptances":"nonacceptance",
"nonaccomplishments":"nonaccomplishment",
"nonachievements":"nonachievement",
"nonages":"nonage",
"nonalignments":"nonalignment",
"nonalinements":"nonalinement",
"nonaries":"nonary",
"nonattenders":"nonattender",
"nonbelieivers":"nonbelieiver",
"nonces":"nonce",
"nonchalances":"nonchalance",
"noncitizens":"noncitizen",
"noncoms":"noncom",
"noncompliances":"noncompliance",
"nonconductors":"nonconductor",
"nonconformances":"nonconformance",
"nonconformists":"nonconformist",
"nonconformities":"nonconformity",
"nondescripts":"nondescript",
"nonentities":"nonentity",
"nonessentials":"nonessential",
"nonesuches":"nonesuch",
"nonfictions":"nonfiction",
"nonindulgences":"nonindulgence",
"noninterferences":"noninterference",
"noninterventions":"nonintervention",
"nonpareils":"nonpareil",
"nonparticipations":"nonparticipation",
"nonpartisanships":"nonpartisanship",
"nonpayments":"nonpayment",
"nonperformances":"nonperformance",
"nonplused":"nonplus",
"nonpluses":"nonplus",
"nonplusing":"nonplus",
"nonplussed":"nonplus",
"nonplusses":"nonplus",
"nonplussing":"nonplus",
"nonprossed":"nonpros",
"nonprossing":"nonpros",
"nonremittals":"nonremittal",
"nonsenses":"nonsense",
"nonsensicalities":"nonsensicality",
"nonsmokers":"nonsmoker",
"nonstarters":"nonstarter",
"nonstops":"nonstop",
"nonsuches":"nonsuch",
"nonsuited":"nonsuit",
"nonsuiting":"nonsuit",
"nonviolences":"nonviolence",
"noodles":"noodle",
"nooks":"nook",
"nookies":"nooky",
"noons":"noon",
"noondays":"noonday",
"noontides":"noontide",
"noosed":"noose",
"nooses":"noose",
"noosing":"noose",
"nopals":"nopal",
"nopaleas":"nopalea",
"noradrenalines":"noradrenaline",
"nordics":"nordic",
"noreasters":"noreaster",
"noregs":"noreg",
"norepinephrines":"norepinephrine",
"norethandrolones":"norethandrolone",
"norethindrones":"norethindrone",
"norges":"norge",
"norias":"noria",
"norms":"norm",
"normals":"normal",
"normalcies":"normalcy",
"normalisations":"normalisation",
"normalities":"normality",
"normalizations":"normalization",
"normalized":"normalize",
"normalizes":"normalize",
"normalizing":"normalize",
"norman-frenches":"norman-french",
"normandies":"normandie",
"normanized":"normanize",
"normanizing":"normanize",
"norses":"norse",
"norsemen":"norseman",
"norths":"north",
"northcountrymen":"northcountryman",
"northeasts":"northeast",
"northeasters":"northeaster",
"northeasterlies":"northeasterly",
"northers":"norther",
"northerlies":"northerly",
"northerners":"northerner",
"northlands":"northland",
"northmen":"northman",
"northwests":"northwest",
"northwesters":"northwester",
"northwesterlies":"northwesterly",
"norways":"norway",
"Norwegians":"Norwegian",
"nosed":"nose",
"noses":"nose",
"nosing":"nose",
"nosebags":"nosebag",
"nosebleeds":"nosebleed",
"nosecounts":"nosecount",
"nosegays":"nosegay",
"nosepieces":"nosepiece",
"nosey-parkers":"nosey-parker",
"noshes":"nosh",
"nosinesses":"nosiness",
"nosologies":"nosology",
"nostocaceaes":"nostocaceae",
"nostrils":"nostril",
"nostrilses":"nostrils",
"nostrums":"nostrum",
"nosier":"nosy",
"nosiest":"nosy",
"nosy-parkers":"nosy-parker",
"notabilities":"notability",
"notables":"notable",
"notarized":"notarize",
"notarizing":"notarize",
"notaries":"notary",
"notated":"notate",
"notating":"notate",
"notations":"notation",
"notched":"notch",
"notches":"notch",
"notching":"notch",
"noted":"note",
"notes":"note",
"noting":"note",
"notebooks":"notebook",
"notecases":"notecase",
"notechises":"notechis",
"notemigonuses":"notemigonus",
"notepapers":"notepaper",
"nothings":"nothing",
"nothingnesses":"nothingness",
"nothofaguses":"nothofagus",
"nothosaurias":"nothosauria",
"noticed":"notice",
"notices":"notice",
"noticing":"notice",
"noticeabilities":"noticeability",
"noticeablenesses":"noticeableness",
"notifications":"notification",
"notified":"notify",
"notifies":"notify",
"notifying":"notify",
"notifyings":"notifying",
"notions":"notion",
"notionses":"notions",
"notomyses":"notomys",
"notonectas":"notonecta",
"notonectidaes":"notonectidae",
"notophthalmuses":"notophthalmus",
"notorieties":"notoriety",
"notornises":"notornis",
"notoryctidaes":"notoryctidae",
"notoryctuses":"notoryctus",
"notostracas":"notostraca",
"notropises":"notropis",
"nota":"notum",
"noughts":"nought",
"noumena":"noumenon",
"noumenons":"noumenon",
"nouns":"noun",
"nourished":"nourish",
"nourishes":"nourish",
"nourishing":"nourish",
"nourishings":"nourishing",
"nourishments":"nourishment",
"nouses":"nous",
"nouveau-riches":"nouveau-riche",
"novs":"nov",
"novae":"nova",
"novas":"nova",
"novels":"novel",
"novelettes":"novelette",
"novelisations":"novelisation",
"novelists":"novelist",
"novelizations":"novelization",
"novelized":"novelize",
"novelizing":"novelize",
"novellas":"novella",
"novelle":"novella",
"noveltieses":"novelties",
"novelties":"novelty",
"novembers":"november",
"novemdecillions":"novemdecillion",
"novenae":"novena",
"novenas":"novena",
"novices":"novice",
"noviciates":"noviciate",
"novitiates":"novitiate",
"novocains":"novocain",
"novocaines":"novocaine",
"nowadayses":"nowadays",
"nownesses":"nowness",
"noxes":"nox",
"noxiousnesses":"noxiousness",
"nozzles":"nozzle",
"nps":"np",
"nsaids":"nsaid",
"nuances":"nuance",
"nubs":"nub",
"nubas":"nuba",
"nubbinesses":"nubbiness",
"nubbier":"nubby",
"nubbiest":"nubby",
"nubeculae":"nubecula",
"nucelli":"nucellus",
"nuchae":"nucha",
"nucifragas":"nucifraga",
"nuclearized":"nuclearize",
"nuclearizing":"nuclearize",
"nucleoles":"nucleole",
"nucleoli":"nucleolus",
"nucleoluses":"nucleolus",
"nucleoplasms":"nucleoplasm",
"nuclei":"nucleus",
"nucleuses":"nucleus",
"nudas":"nuda",
"nuder":"nude",
"nudes":"nude",
"nudest":"nude",
"nudenesses":"nudeness",
"nudged":"nudge",
"nudges":"nudge",
"nudging":"nudge",
"nudibranches":"nudibranch",
"nudibranchias":"nudibranchia",
"nudisms":"nudism",
"nudists":"nudist",
"nudities":"nudity",
"nuernbergs":"nuernberg",
"nuggets":"nugget",
"nuisances":"nuisance",
"nuked":"nuke",
"nukes":"nuke",
"nuking":"nuke",
"nullified":"nullify",
"nullifies":"nullify",
"nullifying":"nullify",
"nulliparae":"nullipara",
"nullities":"nullity",
"numbed":"numb",
"numbing":"numb",
"numbs":"numb",
"numbats":"numbat",
"numbered":"number",
"numbering":"number",
"numbers":"number",
"numberings":"numbering",
"numberplates":"numberplate",
"numberses":"numbers",
"numbfishes":"numbfish",
"numdahs":"numdah",
"numina":"numen",
"numeniuses":"numenius",
"numerals":"numeral",
"numerated":"numerate",
"numerating":"numerate",
"numerations":"numeration",
"numerosities":"numerosity",
"numerousnesses":"numerousness",
"numidas":"numida",
"numididaes":"numididae",
"numidinaes":"numidinae",
"numismaticses":"numismatics",
"numismatists":"numismatist",
"numismatologists":"numismatologist",
"numismatologies":"numismatology",
"nummulitidaes":"nummulitidae",
"numskulls":"numskull",
"nuns":"nun",
"nuncios":"nuncio",
"nunneries":"nunnery",
"nupes":"nupe",
"nuphars":"nuphar",
"nuprins":"nuprin",
"nuptials":"nuptial",
"nuptialses":"nuptials",
"nuremburgs":"nuremburg",
"nuris":"nuri",
"nurnbergs":"nurnberg",
"nursed":"nurse",
"nurses":"nurse",
"nursing":"nurse",
"nurselings":"nurseling",
"nursemaids":"nursemaid",
"nurseries":"nursery",
"nurserymen":"nurseryman",
"nurslings":"nursling",
"nurtured":"nurture",
"nurtures":"nurture",
"nurturing":"nurture",
"nurturings":"nurturing",
"nuts":"nut",
"nutted":"nut",
"nutting":"nut",
"nutated":"nutate",
"nutating":"nutate",
"nutations":"nutation",
"nutcases":"nutcase",
"nutcrackers":"nutcracker",
"nutcrackerses":"nutcrackers",
"nutgrasses":"nutgrass",
"nuthatches":"nuthatch",
"nuthouses":"nuthouse",
"nutmegs":"nutmeg",
"nutmeg-yews":"nutmeg-yew",
"nutrias":"nutria",
"nutrients":"nutrient",
"nutriments":"nutriment",
"nutritionists":"nutritionist",
"nutritiousnesses":"nutritiousness",
"nutritivenesses":"nutritiveness",
"nutsedges":"nutsedge",
"nutshells":"nutshell",
"nuttier":"nutty",
"nuttiest":"nutty",
"nuytsias":"nuytsia",
"nuzzled":"nuzzle",
"nuzzles":"nuzzle",
"nuzzling":"nuzzle",
"nws":"nw",
"nwbns":"nwbn",
"nwbws":"nwbw",
"nyalas":"nyala",
"nyanjas":"nyanja",
"nyasalands":"nyasaland",
"nybbles":"nybble",
"nyctaginaceaes":"nyctaginaceae",
"nyctaginias":"nyctaginia",
"nyctalopias":"nyctalopia",
"nyctanassas":"nyctanassa",
"nyctereuteses":"nyctereutes",
"nycticebuses":"nycticebus",
"nycticoraxes":"nycticorax",
"nyctimenes":"nyctimene",
"nylghais":"nylghai",
"nylghaus":"nylghau",
"nylons":"nylon",
"nylonses":"nylons",
"nymphs":"nymph",
"nymphae":"nympha",
"nymphaeas":"nymphaea",
"nymphaeaceaes":"nymphaeaceae",
"nymphalids":"nymphalid",
"nymphalidaes":"nymphalidae",
"nymphalises":"nymphalis",
"nymphicuses":"nymphicus",
"nymphos":"nympho",
"nympholepsies":"nympholepsy",
"nymphomaniacs":"nymphomaniac",
"nynorsks":"nynorsk",
"nyoros":"nyoro",
"nypas":"nypa",
"nyssas":"nyssa",
"nyssaceaes":"nyssaceae",
"nystatins":"nystatin",
"oes":"o",
"os":"o",
"oafs":"oaf",
"oahus":"oahu",
"oaks":"oak",
"oared":"oar",
"oaring":"oar",
"oars":"oar",
"oarfishes":"oarfish",
"oarlocks":"oarlock",
"oarsmen":"oarsman",
"oases":"oasis",
"oats":"oat",
"oaths":"oath",
"oatmeals":"oatmeal",
"oaxacas":"oaxaca",
"obs":"ob",
"obbligati":"obbligato",
"obbligatos":"obbligato",
"obduracies":"obduracy",
"obeahs":"obeah",
"obeches":"obeche",
"obechis":"obechi",
"obediences":"obedience",
"obedientiaries":"obedientiary",
"obeisances":"obeisance",
"obelisks":"obelisk",
"obeli":"obelus",
"obesities":"obesity",
"obeyed":"obey",
"obeying":"obey",
"obfuscated":"obfuscate",
"obfuscating":"obfuscate",
"obfuscations":"obfuscation",
"obis":"obi",
"obits":"obit",
"obituaries":"obituary",
"objected":"object",
"objecting":"object",
"objects":"object",
"objectified":"objectify",
"objectifies":"objectify",
"objectifying":"objectify",
"objections":"objection",
"objectionablenesses":"objectionableness",
"objectives":"objective",
"objectivenesses":"objectiveness",
"objectivities":"objectivity",
"objectors":"objector",
"objets_d'art":"objet_d'art",
"objurgated":"objurgate",
"objurgates":"objurgate",
"objurgating":"objurgate",
"objurgations":"objurgation",
"oblatenesses":"oblateness",
"oblations":"oblation",
"obligated":"obligate",
"obligates":"obligate",
"obligating":"obligate",
"obligations":"obligation",
"obligatos":"obligato",
"obliged":"oblige",
"obliges":"oblige",
"obliging":"oblige",
"obligingnesses":"obligingness",
"obliqued":"oblique",
"obliques":"oblique",
"obliquing":"oblique",
"obliquenesses":"obliqueness",
"obliquities":"obliquity",
"obliterated":"obliterate",
"obliterates":"obliterate",
"obliterating":"obliterate",
"obliterations":"obliteration",
"oblivions":"oblivion",
"obliviousnesses":"obliviousness",
"oblongs":"oblong",
"oblongnesses":"oblongness",
"obloquies":"obloquy",
"obloquys":"obloquy",
"obnoxiousnesses":"obnoxiousness",
"oboes":"oboe",
"obols":"obol",
"oboli":"obolus",
"obscenities":"obscenity",
"obscured":"obscure",
"obscurer":"obscure",
"obscurest":"obscure",
"obscuring":"obscure",
"obscurenesses":"obscureness",
"obscurities":"obscurity",
"obsequiousnesses":"obsequiousness",
"obsequies":"obsequy",
"observances":"observance",
"observations":"observation",
"observatories":"observatory",
"observed":"observe",
"observes":"observe",
"observing":"observe",
"observers":"observer",
"obsessed":"obsess",
"obsesses":"obsess",
"obsessing":"obsess",
"obsessions":"obsession",
"obsessivenesses":"obsessiveness",
"obsessivities":"obsessivity",
"obsolesced":"obsolesce",
"obsolescing":"obsolesce",
"obsolescences":"obsolescence",
"obsoleted":"obsolete",
"obsoleting":"obsolete",
"obsoletenesses":"obsoleteness",
"obstacles":"obstacle",
"obstetricians":"obstetrician",
"obstetricses":"obstetrics",
"obstinacies":"obstinacy",
"obstinances":"obstinance",
"obstructed":"obstruct",
"obstructing":"obstruct",
"obstructs":"obstruct",
"obstructions":"obstruction",
"obstructionists":"obstructionist",
"obstructors":"obstructor",
"obtained":"obtain",
"obtaining":"obtain",
"obtains":"obtain",
"obtainments":"obtainment",
"obtentions":"obtention",
"obtruded":"obtrude",
"obtrudes":"obtrude",
"obtruding":"obtrude",
"obtunded":"obtund",
"obtunding":"obtund",
"obturated":"obturate",
"obturating":"obturate",
"obtusenesses":"obtuseness",
"obverted":"obvert",
"obverting":"obvert",
"obviated":"obviate",
"obviates":"obviate",
"obviating":"obviate",
"obviations":"obviation",
"obviousnesses":"obviousness",
"ocas":"oca",
"ocarinas":"ocarina",
"occasioned":"occasion",
"occasioning":"occasion",
"occasions":"occasion",
"occidents":"occident",
"occidentals":"occidental",
"Occidentalized":"Occidentalize",
"Occidentalizes":"Occidentalize",
"Occidentalizing":"Occidentalize",
"occipita":"occiput",
"occiputs":"occiput",
"occitans":"occitan",
"occluded":"occlude",
"occludes":"occlude",
"occluding":"occlude",
"occlusions":"occlusion",
"occlusives":"occlusive",
"occulted":"occult",
"occulting":"occult",
"occults":"occult",
"occupancies":"occupancy",
"occupants":"occupant",
"occupations":"occupation",
"occupiers":"occupier",
"occupied":"occupy",
"occupies":"occupy",
"occupying":"occupy",
"occupyings":"occupying",
"occurred":"occur",
"occurring":"occur",
"occurs":"occur",
"occurrences":"occurrence",
"oceans":"ocean",
"oceanaria":"oceanarium",
"oceanariia":"oceanarium",
"oceanariums":"oceanarium",
"oceanias":"oceania",
"oceanics":"oceanic",
"oceanicas":"oceanica",
"oceanides":"oceanid",
"oceanids":"oceanid",
"oceaniteses":"oceanites",
"ocelli":"ocellus",
"ocelluses":"ocellus",
"ocelots":"ocelot",
"ochers":"ocher",
"ochlocracies":"ochlocracy",
"ochnas":"ochna",
"ochnaceaes":"ochnaceae",
"ochotonas":"ochotona",
"ochotonidaes":"ochotonidae",
"ochres":"ochre",
"ochreae":"ochrea",
"ocreae":"ochrea",
"ochromas":"ochroma",
"ocimums":"ocimum",
"ocotillos":"ocotillo",
"octs":"oct",
"octads":"octad",
"octahedra":"octahedron",
"octahedrons":"octahedron",
"octarchies":"octarchy",
"octaves":"octave",
"octavians":"octavian",
"octavos":"octavo",
"octets":"octet",
"octettes":"octette",
"octillions":"octillion",
"octobers":"october",
"octocentenaries":"octocentenary",
"octodecillions":"octodecillion",
"octodecimos":"octodecimo",
"octogenarians":"octogenarian",
"octogenarinarians":"octogenarian",
"octogenaries":"octogenary",
"octogenarnaries":"octogenary",
"octonaries":"octonary",
"octopodas":"octopoda",
"octopodidaes":"octopodidae",
"octopi":"octopus",
"octopuses":"octopus",
"octrois":"octroi",
"octupled":"octuple",
"octupling":"octuple",
"oculars":"ocular",
"oculists":"oculist",
"oculomotors":"oculomotor",
"oculuses":"oculus",
"ocyuruses":"ocyurus",
"ods":"od",
"odalisques":"odalisque",
"odder":"odd",
"oddest":"odd",
"oddballs":"oddball",
"oddities":"oddity",
"oddments":"oddment",
"oddmentses":"oddments",
"oddnesses":"oddness",
"oddses":"odds",
"odes":"ode",
"oders":"oder",
"odea":"odeum",
"odiousnesses":"odiousness",
"odiums":"odium",
"odobenidaes":"odobenidae",
"odobenuses":"odobenus",
"odocoileuses":"odocoileus",
"odometers":"odometer",
"odonatas":"odonata",
"odontaspididaes":"odontaspididae",
"odontaspises":"odontaspis",
"odontocetis":"odontoceti",
"odontophoruses":"odontophorus",
"odors":"odor",
"odours":"odour",
"odysseuses":"odysseus",
"odysseys":"odyssey",
"oecanthuses":"oecanthus",
"oedemas":"oedema",
"oedemata":"oedema",
"oedipuses":"oedipus",
"oedogoniaceaes":"oedogoniaceae",
"oedogonialeses":"oedogoniales",
"oedogoniums":"oedogonium",
"oenanthes":"oenanthe",
"oenguses":"oengus",
"oenologists":"oenologist",
"oenologies":"oenology",
"oenophiles":"oenophile",
"oenophilists":"oenophilist",
"oenotheras":"oenothera",
"oesophaguses":"oesophagus",
"oesterreiches":"oesterreich",
"oestridaes":"oestridae",
"oestrogens":"oestrogen",
"oestrones":"oestrone",
"oestruses":"oestrus",
"oeuvres":"oeuvre",
"off-licences":"off-licence",
"off-roaders":"off-roader",
"off-whites":"off-white",
"offences":"offence",
"offended":"offend",
"offending":"offend",
"offends":"offend",
"offenders":"offender",
"offenses":"offense",
"offensives":"offensive",
"offensivenesses":"offensiveness",
"offered":"offer",
"offering":"offer",
"offers":"offer",
"offerings":"offering",
"offertories":"offertory",
"offices":"office",
"officeholders":"officeholder",
"officered":"officer",
"officering":"officer",
"officers":"officer",
"officials":"official",
"officialdoms":"officialdom",
"officiaries":"officiary",
"officiated":"officiate",
"officiates":"officiate",
"officiating":"officiate",
"officiatings":"officiating",
"officiations":"officiation",
"officiousnesses":"officiousness",
"offprints":"offprint",
"offsets":"offset",
"offsetting":"offset",
"offshoots":"offshoot",
"offsprings":"offspring",
"offstages":"offstage",
"oftennesses":"oftenness",
"ogalalas":"ogalala",
"ogcocephalidaes":"ogcocephalidae",
"ogdoads":"ogdoad",
"ogives":"ogive",
"oglalas":"oglala",
"ogled":"ogle",
"ogling":"ogle",
"ogres":"ogre",
"ohios":"ohio",
"ohioans":"ohioan",
"ohms":"ohm",
"oiled":"oil",
"oiling":"oil",
"oils":"oil",
"oil-water_interfaces":"oil-water_interface",
"oilbirds":"oilbird",
"oilers":"oiler",
"oilfishes":"oilfish",
"oilinesses":"oiliness",
"oilmen":"oilman",
"oilrigs":"oilrig",
"oilskins":"oilskin",
"oilstoves":"oilstove",
"oilier":"oily",
"oiliest":"oily",
"oinked":"oink",
"oinking":"oink",
"oinks":"oink",
"ointments":"ointment",
"ojibwas":"ojibwa",
"ojibways":"ojibway",
"oks":"ok",
"okas":"oka",
"okapis":"okapi",
"okapias":"okapia",
"okayed":"okay",
"okaying":"okay",
"okays":"okay",
"okehs":"okeh",
"okeys":"okey",
"okinawas":"okinawa",
"oklahomas":"oklahoma",
"okras":"okra",
"olas":"ola",
"older":"old",
"oldest":"old",
"old-man-of-the-woodses":"old-man-of-the-woods",
"old-timers":"old-timer",
"oldened":"olden",
"oldening":"olden",
"oldsters":"oldster",
"oldwenches":"oldwench",
"oldwives":"oldwife",
"oles":"ole",
"oleas":"olea",
"oleaceaes":"oleaceae",
"oleaginousnesses":"oleaginousness",
"olealeses":"oleales",
"oleanders":"oleander",
"oleandras":"oleandra",
"oleandraceaes":"oleandraceae",
"olearias":"olearia",
"olefins":"olefin",
"olefines":"olefine",
"oleins":"olein",
"oleos":"oleo",
"oleomargarines":"oleomargarine",
"olea":"oleum",
"oleums":"oleum",
"olfactions":"olfaction",
"olfactories":"olfactory",
"olfersias":"olfersia",
"olibanums":"olibanum",
"oligarchies":"oligarchy",
"oligocenes":"oligocene",
"oligochaetas":"oligochaeta",
"oligochaetes":"oligochaete",
"oligoclases":"oligoclase",
"oligodendrias":"oligodendria",
"oligodendroglias":"oligodendroglia",
"oligopliteses":"oligoplites",
"oligopolies":"oligopoly",
"oligoporuses":"oligoporus",
"oligopsonies":"oligopsony",
"olimboses":"olimbos",
"olios":"olio",
"olives":"olive",
"ollas":"olla",
"olms":"olm",
"ologies":"ology",
"olympias":"olympia",
"olympiads":"olympiad",
"olympians":"olympian",
"olympicses":"olympics",
"olympuses":"olympus",
"omahas":"omaha",
"omasums":"omasum",
"omayyades":"omayyad",
"omayyads":"omayyad",
"ombs":"omb",
"ombus":"ombu",
"ombudsmen":"ombudsman",
"omdurmen":"omdurman",
"omegas":"omega",
"omelets":"omelet",
"omelettes":"omelette",
"omened":"omen",
"omening":"omen",
"omens":"omen",
"omenta":"omentum",
"omissions":"omission",
"omits":"omit",
"omitted":"omit",
"omitting":"omit",
"ommatidia":"ommatidium",
"ommatidtidia":"ommatidium",
"ommiades":"ommiad",
"ommiads":"ommiad",
"omnibuses":"omnibus",
"omnipresences":"omnipresence",
"omnium-gatherums":"omnium-gatherum",
"omomyids":"omomyid",
"omphaloses":"omphalos",
"omphalotuses":"omphalotus",
"omphaluses":"omphalus",
"onagers":"onager",
"onagri":"onager",
"onagraceaes":"onagraceae",
"onanisms":"onanism",
"onanists":"onanist",
"once-overs":"once-over",
"onchocerciases":"onchocerciasis",
"onchorynchuses":"onchorynchus",
"oncidiums":"oncidium",
"oncomings":"oncoming",
"oncovins":"oncovin",
"ondatras":"ondatra",
"ones":"one",
"one-billionths":"one-billionth",
"one-dimensionalities":"one-dimensionality",
"one-eighths":"one-eighth",
"one-eightys":"one-eighty",
"one-fifths":"one-fifth",
"one-fourths":"one-fourth",
"one-halves":"one-half",
"one-hitters":"one-hitter",
"one-hundredths":"one-hundredth",
"one-millionths":"one-millionth",
"one-ninths":"one-ninth",
"one-quadrillionths":"one-quadrillionth",
"one-quintillionths":"one-quintillionth",
"one-sevenths":"one-seventh",
"one-sixths":"one-sixth",
"one-stepped":"one-step",
"one-stepping":"one-step",
"one-tenths":"one-tenth",
"one-thirds":"one-third",
"one-thousandths":"one-thousandth",
"one-trillionths":"one-trillionth",
"one-upped":"one-up",
"one-upping":"one-up",
"oneidas":"oneida",
"onenesses":"oneness",
"onerousnesses":"onerousness",
"onions":"onion",
"onionskins":"onionskin",
"oniscidaes":"oniscidae",
"oniscuses":"oniscus",
"onlaid":"onlay",
"onlaying":"onlay",
"onlookers":"onlooker",
"onobrychises":"onobrychis",
"onocleas":"onoclea",
"onondagas":"onondaga",
"ononises":"ononis",
"onopordons":"onopordon",
"onopordums":"onopordum",
"onosmodiums":"onosmodium",
"onrushes":"onrush",
"onsets":"onset",
"onslaughts":"onslaught",
"ontogeneses":"ontogenesis",
"ontogenies":"ontogeny",
"onuses":"onus",
"onychiums":"onychium",
"onychogaleas":"onychogalea",
"onychomyses":"onychomys",
"onychophoras":"onychophora",
"onychophorans":"onychophoran",
"oodleses":"oodles",
"oogonia":"oogonium",
"oogoniums":"oogonium",
"oomphs":"oomph",
"oomyceteses":"oomycetes",
"oophorectomies":"oophorectomy",
"oothecae":"ootheca",
"oozed":"ooze",
"oozes":"ooze",
"oozing":"ooze",
"oozings":"oozing",
"oozier":"oozy",
"ooziest":"oozy",
"opacified":"opacify",
"opacifying":"opacify",
"opacities":"opacity",
"opahs":"opah",
"opals":"opal",
"opalescences":"opalescence",
"opaqued":"opaque",
"opaques":"opaque",
"opaquing":"opaque",
"opaquenesses":"opaqueness",
"opecs":"opec",
"opened":"open",
"flagships":"flagship",
"opening":"open",
"opens":"open",
"openers":"opener",
"openhandednesses":"openhandedness",
"openings":"opening",
"opennesses":"openness",
"opepes":"opepe",
"operas":"opera",
"operated":"operate",
"operates":"operate",
"operating":"operate",
"operations":"operation",
"operationses":"operations",
"operatives":"operative",
"operators":"operator",
"operas_seria":"opera_seria",
"opera_serias":"opera_seria",
"opercula":"operculum",
"operculums":"operculum",
"operettas":"operetta",
"operosenesses":"operoseness",
"opheodryses":"opheodrys",
"ophidias":"ophidia",
"ophidians":"ophidian",
"ophidiidaes":"ophidiidae",
"ophiodons":"ophiodon",
"ophiodontidaes":"ophiodontidae",
"ophioglossaceaes":"ophioglossaceae",
"ophioglossaleses":"ophioglossales",
"ophioglossums":"ophioglossum",
"ophiolatries":"ophiolatry",
"ophiophaguses":"ophiophagus",
"ophisauruses":"ophisaurus",
"ophiuridas":"ophiurida",
"ophiuroideas":"ophiuroidea",
"ophryses":"ophrys",
"ophthalmias":"ophthalmia",
"ophthalmitises":"ophthalmitis",
"ophthalmologists":"ophthalmologist",
"opiated":"opiate",
"opiating":"opiate",
"opilioneses":"opiliones",
"opined":"opine",
"opines":"opine",
"opining":"opine",
"opinions":"opinion",
"opisthobranchias":"opisthobranchia",
"opisthocomidaes":"opisthocomidae",
"opisthocomuses":"opisthocomus",
"opisthognathidaes":"opisthognathidae",
"opossums":"opossum",
"oppenheimers":"oppenheimer",
"opponents":"opponent",
"opportunenesses":"opportuneness",
"opportunisms":"opportunism",
"opportunists":"opportunist",
"opportunities":"opportunity",
"opposed":"oppose",
"opposes":"oppose",
"opposing":"oppose",
"opposites":"opposite",
"oppositenesses":"oppositeness",
"oppositions":"opposition",
"oppressed":"oppress",
"oppresses":"oppress",
"oppressing":"oppress",
"oppressions":"oppression",
"oppressivenesses":"oppressiveness",
"oppressors":"oppressor",
"opprobriums":"opprobrium",
"oppugned":"oppugn",
"oppugning":"oppugn",
"oppugns":"oppugn",
"opsonified":"opsonify",
"opsonifying":"opsonify",
"opsonized":"opsonize",
"opsonizes":"opsonize",
"opsonizing":"opsonize",
"opted":"opt",
"opting":"opt",
"optatives":"optative",
"optics":"optic",
"opticians":"optician",
"optimized":"optimize",
"optimizing":"optimize",
"optima":"optimum",
"optimums":"optimum",
"options":"option",
"optometrists":"optometrist",
"opulences":"opulence",
"opuntias":"opuntia",
"opuntialeses":"opuntiales",
"opera":"opus",
"opuses":"opus",
"opvs":"opv",
"oraches":"orach",
"oracles":"oracle",
"oradexons":"oradexon",
"orals":"oral",
"orangs":"orang",
"oranges":"orange",
"orangemen":"orangeman",
"orangenesses":"orangeness",
"orangeries":"orangery",
"orangutans":"orangutan",
"orangutangs":"orangutang",
"orated":"orate",
"orating":"orate",
"orations":"oration",
"orators":"orator",
"oratorios":"oratorio",
"oratories":"oratory",
"orbed":"orb",
"orbing":"orb",
"orbs":"orb",
"orbignyas":"orbignya",
"orbited":"orbit",
"orbiting":"orbit",
"orbits":"orbit",
"orbiters":"orbiter",
"orcas":"orca",
"orchards":"orchard",
"orchardmen":"orchardman",
"orchestias":"orchestia",
"orchestiidaes":"orchestiidae",
"orchestras":"orchestra",
"orchestrated":"orchestrate",
"orchestrates":"orchestrate",
"orchestrating":"orchestrate",
"orchids":"orchid",
"orchidaceaes":"orchidaceae",
"orchidaleses":"orchidales",
"orchidectomies":"orchidectomy",
"orchiectomies":"orchiectomy",
"orchils":"orchil",
"orcinuses":"orcinus",
"orcuses":"orcus",
"ordained":"ordain",
"ordaining":"ordain",
"ordains":"ordain",
"ordainings":"ordaining",
"ordeals":"ordeal",
"ordered":"order",
"ordering":"order",
"orders":"order",
"order-chenopodialeses":"order-chenopodiales",
"orderings":"ordering",
"orderlinesses":"orderliness",
"orderlies":"orderly",
"ordinals":"ordinal",
"ordinances":"ordinance",
"ordinaries":"ordinary",
"ordinations":"ordination",
"ordnances":"ordnance",
"ordonnances":"ordonnance",
"ordovicians":"ordovician",
"ordures":"ordure",
"ores":"ore",
"oreamnoses":"oreamnos",
"orebodies":"orebody",
"orectolobidaes":"orectolobidae",
"orectolobuses":"orectolobus",
"oreganos":"oregano",
"oregons":"oregon",
"oreos":"oreo",
"oreopterises":"oreopteris",
"oreortyxes":"oreortyx",
"organs":"organ",
"organums":"organa",
"organdies":"organdie",
"organelles":"organelle",
"organics":"organic",
"organisations":"organisation",
"organisms":"organism",
"organists":"organist",
"organizations":"organization",
"orgainzed":"organize",
"orgainzing":"organize",
"organizes":"organize",
"organizers":"organizer",
"organa":"organon",
"organons":"organon",
"organses":"organs",
"organzas":"organza",
"orgasms":"orgasm",
"orgies":"orgy",
"oribis":"oribi",
"oriels":"oriel",
"oriented":"orient",
"orienting":"orient",
"orients":"orient",
"orientals":"oriental",
"orientalized":"orientalize",
"orientalizing":"orientalize",
"orientated":"orientate",
"orientates":"orientate",
"orientating":"orientate",
"orientations":"orientation",
"orifices":"orifice",
"origins":"origin",
"originals":"original",
"originalities":"originality",
"originated":"originate",
"originates":"originate",
"originating":"originate",
"originations":"origination",
"originators":"originator",
"orinasals":"orinasal",
"orinocos":"orinoco",
"orioles":"oriole",
"oriolidaes":"oriolidae",
"orioluses":"oriolus",
"orions":"orion",
"orisons":"orison",
"oriteses":"orites",
"orleanses":"orleans",
"orlops":"orlop",
"ormazds":"ormazd",
"ormers":"ormer",
"ormosias":"ormosia",
"ormuzds":"ormuzd",
"ornamented":"ornament",
"ornamenting":"ornament",
"ornaments":"ornament",
"ornamentals":"ornamental",
"ornamentalists":"ornamentalist",
"ornamentations":"ornamentation",
"ornatenesses":"ornateness",
"ornerinesses":"orneriness",
"ornerier":"ornery",
"orneriest":"ornery",
"ornithischias":"ornithischia",
"ornithischians":"ornithischian",
"ornithogalums":"ornithogalum",
"ornithologists":"ornithologist",
"ornithomimidas":"ornithomimida",
"ornithopods":"ornithopod",
"ornithopodas":"ornithopoda",
"ornithorhynchidaes":"ornithorhynchidae",
"ornithorhynchuses":"ornithorhynchus",
"orobanchaceaes":"orobanchaceae",
"orontiums":"orontium",
"orphaned":"orphan",
"orphaning":"orphan",
"orphans":"orphan",
"orphanages":"orphanage",
"orphreys":"orphrey",
"orpins":"orpin",
"orpines":"orpine",
"orreries":"orrery",
"orrises":"orris",
"orrisroots":"orrisroot",
"ortalises":"ortalis",
"orthicons":"orthicon",
"orthodontias":"orthodontia",
"orthodonticses":"orthodontics",
"orthodoxies":"orthodoxy",
"orthogonalities":"orthogonality",
"orthographies":"orthography",
"orthopaedicses":"orthopaedics",
"orthopedicses":"orthopedics",
"orthophosphates":"orthophosphate",
"orthopristises":"orthopristis",
"orthopteras":"orthoptera",
"orthopterans":"orthopteran",
"orthopterons":"orthopteron",
"orthostichies":"orthostichy",
"orthotomuses":"orthotomus",
"ortolans":"ortolan",
"orudises":"orudis",
"oruvails":"oruvail",
"orycteropodidaes":"orycteropodidae",
"orycteropuses":"orycteropus",
"oryctolaguses":"oryctolagus",
"oryxes":"oryx",
"oryzas":"oryza",
"oryzomyses":"oryzomys",
"oryzopses":"oryzopsis",
"oses":"os",
"ossa":"os",
"osages":"osage",
"oscillated":"oscillate",
"oscillates":"oscillate",
"oscillating":"oscillate",
"oscillations":"oscillation",
"oscillatoriaceaes":"oscillatoriaceae",
"oscilloscopes":"oscilloscope",
"oscines":"oscine",
"oscineses":"oscines",
"oscitances":"oscitance",
"oscitantancies":"oscitancy",
"osculated":"osculate",
"osculates":"osculate",
"osculating":"osculate",
"osculations":"osculation",
"osculators":"osculator",
"oscula":"osculum",
"oshas":"osha",
"osiers":"osier",
"oslos":"oslo",
"osmanlis":"osmanli",
"osmanthuses":"osmanthus",
"osmeridaes":"osmeridae",
"osmeruses":"osmerus",
"osmitrols":"osmitrol",
"osmiums":"osmium",
"osmosed":"osmose",
"osmosing":"osmose",
"osmunds":"osmund",
"osmundaceaes":"osmundaceae",
"ospreys":"osprey",
"ossicles":"ossicle",
"ossiculums":"ossiculum",
"ossifications":"ossification",
"ossified":"ossify",
"ossifies":"ossify",
"ossifying":"ossify",
"ossuaries":"ossuary",
"ostariophysis":"ostariophysi",
"osteichthyeses":"osteichthyes",
"ostentations":"ostentation",
"ostentatiousnesses":"ostentatiousness",
"osteoarthritises":"osteoarthritis",
"osteoblasts":"osteoblast",
"oateomas":"osteoma",
"oateomata":"osteoma",
"osteomas":"osteoma",
"osteomata":"osteoma",
"osteopaths":"osteopath",
"osteopathists":"osteopathist",
"osteopetroses":"osteopetrosis",
"osteoplasties":"osteoplasty",
"osteosarcomas":"osteosarcoma",
"osteostracans":"osteostracan",
"osteostracis":"osteostraci",
"osteotomies":"osteotomy",
"ostiaries":"ostiary",
"ostia":"ostium",
"ostlers":"ostler",
"ostraciidaes":"ostraciidae",
"ostracisms":"ostracism",
"ostracized":"ostracize",
"ostracizing":"ostracize",
"ostraized":"ostracize",
"ostracods":"ostracod",
"ostracodas":"ostracoda",
"ostracodermis":"ostracodermi",
"ostraca":"ostracon",
"ostreas":"ostrea",
"ostreidaes":"ostreidae",
"ostriches":"ostrich",
"ostryas":"ostrya",
"ostryopses":"ostryopsis",
"ostyaks":"ostyak",
"ostyak-samoyeds":"ostyak-samoyed",
"otalgias":"otalgia",
"otarias":"otaria",
"otariidaes":"otariidae",
"others":"other",
"othernesses":"otherness",
"otherworldlinesses":"otherworldliness",
"otideses":"otides",
"otididaes":"otididae",
"otises":"otis",
"otos":"oto",
"otoes":"otoe",
"otoganglions":"otoganglion",
"otolaryngologists":"otolaryngologist",
"otolaryngologies":"otolaryngology",
"otologists":"otologist",
"otologies":"otology",
"otorhinolaryngologists":"otorhinolaryngologist",
"ottars":"ottar",
"ottawas":"ottawa",
"otters":"otter",
"otterhounds":"otterhound",
"ottos":"otto",
"ottomans":"ottoman",
"ottomen":"ottoman",
"otuses":"otus",
"ouachitas":"ouachita",
"ouijas":"ouija",
"ounces":"ounce",
"ouranopithecuses":"ouranopithecus",
"ouranoses":"ouranos",
"ousels":"ousel",
"ousted":"oust",
"ousting":"oust",
"ousts":"oust",
"ousters":"ouster",
"oustings":"ousting",
"outed":"out",
"outing":"out",
"outs":"out",
"out-baskets":"out-basket",
"out-migrations":"out-migration",
"out-of-doorses":"out-of-doors",
"out-trays":"out-tray",
"outargued":"outargue",
"outarguing":"outargue",
"outbalanced":"outbalance",
"outbalances":"outbalance",
"outbalancing":"outbalance",
"outbidden":"outbid",
"outbidding":"outbid",
"outbids":"outbid",
"outbloomed":"outbloom",
"outblooming":"outbloom",
"outbraved":"outbrave",
"outbraving":"outbrave",
"outbreaks":"outbreak",
"outbred":"outbreed",
"outbreeding":"outbreed",
"outbreeds":"outbreed",
"outbuilding":"outbuild",
"outbuilt":"outbuild",
"outburned":"outburn",
"outburning":"outburn",
"outburnt":"outburn",
"outbursts":"outburst",
"outcasts":"outcast",
"outclassed":"outclass",
"outclassing":"outclass",
"outclimbed":"outclimb",
"outclimbing":"outclimb",
"outcomes":"outcome",
"outcropped":"outcrop",
"outcropping":"outcrop",
"outcrops":"outcrop",
"outcroppings":"outcropping",
"outcrossed":"outcross",
"outcrossing":"outcross",
"outcried":"outcry",
"outcries":"outcry",
"outcrying":"outcry",
"outdated":"outdate",
"outdating":"outdate",
"outdistanced":"outdistance",
"outdistances":"outdistance",
"outdistancing":"outdistance",
"outdid":"outdo",
"outdoes":"outdo",
"outdoing":"outdo",
"outdone":"outdo",
"outdoorses":"outdoors",
"outdoorsmen":"outdoorsman",
"outdrawing":"outdraw",
"outdrawn":"outdraw",
"outdrew":"outdraw",
"outdrank":"outdrink",
"outdrinking":"outdrink",
"outdrunk":"outdrink",
"outerwears":"outerwear",
"outfaced":"outface",
"outfaces":"outface",
"outfacing":"outface",
"outfits":"outfit",
"outfitted":"outfit",
"outfitting":"outfit",
"outflanked":"outflank",
"outflanking":"outflank",
"outflanks":"outflank",
"outflows":"outflow",
"outflew":"outfly",
"outflown":"outfly",
"outflying":"outfly",
"outfoxed":"outfox",
"outfoxes":"outfox",
"outfoxing":"outfox",
"outgassed":"outgas",
"outgasses":"outgas",
"outgassing":"outgas",
"outgeneraled":"outgeneral",
"outgeneraling":"outgeneral",
"outgeneralled":"outgeneral",
"outgeneralling":"outgeneral",
"outgenerals":"outgeneral",
"outgoes":"outgo",
"outgoing":"outgo",
"outgone":"outgo",
"outwent":"outgo",
"outgoers":"outgoer",
"outgrew":"outgrow",
"outgrowing":"outgrow",
"outgrown":"outgrow",
"outgrows":"outgrow",
"outgrowths":"outgrowth",
"outguessed":"outguess",
"outguesses":"outguess",
"outguessing":"outguess",
"outgushed":"outgush",
"outgushing":"outgush",
"outhouses":"outhouse",
"outings":"outing",
"outlanders":"outlander",
"outlandishnesses":"outlandishness",
"outlasted":"outlast",
"outlasting":"outlast",
"outlasts":"outlast",
"outlaughed":"outlaugh",
"outlaughing":"outlaugh",
"outlawed":"outlaw",
"outlawing":"outlaw",
"outlaws":"outlaw",
"outlawries":"outlawry",
"outlaid":"outlay",
"outlaying":"outlay",
"outlays":"outlay",
"outleaped":"outleap",
"outleaping":"outleap",
"outleapt":"outleap",
"outlets":"outlet",
"outlined":"outline",
"outlines":"outline",
"outlining":"outline",
"outlived":"outlive",
"outlives":"outlive",
"outliving":"outlive",
"outlooked":"outlook",
"outlooking":"outlook",
"outlooks":"outlook",
"outmanned":"outman",
"outmanning":"outman",
"outmans":"outman",
"outmaneuvered":"outmaneuver",
"outmaneuvering":"outmaneuver",
"outmaneuvers":"outmaneuver",
"outmanoeuvered":"outmanoeuver",
"outmanoeuvering":"outmanoeuver",
"outmarched":"outmarch",
"outmarching":"outmarch",
"outmatched":"outmatch",
"outmatches":"outmatch",
"outmatching":"outmatch",
"outmoded":"outmode",
"outmoding":"outmode",
"outnumbered":"outnumber",
"outnumbering":"outnumber",
"outpaced":"outpace",
"outpacing":"outpace",
"outperformed":"outperform",
"outperforming":"outperform",
"outplayed":"outplay",
"outplaying":"outplay",
"outpointed":"outpoint",
"outpointing":"outpoint",
"outpoints":"outpoint",
"outpolled":"outpoll",
"outpolling":"outpoll",
"outposts":"outpost",
"outpoured":"outpour",
"outpouring":"outpour",
"outpourings":"outpouring",
"outpulled":"outpull",
"outpulling":"outpull",
"outputs":"output",
"outputted":"output",
"outputting":"output",
"outraced":"outrace",
"outracing":"outrace",
"outraged":"outrage",
"outrages":"outrage",
"outraging":"outrage",
"outrageousnesses":"outrageousness",
"outranged":"outrange",
"outranging":"outrange",
"outranked":"outrank",
"outranking":"outrank",
"outranks":"outrank",
"outreached":"outreach",
"outreaching":"outreach",
"outridden":"outride",
"outrides":"outride",
"outriding":"outride",
"outrode":"outride",
"outrivalled":"outrival",
"outrivalling":"outrival",
"outrivals":"outrival",
"outroared":"outroar",
"outroaring":"outroar",
"outrooted":"outroot",
"outrooting":"outroot",
"outran":"outrun",
"outrunning":"outrun",
"outruns":"outrun",
"outscored":"outscore",
"outscores":"outscore",
"outscoring":"outscore",
"outselling":"outsell",
"outsells":"outsell",
"outsold":"outsell",
"outsets":"outset",
"outshined":"outshine",
"outshines":"outshine",
"outshining":"outshine",
"outshone":"outshine",
"outshooting":"outshoot",
"outshoots":"outshoot",
"outshot":"outshoot",
"outsides":"outside",
"outsiders":"outsider",
"outsang":"outsing",
"outsinging":"outsing",
"outsung":"outsing",
"outskirts":"outskirt",
"outsleeping":"outsleep",
"outslept":"outsleep",
"outsmarted":"outsmart",
"outsmarting":"outsmart",
"outsmarts":"outsmart",
"oursoared":"outsoar",
"outsoaring":"outsoar",
"outspanned":"outspan",
"outspanning":"outspan",
"outspans":"outspan",
"outsparkled":"outsparkle",
"outsparkling":"outsparkle",
"outspeaking":"outspeak",
"outspoke":"outspeak",
"outspoken":"outspeak",
"outsped":"outspeed",
"outspeeded":"outspeed",
"outspeeding":"outspeed",
"outspending":"outspend",
"outspent":"outspend",
"outspokennesses":"outspokenness",
"outspreading":"outspread",
"outspreads":"outspread",
"outstanding":"outstand",
"outstands":"outstand",
"outstood":"outstand",
"outstandings":"outstanding",
"outstared":"outstare",
"outstaring":"outstare",
"outstations":"outstation",
"outstayed":"outstay",
"outstaying":"outstay",
"outstays":"outstay",
"outstretched":"outstretch",
"outstretching":"outstretch",
"ourstrode":"outstride",
"outstridden":"outstride",
"outstriding":"outstride",
"outstripped":"outstrip",
"outstripping":"outstrip",
"outstrips":"outstrip",
"outswearing":"outswear",
"outswore":"outswear",
"outsworn":"outswear",
"outtelling":"outtell",
"outtold":"outtell",
"outthinking":"outthink",
"outthinks":"outthink",
"outthought":"outthink",
"outthrew":"outthrow",
"outthrowing":"outthrow",
"outthrown":"outthrow",
"outtricked":"outtrick",
"outtricking":"outtrick",
"outturns":"outturn",
"outvoted":"outvote",
"outvoting":"outvote",
"outwards":"outward",
"outwardnesses":"outwardness",
"outwatched":"outwatch",
"outwatching":"outwatch",
"outwearing":"outwear",
"outwears":"outwear",
"outwore":"outwear",
"outworn":"outwear",
"outwearied":"outweary",
"outwearying":"outweary",
"outweeping":"outweep",
"outwept":"outweep",
"outweighed":"outweigh",
"outweighing":"outweigh",
"outweighs":"outweigh",
"outwelled":"outwell",
"outwelling":"outwell",
"outwits":"outwit",
"outwitted":"outwit",
"outwitting":"outwit",
"outwked":"outwk",
"outwking":"outwk",
"outwks":"outwk",
"outwrought":"outwk",
"outworked":"outwork",
"outworking":"outwork",
"ouzels":"ouzel",
"ouzos":"ouzo",
"ovals":"oval",
"ovalbumins":"ovalbumin",
"ovalipeses":"ovalipes",
"ovambos":"ovambo",
"ovariectomies":"ovariectomy",
"ovariotomies":"ovariotomy",
"ovaries":"ovary",
"ovations":"ovation",
"ovens":"oven",
"ovenbirds":"ovenbird",
"over-crowdings":"over-crowding",
"overabounded":"overabound",
"overabounding":"overabound",
"overabundances":"overabundance",
"overachieved":"overachieve",
"overachieving":"overachieve",
"overacted":"overact",
"overacting":"overact",
"overacts":"overact",
"overactings":"overacting",
"overalls":"overall",
"overappraisals":"overappraisal",
"overarched":"overarch",
"overarches":"overarch",
"overarching":"overarch",
"overawed":"overawe",
"overawes":"overawe",
"overawing":"overawe",
"overbalanced":"overbalance",
"overbalances":"overbalance",
"overbalancing":"overbalance",
"overbearing":"overbear",
"overbears":"overbear",
"overbore":"overbear",
"overborne":"overbear",
"overbearingnesses":"overbearingness",
"overbidding":"overbid",
"overbids":"overbid",
"overblew":"overblow",
"overblowing":"overblow",
"overblown":"overblow",
"overblows":"overblow",
"overbooked":"overbook",
"overbooking":"overbook",
"overbuilding":"overbuild",
"overbuilds":"overbuild",
"overbuilt":"overbuild",
"overburdened":"overburden",
"overburdening":"overburden",
"overburdens":"overburden",
"overbought":"overbuy",
"overbuying":"overbuy",
"overcalled":"overcall",
"overcalling":"overcall",
"overcalls":"overcall",
"overcapacities":"overcapacity",
"overcapitalized":"overcapitalize",
"overcapitalizing":"overcapitalize",
"overcasting":"overcast",
"overcasts":"overcast",
"overcastings":"overcasting",
"overcharged":"overcharge",
"overcharges":"overcharge",
"overcharging":"overcharge",
"overclotheses":"overclothes",
"ocerclouding":"overcloud",
"overclouded":"overcloud",
"overclouds":"overcloud",
"overcoats":"overcoat",
"overcoatings":"overcoating",
"overcolored":"overcolor",
"overcoloring":"overcolor",
"overcame":"overcome",
"overcomes":"overcome",
"overcoming":"overcome",
"overcompensated":"overcompensate",
"overcompensates":"overcompensate",
"overcompensating":"overcompensate",
"overconfidences":"overconfidence",
"overcounted":"overcount",
"overcounting":"overcount",
"overcropped":"overcrop",
"overcropping":"overcrop",
"overcrops":"overcrop",
"overcrossings":"overcrossing",
"overcrowded":"overcrowd",
"overcrowding":"overcrowd",
"overdeveloped":"overdevelop",
"overdeveloping":"overdevelop",
"overdid":"overdo",
"overdoes":"overdo",
"overdoing":"overdo",
"overdone":"overdo",
"overdosed":"overdose",
"overdoses":"overdose",
"overdosing":"overdose",
"overdrawing":"overdraw",
"overdrawn":"overdraw",
"overdraws":"overdraw",
"overdrew":"overdraw",
"overdressed":"overdress",
"overdresses":"overdress",
"overdressing":"overdress",
"overdrank":"overdrink",
"overdrinking":"overdrink",
"overdrunk":"overdrink",
"overdriven":"overdrive",
"overdrives":"overdrive",
"overdriving":"overdrive",
"overdrove":"overdrive",
"overdried":"overdry",
"overdrying":"overdry",
"overdyed":"overdye",
"overdyeing":"overdye",
"overate":"overeat",
"overeaten":"overeat",
"overeating":"overeat",
"overeatings":"overeating",
"overemphasized":"overemphasize",
"overemphasizes":"overemphasize",
"overemphasizing":"overemphasize",
"overestimated":"overestimate",
"overestimates":"overestimate",
"overestimating":"overestimate",
"overestimations":"overestimation",
"overexcited":"overexcite",
"overexciting":"overexcite",
"overexerted":"overexert",
"overexerting":"overexert",
"overexploitations":"overexploitation",
"overexposed":"overexpose",
"overexposing":"overexpose",
"overextended":"overextend",
"overextending":"overextend",
"overextends":"overextend",
"overfed":"overfeed",
"overfeeding":"overfeed",
"overfilled":"overfill",
"overfilling":"overfill",
"overfished":"overfish",
"overfishing":"overfish",
"overflowed":"overflow",
"overflowing":"overflow",
"overflows":"overflow",
"overflowings":"overflowing",
"overflew":"overfly",
"overflies":"overfly",
"overflown":"overfly",
"overflying":"overfly",
"overgarments":"overgarment",
"overglazed":"overglaze",
"overglazing":"overglaze",
"overgoverned":"overgovern",
"overgoverning":"overgovern",
"overgrazed":"overgraze",
"overgrazing":"overgraze",
"overgrew":"overgrow",
"overgrowing":"overgrow",
"overgrown":"overgrow",
"overgrows":"overgrow",
"overgrowths":"overgrowth",
"overhanded":"overhand",
"overhanding":"overhand",
"overhanging":"overhang",
"overhangs":"overhang",
"overhung":"overhang",
"overhauled":"overhaul",
"overhauling":"overhaul",
"overhauls":"overhaul",
"overhaulings":"overhauling",
"overheads":"overhead",
"overheard":"overhear",
"overhearing":"overhear",
"overhears":"overhear",
"overheated":"overheat",
"overheating":"overheat",
"overindulged":"overindulge",
"overindulges":"overindulge",
"overindulging":"overindulge",
"overindulgences":"overindulgence",
"overissued":"overissue",
"overissues":"overissue",
"overissuing":"overissue",
"overjoyed":"overjoy",
"overjoying":"overjoy",
"overlabored":"overlabor",
"overlaboring":"overlabor",
"overlapped":"overlap",
"overlapping":"overlap",
"overlaps":"overlap",
"overlappings":"overlapping",
"overlaid":"overlay",
"overlaying":"overlay",
"overlays":"overlay",
"overlayers":"overlayer",
"overleaped":"overleap",
"overleaping":"overleap",
"overleapt":"overleap",
"overlain":"overlie",
"overlay":"overlie",
"overlies":"overlie",
"overlying":"overlie",
"overlighted":"overlight",
"overlighting":"overlight",
"overlit":"overlight",
"overloaded":"overload",
"overloading":"overload",
"overloads":"overload",
"overlooked":"overlook",
"overlooking":"overlook",
"overlooks":"overlook",
"overlords":"overlord",
"overmanned":"overman",
"overmanning":"overman",
"overmans":"overman",
"overmen":"overman",
"overmastered":"overmaster",
"overmastering":"overmaster",
"overmasters":"overmaster",
"overmatched":"overmatch",
"overmatching":"overmatch",
"overmuches":"overmuch",
"overmuchnesses":"overmuchness",
"overnighters":"overnighter",
"overpassed":"overpass",
"overpasses":"overpass",
"overpassing":"overpass",
"overpast":"overpass",
"overpaid":"overpay",
"overpaying":"overpay",
"overpays":"overpay",
"overpeopled":"overpeople",
"overpeopling":"overpeople",
"overpersuaded":"overpersuade",
"overpersuading":"overpersuade",
"overplayed":"overplay",
"overplaying":"overplay",
"overplays":"overplay",
"overpluses":"overplus",
"overpopulations":"overpopulation",
"overpowered":"overpower",
"overpowering":"overpower",
"overpowers":"overpower",
"overpraised":"overpraise",
"overpraising":"overpraise",
"overpriced":"overprice",
"overpricing":"overprice",
"overpinted":"overprint",
"overprinted":"overprint",
"overprinting":"overprint",
"overprints":"overprint",
"overprized":"overprize",
"overprizing":"overprize",
"overproduced":"overproduce",
"overproducing":"overproduce",
"overproductions":"overproduction",
"overprotections":"overprotection",
"overrated":"overrate",
"overrates":"overrate",
"overrating":"overrate",
"overratings":"overrating",
"overreached":"overreach",
"overreaches":"overreach",
"overreaching":"overreach",
"overreacted":"overreact",
"overreacting":"overreact",
"overreckonings":"overreckoning",
"overrefined":"overrefine",
"overrefining":"overrefine",
"overrefinements":"overrefinement",
"overridden":"override",
"overrides":"override",
"overriding":"override",
"overrode":"override",
"overroasted":"overroast",
"overroasting":"overroast",
"overruled":"overrule",
"overrules":"overrule",
"overruling":"overrule",
"overran":"overrun",
"overrunning":"overrun",
"overruns":"overrun",
"oversaw":"oversee",
"overseeing":"oversee",
"overseen":"oversee",
"oversees":"oversee",
"overseers":"overseer",
"overselling":"oversell",
"oversells":"oversell",
"oversold":"oversell",
"oversets":"overset",
"oversetting":"overset",
"oversewed":"oversew",
"oversewing":"oversew",
"oversewn":"oversew",
"oversews":"oversew",
"overshadowed":"overshadow",
"overshadowing":"overshadow",
"overshadows":"overshadow",
"overshieldings":"overshielding",
"overshooting":"overshoot",
"overshoots":"overshoot",
"overshot":"overshoot",
"oversights":"oversight",
"oversimplified":"oversimplify",
"oversimplifies":"oversimplify",
"oversimplifying":"oversimplify",
"overslaughed":"overslaugh",
"overslaughing":"overslaugh",
"oversleeping":"oversleep",
"oversleeps":"oversleep",
"overslept":"oversleep",
"overspending":"overspend",
"overspends":"overspend",
"overspent":"overspend",
"overspills":"overspill",
"overspreading":"overspread",
"overspreads":"overspread",
"overstated":"overstate",
"overstates":"overstate",
"overstating":"overstate",
"overstatements":"overstatement",
"overstayed":"overstay",
"overstaying":"overstay",
"overstays":"overstay",
"overstepped":"overstep",
"overstepping":"overstep",
"oversteps":"overstep",
"overstocked":"overstock",
"overstocking":"overstock",
"overstrained":"overstrain",
"overstraining":"overstrain",
"overstrains":"overstrain",
"overstretched":"overstretch",
"overstretches":"overstretch",
"overstretching":"overstretch",
"overstridden":"overstride",
"overstriding":"overstride",
"overstrode":"overstride",
"overstudied":"overstudy",
"overstudying":"overstudy",
"overstuffed":"overstuff",
"overstuffing":"overstuff",
"oversubscribed":"oversubscribe",
"oversubscribing":"oversubscribe",
"oversupplied":"oversupply",
"oversupplies":"oversupply",
"oversupplying":"oversupply",
"overtaken":"overtake",
"overtakes":"overtake",
"overtaking":"overtake",
"overtook":"overtake",
"overtakings":"overtaking",
"overtasked":"overtask",
"overtasking":"overtask",
"overtaxed":"overtax",
"overtaxing":"overtax",
"overthrew":"overthrow",
"overthrowing":"overthrow",
"overthrown":"overthrow",
"overthrows":"overthrow",
"overtimes":"overtime",
"overtired":"overtire",
"overtires":"overtire",
"overtiring":"overtire",
"overtones":"overtone",
"overtopped":"overtop",
"overtopping":"overtop",
"overtops":"overtop",
"overtraded":"overtrade",
"overtrading":"overtrade",
"overtrained":"overtrain",
"overtraining":"overtrain",
"overtrumped":"overtrump",
"overtrumping":"overtrump",
"overtures":"overture",
"overturned":"overturn",
"overturning":"overturn",
"overturns":"overturn",
"overturnings":"overturning",
"overused":"overuse",
"overuses":"overuse",
"overusing":"overuse",
"overutilisations":"overutilisation",
"overutilizations":"overutilization",
"overvaluations":"overvaluation",
"overvalued":"overvalue",
"overvalues":"overvalue",
"overvaluing":"overvalue",
"overwatched":"overwatch",
"overwatching":"overwatch",
"overwearing":"overwear",
"overwore":"overwear",
"overworn":"overwear",
"overwearied":"overweary",
"overwearies":"overweary",
"overwearying":"overweary",
"overweighed":"overweigh",
"overweighing":"overweigh",
"overweighted":"overweight",
"overweighting":"overweight",
"overweights":"overweight",
"overwhelmed":"overwhelm",
"overwhelming":"overwhelm",
"overwhelms":"overwhelm",
"overwinding":"overwind",
"overwinds":"overwind",
"overwound":"overwind",
"overwintered":"overwinter",
"overwintering":"overwinter",
"overworked":"overwork",
"overworking":"overwork",
"overworks":"overwork",
"overwrought":"overwork",
"overworkings":"overworking",
"overwrites":"overwrite",
"overwriting":"overwrite",
"overwritten":"overwrite",
"overwrote":"overwrite",
"oviboses":"ovibos",
"oviducts":"oviduct",
"oviposited":"oviposit",
"oviposting":"oviposit",
"ovises":"ovis",
"ovoflavins":"ovoflavin",
"ovoli":"ovolo",
"ovotestes":"ovotestis",
"ovulated":"ovulate",
"ovulating":"ovulate",
"ova":"ovum",
"owed":"owe",
"owing":"owe",
"owelties":"owelty",
"owls":"owl",
"owlclawses":"owlclaws",
"owlts":"owlt",
"owned":"own",
"owning":"own",
"owns":"own",
"owners":"owner",
"ownerships":"ownership",
"oxen":"ox",
"oxalacetates":"oxalacetate",
"oxalidaceaes":"oxalidaceae",
"oxalises":"oxalis",
"oxaloacetates":"oxaloacetate",
"oxandras":"oxandra",
"oxaprozins":"oxaprozin",
"oxazepams":"oxazepam",
"oxens":"oxen",
"oxeyes":"oxeye",
"oxfords":"oxford",
"oxhearts":"oxheart",
"oxidants":"oxidant",
"oxidations":"oxidation",
"oxidation-reductions":"oxidation-reduction",
"oxides":"oxide",
"oxidisations":"oxidisation",
"oxidizations":"oxidization",
"oxidized":"oxidize",
"oxidizes":"oxidize",
"oxidizing":"oxidize",
"oxidizers":"oxidizer",
"oxlips":"oxlip",
"oxtongues":"oxtongue",
"oxyacids":"oxyacid",
"oxybelises":"oxybelis",
"oxybenzenes":"oxybenzene",
"oxycephalies":"oxycephaly",
"oxydendrums":"oxydendrum",
"oxygens":"oxygen",
"oxygenated":"oxygenate",
"oxygenates":"oxygenate",
"oxygenating":"oxygenate",
"oxylebiuses":"oxylebius",
"oxymomora":"oxymoron",
"oxymora":"oxymoron",
"oxyphenbutazones":"oxyphenbutazone",
"oxytetracyclines":"oxytetracycline",
"oxytropises":"oxytropis",
"oxyuras":"oxyura",
"oxyuranuses":"oxyuranus",
"oxyuridaes":"oxyuridae",
"oysters":"oyster",
"oystercatchers":"oystercatcher",
"oysterfishes":"oysterfish",
"oystermen":"oysterman",
"ozarkses":"ozarks",
"ozocerites":"ozocerite",
"ozokerites":"ozokerite",
"ozoniums":"ozonium",
"ozothamnuses":"ozothamnus",
"ps":"p",
"pas":"pa",
"pabas":"paba",
"pabirs":"pabir",
"pablums":"pablum",
"pabulums":"pabulum",
"pacs":"pac",
"pacas":"paca",
"paced":"pace",
"paces":"pace",
"pacing":"pace",
"pacemakers":"pacemaker",
"pacers":"pacer",
"pacesetters":"pacesetter",
"pachas":"pacha",
"pachoulis":"pachouli",
"pachucos":"pachuco",
"pachycephalas":"pachycephala",
"pachycephalosaurs":"pachycephalosaur",
"pachycephalosauruses":"pachycephalosaurus",
"pachydermas":"pachyderma",
"pachyrhizuses":"pachyrhizus",
"pachysandras":"pachysandra",
"pacifics":"pacific",
"pacifications":"pacification",
"pacificists":"pacificist",
"pacifiers":"pacifier",
"pacifisms":"pacifism",
"pacifists":"pacifist",
"pacified":"pacify",
"pacifies":"pacify",
"pacifying":"pacify",
"pacings":"pacing",
"packed":"pack",
"packing":"pack",
"packs":"pack",
"packaged":"package",
"packages":"package",
"packaging":"package",
"packers":"packer",
"packeras":"packera",
"packeted":"packet",
"packeting":"packet",
"packets":"packet",
"packings":"packing",
"packinghouses":"packinghouse",
"packmen":"packman",
"packrats":"packrat",
"pacts":"pact",
"padded":"pad",
"padding":"pad",
"pads":"pad",
"padauks":"padauk",
"paddas":"padda",
"paddings":"padding",
"paddled":"paddle",
"paddles":"paddle",
"paddling":"paddle",
"paddle-wheelers":"paddle-wheeler",
"paddlefishes":"paddlefish",
"paddlers":"paddler",
"paddlewheels":"paddlewheel",
"paddocked":"paddock",
"paddocking":"paddock",
"paddocks":"paddock",
"paddies":"paddy",
"paddymelons":"paddymelon",
"pademelons":"pademelon",
"padlocked":"padlock",
"padlocking":"padlock",
"padouks":"padouk",
"padovas":"padova",
"padres":"padre",
"padri":"padre",
"padrones":"padrone",
"padroni":"padrone",
"paduas":"padua",
"paeans":"paean",
"paederasts":"paederast",
"paederasties":"paederasty",
"paediatricians":"paediatrician",
"paediatricses":"paediatrics",
"paellas":"paella",
"paeonias":"paeonia",
"paeoniaceaes":"paeoniaceae",
"paeonies":"paeony",
"pagans":"pagan",
"paganisms":"paganism",
"paged":"page",
"pages":"page",
"paging":"page",
"pageants":"pageant",
"pageantries":"pageantry",
"pageboys":"pageboy",
"pagelluses":"pagellus",
"paginated":"paginate",
"paginates":"paginate",
"paginating":"paginate",
"paginations":"pagination",
"pagodas":"pagoda",
"pagophilas":"pagophila",
"pagophiluses":"pagophilus",
"pagruses":"pagrus",
"paguridaes":"paguridae",
"paguruses":"pagurus",
"pahauteas":"pahautea",
"paigles":"paigle",
"pails":"pail",
"pailfuls":"pailful",
"paillasses":"paillasse",
"pained":"pain",
"paining":"pain",
"pains":"pain",
"painfulnesses":"painfulness",
"painkillers":"painkiller",
"painses":"pains",
"painstakingnesses":"painstakingness",
"painted":"paint",
"painting":"paint",
"paints":"paint",
"painters":"painter",
"paintings":"painting",
"paintier":"painty",
"paintiest":"painty",
"paired":"pair",
"pairing":"pair",
"pairs":"pair",
"pairings":"pairing",
"paisas":"paisa",
"paise":"paisa",
"paisan":"paisano",
"paisanos":"paisano",
"paiutes":"paiute",
"pajamas":"pajama",
"pajamases":"pajamas",
"pakchois":"pakchoi",
"pakistans":"pakistan",
"palled":"pal,pall",
"palling":"pal",
"pals":"pal",
"palaces":"palace",
"paladins":"paladin",
"palaemons":"palaemon",
"palaemonidaes":"palaemonidae",
"palaeobiologies":"palaeobiology",
"palaeobotanies":"palaeobotany",
"palaeoclimatologies":"palaeoclimatology",
"palaeodendrologies":"palaeodendrology",
"palaeoencephalons":"palaeoencephalon",
"palaeoethnographies":"palaeoethnography",
"palaeogeographies":"palaeogeography",
"palaeogeologies":"palaeogeology",
"palaeologies":"palaeology",
"palaeontologists":"palaeontologist",
"palaeontologies":"palaeontology",
"palaeopathologies":"palaeopathology",
"palaeornithologies":"palaeornithology",
"palaeozoologies":"palaeozoology",
"palaestras":"palaestra",
"palaetiologies":"palaetiology",
"palanquins":"palanquin",
"palaquiums":"palaquium",
"palases":"palas",
"palatabilities":"palatability",
"palatablenesses":"palatableness",
"palatalized":"palatalize",
"palatalizes":"palatalize",
"palatalizing":"palatalize",
"palates":"palate",
"palatinates":"palatinate",
"palatines":"palatine",
"palavered":"palaver",
"palavering":"palaver",
"palavers":"palaver",
"paled":"pale",
"paler":"pale",
"pales":"pale",
"palest":"pale",
"paling":"pale",
"paleae":"palea",
"paleacritas":"paleacrita",
"paleencephalons":"paleencephalon",
"palenesses":"paleness",
"paleoanthropologies":"paleoanthropology",
"paleobiologies":"paleobiology",
"paleobotanies":"paleobotany",
"paleocenes":"paleocene",
"paleoclimatologies":"paleoclimatology",
"paleocortexes":"paleocortex",
"paleodendrologies":"paleodendrology",
"paleoencephalons":"paleoencephalon",
"paleoethnographies":"paleoethnography",
"paleogeographies":"paleogeography",
"paleogeologies":"paleogeology",
"paleologies":"paleology",
"paleontologists":"paleontologist",
"paleontologies":"paleontology",
"paleopathologies":"paleopathology",
"paleornithologies":"paleornithology",
"paleozoics":"paleozoic",
"paleozoologies":"paleozoology",
"palestines":"palestine",
"palestrae":"palestra",
"palestras":"palestra",
"paletiologies":"paletiology",
"palettes":"palette",
"palfreys":"palfrey",
"palings":"paling",
"palingeneses":"palingenesis",
"palinuridaes":"palinuridae",
"palinuruses":"palinurus",
"palisaded":"palisade",
"palisades":"palisade",
"palisading":"palisade",
"paliuruses":"paliurus",
"palls":"pall",
"palladiums":"palladium",
"pallases":"pallas",
"pallbearers":"pallbearer",
"pallets":"pallet",
"pallettes":"pallette",
"palliasses":"palliasse",
"palliated":"palliate",
"palliates":"palliate",
"palliating":"palliate",
"palliations":"palliation",
"pallidnesses":"pallidness",
"pallia":"pallium",
"palliums":"pallium",
"pallors":"pallor",
"pallier":"pally",
"palliest":"pally",
"palmed":"palm",
"palming":"palm",
"palms":"palm",
"palmaceaes":"palmaceae",
"palmaes":"palmae",
"palmaleses":"palmales",
"palmers":"palmer",
"palmettoes":"palmetto",
"palmettos":"palmetto",
"palmists":"palmist",
"palmistries":"palmistry",
"palmier":"palmy",
"palmiest":"palmy",
"palmyras":"palmyra",
"palometas":"palometa",
"palominos":"palomino",
"palookas":"palooka",
"palps":"palp",
"palpabilities":"palpability",
"palpated":"palpate",
"palpates":"palpate",
"palpating":"palpate",
"palpations":"palpation",
"palpitated":"palpitate",
"palpitates":"palpitate",
"palpitating":"palpitate",
"palpitations":"palpitation",
"palpi":"palpus",
"palsgraves":"palsgrave",
"palsied":"palsy",
"palsies":"palsy",
"palsying":"palsy",
"paltered":"palter",
"paltering":"palter",
"palters":"palter",
"palterings":"paltering",
"paltrinesses":"paltriness",
"paltrier":"paltry",
"paltriest":"paltry",
"pampered":"pamper",
"pampering":"pamper",
"pampers":"pamper",
"pamperings":"pampering",
"pamperos":"pampero",
"pamphlets":"pamphlet",
"pamphleteered":"pamphleteer",
"pamphleteering":"pamphleteer",
"panned":"pan",
"panning":"pan",
"pans":"pan",
"pan-broiled":"pan-broil",
"pan-broiling":"pan-broil",
"panfried":"panfry",
"panfrying":"panfry",
"panaceas":"panacea",
"panaches":"panache",
"panadols":"panadol",
"panamas":"panama",
"panamicas":"panamica",
"panamigas":"panamiga",
"panatelas":"panatela",
"panaxes":"panax",
"pancaked":"pancake",
"pancakes":"pancake",
"pancaking":"pancake",
"pancratia":"pancratium",
"pandas":"panda",
"pandanaceaes":"pandanaceae",
"pandanaleses":"pandanales",
"pandanuses":"pandanus",
"pandars":"pandar",
"pandemoniums":"pandemonium",
"pandered":"pander",
"pandering":"pander",
"panders":"pander",
"panderers":"panderer",
"pandions":"pandion",
"pandionidaes":"pandionidae",
"pandoras":"pandora",
"pandores":"pandora",
"pandowdies":"pandowdy",
"pandied":"pandy",
"pandies":"pandy",
"pandying":"pandy",
"paned":"pane",
"panes":"pane",
"paning":"pane",
"panegyrics":"panegyric",
"panegyrists":"panegyrist",
"panegyrized":"panegyrize",
"panegyrizing":"panegyrize",
"paneled":"panel",
"paneling":"panel",
"panelled":"panel",
"panelling":"panel",
"panels":"panel",
"panelings":"paneling",
"panelists":"panelist",
"panellings":"panelling",
"panetelas":"panetela",
"panetellas":"panetella",
"panettones":"panettone",
"panettoni":"panettone",
"panged":"pang",
"panging":"pang",
"pangs":"pang",
"pangas":"panga",
"pangaeas":"pangaea",
"pangeas":"pangea",
"pangolins":"pangolin",
"panhandled":"panhandle",
"panhandling":"panhandle",
"panhysterectomies":"panhysterectomy",
"panicked":"panic",
"panicking":"panic",
"panics":"panic",
"panicums":"panicum",
"panipats":"panipat",
"panjabis":"panjabi",
"panjandrums":"panjandrum",
"panniers":"pannier",
"panofskies":"panofsky",
"panonychuses":"panonychus",
"panoplies":"panoply",
"panoramas":"panorama",
"panpipes":"panpipe",
"pansies":"pansy",
"panted":"pant",
"panting":"pant",
"pants":"pant",
"pantaloons":"pantaloon",
"pantheisms":"pantheism",
"panthers":"panther",
"pantheras":"panthera",
"panties":"pantie",
"pantings":"panting",
"pantos":"panto",
"pantomimed":"pantomime",
"pantomimes":"pantomime",
"pantomiming":"pantomime",
"pantomimers":"pantomimer",
"pantomimists":"pantomimist",
"pantothens":"pantothen",
"pantotherias":"pantotheria",
"pantries":"pantry",
"pantrymen":"pantryman",
"pantywaists":"pantywaist",
"paps":"pap",
"papas":"papa",
"papacies":"papacy",
"papaias":"papaia",
"paparazzi":"paparazzo",
"papavers":"papaver",
"papaveraceaes":"papaveraceae",
"papaveraleses":"papaverales",
"papaws":"papaw",
"papayas":"papaya",
"papered":"paper",
"papering":"paper",
"papers":"paper",
"paperbacks":"paperback",
"paperboards":"paperboard",
"paperclips":"paperclip",
"paperers":"paperer",
"paperhangers":"paperhanger",
"paperhangings":"paperhanging",
"paperings":"papering",
"paperknives":"paperknife",
"paperses":"papers",
"papeteries":"papeterie",
"paphiopedilums":"paphiopedilum",
"papilionaceaes":"papilionaceae",
"papilionoideaes":"papilionoideae",
"papillae":"papilla",
"papillomas":"papilloma",
"papillomata":"papilloma",
"papillons":"papillon",
"papios":"papio",
"papooses":"papoose",
"papooseroots":"papooseroot",
"pappas":"pappa",
"pappooses":"pappoose",
"pappi":"pappus",
"pappier":"pappy",
"pappies":"pappy",
"pappiest":"pappy",
"paprikas":"paprika",
"papriluses":"paprilus",
"papuas":"papua",
"papuans":"papuan",
"papulae":"papula",
"papules":"papule",
"papyri":"papyrus",
"papyruses":"papyrus",
"pars":"par",
"paras":"para",
"parabases":"parabasis",
"parables":"parable",
"parabolas":"parabola",
"parabolized":"parabolize",
"parabolizing":"parabolize",
"paracenteses":"paracentesis",
"paracheirodons":"paracheirodon",
"parachuted":"parachute",
"parachutes":"parachute",
"parachuting":"parachute",
"parachuters":"parachuter",
"parachutings":"parachuting",
"parachutists":"parachutist",
"paraded":"parade",
"parades":"parade",
"parading":"parade",
"paraders":"parader",
"paradiddles":"paradiddle",
"paradigms":"paradigm",
"paradisaeidaes":"paradisaeidae",
"paradises":"paradise",
"paradoxes":"paradox",
"paradoxuruses":"paradoxurus",
"paradropped":"paradrop",
"paradropping":"paradrop",
"paraesthesias":"paraesthesia",
"paraffined":"paraffin",
"paraffining":"paraffin",
"paraffins":"paraffin",
"paragons":"paragon",
"paragraphed":"paragraph",
"paragraphing":"paragraph",
"paragraphs":"paragraph",
"parakeets":"parakeet",
"paralanguages":"paralanguage",
"paralegals":"paralegal",
"paraleipses":"paraleipsis",
"paralepses":"paralepsis",
"paralichthyses":"paralichthys",
"paralipses":"paralipsis",
"paralithodeses":"paralithodes",
"paralleled":"parallel",
"paralleling":"parallel",
"parallelled":"parallel",
"parallelling":"parallel",
"parallels":"parallel",
"parallelepipeds":"parallelepiped",
"parallelepipedons":"parallelepipedon",
"parallelisms":"parallelism",
"parallelopipeds":"parallelopiped",
"parallelopipedons":"parallelopipedon",
"paralyses":"paralysis",
"paralyzed":"paralyze",
"paralyzes":"paralyze",
"paralyzing":"paralyze",
"paramaribos":"paramaribo",
"paramecias":"paramecia",
"paramecia":"paramecium",
"parameciums":"paramecium",
"paramenta":"parament",
"paraments":"parament",
"parameters":"parameter",
"paramilitaries":"paramilitary",
"paramos":"paramo",
"paramounts":"paramount",
"paramours":"paramour",
"paramyxoviruses":"paramyxovirus",
"paranas":"parana",
"paranoiacs":"paranoiac",
"paranoids":"paranoid",
"paranthiases":"paranthias",
"paranthropuses":"paranthropus",
"parapets":"parapet",
"paraphernalias":"paraphernalia",
"paraphrased":"paraphrase",
"paraphrases":"paraphrase",
"paraphrasing":"paraphrase",
"paraphrenias":"paraphrenia",
"paraphyses":"paraphysis",
"parapodia":"parapodium",
"parapsychologies":"parapsychology",
"paraquets":"paraquet",
"parascalopses":"parascalops",
"paraselenae":"paraselene",
"parashoth":"parashah",
"parasitaxuses":"parasitaxus",
"parasites":"parasite",
"parasitized":"parasitize",
"parasitizing":"parasitize",
"parasols":"parasol",
"parastichies":"parastichy",
"parasympathetics":"parasympathetic",
"parasyntheta":"parasyntheton",
"parathelypterises":"parathelypteris",
"parathyroids":"parathyroid",
"paratroopers":"paratrooper",
"paratyphoids":"paratyphoid",
"parazoas":"parazoa",
"parazoans":"parazoan",
"parboiled":"parboil",
"parboiling":"parboil",
"parboils":"parboil",
"parbuckled":"parbuckle",
"parbuckling":"parbuckle",
"parceled":"parcel",
"parceling":"parcel",
"parcelled":"parcel",
"parcelling":"parcel",
"parcels":"parcel",
"parcelings":"parceling",
"parcellings":"parcelling",
"parched":"parch",
"parches":"parch",
"parching":"parch",
"parchments":"parchment",
"pardners":"pardner",
"pardoned":"pardon",
"pardoning":"pardon",
"pardons":"pardon",
"pared":"pare",
"pares":"pare",
"paring":"pare",
"paregorics":"paregoric",
"parented":"parent",
"parenting":"parent",
"parents":"parent",
"patents-in-law":"parent-in-law",
"parentages":"parentage",
"parentheses":"parenthesis",
"parenthesized":"parenthesize",
"parenthesizes":"parenthesize",
"parenthesizing":"parenthesize",
"parers":"parer",
"parerga":"parergon",
"paresthesias":"paresthesia",
"pareus":"pareu",
"pargeted":"parget",
"pargeting":"parget",
"pargets":"parget",
"pargetted":"parget",
"pargetting":"parget",
"pargetings":"pargeting",
"parhelia":"parhelion",
"parhelions":"parhelion",
"pari-mutuels":"pari-mutuel",
"paris-mutuels":"pari-mutuel",
"pariahs":"pariah",
"paridaes":"paridae",
"parieses":"paries",
"parietaleses":"parietales",
"parietarias":"parietaria",
"parings":"paring",
"paringses":"parings",
"parises":"paris",
"parishes":"parish",
"parities":"parity",
"parked":"park",
"parking":"park",
"parks":"park",
"parkas":"parka",
"parkeriaceaes":"parkeriaceae",
"parkias":"parkia",
"parkinglots":"parkinglot",
"parkinsons":"parkinson",
"parkinsonias":"parkinsonia",
"parkinsonisms":"parkinsonism",
"parkways":"parkway",
"parkier":"parky",
"parkiest":"parky",
"parlances":"parlance",
"parlayed":"parlay",
"parlaying":"parlay",
"parlays":"parlay",
"parleyed":"parley",
"parleying":"parley",
"parleys":"parley",
"parliaments":"parliament",
"parliamentarians":"parliamentarian",
"parlors":"parlor",
"parlormaids":"parlormaid",
"parlours":"parlour",
"parlourmaids":"parlourmaid",
"parmelias":"parmelia",
"parmeliaceaes":"parmeliaceae",
"parnassias":"parnassia",
"parnassuses":"parnassus",
"parochetuses":"parochetus",
"parodists":"parodist",
"parodied":"parody",
"parodies":"parody",
"parodying":"parody",
"paroled":"parole",
"paroles":"parole",
"paroling":"parole",
"parolees":"parolee",
"paronomasias":"paronomasia",
"paronychias":"paronychia",
"parophryses":"parophrys",
"paroquets":"paroquet",
"paroxysms":"paroxysm",
"pardqueted":"parquet",
"parqueted":"parquet",
"parqueting":"parquet",
"parquets":"parquet",
"parqueteries":"parqueterie",
"parquetries":"parquetry",
"parrs":"parr",
"parrakeets":"parrakeet",
"parrokets":"parroket",
"parroquets":"parroquet",
"parroted":"parrot",
"parroting":"parrot",
"parrots":"parrot",
"parrotfishes":"parrotfish",
"parrotias":"parrotia",
"parrotiopses":"parrotiopsis",
"parried":"parry",
"parries":"parry",
"parrying":"parry",
"parsed":"parse",
"parsing":"parse",
"parsecs":"parsec",
"parsees":"parsee",
"parseeisms":"parseeism",
"parsis":"parsi",
"parsiisms":"parsiism",
"parsimoniousnesses":"parsimoniousness",
"parsimonies":"parsimony",
"parsleys":"parsley",
"parsnips":"parsnip",
"parsons":"parson",
"parsonages":"parsonage",
"parted":"part",
"parting":"part",
"parts":"part",
"partaken":"partake",
"partakes":"partake",
"partaking":"partake",
"partook":"partake",
"partakers":"partaker",
"parterres":"parterre",
"partheniums":"parthenium",
"parthenocissuses":"parthenocissus",
"parthenogeneses":"parthenogenesis",
"parthenogenies":"parthenogeny",
"partialities":"partiality",
"participants":"participant",
"participated":"participate",
"participates":"participate",
"participating":"participate",
"participations":"participation",
"participles":"participle",
"particles":"particle",
"particulars":"particular",
"particularities":"particularity",
"particularizations":"particularization",
"particularized":"particularize",
"particularizes":"particularize",
"particularizing":"particularize",
"partings":"parting",
"partisans":"partisan",
"partisanships":"partisanship",
"partitas":"partita",
"partitioned":"partition",
"partitioning":"partition",
"partitions":"partition",
"partitionings":"partitioning",
"partizans":"partizan",
"partnered":"partner",
"partnering":"partner",
"partners":"partner",
"partnerships":"partnership",
"partridges":"partridge",
"partridgeberries":"partridgeberry",
"parturiencies":"parturiency",
"parturitions":"parturition",
"parties":"party",
"parulas":"parula",
"parulidaes":"parulidae",
"parulides":"parulis",
"paruses":"parus",
"parvatis":"parvati",
"parvenus":"parvenu",
"parvos":"parvo",
"parvoviruses":"parvovirus",
"pas-de-calaises":"pas-de-calais",
"pasangs":"pasang",
"pascals":"pascal",
"pasches":"pasch",
"paschas":"pascha",
"pases":"pase",
"paseos":"paseo",
"pashas":"pasha",
"pashtos":"pashto",
"pasos_dobles":"paso_doble",
"paso_dobles":"paso_doble",
"paspalums":"paspalum",
"pasqueflowers":"pasqueflower",
"pasquinaded":"pasquinade",
"pasquinades":"pasquinade",
"pasquinading":"pasquinade",
"pasquinased":"pasquinade",
"passed":"pass",
"passes":"pass",
"passing":"pass",
"passacaglias":"passacaglia",
"passadoes":"passado",
"passados":"passado",
"passaged":"passage",
"passages":"passage",
"passaging":"passage",
"passageways":"passageway",
"passbooks":"passbook",
"passe-partouts":"passe-partout",
"passementeries":"passementerie",
"passengers":"passenger",
"passepieds":"passepied",
"passers":"passer",
"passers-by":"passer-by",
"passersby":"passerby",
"passereses":"passeres",
"passeridaes":"passeridae",
"passeriformeses":"passeriformes",
"passerinas":"passerina",
"passerines":"passerine",
"passeros":"passero",
"passifloras":"passiflora",
"passifloraceaes":"passifloraceae",
"passings":"passing",
"passions":"passion",
"passionatenesses":"passionateness",
"passionflowers":"passionflower",
"passivated":"passivate",
"passivating":"passivate",
"passives":"passive",
"passivenesses":"passiveness",
"passivisms":"passivism",
"passivities":"passivity",
"passkeys":"passkey",
"passovers":"passover",
"passports":"passport",
"passuses":"passus",
"passwords":"password",
"pasts":"past",
"pastas":"pasta",
"pasted":"paste",
"pastes":"paste",
"pasting":"paste",
"pastels":"pastel",
"pasterns":"pastern",
"pasteurs":"pasteur",
"pasteurelloses":"pasteurellosis",
"pasteurized":"pasteurize",
"pasteurizing":"pasteurize",
"pasticci":"pasticcio",
"pastiches":"pastiche",
"pastils":"pastil",
"pastilles":"pastille",
"pastimes":"pastime",
"pastinacas":"pastinaca",
"pastos":"pasto",
"pastors":"pastor",
"postored":"pastor",
"postoring":"pastor",
"pastorals":"pastoral",
"pastorales":"pastorale",
"pastorali":"pastorale",
"pastorates":"pastorate",
"pastoriums":"pastorium",
"pastorships":"pastorship",
"pastries":"pastry",
"pasturages":"pasturage",
"pastured":"pasture",
"pastures":"pasture",
"pasturing":"pasture",
"pasturelands":"pastureland",
"pastier":"pasty",
"pasties":"pasty",
"pastiest":"pasty",
"pats":"pat",
"patted":"pat",
"patting":"pat",
"patagia":"patagium",
"patases":"patas",
"pataviums":"patavium",
"patched":"patch",
"patches":"patch",
"patching":"patch",
"patchboards":"patchboard",
"patchoulis":"patchouli",
"patchoulies":"patchouly",
"patchworks":"patchwork",
"patchier":"patchy",
"patchiest":"patchy",
"pates":"pate",
"patellae":"patella",
"patellas":"patella",
"patellidaes":"patellidae",
"patented":"patent",
"patenting":"patent",
"patents":"patent",
"paters":"pater",
"paterfamiliases":"paterfamilias",
"patresfamilias":"paterfamilias",
"paternities":"paternity",
"paths":"path",
"pathans":"pathan",
"pathfinders":"pathfinder",
"pathologists":"pathologist",
"pathologies":"pathology",
"pathoses":"pathos",
"pathways":"pathway",
"patiences":"patience",
"patients":"patient",
"patinas":"patina",
"patinated":"patinate",
"patinates":"patinate",
"patinating":"patinate",
"patios":"patio",
"patnesses":"patness",
"patoises":"patois",
"patriarches":"patriarch",
"patriarchs":"patriarch",
"patriarchates":"patriarchate",
"patriarchies":"patriarchy",
"patricians":"patrician",
"patricks":"patrick",
"patrikins":"patrikin",
"patrilineages":"patrilineage",
"patrimonies":"patrimony",
"patriots":"patriot",
"patriotisms":"patriotism",
"patrisibs":"patrisib",
"patrolled":"patrol",
"patrolling":"patrol",
"patrols":"patrol",
"patrollings":"patrolling",
"patrolmen":"patrolman",
"patrolwomen":"patrolwoman",
"patrons":"patron",
"patronages":"patronage",
"patronized":"patronize",
"patronizes":"patronize",
"patronizing":"patronize",
"patronnes":"patronne",
"patsies":"patsy",
"pattens":"patten",
"pattered":"patter",
"pattering":"patter",
"patters":"patter",
"patterned":"pattern",
"patterning":"pattern",
"patterns":"pattern",
"patties":"patty",
"paucities":"paucity",
"pauls":"paul",
"paulownias":"paulownia",
"paunches":"paunch",
"paunchinesses":"paunchiness",
"paunchier":"paunchy",
"paunchiest":"paunchy",
"paupers":"pauper",
"pauperisms":"pauperism",
"pauperizations":"pauperization",
"pauperized":"pauperize",
"pauperizes":"pauperize",
"pauperizing":"pauperize",
"pauropodas":"pauropoda",
"paused":"pause",
"pauses":"pause",
"pausing":"pause",
"paved":"pave",
"paving":"pave",
"pavements":"pavement",
"pavilioned":"pavilion",
"pavilioning":"pavilion",
"pavilions":"pavilion",
"pavings":"paving",
"paviors":"pavior",
"paviours":"paviour",
"pavises":"pavis",
"pavlovs":"pavlov",
"pavos":"pavo",
"pawed":"paw",
"pawing":"paw",
"paws":"paw",
"pawkier":"pawky",
"pawkiest":"pawky",
"pawls":"pawl",
"pawned":"pawn",
"pawning":"pawn",
"pawns":"pawn",
"pawnees":"pawnee",
"pawnings":"pawning",
"pawnshops":"pawnshop",
"pawpaws":"pawpaw",
"paxes":"pax",
"paxtos":"paxto",
"paid":"pay",
"paying":"pay",
"pays":"pay",
"pay-phones":"pay-phone",
"pay-stations":"pay-station",
"paychecks":"paycheck",
"payes":"paye",
"payenas":"payena",
"payers":"payer",
"paygrades":"paygrade",
"payings":"paying",
"payloads":"payload",
"payments":"payment",
"payoffs":"payoff",
"payrolls":"payroll",
"paysheets":"paysheet",
"pbs":"pb",
"pbses":"pbs",
"PCs":"PC",
"pcps":"pcp",
"pcts":"pct",
"pds":"pd",
"pdls":"pdl",
"pe-tsais":"pe-tsai",
"peas":"pea",
"pea-soupers":"pea-souper",
"peaces":"peace",
"peaceablenesses":"peaceableness",
"peacefulnesses":"peacefulness",
"peacemakers":"peacemaker",
"peaceniks":"peacenik",
"peached":"peach",
"peaches":"peach",
"peaching":"peach",
"peachwoods":"peachwood",
"peachier":"peachy",
"peachiest":"peachy",
"peacoats":"peacoat",
"peacocked":"peacock",
"peacocking":"peacock",
"peacocks":"peacock",
"peafowls":"peafowl",
"peags":"peag",
"peaked":"peak",
"peaking":"peak",
"peaks":"peak",
"pealed":"peal",
"pealing":"peal",
"peals":"peal",
"pealings":"pealing",
"peans":"pean",
"peanuts":"peanut",
"pears":"pear",
"pearled":"pearl",
"pearling":"pearl",
"pearls":"pearl",
"pearlers":"pearler",
"pearlweeds":"pearlweed",
"pearlworts":"pearlwort",
"pearlies":"pearly",
"peasants":"peasant",
"peasen":"pease",
"peases":"pease",
"peasecods":"peasecod",
"peats":"peat",
"peatier":"peaty",
"peatiest":"peaty",
"peaveys":"peavey",
"peavies":"peavy",
"pebas":"peba",
"pebbled":"pebble",
"pebbles":"pebble",
"pebbling":"pebble",
"pecans":"pecan",
"peccadilloes":"peccadillo",
"peccadillos":"peccadillo",
"peccaries":"peccary",
"peccavis":"peccavi",
"pecked":"peck",
"pecking":"peck",
"pecks":"peck",
"peckers":"pecker",
"peckier":"pecky",
"peckiest":"pecky",
"pecoses":"pecos",
"pecses":"pecs",
"pectens":"pecten",
"pectines":"pecten",
"pectinibranchias":"pectinibranchia",
"pectinidaes":"pectinidae",
"pectorals":"pectoral",
"pectoralises":"pectoralis",
"pectuses":"pectus",
"peculated":"peculate",
"peculates":"peculate",
"peculating":"peculate",
"peculations":"peculation",
"peculators":"peculator",
"peculiarities":"peculiarity",
"peculia":"peculium",
"pedagogues":"pedagogue",
"pedagogies":"pedagogy",
"pedaled":"pedal",
"pedaling":"pedal",
"pedalled":"pedal",
"pedalling":"pedal",
"pedals":"pedal",
"pedalers":"pedaler",
"pedaliaceaes":"pedaliaceae",
"pedallers":"pedaller",
"pedaloes":"pedalo",
"pedalos":"pedalo",
"pedants":"pedant",
"pedantries":"pedantry",
"peddled":"peddle",
"peddles":"peddle",
"peddling":"peddle",
"peddlers":"peddler",
"peddlings":"peddling",
"pederasts":"pederast",
"pederasties":"pederasty",
"pedeses":"pedesis",
"pedestaled":"pedestal",
"pedestaling":"pedestal",
"pedestalled":"pedestal",
"pedestalling":"pedestal",
"pedestals":"pedestal",
"pedestrians":"pedestrian",
"pedestrianized":"pedestrianize",
"pedestrianizing":"pedestrianize",
"pediatricians":"pediatrician",
"pediatricses":"pediatrics",
"pediatrists":"pediatrist",
"pedicabs":"pedicab",
"pediculatis":"pediculati",
"pediculidaes":"pediculidae",
"pediculoses":"pediculosis",
"pediculuses":"pediculus",
"pedigrees":"pedigree",
"pedilanthuses":"pedilanthus",
"pediocactuses":"pediocactus",
"pedioeceteses":"pedioecetes",
"pedionomuses":"pedionomus",
"pedipalpis":"pedipalpi",
"pedlars":"pedlar",
"pedwoods":"pedwood",
"peed":"pee",
"peeing":"pee",
"pees":"pee",
"peeings":"peeing",
"peeked":"peek",
"peeking":"peek",
"peeks":"peek",
"peekaboos":"peekaboo",
"peeled":"peel",
"peeling":"peel",
"peels":"peel",
"peelers":"peeler",
"peened":"peen",
"peening":"peen",
"peeped":"peep",
"peeping":"peep",
"peeps":"peep",
"peepers":"peeper",
"peepholes":"peephole",
"peepshows":"peepshow",
"peepuls":"peepul",
"peered":"peer",
"peering":"peer",
"peers":"peer",
"peerages":"peerage",
"peeresses":"peeress",
"peeved":"peeve",
"peeving":"peeve",
"peevishnesses":"peevishness",
"peewees":"peewee",
"peewits":"peewit",
"pegged":"peg",
"pegging":"peg",
"pegs":"peg",
"pegasuses":"pegasus",
"peglegs":"pegleg",
"peignoirs":"peignoir",
"peipings":"peiping",
"peirces":"peirce",
"peireskias":"peireskia",
"pekans":"pekan",
"pekes":"peke",
"pekineses":"pekinese",
"pekings":"peking",
"pekingeses":"pekingese",
"pekoes":"pekoe",
"pels":"pel",
"pelargoniums":"pelargonium",
"pelecanidaes":"pelecanidae",
"pelecaniformeses":"pelecaniformes",
"pelecanoididaes":"pelecanoididae",
"pelecanuses":"pelecanus",
"pelecypods":"pelecypod",
"pelves":"pelvis",
"pelioses":"peliosis",
"pellaeas":"pellaea",
"pelleted":"pellet",
"pelleting":"pellet",
"pellets":"pellet",
"pelletized":"pelletize",
"pelletizing":"pelletize",
"pellicularias":"pellicularia",
"pellitories":"pellitory",
"pellitory-of-spains":"pellitory-of-spain",
"pellitory-of-the-walls":"pellitory-of-the-wall",
"pellucidities":"pellucidity",
"pellucidnesses":"pellucidness",
"pelmets":"pelmet",
"pelobatidaes":"pelobatidae",
"peloponneses":"peloponnese",
"peloponnesuses":"peloponnesus",
"peloruses":"pelorus",
"pelotas":"pelota",
"pelted":"pelt",
"pelting":"pelt",
"pelts":"pelt",
"peltandras":"peltandra",
"peltings":"pelting",
"peltiphyllums":"peltiphyllum",
"peltries":"peltry",
"peludos":"peludo",
"pelvises":"pelvis",
"pelycosaurias":"pelycosauria",
"pembrokes":"pembroke",
"pempheridaes":"pempheridae",
"penned":"pen",
"penning":"pen",
"pens":"pen",
"pen-friends":"pen-friend",
"penalizations":"penalization",
"penalized":"penalize",
"penalizes":"penalize",
"penalizing":"penalize",
"penalties":"penalty",
"penanced":"penance",
"penances":"penance",
"penancing":"penance",
"penchants":"penchant",
"penciled":"pencil",
"penciling":"pencil",
"pencilled":"pencil",
"pencilling":"pencil",
"pencils":"pencil",
"pended":"pend",
"pending":"pend",
"pendants":"pendant",
"pendencies":"pendency",
"pendulums":"pendulum",
"peneidaes":"peneidae",
"penelopes":"penelope",
"penetrabilities":"penetrability",
"penetrated":"penetrate",
"penetrates":"penetrate",
"penetrating":"penetrate",
"penetrations":"penetration",
"peneuses":"peneus",
"penguins":"penguin",
"penicillia":"penicillium",
"penicilliums":"penicillium",
"peninsulas":"peninsula",
"peninsulars":"peninsular",
"penes":"penis",
"penises":"penis",
"penitences":"penitence",
"penitents":"penitent",
"penitentiaries":"penitentiary",
"penknives":"penknife",
"penmen":"penman",
"penmanships":"penmanship",
"pennae":"penna",
"pennants":"pennant",
"pennatulas":"pennatula",
"pennatulidaes":"pennatulidae",
"pennia":"penni",
"pennis":"penni",
"pennilessnesses":"pennilessness",
"pennings":"penning",
"pennisetums":"pennisetum",
"pennons":"pennon",
"pennoncels":"pennoncel",
"pennoncelles":"pennoncelle",
"pennsylvanias":"pennsylvania",
"Pennsylvanians":"Pennsylvanian",
"pence":"penny",
"pennies":"penny",
"penny-dreadfulls":"penny-dreadful",
"penny-pinchings":"penny-pinching",
"pennyroyals":"pennyroyal",
"pennywhistles":"pennywhistle",
"pennyworths":"pennyworth",
"penochas":"penocha",
"penologies":"penology",
"penoncels":"penoncel",
"penpushers":"penpusher",
"pensees":"pensee",
"pensioned":"pension",
"pensioning":"pension",
"pensions":"pension",
"pensionaries":"pensionary",
"pensioners":"pensioner",
"pensivenesses":"pensiveness",
"penstemons":"penstemon",
"penstocks":"penstock",
"pentacles":"pentacle",
"pentads":"pentad",
"pentagrams":"pentagram",
"pentahedra":"pentahedron",
"pentahedrons":"pentahedron",
"pentails":"pentail",
"pentamethylenetetrazols":"pentamethylenetetrazol",
"pentarchies":"pentarchy",
"pentastomids":"pentastomid",
"pentastomidas":"pentastomida",
"pentateuches":"pentateuch",
"pentecosts":"pentecost",
"pentecostals":"pentecostal",
"pentecostalists":"pentecostalist",
"penthouses":"penthouse",
"pentimenti":"pentimento",
"pentobarbitals":"pentobarbital",
"pentothals":"pentothal",
"pentylenetetrazols":"pentylenetetrazol",
"penuches":"penuche",
"penults":"penult",
"penultimas":"penultima",
"penultimates":"penultimate",
"penumbrae":"penumbra",
"penumbras":"penumbra",
"penuriousnesses":"penuriousness",
"penuries":"penury",
"peons":"peon",
"peonies":"peony",
"peopled":"people",
"peoples":"people",
"peopling":"people",
"pepped":"pep",
"pepping":"pep",
"peps":"pep",
"pepcids":"pepcid",
"peploses":"peplos",
"pepla":"peplum",
"peplums":"peplum",
"pepluses":"peplus",
"pepos":"pepo",
"peppered":"pepper",
"peppering":"pepper",
"peppers":"pepper",
"peppercorns":"peppercorn",
"pepperidges":"pepperidge",
"pepperinesses":"pepperiness",
"peppermints":"peppermint",
"peppershakers":"peppershaker",
"pepperwoods":"pepperwood",
"pepperworts":"pepperwort",
"peppinesses":"peppiness",
"peppier":"peppy",
"peppiest":"peppy",
"pepsis":"pepsi",
"peptidases":"peptidase",
"peptizations":"peptization",
"peptized":"peptize",
"peptizing":"peptize",
"peptizings":"peptizing",
"pequots":"pequot",
"perambulated":"perambulate",
"perambulates":"perambulate",
"perambulating":"perambulate",
"perambulations":"perambulation",
"perambulators":"perambulator",
"peramelidaes":"peramelidae",
"percas":"perca",
"perceived":"perceive",
"perceives":"perceive",
"perceiving":"perceive",
"perceivers":"perceiver",
"perceivings":"perceiving",
"percents":"percent",
"percentages":"percentage",
"percepts":"percept",
"perceptions":"perception",
"perceptivenesses":"perceptiveness",
"perceptivities":"perceptivity",
"perched":"perch",
"perches":"perch",
"perching":"perch",
"perchloromethanes":"perchloromethane",
"percidaes":"percidae",
"perciformeses":"perciformes",
"percinas":"percina",
"percoids":"percoid",
"percoideas":"percoidea",
"percoideans":"percoidean",
"percolated":"percolate",
"percolates":"percolate",
"percolating":"percolate",
"percomorphis":"percomorphi",
"percophidaes":"percophidae",
"percussed":"percuss",
"percussing":"percuss",
"percussions":"percussion",
"perdicidaes":"perdicidae",
"perdicinaes":"perdicinae",
"perditions":"perdition",
"perdixes":"perdix",
"perdured":"perdure",
"perduring":"perdure",
"peregrinated":"peregrinate",
"peregrinating":"peregrinate",
"peregrines":"peregrine",
"perennials":"perennial",
"pereskias":"pereskia",
"perfected":"perfect",
"perfecting":"perfect",
"perfects":"perfect",
"perfectas":"perfecta",
"perfectabilities":"perfectability",
"perfectibilities":"perfectibility",
"perfections":"perfection",
"perfectives":"perfective",
"perfectos":"perfecto",
"perfidiousnesses":"perfidiousness",
"perfidies":"perfidy",
"perforated":"perforate",
"perforates":"perforate",
"perforating":"perforate",
"performed":"perform",
"performing":"perform",
"performs":"perform",
"performances":"performance",
"performers":"performer",
"performings":"performing",
"perfumed":"perfume",
"perfumes":"perfume",
"perfuming":"perfume",
"perfumeries":"perfumery",
"perfused":"perfuse",
"perfuses":"perfuse",
"perfusing":"perfuse",
"pergolas":"pergola",
"perhapses":"perhaps",
"peris":"peri",
"periactins":"periactin",
"perianths":"perianth",
"periapses":"periapsis",
"pericallises":"pericallis",
"pericardia":"pericardium",
"pericardidia":"pericardium",
"pericarps":"pericarp",
"perichondria":"perichondrium",
"periclases":"periclase",
"pericrania":"pericranium",
"peridiniidaes":"peridiniidae",
"peridiniums":"peridinium",
"peridridia":"peridium",
"perigons":"perigon",
"perihelia":"perihelion",
"periled":"peril",
"periling":"peril",
"perilled":"peril",
"perilling":"peril",
"perils":"peril",
"perillas":"perilla",
"perilousnesses":"perilousness",
"perilunes":"perilune",
"perimeters":"perimeter",
"perinephria":"perinephrium",
"perinea":"perineum",
"periods":"period",
"periodicals":"periodical",
"periodicities":"periodicity",
"periodontias":"periodontia",
"periodonticses":"periodontics",
"periodontitises":"periodontitis",
"periodontia":"periodontium",
"perionychia":"perionychium",
"perionychiia":"perionychium",
"periophthalmuses":"periophthalmus",
"periostea":"periosteum",
"peripatetics":"peripatetic",
"peripatidaes":"peripatidae",
"peripatopsidaes":"peripatopsidae",
"peripatopses":"peripatopsis",
"peripatuses":"peripatus",
"peripeteias":"peripeteia",
"peripherals":"peripheral",
"peripheries":"periphery",
"periphrases":"periphrasis",
"periplanetas":"periplaneta",
"periplocas":"periploca",
"periselenes":"periselene",
"perished":"perish",
"perishes":"perish",
"perishing":"perish",
"perishables":"perishable",
"perishableses":"perishables",
"perisoreuses":"perisoreus",
"perissodactyls":"perissodactyl",
"perissodactylas":"perissodactyla",
"peristalses":"peristalsis",
"peristediinaes":"peristediinae",
"peristedions":"peristedion",
"perithecia":"perithecium",
"perithecicia":"perithecium",
"peritonea":"peritoneum",
"peritoneums":"peritoneum",
"periwigs":"periwig",
"periwinkles":"periwinkle",
"perjured":"perjure",
"perjuring":"perjure",
"perjurers":"perjurer",
"perjuries":"perjury",
"perked":"perk",
"perking":"perk",
"perks":"perk",
"perkinesses":"perkiness",
"perkier":"perky",
"perkiest":"perky",
"perliches":"perliche",
"perms":"perm",
"permanences":"permanence",
"permanencies":"permanency",
"permanents":"permanent",
"permeabilities":"permeability",
"permeablenesses":"permeableness",
"permeated":"permeate",
"permeates":"permeate",
"permeating":"permeate",
"permeations":"permeation",
"permians":"permian",
"permissions":"permission",
"permissivenesses":"permissiveness",
"permits":"permit",
"permitted":"permit",
"permitting":"permit",
"permittivities":"permittivity",
"permutabilities":"permutability",
"permutablenesses":"permutableness",
"permutations":"permutation",
"permuted":"permute",
"permutes":"permute",
"permuting":"permute",
"pernambucos":"pernambuco",
"perniciousnesses":"perniciousness",
"pernios":"pernio",
"pernises":"pernis",
"perodicticuses":"perodicticus",
"perognathuses":"perognathus",
"peromyscuses":"peromyscus",
"peronosporas":"peronospora",
"peronosporaceaes":"peronosporaceae",
"peronosporaleses":"peronosporales",
"perorated":"perorate",
"perorating":"perorate",
"peroxided":"peroxide",
"peroxides":"peroxide",
"peroxiding":"peroxide",
"perpendiculars":"perpendicular",
"perpendicularities":"perpendicularity",
"perpetrated":"perpetrate",
"perpetrates":"perpetrate",
"perpetrating":"perpetrate",
"perpetrations":"perpetration",
"perpetrators":"perpetrator",
"perpetuated":"perpetuate",
"perpetuating":"perpetuate",
"perpetuations":"perpetuation",
"perpetuities":"perpetuity",
"perplexed":"perplex",
"perplexes":"perplex",
"perplexing":"perplex",
"perplexities":"perplexity",
"perquisites":"perquisite",
"perrons":"perron",
"perries":"perry",
"perseas":"persea",
"persecuted":"persecute",
"persecutes":"persecute",
"persecuting":"persecute",
"persecutions":"persecution",
"persecutors":"persecutor",
"persephones":"persephone",
"perseverances":"perseverance",
"perseverations":"perseveration",
"persevered":"persevere",
"perseveres":"persevere",
"persevering":"persevere",
"perseverences":"perseverence",
"persias":"persia",
"persians":"persian",
"persimmons":"persimmon",
"persisted":"persist",
"persisting":"persist",
"persists":"persist",
"persistences":"persistence",
"persistencies":"persistency",
"people":"people",
"persons":"person",
"personae":"persona",
"personas":"persona",
"personages":"personage",
"personals":"personal",
"personalities":"personality",
"personalized":"personalize",
"personalizes":"personalize",
"personalizing":"personalize",
"personalties":"personalty",
"personated":"personate",
"personates":"personate",
"personating":"personate",
"personations":"personation",
"personifications":"personification",
"personified":"personify",
"personifies":"personify",
"personifying":"personify",
"personnels":"personnel",
"persoonias":"persoonia",
"perspectives":"perspective",
"perspexes":"perspex",
"perspicaciousnesses":"perspicaciousness",
"perspicacities":"perspicacity",
"perspicuities":"perspicuity",
"perspicuousnesses":"perspicuousness",
"perspirations":"perspiration",
"perspired":"perspire",
"perspires":"perspire",
"perspiring":"perspire",
"perspirings":"perspiring",
"persuaded":"persuade",
"persuades":"persuade",
"persuading":"persuade",
"persuasions":"persuasion",
"persuasivenesses":"persuasiveness",
"perter":"pert",
"pertest":"pert",
"pertained":"pertain",
"pertaining":"pertain",
"pertains":"pertain",
"pertinacities":"pertinacity",
"pertinences":"pertinence",
"pertinencies":"pertinency",
"pertnesses":"pertness",
"perturbed":"perturb",
"perturbing":"perturb",
"perturbs":"perturb",
"perturbations":"perturbation",
"pertusarias":"pertusaria",
"pertusariaceaes":"pertusariaceae",
"pertusses":"pertussis",
"perukes":"peruke",
"perusals":"perusal",
"perused":"peruse",
"perusing":"peruse",
"perusings":"perusing",
"pervaded":"pervade",
"pervades":"pervade",
"pervading":"pervade",
"pervasions":"pervasion",
"perversenesses":"perverseness",
"perversities":"perversity",
"perverted":"pervert",
"perverting":"pervert",
"perverts":"pervert",
"perviousnesses":"perviousness",
"pedes":"pes",
"pesaches":"pesach",
"pesahs":"pesah",
"pesetas":"peseta",
"peskier":"pesky",
"peskiest":"pesky",
"pesos":"peso",
"passaries":"pessary",
"pessaries":"pessary",
"pessimists":"pessimist",
"pests":"pest",
"pestered":"pester",
"pestering":"pester",
"pesters":"pester",
"pesterers":"pesterer",
"pesthouses":"pesthouse",
"pestilences":"pestilence",
"pestled":"pestle",
"pestles":"pestle",
"pestling":"pestle",
"pets":"pet",
"petted":"pet",
"petting":"pet",
"petals":"petal",
"petasiteses":"petasites",
"petauristas":"petaurista",
"petauristidaes":"petauristidae",
"petauruses":"petaurus",
"petcharies":"petchary",
"petechiae":"petechia",
"petered":"peter",
"petering":"peter",
"peters":"peter",
"peterburgs":"peterburg",
"petermen":"peterman",
"petersburgs":"petersburg",
"petfoods":"petfood",
"petioles":"petiole",
"petitenesses":"petiteness",
"petitios":"petitio",
"petitioned":"petition",
"petitioning":"petition",
"petitions":"petition",
"petitioners":"petitioner",
"petrarcas":"petrarca",
"petrarches":"petrarch",
"petrifactions":"petrifaction",
"petrifications":"petrification",
"petrified":"petrify",
"petrifies":"petrify",
"petrifying":"petrify",
"petrocoptises":"petrocoptis",
"petrogales":"petrogale",
"petrograds":"petrograd",
"petrols":"petrol",
"petrolatums":"petrolatum",
"petroleums":"petroleum",
"petrologies":"petrology",
"petromyzons":"petromyzon",
"petromyzoniformeses":"petromyzoniformes",
"petromyzontidaes":"petromyzontidae",
"petroselinums":"petroselinum",
"petterias":"petteria",
"petticoats":"petticoat",
"pettifogged":"pettifog",
"pettifogging":"pettifog",
"pettifogs":"pettifog",
"pettifoggers":"pettifogger",
"pettinesses":"pettiness",
"pettings":"petting",
"pettishnesses":"pettishness",
"pettier":"petty",
"pettiest":"petty",
"petulances":"petulance",
"petunias":"petunia",
"pews":"pew",
"pewees":"pewee",
"pewits":"pewit",
"peyotes":"peyote",
"pezizas":"peziza",
"pezizaceaes":"pezizaceae",
"pezizaleses":"pezizales",
"pezophapses":"pezophaps",
"pfalzs":"pfalz",
"pfannkuchens":"pfannkuchen",
"pfennige":"pfennig",
"pfennigs":"pfennig",
"phs":"ph",
"phacelias":"phacelia",
"phacochoeruses":"phacochoerus",
"phaeophyceaes":"phaeophyceae",
"phaeophytas":"phaeophyta",
"phaethons":"phaethon",
"phaethontidaes":"phaethontidae",
"phaetons":"phaeton",
"phages":"phage",
"phalacrocoracidaes":"phalacrocoracidae",
"phalacrocoraxes":"phalacrocorax",
"phalacroses":"phalacrosis",
"phalaenopses":"phalaenopsis",
"phalaenoptiluses":"phalaenoptilus",
"phalanges":"phalanx",
"phalangers":"phalanger",
"phalangeridaes":"phalangeridae",
"phalangidas":"phalangida",
"phalangiidaes":"phalangiidae",
"phalangiums":"phalangium",
"phalansteries":"phalanstery",
"phalanxes":"phalanx",
"phalarises":"phalaris",
"phalaropidaes":"phalaropidae",
"phalaropuses":"phalaropus",
"phallaceaes":"phallaceae",
"phallaleses":"phallales",
"phalli":"phallus",
"phalluses":"phallus",
"phalsas":"phalsa",
"phanerogams":"phanerogam",
"phantasmata":"phantasma",
"phantasmagorias":"phantasmagoria",
"phantasies":"phantasy",
"phantoms":"phantom",
"pharmaceuticses":"pharmaceutics",
"pharmacists":"pharmacist",
"pharmacologists":"pharmacologist",
"pharmacologies":"pharmacology",
"pharmacopoeias":"pharmacopoeia",
"pharmacies":"pharmacy",
"pharomacruses":"pharomacrus",
"pharoses":"pharos",
"pharsaluses":"pharsalus",
"pharyngitises":"pharyngitis",
"pharyngotomies":"pharyngotomy",
"pharynges":"pharynx",
"pharynxes":"pharynx",
"phascogales":"phascogale",
"phascolarctoses":"phascolarctos",
"phased":"phase",
"phases":"phase",
"phasing":"phase",
"phaseoluses":"phaseolus",
"phasianidaes":"phasianidae",
"phasianuses":"phasianus",
"phasmatidaes":"phasmatidae",
"phasmatodeas":"phasmatodea",
"phasmids":"phasmid",
"phasmidas":"phasmida",
"phasmidaes":"phasmidae",
"phasmidias":"phasmidia",
"pheasants":"pheasant",
"phegopterises":"phegopteris",
"phellems":"phellem",
"phellodendrons":"phellodendron",
"phenacetins":"phenacetin",
"phenicias":"phenicia",
"phenobarbitals":"phenobarbital",
"phenobarbitones":"phenobarbitone",
"phenocopies":"phenocopy",
"phenols":"phenol",
"phenolics":"phenolic",
"phenomena":"phenomenon",
"phenomenons":"phenomenon",
"phenoplasts":"phenoplast",
"phenothiazines":"phenothiazine",
"phenylacetamides":"phenylacetamide",
"phenylamines":"phenylamine",
"phenylbutazones":"phenylbutazone",
"phenylethylenes":"phenylethylene",
"phis":"phi",
"phi-phenomena":"phi-phenomenon",
"phials":"phial",
"philadelphaceaes":"philadelphaceae",
"philadelphias":"philadelphia",
"philaenuses":"philaenus",
"philandered":"philander",
"philandering":"philander",
"philanders":"philander",
"philanderers":"philanderer",
"philanthropists":"philanthropist",
"philanthropies":"philanthropy",
"philatelists":"philatelist",
"philatelies":"philately",
"philhellenes":"philhellene",
"philhellinists":"philhellinist",
"philippis":"philippi",
"philippics":"philippic",
"philippines":"philippine",
"philippineses":"philippines",
"philistines":"philistine",
"philistinisms":"philistinism",
"phillidaes":"phillidae",
"phillyreas":"phillyrea",
"philodendra":"philodendron",
"philodendrons":"philodendron",
"philohelas":"philohela",
"philologists":"philologist",
"philologues":"philologue",
"philologies":"philology",
"philomachuses":"philomachus",
"philophyllas":"philophylla",
"philosophers":"philosopher",
"philosophized":"philosophize",
"philosophizes":"philosophize",
"philosophizing":"philosophize",
"philosophies":"philosophy",
"philtered":"philter",
"philtering":"philter",
"philters":"philter",
"philtres":"philtre",
"philtra":"philtrum",
"phlebodiums":"phlebodium",
"phlebograms":"phlebogram",
"phlebotomuses":"phlebotomus",
"phlebotomies":"phlebotomy",
"phlegms":"phlegm",
"phleums":"phleum",
"phloems":"phloem",
"phloxes":"phlox",
"phlyctenae":"phlyctaena",
"phobias":"phobia",
"phocas":"phoca",
"phocaenas":"phocaena",
"phocidaes":"phocidae",
"phocomelias":"phocomelia",
"phoebes":"phoebe",
"phoebuses":"phoebus",
"phoenicias":"phoenicia",
"phoenicophoriums":"phoenicophorium",
"phoenicopteridaes":"phoenicopteridae",
"phoeniculidaes":"phoeniculidae",
"phoeniculuses":"phoeniculus",
"phoenicuruses":"phoenicurus",
"phoenixes":"phoenix",
"pholadidaes":"pholadidae",
"pholases":"pholas",
"pholidaes":"pholidae",
"pholidotas":"pholidota",
"pholiotas":"pholiota",
"pholises":"pholis",
"pholistomas":"pholistoma",
"phonated":"phonate",
"phonating":"phonate",
"phoned":"phone",
"phones":"phone",
"phoning":"phone",
"phonebooks":"phonebook",
"phonemicses":"phonemics",
"phoners":"phoner",
"phoneys":"phoney",
"phonographed":"phonograph",
"phonographing":"phonograph",
"phonographs":"phonograph",
"phonographies":"phonography",
"phonologies":"phonology",
"phonier":"phony",
"phonies":"phony",
"phoniest":"phony",
"phoradendrons":"phoradendron",
"phoronidas":"phoronida",
"phoronideas":"phoronidea",
"phorrhoeas":"phorrhoea",
"phosphates":"phosphate",
"phosphoresced":"phosphoresce",
"phosphorescing":"phosphoresce",
"phosphori":"phosphorus",
"phosphoruses":"phosphorus",
"photinias":"photinia",
"photoed":"photo",
"photoing":"photo",
"photos":"photo",
"photo-offsets":"photo-offset",
"photoblepharons":"photoblepharon",
"photocells":"photocell",
"photocomposed":"photocompose",
"photocomposing":"photocompose",
"photoconductions":"photoconduction",
"photoconductivities":"photoconductivity",
"photocopied":"photocopy",
"photocopies":"photocopy",
"photocopying":"photocopy",
"photoengravings":"photoengraving",
"photoflashes":"photoflash",
"photofloods":"photoflood",
"photographed":"photograph",
"photographing":"photograph",
"photographs":"photograph",
"photographers":"photographer",
"photographies":"photography",
"photogravures":"photogravure",
"photolithographed":"photolithograph",
"photolithographing":"photolithograph",
"photomapped":"photomap",
"photomapping":"photomap",
"photomaps":"photomap",
"photometers":"photometer",
"photosensitivities":"photosensitivity",
"photosets":"photoset",
"photosetting":"photoset",
"photostated":"photostat",
"photostating":"photostat",
"photostats":"photostat",
"photostatted":"photostat",
"photostatting":"photostat",
"phoxinuses":"phoxinus",
"phragmacones":"phragmacone",
"phragmipediums":"phragmipedium",
"phragmiteses":"phragmites",
"phragmocones":"phragmocone",
"phrased":"phrase",
"phrases":"phrase",
"phrasing":"phrase",
"phraseologies":"phraseology",
"phrasings":"phrasing",
"phratries":"phratry",
"phrenologists":"phrenologist",
"phrensies":"phrensy",
"phrynosomas":"phrynosoma",
"phthiriidaes":"phthiriidae",
"phthiriuses":"phthirius",
"phthiruses":"phthirus",
"phthises":"phthisis",
"phthorimaeas":"phthorimaea",
"phycomyceteses":"phycomycetes",
"phylacteries":"phylactery",
"phylae":"phyle",
"phyllidaes":"phyllidae",
"phyllitises":"phyllitis",
"phylliums":"phyllium",
"phylloclads":"phylloclad",
"phyllocladaceaes":"phyllocladaceae",
"phylloclades":"phylloclade",
"phyllocladuses":"phyllocladus",
"phyllodoces":"phyllodoce",
"phylloporuses":"phylloporus",
"phylloquinones":"phylloquinone",
"phyllorhynchuses":"phyllorhynchus",
"phylloscopuses":"phylloscopus",
"phyllostachyses":"phyllostachys",
"phyllostomatidaes":"phyllostomatidae",
"phyllostomidaes":"phyllostomidae",
"phyllostomuses":"phyllostomus",
"phyllotaxes":"phyllotaxis",
"phyllotaxtaxes":"phyllotaxis",
"phyllotaxies":"phyllotaxy",
"phylloxeras":"phylloxera",
"phylloxeridaes":"phylloxeridae",
"phylogeneses":"phylogenesis",
"phylogenies":"phylogeny",
"phyla":"phylum",
"physalias":"physalia",
"physalises":"physalis",
"physarias":"physaria",
"physchometrikas":"physchometrika",
"physeters":"physeter",
"physeteridaes":"physeteridae",
"physiatricses":"physiatrics",
"physicked":"physic",
"physicking":"physic",
"physics":"physic",
"physicalisms":"physicalism",
"physicalities":"physicality",
"physicalnesses":"physicalness",
"physicians":"physician",
"physicists":"physicist",
"physicses":"physics",
"physidaes":"physidae",
"physiognomies":"physiognomy",
"physiographies":"physiography",
"physiologists":"physiologist",
"physiologies":"physiology",
"physioltherapists":"physioltherapist",
"physiotherapies":"physiotherapy",
"physiques":"physique",
"physostigmas":"physostigma",
"phytelephases":"phytelephas",
"phytohormones":"phytohormone",
"phytolaccas":"phytolacca",
"phytolaccaceaes":"phytolaccaceae",
"phytologists":"phytologist",
"phytologies":"phytology",
"phytomastiginas":"phytomastigina",
"phytonadiones":"phytonadione",
"phytophthoras":"phytophthora",
"pis":"pi",
"pi-mesons":"pi-meson",
"pias":"pia",
"piaffed":"piaffe",
"piaffing":"piaffe",
"piagets":"piaget",
"pianissimos":"pianissimo",
"pianists":"pianist",
"pianos":"piano",
"pianofortes":"pianoforte",
"pianolas":"pianola",
"piasters":"piaster",
"piastres":"piastre",
"piazzas":"piazza",
"piazze":"piazza",
"pibgorns":"pibgorn",
"picas":"pica",
"pica-picas":"pica-pica",
"picadores":"picador",
"picadors":"picador",
"picaninnies":"picaninny",
"picardies":"picardie",
"picariaes":"picariae",
"picaros":"picaro",
"picassos":"picasso",
"piccalillis":"piccalilli",
"piccaninnies":"piccaninny",
"piccolos":"piccolo",
"piceas":"picea",
"pichis":"pichi",
"pichiciagos":"pichiciago",
"pichiciegos":"pichiciego",
"picidaes":"picidae",
"piciformeses":"piciformes",
"picked":"pick",
"picking":"pick",
"picks":"pick",
"pick-me-ups":"pick-me-up",
"pickaninnies":"pickaninny",
"pickaxed":"pickax",
"pickaxes":"pickaxe",
"pickaxing":"pickax",
"pickerels":"pickerel",
"pickerelweeds":"pickerelweed",
"pickeringias":"pickeringia",
"picketed":"picket",
"picketing":"picket",
"pickets":"picket",
"pickings":"picking",
"pickled":"pickle",
"pickles":"pickle",
"pickling":"pickle",
"picklepusses":"picklepuss",
"picknickers":"picknicker",
"pickpockets":"pickpocket",
"pickups":"pickup",
"pickier":"picky",
"pickiest":"picky",
"picnicked":"picnic",
"picnicking":"picnic",
"picnics":"picnic",
"picnickers":"picnicker",
"picoideses":"picoides",
"picometers":"picometer",
"picometres":"picometre",
"picoted":"picot",
"picoting":"picot",
"picrasmas":"picrasma",
"picrises":"picris",
"pictorials":"pictorial",
"pictured":"picture",
"pictures":"picture",
"picturing":"picture",
"picturings":"picturing",
"picumnuses":"picumnus",
"picuses":"picus",
"pids":"pid",
"piddled":"piddle",
"piddles":"piddle",
"piddling":"piddle",
"pidginized":"pidginize",
"pidginizing":"pidginize",
"pidlimdis":"pidlimdi",
"pies":"pie",
"pie-dogs":"pie-dog",
"pieced":"piece",
"pieces":"piece",
"piecing":"piece",
"pieds-a-terre":"pied-a-terre",
"piedmonts":"piedmont",
"piemen":"pieman",
"piemontes":"piemonte",
"pieplants":"pieplant",
"piers":"pier",
"pierced":"pierce",
"pierces":"pierce",
"piercing":"pierce",
"pierids":"pierid",
"pieridaes":"pieridae",
"pierises":"pieris",
"pierres":"pierre",
"pierrots":"pierrot",
"pietas":"pieta",
"pietisms":"pietism",
"pieties":"piety",
"piezoelectricities":"piezoelectricity",
"piffled":"piffle",
"piffles":"piffle",
"piffling":"piffle",
"pigged":"pig",
"pigging":"pig",
"pigs":"pig",
"pigboats":"pigboat",
"pigeoned":"pigeon",
"pigeoning":"pigeon",
"pigeons":"pigeon",
"pigeonholed":"pigeonhole",
"pigeonholes":"pigeonhole",
"pigeonholing":"pigeonhole",
"pigeonholings":"pigeonholing",
"pigfishes":"pigfish",
"piggeries":"piggery",
"piggishnesses":"piggishness",
"piggier":"piggy",
"piggies":"piggy",
"piggiest":"piggy",
"piggybacked":"piggyback",
"piggybacking":"piggyback",
"pigheadednesses":"pigheadedness",
"piglets":"piglet",
"pigmen":"pigman",
"pigmented":"pigment",
"pigmenting":"pigment",
"pigments":"pigment",
"pigmies":"pigmy",
"pignolias":"pignolia",
"pignuts":"pignut",
"pigpens":"pigpen",
"pigsties":"pigsty",
"pigswills":"pigswill",
"pigwashes":"pigwash",
"pigweeds":"pigweed",
"pikas":"pika",
"piked":"pike",
"pikes":"pike",
"piking":"pike",
"pikemen":"pikeman",
"pikeperches":"pikeperch",
"pikestaves":"pikestaff",
"pilafs":"pilaf",
"pilaffs":"pilaff",
"pilaus":"pilau",
"pilaws":"pilaw",
"pilchards":"pilchard",
"piled":"pile",
"piles":"pile",
"piling":"pile",
"pileas":"pilea",
"pileses":"piles",
"pilea":"pileum",
"pileuses":"pileus",
"pileworts":"pilewort",
"pilfered":"pilfer",
"pilfering":"pilfer",
"pilfers":"pilfer",
"pilferers":"pilferer",
"pilgrims":"pilgrim",
"pilgrimages":"pilgrimage",
"pilis":"pili",
"pilings":"piling",
"pilled":"pill",
"pilling":"pill",
"pills":"pill",
"pillaged":"pillage",
"pillages":"pillage",
"pillaging":"pillage",
"pillagers":"pillager",
"pillagings":"pillaging",
"pillared":"pillar",
"pillaring":"pillar",
"pillars":"pillar",
"pillboxes":"pillbox",
"pilloried":"pillory",
"pillories":"pillory",
"pillorying":"pillory",
"pillowed":"pillow",
"pillowing":"pillow",
"pillows":"pillow",
"pillowcases":"pillowcase",
"pillworts":"pillwort",
"pilosellas":"pilosella",
"piloted":"pilot",
"piloting":"pilot",
"pilots":"pilot",
"pilotages":"pilotage",
"pilotfishes":"pilotfish",
"pilothouses":"pilothouse",
"pilotings":"piloting",
"pilseners":"pilsener",
"pilsners":"pilsner",
"pilularias":"pilularia",
"pimentas":"pimenta",
"pimentos":"pimento",
"pimientos":"pimiento",
"pimped":"pimp",
"pimping":"pimp",
"pimps":"pimp",
"pimpernels":"pimpernel",
"pimpinellas":"pimpinella",
"pinned":"pin",
"pinning":"pin",
"pins":"pin",
"pin-ups":"pin-up",
"pinaceaes":"pinaceae",
"pinafores":"pinafore",
"pinballs":"pinball",
"pincers":"pincer",
"pinched":"pinch",
"pinches":"pinch",
"pinching":"pinch",
"pinch-hits":"pinch-hit",
"pinch-hitting":"pinch-hit",
"pinchpennies":"pinchpenny",
"pinckneyas":"pinckneya",
"pinctadas":"pinctada",
"pindarics":"pindaric",
"pined":"pine",
"pines":"pine",
"pining":"pine",
"pineapples":"pineapple",
"pineries":"pinery",
"pinesaps":"pinesap",
"pineta":"pinetum",
"pineuses":"pineus",
"pineweeds":"pineweed",
"pinfishes":"pinfish",
"pinged":"ping",
"pinging":"ping",
"pings":"ping",
"ping-pongs":"ping-pong",
"pingos":"pingo",
"pinguiculas":"pinguicula",
"pinguinuses":"pinguinus",
"pinheads":"pinhead",
"pinicolas":"pinicola",
"pinioned":"pinion",
"pinioning":"pinion",
"pinions":"pinion",
"pinked":"pink",
"pinker":"pink",
"pinkest":"pink",
"pinking":"pink",
"pinks":"pink",
"pinkeyes":"pinkeye",
"pinkies":"pinkie",
"pinkos":"pinko",
"pinnae":"pinna",
"pinnas":"pinna",
"pinnaces":"pinnace",
"pinnacled":"pinnacle",
"pinnacles":"pinnacle",
"pinnacling":"pinnacle",
"pinnatipeds":"pinnatiped",
"pinnipeds":"pinniped",
"pinnipedias":"pinnipedia",
"pinnothereses":"pinnotheres",
"pinnotheridaes":"pinnotheridae",
"pinnulae":"pinnula",
"pinnules":"pinnule",
"pinnies":"pinny",
"pinochles":"pinochle",
"pinons":"pinon",
"pinophytinas":"pinophytina",
"pinopsidas":"pinopsida",
"pinots":"pinot",
"pinpointed":"pinpoint",
"pinpointing":"pinpoint",
"pinpoints":"pinpoint",
"pints":"pint",
"pintados":"pintado",
"pintails":"pintail",
"pintos":"pinto",
"pinuses":"pinus",
"pinwheels":"pinwheel",
"pinworms":"pinworm",
"pinier":"piny",
"piniest":"piny",
"pinyons":"pinyon",
"pions":"pion",
"pioneered":"pioneer",
"pioneering":"pioneer",
"pioneers":"pioneer",
"piousnesses":"piousness",
"pipped":"pip",
"pipping":"pip",
"pips":"pip",
"pip-squeaks":"pip-squeak",
"pipas":"pipa",
"pipages":"pipage",
"pipals":"pipal",
"piped":"pipe",
"pipes":"pipe",
"piping":"pipe",
"pipeclays":"pipeclay",
"pipefishes":"pipefish",
"pipefittings":"pipefitting",
"pipelined":"pipeline",
"pipelines":"pipeline",
"pipelining":"pipeline",
"pipers":"piper",
"piperaceaes":"piperaceae",
"piperaleses":"piperales",
"piperins":"piperin",
"piperines":"piperine",
"piperocaines":"piperocaine",
"pipeses":"pipes",
"pipetted":"pipet",
"pipetting":"pipet",
"pipeworks":"pipework",
"pipeworts":"pipewort",
"pipidaes":"pipidae",
"pipiles":"pipile",
"pipilos":"pipilo",
"pipings":"piping",
"pipistrels":"pipistrel",
"pipistrelles":"pipistrelle",
"pipistrelluses":"pipistrellus",
"pipits":"pipit",
"pipras":"pipra",
"pipridaes":"pipridae",
"pipsissewas":"pipsissewa",
"piptadenias":"piptadenia",
"pipturuses":"pipturus",
"pipuls":"pipul",
"piquances":"piquance",
"piquancies":"piquancy",
"piqued":"pique",
"piques":"pique",
"piquing":"pique",
"piquerias":"piqueria",
"piracies":"piracy",
"piranas":"pirana",
"pirangas":"piranga",
"piranhas":"piranha",
"pirated":"pirate",
"pirates":"pirate",
"pirating":"pirate",
"pirogi":"pirog",
"pirogis":"pirogi",
"pirogues":"pirogue",
"piroshkis":"piroshki",
"pirouetted":"pirouette",
"pirouetting":"pirouette",
"piroxicams":"piroxicam",
"pirozhkis":"pirozhki",
"pisanosaurs":"pisanosaur",
"pisanosauruses":"pisanosaurus",
"piscaries":"piscary",
"pisceses":"pisces",
"piscidias":"piscidia",
"piscinae":"piscina",
"piscinas":"piscina",
"pished":"pish",
"pishing":"pish",
"pisiforms":"pisiform",
"pismires":"pismire",
"pisonias":"pisonia",
"pissed":"piss",
"pisses":"piss",
"pissing":"piss",
"pissings":"pissing",
"pissoirs":"pissoir",
"pistachios":"pistachio",
"pistacias":"pistacia",
"pistias":"pistia",
"pistils":"pistil",
"pistoled":"pistol",
"pistoling":"pistol",
"pistolled":"pistol",
"pistolling":"pistol",
"pistols":"pistol",
"pistol-whipped":"pistol-whip",
"pistol-whipping":"pistol-whip",
"pistol-whips":"pistol-whip",
"pistons":"piston",
"pisums":"pisum",
"pits":"pit",
"pitted":"pit",
"pitting":"pit",
"pitas":"pita",
"pitahayas":"pitahaya",
"pitangas":"pitanga",
"pitapats":"pitapat",
"pitapatted":"pitapat",
"pitapatting":"pitapat",
"pitched":"pitch",
"pitches":"pitch",
"pitching":"pitch",
"pitchblendes":"pitchblende",
"pitchers":"pitcher",
"pitcherfuls":"pitcherful",
"pitchforked":"pitchfork",
"pitchforking":"pitchfork",
"pitchforks":"pitchfork",
"pitchings":"pitching",
"pitchmen":"pitchman",
"pitchier":"pitchy",
"pitchiest":"pitchy",
"pitfalls":"pitfall",
"pithed":"pith",
"pithing":"pith",
"piths":"pith",
"pithecanthropuses":"pithecanthropus",
"pithecellobiums":"pithecellobium",
"pithecias":"pithecia",
"pithecolobiums":"pithecolobium",
"pithinesses":"pithiness",
"pithoi":"pithos",
"pithier":"pithy",
"pithiest":"pithy",
"pitilessnesses":"pitilessness",
"pitmans":"pitman",
"pitmen":"pitman",
"pitprops":"pitprop",
"pitter-pattered":"pitter-patter",
"pitter-pattering":"pitter-patter",
"pitter-patters":"pitter-patter",
"pittidaes":"pittidae",
"pittings":"pitting",
"pituitaries":"pituitary",
"pituophises":"pituophis",
"pitied":"pity",
"pities":"pity",
"pitying":"pity",
"pitymyses":"pitymys",
"pityrogrammas":"pityrogramma",
"piutes":"piute",
"pivoted":"pivot",
"pivoting":"pivot",
"pivots":"pivot",
"pixes":"pix",
"pixels":"pixel",
"pixies":"pixie",
"pizzas":"pizza",
"pizzazs":"pizzaz",
"pizzazzs":"pizzazz",
"pizzerias":"pizzeria",
"pizzicati":"pizzicato",
"pizzicatos":"pizzicato",
"placarded":"placard",
"placarding":"placard",
"placards":"placard",
"placated":"placate",
"placates":"placate",
"placating":"placate",
"placations":"placation",
"placed":"place",
"places":"place",
"placing":"place",
"place-kicked":"place-kick",
"place-kicking":"place-kick",
"place-kickings":"place-kicking",
"place-worships":"place-worship",
"placeboes":"placebo",
"placebos":"placebo",
"placemen":"placeman",
"placements":"placement",
"placentae":"placenta",
"placentas":"placenta",
"placentals":"placental",
"placeseekers":"placeseeker",
"placidities":"placidity",
"placidnesses":"placidness",
"placodermis":"placodermi",
"placunas":"placuna",
"plafonds":"plafond",
"plagianthuses":"plagianthus",
"plagiarisations":"plagiarisation",
"plagiarists":"plagiarist",
"plagiarizations":"plagiarization",
"plagiarized":"plagiarize",
"plagiarizes":"plagiarize",
"plagiarizing":"plagiarize",
"plagiaries":"plagiary",
"plagioclases":"plagioclase",
"plagued":"plague",
"plagues":"plague",
"plaguing":"plague",
"plaices":"plaice",
"plaids":"plaid",
"plainer":"plain",
"plainest":"plain",
"plains":"plain",
"plain-clothesmen":"plain-clothesman",
"plainchants":"plainchant",
"plainclothesmen":"plainclothesman",
"plainnesses":"plainness",
"plainsmen":"plainsman",
"plainsongs":"plainsong",
"plaints":"plaint",
"plaintiffs":"plaintiff",
"plaited":"plait",
"plaiting":"plait",
"plaits":"plait",
"planned":"plan",
"planning":"plan",
"plans":"plan",
"planakeens":"planakeen",
"planarias":"planaria",
"planarians":"planarian",
"planchets":"planchet",
"planed":"plane",
"planes":"plane",
"planing":"plane",
"planenesses":"planeness",
"planers":"planer",
"planets":"planet",
"planetaria":"planetarium",
"planetariia":"planetarium",
"planetariums":"planetarium",
"planetartaries":"planetary",
"planetoids":"planetoid",
"plangencies":"plangency",
"planimeters":"planimeter",
"planked":"plank",
"planking":"plank",
"planks":"plank",
"planners":"planner",
"plannings":"planning",
"planococcuses":"planococcus",
"planographies":"planography",
"planted":"plant",
"planting":"plant",
"plants":"plant",
"plantaes":"plantae",
"plantagenets":"plantagenet",
"plantaginaceaes":"plantaginaceae",
"plantaginaleses":"plantaginales",
"plantagos":"plantago",
"plantains":"plantain",
"plantations":"plantation",
"planters":"planter",
"planthoppers":"planthopper",
"planulae":"planula",
"plaques":"plaque",
"plashed":"plash",
"plashes":"plash",
"plashing":"plash",
"plashier":"plashy",
"plashiest":"plashy",
"plasms":"plasm",
"plasmas":"plasma",
"plasmacytes":"plasmacyte",
"plasmins":"plasmin",
"plasmodesms":"plasmodesm",
"plasmodesdesmata":"plasmodesma",
"plasmodesmata":"plasmodesma",
"plasmodiidaes":"plasmodiidae",
"plasmodiophoras":"plasmodiophora",
"plasmodiophoraceaes":"plasmodiophoraceae",
"plasmodia":"plasmodium",
"plasmodiums":"plasmodium",
"plasseys":"plassey",
"plastered":"plaster",
"plastering":"plaster",
"plasters":"plaster",
"plasterboards":"plasterboard",
"plasterings":"plastering",
"plastics":"plastic",
"plasticities":"plasticity",
"plastiques":"plastique",
"plats":"plat",
"platted":"plat",
"platting":"plat",
"plataeas":"plataea",
"plataleas":"platalea",
"plataleidaes":"plataleidae",
"platans":"platan",
"platanaceaes":"platanaceae",
"platanistidaes":"platanistidae",
"platantheras":"platanthera",
"platanuses":"platanus",
"plated":"plate",
"plates":"plate",
"plating":"plate",
"plateaus":"plateau",
"plateaux":"plateau",
"platefuls":"plateful",
"platelayers":"platelayer",
"platelets":"platelet",
"platformed":"platform",
"platforming":"platform",
"platforms":"platform",
"platformses":"platforms",
"platichthyses":"platichthys",
"platings":"plating",
"platinums":"platinum",
"platitudes":"platitude",
"platonisms":"platonism",
"plattdeutsches":"plattdeutsch",
"plattes":"platte",
"platters":"platter",
"platies":"platy",
"platycephalidaes":"platycephalidae",
"platyceriums":"platycerium",
"platycteneas":"platyctenea",
"platyhelminths":"platyhelminth",
"platyhelmintheses":"platyhelminthes",
"platylobiums":"platylobium",
"platymisciums":"platymiscium",
"platypoeciluses":"platypoecilus",
"platypi":"platypus",
"platypuses":"platypus",
"platyrrhinis":"platyrrhini",
"platystemons":"platystemon",
"plaudits":"plaudit",
"plauditses":"plaudits",
"plausibilities":"plausibility",
"plausiblenesses":"plausibleness",
"plautuses":"plautus",
"played":"play",
"playing":"play",
"plays":"play",
"playas":"playa",
"playactings":"playacting",
"playactors":"playactor",
"playboys":"playboy",
"playdays":"playday",
"players":"player",
"playfellows":"playfellow",
"playfulnesses":"playfulness",
"playgoers":"playgoer",
"playgrounds":"playground",
"playhouses":"playhouse",
"playings":"playing",
"playmates":"playmate",
"playpens":"playpen",
"playrooms":"playroom",
"playschools":"playschool",
"playscripts":"playscript",
"playthings":"plaything",
"playtimes":"playtime",
"playwrights":"playwright",
"played_a_part":"play_a_part",
"playing_a_part":"play_a_part",
"plays_a_part":"play_a_part",
"plazas":"plaza",
"pleas":"plea",
"pleached":"pleach",
"pleaches":"pleach",
"pleaching":"pleach",
"pleaded":"plead",
"pleading":"plead",
"pleads":"plead",
"pled":"plead",
"pleasances":"pleasance",
"pleasanter":"pleasant",
"pleasantest":"pleasant",
"pleasantnesses":"pleasantness",
"pleasantries":"pleasantry",
"pleased":"please",
"pleases":"please",
"pleasing":"please",
"pleasings":"pleasing",
"pleasingnesses":"pleasingness",
"pleasured":"pleasure",
"pleasures":"pleasure",
"pleasuring":"pleasure",
"pleated":"pleat",
"pleating":"pleat",
"pleats":"pleat",
"pleatings":"pleating",
"plebs":"pleb",
"plebes":"plebe",
"plebeians":"plebeian",
"plebiscites":"plebiscite",
"plecopteras":"plecoptera",
"plecopterans":"plecopteran",
"plecotuses":"plecotus",
"plectanias":"plectania",
"plectognaths":"plectognath",
"plectognathis":"plectognathi",
"plectomyceteses":"plectomycetes",
"plectorrhizas":"plectorrhiza",
"plectrons":"plectron",
"plectrophenaxes":"plectrophenax",
"plectra":"plectrum",
"plectrums":"plectrum",
"pledged":"pledge",
"pledges":"pledge",
"pledging":"pledge",
"pleiones":"pleione",
"pleiospiloses":"pleiospilos",
"pleistocenes":"pleistocene",
"plenipotentiaries":"plenipotentiary",
"plenitudes":"plenitude",
"plenteousnesses":"plenteousness",
"plentifulnesses":"plentifulness",
"plentitudes":"plentitude",
"plenties":"plenty",
"plena":"plenum",
"plenums":"plenum",
"pleomorphisms":"pleomorphism",
"pleonastes":"pleonaste",
"pleopods":"pleopod",
"plesianthropuses":"plesianthropus",
"plesiosaurs":"plesiosaur",
"plesiosaurias":"plesiosauria",
"plesiosauruses":"plesiosaurus",
"plethodons":"plethodon",
"plethodonts":"plethodont",
"plethodontidaes":"plethodontidae",
"plethoras":"plethora",
"pleurae":"pleura",
"pleuras":"pleura",
"pleuralgias":"pleuralgia",
"pleurobrachias":"pleurobrachia",
"pleurobrachiidaes":"pleurobrachiidae",
"pleurocarps":"pleurocarp",
"pleurodynias":"pleurodynia",
"pleura":"pleuron",
"pleuronecteses":"pleuronectes",
"pleuronectidaes":"pleuronectidae",
"pleurosoruses":"pleurosorus",
"pleurotomies":"pleurotomy",
"pleurotuses":"pleurotus",
"plevens":"pleven",
"plevnas":"plevna",
"plexiglases":"plexiglas",
"plexiglasses":"plexiglass",
"plexuses":"plexus",
"pliabilities":"pliability",
"pliancies":"pliancy",
"pliantnesses":"pliantness",
"plicae":"plica",
"plicas":"plica",
"plications":"plication",
"plicatoperipatuses":"plicatoperipatus",
"plierses":"pliers",
"plighted":"plight",
"plighting":"plight",
"plights":"plight",
"plimsolls":"plimsoll",
"plinked":"plink",
"plinking":"plink",
"plinths":"plinth",
"pliocenes":"pliocene",
"ploceidaes":"ploceidae",
"ploceuses":"ploceus",
"plodded":"plod",
"plodding":"plod",
"plods":"plod",
"plodders":"plodder",
"ploddings":"plodding",
"plonkos":"plonko",
"plopped":"plop",
"plopping":"plop",
"plops":"plop",
"plosions":"plosion",
"plosives":"plosive",
"plots":"plot",
"plotted":"plot",
"plotting":"plot",
"plotters":"plotter",
"ploughed":"plough",
"ploughing":"plough",
"ploughs":"plough",
"ploughboys":"ploughboy",
"ploughings":"ploughing",
"ploughmen":"ploughman",
"ploughshares":"ploughshare",
"ploughwrights":"ploughwright",
"plowed":"plow",
"plowing":"plow",
"plows":"plow",
"plowboys":"plowboy",
"plowings":"plowing",
"plowmen":"plowman",
"plowshares":"plowshare",
"plowwrights":"plowwright",
"ploys":"ploy",
"ployurethans":"ployurethan",
"plucked":"pluck",
"plucking":"pluck",
"plucks":"pluck",
"pluckinesses":"pluckiness",
"pluckier":"plucky",
"pluckiest":"plucky",
"plugged":"plug",
"plugging":"plug",
"plugs":"plug",
"plug-uglies":"plug-ugly",
"plugboards":"plugboard",
"pluggers":"plugger",
"plums":"plum",
"plumages":"plumage",
"plumbed":"plumb",
"plumbing":"plumb",
"plumbs":"plumb",
"plumbaginaceaes":"plumbaginaceae",
"plumbaginaleses":"plumbaginales",
"plumbagos":"plumbago",
"plumbers":"plumber",
"plumberies":"plumbery",
"plumbings":"plumbing",
"plumbisms":"plumbism",
"plumcots":"plumcot",
"plumed":"plume",
"plumes":"plume",
"pluming":"plume",
"plumerias":"plumeria",
"plumieras":"plumiera",
"plummeted":"plummet",
"plummeting":"plummet",
"plummets":"plummet",
"plummier":"plummy",
"plummiest":"plummy",
"plumped":"plump",
"plumper":"plump",
"plumpest":"plump",
"plumping":"plump",
"plumpnesses":"plumpness",
"plumier":"plumy",
"plumiest":"plumy",
"plundered":"plunder",
"plundering":"plunder",
"plunders":"plunder",
"plunderers":"plunderer",
"plunderings":"plundering",
"plunged":"plunge",
"plunges":"plunge",
"plunging":"plunge",
"plungers":"plunger",
"plunked":"plunk",
"plunking":"plunk",
"plunks":"plunk",
"plunkers":"plunker",
"pluperfects":"pluperfect",
"plurals":"plural",
"pluralities":"plurality",
"pluralized":"pluralize",
"pluralizing":"pluralize",
"pluses":"plus",
"plusher":"plush",
"plushest":"plush",
"plushier":"plushy",
"plushiest":"plushy",
"pluteaceaes":"pluteaceae",
"pluteuses":"pluteus",
"plutos":"pluto",
"plutocracies":"plutocracy",
"plutons":"pluton",
"plutoniums":"plutonium",
"pluvialises":"pluvialis",
"pluvianuses":"pluvianus",
"plied":"ply",
"plies":"ply",
"plying":"ply",
"plyboards":"plyboard",
"plyerses":"plyers",
"plywoods":"plywood",
"pms":"pm",
"pmses":"pms",
"pneumas":"pneuma",
"pneumectomies":"pneumectomy",
"pneumonectomies":"pneumectomy",
"pneumobacilli":"pneumobacillus",
"pneumococcuses":"pneumococcus",
"pneumoconioses":"pneumoconiosis",
"pneumogastrics":"pneumogastric",
"pneumonias":"pneumonia",
"pneumonoconioses":"pneumonoconiosis",
"pos":"po",
"poas":"poa",
"poaceaes":"poaceae",
"poached":"poach",
"poaching":"poach",
"poachers":"poacher",
"pobs":"pob",
"pocahontases":"pocahontas",
"pochards":"pochard",
"pocketed":"pocket",
"pocketing":"pocket",
"pockets":"pocket",
"pocketbooks":"pocketbook",
"pocketcombs":"pocketcomb",
"pocketfuls":"pocketful",
"pocketknives":"pocketknife",
"pockier":"pocky",
"pockiest":"pocky",
"pococuranti":"pococurante",
"podded":"pod",
"podding":"pod",
"pods":"pod",
"podalyrias":"podalyria",
"podargidaes":"podargidae",
"podarguses":"podargus",
"podgier":"podgy",
"podgiest":"podgy",
"podiatrists":"podiatrist",
"podiatries":"podiatry",
"podicepses":"podiceps",
"podicipedidaes":"podicipedidae",
"podicipediformeses":"podicipediformes",
"podicipitiformeses":"podicipitiformes",
"podilymbuses":"podilymbus",
"podia":"podium",
"podiums":"podium",
"podocarpaceaes":"podocarpaceae",
"podocarpuses":"podocarpus",
"podophyllums":"podophyllum",
"podsols":"podsol",
"podzols":"podzol",
"poeciliids":"poeciliid",
"poeciliidaes":"poeciliidae",
"poecilocapsuses":"poecilocapsus",
"poecilogales":"poecilogale",
"poems":"poem",
"poenologies":"poenology",
"poephilas":"poephila",
"poesies":"poesy",
"poets":"poet",
"poet-singers":"poet-singer",
"poetized":"poetize",
"poetizes":"poetize",
"poetizing":"poetize",
"poetries":"poetry",
"pogeys":"pogey",
"pogges":"pogge",
"pogonophoras":"pogonophora",
"pogonophorans":"pogonophoran",
"pogostemons":"pogostemon",
"pogies":"pogy",
"poignances":"poignance",
"poignancies":"poignancy",
"poilus":"poilu",
"poincianas":"poinciana",
"poinsettias":"poinsettia",
"pointed":"point",
"pointing":"point",
"points":"point",
"pointednesses":"pointedness",
"pointers":"pointer",
"pointlessnesses":"pointlessness",
"pointsmen":"pointsman",
"pointier":"pointy",
"pointiest":"pointy",
"poised":"poise",
"poises":"poise",
"poising":"poise",
"poisoned":"poison",
"poisoning":"poison",
"poisons":"poison",
"poisonberries":"poisonberry",
"poitierses":"poitiers",
"poitous":"poitou",
"poitou-charenteses":"poitou-charentes",
"poivrades":"poivrade",
"poked":"poke",
"pokes":"poke",
"poking":"poke",
"pokeberries":"pokeberry",
"pokered":"poker",
"pokering":"poker",
"pokers":"poker",
"pokeys":"pokey",
"pokings":"poking",
"pokier":"poky",
"pokies":"poky",
"pokiest":"poky",
"pols":"pol",
"polands":"poland",
"polanisias":"polanisia",
"polarimeters":"polarimeter",
"polarises":"polarise",
"polarisations":"polarisation",
"polariscopes":"polariscope",
"polarities":"polarity",
"polarizations":"polarization",
"polarized":"polarize",
"polarizing":"polarize",
"poled":"pole",
"poles":"pole",
"poling":"pole",
"pole-vaulted":"pole-vault",
"pole-vaulting":"pole-vault",
"poleaxes":"poleax",
"polecats":"polecat",
"polemized":"polemize",
"polemizes":"polemize",
"polemizing":"polemize",
"polemoniaceaes":"polemoniaceae",
"polemonialeses":"polemoniales",
"polers":"poler",
"polestars":"polestar",
"poliantheses":"polianthes",
"policed":"police",
"polices":"police",
"policing":"police",
"policemen":"policeman",
"policewomen":"policewoman",
"policies":"policy",
"polios":"polio",
"poliomyelitises":"poliomyelitis",
"polioptilas":"polioptila",
"poleis":"polis",
"polished":"polish",
"polishes":"polish",
"polishing":"polish",
"polishers":"polisher",
"polishings":"polishing",
"polisteses":"polistes",
"politenesses":"politeness",
"politesses":"politesse",
"politicked":"politic",
"politicking":"politic",
"politicians":"politician",
"politicized":"politicize",
"politicizing":"politicize",
"politicos":"politico",
"polities":"polity",
"polks":"polk",
"polkaed":"polka",
"polkaing":"polka",
"polkas":"polka",
"polled":"poll",
"polling":"poll",
"polls":"poll",
"pollachiuses":"pollachius",
"pollacks":"pollack",
"pollarded":"pollard",
"pollarding":"pollard",
"pollards":"pollard",
"pollened":"pollen",
"pollening":"pollen",
"pollenations":"pollenation",
"pollexes":"pollex",
"pollinated":"pollinate",
"pollinates":"pollinate",
"pollinating":"pollinate",
"pollinations":"pollination",
"polliniia":"pollinium",
"pollinoses":"pollinosis",
"polliwogs":"polliwog",
"pollocks":"pollock",
"pollsters":"pollster",
"polluted":"pollute",
"pollutes":"pollute",
"polluting":"pollute",
"pollutions":"pollution",
"pollyannas":"pollyanna",
"pollyfishes":"pollyfish",
"pollywogs":"pollywog",
"polos":"polo",
"polo-necks":"polo-neck",
"poloniums":"polonium",
"polonies":"polony",
"polskas":"polska",
"poltroons":"poltroon",
"polys":"poly",
"polyamides":"polyamide",
"polyangiaceaes":"polyangiaceae",
"polyangiums":"polyangium",
"polyanthuses":"polyanthus",
"polyboruses":"polyborus",
"polybotrias":"polybotria",
"polybotryas":"polybotrya",
"polybutenes":"polybutene",
"polybutylenes":"polybutylene",
"polychaetas":"polychaeta",
"polychaetes":"polychaete",
"polychasia":"polychasium",
"polychetes":"polychete",
"polychromed":"polychrome",
"polychromes":"polychrome",
"polychroming":"polychrome",
"polycirruses":"polycirrus",
"polydactyluses":"polydactylus",
"polyerguses":"polyergus",
"polyethylenes":"polyethylene",
"polyfoams":"polyfoam",
"polygalas":"polygala",
"polygalaceaes":"polygalaceae",
"polygamies":"polygamy",
"polyglots":"polyglot",
"polygons":"polygon",
"polygonaceaes":"polygonaceae",
"polygonaleses":"polygonales",
"polygonatums":"polygonatum",
"polygonias":"polygonia",
"polygonums":"polygonum",
"polygynies":"polygyny",
"polyhedra":"polyhedron",
"polyhedrons":"polyhedron",
"polymastiginas":"polymastigina",
"polymerisations":"polymerisation",
"polymerizations":"polymerization",
"polymorphisms":"polymorphism",
"polynemidaes":"polynemidae",
"polyodons":"polyodon",
"polyodontidaes":"polyodontidae",
"polyomas":"polyoma",
"polyoses":"polyose",
"polyps":"polyp",
"polyparparia":"polyparium",
"polyparies":"polypary",
"polypedateses":"polypedates",
"polypedatidaes":"polypedatidae",
"polyphones":"polyphone",
"polyphonies":"polyphony",
"polyplacophoras":"polyplacophora",
"polyplacophores":"polyplacophore",
"polypodiaceaes":"polypodiaceae",
"polypodialeses":"polypodiales",
"polypodiums":"polypodium",
"polypodies":"polypody",
"polyporaceaes":"polyporaceae",
"polypores":"polypore",
"polyporuses":"polyporus",
"polyprions":"polyprion",
"polypropenes":"polypropene",
"polypropylenes":"polypropylene",
"polypuses":"polypus",
"polysaccharides":"polysaccharide",
"polystichums":"polystichum",
"polysyllables":"polysyllable",
"polytechnics":"polytechnic",
"polytetrafluoroethylenes":"polytetrafluoroethylene",
"polytheisms":"polytheism",
"polythenes":"polythene",
"polytonalisms":"polytonalism",
"polytonalities":"polytonality",
"polyurethanes":"polyurethane",
"polyzoas":"polyzoa",
"polyzoans":"polyzoan",
"polyzoariia":"polyzoarium",
"poms":"pom",
"pom-poms":"pom-pom",
"pomacanthuses":"pomacanthus",
"pomacentridaes":"pomacentridae",
"pomacentruses":"pomacentrus",
"pomaded":"pomade",
"pomades":"pomade",
"pomading":"pomade",
"pomaderrises":"pomaderris",
"pomatomidaes":"pomatomidae",
"pomatomuses":"pomatomus",
"pomatums":"pomatum",
"pomes":"pome",
"pomegranates":"pomegranate",
"pomelos":"pomelo",
"pomfrets":"pomfret",
"pommeled":"pommel",
"pommeling":"pommel",
"pommelled":"pommel",
"pommelling":"pommel",
"pommels":"pommel",
"pommies":"pommy",
"pomolobuses":"pomolobus",
"pomoxes":"pomoxis",
"pomps":"pomp",
"pompanos":"pompano",
"pompeys":"pompey",
"pompons":"pompon",
"pomposities":"pomposity",
"pompousnesses":"pompousness",
"poncas":"ponca",
"ponces":"ponce",
"ponchos":"poncho",
"ponciruses":"poncirus",
"ponded":"pond",
"ponding":"pond",
"ponds":"pond",
"pond-skaters":"pond-skater",
"pondered":"ponder",
"pondering":"ponder",
"ponders":"ponder",
"ponderosas":"ponderosa",
"ponderosities":"ponderosity",
"ponderousnesses":"ponderousness",
"pondos":"pondo",
"pondweeds":"pondweed",
"pones":"pone",
"ponged":"pong",
"ponging":"pong",
"pongamias":"pongamia",
"pongids":"pongid",
"pongidaes":"pongidae",
"pongos":"pongo",
"poniarded":"poniard",
"poniarding":"poniard",
"poniards":"poniard",
"ponkas":"ponka",
"ponses":"pons",
"ponstels":"ponstel",
"pontederias":"pontederia",
"pontederiaceaes":"pontederiaceae",
"pontifices":"pontifex",
"pontiffs":"pontiff",
"pontificated":"pontificate",
"pontificates":"pontificate",
"pontificating":"pontificate",
"pontoses":"pontos",
"pontuses":"pontus",
"ponied":"pony",
"ponies":"pony",
"ponying":"pony",
"ponycarts":"ponycart",
"pooches":"pooch",
"poodles":"poodle",
"pooeceteses":"pooecetes",
"poofs":"poof",
"pooh-bahs":"pooh-bah",
"pooh-poohed":"pooh-pooh",
"pooh-poohing":"pooh-pooh",
"pooh-poohs":"pooh-pooh",
"pooled":"pool",
"pooling":"pool",
"pools":"pool",
"pooped":"poop",
"pooping":"poop",
"poops":"poop",
"poorer":"poor",
"poorest":"poor",
"poor-mouthed":"poor-mouth",
"poor-mouthing":"poor-mouth",
"poorhouses":"poorhouse",
"poornesses":"poorness",
"poorwills":"poorwill",
"pooves":"poof",
"popped":"pop",
"popping":"pop",
"pops":"pop",
"popcorns":"popcorn",
"popes":"pope",
"popillias":"popillia",
"poplars":"poplar",
"poppets":"poppet",
"poppings":"popping",
"poppled":"popple",
"poppling":"popple",
"poppies":"poppy",
"poppycocks":"poppycock",
"popsicles":"popsicle",
"popsies":"popsy",
"populaces":"populace",
"popularisations":"popularisation",
"popularizations":"popularization",
"popularized":"popularize",
"popularizes":"popularize",
"popularizing":"popularize",
"populated":"populate",
"populates":"populate",
"populating":"populate",
"populatings":"populating",
"populations":"population",
"populists":"populist",
"populuses":"populus",
"porbeagles":"porbeagle",
"porcs":"porc",
"porcellios":"porcellio",
"porcellionidaes":"porcellionidae",
"porches":"porch",
"porcupines":"porcupine",
"porcupinefishes":"porcupinefish",
"porcupineses":"porcupines",
"pored":"pore",
"pores":"pore",
"poring":"pore",
"porgies":"porgy",
"poriferas":"porifera",
"poriferans":"poriferan",
"porks":"pork",
"porkfishes":"porkfish",
"porkpies":"porkpie",
"porkier":"porky",
"porkiest":"porky",
"porns":"porn",
"pornos":"porno",
"pornographers":"pornographer",
"pornographies":"pornography",
"poronotuses":"poronotus",
"poroporos":"poroporo",
"porosities":"porosity",
"porousnesses":"porousness",
"porphyras":"porphyra",
"porphyrios":"porphyrio",
"porphyrulas":"porphyrula",
"porphyries":"porphyry",
"porpoises":"porpoise",
"ported":"port",
"porting":"port",
"ports":"port",
"port-au-princes":"port-au-prince",
"port-of-spains":"port-of-spain",
"portabilities":"portability",
"portables":"portable",
"portaged":"portage",
"portaging":"portage",
"portals":"portal",
"portamenti":"portamento",
"portended":"portend",
"portending":"portend",
"portends":"portend",
"portents":"portent",
"porters":"porter",
"porterhouses":"porterhouse",
"portfolios":"portfolio",
"portholes":"porthole",
"porticoes":"portico",
"porticos":"portico",
"portieres":"portiere",
"portioned":"portion",
"portioning":"portion",
"portions":"portion",
"portlier":"portly",
"portlies":"portly",
"portliest":"portly",
"portmanteaus":"portmanteau",
"portmanteaux":"portmanteau",
"portraits":"portrait",
"portraitists":"portraitist",
"portraitures":"portraiture",
"portrayed":"portray",
"portraying":"portray",
"portrays":"portray",
"portrayals":"portrayal",
"portrayings":"portraying",
"portulacacaeas":"portulacacaea",
"portunidaes":"portunidae",
"portunuses":"portunus",
"porzanas":"porzana",
"posadas":"posada",
"posed":"pose",
"poses":"pose",
"posing":"pose",
"posers":"poser",
"poseurs":"poseur",
"posings":"posing",
"posited":"posit",
"positing":"posit",
"posits":"posit",
"positioned":"position",
"positioning":"position",
"positions":"position",
"positioners":"positioner",
"positionings":"positioning",
"positives":"positive",
"positivisms":"positivism",
"positivists":"positivist",
"positivities":"positivity",
"positrons":"positron",
"posses":"posse",
"possemen":"posseman",
"possessed":"possess",
"possesses":"possess",
"possessing":"possess",
"possessions":"possession",
"possessives":"possessive",
"possessors":"possessor",
"possibilities":"possibility",
"possiblenesses":"possibleness",
"possums":"possum",
"possumwoods":"possumwood",
"posted":"post",
"posting":"post",
"posts":"post",
"postages":"postage",
"postagestamps":"postagestamp",
"postals":"postal",
"postbags":"postbag",
"postboxes":"postbox",
"postcards":"postcard",
"postcavas":"postcava",
"postcodes":"postcode",
"postdated":"postdate",
"postdates":"postdate",
"postdating":"postdate",
"posters":"poster",
"posterboards":"posterboard",
"posteriors":"posterior",
"posteriorities":"posteriority",
"posterities":"posterity",
"posterns":"postern",
"postfixed":"postfix",
"postfixing":"postfix",
"postgraduates":"postgraduate",
"postholes":"posthole",
"postiches":"postiche",
"postilions":"postilion",
"postillions":"postillion",
"postings":"posting",
"postliminiia":"postliminium",
"postliminies":"postliminy",
"postmen":"postman",
"postmarked":"postmark",
"postmarking":"postmark",
"postmarks":"postmark",
"postmasters":"postmaster",
"postwomen":"postmen",
"postmortems":"postmortem",
"postoffices":"postoffice",
"postponed":"postpone",
"postpones":"postpone",
"postponing":"postpone",
"postponements":"postponement",
"postponers":"postponer",
"postscripts":"postscript",
"postulated":"postulate",
"postulates":"postulate",
"postulating":"postulate",
"postulations":"postulation",
"postured":"posture",
"postures":"posture",
"posturing":"posture",
"posies":"posy",
"pots":"pot",
"potted":"pot",
"potting":"pot",
"potables":"potable",
"potamogales":"potamogale",
"potamogalidaes":"potamogalidae",
"potamogetons":"potamogeton",
"potamogetonaceaes":"potamogetonaceae",
"potamophises":"potamophis",
"potashes":"potash",
"potassiums":"potassium",
"potations":"potation",
"potatoes":"potato",
"potbellies":"potbelly",
"potboys":"potboy",
"potences":"potence",
"potencies":"potency",
"potentates":"potentate",
"potentials":"potential",
"potentialities":"potentiality",
"potentiated":"potentiate",
"potentiating":"potentiate",
"potentillas":"potentilla",
"potentiometers":"potentiometer",
"poteriums":"poterium",
"potfuls":"potful",
"pothecarcaries":"pothecary",
"pothered":"pother",
"pothering":"pother",
"pothers":"pother",
"potholes":"pothole",
"potholers":"potholer",
"pothoses":"pothos",
"pothouses":"pothouse",
"potiches":"potiche",
"potmen":"potman",
"potomacs":"potomac",
"potomanias":"potomania",
"potoroinaes":"potoroinae",
"potorouses":"potorous",
"potoses":"potos",
"potpourris":"potpourri",
"pottered":"potter",
"pottering":"potter",
"potters":"potter",
"potterers":"potterer",
"potteries":"pottery",
"pottos":"potto",
"pottier":"potty",
"potties":"potty",
"pottiest":"potty",
"pouched":"pouch",
"pouches":"pouch",
"pouching":"pouch",
"poudrins":"poudrin",
"poufs":"pouf",
"pouffes":"pouffe",
"poulets":"poulet",
"poulterers":"poulterer",
"poulticed":"poultice",
"poultices":"poultice",
"poulticing":"poultice",
"poultries":"poultry",
"poultrymen":"poultryman",
"pounced":"pounce",
"pounces":"pounce",
"pouncing":"pounce",
"pounded":"pound",
"pounding":"pound",
"pounds":"pound",
"poundages":"poundage",
"poundals":"poundal",
"poundings":"pounding",
"poured":"pour",
"pouring":"pour",
"pours":"pour",
"pourboires":"pourboire",
"pourings":"pouring",
"pousse-cafes":"pousse-cafe",
"poussetted":"poussette",
"poussetting":"poussette",
"pouted":"pout",
"pouting":"pout",
"pouts":"pout",
"pouterias":"pouteria",
"poutier":"pouty",
"poutiest":"pouty",
"poverties":"poverty",
"pows":"pow",
"powdered":"powder",
"powdering":"powder",
"powders":"powder",
"powderinesses":"powderiness",
"powderpuffs":"powderpuff",
"powered":"power",
"powering":"power",
"powers":"power",
"powerboats":"powerboat",
"powerfulnesses":"powerfulness",
"powerhouses":"powerhouse",
"powerlessnesses":"powerlessness",
"powhatans":"powhatan",
"powwowed":"powwow",
"powwowing":"powwow",
"powwows":"powwow",
"poxes":"pox",
"poyous":"poyou",
"prs":"pr",
"practicabilities":"practicability",
"practicablenesses":"practicableness",
"practiced":"practice",
"practices":"practice",
"practicing":"practice",
"practicians":"practician",
"practised":"practise",
"practises":"practise",
"practising":"practise",
"practitioners":"practitioner",
"praenonomens":"praenomen",
"praenonomina":"praenomen",
"praesidiums":"praesidium",
"praetors":"praetor",
"praetoriums":"praetorium",
"prags":"prag",
"pragues":"prague",
"prahas":"praha",
"praias":"praia",
"prairies":"prairie",
"praised":"praise",
"praises":"praise",
"praising":"praise",
"prams":"pram",
"pranced":"prance",
"prances":"prance",
"prancing":"prance",
"pranked":"prank",
"pranking":"prank",
"pranks":"prank",
"prankishnesses":"prankishness",
"pranksters":"prankster",
"praseodymiums":"praseodymium",
"prats":"prat",
"prated":"prate",
"prates":"prate",
"prating":"prate",
"pratincoles":"pratincole",
"prattled":"prattle",
"prattles":"prattle",
"prattling":"prattle",
"praunuses":"praunus",
"prawned":"prawn",
"prawning":"prawn",
"prawns":"prawn",
"praxes":"praxis",
"praxises":"praxis",
"prayed":"pray",
"praying":"pray",
"prays":"pray",
"prayers":"prayer",
"prcs":"prc",
"preached":"preach",
"preaches":"preach",
"preaching":"preach",
"preachers":"preacher",
"preachified":"preachify",
"preachifies":"preachify",
"preachifying":"preachify",
"preachings":"preaching",
"preachments":"preachment",
"preachier":"preachy",
"preachiest":"preachy",
"prearranged":"prearrange",
"prearranging":"prearrange",
"prebendaries":"prebendary",
"precambrians":"precambrian",
"precanceled":"precancel",
"precanceling":"precancel",
"precancelled":"precancel",
"precancelling":"precancel",
"precancels":"precancel",
"precasting":"precast",
"precasts":"precast",
"precautions":"precaution",
"precavas":"precava",
"preceded":"precede",
"precedes":"precede",
"preceding":"precede",
"precedences":"precedence",
"precedencies":"precedency",
"precdedents":"precedent",
"precedents":"precedent",
"precentors":"precentor",
"precepts":"precept",
"preceptors":"preceptor",
"preceptories":"preceptory",
"precessed":"precess",
"precessing":"precess",
"precessions":"precession",
"precincts":"precinct",
"preciosities":"preciosity",
"preciousnesses":"preciousness",
"precipices":"precipice",
"precipitances":"precipitance",
"precipitancies":"precipitancy",
"precipitated":"precipitate",
"precipitates":"precipitate",
"precipitating":"precipitate",
"precipitatenesses":"precipitateness",
"precipitations":"precipitation",
"precipitators":"precipitator",
"precipitousnesses":"precipitousness",
"precised":"precis",
"precises":"precis",
"precising":"precis",
"precisenesses":"preciseness",
"precisions":"precision",
"precluded":"preclude",
"precludes":"preclude",
"precluding":"preclude",
"preclusions":"preclusion",
"precociousnesses":"precociousness",
"precocities":"precocity",
"precognitions":"precognition",
"preconceived":"preconceive",
"preconceiving":"preconceive",
"preconceptions":"preconception",
"preconcerted":"preconcert",
"preconcerting":"preconcert",
"precondemned":"precondemn",
"precondemning":"precondemn",
"preconditioned":"precondition",
"preconditioning":"precondition",
"preconditions":"precondition",
"preconized":"preconize",
"preconizing":"preconize",
"precontracted":"precontract",
"precontracting":"precontract",
"precooked":"precook",
"precooking":"precook",
"precursors":"precursor",
"predated":"predate",
"predates":"predate",
"predating":"predate",
"predations":"predation",
"predators":"predator",
"predeceased":"predecease",
"predeceasing":"predecease",
"predecessors":"predecessor",
"predelle":"predella",
"predestinated":"predestinate",
"predestinates":"predestinate",
"predestinating":"predestinate",
"predestinations":"predestination",
"predestinationists":"predestinationist",
"predestined":"predestine",
"predestines":"predestine",
"predestining":"predestine",
"predeterminations":"predetermination",
"predetermined":"predetermine",
"predetermines":"predetermine",
"predetermining":"predetermine",
"predicaments":"predicament",
"predicated":"predicate",
"predicates":"predicate",
"predicating":"predicate",
"predications":"predication",
"predicted":"predict",
"predicting":"predict",
"predicts":"predict",
"predictions":"prediction",
"predictors":"predictor",
"predigested":"predigest",
"predigesting":"predigest",
"predilections":"predilection",
"predisposed":"predispose",
"predisposing":"predispose",
"predispositions":"predisposition",
"predominances":"predominance",
"predominated":"predominate",
"predominates":"predominate",
"predominating":"predominate",
"predominations":"predomination",
"preemies":"preemie",
"preeminences":"preeminence",
"preempted":"preempt",
"preempting":"preempt",
"preened":"preen",
"preening":"preen",
"preens":"preen",
"preexisted":"preexist",
"preexisting":"preexist",
"prefabbed":"prefab",
"prefabbing":"prefab",
"prefabricated":"prefabricate",
"prefabricates":"prefabricate",
"prefabricating":"prefabricate",
"prefaced":"preface",
"prefaces":"preface",
"prefacing":"preface",
"prefects":"prefect",
"prefectures":"prefecture",
"preferring":"prefer",
"prefers":"prefer",
"preferences":"preference",
"preferments":"preferment",
"prefigurations":"prefiguration",
"prefigured":"prefigure",
"prefigures":"prefigure",
"prefiguring":"prefigure",
"prefixed":"prefix",
"prefixes":"prefix",
"prefixing":"prefix",
"preformed":"preform",
"preforming":"preform",
"pregnancies":"pregnancy",
"preheated":"preheat",
"preheating":"preheat",
"prehensions":"prehension",
"prehistories":"prehistory",
"prejudged":"prejudge",
"prejudging":"prejudge",
"prejudgements":"prejudgement",
"prejudgments":"prejudgment",
"prejudiced":"prejudice",
"prejudices":"prejudice",
"prejudicing":"prejudice",
"prelacies":"prelacy",
"prelates":"prelate",
"prelatures":"prelature",
"prelims":"prelim",
"preliminaries":"preliminary",
"prelimses":"prelims",
"preluded":"prelude",
"preludes":"prelude",
"preluding":"prelude",
"prematurenesses":"prematureness",
"prematurities":"prematurity",
"premaxillae":"premaxilla",
"premeditated":"premeditate",
"premeditating":"premeditate",
"premies":"premie",
"premiered":"premiere",
"premiering":"premiere",
"premiers":"premier",
"premieres":"premiere",
"premised":"premise",
"premises":"premise",
"premising":"premise",
"premisses":"premiss",
"premiums":"premium",
"premixes":"premix",
"premolars":"premolar",
"premonished":"premonish",
"premonishing":"premonish",
"premonitions":"premonition",
"prenantheses":"prenanthes",
"prenonomens":"prenomen",
"prenonomina":"prenomen",
"prentices":"prentice",
"preoccupancies":"preoccupancy",
"preoccupations":"preoccupation",
"preoccupied":"preoccupy",
"preoccupies":"preoccupy",
"preoccupying":"preoccupy",
"preordained":"preordain",
"preordaining":"preordain",
"preordains":"preordain",
"preordinations":"preordination",
"prepped":"prep",
"prepping":"prep",
"preps":"prep",
"prepacked":"prepack",
"prepacking":"prepack",
"prepackaged":"prepackage",
"prepackaging":"prepackage",
"preparations":"preparation",
"preparatories":"preparatory",
"prepared":"prepare",
"prepares":"prepare",
"preparing":"prepare",
"preparednesses":"preparedness",
"prepaid":"prepay",
"prepaying":"prepay",
"prepays":"prepay",
"preponderances":"preponderance",
"preponderated":"preponderate",
"preponderates":"preponderate",
"preponderating":"preponderate",
"prepositions":"preposition",
"prepossessed":"prepossess",
"prepossesses":"prepossess",
"prepossessing":"prepossess",
"prepossessions":"prepossession",
"preppies":"preppy",
"prepuces":"prepuce",
"prerecorded":"prerecord",
"prerecording":"prerecord",
"prerequisites":"prerequisite",
"prerogatives":"prerogative",
"prese":"presa",
"presaged":"presage",
"presages":"presage",
"presaging":"presage",
"presbyteries":"presbytery",
"presbyteses":"presbytes",
"presciences":"prescience",
"prescinded":"prescind",
"prescinding":"prescind",
"prescribed":"prescribe",
"prescribes":"prescribe",
"prescribing":"prescribe",
"prescripts":"prescript",
"prescriptions":"prescription",
"presences":"presence",
"presented":"present",
"presenting":"present",
"presents":"present",
"presentations":"presentation",
"presenters":"presenter",
"presentiments":"presentiment",
"presentments":"presentment",
"presentnesses":"presentness",
"preservations":"preservation",
"preservatives":"preservative",
"preserved":"preserve",
"preserves":"preserve",
"preserving":"preserve",
"preservers":"preserver",
"preserveses":"preserves",
"preservings":"preserving",
"presetting":"preset",
"presided":"preside",
"presides":"preside",
"presiding":"preside",
"presidencies":"presidency",
"presidents":"president",
"presidentships":"presidentship",
"presidios":"presidio",
"presidia":"presidium",
"presidiums":"presidium",
"presignified":"presignify",
"presignifies":"presignify",
"presignifying":"presignify",
"pressed":"press",
"presses":"press",
"pressing":"press",
"press-ups":"press-up",
"pressings":"pressing",
"pressmen":"pressman",
"pressmarks":"pressmark",
"pressured":"pressure",
"pressures":"pressure",
"pressuring":"pressure",
"pressurized":"pressurize",
"pressurizes":"pressurize",
"pressurizing":"pressurize",
"prestidigitations":"prestidigitation",
"prestidigitators":"prestidigitator",
"prestiges":"prestige",
"prestigiousnesses":"prestigiousness",
"prestissimos":"prestissimo",
"prestos":"presto",
"presumed":"presume",
"presumes":"presume",
"presuming":"presume",
"presumptions":"presumption",
"presumptuousnesses":"presumptuousness",
"presupposed":"presuppose",
"presupposing":"presuppose",
"presuppositions":"presupposition",
"pretences":"pretence",
"pretended":"pretend",
"pretending":"pretend",
"pretends":"pretend",
"pretenders":"pretender",
"pretendings":"pretending",
"pretenses":"pretense",
"pretensions":"pretension",
"pretentiousnesses":"pretentiousness",
"preterits":"preterit",
"preterites":"preterite",
"preteritions":"preterition",
"pretermissions":"pretermission",
"pretermits":"pretermit",
"pretermitted":"pretermit",
"pretermitting":"pretermit",
"pretested":"pretest",
"pretesting":"pretest",
"pretexts":"pretext",
"pretors":"pretor",
"pretorias":"pretoria",
"pretoriums":"pretorium",
"pretrials":"pretrial",
"prettified":"prettify",
"prettifies":"prettify",
"prettifying":"prettify",
"prettinesses":"prettiness",
"prettied":"pretty",
"prettier":"pretty",
"pretties":"pretty",
"prettiest":"pretty",
"prettying":"pretty",
"preussens":"preussen",
"prevailed":"prevail",
"prevailing":"prevail",
"prevails":"prevail",
"prevalences":"prevalence",
"prevaricated":"prevaricate",
"prevaricates":"prevaricate",
"prevaricating":"prevaricate",
"prevarications":"prevarication",
"prevaricators":"prevaricator",
"prevented":"prevent",
"preventing":"prevent",
"prevents":"prevent",
"preventatives":"preventative",
"preventions":"prevention",
"preventives":"preventive",
"previewed":"preview",
"previewing":"preview",
"previews":"preview",
"previsions":"prevision",
"prevues":"prevue",
"prexes":"prexy",
"prexies":"prexy",
"preyed":"prey",
"preying":"prey",
"preys":"prey",
"preyings":"preying",
"priacanthidaes":"priacanthidae",
"priacanthuses":"priacanthus",
"priced":"price",
"prices":"price",
"pricing":"price",
"pricelessnesses":"pricelessness",
"pricier":"pricey",
"priciest":"pricey",
"pricked":"prick",
"pricking":"prick",
"pricks":"prick",
"prickers":"pricker",
"prickled":"prickle",
"prickles":"prickle",
"prickling":"prickle",
"prickle-weeds":"prickle-weed",
"pricklebacks":"prickleback",
"pricklings":"prickling",
"pricklier":"prickly",
"prickliest":"prickly",
"prickteasers":"prickteaser",
"prided":"pride",
"prides":"pride",
"priding":"pride",
"pride-of-indias":"pride-of-india",
"pridefulnesses":"pridefulness",
"prie-dieus":"prie-dieu",
"prie-dieux":"prie-dieu",
"priested":"priest",
"priesting":"priest",
"priests":"priest",
"priest-doctors":"priest-doctor",
"priestlier":"priestly",
"priestliest":"priestly",
"prigs":"prig",
"priggishnesses":"priggishness",
"prilled":"prill",
"prilling":"prill",
"primmed":"prim",
"primmer":"prim",
"primmest":"prim",
"primming":"prim",
"prims":"prim",
"primacies":"primacy",
"primaries":"primary",
"primates":"primate",
"primateses":"primates",
"primed":"prime",
"primes":"prime",
"priming":"prime",
"primeministers":"primeminister",
"primers":"primer",
"primigravidas":"primigravida",
"primiparae":"primipara",
"primiparas":"primipara",
"primitives":"primitive",
"primitivenesses":"primitiveness",
"primitivisms":"primitivism",
"primnesses":"primness",
"primi":"primo",
"primos":"primo",
"primogenitors":"primogenitor",
"primordia":"primordium",
"primordiums":"primordium",
"primped":"primp",
"primping":"primp",
"primps":"primp",
"primroses":"primrose",
"primulas":"primula",
"primulaceaes":"primulaceae",
"primulaleses":"primulales",
"primuses":"primus",
"princes":"prince",
"princedoms":"princedom",
"princelier":"princely",
"princeliest":"princely",
"princesses":"princess",
"princetons":"princeton",
"princewoods":"princewood",
"principals":"principal",
"principalities":"principality",
"principia":"principium",
"principiia":"principium",
"principles":"principle",
"prinias":"prinia",
"prinked":"prink",
"prinking":"prink",
"prinks":"prink",
"printed":"print",
"printing":"print",
"prints":"print",
"printers":"printer",
"printeries":"printery",
"printings":"printing",
"printmakers":"printmaker",
"priodonteses":"priodontes",
"prionaces":"prionace",
"prionotuses":"prionotus",
"priors":"prior",
"prioresses":"prioress",
"priorities":"priority",
"priories":"priory",
"prisms":"prism",
"prisons":"prison",
"prison-breakings":"prison-breaking",
"prisonbreaks":"prisonbreak",
"prisoners":"prisoner",
"prissier":"prissy",
"prissiest":"prissy",
"pristidaes":"pristidae",
"pristises":"pristis",
"pritzelagos":"pritzelago",
"privacies":"privacy",
"privates":"private",
"privateered":"privateer",
"privateering":"privateer",
"privateers":"privateer",
"privateersmen":"privateersman",
"privatenesses":"privateness",
"privateses":"privates",
"privations":"privation",
"privileged":"privilege",
"privileges":"privilege",
"privileging":"privilege",
"privities":"privity",
"privies":"privy",
"prized":"prize",
"prizes":"prize",
"prizing":"prize",
"prizefights":"prizefight",
"prizefighters":"prizefighter",
"pros":"pro",
"probabilities":"probability",
"probated":"probate",
"probates":"probate",
"probating":"probate",
"probationers":"probationer",
"probed":"probe",
"probes":"probe",
"probing":"probe",
"probings":"probing",
"problems":"problem",
"proboscideas":"proboscidea",
"proboscideans":"proboscidean",
"proboscidians":"proboscidian",
"proboscides":"proboscis",
"proboscises":"proboscis",
"procaryotes":"procaryote",
"procavias":"procavia",
"procaviidaes":"procaviidae",
"procedures":"procedure",
"proceeded":"proceed",
"proceeding":"proceed",
"proceeds":"proceed",
"proceedings":"proceeding",
"proceedingses":"proceedings",
"proceedses":"proceeds",
"procellarias":"procellaria",
"procellariidaes":"procellariidae",
"procellariiformeses":"procellariiformes",
"proces-verbaux":"proces-verbal",
"processed":"process",
"processes":"process",
"processing":"process",
"processioned":"procession",
"processioning":"procession",
"processions":"procession",
"processionals":"processional",
"processors":"processor",
"prociphiluses":"prociphilus",
"proclaimed":"proclaim",
"proclaiming":"proclaim",
"proclaims":"proclaim",
"proclamations":"proclamation",
"proclivities":"proclivity",
"procniases":"procnias",
"proconsulates":"proconsulate",
"proconsulships":"proconsulship",
"procrastinated":"procrastinate",
"procrastinates":"procrastinate",
"procrastinating":"procrastinate",
"procrastinations":"procrastination",
"procrastinators":"procrastinator",
"procreated":"procreate",
"procreates":"procreate",
"procreating":"procreate",
"procreations":"procreation",
"proctored":"proctor",
"proctoring":"proctor",
"proctors":"proctor",
"procurals":"procural",
"procurances":"procurance",
"procurators":"procurator",
"procured":"procure",
"procures":"procure",
"procuring":"procure",
"procurements":"procurement",
"procurers":"procurer",
"procyons":"procyon",
"procyonidaes":"procyonidae",
"prodded":"prod",
"prodding":"prod",
"prods":"prod",
"proddings":"prodding",
"prodigals":"prodigal",
"prodigalities":"prodigality",
"prodigies":"prodigy",
"produced":"produce",
"produces":"produce",
"producing":"produce",
"producers":"producer",
"products":"product",
"productions":"production",
"productivenesses":"productiveness",
"productivities":"productivity",
"profanations":"profanation",
"profaned":"profane",
"profanes":"profane",
"profaning":"profane",
"profanenesses":"profaneness",
"profanities":"profanity",
"professed":"profess",
"professes":"profess",
"professing":"profess",
"professings":"professing",
"professions":"profession",
"professionals":"professional",
"professionalized":"professionalize",
"professionalizing":"professionalize",
"professors":"professor",
"professorships":"professorship",
"proffered":"proffer",
"proffering":"proffer",
"proffers":"proffer",
"proficiencies":"proficiency",
"proficients":"proficient",
"profiled":"profile",
"profiles":"profile",
"profiling":"profile",
"profited":"profit",
"profiting":"profit",
"profits":"profit",
"profitabilities":"profitability",
"profitablenesses":"profitableness",
"profiteered":"profiteer",
"profiteering":"profiteer",
"profiteers":"profiteer",
"profitses":"profits",
"profligacies":"profligacy",
"profligates":"profligate",
"profounder":"profound",
"profoundest":"profound",
"profoundnesses":"profoundness",
"profundities":"profundity",
"profusenesses":"profuseness",
"profusions":"profusion",
"progged":"prog",
"progging":"prog",
"progenitors":"progenitor",
"progenies":"progeny",
"proglotglottides":"proglottid",
"proglottides":"proglottid",
"prognes":"progne",
"prognoses":"prognosis",
"prognostics":"prognostic",
"prognosticated":"prognosticate",
"prognosticates":"prognosticate",
"prognosticating":"prognosticate",
"prognostications":"prognostication",
"prognosticators":"prognosticator",
"programed":"program",
"programing":"program",
"programmed":"program",
"programming":"program",
"programs":"program",
"programmes":"programme",
"programmers":"programmer",
"programmings":"programming",
"progressed":"progress",
"progresses":"progress",
"progressing":"progress",
"progressions":"progression",
"progressives":"progressive",
"progressivenesses":"progressiveness",
"progressivities":"progressivity",
"prohibited":"prohibit",
"prohibiting":"prohibit",
"prohibits":"prohibit",
"prohibiters":"prohibiter",
"prohibitions":"prohibition",
"prohibitionists":"prohibitionist",
"projected":"project",
"projecting":"project",
"projects":"project",
"projectiles":"projectile",
"projections":"projection",
"projectionists":"projectionist",
"prokaryotes":"prokaryote",
"prolapsed":"prolapse",
"prolapses":"prolapse",
"prolapsing":"prolapse",
"prolapsuses":"prolapsus",
"proles":"prole",
"prolegomena":"prolegomenon",
"prolepses":"prolepsis",
"proletarians":"proletarian",
"proletariats":"proletariat",
"proletaries":"proletary",
"proletartaries":"proletary",
"proliferated":"proliferate",
"proliferating":"proliferate",
"prolificacies":"prolificacy",
"prolixities":"prolixity",
"prolixnesses":"prolixness",
"prologed":"prolog",
"prologing":"prolog",
"prologs":"prolog",
"prologued":"prologue",
"prologues":"prologue",
"prologuing":"prologue",
"prologuized":"prologuize",
"prologuizing":"prologuize",
"prolonged":"prolong",
"prolonging":"prolong",
"prolongs":"prolong",
"prolongations":"prolongation",
"prolusions":"prolusion",
"proms":"prom",
"promenaded":"promenade",
"promenades":"promenade",
"promenading":"promenade",
"promethiums":"promethium",
"prominences":"prominence",
"promiscuities":"promiscuity",
"promiscuousnesses":"promiscuousness",
"promised":"promise",
"promises":"promise",
"promising":"promise",
"promisers":"promiser",
"promisors":"promisor",
"promos":"promo",
"promontories":"promontory",
"promoted":"promote",
"promotes":"promote",
"promoting":"promote",
"promoters":"promoter",
"promotions":"promotion",
"prompted":"prompt",
"prompter":"prompt",
"promptest":"prompt",
"prompting":"prompt",
"prompts":"prompt",
"promptbooks":"promptbook",
"prompters":"prompter",
"promptings":"prompting",
"promptitudes":"promptitude",
"promptnesses":"promptness",
"promulgated":"promulgate",
"promulgates":"promulgate",
"promulgating":"promulgate",
"promulgations":"promulgation",
"promycelilia":"promycelium",
"pronated":"pronate",
"pronating":"pronate",
"pronephra":"pronephros",
"pronephroi":"pronephros",
"pronged":"prong",
"pronging":"prong",
"prongbucks":"prongbuck",
"pronghorns":"pronghorn",
"pronouns":"pronoun",
"pronounced":"pronounce",
"pronounces":"pronounce",
"pronouncing":"pronounce",
"pronouncements":"pronouncement",
"pronuclei":"pronucleus",
"pronunciamentoes":"pronunciamento",
"pronunciamentos":"pronunciamento",
"pronunciations":"pronunciation",
"proofed":"proof",
"proofing":"proof",
"proofs":"proof",
"prooves":"proof",
"proofreading":"proofread",
"proofreads":"proofread",
"propped":"prop",
"propping":"prop",
"props":"prop",
"propagandists":"propagandist",
"propagandized":"propagandize",
"propagandizing":"propagandize",
"propagated":"propagate",
"propagates":"propagate",
"propagating":"propagate",
"propagations":"propagation",
"propagators":"propagator",
"propanals":"propanal",
"propanamides":"propanamide",
"propanols":"propanol",
"propanones":"propanone",
"propelled":"propel",
"propelling":"propel",
"propels":"propel",
"propellants":"propellant",
"propellents":"propellent",
"propellers":"propeller",
"propellors":"propellor",
"propenals":"propenal",
"propended":"propend",
"propending":"propend",
"propenes":"propene",
"propenoates":"propenoate",
"propenonitriles":"propenonitrile",
"propensities":"propensity",
"propernesses":"properness",
"properties":"property",
"prophecies":"prophecy",
"prophesied":"prophesy",
"prophesies":"prophesy",
"prophesying":"prophesy",
"prophets":"prophet",
"prophylactics":"prophylactic",
"prophylaxes":"prophylaxis",
"propinquities":"propinquity",
"propionaldehydes":"propionaldehyde",
"propitiated":"propitiate",
"propitiates":"propitiate",
"propitiating":"propitiate",
"propitiations":"propitiation",
"propitiousnesses":"propitiousness",
"propjets":"propjet",
"propmen":"propman",
"proponed":"propone",
"proponing":"propone",
"proponents":"proponent",
"proportioning":"proportion",
"proportions":"proportion",
"proportionals":"proportional",
"proportionalities":"proportionality",
"proportionated":"proportionate",
"proportionating":"proportionate",
"proportionatenesses":"proportionateness",
"proposals":"proposal",
"proposes":"propose",
"proposing":"propose",
"proposers":"proposer",
"propositioned":"proposition",
"propositioning":"proposition",
"propositions":"proposition",
"propositi":"propositus",
"propounded":"propound",
"propounding":"propound",
"propoxyphenes":"propoxyphene",
"propranolols":"propranolol",
"proprietaries":"proprietary",
"proprietors":"proprietor",
"proprietorships":"proprietorship",
"proprieties":"propriety",
"proprionamides":"proprionamide",
"proptoses":"proptosis",
"propulsions":"propulsion",
"propyls":"propyl",
"propylaea":"propylaeum",
"propylenes":"propylene",
"propyla":"propylon",
"propylons":"propylon",
"prorated":"prorate",
"prorating":"prorate",
"prorogued":"prorogue",
"proroguing":"prorogue",
"prosaicnesses":"prosaicness",
"prosauropodas":"prosauropoda",
"prosceniums":"proscenium",
"proscribed":"proscribe",
"proscribes":"proscribe",
"proscribing":"proscribe",
"proscriptions":"proscription",
"prosed":"prose",
"proses":"prose",
"prosing":"prose",
"prosected":"prosect",
"prosecting":"prosect",
"prosecuted":"prosecute",
"prosecutes":"prosecute",
"prosecuting":"prosecute",
"prosecutions":"prosecution",
"prosecutors":"prosecutor",
"proselyted":"proselyte",
"proselyting":"proselyte",
"proselytisms":"proselytism",
"proselytized":"proselytize",
"proselytizing":"proselytize",
"prosencephala":"prosencephalon",
"prosencephalons":"prosencephalon",
"proserpinas":"proserpina",
"proserpines":"proserpine",
"prosimiis":"prosimii",
"prosinesses":"prosiness",
"prosodions":"prosodion",
"prosodies":"prosody",
"prosopises":"prosopis",
"prosopiums":"prosopium",
"prosopopeias":"prosopopeia",
"prosopopoeias":"prosopopoeia",
"prospected":"prospect",
"prospecting":"prospect",
"prospects":"prospect",
"prospectors":"prospector",
"prospectuses":"prospectus",
"prospered":"prosper",
"prospering":"prosper",
"prospers":"prosper",
"prosperities":"prosperity",
"prostates":"prostate",
"prostatectomies":"prostatectomy",
"prostheses":"prosthesis",
"prostituted":"prostitute",
"prostitutes":"prostitute",
"prostituting":"prostitute",
"prostitutions":"prostitution",
"prostomia":"prostomium",
"prostrated":"prostrate",
"prostrates":"prostrate",
"prostrating":"prostrate",
"prosier":"prosy",
"prosiest":"prosy",
"protactiniums":"protactinium",
"protagonists":"protagonist",
"protanopias":"protanopia",
"protases":"protasis",
"proteaceaes":"proteaceae",
"protealeses":"proteales",
"proteases":"protease",
"protected":"protect",
"protecting":"protect",
"protectings":"protecting",
"protections":"protection",
"protectors":"protector",
"protectorates":"protectorate",
"protectories":"protectory",
"proteidaes":"proteidae",
"proteins":"protein",
"proteinases":"proteinase",
"proteinurias":"proteinuria",
"proteleses":"proteles",
"proterochampsas":"proterochampsa",
"proterozoics":"proterozoic",
"protested":"protest",
"protesting":"protest",
"protests":"protest",
"Protestants":"Protestant",
"protestations":"protestation",
"protesters":"protester",
"proteuses":"proteus",
"prothalamia":"prothalamion",
"prothalamimia":"prothalamion",
"prothallia":"prothallium",
"prothalli":"prothallus",
"prothonotaries":"prothonotary",
"prothothoraces":"prothorax",
"prothothoraxes":"prothorax",
"protists":"protist",
"protistas":"protista",
"protistans":"protistan",
"protiums":"protium",
"protoactiniums":"protoactinium",
"protoanthropologies":"protoanthropology",
"protoarchaeologies":"protoarchaeology",
"protoarcheologies":"protoarcheology",
"protocoled":"protocol",
"protocoling":"protocol",
"protocols":"protocol",
"protoctistas":"protoctista",
"protohistories":"protohistory",
"protomammals":"protomammal",
"protonemata":"protonema",
"protoplasms":"protoplasm",
"protoplasts":"protoplast",
"prototherias":"prototheria",
"prototypes":"prototype",
"protozoas":"protozoa",
"protozoa":"protozoan",
"protozoans":"protozoan",
"protozoons":"protozoon",
"protracted":"protract",
"protracting":"protract",
"protracts":"protract",
"protractions":"protraction",
"protruded":"protrude",
"protrudes":"protrude",
"protruding":"protrude",
"protrusions":"protrusion",
"protuberances":"protuberance",
"protuberated":"protuberate",
"protuberating":"protuberate",
"proturas":"protura",
"proturans":"proturan",
"prouder":"proud",
"proudest":"proud",
"prousts":"proust",
"provabilities":"provability",
"proved":"prove",
"proven":"prove",
"proves":"prove",
"proving":"prove",
"provenances":"provenance",
"provencals":"provencal",
"provenders":"provender",
"proventils":"proventil",
"proventricutriculi":"proventriculus",
"proveras":"provera",
"proverbs":"proverb",
"provides":"provide",
"providing":"provide",
"providences":"providence",
"providers":"provider",
"providings":"providing",
"provinces":"province",
"provincials":"provincial",
"provincialisms":"provincialism",
"provincialized":"provincialize",
"provincializing":"provincialize",
"provings":"proving",
"provisioned":"provision",
"provisioning":"provision",
"provisions":"provision",
"provisionals":"provisional",
"provisioners":"provisioner",
"provisionses":"provisions",
"provisoes":"proviso",
"provisos":"proviso",
"provos":"provo",
"provocations":"provocation",
"provoked":"provoke",
"provokes":"provoke",
"provoking":"provoke",
"provokers":"provoker",
"prows":"prow",
"prowesses":"prowess",
"prowled":"prowl",
"prowling":"prowl",
"prowls":"prowl",
"prowlers":"prowler",
"proximas":"proxima",
"proximities":"proximity",
"proxies":"proxy",
"prozacs":"prozac",
"prudes":"prude",
"prudences":"prudence",
"pruderies":"prudery",
"prudishnesses":"prudishness",
"prumnopityses":"prumnopitys",
"pruned":"prune",
"prunes":"prune",
"pruning":"prune",
"prunellas":"prunella",
"prunellidaes":"prunellidae",
"pruners":"pruner",
"prunuses":"prunus",
"pruriences":"prurience",
"pruriencies":"pruriency",
"prussias":"prussia",
"pried":"pry",
"pries":"pry",
"prying":"pry",
"pryings":"prying",
"prytanea":"prytaneum",
"pses":"ps",
"psalmed":"psalm",
"psalming":"psalm",
"psalms":"psalm",
"psalmodies":"psalmody",
"psalters":"psalter",
"psalteriums":"psalterium",
"psalteries":"psaltery",
"psaltriparuses":"psaltriparus",
"psammomas":"psammoma",
"pseneses":"psenes",
"psephuruses":"psephurus",
"psettas":"psetta",
"psettichthyses":"psettichthys",
"pseuds":"pseud",
"pseudacrises":"pseudacris",
"pseudaletias":"pseudaletia",
"pseudechises":"pseudechis",
"pseudemyses":"pseudemys",
"pseudos":"pseudo",
"pseudobombaxes":"pseudobombax",
"pseudocarps":"pseudocarp",
"pseudococcidaes":"pseudococcidae",
"pseudococcuses":"pseudococcus",
"pseudocoluses":"pseudocolus",
"pseudolarixes":"pseudolarix",
"pseudomonadaleses":"pseudomonadales",
"pseudomonases":"pseudomonas",
"pseudomonodaceaes":"pseudomonodaceae",
"pseudomutualities":"pseudomutuality",
"pseudonyms":"pseudonym",
"pseudopleuronecteses":"pseudopleuronectes",
"pseudopods":"pseudopod",
"pseudopodia":"pseudopodium",
"pseudopodiums":"pseudopodium",
"pseudoryxes":"pseudoryx",
"pseudoscorpions":"pseudoscorpion",
"pseudoscorpioneses":"pseudoscorpiones",
"pseudoscorpionidas":"pseudoscorpionida",
"pseudotaxuses":"pseudotaxus",
"pseudotsugas":"pseudotsuga",
"pseudowinteras":"pseudowintera",
"pshawed":"pshaw",
"pshawing":"pshaw",
"pshaws":"pshaw",
"psis":"psi",
"psidiums":"psidium",
"psilocins":"psilocin",
"psilocybins":"psilocybin",
"psilophytaceaes":"psilophytaceae",
"psilophytaleses":"psilophytales",
"psilopsidas":"psilopsida",
"psilotaceaes":"psilotaceae",
"psilotaleses":"psilotales",
"psilotataes":"psilotatae",
"psilotums":"psilotum",
"psithyruses":"psithyrus",
"psittacidaes":"psittacidae",
"psittaciformeses":"psittaciformes",
"psittacosaurs":"psittacosaur",
"psittacosauruses":"psittacosaurus",
"psittacoses":"psittacosis",
"psittaculas":"psittacula",
"psittacuses":"psittacus",
"psoae":"psoas",
"psoai":"psoas",
"psocidaes":"psocidae",
"psocopteras":"psocoptera",
"psophias":"psophia",
"psophiidaes":"psophiidae",
"psophocarpuses":"psophocarpus",
"psoraleas":"psoralea",
"psts":"pst",
"psyches":"psyche",
"psychiatrists":"psychiatrist",
"psychiatries":"psychiatry",
"psychics":"psychic",
"psychos":"psycho",
"psychoanalyses":"psychoanalysis",
"psychoanalysts":"psychoanalyst",
"psychoanalyzed":"psychoanalyze",
"psychoanalyzes":"psychoanalyze",
"psychoanalyzing":"psychoanalyze",
"psychodidaes":"psychodidae",
"psychohistories":"psychohistory",
"psychokineses":"psychokinesis",
"psychologists":"psychologist",
"psychologized":"psychologize",
"psychologizing":"psychologize",
"psychologies":"psychology",
"psychometricses":"psychometrics",
"psychometries":"psychometry",
"psychoneuroses":"psychoneurosis",
"psychoneurotics":"psychoneurotic",
"psychonomicses":"psychonomics",
"psychopaths":"psychopath",
"psychopathologies":"psychopathology",
"psychopathies":"psychopathy",
"psychophysiologies":"psychophysiology",
"psychopses":"psychopsis",
"psychochoses":"psychosis",
"psychoses":"psychosis",
"psychotherapeuticses":"psychotherapeutics",
"psychotherapists":"psychotherapist",
"psychotherapies":"psychotherapy",
"psychotics":"psychotic",
"psychotrias":"psychotria",
"psyllas":"psylla",
"psyllids":"psyllid",
"psyllidaes":"psyllidae",
"psylliums":"psyllium",
"pts":"pt",
"ptarmigans":"ptarmigan",
"pteretises":"pteretis",
"pteridaceaes":"pteridaceae",
"pteridiums":"pteridium",
"pteridophytas":"pteridophyta",
"pteridophytes":"pteridophyte",
"pteridosperms":"pteridosperm",
"pteridospermaes":"pteridospermae",
"pteridospermaphytas":"pteridospermaphyta",
"pteridospermopsidas":"pteridospermopsida",
"pteriidaes":"pteriidae",
"pterises":"pteris",
"pternohylas":"pternohyla",
"pterocarpuses":"pterocarpus",
"pterocaryas":"pterocarya",
"pterocleses":"pterocles",
"pteroclididaes":"pteroclididae",
"pterocnemias":"pterocnemia",
"pterodactylidaes":"pterodactylidae",
"pterodactyluses":"pterodactylus",
"pteroises":"pterois",
"pteropogons":"pteropogon",
"pteropsidas":"pteropsida",
"pteropuses":"pteropus",
"pterosaurs":"pterosaur",
"pterosaurias":"pterosauria",
"pterospermums":"pterospermum",
"pterostylises":"pterostylis",
"pterygia":"pterygium",
"pterylae":"pteryla",
"ptilocercuses":"ptilocercus",
"ptilocrinuses":"ptilocrinus",
"ptilonorhynchidaes":"ptilonorhynchidae",
"ptilonorhynchuses":"ptilonorhynchus",
"ptlorises":"ptloris",
"ptochocracies":"ptochocracy",
"ptolemies":"ptolemy",
"ptomains":"ptomain",
"ptomaines":"ptomaine",
"ptoses":"ptosis",
"ptsds":"ptsd",
"ptyases":"ptyas",
"ptychozoons":"ptychozoon",
"pus":"pu",
"pubs":"pub",
"pub-crawled":"pub-crawl",
"pub-crawling":"pub-crawl",
"pub-crawls":"pub-crawl",
"puberties":"puberty",
"pubeses":"pubes",
"pubescences":"pubescence",
"pubes":"pubis",
"pubises":"pubis",
"publics":"public",
"publicans":"publican",
"publications":"publication",
"publicists":"publicist",
"publicities":"publicity",
"publicized":"publicize",
"publicizes":"publicize",
"publicizing":"publicize",
"publicizers":"publicizer",
"publicizings":"publicizing",
"published":"publish",
"publishes":"publish",
"publishing":"publish",
"publishers":"publisher",
"publishings":"publishing",
"puccinias":"puccinia",
"pucciniaceaes":"pucciniaceae",
"puccoons":"puccoon",
"pucks":"puck",
"puckered":"pucker",
"puckering":"pucker",
"puckers":"pucker",
"puckerbushes":"puckerbush",
"puckishnesses":"puckishness",
"puds":"pud",
"pudden-heads":"pudden-head",
"puddings":"pudding",
"puddingwives":"puddingwife",
"puddled":"puddle",
"puddles":"puddle",
"puddling":"puddle",
"puddlers":"puddler",
"pudenda":"pudendum",
"pudginesses":"pudginess",
"pudgier":"pudgy",
"pudgiest":"pudgy",
"pueblos":"pueblo",
"puerarias":"pueraria",
"puerilities":"puerility",
"puffed":"puff",
"puffing":"puff",
"puffs":"puff",
"puffballs":"puffball",
"puffers":"puffer",
"pufferies":"puffery",
"puffinesses":"puffiness",
"puffingls":"puffingl",
"puffinuses":"puffinus",
"puffier":"puffy",
"puffiest":"puffy",
"pugs":"pug",
"pug-dogs":"pug-dog",
"pugilisms":"pugilism",
"pugilists":"pugilist",
"puglias":"puglia",
"pugnacities":"pugnacity",
"pujunans":"pujunan",
"pukas":"puka",
"puked":"puke",
"pukes":"puke",
"puking":"puke",
"pukings":"puking",
"pukus":"puku",
"puli":"pul",
"puls":"pul",
"pulasans":"pulasan",
"pulassans":"pulassan",
"puled":"pule",
"pules":"pule",
"puling":"pule",
"pulexes":"pulex",
"pulicarias":"pulicaria",
"pulicidaes":"pulicidae",
"pulled":"pull",
"pulling":"pull",
"pulls":"pull",
"pull-ins":"pull-in",
"pull-offs":"pull-off",
"pull-ups":"pull-up",
"pullets":"pullet",
"pulleyed":"pulley",
"pulleying":"pulley",
"pulleys":"pulley",
"pulley-blocks":"pulley-block",
"pullings":"pulling",
"pullmans":"pullman",
"pullmen":"pullman",
"pullouts":"pullout",
"pullovers":"pullover",
"pullulated":"pullulate",
"pullulates":"pullulate",
"pullulating":"pullulate",
"pullulations":"pullulation",
"pulmonatas":"pulmonata",
"pulped":"pulp",
"pulping":"pulp",
"pulps":"pulp",
"pulpits":"pulpit",
"pulpier":"pulpy",
"pulpiest":"pulpy",
"pulsated":"pulsate",
"pulsates":"pulsate",
"pulsating":"pulsate",
"pulsatillas":"pulsatilla",
"pulsations":"pulsation",
"pulsed":"pulse",
"pulses":"pulse",
"pulsing":"pulse",
"pulsings":"pulsing",
"pulverisations":"pulverisation",
"pulverizations":"pulverization",
"pulverized":"pulverize",
"pulverizes":"pulverize",
"pulverizing":"pulverize",
"pulverizers":"pulverizer",
"pulvilli":"pulvillus",
"pulvini":"pulvinus",
"pumas":"puma",
"pumiced":"pumice",
"pumices":"pumice",
"pumicing":"pumice",
"pummeled":"pummel",
"pummeling":"pummel",
"pummelled":"pummel",
"pummelling":"pummel",
"pummels":"pummel",
"pummelos":"pummelo",
"pumped":"pump",
"pumping":"pump",
"pumps":"pump",
"pumpernickels":"pumpernickel",
"pumpkins":"pumpkin",
"pumpkinseeds":"pumpkinseed",
"pumpses":"pumps",
"punned":"pun",
"punning":"pun",
"puns":"pun",
"punched":"punch",
"punches":"punch",
"punching":"punch",
"punchballs":"punchball",
"punchers":"puncher",
"punchinelloes":"punchinello",
"punchinellos":"punchinello",
"punchier":"punchy",
"punchiest":"punchy",
"punctilios":"punctilio",
"punctiliousnesses":"punctiliousness",
"punctualities":"punctuality",
"punctuated":"punctuate",
"punctuates":"punctuate",
"punctuating":"punctuate",
"punctuations":"punctuation",
"punctuators":"punctuator",
"punctured":"puncture",
"punctures":"puncture",
"puncturing":"puncture",
"puncturings":"puncturing",
"pundits":"pundit",
"pungapungs":"pungapung",
"pungencies":"pungency",
"punicas":"punica",
"punicaceaes":"punicaceae",
"puninesses":"puniness",
"punished":"punish",
"punishes":"punish",
"punishing":"punish",
"punishments":"punishment",
"Punjabis":"Punjabi",
"punks":"punk",
"punkeys":"punkey",
"punkies":"punkie",
"punnings":"punning",
"punted":"punt",
"punting":"punt",
"punts":"punt",
"punters":"punter",
"puntings":"punting",
"punties":"punty",
"punier":"puny",
"puniest":"puny",
"pupped":"pup",
"pupping":"pup",
"pups":"pup",
"pupae":"pupa",
"pupas":"pupa",
"pupariia":"puparium",
"pupated":"pupate",
"pupating":"pupate",
"pupils":"pupil",
"puppets":"puppet",
"puppeteered":"puppeteer",
"puppeteering":"puppeteer",
"puppetries":"puppetry",
"puppies":"puppy",
"puraus":"purau",
"purchased":"purchase",
"purchases":"purchase",
"purchasing":"purchase",
"purchasers":"purchaser",
"purchasings":"purchasing",
"purdahs":"purdah",
"purer":"pure",
"purest":"pure",
"purebloods":"pureblood",
"purebreds":"purebred",
"pureed":"puree",
"pureeing":"puree",
"purees":"puree",
"purenesses":"pureness",
"purgations":"purgation",
"purgatives":"purgative",
"purgatories":"purgatory",
"purged":"purge",
"purges":"purge",
"purging":"purge",
"purgers":"purger",
"purgings":"purging",
"purified":"purify",
"purifies":"purify",
"purifying":"purify",
"purinethols":"purinethol",
"puritans":"puritan",
"purities":"purity",
"purled":"purl",
"purling":"purl",
"purls":"purl",
"purloined":"purloin",
"purloining":"purloin",
"purloins":"purloin",
"purloos":"purloo",
"purpled":"purple",
"purpler":"purple",
"purples":"purple",
"purplest":"purple",
"purpling":"purple",
"purplenesses":"purpleness",
"purported":"purport",
"purporting":"purport",
"purports":"purport",
"purposed":"purpose",
"purposes":"purpose",
"purposing":"purpose",
"purposefulnesses":"purposefulness",
"purposelessnesses":"purposelessness",
"purpuras":"purpura",
"purred":"purr",
"purring":"purr",
"purrs":"purr",
"pursed":"purse",
"purses":"purse",
"pursing":"purse",
"pursers":"purser",
"pursuances":"pursuance",
"pursued":"pursue",
"pursues":"pursue",
"pursuing":"pursue",
"pursueds":"pursued",
"pursuers":"pursuer",
"pursuits":"pursuit",
"pursier":"pursy",
"pursiest":"pursy",
"purulences":"purulence",
"purulencies":"purulency",
"puruses":"purus",
"purveyed":"purvey",
"purveying":"purvey",
"purveys":"purvey",
"purveyors":"purveyor",
"purviews":"purview",
"puses":"pus",
"puseyisms":"puseyism",
"pushed":"push",
"pushes":"push",
"pushing":"push",
"push-ups":"push-up",
"pushcarts":"pushcart",
"pushchairs":"pushchair",
"pushers":"pusher",
"pushinesses":"pushiness",
"pushings":"pushing",
"pushovers":"pushover",
"pushpins":"pushpin",
"pushups":"pushup",
"pushier":"pushy",
"pushiest":"pushy",
"pusillanimities":"pusillanimity",
"pusillanimousnesses":"pusillanimousness",
"puslies":"pusly",
"pusses":"puss",
"pussleys":"pussley",
"pussies":"pussy",
"pussy-paws":"pussy-paw",
"pussy-pawses":"pussy-paws",
"pussycats":"pussycat",
"pussyfooted":"pussyfoot",
"pussyfooting":"pussyfoot",
"pussyfoots":"pussyfoot",
"pussytoeses":"pussytoes",
"puts":"put",
"putting":"put",
"put-downs":"put-down",
"put-ons":"put-on",
"put-puts":"put-put",
"put-putted":"put-put",
"put-putting":"put-put",
"putatamina":"putamen",
"putrefactions":"putrefaction",
"putrefied":"putrefy",
"putrefies":"putrefy",
"putrefying":"putrefy",
"putrescences":"putrescence",
"putridnesses":"putridness",
"putsches":"putsch",
"putted":"putt",
"putts":"putt",
"puttees":"puttee",
"putties":"putty",
"putteeses":"puttees",
"puttered":"putter",
"puttering":"putter",
"putters":"putter",
"putterers":"putterer",
"puttings":"putting",
"putti":"putto",
"puttied":"putty",
"puttying":"putty",
"puttyroots":"puttyroot",
"puzzled":"puzzle",
"puzzles":"puzzle",
"puzzling":"puzzle",
"puzzlements":"puzzlement",
"puzzlers":"puzzler",
"pvas":"pva",
"pvcs":"pvc",
"pycnanthemums":"pycnanthemum",
"pycnidiia":"pycnidium",
"pycnogonids":"pycnogonid",
"pycnogonidas":"pycnogonida",
"pycnoses":"pycnosis",
"pydnas":"pydna",
"pye-dogs":"pye-dog",
"pygidiia":"pygidium",
"pygmies":"pygmy",
"pygopodidaes":"pygopodidae",
"pygopuses":"pygopus",
"pygoscelises":"pygoscelis",
"pyjamas":"pyjama",
"pyjamases":"pyjamas",
"pyknoses":"pyknosis",
"pylodictuses":"pylodictus",
"pylorectomies":"pylorectomy",
"pylori":"pylorus",
"pyongyangs":"pyongyang",
"pyorrheas":"pyorrhea",
"pyorrhoeas":"pyorrhoea",
"pyracanths":"pyracanth",
"pyracanthas":"pyracantha",
"pyralids":"pyralid",
"pyralidaes":"pyralidae",
"pyralididaes":"pyralididae",
"pyralises":"pyralis",
"pyramided":"pyramid",
"pyramiding":"pyramid",
"pyramids":"pyramid",
"pyraustas":"pyrausta",
"pyres":"pyre",
"pyrenomyceteses":"pyrenomycetes",
"pyrethrums":"pyrethrum",
"pyrexias":"pyrexia",
"pyridoxals":"pyridoxal",
"pyridoxamines":"pyridoxamine",
"pyridoxines":"pyridoxine",
"pyrites":"pyrite",
"pyrocephaluses":"pyrocephalus",
"pyrographies":"pyrography",
"pyrolas":"pyrola",
"pyrolaceaes":"pyrolaceae",
"pyrolatries":"pyrolatry",
"pyrophoruses":"pyrophorus",
"pyroscopes":"pyroscope",
"pyroses":"pyrosis",
"pyrotechnicses":"pyrotechnics",
"pyrotechnies":"pyrotechny",
"pyrrhics":"pyrrhic",
"pyrrhocoridaes":"pyrrhocoridae",
"pyrrhulas":"pyrrhula",
"pyrrhuloxias":"pyrrhuloxia",
"pyrrosias":"pyrrosia",
"pyrularias":"pyrularia",
"pyruses":"pyrus",
"pythiaceaes":"pythiaceae",
"pythonidaes":"pythonidae",
"pythoninaes":"pythoninae",
"pyxes":"pyx",
"pyxidantheras":"pyxidanthera",
"pyxidiia":"pyxidium",
"pyxies":"pyxie",
"pyxides":"pyxis",
"qaddishim":"qaddish",
"qadis":"qadi",
"qatars":"qatar",
"qataris":"qatari",
"qianas":"qiana",
"qiangs":"qiang",
"qiangics":"qiangic",
"qindarkas":"qindarka",
"qintars":"qintar",
"quaaludes":"quaalude",
"quacked":"quack",
"quacking":"quack",
"quacks":"quack",
"quackeries":"quackery",
"quackgrasses":"quackgrass",
"quads":"quad",
"quadragesimas":"quadragesima",
"quadrangles":"quadrangle",
"quadrants":"quadrant",
"quadraphonies":"quadraphony",
"quadrated":"quadrate",
"quadrating":"quadrate",
"quadratics":"quadratic",
"quadrennia":"quadrennium",
"quadrenniums":"quadrennium",
"quadricepses":"quadriceps",
"quadrigae":"quadriga",
"quadrigas":"quadriga",
"quadrilaterals":"quadrilateral",
"quadrillions":"quadrillion",
"quadrillionths":"quadrillionth",
"quadrisected":"quadrisect",
"quadrisecting":"quadrisect",
"quadrivia":"quadrivium",
"quadrupled":"quadruple",
"quadrupling":"quadruple",
"quadruplets":"quadruplet",
"quadruplicated":"quadruplicate",
"quadruplicates":"quadruplicate",
"quadruplicating":"quadruplicate",
"quaffed":"quaff",
"quaffing":"quaff",
"quaffs":"quaff",
"quaggas":"quagga",
"quaggier":"quaggy",
"quaggiest":"quaggy",
"quagmires":"quagmire",
"quahaugs":"quahaug",
"quahogs":"quahog",
"quailed":"quail",
"quailing":"quail",
"quails":"quail",
"quainter":"quaint",
"quaintest":"quaint",
"quaked":"quake",
"quakes":"quake",
"quaking":"quake",
"Quakers":"Quaker",
"quakerses":"quakers",
"quakier":"quaky",
"quakiest":"quaky",
"qualia":"quale",
"qualifications":"qualification",
"qualifiers":"qualifier",
"qualifies":"qualify",
"qualifying":"qualify",
"qualifyings":"qualifying",
"qualities":"quality",
"qualms":"qualm",
"quamashes":"quamash",
"quamassias":"quamassia",
"quandangs":"quandang",
"quandaries":"quandary",
"quandongs":"quandong",
"quangos":"quango",
"quantifiabilities":"quantifiability",
"quantified":"quantify",
"quantifies":"quantify",
"quantifying":"quantify",
"quantisations":"quantisation",
"quantities":"quantity",
"quantizations":"quantization",
"quantized":"quantize",
"quantizing":"quantize",
"quantongs":"quantong",
"quanta":"quantum",
"quantums":"quantum",
"quarantined":"quarantine",
"quarantining":"quarantine",
"quarreled":"quarrel",
"quarreling":"quarrel",
"quarrelled":"quarrel",
"quarrelling":"quarrel",
"quarrels":"quarrel",
"quarrelers":"quarreler",
"quarrelsomenesses":"quarrelsomeness",
"quarriers":"quarrier",
"quarried":"quarry",
"quarries":"quarry",
"quarrying":"quarry",
"quarrymen":"quarryman",
"quarts":"quart",
"quartered":"quarter",
"quartering":"quarter",
"quarters":"quarter",
"quarter-circles":"quarter-circle",
"quarter-hours":"quarter-hour",
"quarterbacked":"quarterback",
"quarterbacking":"quarterback",
"quarterbacks":"quarterback",
"quarterlies":"quarterly",
"quartermasters":"quartermaster",
"quarterns":"quartern",
"quarterses":"quarters",
"quartersawed":"quartersaw",
"quartersawing":"quartersaw",
"quartersawn":"quartersaw",
"quartersaws":"quartersaw",
"quarterstaves":"quarterstaff",
"quartervines":"quartervine",
"quartets":"quartet",
"quartettes":"quartette",
"quartics":"quartic",
"quartos":"quarto",
"quartzs":"quartz",
"quasars":"quasar",
"quashed":"quash",
"quashes":"quash",
"quashing":"quash",
"quassias":"quassia",
"quatercentenaries":"quatercentenary",
"quatercentennials":"quatercentennial",
"quaterns":"quatern",
"quaternaries":"quaternary",
"quaternions":"quaternion",
"quaternities":"quaternity",
"quattuordecillions":"quattuordecillion",
"quavered":"quaver",
"quavering":"quaver",
"quavers":"quaver",
"quays":"quay",
"queasinesses":"queasiness",
"queasier":"queasy",
"queasiest":"queasy",
"quebecs":"quebec",
"quebrachos":"quebracho",
"quechuas":"quechua",
"queened":"queen",
"queening":"queen",
"queens":"queen",
"queenfishes":"queenfish",
"queenlier":"queenly",
"queenliest":"queenly",
"queered":"queer",
"queerer":"queer",
"queerest":"queer",
"queering":"queer",
"queers":"queer",
"queernesses":"queerness",
"quelled":"quell",
"quelling":"quell",
"quells":"quell",
"quellings":"quelling",
"quenched":"quench",
"quenches":"quench",
"quenching":"quench",
"quenchings":"quenching",
"quercitrons":"quercitron",
"quercuses":"quercus",
"queried":"query",
"queries":"query",
"querying":"query",
"quested":"quest",
"questing":"quest",
"quests":"quest",
"questioned":"question",
"questioning":"question",
"questions":"question",
"questionaries":"questionary",
"questioners":"questioner",
"questionings":"questioning",
"questionnaires":"questionnaire",
"quetzales":"quetzal",
"quetzals":"quetzal",
"queued":"queue",
"queues":"queue",
"queuing":"queue",
"quezales":"quezal",
"quiaquias":"quiaquia",
"quibbled":"quibble",
"quibbles":"quibble",
"quibbling":"quibble",
"quibblers":"quibbler",
"quichuas":"quichua",
"quicker":"quick",
"quickest":"quick",
"quick-freezes":"quick-freeze",
"quick-freezing":"quick-freeze",
"quick-froze":"quick-freeze",
"quick-frozen":"quick-freeze",
"quick-wittednesses":"quick-wittedness",
"quickened":"quicken",
"quickening":"quicken",
"quickens":"quicken",
"quickenings":"quickening",
"quickies":"quickie",
"quicklimes":"quicklime",
"quicknesses":"quickness",
"quicksilvered":"quicksilver",
"quicksilvering":"quicksilver",
"quicksilvers":"quicksilver",
"quickstepped":"quickstep",
"quickstepping":"quickstep",
"quicksteps":"quickstep",
"quids":"quid",
"quiddities":"quiddity",
"quiescences":"quiescence",
"quiescencies":"quiescency",
"quieted":"quiet",
"quieter":"quiet",
"quietest":"quiet",
"quieting":"quiet",
"quiets":"quiet",
"quietnesses":"quietness",
"quietudes":"quietude",
"quietuses":"quietus",
"quilled":"quill",
"quilling":"quill",
"quills":"quill",
"quilted":"quilt",
"quilting":"quilt",
"quilts":"quilt",
"quins":"quin",
"quinacrines":"quinacrine",
"quinaries":"quinary",
"quinces":"quince",
"quincentenaries":"quincentenary",
"quincentennials":"quincentennial",
"quines":"quine",
"quinellas":"quinella",
"quinquagesimas":"quinquagesima",
"quinquecentenaries":"quinquecentenary",
"quinquennia":"quinquennium",
"quints":"quint",
"quintals":"quintal",
"quintessences":"quintessence",
"quintets":"quintet",
"quintettes":"quintette",
"quintillions":"quintillion",
"quintillionths":"quintillionth",
"quintupled":"quintuple",
"quintupling":"quintuple",
"quintuplets":"quintuplet",
"quintuplicated":"quintuplicate",
"quintuplicating":"quintuplicate",
"quipped":"quip",
"quipping":"quip",
"quips":"quip",
"quipus":"quipu",
"quiras":"quira",
"quirks":"quirk",
"quirkinesses":"quirkiness",
"quirted":"quirt",
"quirting":"quirt",
"quiscaluses":"quiscalus",
"quislings":"quisling",
"quislingisms":"quislingism",
"quists":"quist",
"quits":"quit",
"quitted":"quit",
"quitting":"quit",
"quitclaimed":"quitclaim",
"quitclaiming":"quitclaim",
"quitclaims":"quitclaim",
"quitos":"quito",
"quittances":"quittance",
"quivered":"quiver",
"quivering":"quiver",
"quivers":"quiver",
"quiverings":"quivering",
"quixotisms":"quixotism",
"quizzed":"quiz",
"quizzes":"quiz",
"quizzing":"quiz",
"quizmasters":"quizmaster",
"quoined":"quoin",
"quoining":"quoin",
"quoins":"quoin",
"quoitses":"quoits",
"quotas":"quota",
"quotations":"quotation",
"quoted":"quote",
"quotes":"quote",
"quoting":"quote",
"qurans":"quran",
"rs":"r",
"ras":"ra",
"rabats":"rabat",
"rabatos":"rabato",
"rabbeted":"rabbet",
"rabbeting":"rabbet",
"rabbets":"rabbet",
"rabbies":"rabbi",
"rabbis":"rabbi",
"rabbited":"rabbit",
"rabbiting":"rabbit",
"rabbits":"rabbit",
"rabbitted":"rabbit",
"rabbitting":"rabbit",
"rabbiteyes":"rabbiteye",
"rabbitfishes":"rabbitfish",
"rabbitries":"rabbitry",
"rabbitweeds":"rabbitweed",
"rabbitwoods":"rabbitwood",
"rabbled":"rabble",
"rabbles":"rabble",
"rabbling":"rabble",
"rabble-rousers":"rabble-rouser",
"rabelaises":"rabelais",
"rabieses":"rabies",
"raccoons":"raccoon",
"raced":"race",
"races":"race",
"racing":"race",
"racecourses":"racecourse",
"racehorses":"racehorse",
"racers":"racer",
"racerunners":"racerunner",
"racetracks":"racetrack",
"raceways":"raceway",
"rachets":"rachet",
"rachises":"rachis",
"rhachises":"rachis",
"rachitises":"rachitis",
"rachycentridaes":"rachycentridae",
"rachycentrons":"rachycentron",
"racialisms":"racialism",
"racialists":"racialist",
"racines":"racine",
"racinesses":"raciness",
"racisms":"racism",
"racists":"racist",
"racked":"rack",
"racking":"rack",
"racks":"rack",
"rack-rented":"rack-rent",
"rack-renting":"rack-rent",
"racketed":"racket",
"racketing":"racket",
"rackets":"racket",
"racketeered":"racketeer",
"racketeering":"racketeer",
"racketeers":"racketeer",
"racketinesses":"racketiness",
"racons":"racon",
"raconteurs":"raconteur",
"racoons":"racoon",
"racquets":"racquet",
"racier":"racy",
"raciest":"racy",
"rads":"rad",
"radars":"radar",
"radials":"radial",
"radians":"radian",
"radiances":"radiance",
"radiancies":"radiancy",
"radiated":"radiate",
"radiates":"radiate",
"radiating":"radiate",
"radiations":"radiation",
"radiators":"radiator",
"radicals":"radical",
"radiigeras":"radiigera",
"radioed":"radio",
"radioing":"radio",
"radios":"radio",
"radio-gramophones":"radio-gramophone",
"radio-phonographs":"radio-phonograph",
"radioactivities":"radioactivity",
"radiobroadcasted":"radiobroadcast",
"radiobroadcasting":"radiobroadcast",
"radiocarbons":"radiocarbon",
"radiocasted":"radiocast",
"radiocasting":"radiocast",
"radiocommunications":"radiocommunication",
"radiograms":"radiogram",
"radiographed":"radiograph",
"radiographing":"radiograph",
"radiographs":"radiograph",
"radiographies":"radiography",
"radiolarias":"radiolaria",
"radiolocations":"radiolocation",
"radiologists":"radiologist",
"radiologies":"radiology",
"radiophoned":"radiophone",
"radiophones":"radiophone",
"radiophoning":"radiophone",
"radioscopies":"radioscopy",
"radiosensitivities":"radiosensitivity",
"radiotelegraphs":"radiotelegraph",
"radiotelegraphies":"radiotelegraphy",
"radiotelephoned":"radiotelephone",
"radiotelephones":"radiotelephone",
"radiotelephoning":"radiotelephone",
"radiotelephonies":"radiotelephony",
"radiotherapists":"radiotherapist",
"radiotherapies":"radiotherapy",
"radishes":"radish",
"radiums":"radium",
"radii":"radius",
"radiuses":"radius",
"radices":"radix",
"radixes":"radix",
"radomes":"radome",
"radons":"radon",
"radulae":"radula",
"radyeras":"radyera",
"raetams":"raetam",
"rafs":"raf",
"raffias":"raffia",
"raffled":"raffle",
"raffles":"raffle",
"raffling":"raffle",
"rafted":"raft",
"rafting":"raft",
"rafts":"raft",
"raftered":"rafter",
"raftering":"rafter",
"rafters":"rafter",
"raftmen":"raftman",
"raftses":"rafts",
"raftsmen":"raftsman",
"ragged":"rag",
"ragging":"rag",
"rags":"rag",
"ragamuffins":"ragamuffin",
"ragbags":"ragbag",
"raged":"rage",
"rages":"rage",
"raging":"rage",
"ragees":"ragee",
"ragis":"ragi",
"ragmen":"ragman",
"ragnaroks":"ragnarok",
"ragouted":"ragout",
"ragouting":"ragout",
"ragouts":"ragout",
"ragtags":"ragtag",
"ragtimes":"ragtime",
"ragweeds":"ragweed",
"ragworts":"ragwort",
"raided":"raid",
"raiding":"raid",
"raids":"raid",
"raiders":"raider",
"railed":"rail",
"railing":"rail",
"rails":"rail",
"railcars":"railcar",
"railings":"railing",
"railleries":"raillery",
"railroaded":"railroad",
"railroading":"railroad",
"railroads":"railroad",
"railroaders":"railroader",
"railses":"rails",
"railways":"railway",
"railwaymen":"railwayman",
"raiments":"raiment",
"rained":"rain",
"raining":"rain",
"rains":"rain",
"rain-givers":"rain-giver",
"rainbows":"rainbow",
"raincoats":"raincoat",
"raindrops":"raindrop",
"rainfalls":"rainfall",
"rainproofed":"rainproof",
"rainproofing":"rainproof",
"rainwaters":"rainwater",
"rainier":"rainy",
"rainiest":"rainy",
"raises":"raise",
"raising":"raise",
"raisers":"raiser",
"raisins":"raisin",
"raisings":"raising",
"rajas":"raja",
"rajahs":"rajah",
"rajidaes":"rajidae",
"rajiformeses":"rajiformes",
"raked":"rake",
"rakes":"rake",
"raking":"rake",
"rakishnesses":"rakishness",
"rales":"rale",
"raleighs":"raleigh",
"rallidaes":"rallidae",
"rallied":"rally",
"rallies":"rally",
"rallying":"rally",
"rallyings":"rallying",
"rammed":"ram",
"ramming":"ram",
"rams":"ram",
"rambled":"ramble",
"rambles":"ramble",
"rambling":"ramble",
"rambotans":"rambotan",
"rambutans":"rambutan",
"ramees":"ramee",
"ramekins":"ramekin",
"ramenta":"ramentum",
"ramequins":"ramequin",
"ramies":"ramie",
"ramifications":"ramification",
"ramified":"ramify",
"ramifies":"ramify",
"ramifying":"ramify",
"ramjets":"ramjet",
"ramonas":"ramona",
"ramontchis":"ramontchi",
"ramped":"ramp",
"ramping":"ramp",
"ramps":"ramp",
"rampaged":"rampage",
"rampages":"rampage",
"rampaging":"rampage",
"ramparted":"rampart",
"ramparting":"rampart",
"ramparts":"rampart",
"ramphastidaes":"ramphastidae",
"ramphomicrons":"ramphomicron",
"rampions":"rampion",
"ramrodded":"ramrod",
"ramrodding":"ramrod",
"ramrods":"ramrod",
"ramsonses":"ramsons",
"rami":"ramus",
"ranas":"rana",
"ranaleses":"ranales",
"ranatras":"ranatra",
"ranched":"ranch",
"ranches":"ranch",
"ranching":"ranch",
"rancheros":"ranchero",
"ranchmen":"ranchman",
"ranchos":"rancho",
"rancors":"rancor",
"rancours":"rancour",
"randomisations":"randomisation",
"randomizations":"randomization",
"randomized":"randomize",
"randomizing":"randomize",
"randomnesses":"randomness",
"randier":"randy",
"randies":"randy",
"randiest":"randy",
"ranees":"ranee",
"ranged":"range",
"ranges":"range",
"ranging":"range",
"rangers":"ranger",
"rangifers":"rangifer",
"rangoons":"rangoon",
"rangpurs":"rangpur",
"rangier":"rangy",
"rangiest":"rangy",
"ranis":"rani",
"ranids":"ranid",
"ranidaes":"ranidae",
"ranitidines":"ranitidine",
"ranked":"rank",
"ranker":"rank",
"rankest":"rank",
"ranking":"rank",
"ranks":"rank",
"rankines":"rankine",
"rankled":"rankle",
"rankles":"rankle",
"rankling":"rankle",
"ranknesses":"rankness",
"ransacked":"ransack",
"ransacking":"ransack",
"ransacks":"ransack",
"ransackings":"ransacking",
"ransomed":"ransom",
"ransoming":"ransom",
"ransoms":"ransom",
"ranted":"rant",
"ranting":"rant",
"rants":"rant",
"ranters":"ranter",
"rantings":"ranting",
"ranunculaceaes":"ranunculaceae",
"ranunculaleses":"ranunculales",
"ranunculuses":"ranunculus",
"raoulias":"raoulia",
"rapped":"rap",
"rapping":"rap",
"raps":"rap",
"rapt":"rap",
"rapaciousnesses":"rapaciousness",
"rapacities":"rapacity",
"rapateaceaes":"rapateaceae",
"raped":"rape",
"rapes":"rape",
"raping":"rape",
"rapers":"raper",
"raphanuses":"raphanus",
"raphae":"raphe",
"raphias":"raphia",
"raphiceruses":"raphicerus",
"raphidaes":"raphidae",
"raphides":"raphide",
"raphidiidaes":"raphidiidae",
"raphuses":"raphus",
"rapider":"rapid",
"rapidest":"rapid",
"rapidities":"rapidity",
"rapines":"rapine",
"rapists":"rapist",
"rappelled":"rappel",
"rappelling":"rappel",
"rappels":"rappel",
"rapports":"rapport",
"rapprochements":"rapprochement",
"rapscallions":"rapscallion",
"raptors":"raptor",
"raptoreses":"raptores",
"raptured":"rapture",
"raptures":"rapture",
"rapturing":"rapture",
"rarer":"rare",
"rarest":"rare",
"rarebits":"rarebit",
"raree-shows":"raree-show",
"rarefied":"rarefy",
"rarefies":"rarefy",
"rarefying":"rarefy",
"rarfied":"rarefy",
"rarfies":"rarefy",
"rarfying":"rarefy",
"rarenesses":"rareness",
"rarities":"rarity",
"rascals":"rascal",
"rascalities":"rascality",
"rased":"rase",
"rases":"rase",
"rasing":"rase",
"rasher":"rash",
"rashes":"rash",
"rashest":"rash",
"rashers":"rasher",
"rashnesses":"rashness",
"raskolnikovs":"raskolnikov",
"rasped":"rasp",
"rasping":"rasp",
"rasps":"rasp",
"raspaies":"raspatory",
"raspberries":"raspberry",
"raspings":"rasping",
"raspier":"raspy",
"raspiest":"raspy",
"rasslings":"rassling",
"rats":"rat",
"ratted":"rat",
"ratting":"rat",
"rat-a-tat-tats":"rat-a-tat-tat",
"rat-catchers":"rat-catcher",
"rat-tats":"rat-tat",
"ratabilities":"ratability",
"ratableses":"ratables",
"ratafees":"ratafee",
"ratafias":"ratafia",
"ratans":"ratan",
"ratches":"ratch",
"ratchets":"ratchet",
"rated":"rate",
"rates":"rate",
"rating":"rate",
"rateabilities":"rateability",
"rateableses":"rateables",
"ratels":"ratel",
"ratepayers":"ratepayer",
"ratfishes":"ratfish",
"ratibidas":"ratibida",
"ratifications":"ratification",
"ratifiers":"ratifier",
"ratified":"ratify",
"ratifies":"ratify",
"ratifying":"ratify",
"ratings":"rating",
"ratios":"ratio",
"ratiocinated":"ratiocinate",
"ratiocinating":"ratiocinate",
"ratiocinators":"ratiocinator",
"rationed":"ration",
"rationing":"ration",
"rations":"ration",
"rationals":"rational",
"rationales":"rationale",
"rationalisations":"rationalisation",
"rationalisms":"rationalism",
"rationalists":"rationalist",
"rationalities":"rationality",
"rationalizations":"rationalization",
"rationalized":"rationalize",
"rationalizes":"rationalize",
"rationalizing":"rationalize",
"rationalnesses":"rationalness",
"ratitaes":"ratitae",
"ratites":"ratite",
"ratlins":"ratlin",
"ratlines":"ratline",
"rattails":"rattail",
"rattans":"rattan",
"ratters":"ratter",
"rattings":"ratting",
"rattled":"rattle",
"rattles":"rattle",
"rattling":"rattle",
"rattleboxes":"rattlebox",
"rattlers":"rattler",
"rattlesnakes":"rattlesnake",
"rattletops":"rattletop",
"rattlings":"rattling",
"rattlier":"rattly",
"rattliest":"rattly",
"rattuses":"rattus",
"rattier":"ratty",
"rattiest":"ratty",
"rau-seds":"rau-sed",
"raunchier":"raunchy",
"raunchiest":"raunchy",
"rauvolfias":"rauvolfia",
"rauwolfias":"rauwolfia",
"ravaged":"ravage",
"ravages":"ravage",
"ravaging":"ravage",
"ravagings":"ravaging",
"raved":"rave",
"raves":"rave",
"raving":"rave",
"raveled":"ravel",
"raveling":"ravel",
"ravelled":"ravel",
"ravelling":"ravel",
"ravels":"ravel",
"ravelings":"raveling",
"ravellings":"ravelling",
"ravened":"raven",
"ravening":"raven",
"ravens":"raven",
"ravenalas":"ravenala",
"ravennas":"ravenna",
"ravenousnesses":"ravenousness",
"ravers":"raver",
"ravines":"ravine",
"ravings":"raving",
"raviolis":"ravioli",
"ravished":"ravish",
"ravishes":"ravish",
"ravishing":"ravish",
"ravishers":"ravisher",
"ravishments":"ravishment",
"rawer":"raw",
"rawest":"raw",
"raws":"raw",
"rawhided":"rawhide",
"rawhiding":"rawhide",
"rayed":"ray",
"raying":"ray",
"rays":"ray",
"rayonses":"rayons",
"raz-cuts":"raz-cut",
"raz-cutting":"raz-cut",
"razed":"raze",
"razes":"raze",
"razing":"raze",
"razeed":"razee",
"razeeing":"razee",
"razees":"razee",
"razings":"razing",
"razmatazs":"razmataz",
"razored":"razor",
"razoring":"razor",
"razors":"razor",
"razorbacks":"razorback",
"razorbills":"razorbill",
"razzed":"razz",
"razzing":"razz",
"razzias":"razzia",
"razzings":"razzing",
"razzles":"razzle",
"razzle-dazzles":"razzle-dazzle",
"razzmatazzs":"razzmatazz",
"rbs":"rb",
"rbis":"rbi",
"res":"re",
"re-acted":"re-act",
"re-acting":"re-act",
"re-afforestations":"re-afforestation",
"re-claimed":"re-claim",
"re-claiming":"re-claim",
"re-counted":"re-count",
"re-counting":"re-count",
"re-covered":"re-cover",
"re-covering":"re-cover",
"re-echoed":"re-echo",
"re-echoing":"re-echo",
"re-edited":"re-edit",
"re-editing":"re-edit",
"re-educated":"re-educate",
"re-educating":"re-educate",
"re-elected":"re-elect",
"re-electing":"re-elect",
"re-embarked":"re-embark",
"re-embarking":"re-embark",
"re-enacted":"re-enact",
"re-enacting":"re-enact",
"re-encountered":"re-encounter",
"re-encountering":"re-encounter",
"re-entries":"re-entry",
"re-equipped":"re-equip",
"re-equipping":"re-equip",
"re-equips":"re-equip",
"re-established":"re-establish",
"re-establishing":"re-establish",
"re-evaluated":"re-evaluate",
"re-evaluating":"re-evaluate",
"re-experienced":"re-experience",
"re-experiencing":"re-experience",
"re-experiencings":"re-experiencing",
"re-formed":"re-form",
"re-forming":"re-form",
"re-laid":"re-lay",
"re-laying":"re-lay",
"re-leased":"re-lease",
"re-leasing":"re-lease",
"re-recorded":"re-record",
"re-recording":"re-record",
"re-sentencings":"re-sentencing",
"re-treading":"re-tread",
"re-treads":"re-tread",
"re-trod":"re-tread",
"re-trodden":"re-tread",
"re-upped":"re-up",
"re-upping":"re-up",
"re-uptakes":"re-uptake",
"reached":"reach",
"reaches":"reach",
"reaching":"reach",
"reachings":"reaching",
"reacted":"react",
"reacting":"react",
"reacts":"react",
"reactions":"reaction",
"reactionaries":"reactionary",
"reactivataing":"reactivate",
"reactivated":"reactivate",
"reactivities":"reactivity",
"reactors":"reactor",
"reading":"read",
"reads":"read",
"readabilities":"readability",
"readdressed":"readdress",
"readdressing":"readdress",
"readers":"reader",
"readinesses":"readiness",
"readings":"reading",
"readjusted":"readjust",
"readjusting":"readjust",
"readjusts":"readjust",
"readjustments":"readjustment",
"readopted":"readopt",
"readopting":"readopt",
"readied":"ready",
"readier":"ready",
"readiest":"ready",
"readying":"ready",
"readyings":"readying",
"reaffirmed":"reaffirm",
"reaffirming":"reaffirm",
"reagans":"reagan",
"reals":"real",
"realigned":"realign",
"realigning":"realign",
"realigns":"realign",
"realisations":"realisation",
"realisms":"realism",
"realists":"realist",
"realities":"reality",
"realizations":"realization",
"realized":"realize",
"realizes":"realize",
"realizing":"realize",
"reallocations":"reallocation",
"reallotments":"reallotment",
"realms":"realm",
"realnesses":"realness",
"realtors":"realtor",
"realties":"realty",
"reamed":"ream",
"reaming":"ream",
"reamers":"reamer",
"reanimated":"reanimate",
"reanimates":"reanimate",
"reanimating":"reanimate",
"reaped":"reap",
"reaping":"reap",
"reaps":"reap",
"reapers":"reaper",
"reappeared":"reappear",
"reappearing":"reappear",
"reappears":"reappear",
"reappointed":"reappoint",
"reappointing":"reappoint",
"reapportioned":"reapportion",
"reapportioning":"reapportion",
"reapportions":"reapportion",
"reapportionings":"reapportioning",
"reapportionments":"reapportionment",
"reappraisals":"reappraisal",
"reappraised":"reappraise",
"reappraising":"reappraise",
"reared":"rear",
"rearing":"rear",
"rears":"rear",
"rearings":"rearing",
"rearmed":"rearm",
"rearming":"rearm",
"rearms":"rearm",
"rearmice":"rearmouse",
"reremice":"rearmouse",
"rearranged":"rearrange",
"rearranging":"rearrange",
"reasoned":"reason",
"reasoning":"reason",
"reasons":"reason",
"reasonablenesses":"reasonableness",
"reasoners":"reasoner",
"reasonings":"reasoning",
"reassembled":"reassemble",
"reassembling":"reassemble",
"reassemblies":"reassembly",
"reasserted":"reassert",
"reasserting":"reassert",
"reasserts":"reassert",
"reassessed":"reassess",
"reassesses":"reassess",
"reassessing":"reassess",
"reassessments":"reassessment",
"reassigned":"reassign",
"reassigning":"reassign",
"reassigns":"reassign",
"reassociated":"reassociate",
"reassociating":"reassociate",
"reassumed":"reassume",
"reassuming":"reassume",
"reassured":"reassure",
"reassures":"reassure",
"reassuring":"reassure",
"reaumurs":"reaumur",
"reaved":"reave",
"reaves":"reave",
"reaving":"reave",
"reft":"reave",
"rebs":"reb",
"rebated":"rebate",
"rebates":"rebate",
"rebating":"rebate",
"rebatos":"rebato",
"rebelled":"rebel",
"rebelling":"rebel",
"rebels":"rebel",
"rebellions":"rebellion",
"rebelliousnesses":"rebelliousness",
"rebinding":"rebind",
"rebound":"rebind",
"rebirths":"rebirth",
"rebounded":"rebound",
"rebounding":"rebound",
"rebounds":"rebound",
"rebozos":"rebozo",
"rebroadcasted":"rebroadcast",
"rebroadcasting":"rebroadcast",
"rebroadcasts":"rebroadcast",
"rebuffed":"rebuff",
"rebuffing":"rebuff",
"rebuffs":"rebuff",
"rebuilding":"rebuild",
"rebuilds":"rebuild",
"rebuilt":"rebuild",
"rebuked":"rebuke",
"rebukes":"rebuke",
"rebuking":"rebuke",
"reburials":"reburial",
"reburied":"rebury",
"reburying":"rebury",
"reburyings":"reburying",
"rebuses":"rebus",
"rebuts":"rebut",
"rebutted":"rebut",
"rebutting":"rebut",
"rebuttals":"rebuttal",
"rebutters":"rebutter",
"recalcitrances":"recalcitrance",
"recalcitrancies":"recalcitrancy",
"recalcitrated":"recalcitrate",
"recalcitrating":"recalcitrate",
"recalled":"recall",
"recalling":"recall",
"recalls":"recall",
"recanted":"recant",
"recanting":"recant",
"recants":"recant",
"recantations":"recantation",
"recapped":"recap",
"recapping":"recap",
"recaps":"recap",
"recapitalized":"recapitalize",
"recapitalizing":"recapitalize",
"recapitulated":"recapitulate",
"recapitulates":"recapitulate",
"recapitulating":"recapitulate",
"recapitulations":"recapitulation",
"recaptured":"recapture",
"recaptures":"recapture",
"recapturing":"recapture",
"recasted":"recast",
"recasting":"recast",
"recasts":"recast",
"recastings":"recasting",
"recces":"recce",
"reccos":"recco",
"reccies":"reccy",
"receded":"recede",
"recedes":"recede",
"receding":"recede",
"recedings":"receding",
"receipted":"receipt",
"receipting":"receipt",
"receipts":"receipt",
"receiptses":"receipts",
"received":"receive",
"receives":"receive",
"receiving":"receive",
"receivers":"receiver",
"receivings":"receiving",
"recencies":"recency",
"recentnesses":"recentness",
"receptacles":"receptacle",
"receptions":"reception",
"receptivenesses":"receptiveness",
"receptivities":"receptivity",
"receptors":"receptor",
"recessed":"recess",
"recesses":"recess",
"recessing":"recess",
"recessions":"recession",
"recharged":"recharge",
"recharges":"recharge",
"recharging":"recharge",
"rechristened":"rechristen",
"rechristening":"rechristen",
"recidivated":"recidivate",
"recidivates":"recidivate",
"recidivating":"recidivate",
"recidivisms":"recidivism",
"recidivists":"recidivist",
"recifes":"recife",
"recipes":"recipe",
"recipients":"recipient",
"reciprocals":"reciprocal",
"reciprocalities":"reciprocality",
"reciprocated":"reciprocate",
"reciprocating":"reciprocate",
"reciprocations":"reciprocation",
"reciprocities":"reciprocity",
"recissions":"recission",
"recitals":"recital",
"recitations":"recitation",
"recited":"recite",
"recites":"recite",
"reciting":"recite",
"recked":"reck",
"recking":"reck",
"recklessnesses":"recklessness",
"reckoned":"reckon",
"reckoning":"reckon",
"reckons":"reckon",
"reckoners":"reckoner",
"reckonings":"reckoning",
"reclaimed":"reclaim",
"reclaiming":"reclaim",
"reclaims":"reclaim",
"reclamations":"reclamation",
"reclassified":"reclassify",
"reclassifying":"reclassify",
"reclined":"recline",
"reclines":"recline",
"reclining":"recline",
"recliners":"recliner",
"reclad":"reclothe",
"reclothed":"reclothe",
"reclothing":"reclothe",
"recluses":"recluse",
"reclusivenesses":"reclusiveness",
"recognisances":"recognisance",
"recognitions":"recognition",
"recognizances":"recognizance",
"recognizes":"recognize",
"recognizing":"recognize",
"recoiled":"recoil",
"recoiling":"recoil",
"recoils":"recoil",
"recoined":"recoin",
"recoining":"recoin",
"recollected":"recollect",
"recollecting":"recollect",
"recollects":"recollect",
"recollections":"recollection",
"recolored":"recolor",
"recoloring":"recolor",
"recombined":"recombine",
"recombining":"recombine",
"recommencements":"recommencement",
"recommended":"recommend",
"recommending":"recommend",
"recommends":"recommend",
"recommendations":"recommendation",
"recommits":"recommit",
"recommitted":"recommit",
"recommitting":"recommit",
"recompensed":"recompense",
"recompenses":"recompense",
"recompensing":"recompense",
"recomposed":"recompose",
"recomposing":"recompose",
"recomputed":"recompute",
"recomputing":"recompute",
"reconciled":"reconcile",
"reconciles":"reconcile",
"reconciling":"reconcile",
"reconcilers":"reconciler",
"reconciliations":"reconciliation",
"reconditenesses":"reconditeness",
"reconditioned":"recondition",
"reconditioning":"recondition",
"reconnected":"reconnect",
"reconnecting":"reconnect",
"reconnoitered":"reconnoiter",
"reconnoitering":"reconnoiter",
"reconnoiters":"reconnoiter",
"reconnoiterings":"reconnoitering",
"reconnoitred":"reconnoitre",
"reconnoitres":"reconnoitre",
"reconnoitring":"reconnoitre",
"reconquered":"reconquer",
"reconquering":"reconquer",
"reconsidered":"reconsider",
"reconsidering":"reconsider",
"reconsiderations":"reconsideration",
"reconsolidated":"reconsolidate",
"reconsolidating":"reconsolidate",
"reconstituted":"reconstitute",
"reconstituting":"reconstitute",
"reconstructed":"reconstruct",
"reconstructing":"reconstruct",
"reconstructs":"reconstruct",
"reconstructions":"reconstruction",
"recontaminated":"recontaminate",
"recontaminating":"recontaminate",
"reconvened":"reconvene",
"reconvening":"reconvene",
"reconverted":"reconvert",
"reconverting":"reconvert",
"reconveyed":"reconvey",
"reconveying":"reconvey",
"reconvicted":"reconvict",
"reconvicting":"reconvict",
"recopied":"recopy",
"recopies":"recopy",
"recopying":"recopy",
"recording":"record",
"records":"record",
"record-breakers":"record-breaker",
"record-holders":"record-holder",
"record-keepers":"record-keeper",
"recordbooks":"recordbook",
"recorders":"recorder",
"recordings":"recording",
"recounted":"recount",
"recounting":"recount",
"recounts":"recount",
"recountings":"recounting",
"recouped":"recoup",
"recouping":"recoup",
"recoups":"recoup",
"recourses":"recourse",
"recovered":"recover",
"recovering":"recover",
"recovers":"recover",
"recoverers":"recoverer",
"recoveries":"recovery",
"recreants":"recreant",
"recreated":"recreate",
"recreates":"recreate",
"recreating":"recreate",
"recreations":"recreation",
"recriminated":"recriminate",
"recriminating":"recriminate",
"recrudesced":"recrudesce",
"recrudescing":"recrudesce",
"recruited":"recruit",
"recruiting":"recruit",
"recruits":"recruit",
"recruitments":"recruitment",
"rectangles":"rectangle",
"rectangularities":"rectangularity",
"rectifications":"rectification",
"rectified":"rectify",
"rectifies":"rectify",
"rectifying":"rectify",
"rectitudes":"rectitude",
"rectos":"recto",
"rectors":"rector",
"rectories":"rectory",
"rectrices":"rectrix",
"recta":"rectum",
"rectums":"rectum",
"recti":"rectus",
"recuperated":"recuperate",
"recuperates":"recuperate",
"recuperating":"recuperate",
"recuperations":"recuperation",
"recurred":"recur",
"recurring":"recur",
"recurs":"recur",
"recurrences":"recurrence",
"recurved":"recurve",
"recurving":"recurve",
"recurvirostras":"recurvirostra",
"recurvirostridaes":"recurvirostridae",
"recusals":"recusal",
"recusants":"recusant",
"recusations":"recusation",
"recycled":"recycle",
"recycles":"recycle",
"recycling":"recycle",
"redded":"redd",
"redder":"red",
"reddest":"red",
"redding":"redd",
"reds":"red",
"red-blindnesses":"red-blindness",
"red-hots":"red-hot",
"red-penciled":"red-pencil",
"red-penciling":"red-pencil",
"red-pencilled":"red-pencil",
"red-pencilling":"red-pencil",
"red-pencillled":"red-pencil",
"red-pencillling":"red-pencil",
"red-pencills":"red-pencil",
"redactions":"redaction",
"redactors":"redactor",
"redbellies":"redbelly",
"redberries":"redberry",
"redbirds":"redbird",
"redbreasts":"redbreast",
"redbrushes":"redbrush",
"redbuds":"redbud",
"redbugs":"redbug",
"redcaps":"redcap",
"redcoats":"redcoat",
"redds":"redd",
"reddened":"redden",
"reddening":"redden",
"reddens":"redden",
"redeemed":"redeem",
"redeeming":"redeem",
"redeems":"redeem",
"redeemers":"redeemer",
"redemonstrated":"redemonstrate",
"redemonstrating":"redemonstrate",
"redemptions":"redemption",
"redeployed":"redeploy",
"redeploying":"redeploy",
"redeployments":"redeployment",
"redescribed":"redescribe",
"redescribing":"redescribe",
"redesigned":"redesign",
"redesigning":"redesign",
"redeveloped":"redevelop",
"redeveloping":"redevelop",
"redevelops":"redevelop",
"redevelopments":"redevelopment",
"redfishes":"redfish",
"redheads":"redhead",
"redheaders":"redheader",
"redhorses":"redhorse",
"rediae":"redia",
"redintegrated":"redintegrate",
"redintegrating":"redintegrate",
"redirected":"redirect",
"redirecting":"redirect",
"redirects":"redirect",
"rediscounted":"rediscount",
"rediscounting":"rediscount",
"rediscovered":"rediscover",
"rediscovering":"rediscover",
"rediscoveries":"rediscovery",
"redispositions":"redisposition",
"redissolved":"redissolve",
"redissolving":"redissolve",
"redistributed":"redistribute",
"redistributing":"redistribute",
"redistricted":"redistrict",
"redistricting":"redistrict",
"redivided":"redivide",
"redividing":"redivide",
"redmaidses":"redmaids",
"rednecks":"redneck",
"rednesses":"redness",
"redid":"redo",
"redoes":"redo",
"redoing":"redo",
"redone":"redo",
"redolences":"redolence",
"redoubled":"redouble",
"redoubles":"redouble",
"redoubling":"redouble",
"redoubts":"redoubt",
"redounded":"redound",
"redounding":"redound",
"redoxes":"redox",
"redpolls":"redpoll",
"redrafted":"redraft",
"redrafting":"redraft",
"redrawing":"redraw",
"redrawn":"redraw",
"redrew":"redraw",
"redressed":"redress",
"redresses":"redress",
"redressing":"redress",
"redriven":"redrive",
"redriving":"redrive",
"redrove":"redrive",
"redroots":"redroot",
"redshanks":"redshank",
"redskins":"redskin",
"redstarts":"redstart",
"redtails":"redtail",
"reduces":"reduce",
"reducing":"reduce",
"reducings":"reducing",
"reductions":"reduction",
"redundances":"redundance",
"redundancies":"redundancy",
"reduplicated":"reduplicate",
"reduplicates":"reduplicate",
"reduplicating":"reduplicate",
"reduviids":"reduviid",
"reduviidaes":"reduviidae",
"redwings":"redwing",
"redwoods":"redwood",
"reeboks":"reebok",
"reechoed":"reecho",
"reechoing":"reecho",
"reeded":"reed",
"reeding":"reed",
"reeds":"reed",
"reedbirds":"reedbird",
"reedbucks":"reedbuck",
"reedited":"reedit",
"reediting":"reedit",
"reedmaces":"reedmace",
"reedier":"reedy",
"reediest":"reedy",
"reefed":"reef",
"reefing":"reef",
"reefs":"reef",
"reefers":"reefer",
"reeked":"reek",
"reeking":"reek",
"reeks":"reek",
"reeled":"reel",
"reeling":"reel",
"reels":"reel",
"reenforced":"reenforce",
"reenforces":"reenforce",
"reenforcing":"reenforce",
"reenforcements":"reenforcement",
"reentered":"reenter",
"reentering":"reenter",
"reentries":"reentry",
"reeved":"reeve",
"reeves":"reeve",
"reeving":"reeve",
"rove":"reeve",
"reexaminations":"reexamination",
"reexamined":"reexamine",
"reexamines":"reexamine",
"reexamining":"reexamine",
"reexported":"reexport",
"reexporting":"reexport",
"reffed":"ref",
"reffing":"ref",
"refs":"ref",
"refabrications":"refabrication",
"refaced":"reface",
"refacing":"reface",
"refashioned":"refashion",
"refashioning":"refashion",
"refashions":"refashion",
"refastened":"refasten",
"refastening":"refasten",
"refected":"refect",
"refecting":"refect",
"refectories":"refectory",
"referred":"refer",
"referring":"refer",
"refers":"refer",
"refereed":"referee",
"refereeing":"referee",
"referees":"referee",
"refereeings":"refereeing",
"referenced":"reference",
"references":"reference",
"referencing":"reference",
"referenda":"referendum",
"referendums":"referendum",
"refilled":"refill",
"refilling":"refill",
"refills":"refill",
"refillings":"refilling",
"refinanced":"refinance",
"refinancing":"refinance",
"refined":"refine",
"refines":"refine",
"refining":"refine",
"refinements":"refinement",
"refineries":"refinery",
"refinings":"refining",
"refinished":"refinish",
"refinishing":"refinish",
"refinishers":"refinisher",
"refired":"refire",
"refiring":"refire",
"refits":"refit",
"refitted":"refit",
"refitting":"refit",
"reflected":"reflect",
"reflecting":"reflect",
"reflects":"reflect",
"reflectances":"reflectance",
"reflections":"reflection",
"reflectivities":"reflectivity",
"reflectors":"reflector",
"reflectorized":"reflectorize",
"reflectorizing":"reflectorize",
"reflexed":"reflex",
"reflexes":"reflex",
"reflexing":"reflex",
"reflexions":"reflexion",
"reflexives":"reflexive",
"reflexivenesses":"reflexiveness",
"reflexivities":"reflexivity",
"reflowered":"reflower",
"reflowering":"reflower",
"refluxes":"reflux",
"reforested":"reforest",
"reforesting":"reforest",
"reforestations":"reforestation",
"reformed":"reform",
"reforming":"reform",
"reforms":"reform",
"reformations":"reformation",
"reformatories":"reformatory",
"reformers":"reformer",
"reformists":"reformist",
"reformulated":"reformulate",
"reformulates":"reformulate",
"reformulating":"reformulate",
"refortified":"refortify",
"refortifying":"refortify",
"refracted":"refract",
"refracting":"refract",
"refractions":"refraction",
"refractivenesses":"refractiveness",
"refractivities":"refractivity",
"refractorinesses":"refractoriness",
"refractories":"refractory",
"refrained":"refrain",
"refraining":"refrain",
"refrains":"refrain",
"reframed":"reframe",
"reframing":"reframe",
"refreezed":"refreeze",
"refreezing":"refreeze",
"refreshed":"refresh",
"refreshes":"refresh",
"refreshing":"refresh",
"refreshers":"refresher",
"refreshments":"refreshment",
"refrigerated":"refrigerate",
"refrigerating":"refrigerate",
"refrigerations":"refrigeration",
"refrigerators":"refrigerator",
"refueled":"refuel",
"refueling":"refuel",
"refuelled":"refuel",
"refuelling":"refuel",
"refuels":"refuel",
"refuelings":"refueling",
"refuged":"refuge",
"refuges":"refuge",
"refuging":"refuge",
"refugees":"refugee",
"refugia":"refugium",
"refulgences":"refulgence",
"refulgencies":"refulgency",
"refunded":"refund",
"refunding":"refund",
"refunds":"refund",
"refurbished":"refurbish",
"refurbishes":"refurbish",
"refurbishing":"refurbish",
"refurnished":"refurnish",
"refurnishing":"refurnish",
"refusals":"refusal",
"refused":"refuse",
"refuses":"refuse",
"refusing":"refuse",
"refutations":"refutation",
"refuted":"refute",
"refutes":"refute",
"refuting":"refute",
"refutings":"refuting",
"regained":"regain",
"regaining":"regain",
"regains":"regain",
"regainings":"regaining",
"regaled":"regale",
"regales":"regale",
"regaling":"regale",
"regalecidaes":"regalecidae",
"regalias":"regalia",
"regalities":"regality",
"regarded":"regard",
"regarding":"regard",
"regards":"regard",
"regathered":"regather",
"regathering":"regather",
"regattas":"regatta",
"regencies":"regency",
"regenerated":"regenerate",
"regenerates":"regenerate",
"regenerating":"regenerate",
"regents":"regent",
"regerminated":"regerminate",
"regerminating":"regerminate",
"regimes":"regime",
"regimens":"regimen",
"regimented":"regiment",
"regimenting":"regiment",
"regiments":"regiment",
"regions":"region",
"registered":"register",
"registering":"register",
"registers":"register",
"registrars":"registrar",
"registrations":"registration",
"registries":"registry",
"reglaecuses":"reglaecus",
"regnellidiums":"regnellidium",
"regorged":"regorge",
"regorges":"regorge",
"regorging":"regorge",
"regressed":"regress",
"regresses":"regress",
"regressing":"regress",
"regressions":"regression",
"regrets":"regret",
"regretted":"regret",
"regretting":"regret",
"regretses":"regrets",
"regrouped":"regroup",
"regrouping":"regroup",
"regroups":"regroup",
"regulars":"regular",
"regularisations":"regularisation",
"regularities":"regularity",
"regularizations":"regularization",
"regularized":"regularize",
"regularizes":"regularize",
"regularizing":"regularize",
"regulated":"regulate",
"regulates":"regulate",
"regulating":"regulate",
"regulatings":"regulating",
"regulations":"regulation",
"regulators":"regulator",
"reguluses":"regulus",
"regurs":"regur",
"regurgitated":"regurgitate",
"regurgitates":"regurgitate",
"regurgitating":"regurgitate",
"regurgitations":"regurgitation",
"rehabilitated":"rehabilitate",
"rehabilitating":"rehabilitate",
"rehabilitations":"rehabilitation",
"rehandled":"rehandle",
"rehandling":"rehandle",
"rehashed":"rehash",
"rehashes":"rehash",
"rehashing":"rehash",
"reheard":"rehear",
"rehearing":"rehear",
"rehears":"rehear",
"rehearings":"rehearing",
"rehearsals":"rehearsal",
"rehearsed":"rehearse",
"rehearses":"rehearse",
"rehearsing":"rehearse",
"reheated":"reheat",
"reheating":"reheat",
"rehired":"rehire",
"rehiring":"rehire",
"rehospitalized":"rehospitalize",
"rehospitalizing":"rehospitalize",
"rehoused":"rehouse",
"rehousing":"rehouse",
"rehydrated":"rehydrate",
"rehydrating":"rehydrate",
"reichsmarks":"reichsmark",
"reifications":"reification",
"reified":"reify",
"reifies":"reify",
"reifying":"reify",
"reigned":"reign",
"reigning":"reign",
"reigns":"reign",
"reignited":"reignite",
"reigniting":"reignite",
"reimbursed":"reimburse",
"reimburses":"reimburse",
"reimbursing":"reimburse",
"reimported":"reimport",
"reimporting":"reimport",
"reimposed":"reimpose",
"reimposing":"reimpose",
"reimprisoned":"reimprison",
"reimprisoning":"reimprison",
"reined":"rein",
"reining":"rein",
"reins":"rein",
"reincarnated":"reincarnate",
"reincarnating":"reincarnate",
"reincarnations":"reincarnation",
"reindeers":"reindeer",
"reindoctrinated":"reindoctrinate",
"reindoctrinating":"reindoctrinate",
"reinfected":"reinfect",
"reinfecting":"reinfect",
"reinflamed":"reinflame",
"reinflaming":"reinflame",
"reinflated":"reinflate",
"reinflating":"reinflate",
"reinforced":"reinforce",
"reinforces":"reinforce",
"reinforcing":"reinforce",
"reinforcements":"reinforcement",
"reinforcers":"reinforcer",
"reinhabited":"reinhabit",
"reinhabiting":"reinhabit",
"reinjected":"reinject",
"reinjecting":"reinject",
"reinserted":"reinsert",
"reinserting":"reinsert",
"reinsmen":"reinsman",
"reinspected":"reinspect",
"reinspecting":"reinspect",
"reinstalled":"reinstall",
"reinstalling":"reinstall",
"reinstated":"reinstate",
"reinstates":"reinstate",
"reinstating":"reinstate",
"reinstituted":"reinstitute",
"reinstituting":"reinstitute",
"reinsured":"reinsure",
"reinsuring":"reinsure",
"reintegrated":"reintegrate",
"reintegrating":"reintegrate",
"reintered":"reinter",
"reintering":"reinter",
"reinterpreted":"reinterpret",
"reinterpreting":"reinterpret",
"reinterprets":"reinterpret",
"reinterrogated":"reinterrogate",
"reinterrogating":"reinterrogate",
"reintroduced":"reintroduce",
"reintroducing":"reintroduce",
"reinvaded":"reinvade",
"reinvading":"reinvade",
"reinvented":"reinvent",
"reinventing":"reinvent",
"reinvested":"reinvest",
"reinvesting":"reinvest",
"reinvestigated":"reinvestigate",
"reinvestigating":"reinvestigate",
"reinvigorated":"reinvigorate",
"reinvigorates":"reinvigorate",
"reinvigorating":"reinvigorate",
"reinvited":"reinvite",
"reinviting":"reinvite",
"reissues":"reissue",
"reiterated":"reiterate",
"reiterates":"reiterate",
"reiterating":"reiterate",
"reiterations":"reiteration",
"reithrodontomyses":"reithrodontomys",
"rejected":"reject",
"rejecting":"reject",
"rejects":"reject",
"rejections":"rejection",
"rejoiced":"rejoice",
"rejoices":"rejoice",
"rejoicing":"rejoice",
"rejoicings":"rejoicing",
"rejoined":"rejoin",
"rejoining":"rejoin",
"rejoins":"rejoin",
"rejoinders":"rejoinder",
"rejudged":"rejudge",
"rejudging":"rejudge",
"rejuvenated":"rejuvenate",
"rejuvenating":"rejuvenate",
"rejuvenations":"rejuvenation",
"rekindled":"rekindle",
"rekindling":"rekindle",
"reknitted":"reknit",
"reknitting":"reknit",
"relafens":"relafen",
"relapsed":"relapse",
"relapses":"relapse",
"relapsing":"relapse",
"relapsings":"relapsing",
"related":"relate",
"relates":"relate",
"relating":"relate",
"relations":"relation",
"relationses":"relations",
"relationships":"relationship",
"relatives":"relative",
"relative-in-laws":"relative-in-law",
"relativities":"relativity",
"relata":"relatum",
"relaunched":"relaunch",
"relaunching":"relaunch",
"relaundered":"relaunder",
"relaundering":"relaunder",
"relaxed":"relax",
"relaxes":"relax",
"relaxing":"relax",
"relaxants":"relaxant",
"relaxations":"relaxation",
"relayed":"relay",
"relaying":"relay",
"relays":"relay",
"relayses":"relays",
"released":"release",
"releases":"release",
"releasing":"release",
"relegated":"relegate",
"relegates":"relegate",
"relegating":"relegate",
"relegatings":"relegating",
"relegations":"relegation",
"relending":"relend",
"relent":"relend",
"relented":"relent",
"relenting":"relent",
"relents":"relent",
"relentlessnesses":"relentlessness",
"reletting":"relet",
"relevances":"relevance",
"relevancies":"relevancy",
"reliabilities":"reliability",
"reliablenesses":"reliableness",
"reliances":"reliance",
"relics":"relic",
"reliefs":"relief",
"relieves":"relieve",
"relieving":"relieve",
"relievers":"reliever",
"relievos":"relievo",
"relighted":"relight",
"relighting":"relight",
"relit":"relight",
"religions":"religion",
"religionists":"religionist",
"religiosities":"religiosity",
"religiousnesses":"religiousness",
"relined":"reline",
"relining":"reline",
"relinquished":"relinquish",
"relinquishes":"relinquish",
"relinquishing":"relinquish",
"relinquishings":"relinquishing",
"relinquishments":"relinquishment",
"reliquaries":"reliquary",
"reliquidated":"reliquidate",
"reliquidating":"reliquidate",
"relished":"relish",
"relishes":"relish",
"relishing":"relish",
"relishings":"relishing",
"relistenings":"relistening",
"relived":"relive",
"relives":"relive",
"reliving":"relive",
"relivings":"reliving",
"reloaded":"reload",
"reloading":"reload",
"reloads":"reload",
"reloaned":"reloan",
"reloaning":"reloan",
"relocated":"relocate",
"relocates":"relocate",
"relocating":"relocate",
"relocations":"relocation",
"relucted":"reluct",
"relucting":"reluct",
"reluctances":"reluctance",
"reluctivities":"reluctivity",
"relied":"rely",
"relies":"rely",
"relying":"rely",
"rems":"rem",
"remained":"remain",
"remaining":"remain",
"remains":"remain",
"remaindered":"remainder",
"remaindering":"remainder",
"remainders":"remainder",
"remaindermen":"remainderman",
"remainses":"remains",
"remade":"remake",
"remakes":"remake",
"remaking":"remake",
"remakings":"remaking",
"remanned":"reman",
"remanning":"reman",
"remanded":"remand",
"remanding":"remand",
"remands":"remand",
"remarked":"remark",
"remarking":"remark",
"remarks":"remark",
"remarried":"remarry",
"remarrying":"remarry",
"rematches":"rematch",
"rembrandts":"rembrandt",
"remeasured":"remeasure",
"remeasuring":"remeasure",
"remediations":"remediation",
"remedied":"remedy",
"remedies":"remedy",
"remedying":"remedy",
"remembered":"remember",
"remembering":"remember",
"remembers":"remember",
"rememberings":"remembering",
"remembrances":"remembrance",
"remerged":"remerge",
"remerging":"remerge",
"remiges":"remex",
"remilegias":"remilegia",
"remilitarized":"remilitarize",
"remilitarizing":"remilitarize",
"reminded":"remind",
"reminding":"remind",
"reminds":"remind",
"reminders":"reminder",
"reminisced":"reminisce",
"reminiscing":"reminisce",
"reminiscences":"reminiscence",
"remised":"remise",
"remising":"remise",
"remissions":"remission",
"remissnesses":"remissness",
"remits":"remit",
"remitted":"remit",
"remitting":"remit",
"remittals":"remittal",
"remittances":"remittance",
"remitters":"remitter",
"remixed":"remix",
"remixing":"remix",
"remnants":"remnant",
"remodeled":"remodel",
"remodeling":"remodel",
"remodelled":"remodel",
"remodelling":"remodel",
"remodified":"remodify",
"remodifying":"remodify",
"remonstrances":"remonstrance",
"remonstrated":"remonstrate",
"remonstrates":"remonstrate",
"remonstrating":"remonstrate",
"remonstrators":"remonstrator",
"remoras":"remora",
"remorses":"remorse",
"remoter":"remote",
"remotes":"remote",
"remotest":"remote",
"remotenesses":"remoteness",
"remotions":"remotion",
"remounted":"remount",
"remounting":"remount",
"remouted":"remount",
"removals":"removal",
"removes":"remove",
"removing":"remove",
"remunerated":"remunerate",
"remunerates":"remunerate",
"remunerating":"remunerate",
"remunerations":"remuneration",
"remunerators":"remunerator",
"renaissances":"renaissance",
"renamed":"rename",
"renaming":"rename",
"renascences":"renascence",
"rencountered":"rencounter",
"rencountering":"rencounter",
"rending":"rend",
"rends":"rend",
"rent":"rend",
"rendered":"render",
"rendering":"render",
"renders":"render",
"renderings":"rendering",
"rendezvoused":"rendezvous",
"rendezvouses":"rendezvous",
"rendezvousing":"rendezvous",
"renditions":"rendition",
"renegades":"renegade",
"renegados":"renegado",
"reneges":"renege",
"renegotiated":"renegotiate",
"renegotiating":"renegotiate",
"renewing":"renew",
"renews":"renew",
"renewals":"renewal",
"rennins":"rennin",
"renominated":"renominate",
"renominating":"renominate",
"renounced":"renounce",
"renounces":"renounce",
"renouncing":"renounce",
"renouncements":"renouncement",
"renovated":"renovate",
"renovates":"renovate",
"renovating":"renovate",
"renovations":"renovation",
"renovators":"renovator",
"renowns":"renown",
"rented":"rent",
"renting":"rent",
"rents":"rent",
"rentals":"rental",
"rentes":"rente",
"renters":"renter",
"rentiers":"rentier",
"rentings":"renting",
"renunciations":"renunciation",
"reoccupied":"reoccupy",
"reoccupying":"reoccupy",
"reopened":"reopen",
"reopening":"reopen",
"reopposed":"reoppose",
"reopposing":"reoppose",
"reordered":"reorder",
"reordering":"reorder",
"reorganisations":"reorganisation",
"reorganizations":"reorganization",
"reorganized":"reorganize",
"reorganizes":"reorganize",
"reorganizing":"reorganize",
"reoriented":"reorient",
"reorienting":"reorient",
"reorients":"reorient",
"reps":"rep",
"repackaged":"repackage",
"repackaging":"repackage",
"repainted":"repaint",
"repainting":"repaint",
"repaired":"repair",
"repairing":"repair",
"repairs":"repair",
"repairers":"repairer",
"repairmen":"repairman",
"reparations":"reparation",
"repartitioned":"repartition",
"repartitioning":"repartition",
"repasts":"repast",
"repatriated":"repatriate",
"repatriates":"repatriate",
"repatriating":"repatriate",
"repaved":"repave",
"repaving":"repave",
"repaid":"repay",
"repaying":"repay",
"repays":"repay",
"repayments":"repayment",
"repealed":"repeal",
"repealing":"repeal",
"repeals":"repeal",
"repeating":"repeat",
"repeats":"repeat",
"repeaters":"repeater",
"repeatings":"repeating",
"repelled":"repel",
"repelling":"repel",
"repels":"repel",
"repellants":"repellant",
"repellents":"repellent",
"repellings":"repelling",
"repented":"repent",
"repenting":"repent",
"repents":"repent",
"repentances":"repentance",
"repeopled":"repeople",
"repeopling":"repeople",
"repercussions":"repercussion",
"repertoires":"repertoire",
"repertories":"repertory",
"repetitions":"repetition",
"repetitiousnesses":"repetitiousness",
"repetitivenesses":"repetitiveness",
"rephrased":"rephrase",
"rephrases":"rephrase",
"rephrasing":"rephrase",
"rephrasings":"rephrasing",
"repined":"repine",
"repining":"repine",
"replaced":"replace",
"replaces":"replace",
"replacing":"replace",
"replaceabilities":"replaceability",
"replacements":"replacement",
"replacings":"replacing",
"replanted":"replant",
"replanting":"replant",
"replayed":"replay",
"replaying":"replay",
"replays":"replay",
"replenished":"replenish",
"replenishes":"replenish",
"replenishing":"replenish",
"replenishers":"replenisher",
"replenishments":"replenishment",
"repleted":"replete",
"repletes":"replete",
"repleting":"replete",
"repletions":"repletion",
"replevined":"replevin",
"replevining":"replevin",
"replevied":"replevy",
"replevies":"replevy",
"replevying":"replevy",
"replicas":"replica",
"replicated":"replicate",
"replicates":"replicate",
"replicating":"replicate",
"replications":"replication",
"replied":"reply",
"replies":"reply",
"replying":"reply",
"repolished":"repolish",
"repolishing":"repolish",
"reported":"report",
"reporting":"report",
"reports":"report",
"reportages":"reportage",
"reporters":"reporter",
"reportings":"reporting",
"reposed":"repose",
"reposes":"repose",
"reposing":"repose",
"reposited":"reposit",
"repositing":"reposit",
"repositings":"repositing",
"repositioned":"reposition",
"repositioning":"reposition",
"repositions":"reposition",
"repositories":"repository",
"repossessed":"repossess",
"repossesses":"repossess",
"repossessing":"repossess",
"repots":"repot",
"repotted":"repot",
"repotting":"repot",
"repps":"repp",
"reprehended":"reprehend",
"reprehending":"reprehend",
"reprehensions":"reprehension",
"represented":"represent",
"representing":"represent",
"represents":"represent",
"representations":"representation",
"representatives":"representative",
"repressed":"repress",
"represses":"repress",
"repressing":"repress",
"reprieved":"reprieve",
"reprieves":"reprieve",
"reprieving":"reprieve",
"reprimanded":"reprimand",
"reprimanding":"reprimand",
"reprimands":"reprimand",
"reprinted":"reprint",
"reprinting":"reprint",
"reprints":"reprint",
"reprintings":"reprinting",
"reprised":"reprise",
"reprises":"reprise",
"reprising":"reprise",
"repristinated":"repristinate",
"repristinating":"repristinate",
"repros":"repro",
"reproached":"reproach",
"reproaches":"reproach",
"reproaching":"reproach",
"reprobated":"reprobate",
"reprobates":"reprobate",
"reprobating":"reprobate",
"reprocessed":"reprocess",
"reprocesses":"reprocess",
"reprocessing":"reprocess",
"reproduced":"reproduce",
"reproduces":"reproduce",
"reproducing":"reproduce",
"reproducers":"reproducer",
"reproducibilities":"reproducibility",
"reproductions":"reproduction",
"reprogramed":"reprogram",
"reprograming":"reprogram",
"reprogrammed":"reprogram",
"reprogramming":"reprogram",
"reproofed":"reproof",
"reproofing":"reproof",
"reproofs":"reproof",
"reprooves":"reproof",
"reprovals":"reproval",
"reproved":"reprove",
"reproves":"reprove",
"reproving":"reprove",
"reprovisioned":"reprovision",
"reprovisioning":"reprovision",
"reptantias":"reptantia",
"reptiles":"reptile",
"reptilias":"reptilia",
"reptilians":"reptilian",
"reptures":"repture",
"republics":"republic",
"republicans":"republican",
"republications":"republication",
"republished":"republish",
"republishing":"republish",
"republishings":"republishing",
"repudiated":"repudiate",
"repudiates":"repudiate",
"repudiating":"repudiate",
"repudiations":"repudiation",
"repudiators":"repudiator",
"repugned":"repugn",
"repugning":"repugn",
"repugns":"repugn",
"repugnances":"repugnance",
"repulsed":"repulse",
"repulses":"repulse",
"repulsing":"repulse",
"repulsions":"repulsion",
"repulsivenesses":"repulsiveness",
"repurchased":"repurchase",
"repurchases":"repurchase",
"repurchasing":"repurchase",
"reputabilities":"reputability",
"reputations":"reputation",
"reputed":"repute",
"reputes":"repute",
"reputing":"repute",
"requested":"request",
"requesting":"request",
"requests":"request",
"requiems":"requiem",
"requires":"require",
"requiring":"require",
"requirements":"requirement",
"requisites":"requisite",
"requisitioned":"requisition",
"requisitioning":"requisition",
"requisitions":"requisition",
"requited":"requite",
"requites":"requite",
"requiting":"requite",
"requittals":"requittal",
"reradiated":"reradiate",
"reradiating":"reradiate",
"rereading":"reread",
"rerebraces":"rerebrace",
"reredoses":"reredos",
"rerouted":"reroute",
"rerouting":"reroute",
"reran":"rerun",
"rerunning":"rerun",
"reruns":"rerun",
"resailed":"resail",
"resailing":"resail",
"rescinded":"rescind",
"rescinding":"rescind",
"rescinds":"rescind",
"rescindings":"rescinding",
"rescissions":"rescission",
"rescripts":"rescript",
"rescued":"rescue",
"rescues":"rescue",
"rescuing":"rescue",
"rescuers":"rescuer",
"researched":"research",
"researches":"research",
"researching":"research",
"researchers":"researcher",
"reseated":"reseat",
"reseating":"reseat",
"reseaus":"reseau",
"reseaux":"reseau",
"resected":"resect",
"resecting":"resect",
"resedaceaes":"resedaceae",
"reselling":"resell",
"resold":"resell",
"resemblances":"resemblance",
"resembled":"resemble",
"resembling":"resemble",
"resending":"resend",
"resent":"resend",
"resented":"resent",
"resenting":"resent",
"resents":"resent",
"resentments":"resentment",
"reserpines":"reserpine",
"reservations":"reservation",
"reserves":"reserve",
"reserving":"reserve",
"reserveses":"reserves",
"reservoired":"reservoir",
"reservoiring":"reservoir",
"reservoirs":"reservoir",
"resets":"reset",
"resetting":"reset",
"resettled":"resettle",
"resettling":"resettle",
"resettlements":"resettlement",
"reshaped":"reshape",
"reshapes":"reshape",
"reshaping":"reshape",
"reshuffled":"reshuffle",
"reshuffles":"reshuffle",
"reshuffling":"reshuffle",
"reshufflings":"reshuffling",
"resided":"reside",
"resides":"reside",
"residing":"reside",
"residences":"residence",
"residencies":"residency",
"residents":"resident",
"residentiaries":"residentiary",
"residuals":"residual",
"residues":"residue",
"residua":"residuum",
"residuums":"residuum",
"resigned":"resign",
"resigning":"resign",
"resigns":"resign",
"resignations":"resignation",
"resiled":"resile",
"resiling":"resile",
"resiliences":"resilience",
"resiliencies":"resiliency",
"resined":"resin",
"resining":"resin",
"resins":"resin",
"resinated":"resinate",
"resinating":"resinate",
"resisted":"resist",
"resisting":"resist",
"resists":"resist",
"resistances":"resistance",
"resisters":"resister",
"resistivities":"resistivity",
"resistors":"resistor",
"resat":"resit",
"resits":"resit",
"resitting":"resit",
"resoled":"resole",
"resoles":"resole",
"resoling":"resole",
"resolutes":"resolute",
"resolutenesses":"resoluteness",
"resolutions":"resolution",
"resolved":"resolve",
"resolves":"resolve",
"resolving":"resolve",
"resolvents":"resolvent",
"resolvings":"resolving",
"resonances":"resonance",
"resonated":"resonate",
"resonates":"resonate",
"resonating":"resonate",
"resonators":"resonator",
"resorcinolphthaleins":"resorcinolphthalein",
"resorted":"resort",
"resorting":"resort",
"resorts":"resort",
"resounded":"resound",
"resounding":"resound",
"resounds":"resound",
"resources":"resource",
"resourcefulnesses":"resourcefulness",
"respecting":"respect",
"respects":"respect",
"respectabilities":"respectability",
"respectables":"respectable",
"respectfulnesses":"respectfulness",
"respirations":"respiration",
"respirators":"respirator",
"respired":"respire",
"respires":"respire",
"respiring":"respire",
"respites":"respite",
"resplendences":"resplendence",
"resplendencies":"resplendency",
"responded":"respond",
"responding":"respond",
"responds":"respond",
"respondents":"respondent",
"responders":"responder",
"responses":"response",
"responsibilities":"responsibility",
"responsiblenesses":"responsibleness",
"responsivenesses":"responsiveness",
"responsories":"responsory",
"responsa":"responsum",
"rested":"rest",
"resting":"rest",
"rests":"rest",
"restated":"restate",
"restates":"restate",
"restating":"restate",
"restaurants":"restaurant",
"restauranters":"restauranter",
"restaurateurs":"restaurateur",
"restharrows":"restharrow",
"restituted":"restitute",
"restitutes":"restitute",
"restituting":"restitute",
"restitutions":"restitution",
"restivenesses":"restiveness",
"restlessnesses":"restlessness",
"restocked":"restock",
"restocking":"restock",
"restorations":"restoration",
"restoratives":"restorative",
"restored":"restore",
"restores":"restore",
"restoring":"restore",
"restorers":"restorer",
"restrained":"restrain",
"restraining":"restrain",
"restrains":"restrain",
"restraints":"restraint",
"restricted":"restrict",
"restricting":"restrict",
"restricts":"restrict",
"restrictions":"restriction",
"restrooms":"restroom",
"restructured":"restructure",
"restructuring":"restructure",
"resulted":"result",
"resulting":"result",
"results":"result",
"resultants":"resultant",
"resumed":"resume",
"resumes":"resume",
"resuming":"resume",
"resumptions":"resumption",
"resurfaced":"resurface",
"resurfacing":"resurface",
"resurged":"resurge",
"resurging":"resurge",
"resurgences":"resurgence",
"resurrected":"resurrect",
"resurrecting":"resurrect",
"resurrects":"resurrect",
"resurveyed":"resurvey",
"resurveying":"resurvey",
"resuscitated":"resuscitate",
"resuscitates":"resuscitate",
"resuscitating":"resuscitate",
"rets":"ret",
"retted":"ret",
"retting":"ret",
"retailed":"retail",
"retailing":"retail",
"retailers":"retailer",
"retained":"retain",
"retaining":"retain",
"retains":"retain",
"retainers":"retainer",
"retaken":"retake",
"retakes":"retake",
"retaking":"retake",
"retook":"retake",
"retakings":"retaking",
"retaliated":"retaliate",
"retaliates":"retaliate",
"retaliating":"retaliate",
"retaliations":"retaliation",
"retaliators":"retaliator",
"retamas":"retama",
"retarded":"retard",
"retarding":"retard",
"retards":"retard",
"retardations":"retardation",
"retched":"retch",
"retches":"retch",
"retching":"retch",
"retia":"rete",
"retelling":"retell",
"retells":"retell",
"retold":"retell",
"retems":"retem",
"retentions":"retention",
"retentivenesses":"retentiveness",
"retentivities":"retentivity",
"rethinking":"rethink",
"rethinks":"rethink",
"rethought":"rethink",
"retiararii":"retiarius",
"reticences":"reticence",
"reticles":"reticle",
"reticulated":"reticulate",
"reticulating":"reticulate",
"reticulations":"reticulation",
"reticules":"reticule",
"reticulitermeses":"reticulitermes",
"reticulums":"reticulum",
"retinae":"retina",
"retinas":"retina",
"retinacula":"retinaculum",
"retinals":"retinal",
"retinenes":"retinene",
"retinols":"retinol",
"retinues":"retinue",
"retired":"retire",
"retires":"retire",
"retiring":"retire",
"retirees":"retiree",
"retirements":"retirement",
"retooled":"retool",
"retooling":"retool",
"retools":"retool",
"retorted":"retort",
"retorting":"retort",
"retorts":"retort",
"retouched":"retouch",
"retouches":"retouch",
"retouching":"retouch",
"retraced":"retrace",
"retraces":"retrace",
"retracing":"retrace",
"retracted":"retract",
"retracting":"retract",
"retracts":"retract",
"retractions":"retraction",
"retrained":"retrain",
"retraining":"retrain",
"retreaded":"retread",
"retreading":"retread",
"retreads":"retread",
"retreated":"retreat",
"retreating":"retreat",
"retreats":"retreat",
"retrenched":"retrench",
"retrenching":"retrench",
"retrenchments":"retrenchment",
"retributions":"retribution",
"retrievals":"retrieval",
"retrieved":"retrieve",
"retrieves":"retrieve",
"retrieving":"retrieve",
"retros":"retro",
"retro-rockets":"retro-rocket",
"retroacted":"retroact",
"retroacting":"retroact",
"retroceded":"retrocede",
"retroceding":"retrocede",
"retrofired":"retrofire",
"retrofiring":"retrofire",
"retrofits":"retrofit",
"retrofitted":"retrofit",
"retrofitting":"retrofit",
"retroflections":"retroflection",
"retroflexions":"retroflexion",
"retrograded":"retrograde",
"retrogrades":"retrograde",
"retrograding":"retrograde",
"retrogressed":"retrogress",
"retrogresses":"retrogress",
"retrogressing":"retrogress",
"retrogressions":"retrogression",
"retrophyllums":"retrophyllum",
"retrospected":"retrospect",
"retrospecting":"retrospect",
"retrospects":"retrospect",
"retroversions":"retroversion",
"retried":"retry",
"retries":"retry",
"retrying":"retry",
"returned":"return",
"returning":"return",
"returns":"return",
"reunifications":"reunification",
"reunified":"reunify",
"reunifies":"reunify",
"reunifying":"reunify",
"reunions":"reunion",
"reunited":"reunite",
"reunites":"reunite",
"reuniting":"reunite",
"reuptakes":"reuptake",
"revs":"rev",
"revved":"rev",
"revving":"rev",
"revalorized":"revalorize",
"revalorizes":"revalorize",
"revalorizing":"revalorize",
"revaluations":"revaluation",
"revalued":"revalue",
"revalues":"revalue",
"revaluing":"revalue",
"revamped":"revamp",
"revamping":"revamp",
"revamps":"revamp",
"revascularized":"revascularize",
"revascularizing":"revascularize",
"revealed":"reveal",
"revealing":"reveal",
"reveals":"reveal",
"revealings":"revealing",
"revealments":"revealment",
"reveilles":"reveille",
"reveled":"revel",
"reveling":"revel",
"revelled":"revel",
"revelling":"revel",
"revels":"revel",
"revelations":"revelation",
"revelers":"reveler",
"revellers":"reveller",
"revelries":"revelry",
"revenged":"revenge",
"revenges":"revenge",
"revenging":"revenge",
"revenues":"revenue",
"reverbed":"reverb",
"reverbing":"reverb",
"reverberances":"reverberance",
"reverberated":"reverberate",
"reverberates":"reverberate",
"reverberating":"reverberate",
"reverberations":"reverberation",
"reverberatories":"reverberatory",
"revered":"revere",
"reveres":"revere",
"revering":"revere",
"reverenced":"reverence",
"reverences":"reverence",
"reverencing":"reverence",
"reverends":"reverend",
"reveries":"reverie",
"reverses":"reverse",
"reversals":"reversal",
"reversed":"reverse",
"reversing":"reverse",
"reversions":"reversion",
"reversionists":"reversionist",
"reversos":"reverso",
"reverted":"revert",
"reverting":"revert",
"reverts":"revert",
"revertings":"reverting",
"revested":"revest",
"revesting":"revest",
"revets":"revet",
"revetted":"revet",
"revetting":"revet",
"revetements":"revetement",
"revetments":"revetment",
"reviewed":"review",
"reviewing":"review",
"reviews":"review",
"reviewers":"reviewer",
"reviled":"revile",
"reviles":"revile",
"reviling":"revile",
"revilements":"revilement",
"revilers":"reviler",
"revisals":"revisal",
"revised":"revise",
"revises":"revise",
"revising":"revise",
"revisers":"reviser",
"revisings":"revising",
"revisions":"revision",
"revisited":"revisit",
"revisiting":"revisit",
"revitalisations":"revitalisation",
"revitalizations":"revitalization",
"revitalized":"revitalize",
"revitalizes":"revitalize",
"revitalizing":"revitalize",
"revivals":"revival",
"revivalists":"revivalist",
"revived":"revive",
"revives":"revive",
"reviving":"revive",
"revivifications":"revivification",
"revivified":"revivify",
"revivifies":"revivify",
"revivifying":"revivify",
"revoked":"revoke",
"revokes":"revoke",
"revoking":"revoke",
"revolted":"revolt",
"revolting":"revolt",
"revolts":"revolt",
"revolutions":"revolution",
"revolutionaries":"revolutionary",
"revolutionists":"revolutionist",
"revolutionized":"revolutionize",
"revolutionizes":"revolutionize",
"revolutionizing":"revolutionize",
"revolved":"revolve",
"revolves":"revolve",
"revolving":"revolve",
"revolvers":"revolver",
"revues":"revue",
"revulsions":"revulsion",
"rewa-rewas":"rewa-rewa",
"rewarded":"reward",
"rewarding":"reward",
"rewards":"reward",
"rewinning":"rewin",
"rewon":"rewin",
"rewinding":"rewind",
"rewinds":"rewind",
"rewound":"rewind",
"rewired":"rewire",
"rewiring":"rewire",
"reworded":"reword",
"rewording":"reword",
"rewords":"reword",
"rewordings":"rewording",
"reworked":"rework",
"reworking":"rework",
"rewrought":"rework",
"rewrites":"rewrite",
"rewriting":"rewrite",
"rewritten":"rewrite",
"rewrote":"rewrite",
"rewriters":"rewriter",
"rewritings":"rewriting",
"reykjaviks":"reykjavik",
"rfs":"rf",
"rhs":"rh",
"rhabdomyomas":"rhabdomyoma",
"rhabdomyomata":"rhabdomyoma",
"rachides":"rhachis",
"rhachides":"rhachis",
"rhagoletises":"rhagoletis",
"rhamnaceaes":"rhamnaceae",
"rhamnaleses":"rhamnales",
"rhamnuses":"rhamnus",
"rhapises":"rhapis",
"rhapsodized":"rhapsodize",
"rhapsodizing":"rhapsodize",
"rhapsodies":"rhapsody",
"rhatanies":"rhatany",
"rheas":"rhea",
"rheboks":"rhebok",
"rheidaes":"rheidae",
"rheiformeses":"rheiformes",
"rheins":"rhein",
"rheinlands":"rheinland",
"rheniums":"rhenium",
"rhennishes":"rhennish",
"rheostats":"rheostat",
"rhesuses":"rhesus",
"rhetorics":"rhetoric",
"rhetoricians":"rhetorician",
"rheums":"rheum",
"rheumatics":"rheumatic",
"rheumatisms":"rheumatism",
"rheumier":"rheumy",
"rheumiest":"rheumy",
"rhexias":"rhexia",
"rhibhuses":"rhibhus",
"rhincodons":"rhincodon",
"rhincodontidaes":"rhincodontidae",
"rhines":"rhine",
"rhinelands":"rhineland",
"rhinencephala":"rhinencephalon",
"rhinencephalons":"rhinencephalon",
"rhinitises":"rhinitis",
"rhinos":"rhino",
"rhinobatidaes":"rhinobatidae",
"rhinoceri":"rhinoceros",
"rhinoceroses":"rhinoceros",
"rhinocerotidaes":"rhinocerotidae",
"rhinolaryngologists":"rhinolaryngologist",
"rhinolophidaes":"rhinolophidae",
"rhinonicterises":"rhinonicteris",
"rhinoplasties":"rhinoplasty",
"rhinopteras":"rhinoptera",
"rhinotermitidaes":"rhinotermitidae",
"rhipsalises":"rhipsalis",
"rhiptoglossas":"rhiptoglossa",
"rhizobiaceaes":"rhizobiaceae",
"rhizobiums":"rhizobium",
"rhizomes":"rhizome",
"rhizophoras":"rhizophora",
"rhizophoraceaes":"rhizophoraceae",
"rhizopods":"rhizopod",
"rhizopodas":"rhizopoda",
"rhizopodans":"rhizopodan",
"rhizopogons":"rhizopogon",
"rhizopogonaceaes":"rhizopogonaceae",
"rhizotomies":"rhizotomy",
"rhos":"rho",
"rhodanthes":"rhodanthe",
"rhodesias":"rhodesia",
"rhodiums":"rhodium",
"rhodophyceaes":"rhodophyceae",
"rhodophytas":"rhodophyta",
"rhodopsins":"rhodopsin",
"rhodosphaeras":"rhodosphaera",
"rhodymenias":"rhodymenia",
"rhodymeniaceaes":"rhodymeniaceae",
"rhoeadaleses":"rhoeadales",
"rhombs":"rhomb",
"rhombencephalons":"rhombencephalon",
"rhombohedra":"rhombohedron",
"rhomboidei":"rhomboideus",
"rhombi":"rhombus",
"rhombuses":"rhombus",
"rhonchuses":"rhonchus",
"rhones":"rhone",
"rhubarbs":"rhubarb",
"rhumbs":"rhumb",
"rhumbas":"rhumba",
"rhuses":"rhus",
"rhyacotritons":"rhyacotriton",
"rhymed":"rhyme",
"rhymes":"rhyme",
"rhyming":"rhyme",
"rhynchocephalias":"rhynchocephalia",
"rhynchoelapses":"rhynchoelaps",
"rhyncostylises":"rhyncostylis",
"rhynias":"rhynia",
"rhyniaceaes":"rhyniaceae",
"rhythms":"rhythm",
"rhytidectomies":"rhytidectomy",
"rhytidoplasties":"rhytidoplasty",
"rhyta":"rhyton",
"rials":"rial",
"rialtos":"rialto",
"riatas":"riata",
"ribbed":"rib",
"ribbing":"rib",
"ribs":"rib",
"ribaldries":"ribaldry",
"ribands":"riband",
"ribbands":"ribband",
"ribboned":"ribbon",
"ribboning":"ribbon",
"ribbons":"ribbon",
"ribbonfishes":"ribbonfish",
"ribbonwoods":"ribbonwood",
"ribeses":"ribes",
"ribgrasses":"ribgrass",
"ribhuses":"ribhus",
"riboflavins":"riboflavin",
"ribworts":"ribwort",
"riced":"rice",
"ricing":"rice",
"ricebirds":"ricebird",
"ricegrasses":"ricegrass",
"ricercars":"ricercar",
"ricercacari":"ricercare",
"ricercari":"ricercare",
"richer":"rich",
"richest":"rich",
"richeas":"richea",
"richelieus":"richelieu",
"richened":"richen",
"richening":"richen",
"richeses":"riches",
"richmonds":"richmond",
"richmondenas":"richmondena",
"richnesses":"richness",
"richweeds":"richweed",
"ricinuses":"ricinus",
"ricked":"rick",
"ricking":"rick",
"ricks":"rick",
"ricketinesses":"ricketiness",
"ricketses":"rickets",
"rickettsiae":"rickettsia",
"rickettsias":"rickettsia",
"rickettsiaceaes":"rickettsiaceae",
"rickettsialeses":"rickettsiales",
"ricketier":"rickety",
"ricketiest":"rickety",
"rickeys":"rickey",
"rickracks":"rickrack",
"rickshas":"ricksha",
"rickshaws":"rickshaw",
"ricocheted":"ricochet",
"ricocheting":"ricochet",
"ricochets":"ricochet",
"ricochetted":"ricochet",
"ricochetting":"ricochet",
"ricracs":"ricrac",
"rictuses":"rictus",
"ridded":"rid",
"ridding":"rid",
"rids":"rid",
"riddances":"riddance",
"riddled":"riddle",
"riddles":"riddle",
"riddling":"riddle",
"ridden":"ride",
"rides":"ride",
"riding":"ride",
"rode":"ride",
"riders":"rider",
"ridged":"ridge",
"ridges":"ridge",
"ridging":"ridge",
"ridgels":"ridgel",
"ridgelings":"ridgeling",
"ridgepoles":"ridgepole",
"ridgils":"ridgil",
"ridglings":"ridgling",
"ridgier":"ridgy",
"ridgiest":"ridgy",
"ridiculed":"ridicule",
"ridicules":"ridicule",
"ridiculing":"ridicule",
"ridiculousnesses":"ridiculousness",
"ridings":"riding",
"ridottos":"ridotto",
"riemanns":"riemann",
"rifer":"rife",
"rifest":"rife",
"riffed":"riff",
"riffing":"riff",
"riffs":"riff",
"riffians":"riffian",
"riffled":"riffle",
"riffles":"riffle",
"riffling":"riffle",
"riffraffs":"riffraff",
"rifled":"rifle",
"rifles":"rifle",
"rifling":"rifle",
"riflebirds":"riflebird",
"riflemen":"rifleman",
"riflings":"rifling",
"rifted":"rift",
"rifting":"rift",
"rifts":"rift",
"rigged":"rig",
"rigging":"rig",
"rigs":"rig",
"rigas":"riga",
"rigamaroles":"rigamarole",
"rigels":"rigel",
"riggings":"rigging",
"righted":"right",
"righting":"right",
"rights":"right",
"right-handednesses":"right-handedness",
"right-handers":"right-hander",
"right-of-ways":"right-of-way",
"rights-of-way":"right-of-way",
"right-wingers":"right-winger",
"rightfields":"rightfield",
"rightfulnesses":"rightfulness",
"rightists":"rightist",
"rightnesses":"rightness",
"rigidified":"rigidify",
"rigidifies":"rigidify",
"rigidifying":"rigidify",
"rigidities":"rigidity",
"rigidnesses":"rigidness",
"rigils":"rigil",
"rigmaroles":"rigmarole",
"rign-a-rosies":"rign-a-rosy",
"rigors":"rigor",
"rigorousnesses":"rigorousness",
"rigours":"rigour",
"riksmals":"riksmal",
"riled":"rile",
"riles":"rile",
"riling":"rile",
"rilievos":"rilievo",
"rilled":"rill",
"rilling":"rill",
"rills":"rill",
"rimmed":"rim",
"rimming":"rim",
"rims":"rim",
"rimed":"rime",
"rimes":"rime",
"riming":"rime",
"rimus":"rimu",
"rimier":"rimy",
"rimiest":"rimy",
"rinded":"rind",
"rinding":"rind",
"rinds":"rind",
"rinderpests":"rinderpest",
"rang":"ring",
"ringed":"ring",
"ringing":"ring",
"rings":"ring",
"rung":"ring",
"ring-around-a-rosies":"ring-around-a-rosy",
"ring-around-the-rosies":"ring-around-the-rosy",
"ring-binders":"ring-binder",
"ringdoves":"ringdove",
"ringers":"ringer",
"ringhalses":"ringhals",
"ringings":"ringing",
"ringleaders":"ringleader",
"ringlets":"ringlet",
"ringsides":"ringside",
"ringtails":"ringtail",
"ringworms":"ringworm",
"rinks":"rink",
"rinkhalses":"rinkhals",
"rinsed":"rinse",
"rinses":"rinse",
"rinsing":"rinse",
"rinsings":"rinsing",
"rios":"rio",
"rioted":"riot",
"rioting":"riot",
"riots":"riot",
"riotings":"rioting",
"ripped":"rip",
"ripping":"rip",
"rips":"rip",
"rip-offs":"rip-off",
"riparias":"riparia",
"riper":"ripe",
"ripest":"ripe",
"ripened":"ripen",
"ripening":"ripen",
"ripenings":"ripening",
"riposted":"riposte",
"ripostes":"riposte",
"riposting":"riposte",
"rippled":"ripple",
"ripples":"ripple",
"rippling":"ripple",
"ripple-grasses":"ripple-grass",
"ripplings":"rippling",
"ripsaws":"ripsaw",
"riptides":"riptide",
"riscs":"risc",
"risen":"rise",
"rises":"rise",
"rising":"rise",
"rose":"rise",
"risibilities":"risibility",
"risings":"rising",
"risked":"risk",
"risking":"risk",
"risks":"risk",
"riskinesses":"riskiness",
"riskings":"risking",
"riskier":"risky",
"riskiest":"risky",
"risottos":"risotto",
"rissas":"rissa",
"ritalins":"ritalin",
"rites":"rite",
"ritornellos":"ritornello",
"rituals":"ritual",
"ritzier":"ritzy",
"ritziest":"ritzy",
"rivaled":"rival",
"rivaling":"rival",
"rivalled":"rival",
"rivalling":"rival",
"rivals":"rival",
"rivalries":"rivalry",
"rived":"rive",
"riven":"rive",
"rives":"rive",
"riving":"rive",
"rivers":"river",
"riverbanks":"riverbank",
"riverbeds":"riverbed",
"riversides":"riverside",
"riveted":"rivet",
"riveting":"rivet",
"rivets":"rivet",
"rivetted":"rivet",
"rivetting":"rivet",
"riveters":"riveter",
"rivetters":"rivetter",
"rivinas":"rivina",
"rivulets":"rivulet",
"riyadhs":"riyadh",
"riyals":"riyal",
"rns":"rn",
"rnas":"rna",
"roaches":"roach",
"roads":"road",
"roadblocks":"roadblock",
"roadhogs":"roadhog",
"roadhouses":"roadhouse",
"roadmen":"roadman",
"roadrunners":"roadrunner",
"roadses":"roads",
"roadsides":"roadside",
"roadsteads":"roadstead",
"roadsters":"roadster",
"roadways":"roadway",
"roamed":"roam",
"roaming":"roam",
"roams":"roam",
"roamers":"roamer",
"roans":"roan",
"roared":"roar",
"roaring":"roar",
"roars":"roar",
"roarers":"roarer",
"roarings":"roaring",
"roasted":"roast",
"roasting":"roast",
"roasts":"roast",
"robbed":"rob",
"robbing":"rob",
"robs":"rob",
"robalos":"robalo",
"robaxins":"robaxin",
"robbers":"robber",
"robberies":"robbery",
"robed":"robe",
"robes":"robe",
"robing":"robe",
"robe-de-chambres":"robe-de-chambre",
"robertses":"roberts",
"robins":"robin",
"robinias":"robinia",
"robles":"roble",
"robots":"robot",
"robotized":"robotize",
"robotizing":"robotize",
"robustnesses":"robustness",
"rocamboles":"rocambole",
"roccellas":"roccella",
"roccellaceaes":"roccellaceae",
"roccuses":"roccus",
"rocephins":"rocephin",
"rocked":"rock",
"rocking":"rock",
"rocks":"rock",
"rockchucks":"rockchuck",
"rockcresses":"rockcress",
"rockers":"rocker",
"rockeries":"rockery",
"rocketed":"rocket",
"rocketing":"rocket",
"rockets":"rocket",
"rochfish":"rockfish",
"rockfishes":"rockfish",
"rockfoils":"rockfoil",
"rockieses":"rockies",
"rocklings":"rockling",
"rockroses":"rockrose",
"rockier":"rocky",
"rockiest":"rocky",
"rocrois":"rocroi",
"rods":"rod",
"rodents":"rodent",
"rodentias":"rodentia",
"rodeos":"rodeo",
"rodolias":"rodolia",
"rodomontades":"rodomontade",
"roes":"roe",
"roebucks":"roebuck",
"roentgens":"roentgen",
"roentgenograms":"roentgenogram",
"roentgenoscopes":"roentgenoscope",
"rogaines":"rogaine",
"rogued":"rogue",
"rogues":"rogue",
"roguing":"rogue",
"rogueries":"roguery",
"roguishnesses":"roguishness",
"roiled":"roil",
"roiling":"roil",
"roils":"roil",
"roilier":"roily",
"roiliest":"roily",
"roistered":"roister",
"roistering":"roister",
"roisters":"roister",
"roles":"role",
"rolled":"roll",
"rolling":"roll",
"rolls":"roll",
"rollbacks":"rollback",
"rollcalls":"rollcall",
"rollers":"roller",
"roller-skated":"roller-skate",
"roller-skating":"roller-skate",
"rollicked":"rollick",
"rollicking":"rollick",
"rollicks":"rollick",
"rollings":"rolling",
"roly-polies":"roly-poly",
"rolypolinesses":"rolypoliness",
"roms":"rom",
"romas":"roma",
"romaics":"romaic",
"romaines":"romaine",
"romen":"roman",
"romans-fleuves":"roman-fleuve",
"romanced":"romance",
"romances":"romance",
"romancing":"romance",
"romanesques":"romanesque",
"romanias":"romania",
"romanisms":"romanism",
"romanized":"romanize",
"romanizes":"romanize",
"romanizing":"romanize",
"romanoffs":"romanoff",
"romanovs":"romanov",
"romantics":"romantic",
"romanticisations":"romanticisation",
"romanticisms":"romanticism",
"romanticists":"romanticist",
"romanticizations":"romanticization",
"romanticized":"romanticize",
"romanticizes":"romanticize",
"romanticizing":"romanticize",
"Romanies":"Romany",
"romes":"rome",
"romeos":"romeo",
"rommanies":"rommany",
"rommels":"rommel",
"romneyas":"romneya",
"romped":"romp",
"romping":"romp",
"romps":"romp",
"rons":"ron",
"rondeaus":"rondeau",
"rondeaux":"rondeau",
"rondels":"rondel",
"rondos":"rondo",
"roneos":"roneo",
"roneographs":"roneograph",
"roods":"rood",
"rood-trees":"rood-tree",
"roofed":"roof",
"roofing":"roof",
"roofs":"roof",
"rooftrees":"rooftree",
"rooiboses":"rooibos",
"rooked":"rook",
"rooking":"rook",
"rooks":"rook",
"rookeries":"rookery",
"rookies":"rookie",
"rookier":"rooky",
"rookiest":"rooky",
"roomed":"room",
"rooming":"room",
"rooms":"room",
"roomers":"roomer",
"roomfuls":"roomful",
"roominesses":"roominess",
"roomses":"rooms",
"roomier":"roomy",
"roomiest":"roomy",
"roosevelts":"roosevelt",
"roosted":"roost",
"roosting":"roost",
"roosts":"roost",
"roosters":"rooster",
"rooted":"root",
"rooting":"root",
"roots":"root",
"rootstalks":"rootstalk",
"rootstocks":"rootstock",
"rootier":"rooty",
"rootiest":"rooty",
"roped":"rope",
"ropes":"rope",
"roping":"rope",
"ropebarks":"ropebark",
"ropedancers":"ropedancer",
"roperies":"ropery",
"ropewalks":"ropewalk",
"ropewalkers":"ropewalker",
"ropeways":"ropeway",
"ropinesses":"ropiness",
"ropier":"ropy",
"ropiest":"ropy",
"roqueted":"roquet",
"roqueting":"roquet",
"roquets":"roquet",
"roquettes":"roquette",
"roridulaceaes":"roridulaceae",
"rorippas":"rorippa",
"rorquals":"rorqual",
"rosas":"rosa",
"rosaceas":"rosacea",
"rosaceaes":"rosaceae",
"rosaleses":"rosales",
"rosarsaria":"rosarium",
"rosarsariums":"rosarium",
"rosaries":"rosary",
"rosed":"rose",
"roses":"rose",
"rosing":"rose",
"rose-roots":"rose-root",
"rosebays":"rosebay",
"rosebuds":"rosebud",
"rosefishes":"rosefish",
"roselles":"roselle",
"rosellinias":"rosellinia",
"rosemaries":"rosemary",
"roseries":"rosery",
"rosettes":"rosette",
"rosewoods":"rosewood",
"rosidaes":"rosidae",
"rosillas":"rosilla",
"rosined":"rosin",
"rosining":"rosin",
"rosins":"rosin",
"rosinesses":"rosiness",
"rosinweeds":"rosinweed",
"rositas":"rosita",
"rosmarinuses":"rosmarinus",
"rosses":"ross",
"rossbaches":"rossbach",
"rossettis":"rossetti",
"rossinis":"rossini",
"rostella":"rostellum",
"rosters":"roster",
"rostovs":"rostov",
"rostra":"rostrum",
"rostrums":"rostrum",
"rosier":"rosy",
"rosiest":"rosy",
"rots":"rot",
"rotted":"rot",
"rotting":"rot",
"rotas":"rota",
"rotaries":"rotary",
"rotated":"rotate",
"rotates":"rotate",
"rotating":"rotate",
"rotations":"rotation",
"rotatores":"rotator",
"rotators":"rotator",
"rotcs":"rotc",
"rotes":"rote",
"rotiferas":"rotifera",
"artal":"rotl",
"rotls":"rotl",
"rotogravures":"rotogravure",
"rotors":"rotor",
"rottener":"rotten",
"rottenest":"rotten",
"rottennesses":"rottenness",
"rotters":"rotter",
"rottings":"rotting",
"rotundas":"rotunda",
"rotundities":"rotundity",
"roubles":"rouble",
"roues":"roue",
"rouged":"rouge",
"rouges":"rouge",
"rouging":"rouge",
"rougeberries":"rougeberry",
"roughed":"rough",
"rougher":"rough",
"roughest":"rough",
"roughing":"rough",
"roughs":"rough",
"rough-and-tumbles":"rough-and-tumble",
"rough-dried":"rough-dry",
"rough-dries":"rough-dry",
"rough-drying":"rough-dry",
"rough-hewed":"rough-hew",
"rough-hewing":"rough-hew",
"rough-hewn":"rough-hew",
"rough-hews":"rough-hew",
"roughcasting":"roughcast",
"roughcasts":"roughcast",
"roughened":"roughen",
"roughening":"roughen",
"roughhewed":"roughhew",
"roughhewing":"roughhew",
"roughhewn":"roughhew",
"roughhoused":"roughhouse",
"roughhouses":"roughhouse",
"roughhousing":"roughhouse",
"roughlegs":"roughleg",
"roughnecks":"roughneck",
"roughnesses":"roughness",
"rouleaus":"rouleau",
"rouleaux":"rouleau",
"roulettes":"roulette",
"roumanias":"roumania",
"rounded":"round",
"rounder":"round",
"roundest":"round",
"rounding":"round",
"rounds":"round",
"roundabouts":"roundabout",
"roundednesses":"roundedness",
"roundels":"roundel",
"roundhouses":"roundhouse",
"roundsmen":"roundsman",
"roundtables":"roundtable",
"roundtrips":"roundtrip",
"roundworms":"roundworm",
"roused":"rouse",
"rouses":"rouse",
"rousing":"rouse",
"rousings":"rousing",
"rousseaus":"rousseau",
"rousted":"roust",
"rousting":"roust",
"roustabouts":"roustabout",
"routed":"route",
"routing":"route",
"routs":"rout",
"routes":"route",
"routines":"routine",
"roved":"rove",
"roves":"rove",
"roving":"rove",
"rovers":"rover",
"rovings":"roving",
"rowed":"row",
"rowing":"row",
"rows":"row",
"rowans":"rowan",
"rowboats":"rowboat",
"rowdinesses":"rowdiness",
"rowdier":"rowdy",
"rowdies":"rowdy",
"rowdiest":"rowdy",
"rowdyisms":"rowdyism",
"roweled":"rowel",
"roweling":"rowel",
"rowelled":"rowel",
"rowelling":"rowel",
"rowels":"rowel",
"rowers":"rower",
"rowings":"rowing",
"rowlocks":"rowlock",
"royals":"royal",
"royalists":"royalist",
"royalties":"royalty",
"roystoneas":"roystonea",
"rozelles":"rozelle",
"rpms":"rpm",
"rtlts":"rtlt",
"rus":"ru",
"ruandas":"ruanda",
"rubbed":"rub",
"rubbing":"rub",
"rubs":"rub",
"rub-a-dubs":"rub-a-dub",
"rubati":"rubato",
"rubatos":"rubato",
"rubbered":"rubber",
"rubbering":"rubber",
"rubbers":"rubber",
"rubber-neckings":"rubber-necking",
"rubberized":"rubberize",
"rubberizes":"rubberize",
"rubberizing":"rubberize",
"rubbernecked":"rubberneck",
"rubbernecking":"rubberneck",
"rubbernecks":"rubberneck",
"rubbings":"rubbing",
"rubbishes":"rubbish",
"rubbles":"rubble",
"rubbies":"rubby",
"rubes":"rube",
"rubellas":"rubella",
"rubeolas":"rubeola",
"rubias":"rubia",
"rubiaceaes":"rubiaceae",
"rubialeses":"rubiales",
"rubicons":"rubicon",
"rubidiums":"rubidium",
"rubles":"ruble",
"rubrics":"rubric",
"rubuses":"rubus",
"rubied":"ruby",
"rubies":"ruby",
"rubying":"ruby",
"rucked":"ruck",
"rucking":"ruck",
"rucks":"ruck",
"rucksacks":"rucksack",
"ruckuses":"ruckus",
"ructions":"ruction",
"rudapithecuses":"rudapithecus",
"rudbeckias":"rudbeckia",
"rudds":"rudd",
"rudders":"rudder",
"rudderfishes":"rudderfish",
"rudderposts":"rudderpost",
"rudderstocks":"rudderstock",
"ruddinesses":"ruddiness",
"ruddled":"ruddle",
"ruddles":"ruddle",
"ruddling":"ruddle",
"ruddleses":"ruddles",
"ruddier":"ruddy",
"ruddiest":"ruddy",
"ruder":"rude",
"rudest":"rude",
"rudenesses":"rudeness",
"rudiments":"rudiment",
"rudimentses":"rudiments",
"rued":"rue",
"rues":"rue",
"ruing":"rue",
"ruefulnesses":"ruefulness",
"ruffs":"ruff",
"ruffians":"ruffian",
"ruffled":"ruffle",
"ruffles":"ruffle",
"ruffling":"ruffle",
"rugs":"rug",
"rugae":"ruga",
"rugbies":"rugby",
"ruggedisations":"ruggedisation",
"ruggedizations":"ruggedization",
"ruggedized":"ruggedize",
"ruggedizes":"ruggedize",
"ruggedizing":"ruggedize",
"ruggednesses":"ruggedness",
"ruggers":"rugger",
"ruhrs":"ruhr",
"ruined":"ruin",
"ruining":"ruin",
"ruins":"ruin",
"ruinations":"ruination",
"ruiners":"ruiner",
"ruinings":"ruining",
"ruled":"rule",
"rules":"rule",
"ruling":"rule",
"rulers":"ruler",
"rulings":"ruling",
"rummer":"rum",
"rummest":"rum",
"rums":"rum",
"rumanias":"rumania",
"rumbas":"rumba",
"rumbled":"rumble",
"rumbles":"rumble",
"rumbling":"rumble",
"rumblings":"rumbling",
"rumens":"rumen",
"rumina":"rumen",
"rumexes":"rumex",
"ruminantias":"ruminantia",
"ruminated":"ruminate",
"ruminates":"ruminate",
"ruminating":"ruminate",
"ruminations":"rumination",
"rummaged":"rummage",
"rummages":"rummage",
"rummaging":"rummage",
"rummies":"rummy",
"rumohras":"rumohra",
"rumored":"rumor",
"rumoring":"rumor",
"rumors":"rumor",
"rumormongers":"rumormonger",
"rumoured":"rumour",
"rumouring":"rumour",
"rumours":"rumour",
"rumourmongers":"rumourmonger",
"rumps":"rump",
"rumpled":"rumple",
"rumples":"rumple",
"rumpling":"rumple",
"rumpuses":"rumpus",
"rumrunners":"rumrunner",
"ran":"run",
"running":"run",
"runs":"run",
"run-ins":"run-in",
"runabouts":"runabout",
"runaways":"runaway",
"runches":"runch",
"rundles":"rundle",
"rundowns":"rundown",
"rundstedts":"rundstedt",
"runes":"rune",
"rungs":"rung",
"runnels":"runnel",
"runners":"runner",
"runners-up":"runner-up",
"runninesses":"runniness",
"runnings":"running",
"runnier":"runny",
"runniest":"runny",
"runoffs":"runoff",
"runts":"runt",
"runtinesses":"runtiness",
"runtier":"runty",
"runtiest":"runty",
"runways":"runway",
"rupees":"rupee",
"ruperts":"rupert",
"rupiahs":"rupiah",
"rupicapras":"rupicapra",
"rupicolas":"rupicola",
"ruptiliocarpons":"ruptiliocarpon",
"ruptured":"rupture",
"ruptures":"rupture",
"rupturing":"rupture",
"ruptureworts":"rupturewort",
"ruralized":"ruralize",
"ruralizing":"ruralize",
"ruscaceaes":"ruscaceae",
"ruscuses":"ruscus",
"ruses":"ruse",
"rushed":"rush",
"rushes":"rush",
"rushing":"rush",
"rushings":"rushing",
"rushlights":"rushlight",
"rushmores":"rushmore",
"rushier":"rushy",
"rushiest":"rushy",
"rusks":"rusk",
"russes":"russ",
"russells":"russell",
"russets":"russet",
"russias":"russia",
"russianized":"russianize",
"russianizes":"russianize",
"russianizing":"russianize",
"russkis":"russki",
"russkies":"russky",
"russulas":"russula",
"russulaceaes":"russulaceae",
"rusted":"rust",
"rusting":"rust",
"rusts":"rust",
"rustics":"rustic",
"rusticated":"rusticate",
"rusticates":"rusticate",
"rusticating":"rusticate",
"rusticities":"rusticity",
"rustings":"rusting",
"rustled":"rustle",
"rustles":"rustle",
"rustling":"rustle",
"rustlers":"rustler",
"rustlings":"rustling",
"rustier":"rusty",
"rustiest":"rusty",
"ruts":"rut",
"rutted":"rut",
"rutting":"rut",
"rutas":"ruta",
"rutabagas":"rutabaga",
"rutaceaes":"rutaceae",
"ruths":"ruth",
"rutheniums":"ruthenium",
"rutherfordiums":"rutherfordium",
"ruthfulnesses":"ruthfulness",
"ruthlessnesses":"ruthlessness",
"rutiluses":"rutilus",
"ruttier":"rutty",
"ruttiest":"rutty",
"rvs":"rv",
"rwandas":"rwanda",
"rxs":"rx",
"ryas":"rya",
"rydbergs":"rydberg",
"ryes":"rye",
"ryegrasses":"ryegrass",
"rynchopidaes":"rynchopidae",
"rynchopses":"rynchops",
"rypticuses":"rypticus",
"ses":"s",
"s/ns":"s/n",
"sabahs":"sabah",
"sabals":"sabal",
"sabatons":"sabaton",
"sabayons":"sabayon",
"sabbats":"sabbat",
"sabbaticals":"sabbatical",
"sabered":"saber",
"sabering":"saber",
"sabers":"saber",
"saberteeth":"sabertooth",
"sabicus":"sabicu",
"sabines":"sabine",
"sabineas":"sabinea",
"sables":"sable",
"sabots":"sabot",
"sabotaged":"sabotage",
"sabotages":"sabotage",
"sabotaging":"sabotage",
"saboteurs":"saboteur",
"sabras":"sabra",
"sabred":"sabre",
"sabres":"sabre",
"sabring":"sabre",
"sacs":"sac",
"saccharides":"saccharide",
"saccharified":"saccharify",
"saccharifies":"saccharify",
"saccharifying":"saccharify",
"saccharomyceses":"saccharomyces",
"saccharomycetaceaes":"saccharomycetaceae",
"saccharoses":"saccharose",
"saccharums":"saccharum",
"saccules":"saccule",
"sacculuses":"sacculus",
"sachsens":"sachsen",
"sacked":"sack",
"sacking":"sack",
"sacks":"sack",
"sackfuls":"sackful",
"sackings":"sacking",
"sacques":"sacque",
"sacralized":"sacralize",
"sacralizing":"sacralize",
"sacraments":"sacrament",
"sacramentos":"sacramento",
"sacrarcraria":"sacrarium",
"sacraria":"sacrarium",
"sacrificed":"sacrifice",
"sacrifices":"sacrifice",
"sacrificing":"sacrifice",
"sacrileges":"sacrilege",
"sacristans":"sacristan",
"sacristies":"sacristy",
"sacra":"sacrum",
"sadder":"sad",
"saddest":"sad",
"sads":"sad",
"saddened":"sadden",
"saddening":"sadden",
"saddens":"sadden",
"saddhus":"saddhu",
"saddled":"saddle",
"saddles":"saddle",
"saddling":"saddle",
"saddlebacks":"saddleback",
"saddlebills":"saddlebill",
"saddlebows":"saddlebow",
"saddlecloths":"saddlecloth",
"saddlecoths":"saddlecoth",
"saddleries":"saddlery",
"sadducees":"sadducee",
"sades":"sade",
"sadhus":"sadhu",
"sadlerias":"sadleria",
"sadnesses":"sadness",
"safaris":"safari",
"safer":"safe",
"safes":"safe",
"safest":"safe",
"safe-deposits":"safe-deposit",
"safebreakers":"safebreaker",
"safecrackers":"safecracker",
"safeguarded":"safeguard",
"safeguarding":"safeguard",
"safeguards":"safeguard",
"safekeepings":"safekeeping",
"safeties":"safety",
"safety-deposits":"safety-deposit",
"safflowers":"safflower",
"saffrons":"saffron",
"sagged":"sag",
"sagging":"sag",
"sags":"sag",
"sagas":"saga",
"sagaciousnesses":"sagaciousness",
"sagacities":"sagacity",
"sager":"sage",
"sages":"sage",
"sagest":"sage",
"sagebrushes":"sagebrush",
"saggier":"saggy",
"saggiest":"saggy",
"saginas":"sagina",
"sagittarias":"sagittaria",
"sagittariidaes":"sagittariidae",
"sagittariuses":"sagittarius",
"sagittate-leaves":"sagittate-leaf",
"saguaros":"saguaro",
"sahaptans":"sahaptan",
"sahaptians":"sahaptian",
"sahaptins":"sahaptin",
"saharas":"sahara",
"sahuaros":"sahuaro",
"saigas":"saiga",
"saigons":"saigon",
"sailed":"sail",
"sailing":"sail",
"sails":"sail",
"sailboats":"sailboat",
"sailfishes":"sailfish",
"sailings":"sailing",
"sailing-races":"sailing-race",
"sailors":"sailor",
"sailplanes":"sailplane",
"sailplanings":"sailplaning",
"saimiris":"saimiri",
"sainfoins":"sainfoin",
"sainted":"saint",
"sainting":"saint",
"saints":"saint",
"saint-mihiels":"saint-mihiel",
"saintlier":"saintly",
"saintliest":"saintly",
"saintpaulias":"saintpaulia",
"sakartvelos":"sakartvelo",
"sakes":"sake",
"sakis":"saki",
"sakkaras":"sakkara",
"saktis":"sakti",
"saktisms":"saktism",
"salaamed":"salaam",
"salaaming":"salaam",
"salaciousnesses":"salaciousness",
"salacities":"salacity",
"salads":"salad",
"salais":"salai",
"salals":"salal",
"salamanders":"salamander",
"salamandras":"salamandra",
"salamandridaes":"salamandridae",
"salamis":"salami",
"salaried":"salary",
"salaries":"salary",
"salarying":"salary",
"sales":"sale",
"salems":"salem",
"saleratuses":"saleratus",
"salerooms":"saleroom",
"saleses":"sales",
"salesclerks":"salesclerk",
"salesgirls":"salesgirl",
"salesladies":"saleslady",
"salesmen":"salesman",
"salesrooms":"salesroom",
"saleswomen":"saleswoman",
"salians":"salian",
"salicaceaes":"salicaceae",
"salicaleses":"salicales",
"salicornias":"salicornia",
"saliences":"salience",
"saliencies":"saliency",
"salients":"salient",
"salientias":"salientia",
"salientians":"salientian",
"salified":"salify",
"salifies":"salify",
"salifying":"salify",
"salinas":"salina",
"salines":"saline",
"salinities":"salinity",
"salisburies":"salisbury",
"salishes":"salish",
"salishans":"salishan",
"salivas":"saliva",
"salivated":"salivate",
"salivating":"salivate",
"salixes":"salix",
"sallades":"sallade",
"sallets":"sallet",
"sallowed":"sallow",
"sallower":"sallow",
"sallowest":"sallow",
"sallowing":"sallow",
"sallows":"sallow",
"sallied":"sally",
"sallies":"sally",
"sallying":"sally",
"salmis":"salmi",
"salmos":"salmo",
"salmons":"salmon",
"salmonberries":"salmonberry",
"salmonellae":"salmonella",
"salmonellas":"salmonella",
"salmonidaes":"salmonidae",
"salmwoods":"salmwood",
"salols":"salol",
"salons":"salon",
"salonikas":"salonika",
"saloons":"saloon",
"salps":"salp",
"salpas":"salpa",
"salpichroas":"salpichroa",
"salpidaes":"salpidae",
"salpincteses":"salpinctes",
"salpingectomies":"salpingectomy",
"salpinges":"salpinx",
"salsifies":"salsify",
"salsillas":"salsilla",
"salsolas":"salsola",
"salted":"salt",
"salting":"salt",
"salts":"salt",
"saltarelli":"saltarello",
"saltarellos":"saltarello",
"saltinesses":"saltiness",
"saltires":"saltire",
"saltpeters":"saltpeter",
"saltpetres":"saltpetre",
"saltshakers":"saltshaker",
"saltuses":"saltus",
"saltwaters":"saltwater",
"saltworts":"saltwort",
"saltier":"salty",
"saltiest":"salty",
"salubriousnesses":"salubriousness",
"salubrities":"salubrity",
"salukis":"saluki",
"salutations":"salutation",
"salutatorians":"salutatorian",
"salutatories":"salutatory",
"saluted":"salute",
"salutes":"salute",
"saluting":"salute",
"salvadors":"salvador",
"salvadorans":"salvadoran",
"salvadoreans":"salvadorean",
"salvadorians":"salvadorian",
"salvaged":"salvage",
"salvages":"salvage",
"salvaging":"salvage",
"salvagers":"salvager",
"salvations":"salvation",
"salved":"salve",
"salves":"salve",
"salving":"salve",
"salvelinuses":"salvelinus",
"salvias":"salvia",
"salvinias":"salvinia",
"salviniaceaes":"salviniaceae",
"salvoes":"salvo",
"salvos":"salvo",
"salvors":"salvor",
"sams":"sam",
"samen":"saman",
"samaras":"samara",
"samarcands":"samarcand",
"samaritans":"samaritan",
"samariums":"samarium",
"samarkands":"samarkand",
"sambas":"samba",
"sambars":"sambar",
"sambos":"sambo",
"sambucuses":"sambucus",
"samburs":"sambur",
"samenesses":"sameness",
"samhitas":"samhita",
"samis":"sami",
"samias":"samia",
"samiels":"samiel",
"sammies":"sammy",
"samoas":"samoa",
"samoluses":"samolus",
"samoyeds":"samoyed",
"samoyedes":"samoyede",
"samoyedics":"samoyedic",
"samphires":"samphire",
"sampled":"sample",
"samples":"sample",
"sampling":"sample",
"samplers":"sampler",
"samurairais":"samurai",
"sanas":"sana",
"sanaas":"sanaa",
"sanatariums":"sanatarium",
"sanatoria":"sanatorium",
"sanatoriums":"sanatorium",
"sanbenitos":"sanbenito",
"sanctified":"sanctify",
"sanctifies":"sanctify",
"sanctifying":"sanctify",
"sanctimoniousnesses":"sanctimoniousness",
"sanctimonies":"sanctimony",
"sanctioned":"sanction",
"sanctioning":"sanction",
"sanctions":"sanction",
"sanctities":"sanctity",
"sanctuaries":"sanctuary",
"sancta":"sanctum",
"sanctums":"sanctum",
"sanded":"sand",
"sanding":"sand",
"sands":"sand",
"sand-casting":"sand-cast",
"sand-casts":"sand-cast",
"sandals":"sandal",
"sandaracs":"sandarac",
"sandaraches":"sandarach",
"sandbagged":"sandbag",
"sandbagging":"sandbag",
"sandbags":"sandbag",
"sandbars":"sandbar",
"sandberries":"sandberry",
"sandblasted":"sandblast",
"sandblasting":"sandblast",
"sandboxes":"sandbox",
"sandburs":"sandbur",
"sanders":"sander",
"sanderlings":"sanderling",
"sandfishes":"sandfish",
"sandflies":"sandfly",
"sandglasses":"sandglass",
"sandgrouses":"sandgrouse",
"sandhis":"sandhi",
"sandhoppers":"sandhopper",
"sandmen":"sandman",
"sandpapered":"sandpaper",
"sandpapering":"sandpaper",
"sandpapers":"sandpaper",
"sandpiles":"sandpile",
"sandrils":"sandril",
"sandses":"sands",
"sandspurs":"sandspur",
"sandstorms":"sandstorm",
"sandwiched":"sandwich",
"sandwiches":"sandwich",
"sandwiching":"sandwich",
"sandworts":"sandwort",
"sandier":"sandy",
"sandiest":"sandy",
"saner":"sane",
"sanest":"sane",
"sanenesses":"saneness",
"sanfoins":"sanfoin",
"sangs":"sang",
"sang-froids":"sang-froid",
"sangapenums":"sangapenum",
"sangarees":"sangaree",
"sangraals":"sangraal",
"sangrias":"sangria",
"sanguinarias":"sanguinaria",
"sanguinenesses":"sanguineness",
"sanguinities":"sanguinity",
"sanicles":"sanicle",
"saniculas":"sanicula",
"sanieses":"sanies",
"sanitaria":"sanitarium",
"sanitariums":"sanitarium",
"sanitaries":"sanitary",
"sanitations":"sanitation",
"sanitisations":"sanitisation",
"sanitizations":"sanitization",
"sanitized":"sanitize",
"sanitizes":"sanitize",
"sanitizing":"sanitize",
"sanitizings":"sanitizing",
"sanities":"sanity",
"sanseis":"sansei",
"sansevierias":"sansevieria",
"sanskrits":"sanskrit",
"santalaceaes":"santalaceae",
"santalaleses":"santalales",
"santalums":"santalum",
"santees":"santee",
"santiagos":"santiago",
"santolinas":"santolina",
"santonicas":"santonica",
"sanvitalias":"sanvitalia",
"saones":"saone",
"sapped":"sap",
"sapping":"sap",
"saps":"sap",
"sapheads":"saphead",
"saphenae":"saphena",
"sapidities":"sapidity",
"sapidnesses":"sapidness",
"sapiences":"sapience",
"sapindaceaes":"sapindaceae",
"sapindaleses":"sapindales",
"sapinduses":"sapindus",
"sapirs":"sapir",
"saplings":"sapling",
"sapodillas":"sapodilla",
"saponarias":"saponaria",
"saponified":"saponify",
"saponifies":"saponify",
"saponifying":"saponify",
"sapotas":"sapota",
"sapotaceaes":"sapotaceae",
"sapotes":"sapote",
"sapphires":"sapphire",
"sapphisms":"sapphism",
"sappier":"sappy",
"sappiest":"sappy",
"sapraemias":"sapraemia",
"sapremias":"sapremia",
"saprolegnias":"saprolegnia",
"saprolegnialeses":"saprolegniales",
"saprophytes":"saprophyte",
"saqqaras":"saqqara",
"saqqarahs":"saqqarah",
"saragossas":"saragossa",
"sarapes":"sarape",
"saratogas":"saratoga",
"sarcasms":"sarcasm",
"sarcinae":"sarcina",
"sarcinas":"sarcina",
"sarcobatuses":"sarcobatus",
"sarcocephaluses":"sarcocephalus",
"sarcochiluses":"sarcochilus",
"sarcocystideans":"sarcocystidean",
"sarcocystieians":"sarcocystieian",
"sarcocystises":"sarcocystis",
"sarcodeses":"sarcodes",
"sarcodinas":"sarcodina",
"sarcodines":"sarcodine",
"sarcodinians":"sarcodinian",
"sarcolemmas":"sarcolemma",
"sarcomas":"sarcoma",
"sarcomata":"sarcoma",
"sarcophagas":"sarcophaga",
"sarcophagi":"sarcophagus",
"sarcophaguses":"sarcophagus",
"sarcophiluses":"sarcophilus",
"sarcopteses":"sarcoptes",
"sarcoptids":"sarcoptid",
"sarcoptidaes":"sarcoptidae",
"sarcorhamphuses":"sarcorhamphus",
"sarcoscyphaceaes":"sarcoscyphaceae",
"sarcosporidias":"sarcosporidia",
"sarcosporidians":"sarcosporidian",
"sarcostemmas":"sarcostemma",
"sarcostyles":"sarcostyle",
"sards":"sard",
"sardas":"sarda",
"sardegnas":"sardegna",
"sardinas":"sardina",
"sardines":"sardine",
"sardinias":"sardinia",
"sardinopses":"sardinops",
"sardiuses":"sardius",
"sarees":"saree",
"sargassos":"sargasso",
"sargassums":"sargassum",
"saris":"sari",
"sarpanitus":"sarpanitu",
"sarracenias":"sarracenia",
"sarraceniaceaes":"sarraceniaceae",
"sarracenialeses":"sarraceniales",
"sarsaparillas":"sarsaparilla",
"sartors":"sartor",
"sartorii":"sartorius",
"sartoriuses":"sartorius",
"sashed":"sash",
"sashes":"sash",
"sashing":"sash",
"sashayed":"sashay",
"sashaying":"sashay",
"sashays":"sashay",
"saskatoons":"saskatoon",
"sasquatches":"sasquatch",
"sassed":"sass",
"sasses":"sass",
"sassing":"sass",
"sassabies":"sassaby",
"sassafrases":"sassafras",
"sassasanidae":"sassanid",
"sassasanids":"sassanid",
"sassings":"sassing",
"sassier":"sassy",
"sassiest":"sassy",
"sats":"sat",
"satans":"satan",
"satanisms":"satanism",
"satanists":"satanist",
"satchels":"satchel",
"sated":"sate",
"sates":"sate",
"sating":"sate",
"satellites":"satellite",
"satiated":"satiate",
"satiates":"satiate",
"satiating":"satiate",
"satiations":"satiation",
"satieties":"satiety",
"satinleaves":"satinleaf",
"satinpods":"satinpod",
"satinwoods":"satinwood",
"satires":"satire",
"satirists":"satirist",
"satirized":"satirize",
"satirizes":"satirize",
"satirizing":"satirize",
"satisfactions":"satisfaction",
"satisfied":"satisfy",
"satisfies":"satisfy",
"satisfying":"satisfy",
"satisfyings":"satisfying",
"satrapies":"satrapy",
"satsumas":"satsuma",
"saturates":"saturate",
"saturating":"saturate",
"saturations":"saturation",
"saturdays":"saturday",
"satureias":"satureia",
"saturejas":"satureja",
"saturnalias":"saturnalia",
"saturnias":"saturnia",
"saturniids":"saturniid",
"saturniidaes":"saturniidae",
"saturnisms":"saturnism",
"satyrs":"satyr",
"sauced":"sauce",
"sauces":"sauce",
"saucing":"sauce",
"sauce-alones":"sauce-alone",
"sauceboats":"sauceboat",
"saucepans":"saucepan",
"saucers":"saucer",
"saucinesses":"sauciness",
"sauccier":"saucy",
"saucciest":"saucy",
"saucier":"saucy",
"sauciest":"saucy",
"Saudis":"Saudi",
"sauls":"saul",
"saunas":"sauna",
"sauntered":"saunter",
"sauntering":"saunter",
"saunters":"saunter",
"saunterers":"saunterer",
"saurels":"saurel",
"saurias":"sauria",
"saurischias":"saurischia",
"saurischians":"saurischian",
"sauromaluses":"sauromalus",
"sauropods":"sauropod",
"sauropodas":"sauropoda",
"sauropodomorphas":"sauropodomorpha",
"sauropterygias":"sauropterygia",
"saurosuchuses":"saurosuchus",
"saururaceaes":"saururaceae",
"saururuses":"saururus",
"sauries":"saury",
"sausages":"sausage",
"saussureas":"saussurea",
"sauteed":"saute",
"sauteing":"saute",
"sautes":"saute",
"sauteings":"sauteing",
"sauternes":"sauterne",
"sauterneses":"sauternes",
"savaged":"savage",
"savages":"savage",
"savaging":"savage",
"savagenesses":"savageness",
"savageries":"savagery",
"savannas":"savanna",
"savannahs":"savannah",
"savants":"savant",
"saved":"save",
"saves":"save",
"saving":"save",
"savers":"saver",
"savins":"savin",
"savings":"saving",
"savingses":"savings",
"saviors":"savior",
"saviours":"saviour",
"savoir-faires":"savoir-faire",
"savored":"savor",
"savoring":"savor",
"savors":"savor",
"savorinesses":"savoriness",
"savorings":"savoring",
"savorlessnesses":"savorlessness",
"savorier":"savory",
"savories":"savory",
"savoriest":"savory",
"savouries":"savoury",
"savours":"savour",
"savourier":"savoury",
"savouriest":"savoury",
"savoys":"savoy",
"savvied":"savvy",
"savvies":"savvy",
"savvying":"savvy",
"sawed":"saw",
"sawing":"saw",
"sawn":"saw",
"saws":"saw",
"sawbills":"sawbill",
"sawboneses":"sawbones",
"sawbucks":"sawbuck",
"sawfishes":"sawfish",
"sawflies":"sawfly",
"sawhorses":"sawhorse",
"sawmills":"sawmill",
"sawteeth":"sawtooth",
"sawworts":"sawwort",
"sawyers":"sawyer",
"saxes":"sax",
"saxe-gotheas":"saxe-gothea",
"saxegotheas":"saxegothea",
"saxicolas":"saxicola",
"saxifragas":"saxifraga",
"saxifragaceaes":"saxifragaceae",
"saxifrages":"saxifrage",
"saxonies":"saxony",
"saxophones":"saxophone",
"saxtubas":"saxtuba",
"said":"say",
"saying":"say",
"says":"say",
"say-sos":"say-so",
"sayancis":"sayanci",
"sayings":"saying",
"sayonaras":"sayonara",
"sayornises":"sayornis",
"sbs":"sb",
"sbes":"sbe",
"sbws":"sbw",
"scs":"sc",
"scabbed":"scab",
"scabbing":"scab",
"scabs":"scab",
"scabbarded":"scabbard",
"scabbarding":"scabbard",
"scabbards":"scabbard",
"scabbled":"scabble",
"scabling":"scabble",
"scabbier":"scabby",
"scabbiest":"scabby",
"scabieses":"scabies",
"scabiosas":"scabiosa",
"scabiouses":"scabious",
"scads":"scad",
"scadses":"scads",
"scaffolded":"scaffold",
"scaffolding":"scaffold",
"scaffolds":"scaffold",
"scags":"scag",
"scalades":"scalade",
"scalalados":"scalado",
"scalawags":"scalawag",
"scalded":"scald",
"scalding":"scald",
"scalds":"scald",
"scaldfishes":"scaldfish",
"scaled":"scale",
"scales":"scale",
"scaling":"scale",
"scaleni":"scalenus",
"scalenuses":"scalenus",
"scalings":"scaling",
"scallions":"scallion",
"scalloped":"scallop",
"scalloping":"scallop",
"scallops":"scallop",
"scallopers":"scalloper",
"scallopines":"scallopine",
"scallopinis":"scallopini",
"scallywags":"scallywag",
"scalped":"scalp",
"scalping":"scalp",
"scalps":"scalp",
"scalier":"scaly",
"scaliest":"scaly",
"scams":"scam",
"scammonies":"scammony",
"scammonyroots":"scammonyroot",
"scamped":"scamp",
"scamping":"scamp",
"scamps":"scamp",
"scampered":"scamper",
"scampering":"scamper",
"scampers":"scamper",
"scampos":"scampo",
"scanned":"scan",
"scanning":"scan",
"scans":"scan",
"scandals":"scandal",
"scandalisations":"scandalisation",
"scandalizations":"scandalization",
"scandalized":"scandalize",
"scandalizes":"scandalize",
"scandalizing":"scandalize",
"scandalmongerings":"scandalmongering",
"scandentias":"scandentia",
"scandinavias":"scandinavia",
"scandinavians":"scandinavian",
"scandiums":"scandium",
"scanted":"scant",
"scanter":"scant",
"scantest":"scant",
"scanting":"scant",
"scantinesses":"scantiness",
"scantlings":"scantling",
"scantnesses":"scantness",
"scantier":"scanty",
"scanties":"scanty",
"scantiest":"scanty",
"scapes":"scape",
"scapegoats":"scapegoat",
"scapegraces":"scapegrace",
"scaphiopuses":"scaphiopus",
"scaphopodas":"scaphopoda",
"scaphosepalums":"scaphosepalum",
"scapulae":"scapula",
"scapulas":"scapula",
"scapulars":"scapular",
"scapularies":"scapulary",
"scarred":"scar",
"scarring":"scar",
"scars":"scar",
"scarabs":"scarab",
"scarabaeans":"scarabaean",
"scarabaeids":"scarabaeid",
"scarabaeidaes":"scarabaeidae",
"scarabaeuses":"scarabaeus",
"scarcer":"scarce",
"scarcest":"scarce",
"scarcenesses":"scarceness",
"scarcities":"scarcity",
"scardiniuses":"scardinius",
"scares":"scare",
"scaring":"scare",
"scarecrows":"scarecrow",
"scaremongers":"scaremonger",
"scarfed":"scarf",
"scarfing":"scarf",
"scarfs":"scarf",
"scarves":"scarf",
"scarfpins":"scarfpin",
"scaridaes":"scaridae",
"scarified":"scarify",
"scarifies":"scarify",
"scarifying":"scarify",
"scarlatinas":"scarlatina",
"scarlets":"scarlet",
"scarped":"scarp",
"scarping":"scarp",
"scarps":"scarp",
"scarpered":"scarper",
"scarpering":"scarper",
"scarpers":"scarper",
"scartellas":"scartella",
"scarier":"scary",
"scariest":"scary",
"scats":"scat",
"scatted":"scat",
"scatting":"scat",
"scathed":"scathe",
"scathes":"scathe",
"scathing":"scathe",
"scattered":"scatter",
"scattering":"scatter",
"scatters":"scatter",
"scatterbrains":"scatterbrain",
"scatterguns":"scattergun",
"scatterings":"scattering",
"scattier":"scatty",
"scattiest":"scatty",
"scaups":"scaup",
"scavenged":"scavenge",
"scavenges":"scavenge",
"scavenging":"scavenge",
"scavengers":"scavenger",
"scds":"scd",
"sceliphrons":"sceliphron",
"sceloglauxes":"sceloglaux",
"sceloporuses":"sceloporus",
"scenarios":"scenario",
"scended":"scend",
"scending":"scend",
"scends":"scend",
"scenes":"scene",
"sceneries":"scenery",
"scented":"scent",
"scenting":"scent",
"scents":"scent",
"sceptered":"scepter",
"sceptering":"scepter",
"scepters":"scepter",
"sceptics":"sceptic",
"scepticisms":"scepticism",
"sceptred":"sceptre",
"sceptres":"sceptre",
"sceptring":"sceptre",
"scets":"scet",
"schadenfreudes":"schadenfreude",
"schaffnerias":"schaffneria",
"schatchens":"schatchen",
"schatchonim":"schatchen",
"shadchans":"schatchen",
"scheduled":"schedule",
"schedules":"schedule",
"scheduling":"schedule",
"schedulings":"scheduling",
"scheffleras":"schefflera",
"schemas":"schema",
"schemata":"schema",
"schematics":"schematic",
"schematisations":"schematisation",
"schematizations":"schematization",
"schematized":"schematize",
"schematizing":"schematize",
"schemed":"scheme",
"schemes":"scheme",
"scheming":"scheme",
"schemers":"schemer",
"schenks":"schenk",
"scheols":"scheol",
"scherzandi":"scherzando",
"scherzandos":"scherzando",
"scherzi":"scherzo",
"scherzoi":"scherzo",
"scherzos":"scherzo",
"scheuchzeriaceaes":"scheuchzeriaceae",
"schinuses":"schinus",
"schisms":"schism",
"schismatized":"schismatize",
"schismatizing":"schismatize",
"schistorrhachises":"schistorrhachis",
"schistosomas":"schistosoma",
"schistosomatidaes":"schistosomatidae",
"schistosomes":"schistosome",
"schistosomiases":"schistosomiasis",
"schizachyriums":"schizachyrium",
"schizaeas":"schizaea",
"schizaeaceaes":"schizaeaceae",
"schizanthuses":"schizanthus",
"schizos":"schizo",
"schizomyceteses":"schizomycetes",
"schizopetalons":"schizopetalon",
"schizophragmas":"schizophragma",
"schizophrenias":"schizophrenia",
"schizophyceaes":"schizophyceae",
"schizophytas":"schizophyta",
"schizosaccharomyceses":"schizosaccharomyces",
"schizosaccharomycetaceaes":"schizosaccharomycetaceae",
"schlemiels":"schlemiel",
"schlepped":"schlep",
"schlepping":"schlep",
"schleps":"schlep",
"schlesiens":"schlesien",
"schlocks":"schlock",
"schlockmeisters":"schlockmeister",
"schlumbergeras":"schlumbergera",
"schmaltzs":"schmaltz",
"schmalzs":"schmalz",
"schmears":"schmear",
"schmeers":"schmeer",
"schmoes":"schmo",
"schmucks":"schmuck",
"schnappses":"schnapps",
"schnapses":"schnaps",
"schneckens":"schnecken",
"schnittlaughs":"schnittlaugh",
"schnitzels":"schnitzel",
"schnorchels":"schnorchel",
"schnorkels":"schnorkel",
"schnozzles":"schnozzle",
"scholars":"scholar",
"scholarships":"scholarship",
"scholastics":"scholastic",
"scholasticisms":"scholasticism",
"scholia":"scholium",
"schomburgkias":"schomburgkia",
"schooled":"school",
"schooling":"school",
"schools":"school",
"schoolbooks":"schoolbook",
"schoolboys":"schoolboy",
"schoolchildren":"schoolchild",
"schooldayses":"schooldays",
"schoolfellows":"schoolfellow",
"schoolgirls":"schoolgirl",
"schoolhouses":"schoolhouse",
"schoolings":"schooling",
"schoolmen":"schoolman",
"schoolmarms":"schoolmarm",
"schoolmasters":"schoolmaster",
"schoolmates":"schoolmate",
"schoolmistresses":"schoolmistress",
"schoolrooms":"schoolroom",
"schoolteachers":"schoolteacher",
"schooltimes":"schooltime",
"schooners":"schooner",
"schrods":"schrod",
"schrodingers":"schrodinger",
"schuln":"schul",
"schussed":"schuss",
"schussing":"schuss",
"schutzstaffeln":"schutzstaffel",
"schwas":"schwa",
"schwarzwalds":"schwarzwald",
"schweizs":"schweiz",
"sciadopityaceaes":"sciadopityaceae",
"sciadopityses":"sciadopitys",
"sciaenas":"sciaena",
"sciaenids":"sciaenid",
"sciaenidaes":"sciaenidae",
"sciaenopses":"sciaenops",
"sciamachies":"sciamachy",
"sciaras":"sciara",
"sciarids":"sciarid",
"sciaridaes":"sciaridae",
"sciences":"science",
"scientists":"scientist",
"scillas":"scilla",
"scincellas":"scincella",
"scincids":"scincid",
"scincidaes":"scincidae",
"scincuses":"scincus",
"scindapsuses":"scindapsus",
"scintillas":"scintilla",
"scintillated":"scintillate",
"scintillates":"scintillate",
"scintillating":"scintillate",
"scintillations":"scintillation",
"sciomachies":"sciomachy",
"scipios":"scipio",
"scirpuses":"scirpus",
"scirrhi":"scirrhus",
"scirrhuses":"scirrhus",
"scissored":"scissor",
"scissoring":"scissor",
"scissortails":"scissortail",
"scissures":"scissure",
"sciuridaes":"sciuridae",
"sciuromorphas":"sciuromorpha",
"sciuruses":"sciurus",
"scleras":"sclera",
"scleranthuses":"scleranthus",
"sclerenchymata":"sclerenchyma",
"sclerodermas":"scleroderma",
"sclerodermataceaes":"sclerodermataceae",
"sclerodermataleses":"sclerodermatales",
"scleromata":"scleroma",
"scleropareis":"scleroparei",
"scleroproteins":"scleroprotein",
"scleroses":"sclerosis",
"sclerotiniaceaes":"sclerotiniaceae",
"sclerotiums":"sclerotium",
"sclerotomies":"sclerotomy",
"sclks":"sclk",
"scoffed":"scoff",
"scoffing":"scoff",
"scoffs":"scoff",
"scoffers":"scoffer",
"scoffings":"scoffing",
"scokes":"scoke",
"scolded":"scold",
"scolding":"scold",
"scolds":"scold",
"scolders":"scolder",
"scoldings":"scolding",
"scoleces":"scolex",
"scolices":"scolex",
"scolions":"scolion",
"scolloped":"scollop",
"scolloping":"scollop",
"scollops":"scollop",
"scolopacidaes":"scolopacidae",
"scolopaxes":"scolopax",
"scolymuses":"scolymus",
"scolytidaes":"scolytidae",
"scolytuses":"scolytus",
"scombers":"scomber",
"scomberesocidaes":"scomberesocidae",
"scomberesoxes":"scomberesox",
"scomberomoruses":"scomberomorus",
"scombresocidaes":"scombresocidae",
"scombresoxes":"scombresox",
"scombridaes":"scombridae",
"scombroids":"scombroid",
"scombroideas":"scombroidea",
"sconces":"sconce",
"scooped":"scoop",
"scooping":"scoop",
"scoops":"scoop",
"scoopfuls":"scoopful",
"scooted":"scoot",
"scooting":"scoot",
"scoots":"scoot",
"scooters":"scooter",
"scopes":"scope",
"scophthalmuses":"scophthalmus",
"scopolamines":"scopolamine",
"scopolias":"scopolia",
"scopulae":"scopula",
"scopulas":"scopula",
"scorched":"scorch",
"scorches":"scorch",
"scorching":"scorch",
"scored":"score",
"scores":"score",
"scoring":"score",
"scorecards":"scorecard",
"scorekeepers":"scorekeeper",
"scorers":"scorer",
"scoreses":"scores",
"scorias":"scoria",
"socriae":"scoria",
"scorified":"scorify",
"scorifies":"scorify",
"scorifying":"scorify",
"scorned":"scorn",
"scorning":"scorn",
"scorns":"scorn",
"scorpaenas":"scorpaena",
"scorpaenids":"scorpaenid",
"scorpaenidaes":"scorpaenidae",
"scorpaenoids":"scorpaenoid",
"scorpaenoideas":"scorpaenoidea",
"scorpios":"scorpio",
"scorpions":"scorpion",
"scorpionfishes":"scorpionfish",
"scorpionidas":"scorpionida",
"scorpionweeds":"scorpionweed",
"scorpiuses":"scorpius",
"scorzoneras":"scorzonera",
"scots":"scot",
"scotched":"scotch",
"scotches":"scotch",
"scotching":"scotch",
"Scotchmen":"Scotchman",
"Scotchwomen":"Scotchwoman",
"scoters":"scoter",
"scotomas":"scotoma",
"scotomata":"scotoma",
"scotses":"scots",
"Scotsmen":"Scotsman",
"Scotswomen":"Scotswoman",
"scotties":"scottie",
"scottishes":"scottish",
"scoundrels":"scoundrel",
"scoured":"scour",
"scouring":"scour",
"scours":"scour",
"scourged":"scourge",
"scourges":"scourge",
"scourging":"scourge",
"scourings":"scouring",
"scouses":"scouse",
"scouted":"scout",
"scouting":"scout",
"scouts":"scout",
"scoutings":"scouting",
"scows":"scow",
"scowled":"scowl",
"scowling":"scowl",
"scowls":"scowl",
"scrabbled":"scrabble",
"scrabbles":"scrabble",
"scrabbling":"scrabble",
"scrabblier":"scrabbly",
"scrabbliest":"scrabbly",
"scragged":"scrag",
"scragging":"scrag",
"scrags":"scrag",
"scragglier":"scraggly",
"scraggliest":"scraggly",
"scraggier":"scraggy",
"scraggiest":"scraggy",
"scrammed":"scram",
"scramming":"scram",
"scrams":"scram",
"scrambled":"scramble",
"scrambles":"scramble",
"scrambling":"scramble",
"scrapped":"scrap",
"scrapping":"scrap",
"scraps":"scrap",
"scrapbooks":"scrapbook",
"scraped":"scrape",
"scrapes":"scrape",
"scraping":"scrape",
"scrapers":"scraper",
"scrapheaps":"scrapheap",
"scrapings":"scraping",
"scrappers":"scrapper",
"scrappier":"scrappy",
"scrappiest":"scrappy",
"scrapses":"scraps",
"scratched":"scratch",
"scratches":"scratch",
"scratching":"scratch",
"scratchinesses":"scratchiness",
"scratchings":"scratching",
"scratchier":"scratchy",
"scratchiest":"scratchy",
"scrawled":"scrawl",
"scrawling":"scrawl",
"scrawls":"scrawl",
"scrawninesses":"scrawniness",
"scrawnier":"scrawny",
"scrawniest":"scrawny",
"screamed":"scream",
"screaming":"scream",
"screams":"scream",
"screamings":"screaming",
"screes":"scree",
"screeched":"screech",
"screeches":"screech",
"screeching":"screech",
"screechings":"screeching",
"screechier":"screechy",
"screechiest":"screechy",
"screened":"screen",
"screening":"screen",
"screens":"screen",
"screenings":"screening",
"screenwriters":"screenwriter",
"screwed":"screw",
"screwing":"screw",
"screws":"screw",
"screwballs":"screwball",
"screwbeans":"screwbean",
"screwings":"screwing",
"screwier":"screwy",
"screwiest":"screwy",
"scribbled":"scribble",
"scribbles":"scribble",
"scribbling":"scribble",
"scribblers":"scribbler",
"scribed":"scribe",
"scribes":"scribe",
"scribing":"scribe",
"scribers":"scriber",
"scrimmaged":"scrimmage",
"scrimmages":"scrimmage",
"scrimmaging":"scrimmage",
"scrimped":"scrimp",
"scrimping":"scrimp",
"scrimps":"scrimp",
"scrimpier":"scrimpy",
"scrimpiest":"scrimpy",
"scrimshawed":"scrimshaw",
"scrimshawing":"scrimshaw",
"scripted":"script",
"scripting":"script",
"scripts":"script",
"scriptoria":"scriptorium",
"scriptoriums":"scriptorium",
"scriptures":"scripture",
"scriveners":"scrivener",
"scrods":"scrod",
"scrofulas":"scrofula",
"scrolled":"scroll",
"scrolling":"scroll",
"scrolls":"scroll",
"scrooges":"scrooge",
"scrophularias":"scrophularia",
"scrophulariaceaes":"scrophulariaceae",
"scrophularialeses":"scrophulariales",
"scrota":"scrotum",
"scrotums":"scrotum",
"scrounged":"scrounge",
"scrounges":"scrounge",
"scrounging":"scrounge",
"scroungers":"scrounger",
"scroungier":"scroungy",
"scroungiest":"scroungy",
"scrubbed":"scrub",
"scrubbing":"scrub",
"scrubs":"scrub",
"scrubbings":"scrubbing",
"scrubbirds":"scrubbird",
"scrubbier":"scrubby",
"scrubbiest":"scrubby",
"scrubses":"scrubs",
"scrubwomen":"scrubwoman",
"scruffs":"scruff",
"scruffier":"scruffy",
"scruffiest":"scruffy",
"scrummed":"scrum",
"scrumming":"scrum",
"scrums":"scrum",
"scrummaged":"scrummage",
"scrummages":"scrummage",
"scrummaging":"scrummage",
"scrunched":"scrunch",
"scrunches":"scrunch",
"scrunching":"scrunch",
"scrupled":"scruple",
"scruples":"scruple",
"scrupling":"scruple",
"scrupleses":"scruples",
"scrupulousnesses":"scrupulousness",
"scrutineers":"scrutineer",
"scrutinized":"scrutinize",
"scrutinizes":"scrutinize",
"scrutinizing":"scrutinize",
"scrutinies":"scrutiny",
"scried":"scry",
"scries":"scry",
"scrying":"scry",
"scsis":"scsi",
"scubas":"scuba",
"scudded":"scud",
"scudding":"scud",
"scuds":"scud",
"scuddings":"scudding",
"scudi":"scudo",
"scuffed":"scuff",
"scuffing":"scuff",
"scuffs":"scuff",
"scuffings":"scuffing",
"scuffled":"scuffle",
"scuffles":"scuffle",
"scuffling":"scuffle",
"scuffses":"scuffs",
"sculled":"scull",
"sculling":"scull",
"sculleries":"scullery",
"sculpins":"sculpin",
"sculpted":"sculpt",
"sculpting":"sculpt",
"sculpts":"sculpt",
"sculptors":"sculptor",
"sculptured":"sculpture",
"sculptures":"sculpture",
"sculpturing":"sculpture",
"sculpturers":"sculpturer",
"scummed":"scum",
"scumming":"scum",
"scums":"scum",
"scumbled":"scumble",
"scumbling":"scumble",
"scummier":"scummy",
"scummiest":"scummy",
"scungier":"scungy",
"scungiest":"scungy",
"scunnered":"scunner",
"scunnering":"scunner",
"scups":"scup",
"scurfs":"scurf",
"scurfier":"scurfy",
"scurfiest":"scurfy",
"scurrilities":"scurrility",
"scurried":"scurry",
"scurries":"scurry",
"scurrying":"scurry",
"scurvier":"scurvy",
"scurviest":"scurvy",
"scutcheons":"scutcheon",
"scutellarias":"scutellaria",
"scutella":"scutellum",
"scutigeras":"scutigera",
"scutigerellas":"scutigerella",
"scutigeridaes":"scutigeridae",
"scuttered":"scutter",
"scuttering":"scutter",
"scuttled":"scuttle",
"scuttles":"scuttle",
"scuttling":"scuttle",
"scuttlebutts":"scuttlebutt",
"scuta":"scutum",
"scyliorhinidaes":"scyliorhinidae",
"scyphistomae":"scyphistoma",
"scyphistomas":"scyphistoma",
"scyphozoas":"scyphozoa",
"scyphi":"scyphus",
"scythed":"scythe",
"scythes":"scythe",
"scything":"scythe",
"seas":"sea",
"sea-duties":"sea-duty",
"sea-ears":"sea-ear",
"sea-rockets":"sea-rocket",
"seabeds":"seabed",
"seabirds":"seabird",
"seaboards":"seaboard",
"seacoasts":"seacoast",
"seafarers":"seafarer",
"seafarings":"seafaring",
"seafowls":"seafowl",
"seagulls":"seagull",
"seahorses":"seahorse",
"sealing":"seal",
"seals":"seal",
"sealants":"sealant",
"sealers":"sealer",
"sealings":"sealing",
"sealskins":"sealskin",
"sealyhams":"sealyham",
"seamed":"seam",
"seaming":"seam",
"seams":"seam",
"seamen":"seaman",
"seamstresses":"seamstress",
"seamier":"seamy",
"seamiest":"seamy",
"seanads":"seanad",
"seances":"seance",
"seaplanes":"seaplane",
"seapooses":"seapoose",
"seaports":"seaport",
"seaquakes":"seaquake",
"seared":"sear",
"searing":"sear",
"sears":"sear",
"searched":"search",
"searches":"search",
"searching":"search",
"searchers":"searcher",
"searchings":"searching",
"searchlights":"searchlight",
"searobins":"searobin",
"seashells":"seashell",
"seashores":"seashore",
"seasicknesses":"seasickness",
"seasides":"seaside",
"seasnails":"seasnail",
"seasoned":"season",
"seasoning":"season",
"seasons":"season",
"seasonablenesses":"seasonableness",
"seasoners":"seasoner",
"seasonings":"seasoning",
"seating":"seat",
"seats":"seat",
"seatings":"seating",
"seatses":"seats",
"seawalls":"seawall",
"seawaters":"seawater",
"seaways":"seaway",
"seaworthinesses":"seaworthiness",
"seaworthier":"seaworthy",
"seaworthiest":"seaworthy",
"sebastianas":"sebastiana",
"sebastodeses":"sebastodes",
"sebastopols":"sebastopol",
"sebes":"sebe",
"sebses":"sebs",
"secs":"sec",
"secales":"secale",
"seccos":"secco",
"seceded":"secede",
"secedes":"secede",
"seceding":"secede",
"secessions":"secession",
"sechuanas":"sechuana",
"seckels":"seckel",
"secluded":"seclude",
"secludes":"seclude",
"secluding":"seclude",
"seclusions":"seclusion",
"secobarbitals":"secobarbital",
"seconals":"seconal",
"seconded":"second",
"seconding":"second",
"seconds":"second",
"second-guessed":"second-guess",
"second-guessing":"second-guess",
"second-raters":"second-rater",
"secondaries":"secondary",
"secondi":"secondo",
"secotiaceaes":"secotiaceae",
"secotialeses":"secotiales",
"secpars":"secpar",
"secrecies":"secrecy",
"secrets":"secret",
"secretaires":"secretaire",
"secretariats":"secretariat",
"secretariates":"secretariate",
"secretaries":"secretary",
"secretaries-general":"secretary-general",
"secreted":"secrete",
"secretes":"secrete",
"secreting":"secrete",
"secretings":"secreting",
"secretivenesses":"secretiveness",
"sects":"sect",
"sectarianisms":"sectarianism",
"sectaries":"sectary",
"sectioned":"section",
"sectioning":"section",
"sections":"section",
"sectionalisms":"sectionalism",
"sectionalizations":"sectionalization",
"sectored":"sector",
"sectoring":"sector",
"sectors":"sector",
"sectrals":"sectral",
"seculars":"secular",
"secularisations":"secularisation",
"secularists":"secularist",
"secularities":"secularity",
"secularizations":"secularization",
"secularized":"secularize",
"secularizing":"secularize",
"secundigravidas":"secundigravida",
"securer":"secure",
"securest":"secure",
"securing":"secure",
"securenesses":"secureness",
"securities":"security",
"sedans":"sedan",
"sedater":"sedate",
"sedates":"sedate",
"sedatest":"sedate",
"sedatenesses":"sedateness",
"sedations":"sedation",
"sedatives":"sedative",
"sedative-hypnotics":"sedative-hypnotic",
"seders":"seder",
"sediments":"sediment",
"sedimentations":"sedimentation",
"seduced":"seduce",
"seduces":"seduce",
"seducing":"seduce",
"seducements":"seducement",
"seducers":"seducer",
"seductions":"seduction",
"sedulities":"sedulity",
"sedulousnesses":"sedulousness",
"saw":"see",
"seeing":"see",
"seen":"see",
"sees":"see",
"seeded":"seed",
"seeding":"seed",
"seeds":"seed",
"seedcases":"seedcase",
"seedinesses":"seediness",
"seedlings":"seedling",
"seedmen":"seedman",
"seedpods":"seedpod",
"seedsmen":"seedsman",
"seedier":"seedy",
"seediest":"seedy",
"seeings":"seeing",
"seeking":"seek",
"seeks":"seek",
"sought":"seek",
"seekers":"seeker",
"seekings":"seeking",
"seelands":"seeland",
"seemed":"seem",
"seeming":"seem",
"seems":"seem",
"seemings":"seeming",
"seemlinesses":"seemliness",
"seemlier":"seemly",
"seemliest":"seemly",
"seeped":"seep",
"seeping":"seep",
"seeps":"seep",
"seepages":"seepage",
"seers":"seer",
"seesawed":"seesaw",
"seesawing":"seesaw",
"seesaws":"seesaw",
"seethed":"seethe",
"seethes":"seethe",
"seething":"seethe",
"segmented":"segment",
"segmenting":"segment",
"segments":"segment",
"segmentalized":"segmentalize",
"segmentalizing":"segmentalize",
"segmentations":"segmentation",
"segni":"segno",
"segregated":"segregate",
"segregating":"segregate",
"segregations":"segregation",
"segregationists":"segregationist",
"seigneurs":"seigneur",
"seigneuries":"seigneury",
"seigniors":"seignior",
"seigniories":"seigniory",
"seignories":"seignory",
"seined":"seine",
"seines":"seine",
"seining":"seine",
"seisms":"seism",
"seismosaurs":"seismosaur",
"seismosauruses":"seismosaurus",
"seiuruses":"seiurus",
"seized":"seize",
"seizes":"seize",
"seizing":"seize",
"seizers":"seizer",
"seizings":"seizing",
"seizures":"seizure",
"sekhets":"sekhet",
"selachians":"selachian",
"selachiis":"selachii",
"selaginellas":"selaginella",
"selaginellaceaes":"selaginellaceae",
"selaginellaleses":"selaginellales",
"selars":"selar",
"selected":"select",
"selecting":"select",
"selects":"select",
"selections":"selection",
"selectmen":"selectman",
"selectors":"selector",
"selenarctoses":"selenarctos",
"selenes":"selene",
"selenicereuses":"selenicereus",
"selenipediums":"selenipedium",
"seleniums":"selenium",
"selenolatries":"selenolatry",
"seleucidae":"seleucid",
"seleucids":"seleucid",
"seleucuses":"seleucus",
"selves":"self",
"self-abasements":"self-abasement",
"self-abnegations":"self-abnegation",
"self-abuses":"self-abuse",
"self-accusations":"self-accusation",
"self-actualized":"self-actualize",
"self-actualizing":"self-actualize",
"self-aggrandisements":"self-aggrandisement",
"self-aggrandizements":"self-aggrandizement",
"self-analyses":"self-analysis",
"self-annihilations":"self-annihilation",
"self-assertivenesses":"self-assertiveness",
"self-assurances":"self-assurance",
"self-centerednesses":"self-centeredness",
"self-commands":"self-command",
"self-complacencies":"self-complacency",
"self-concerns":"self-concern",
"self-condemnations":"self-condemnation",
"self-confidences":"self-confidence",
"self-consciousnesses":"self-consciousness",
"self-contemplations":"self-contemplation",
"self-controls":"self-control",
"self-cultivations":"self-cultivation",
"self-deceits":"self-deceit",
"self-deceptions":"self-deception",
"self-defences":"self-defence",
"self-defenses":"self-defense",
"self-denials":"self-denial",
"self-destructions":"self-destruction",
"self-determinations":"self-determination",
"self-directions":"self-direction",
"self-disciplines":"self-discipline",
"self-disgusts":"self-disgust",
"self-distrusts":"self-distrust",
"self-doubts":"self-doubt",
"self-educations":"self-education",
"self-effacements":"self-effacement",
"self-esteems":"self-esteem",
"self-examinations":"self-examination",
"self-feeders":"self-feeder",
"self-fertilisations":"self-fertilisation",
"self-fertilizations":"self-fertilization",
"self-flagellations":"self-flagellation",
"self-fulfillments":"self-fulfillment",
"self-governments":"self-government",
"self-gratifications":"self-gratification",
"self-hatreds":"self-hatred",
"self-heals":"self-heal",
"self-hypnoses":"self-hypnosis",
"self-ignited":"self-ignite",
"self-igniting":"self-ignite",
"self-importances":"self-importance",
"self-improvements":"self-improvement",
"self-inductances":"self-inductance",
"self-indulgences":"self-indulgence",
"self-interests":"self-interest",
"self-justifications":"self-justification",
"self-loves":"self-love",
"self-mortifications":"self-mortification",
"self-organisations":"self-organisation",
"self-organizations":"self-organization",
"self-possessions":"self-possession",
"self-praises":"self-praise",
"self-prides":"self-pride",
"self-protections":"self-protection",
"self-punishments":"self-punishment",
"self-realisations":"self-realisation",
"self-realizations":"self-realization",
"self-reformations":"self-reformation",
"self-regards":"self-regard",
"self-reliances":"self-reliance",
"self-renunciations":"self-renunciation",
"self-reproaches":"self-reproach",
"self-reproofs":"self-reproof",
"self-reprooves":"self-reproof",
"self-respects":"self-respect",
"self-restraints":"self-restraint",
"self-rules":"self-rule",
"self-sacrifices":"self-sacrifice",
"self-satisfactions":"self-satisfaction",
"self-seekers":"self-seeker",
"self-seekings":"self-seeking",
"self-starters":"self-starter",
"self-studies":"self-study",
"self-sufficiencies":"self-sufficiency",
"self-suggestions":"self-suggestion",
"self-torments":"self-torment",
"self-tortures":"self-torture",
"self-wills":"self-will",
"self-worships":"self-worship",
"selflessnesses":"selflessness",
"selkups":"selkup",
"selling":"sell",
"sells":"sell",
"sold":"sell",
"sellers":"seller",
"sellings":"selling",
"seltzers":"seltzer",
"selvages":"selvage",
"selvedges":"selvedge",
"semanticists":"semanticist",
"semaphored":"semaphore",
"semaphoring":"semaphore",
"semblances":"semblance",
"semens":"semen",
"semesters":"semester",
"semis":"semi",
"semiautomatics":"semiautomatic",
"semibreves":"semibreve",
"semicircles":"semicircle",
"semicolons":"semicolon",
"semiconductors":"semiconductor",
"semiconsciousnesses":"semiconsciousness",
"semiepiphytes":"semiepiphyte",
"semifinals":"semifinal",
"seminars":"seminar",
"seminarians":"seminarian",
"seminarists":"seminarist",
"seminaries":"seminary",
"seminoles":"seminole",
"seminomas":"seminoma",
"semioticians":"semiotician",
"semipros":"semipro",
"semiprofessionals":"semiprofessional",
"semiquavers":"semiquaver",
"semitones":"semitone",
"semitrailers":"semitrailer",
"semitransparencies":"semitransparency",
"semitropicses":"semitropics",
"semivowels":"semivowel",
"semiweeklies":"semiweekly",
"sempatches":"sempatch",
"sempstresses":"sempstress",
"senates":"senate",
"senators":"senator",
"sending":"send",
"sends":"send",
"sent":"send",
"send-offs":"send-off",
"senders":"sender",
"sendups":"sendup",
"senecas":"seneca",
"senecios":"senecio",
"senegas":"senega",
"senescences":"senescence",
"seneschals":"seneschal",
"senilities":"senility",
"seniors":"senior",
"seniorities":"seniority",
"senores":"senor",
"senors":"senor",
"senoras":"senora",
"senoritas":"senorita",
"senses":"sense",
"sensations":"sensation",
"sensationalisms":"sensationalism",
"sensationalists":"sensationalist",
"sensed":"sense",
"sensing":"sense",
"senselessnesses":"senselessness",
"sensibilities":"sensibility",
"sensilla":"sensillum",
"sensings":"sensing",
"sensitisations":"sensitisation",
"sensitivenesses":"sensitiveness",
"sensitivities":"sensitivity",
"sensitizations":"sensitization",
"sensitized":"sensitize",
"sensitizes":"sensitize",
"sensitizing":"sensitize",
"sensitizings":"sensitizing",
"sensors":"sensor",
"sensualisms":"sensualism",
"sensualities":"sensuality",
"sensualized":"sensualize",
"sensualizes":"sensualize",
"sensualizing":"sensualize",
"sensualnesses":"sensualness",
"sentenced":"sentence",
"sentences":"sentence",
"sentencing":"sentence",
"sentiences":"sentience",
"sentiencies":"sentiency",
"sentiments":"sentiment",
"sentimentalisations":"sentimentalisation",
"sentimentalists":"sentimentalist",
"sentimentalities":"sentimentality",
"sentimentalizations":"sentimentalization",
"sentimentalized":"sentimentalize",
"sentimentalizes":"sentimentalize",
"sentimentalizing":"sentimentalize",
"sentineled":"sentinel",
"sentineling":"sentinel",
"sentinelled":"sentinel",
"sentinelling":"sentinel",
"sentinels":"sentinel",
"sentries":"sentry",
"senussis":"senusi",
"seouls":"seoul",
"seps":"sep",
"separates":"separate",
"separating":"separate",
"separatenesses":"separateness",
"separations":"separation",
"separators":"separator",
"separatrixes":"separatrix",
"sephardim":"sephardi",
"sepias":"sepia",
"sepiidaes":"sepiidae",
"sepiolites":"sepiolite",
"septs":"sept",
"septariia":"septarium",
"Septembers":"September",
"septenaries":"septenary",
"septennia":"septennium",
"septenniums":"septennium",
"septentrions":"septentrion",
"septets":"septet",
"septettes":"septette",
"septicaemias":"septicaemia",
"septicemias":"septicemia",
"septillions":"septillion",
"septobasidiaceaes":"septobasidiaceae",
"septobasidiums":"septobasidium",
"septuagesimas":"septuagesima",
"septa":"septum",
"sepulchered":"sepulcher",
"sepulchering":"sepulcher",
"sepulchers":"sepulcher",
"sepulchres":"sepulchre",
"sepultures":"sepulture",
"sequels":"sequel",
"sequelae":"sequela",
"sequences":"sequence",
"sequestered":"sequester",
"sequestering":"sequester",
"sequesters":"sequester",
"sequestrated":"sequestrate",
"sequestrates":"sequestrate",
"sequestrating":"sequestrate",
"sequestrations":"sequestration",
"sequestra":"sequestrum",
"sequins":"sequin",
"sequoias":"sequoia",
"sequoiadendrons":"sequoiadendron",
"seraglios":"seraglio",
"serais":"serai",
"serails":"serail",
"serapes":"serape",
"seraphim":"seraph",
"seraphs":"seraph",
"seraxes":"serax",
"serbs":"serb",
"serbias":"serbia",
"serbians":"serbian",
"serbo-croats":"serbo-croat",
"serbo-croatians":"serbo-croatian",
"serenaded":"serenade",
"serenades":"serenade",
"serenading":"serenade",
"serener":"serene",
"serenest":"serene",
"serenities":"serenity",
"serenoas":"serenoa",
"serfs":"serf",
"serves":"serve",
"serfdoms":"serfdom",
"serfhoods":"serfhood",
"serged":"serge",
"serging":"serge",
"sergeants":"sergeant",
"sergeant-at-laws":"sergeant-at-law",
"serials":"serial",
"serialisations":"serialisation",
"serialisms":"serialism",
"serializations":"serialization",
"serialized":"serialize",
"serializing":"serialize",
"sericocarpuses":"sericocarpus",
"sericteriums":"sericterium",
"sericteries":"serictery",
"seriemas":"seriema",
"serifs":"serif",
"serinuses":"serinus",
"seriocomedies":"seriocomedy",
"seriolas":"seriola",
"serious-mindednesses":"serious-mindedness",
"seriousnesses":"seriousness",
"seriphs":"seriph",
"seriphidiums":"seriphidium",
"seriphuses":"seriphus",
"serjeants":"serjeant",
"serjeant-at-armses":"serjeant-at-arms",
"serjeant-at-laws":"serjeant-at-law",
"sermons":"sermon",
"sermonized":"sermonize",
"sermonizes":"sermonize",
"sermonizing":"sermonize",
"sermonizers":"sermonizer",
"serographs":"serograph",
"serologists":"serologist",
"serosae":"serosa",
"serosas":"serosa",
"serotherapies":"serotherapy",
"serotines":"serotine",
"serotonins":"serotonin",
"serpasils":"serpasil",
"serpents":"serpent",
"serpent-worships":"serpent-worship",
"serpenteses":"serpentes",
"serpentined":"serpentine",
"serpentining":"serpentine",
"serranids":"serranid",
"serranidaes":"serranidae",
"serranuses":"serranus",
"serrasalmuses":"serrasalmus",
"serratulas":"serratula",
"serratuses":"serratus",
"sertularias":"sertularia",
"sera":"serum",
"serums":"serum",
"servals":"serval",
"servants":"servant",
"served":"serve",
"serving":"serve",
"servers":"server",
"serviced":"service",
"services":"service",
"servicing":"service",
"serviceabilities":"serviceability",
"serviceablenesses":"serviceableness",
"serviceberries":"serviceberry",
"servicemen":"serviceman",
"servicings":"servicing",
"serviettes":"serviette",
"servilities":"servility",
"servings":"serving",
"servos":"servo",
"servomechanisms":"servomechanism",
"servosystems":"servosystem",
"sesames":"sesame",
"sesamums":"sesamum",
"seselis":"seseli",
"sesothos":"sesotho",
"sesquipedalias":"sesquipedalia",
"sesquipedalians":"sesquipedalian",
"sesses":"sess",
"sessions":"session",
"sestertia":"sestertium",
"sestets":"sestet",
"sets":"set",
"setting":"set",
"set-tos":"set-to",
"setae":"seta",
"setarias":"setaria",
"setbacks":"setback",
"seths":"seth",
"setoffs":"setoff",
"setophagas":"setophaga",
"setswanas":"setswana",
"setts":"sett",
"settees":"settee",
"setterworts":"setterwort",
"settings":"setting",
"settles":"settle",
"settling":"settle",
"settlements":"settlement",
"settlers":"settler",
"settlings":"settling",
"setups":"setup",
"sevastopols":"sevastopol",
"sevens":"seven",
"seven-ups":"seven-up",
"seveners":"sevener",
"sevenses":"sevens",
"sevensomes":"sevensome",
"seventeens":"seventeen",
"seventeenths":"seventeenth",
"sevenths":"seventh",
"seventieses":"seventies",
"seventies":"seventy",
"severed":"sever",
"severing":"sever",
"severs":"sever",
"severalties":"severalty",
"severances":"severance",
"severer":"severe",
"severest":"severe",
"severenesses":"severeness",
"severings":"severing",
"severities":"severity",
"sewed":"sew",
"sewing":"sew",
"sewn":"sew",
"sews":"sew",
"sewages":"sewage",
"sewellels":"sewellel",
"sewered":"sewer",
"sewering":"sewer",
"sewers":"sewer",
"sewerages":"sewerage",
"sewings":"sewing",
"sexed":"sex",
"sexes":"sex",
"sexing":"sex",
"sexcentenaries":"sexcentenary",
"sexinesses":"sexiness",
"sexists":"sexist",
"sexlessnesses":"sexlessness",
"sextets":"sextet",
"sextettes":"sextette",
"sextillions":"sextillion",
"sextos":"sexto",
"sextodecimos":"sextodecimo",
"sextons":"sexton",
"sextupled":"sextuple",
"sextupling":"sextuple",
"sextuplets":"sextuplet",
"sexualities":"sexuality",
"sexualized":"sexualize",
"sexulizing":"sexualize",
"sexier":"sexy",
"sexiest":"sexy",
"seymours":"seymour",
"sgmls":"sgml",
"sgraffiti":"sgraffito",
"shabbasim":"shabbas",
"shabbatim":"shabbat",
"shabbinesses":"shabbiness",
"shabbier":"shabby",
"shabbiest":"shabby",
"shabuoths":"shabuoth",
"shacked":"shack",
"shacking":"shack",
"shacks":"shack",
"shackled":"shackle",
"shackles":"shackle",
"shackling":"shackle",
"shackoes":"shacko",
"shackos":"shacko",
"shads":"shad",
"shadberries":"shadberry",
"shadblows":"shadblow",
"shadbushes":"shadbush",
"shadchanim":"shadchan",
"shaddocks":"shaddock",
"shaded":"shade",
"shades":"shade",
"shading":"shade",
"shadeses":"shades",
"shadflowers":"shadflower",
"shadflies":"shadfly",
"shadinesses":"shadiness",
"shadings":"shading",
"shadowed":"shadow",
"shadowing":"shadow",
"shadows":"shadow",
"shadowboxed":"shadowbox",
"shadowboxes":"shadowbox",
"shadowboxing":"shadowbox",
"shadowgraphs":"shadowgraph",
"shadowinesses":"shadowiness",
"shadowings":"shadowing",
"shadowier":"shadowy",
"shadowiest":"shadowy",
"shadier":"shady",
"shadiest":"shady",
"shafted":"shaft",
"shafting":"shaft",
"shafts":"shaft",
"shagged":"shag",
"shagging":"shag",
"shags":"shag",
"shagbarks":"shagbark",
"shaggings":"shagging",
"shaggier":"shaggy",
"shaggiest":"shaggy",
"shaggycaps":"shaggycap",
"shaggymanes":"shaggymane",
"shahaptians":"shahaptian",
"shaken":"shake",
"shakes":"shake",
"shaking":"shake",
"shook":"shake",
"shake-ups":"shake-up",
"shakespeares":"shakespeare",
"shaken_hands":"shake_hands",
"shakes_hands":"shake_hands",
"shaking_hands":"shake_hands",
"shook_hands":"shake_hands",
"shakinesses":"shakiness",
"shakings":"shaking",
"shakoes":"shako",
"shakos":"shako",
"shaksperes":"shakspere",
"shaktis":"shakti",
"shaktisms":"shaktism",
"shakier":"shaky",
"shakiest":"shaky",
"should":"should",
"shallons":"shallon",
"shallots":"shallot",
"shallowed":"shallow",
"shallower":"shallow",
"shallowest":"shallow",
"shallowing":"shallow",
"shallows":"shallow",
"shallownesses":"shallowness",
"shallus":"shallu",
"shammed":"sham",
"shamming":"sham",
"shams":"sham",
"shamen":"shaman",
"shambled":"shamble",
"shambles":"shamble",
"shambling":"shamble",
"shambleses":"shambles",
"shamblings":"shambling",
"shamed":"shame",
"shames":"shame",
"shaming":"shame",
"shamefacednesses":"shamefacedness",
"shamefulnesses":"shamefulness",
"shamelessnesses":"shamelessness",
"shammosim":"shammas",
"shammies":"shammy",
"shampooed":"shampoo",
"shampooing":"shampoo",
"shampoos":"shampoo",
"shamrocks":"shamrock",
"shamuses":"shamus",
"shans":"shan",
"shandies":"shandy",
"shandygaffs":"shandygaff",
"shanghaied":"shanghai",
"shanghaiing":"shanghai",
"shanghais":"shanghai",
"shanghaiers":"shanghaier",
"shangri-las":"shangri-la",
"shanks":"shank",
"shannies":"shanny",
"shanteys":"shantey",
"shanties":"shanty",
"shapes":"shape",
"shaping":"shape",
"shapelinesses":"shapeliness",
"shapelier":"shapely",
"shapeliest":"shapely",
"shapers":"shaper",
"shapings":"shaping",
"shards":"shard",
"shared":"share",
"shares":"share",
"sharing":"share",
"share-outs":"share-out",
"sharecropped":"sharecrop",
"sharecropping":"sharecrop",
"sharecrops":"sharecrop",
"sharecroppers":"sharecropper",
"shareholders":"shareholder",
"shareowners":"shareowner",
"sharers":"sharer",
"sharings":"sharing",
"sharked":"shark",
"sharking":"shark",
"sharks":"shark",
"sharksuckers":"sharksucker",
"sharped":"sharp",
"sharper":"sharp",
"sharpest":"sharp",
"sharping":"sharp",
"sharps":"sharp",
"sharp-sightednesses":"sharp-sightedness",
"sharpened":"sharpen",
"sharpening":"sharpen",
"sharpens":"sharpen",
"sharpers":"sharper",
"sharpies":"sharpie",
"sharpnesses":"sharpness",
"sharpshooters":"sharpshooter",
"shattered":"shatter",
"shattering":"shatter",
"shatters":"shatter",
"shatterings":"shattering",
"shaved":"shave",
"shaven":"shave",
"shaves":"shave",
"shaving":"shave",
"shavers":"shaver",
"shavings":"shaving",
"shavouses":"shavous",
"shavuots":"shavuot",
"shavuoths":"shavuoth",
"shaws":"shaw",
"shawled":"shawl",
"shawling":"shawl",
"shawls":"shawl",
"shawnees":"shawnee",
"shawnies":"shawny",
"she-goats":"she-goat",
"sheaves":"sheaf",
"sheared":"shear",
"shearing":"shear",
"shears":"shear",
"shn":"shear",
"shorn":"shear",
"sheatfishes":"sheatfish",
"sheaths":"sheath",
"sheathed":"sheathe",
"sheathing":"sheathe",
"sheathings":"sheathing",
"sheaved":"sheave",
"sheaving":"sheave",
"shebats":"shebat",
"shedded":"shed",
"shedding":"shed",
"sheds":"shed",
"sheddings":"shedding",
"sheened":"sheen",
"sheening":"sheen",
"sheens":"sheen",
"sheenier":"sheeny",
"sheenies":"sheeny",
"sheeniest":"sheeny",
"sheepcotes":"sheepcote",
"sheepdogs":"sheepdog",
"sheepfolds":"sheepfold",
"sheepherders":"sheepherder",
"sheepishnesses":"sheepishness",
"sheepmen":"sheepman",
"sheepruns":"sheeprun",
"sheepsheads":"sheepshead",
"sheepskins":"sheepskin",
"sheepticks":"sheeptick",
"sheepwalks":"sheepwalk",
"sheered":"sheer",
"sheerer":"sheer",
"sheerest":"sheer",
"sheering":"sheer",
"sheeted":"sheet",
"sheeting":"sheet",
"sheets":"sheet",
"sheiks":"sheik",
"sheikas":"sheika",
"sheikdoms":"sheikdom",
"sheikhs":"sheikh",
"sheikhas":"sheikha",
"sheikhdoms":"sheikhdom",
"shekels":"shekel",
"shekelses":"shekels",
"sheldrakes":"sheldrake",
"shelves":"shelf",
"shelled":"shell",
"shelling":"shell",
"shells":"shell",
"shellaced":"shellac",
"shellacing":"shellac",
"shellacs":"shellac",
"shellbarks":"shellbark",
"shellfishes":"shellfish",
"shellflowers":"shellflower",
"shellings":"shelling",
"sheltered":"shelter",
"sheltering":"shelter",
"shelters":"shelter",
"shelterbelts":"shelterbelt",
"shelties":"sheltie",
"shelved":"shelve",
"shelving":"shelve",
"shen-paos":"shen-pao",
"shenanigans":"shenanigan",
"shending":"shend",
"shends":"shend",
"shent":"shend",
"shenyangs":"shenyang",
"shepards":"shepard",
"shepherded":"shepherd",
"shepherding":"shepherd",
"shepherds":"shepherd",
"sherberts":"sherbert",
"sherbets":"sherbet",
"sherds":"sherd",
"sheriffs":"sheriff",
"sherlocks":"sherlock",
"sherpas":"sherpa",
"sherries":"sherry",
"shetlands":"shetland",
"shevats":"shevat",
"shewed":"shew",
"shewing":"shew",
"shewn":"shew",
"shews":"shew",
"shfs":"shf",
"shias":"shia",
"shiahs":"shiah",
"shiatsus":"shiatsu",
"shibahs":"shibah",
"shibboleths":"shibboleth",
"shielded":"shield",
"shielding":"shield",
"shields":"shield",
"shifted":"shift",
"shifting":"shift",
"shifts":"shift",
"shiftinesses":"shiftiness",
"shiftings":"shifting",
"shiftier":"shifty",
"shiftiest":"shifty",
"shigellae":"shigella",
"shigelloses":"shigellosis",
"shiitakes":"shiitake",
"shiites":"shiite",
"shikarred":"shikar",
"shikarring":"shikar",
"shikars":"shikar",
"shikarees":"shikaree",
"shikaris":"shikari",
"shiksas":"shiksa",
"shikses":"shikse",
"shillalahs":"shillalah",
"shillelaghs":"shillelagh",
"shillings":"shilling",
"shilly-shallied":"shilly-shally",
"shilly-shallies":"shilly-shally",
"shilly-shallying":"shilly-shally",
"shillyshallies":"shillyshally",
"shilohs":"shiloh",
"shimmed":"shim",
"shimming":"shim",
"shims":"shim",
"shimmered":"shimmer",
"shimmering":"shimmer",
"shimmers":"shimmer",
"shimmied":"shimmy",
"shimmies":"shimmy",
"shimmying":"shimmy",
"shinned":"shin",
"shinning":"shin",
"shins":"shin",
"shinbones":"shinbone",
"shindigs":"shindig",
"shindies":"shindy",
"shined":"shine",
"shines":"shine",
"shining":"shine",
"shone":"shine",
"shiners":"shiner",
"shingled":"shingle",
"shingles":"shingle",
"shingling":"shingle",
"shinglers":"shingler",
"shingleses":"shingles",
"shininesses":"shininess",
"shinings":"shining",
"shinleaves":"shinleaf",
"shinnied":"shinny",
"shinnies":"shinny",
"shinnying":"shinny",
"shinties":"shinny",
"shinpads":"shinpad",
"shintos":"shinto",
"shintoisms":"shintoism",
"shinier":"shiny",
"shiniest":"shiny",
"shipped":"ship",
"shipping":"ship",
"ships":"ship",
"shiploads":"shipload",
"shipmen":"shipman",
"shipmasters":"shipmaster",
"shipments":"shipment",
"shippers":"shipper",
"shippings":"shipping",
"shipways":"shipway",
"shipworms":"shipworm",
"shipwrecked":"shipwreck",
"shipwrecking":"shipwreck",
"shipwrecks":"shipwreck",
"shipyards":"shipyard",
"shires":"shire",
"shirked":"shirk",
"shirking":"shirk",
"shirks":"shirk",
"shirkers":"shirker",
"shirkings":"shirking",
"shirred":"shirr",
"shirring":"shirr",
"shirts":"shirt",
"shirtfronts":"shirtfront",
"shirtwaists":"shirtwaist",
"shirtwaisters":"shirtwaister",
"shirtier":"shirty",
"shirtiest":"shirty",
"shat":"shit",
"shits":"shit",
"shitting":"shit",
"shitheads":"shithead",
"shitlists":"shitlist",
"shittahs":"shittah",
"shittims":"shittim",
"shittimwoods":"shittimwood",
"shittings":"shitting",
"shittier":"shitty",
"shittiest":"shitty",
"shivas":"shiva",
"shivahs":"shivah",
"shivaisms":"shivaism",
"shivarees":"shivaree",
"shivered":"shiver",
"shivering":"shiver",
"shivers":"shiver",
"shiverings":"shivering",
"shlemiels":"shlemiel",
"shlocks":"shlock",
"shlockmeisters":"shlockmeister",
"shluhs":"shluh",
"shmears":"shmear",
"shmoes":"shmo",
"shoaled":"shoal",
"shoaling":"shoal",
"shoals":"shoal",
"shoalier":"shoaly",
"shoaliest":"shoaly",
"shoats":"shoat",
"shocked":"shock",
"shocking":"shock",
"shocks":"shock",
"shoddinesses":"shoddiness",
"shoddier":"shoddy",
"shoddies":"shoddy",
"shoddiest":"shoddy",
"shod":"shoe",
"shodden":"shoe",
"shoed":"shoe",
"shoeing":"shoe",
"shoes":"shoe",
"shoebills":"shoebill",
"shoebirds":"shoebird",
"shoeblacks":"shoeblack",
"shoelaces":"shoelace",
"shoemakers":"shoemaker",
"shoemakings":"shoemaking",
"shoeses":"shoes",
"shoeshops":"shoeshop",
"shoestrings":"shoestring",
"shofars":"shofar",
"shoforth":"shofar",
"shofroth":"shofar",
"shogunates":"shogunate",
"shojis":"shoji",
"shonas":"shona",
"shooed":"shoo",
"shooing":"shoo",
"shoos":"shoo",
"shoo-ins":"shoo-in",
"shooflies":"shoofly",
"shooked":"shook",
"shooking":"shook",
"shooks":"shook",
"shooting":"shoot",
"shoots":"shoot",
"shooters":"shooter",
"shootings":"shooting",
"shootouts":"shootout",
"shopped":"shop",
"shopping":"shop",
"shops":"shop",
"shopfronts":"shopfront",
"shophars":"shophar",
"shopkeepers":"shopkeeper",
"shoplifters":"shoplifter",
"shopwalkers":"shopwalker",
"shopwindows":"shopwindow",
"shored":"shore",
"shores":"shore",
"shoring":"shore",
"shoreas":"shorea",
"shorebirds":"shorebird",
"shorelines":"shoreline",
"shorings":"shoring",
"shorter":"short",
"shortest":"short",
"shorts":"short",
"short-circuited":"short-circuit",
"short-circuiting":"short-circuit",
"short-circuits":"short-circuit",
"short-stops":"short-stop",
"short-waved":"short-wave",
"short-waving":"short-wave",
"shortages":"shortage",
"shortbreads":"shortbread",
"shortchanged":"shortchange",
"shortchanging":"shortchange",
"shortcomings":"shortcoming",
"shortcuts":"shortcut",
"shortened":"shorten",
"shortening":"shorten",
"shortens":"shorten",
"shortfalls":"shortfall",
"shorthands":"shorthand",
"shorthorns":"shorthorn",
"shortnesses":"shortness",
"shortsightednesses":"shortsightedness",
"shortstops":"shortstop",
"shorties":"shorty",
"shoshones":"shoshone",
"shoshoneans":"shoshonean",
"shoshonis":"shoshoni",
"shoshonians":"shoshonian",
"shots":"shot",
"shotted":"shot",
"shotting":"shot",
"shotguned":"shotgun",
"shotguning":"shotgun",
"shotguns":"shotgun",
"shouldered":"shoulder",
"shouldering":"shoulder",
"shoulders":"shoulder",
"shouted":"shout",
"shouting":"shout",
"shouts":"shout",
"shouters":"shouter",
"shoutings":"shouting",
"shoved":"shove",
"shoves":"shove",
"shoving":"shove",
"shove-halfpennies":"shove-halfpenny",
"shoveled":"shovel",
"shoveling":"shovel",
"shovelled":"shovel",
"shovelling":"shovel",
"shovels":"shovel",
"shovelboards":"shovelboard",
"shovelers":"shoveler",
"shovelfuls":"shovelful",
"shovelheads":"shovelhead",
"showed":"show",
"showing":"show",
"shown":"show",
"shows":"show",
"show-offs":"show-off",
"showcased":"showcase",
"showcases":"showcase",
"showcasing":"showcase",
"showdowns":"showdown",
"showered":"shower",
"showering":"shower",
"showers":"shower",
"showgirls":"showgirl",
"showinesses":"showiness",
"showings":"showing",
"showjumpings":"showjumping",
"showmen":"showman",
"showpieces":"showpiece",
"showrooms":"showroom",
"showier":"showy",
"showiest":"showy",
"shredded":"shred",
"shredding":"shred",
"shreds":"shred",
"shredders":"shredder",
"shreikings":"shreiking",
"shrews":"shrew",
"shrewder":"shrewd",
"shrewdest":"shrewd",
"shrewdnesses":"shrewdness",
"shrewmice":"shrewmouse",
"shrieked":"shriek",
"shrieking":"shriek",
"shrieks":"shriek",
"shriekings":"shrieking",
"shrievalties":"shrievalty",
"shrilled":"shrill",
"shriller":"shrill",
"shrillest":"shrill",
"shrilling":"shrill",
"shrills":"shrill",
"shrillnesses":"shrillness",
"shrimped":"shrimp",
"shrimping":"shrimp",
"shrimps":"shrimp",
"shrimpier":"shrimpy",
"shrimpiest":"shrimpy",
"shrined":"shrine",
"shrines":"shrine",
"shrining":"shrine",
"shrank":"shrink",
"shrinking":"shrink",
"shrinks":"shrink",
"shrunk":"shrink",
"shrunken":"shrink",
"shrink-wrapped":"shrink-wrap",
"shrink-wrapping":"shrink-wrap",
"shrink-wraps":"shrink-wrap",
"shrinkages":"shrinkage",
"shrinkings":"shrinking",
"shrived":"shrive",
"shriven":"shrive",
"shrives":"shrive",
"shriving":"shrive",
"shrove":"shrive",
"shriveled":"shrivel",
"shriveling":"shrivel",
"shrivelled":"shrivel",
"shrivelling":"shrivel",
"shrivels":"shrivel",
"shrouded":"shroud",
"shrouding":"shroud",
"shrouds":"shroud",
"shrubs":"shrub",
"shrubberies":"shrubbery",
"shrubbier":"shrubby",
"shrubbiest":"shrubby",
"shrugged":"shrug",
"shrugging":"shrug",
"shrugs":"shrug",
"sht-cutting":"sht-cut",
"shuas":"shua",
"shucked":"shuck",
"shucking":"shuck",
"shucks":"shuck",
"shuckses":"shucks",
"shuddered":"shudder",
"shuddering":"shudder",
"shudders":"shudder",
"shudras":"shudra",
"shuffled":"shuffle",
"shuffles":"shuffle",
"shuffling":"shuffle",
"shuffleboards":"shuffleboard",
"shufflings":"shuffling",
"shufties":"shufty",
"shuggies":"shuggy",
"shuln":"shul",
"shumacs":"shumac",
"shunned":"shun",
"shunning":"shun",
"shuns":"shun",
"shunnings":"shunning",
"shunted":"shunt",
"shunting":"shunt",
"shunts":"shunt",
"shushed":"shush",
"shushing":"shush",
"shuts":"shut",
"shutting":"shut",
"shut-ins":"shut-in",
"shutdowns":"shutdown",
"shuttered":"shutter",
"shuttering":"shutter",
"shutters":"shutter",
"shuttings":"shutting",
"shuttled":"shuttle",
"shuttles":"shuttle",
"shuttling":"shuttle",
"shuttlecocked":"shuttlecock",
"shuttlecocking":"shuttlecock",
"shuttlecocks":"shuttlecock",
"shwas":"shwa",
"shied":"shy",
"shier":"shy",
"shies":"shy",
"shiest":"shy",
"shyer":"shy",
"shyest":"shy",
"shying":"shy",
"shysters":"shyster",
"sis":"si",
"sialias":"sialia",
"sialidaes":"sialidae",
"sialises":"sialis",
"sialoliths":"sialolith",
"siams":"siam",
"siamangs":"siamang",
"siameses":"siamese",
"sians":"sian",
"sibs":"sib",
"sibilants":"sibilant",
"sibines":"sibine",
"siblings":"sibling",
"sicked":"sic",
"sicking":"sic",
"sics":"sic",
"sichuans":"sichuan",
"sicilias":"sicilia",
"sicilies":"sicily",
"sicker":"sick",
"sickest":"sick",
"sicks":"sick",
"sickbays":"sickbay",
"sickened":"sicken",
"sickening":"sicken",
"sickens":"sicken",
"sickeners":"sickener",
"sickeningnesses":"sickeningness",
"sickles":"sickle",
"sicklepods":"sicklepod",
"sicklied":"sickly",
"sicklier":"sickly",
"sickliest":"sickly",
"sicklying":"sickly",
"sicknesses":"sickness",
"sidas":"sida",
"sidalceas":"sidalcea",
"siddharthas":"siddhartha",
"siddurim":"siddur",
"siddurs":"siddur",
"sided":"side",
"sides":"side",
"siding":"side",
"side-glances":"side-glance",
"side-looks":"side-look",
"side-stepped":"side-step",
"side-stepping":"side-step",
"side-whiskerses":"side-whiskers",
"sideboards":"sideboard",
"sideburns":"sideburn",
"sidekicks":"sidekick",
"sidelights":"sidelight",
"sidelines":"sideline",
"sidemen":"sideman",
"siderites":"siderite",
"sideritises":"sideritis",
"sideslipped":"sideslip",
"sideslipping":"sideslip",
"sideslips":"sideslip",
"sidesmen":"sidesman",
"sidesplitters":"sidesplitter",
"sidestepped":"sidestep",
"sidestepping":"sidestep",
"sidesteps":"sidestep",
"sideswiped":"sideswipe",
"sideswiping":"sideswipe",
"sidetracked":"sidetrack",
"sidetracking":"sidetrack",
"sidetracks":"sidetrack",
"sidewalks":"sidewalk",
"sidewinders":"sidewinder",
"sidings":"siding",
"sidled":"sidle",
"sidles":"sidle",
"sidling":"sidle",
"sidses":"sids",
"sieged":"siege",
"sieges":"siege",
"sieging":"siege",
"siemenses":"siemens",
"sierras":"sierra",
"siestas":"siesta",
"sieved":"sieve",
"sieves":"sieve",
"sieving":"sieve",
"sifted":"sift",
"sifting":"sift",
"sifts":"sift",
"siftings":"sifting",
"sighed":"sigh",
"sighing":"sigh",
"sighs":"sigh",
"sighted":"sight",
"sighting":"sight",
"sights":"sight",
"sight-reading":"sight-read",
"sight-reads":"sight-read",
"sightednesses":"sightedness",
"sightlessnesses":"sightlessness",
"sightlier":"sightly",
"sightliest":"sightly",
"sightsaw":"sightsee",
"sightseeing":"sightsee",
"sightseen":"sightsee",
"sightsees":"sightsee",
"sightseeings":"sightseeing",
"sightseers":"sightseer",
"sigints":"sigint",
"sigloi":"siglos",
"sigmas":"sigma",
"sigmodons":"sigmodon",
"signed":"sign",
"signing":"sign",
"signs":"sign",
"signaled":"signal",
"signaling":"signal",
"signalled":"signal",
"signalling":"signal",
"signals":"signal",
"signal-to-noises":"signal-to-noise",
"signal/noises":"signal/noise",
"signalers":"signaler",
"signalings":"signaling",
"signalized":"signalize",
"signalizes":"signalize",
"signalizing":"signalize",
"signallers":"signaller",
"signalmen":"signalman",
"signatories":"signatory",
"signatures":"signature",
"signboards":"signboard",
"signers":"signer",
"signeted":"signet",
"signeting":"signet",
"signets":"signet",
"significances":"significance",
"significants":"significant",
"significations":"signification",
"signified":"signify",
"signifies":"signify",
"signifying":"signify",
"signings":"signing",
"signiors":"signior",
"signori":"signor",
"signors":"signor",
"signoras":"signora",
"signore":"signora",
"signorinas":"signorina",
"signorine":"signorina",
"signories":"signory",
"signposts":"signpost",
"sikas":"sika",
"silages":"silage",
"silenced":"silence",
"silences":"silence",
"silencing":"silence",
"silencers":"silencer",
"silenes":"silene",
"silents":"silent",
"silesias":"silesia",
"silhouetted":"silhouette",
"silhouettes":"silhouette",
"silhouetting":"silhouette",
"silicas":"silica",
"silicified":"silicify",
"silicifies":"silicify",
"silicifying":"silicify",
"silicons":"silicon",
"silicones":"silicone",
"siliquas":"siliqua",
"siliques":"silique",
"silks":"silk",
"silk-screens":"silk-screen",
"silkgrasses":"silkgrass",
"silkinesses":"silkiness",
"silkweeds":"silkweed",
"silkwoods":"silkwood",
"silkworms":"silkworm",
"silkier":"silky",
"silkiest":"silky",
"sills":"sill",
"sillabubs":"sillabub",
"sillaginidaes":"sillaginidae",
"sillagos":"sillago",
"sillinesses":"silliness",
"sillier":"silly",
"sillies":"silly",
"silliest":"silly",
"silos":"silo",
"silphiums":"silphium",
"silted":"silt",
"silting":"silt",
"silts":"silt",
"silurians":"silurian",
"silurids":"silurid",
"siluridaes":"siluridae",
"siluriformeses":"siluriformes",
"siluruses":"silurus",
"silvas":"silva",
"silvans":"silvan",
"silvanuses":"silvanus",
"silvered":"silver",
"silvering":"silver",
"silvers":"silver",
"silver-laces":"silver-lace",
"silverberries":"silverberry",
"silverbushes":"silverbush",
"silverfishes":"silverfish",
"silverlaces":"silverlace",
"silverrods":"silverrod",
"silversides":"silverside",
"silversideses":"silversides",
"silversmiths":"silversmith",
"silverswords":"silversword",
"silvertips":"silvertip",
"silvervines":"silvervine",
"silverweeds":"silverweed",
"silverworkers":"silverworker",
"silvias":"silvia",
"silybums":"silybum",
"simals":"simal",
"simaroubas":"simarouba",
"simaroubaceaes":"simaroubaceae",
"similars":"similar",
"similarities":"similarity",
"similitudes":"similitude",
"simmered":"simmer",
"simmering":"simmer",
"simmerings":"simmering",
"simooms":"simoom",
"simoons":"simoon",
"simpered":"simper",
"simpering":"simper",
"simpers":"simper",
"simpler":"simple",
"simples":"simple",
"simplest":"simple",
"simplenesses":"simpleness",
"simpletons":"simpleton",
"simplexes":"simplex",
"simplices":"simplex",
"simplicities":"simplicity",
"simplifications":"simplification",
"simplified":"simplify",
"simplifies":"simplify",
"simplifying":"simplify",
"simpsons":"simpson",
"simulacra":"simulacrum",
"simulacrums":"simulacrum",
"simulated":"simulate",
"simulates":"simulate",
"simulating":"simulate",
"simulations":"simulation",
"simulcasted":"simulcast",
"simulcasting":"simulcast",
"simuliidaes":"simuliidae",
"simuliums":"simulium",
"simultaneities":"simultaneity",
"simultaneousnesses":"simultaneousness",
"sinned":"sin",
"sinning":"sin",
"sins":"sin",
"sinais":"sinai",
"sinanthropuses":"sinanthropus",
"sinapises":"sinapis",
"sinapisms":"sinapism",
"sincerer":"sincere",
"sincerest":"sincere",
"sincerities":"sincerity",
"sincipita":"sinciput",
"sinciputs":"sinciput",
"sindhis":"sindhi",
"sinequans":"sinequan",
"sinewed":"sinew",
"sinewing":"sinew",
"sinews":"sinew",
"sinfonie":"sinfonia",
"sinfoniettas":"sinfonietta",
"sinfulnesses":"sinfulness",
"sang":"sing",
"singing":"sing",
"sings":"sing",
"sung":"sing",
"sing-kwas":"sing-kwa",
"singans":"singan",
"singapores":"singapore",
"singed":"singe",
"singeing":"singe",
"singes":"singe",
"singers":"singer",
"singhaleses":"singhalese",
"singings":"singing",
"singled":"single",
"singles":"single",
"singling":"single",
"single-feet":"single-foot",
"single-footed":"single-foot",
"single-footing":"single-foot",
"single-foots":"single-foot",
"single-leaves":"single-leaf",
"single-spaced":"single-space",
"single-spacing":"single-space",
"single-stepped":"single-step",
"single-stepping":"single-step",
"single-steps":"single-step",
"singlenesses":"singleness",
"singlets":"singlet",
"singulars":"singular",
"singularities":"singularity",
"singularized":"singularize",
"singularizing":"singularize",
"singultuses":"singultus",
"sinhalas":"sinhala",
"sinhaleses":"sinhalese",
"sinicized":"sinicize",
"sinicizing":"sinicize",
"sinistralities":"sinistrality",
"sinitics":"sinitic",
"sank":"sink",
"sinking":"sink",
"sinks":"sink",
"sunk":"sink",
"sunken":"sink",
"sinkers":"sinker",
"sinkholes":"sinkhole",
"sinkings":"sinking",
"sinlessnesses":"sinlessness",
"sinners":"sinner",
"sinnings":"sinning",
"sinningias":"sinningia",
"sino-tibetans":"sino-tibetan",
"sinopers":"sinoper",
"sinopias":"sinopia",
"sinopises":"sinopis",
"sinuationtions":"sinuation",
"sinuosities":"sinuosity",
"sinuousnesses":"sinuousness",
"sinuses":"sinus",
"sinusoids":"sinusoid",
"siouans":"siouan",
"siouxes":"sioux",
"sipped":"sip",
"sipping":"sip",
"sips":"sip",
"siphoned":"siphon",
"siphoning":"siphon",
"siphons":"siphon",
"siphonapteras":"siphonaptera",
"siphonophoras":"siphonophora",
"sippers":"sipper",
"sippings":"sipping",
"sipunculas":"sipuncula",
"sipunculids":"sipunculid",
"sirs":"sir",
"siracusas":"siracusa",
"sired":"sire",
"sires":"sire",
"siring":"sire",
"sirens":"siren",
"sirenias":"sirenia",
"sirenians":"sirenian",
"sirenidaes":"sirenidae",
"siriases":"siriasis",
"sirises":"siris",
"siriuses":"sirius",
"siroccos":"sirocco",
"sirups":"sirup",
"sisals":"sisal",
"sishams":"sisham",
"siskins":"siskin",
"sisons":"sison",
"sissinesses":"sissiness",
"sissoos":"sissoo",
"sissus":"sissu",
"sissies":"sissy",
"sisters":"sister",
"sisters-in-law":"sister-in-law",
"sisterhoods":"sisterhood",
"sisterships":"sistership",
"sistra":"sistrum",
"sistruruses":"sistrurus",
"sisyridaes":"sisyridae",
"sisyrinchiums":"sisyrinchium",
"sat":"sit",
"sits":"sit",
"sitting":"sit",
"sit-downs":"sit-down",
"sit-ins":"sit-in",
"sited":"site",
"sites":"site",
"siting":"site",
"sitophyluses":"sitophylus",
"sitotrogas":"sitotroga",
"sitsangs":"sitsang",
"sittas":"sitta",
"sitters":"sitter",
"sittidaes":"sittidae",
"sittings":"sitting",
"situated":"situate",
"situates":"situate",
"situating":"situate",
"situatings":"situating",
"situations":"situation",
"situlae":"situla",
"siums":"sium",
"sivas":"siva",
"sivaisms":"sivaism",
"sivans":"sivan",
"siwans":"siwan",
"sixes":"six",
"six-guns":"six-gun",
"six-shooters":"six-shooter",
"sixers":"sixer",
"sixmos":"sixmo",
"sixpences":"sixpence",
"sixsomes":"sixsome",
"sixteens":"sixteen",
"sixteenmos":"sixteenmo",
"sixteenths":"sixteenth",
"sixths":"sixth",
"sixtieses":"sixties",
"sixties":"sixty",
"sixty-fourmos":"sixty-fourmo",
"sixty-nines":"sixty-nine",
"sized":"size",
"sizes":"size",
"sizing":"size",
"sizeablenesses":"sizeableness",
"sizings":"sizing",
"sizzled":"sizzle",
"sizzling":"sizzle",
"sjaellands":"sjaelland",
"sk-ampicillins":"sk-ampicillin",
"skated":"skate",
"skates":"skate",
"skating":"skate",
"skateboarded":"skateboard",
"skateboarding":"skateboard",
"skaters":"skater",
"skateses":"skates",
"skedaddled":"skedaddle",
"skedaddling":"skedaddle",
"skeets":"skeet",
"skeins":"skein",
"skeletons":"skeleton",
"skeletonized":"skeletonize",
"skeletonizing":"skeletonize",
"skellied":"skelly",
"skellies":"skelly",
"skellying":"skelly",
"skeltered":"skelter",
"skeltering":"skelter",
"skenned":"sken",
"skenning":"sken",
"skens":"sken",
"skeptics":"skeptic",
"skepticisms":"skepticism",
"skerries":"skerry",
"skets":"sket",
"sketted":"sket",
"sketting":"sket",
"sketched":"sketch",
"sketches":"sketch",
"sketching":"sketch",
"sketchblocks":"sketchblock",
"sketchbooks":"sketchbook",
"sketchier":"sketchy",
"sketchiest":"sketchy",
"skewed":"skew",
"skewing":"skew",
"skews":"skew",
"skewered":"skewer",
"skewering":"skewer",
"skewers":"skewer",
"skewnesses":"skewness",
"skied":"ski",
"skiing":"ski",
"skis":"ski",
"skiagrams":"skiagram",
"skiagraphs":"skiagraph",
"skiagraphies":"skiagraphy",
"skiamachies":"skiamachy",
"skidded":"skid",
"skidding":"skid",
"skids":"skid",
"skiddooed":"skiddoo",
"skiddooing":"skiddoo",
"skiddier":"skiddy",
"skiddiest":"skiddy",
"skills":"skill",
"skillets":"skillet",
"skilletfishes":"skilletfish",
"skimmed":"skim",
"skimming":"skim",
"skims":"skim",
"skimmers":"skimmer",
"skimmings":"skimming",
"skimped":"skimp",
"skimping":"skimp",
"skimps":"skimp",
"skimpier":"skimpy",
"skimpiest":"skimpy",
"skinned":"skin",
"skinning":"skin",
"skins":"skin",
"skin-dived":"skin-dive",
"skin-dives":"skin-dive",
"skin-diving":"skin-dive",
"skin-dove":"skin-dive",
"skin-divers":"skin-diver",
"skin-popped":"skin-pop",
"skin-popping":"skin-pop",
"skin-pops":"skin-pop",
"skinflints":"skinflint",
"skinfuls":"skinful",
"skinks":"skink",
"skinners":"skinner",
"skinninesses":"skinniness",
"skinnier":"skinny",
"skinnies":"skinny",
"skinniest":"skinny",
"skinny-dipped":"skinny-dip",
"skinny-dipping":"skinny-dip",
"skinny-dips":"skinny-dip",
"skinny-dipt":"skinny-dip",
"skipped":"skip",
"skipping":"skip",
"skips":"skip",
"skipjacks":"skipjack",
"skippered":"skipper",
"skippering":"skipper",
"skippers":"skipper",
"skirled":"skirl",
"skirling":"skirl",
"skirls":"skirl",
"skirmished":"skirmish",
"skirmishes":"skirmish",
"skirmishing":"skirmish",
"skirrets":"skirret",
"skirted":"skirt",
"skirting":"skirt",
"skirts":"skirt",
"skises":"skis",
"skittered":"skitter",
"skittering":"skitter",
"skitters":"skitter",
"skittishnesses":"skittishness",
"skittles":"skittle",
"skittleses":"skittles",
"skived":"skive",
"skiving":"skive",
"skivvieses":"skivvies",
"skivvies":"skivvy",
"skollies":"skollie",
"skuas":"skua",
"skulduggeries":"skulduggery",
"skulked":"skulk",
"skulking":"skulk",
"skulks":"skulk",
"skulkers":"skulker",
"skulkings":"skulking",
"skulls":"skull",
"skullcaps":"skullcap",
"skullduggeries":"skullduggery",
"skunked":"skunk",
"skunking":"skunk",
"skunks":"skunk",
"skunkbushes":"skunkbush",
"skunkweeds":"skunkweed",
"skies":"sky",
"skyed":"sky",
"skying":"sky",
"sky-blues":"sky-blue",
"skydived":"skydive",
"skydives":"skydive",
"skydiving":"skydive",
"skydove":"skydive",
"skydivers":"skydiver",
"skyjacked":"skyjack",
"skyjacking":"skyjack",
"skylarked":"skylark",
"skylarking":"skylark",
"skylarks":"skylark",
"skylighted":"skylight",
"skylighting":"skylight",
"skylights":"skylight",
"skylines":"skyline",
"skyrocketed":"skyrocket",
"skyrocketing":"skyrocket",
"skyrockets":"skyrocket",
"skyscrapers":"skyscraper",
"skywriting":"skywrite",
"skywritten":"skywrite",
"skywrote":"skywrite",
"slabbed":"slab",
"slabbing":"slab",
"slabs":"slab",
"slacked":"slack",
"slacker":"slack",
"slackest":"slack",
"slacking":"slack",
"slacks":"slack",
"slackened":"slacken",
"slackening":"slacken",
"slackens":"slacken",
"slackenings":"slackening",
"slackers":"slacker",
"slackings":"slacking",
"slacknesses":"slackness",
"slagged":"slag",
"slagging":"slag",
"slags":"slag",
"slaggier":"slaggy",
"slaggiest":"slaggy",
"slaked":"slake",
"slakes":"slake",
"slaking":"slake",
"slalomed":"slalom",
"slaloming":"slalom",
"slammed":"slam",
"slamming":"slam",
"slams":"slam",
"slandered":"slander",
"slandering":"slander",
"slanders":"slander",
"slanderers":"slanderer",
"slanged":"slang",
"slanging":"slang",
"slangs":"slang",
"slangier":"slangy",
"slangiest":"slangy",
"slanted":"slant",
"slanting":"slant",
"slants":"slant",
"slant-eyes":"slant-eye",
"slapped":"slap",
"slapping":"slap",
"slaps":"slap",
"slaphappier":"slaphappy",
"slaphappiest":"slaphappy",
"slashed":"slash",
"slashes":"slash",
"slashing":"slash",
"slashings":"slashing",
"slasks":"slask",
"slats":"slat",
"slatted":"slat",
"slatting":"slat",
"slated":"slate",
"slates":"slate",
"slating":"slate",
"slaters":"slater",
"slatings":"slating",
"slatterns":"slattern",
"slatternlinesses":"slatternliness",
"slatier":"slaty",
"slatiest":"slaty",
"slaughtered":"slaughter",
"slaughtering":"slaughter",
"slaughters":"slaughter",
"slaughterers":"slaughterer",
"slaughterhouses":"slaughterhouse",
"slaughtermen":"slaughterman",
"slaved":"slave",
"slaves":"slave",
"slaving":"slave",
"slave-makers":"slave-maker",
"slaveholders":"slaveholder",
"slavered":"slaver",
"slavering":"slaver",
"slavers":"slaver",
"slaveries":"slavery",
"slaveys":"slavey",
"slavics":"slavic",
"slavocracies":"slavocracy",
"slavonics":"slavonic",
"slaws":"slaw",
"slain":"slay",
"slaying":"slay",
"slays":"slay",
"slew":"slay",
"slayers":"slayer",
"slayings":"slaying",
"sles":"sle",
"sleaved":"sleave",
"sleaving":"sleave",
"sleazes":"sleaze",
"sleazier":"sleazy",
"sleaziest":"sleazy",
"sledded":"sled",
"sledding":"sled",
"sleds":"sled",
"sleddings":"sledding",
"sledged":"sledge",
"sledges":"sledge",
"sledging":"sledge",
"sledgehammered":"sledgehammer",
"sledgehammering":"sledgehammer",
"sledgehammers":"sledgehammer",
"sleeked":"sleek",
"sleeker":"sleek",
"sleekest":"sleek",
"sleeking":"sleek",
"sleeknesses":"sleekness",
"sleeping":"sleep",
"sleeps":"sleep",
"slept":"sleep",
"sleepers":"sleeper",
"sleepinesses":"sleepiness",
"sleepings":"sleeping",
"sleeplessnesses":"sleeplessness",
"sleepwalked":"sleepwalk",
"sleepwalking":"sleepwalk",
"sleepwalks":"sleepwalk",
"sleepwalkers":"sleepwalker",
"sleepwalkings":"sleepwalking",
"sleepier":"sleepy",
"sleepiest":"sleepy",
"sleeted":"sleet",
"sleeting":"sleet",
"sleetier":"sleety",
"sleetiest":"sleety",
"sleeved":"sleeve",
"sleeves":"sleeve",
"sleeving":"sleeve",
"sleighed":"sleigh",
"sleighing":"sleigh",
"sleighs":"sleigh",
"sleights":"sleight",
"slenderized":"slenderize",
"slenderizes":"slenderize",
"slenderizing":"slenderize",
"slendernesses":"slenderness",
"sleuths":"sleuth",
"sleuthhounds":"sleuthhound",
"sleuthings":"sleuthing",
"slewed":"slew",
"slewing":"slew",
"slews":"slew",
"slewses":"slews",
"slezskos":"slezsko",
"sliced":"slice",
"slices":"slice",
"slicing":"slice",
"slicked":"slick",
"slicker":"slick",
"slickest":"slick",
"slicking":"slick",
"slicks":"slick",
"slickers":"slicker",
"slicknesses":"slickness",
"slid":"slide",
"slides":"slide",
"sliding":"slide",
"sliders":"slider",
"slighted":"slight",
"slighter":"slight",
"slightest":"slight",
"slighting":"slight",
"slights":"slight",
"slightnesses":"slightness",
"slimmed":"slim",
"slimmer":"slim",
"slimmest":"slim",
"slimming":"slim",
"slimed":"slime",
"slimes":"slime",
"sliming":"slime",
"sliminesses":"sliminess",
"slimnesses":"slimness",
"slimsier":"slimsy",
"slimsiest":"slimsy",
"slimier":"slimy",
"slimiest":"slimy",
"slinging":"sling",
"slings":"sling",
"slung":"sling",
"slingshots":"slingshot",
"slinked":"slink",
"slinking":"slink",
"slinks":"slink",
"slunk":"slink",
"slinkier":"slinky",
"slinkiest":"slinky",
"slipped":"slip",
"slipping":"slip",
"slips":"slip",
"slipcovered":"slipcover",
"slipcovering":"slipcover",
"slipcovers":"slipcover",
"slipovers":"slipover",
"slippered":"slipper",
"slippering":"slipper",
"slippers":"slipper",
"slipperinesses":"slipperiness",
"slipperworts":"slipperwort",
"slipperier":"slippery",
"slipperiest":"slippery",
"slippier":"slippy",
"slippiest":"slippy",
"slipsticks":"slipstick",
"slipstreams":"slipstream",
"slipups":"slipup",
"slipways":"slipway",
"slits":"slit",
"slitting":"slit",
"slithered":"slither",
"slithering":"slither",
"slithers":"slither",
"slivered":"sliver",
"slivering":"sliver",
"slivers":"sliver",
"sloaneas":"sloanea",
"slobs":"slob",
"slobbered":"slobber",
"slobbering":"slobber",
"slobbers":"slobber",
"sloes":"sloe",
"slogged":"slog",
"slogging":"slog",
"slogs":"slog",
"slogans":"slogan",
"sloganeered":"sloganeer",
"sloganeering":"sloganeer",
"sloganized":"sloganize",
"sloganizing":"sloganize",
"sloggers":"slogger",
"sloops":"sloop",
"slopped":"slop",
"slopping":"slop",
"slops":"slop",
"sloped":"slope",
"slopes":"slope",
"sloping":"slope",
"sloppinesses":"sloppiness",
"sloppier":"sloppy",
"sloppiest":"sloppy",
"slopses":"slops",
"slopshops":"slopshop",
"sloshed":"slosh",
"sloshes":"slosh",
"sloshing":"slosh",
"slots":"slot",
"slotted":"slot",
"slotting":"slot",
"sloths":"sloth",
"slothfulnesses":"slothfulness",
"slouched":"slouch",
"slouches":"slouch",
"slouching":"slouch",
"slouchier":"slouchy",
"slouchiest":"slouchy",
"sloughed":"slough",
"sloughing":"slough",
"sloughs":"slough",
"sloughings":"sloughing",
"slovens":"sloven",
"slovenlinesses":"slovenliness",
"slovenlier":"slovenly",
"slovenliest":"slovenly",
"slowed":"slow",
"slower":"slow",
"slowest":"slow",
"slowing":"slow",
"slow-wittednesses":"slow-wittedness",
"slowcoaches":"slowcoach",
"slowdowns":"slowdown",
"slowings":"slowing",
"slownesses":"slowness",
"slowpokes":"slowpoke",
"slowworms":"slowworm",
"slubs":"slub",
"slubbered":"slubber",
"slubbering":"slubber",
"sludges":"sludge",
"sludgier":"sludgy",
"sludgiest":"sludgy",
"slued":"slue",
"slues":"slue",
"sluing":"slue",
"slugged":"slug",
"slugging":"slug",
"slugs":"slug",
"slugabeds":"slugabed",
"slugfests":"slugfest",
"sluggards":"sluggard",
"sluggers":"slugger",
"sluggishnesses":"sluggishness",
"sluiced":"sluice",
"sluices":"sluice",
"sluicing":"sluice",
"sluicegates":"sluicegate",
"sluiceways":"sluiceway",
"slummed":"slum",
"slumming":"slum",
"slums":"slum",
"slumbered":"slumber",
"slumbering":"slumber",
"slumbers":"slumber",
"slumberers":"slumberer",
"slummier":"slummy",
"slummiest":"slummy",
"slumped":"slump",
"slumping":"slump",
"slumps":"slump",
"slurred":"slur",
"slurring":"slur",
"slurs":"slur",
"slurped":"slurp",
"slurping":"slurp",
"slurries":"slurry",
"slushed":"slush",
"slushes":"slush",
"slushing":"slush",
"slushier":"slushy",
"slushiest":"slushy",
"sluts":"slut",
"sluttishnesses":"sluttishness",
"slier":"sly",
"sliest":"sly",
"slyer":"sly",
"slyest":"sly",
"slybootses":"slyboots",
"slynesses":"slyness",
"sms":"sm",
"smacked":"smack",
"smacking":"smack",
"smacks":"smack",
"smackings":"smacking",
"smaller":"small",
"smallest":"small",
"smalls":"small",
"small-arms":"small-arm",
"smallmouths":"smallmouth",
"smallnesses":"smallness",
"smallpoxes":"smallpox",
"smalti":"smalto",
"smaltos":"smalto",
"smarms":"smarm",
"smarminesses":"smarminess",
"smarmier":"smarmy",
"smarmiest":"smarmy",
"smarted":"smart",
"smarter":"smart",
"smartest":"smart",
"smarting":"smart",
"smarts":"smart",
"smartened":"smarten",
"smartening":"smarten",
"smartings":"smarting",
"smartnesses":"smartness",
"smarties":"smarty",
"smart_alecks":"smart_aleck",
"smashed":"smash",
"smashes":"smash",
"smashing":"smash",
"smash-ups":"smash-up",
"smashers":"smasher",
"smashings":"smashing",
"smashups":"smashup",
"smattered":"smatter",
"smattering":"smatter",
"smatters":"smatter",
"smatterings":"smattering",
"smeared":"smear",
"smearing":"smear",
"smears":"smear",
"smearier":"smeary",
"smeariest":"smeary",
"smelled":"smell",
"smelling":"smell",
"smells":"smell",
"smelt":"smell",
"smellings":"smelling",
"smellier":"smelly",
"smelliest":"smelly",
"smelted":"smelt",
"smelting":"smelt",
"smelts":"smelt",
"smelters":"smelter",
"smelteries":"smeltery",
"smews":"smew",
"smidges":"smidge",
"smidgens":"smidgen",
"smidgeons":"smidgeon",
"smidgins":"smidgin",
"smilacaceaes":"smilacaceae",
"smilaxes":"smilax",
"smiled":"smile",
"smiles":"smile",
"smiling":"smile",
"smiledons":"smiledon",
"smilers":"smiler",
"smilings":"smiling",
"smilos":"smilo",
"smirched":"smirch",
"smirches":"smirch",
"smirching":"smirch",
"smirked":"smirk",
"smirking":"smirk",
"smirks":"smirk",
"smit":"smite",
"smites":"smite",
"smiting":"smite",
"smitten":"smite",
"smote":"smite",
"smiths":"smith",
"smitheries":"smithery",
"smithies":"smithy",
"smocked":"smock",
"smocking":"smock",
"smocks":"smock",
"smogs":"smog",
"smogginesses":"smogginess",
"smoked":"smoke",
"smokes":"smoke",
"smoking":"smoke",
"smokehouses":"smokehouse",
"smokers":"smoker",
"smokestacks":"smokestack",
"smokings":"smoking",
"smokier":"smoky",
"smokiest":"smoky",
"smoldered":"smolder",
"smoldering":"smolder",
"smolders":"smolder",
"smooched":"smooch",
"smooches":"smooch",
"smooching":"smooch",
"smoochings":"smooching",
"smoothed":"smooth",
"smoother":"smooth",
"smoothest":"smooth",
"smoothing":"smooth",
"smoothers":"smoother",
"smoothhounds":"smoothhound",
"smoothies":"smoothie",
"smothered":"smother",
"smothering":"smother",
"smothers":"smother",
"smouldered":"smoulder",
"smouldering":"smoulder",
"smoulders":"smoulder",
"smudged":"smudge",
"smudges":"smudge",
"smudging":"smudge",
"smudgier":"smudgy",
"smudgiest":"smudgy",
"smugger":"smug",
"smuggest":"smug",
"smugs":"smug",
"smuggled":"smuggle",
"smuggles":"smuggle",
"smuggling":"smuggle",
"smugglers":"smuggler",
"smuts":"smut",
"smutted":"smut",
"smutting":"smut",
"smuttinesses":"smuttiness",
"smuttier":"smutty",
"smuttiest":"smutty",
"smyrniums":"smyrnium",
"sns":"sn",
"snacked":"snack",
"snacking":"snack",
"snacks":"snack",
"snaffled":"snaffle",
"snaffles":"snaffle",
"snaffling":"snaffle",
"snafued":"snafu",
"snafues":"snafu",
"snafuing":"snafu",
"snafus":"snafu",
"snagged":"snag",
"snagging":"snag",
"snags":"snag",
"snaggleteeth":"snaggletooth",
"snails":"snail",
"snailfishes":"snailfish",
"snailflowers":"snailflower",
"snaked":"snake",
"snakes":"snake",
"snaking":"snake",
"snakeberries":"snakeberry",
"snakebirds":"snakebird",
"snakeblennies":"snakeblenny",
"snakefishes":"snakefish",
"snakeheads":"snakehead",
"snakeroots":"snakeroot",
"snakeweeds":"snakeweed",
"snakewoods":"snakewood",
"snakier":"snaky",
"snakiest":"snaky",
"snapped":"snap",
"snapping":"snap",
"snaps":"snap",
"snaplines":"snapline",
"snappers":"snapper",
"snappishnesses":"snappishness",
"snappier":"snappy",
"snappiest":"snappy",
"snapshots":"snapshot",
"snapshotted":"snapshot",
"snapshotting":"snapshot",
"snared":"snare",
"snares":"snare",
"snaring":"snare",
"snarled":"snarl",
"snarling":"snarl",
"snarls":"snarl",
"snarl-ups":"snarl-up",
"snarlier":"snarly",
"snarliest":"snarly",
"snatched":"snatch",
"snatches":"snatch",
"snatching":"snatch",
"snatchers":"snatcher",
"snatchier":"snatchy",
"snatchiest":"snatchy",
"snazzier":"snazzy",
"snazziest":"snazzy",
"sneaked":"sneak",
"sneaking":"sneak",
"sneaks":"sneak",
"snuck":"sneak",
"sneakers":"sneaker",
"sneakinesses":"sneakiness",
"sneakier":"sneaky",
"sneakiest":"sneaky",
"snedded":"sned",
"snedding":"sned",
"sneds":"sned",
"sneered":"sneer",
"sneering":"sneer",
"sneers":"sneer",
"sneerings":"sneering",
"sneezed":"sneeze",
"sneezes":"sneeze",
"sneezing":"sneeze",
"sneezers":"sneezer",
"sneezeworts":"sneezewort",
"sneezings":"sneezing",
"snicked":"snick",
"snicking":"snick",
"snicks":"snick",
"snickered":"snicker",
"snickering":"snicker",
"snickers":"snicker",
"snickersnees":"snickersnee",
"snider":"snide",
"snidest":"snide",
"sniffed":"sniff",
"sniffing":"sniff",
"sniffs":"sniff",
"sniffled":"sniffle",
"sniffles":"sniffle",
"sniffling":"sniffle",
"sniffier":"sniffy",
"sniffiest":"sniffy",
"snifters":"snifter",
"sniggers":"snigger",
"sniggled":"sniggle",
"sniggling":"sniggle",
"snipped":"snip",
"snipping":"snip",
"snips":"snip",
"sniped":"snipe",
"snipes":"snipe",
"sniping":"snipe",
"snipefishes":"snipefish",
"snipers":"sniper",
"snippets":"snippet",
"snippings":"snipping",
"snippier":"snippy",
"snippiest":"snippy",
"snipses":"snips",
"snitched":"snitch",
"snitches":"snitch",
"snitching":"snitch",
"sniveled":"snivel",
"sniveling":"snivel",
"snivelled":"snivel",
"snivelling":"snivel",
"snivels":"snivel",
"snivelers":"sniveler",
"snivelings":"sniveling",
"snobs":"snob",
"snobberies":"snobbery",
"snobbishnesses":"snobbishness",
"snogged":"snog",
"snogging":"snog",
"snogs":"snog",
"snooded":"snood",
"snooding":"snood",
"snooks":"snook",
"snooped":"snoop",
"snooping":"snoop",
"snoops":"snoop",
"snoopers":"snooper",
"snoopinesses":"snoopiness",
"snoopier":"snoopy",
"snoopiest":"snoopy",
"snooted":"snoot",
"snooting":"snoot",
"snoots":"snoot",
"snootier":"snooty",
"snootiest":"snooty",
"snoozed":"snooze",
"snoozes":"snooze",
"snoozing":"snooze",
"snored":"snore",
"snores":"snore",
"snoring":"snore",
"snorers":"snorer",
"snorings":"snoring",
"snorkels":"snorkel",
"snorkelings":"snorkeling",
"snorted":"snort",
"snorting":"snort",
"snorts":"snort",
"snorters":"snorter",
"snortings":"snorting",
"snots":"snot",
"snottier":"snotty",
"snotties":"snotty",
"snottiest":"snotty",
"snouts":"snout",
"snowed":"snow",
"snowing":"snow",
"snows":"snow",
"snow-in-summers":"snow-in-summer",
"snow-on-the-mountains":"snow-on-the-mountain",
"snowballed":"snowball",
"snowballing":"snowball",
"snowballs":"snowball",
"snowbanks":"snowbank",
"snowbells":"snowbell",
"snowberries":"snowberry",
"snowbirds":"snowbird",
"snowdrops":"snowdrop",
"snowfalls":"snowfall",
"snowflakes":"snowflake",
"snowmen":"snowman",
"snowploughs":"snowplough",
"snowplows":"snowplow",
"snowshoed":"snowshoe",
"snowshoeing":"snowshoe",
"snowshoes":"snowshoe",
"snowstorms":"snowstorm",
"snowier":"snowy",
"snowiest":"snowy",
"snubbed":"snub",
"snubbing":"snub",
"snubs":"snub",
"snubbers":"snubber",
"snuffed":"snuff",
"snuffing":"snuff",
"snuffs":"snuff",
"snuff-colors":"snuff-color",
"snuff-colours":"snuff-colour",
"snuffled":"snuffle",
"snuffles":"snuffle",
"snuffling":"snuffle",
"snuffier":"snuffy",
"snuffiest":"snuffy",
"snugged":"snug",
"snugger":"snug",
"snuggest":"snug",
"snugging":"snug",
"snugs":"snug",
"snuggeries":"snuggery",
"snuggled":"snuggle",
"snuggles":"snuggle",
"snuggling":"snuggle",
"snugglings":"snuggling",
"snugnesses":"snugness",
"sos":"so",
"so-and-sos":"so-and-so",
"soaked":"soak",
"soaking":"soak",
"soaks":"soak",
"soakages":"soakage",
"soakers":"soaker",
"soakings":"soaking",
"soaped":"soap",
"soaping":"soap",
"soaps":"soap",
"soapberries":"soapberry",
"soapboxes":"soapbox",
"soaprocks":"soaprock",
"soapstones":"soapstone",
"soapsudses":"soapsuds",
"soapweeds":"soapweed",
"soapworts":"soapwort",
"soapier":"soapy",
"soapiest":"soapy",
"soared":"soar",
"soaring":"soar",
"soars":"soar",
"soarings":"soaring",
"sobbed":"sob",
"sobbing":"sob",
"sobs":"sob",
"sobbings":"sobbing",
"sobered":"sober",
"soberer":"sober",
"soberest":"sober",
"sobering":"sober",
"sobernesses":"soberness",
"sobrieties":"sobriety",
"sobriquets":"sobriquet",
"soccers":"soccer",
"sociabilities":"sociability",
"sociables":"sociable",
"sociablenesses":"sociableness",
"socials":"social",
"socialisations":"socialisation",
"socialisms":"socialism",
"socialists":"socialist",
"socialities":"sociality",
"socializations":"socialization",
"socialized":"socialize",
"socializes":"socialize",
"socializing":"socialize",
"socializings":"socializing",
"societies":"society",
"sociopaths":"sociopath",
"socked":"sock",
"socking":"sock",
"socks":"sock",
"sox":"sock",
"socketed":"socket",
"socketing":"socket",
"sockets":"socket",
"sockeyes":"sockeye",
"socmen":"socman",
"sodded":"sod",
"sodding":"sod",
"sods":"sod",
"sodas":"soda",
"sodalities":"sodality",
"sodbusters":"sodbuster",
"soddened":"sodden",
"soddening":"sodden",
"soddier":"soddy",
"soddies":"soddy",
"soddiest":"soddy",
"sodiums":"sodium",
"sodokus":"sodoku",
"sodomists":"sodomist",
"sodomites":"sodomite",
"sodomies":"sodomy",
"sofas":"sofa",
"sofias":"sofia",
"softer":"soft",
"softest":"soft",
"soft-covers":"soft-cover",
"soft-pedaled":"soft-pedal",
"soft-pedaling":"soft-pedal",
"soft-pedalled":"soft-pedal",
"soft-pedalling":"soft-pedal",
"soft-pedals":"soft-pedal",
"soft-shoes":"soft-shoe",
"soft-soaped":"soft-soap",
"soft-soaping":"soft-soap",
"softbacks":"softback",
"softballs":"softball",
"softened":"soften",
"softening":"soften",
"softens":"soften",
"softheartednesses":"softheartedness",
"softies":"softie",
"softwares":"software",
"softwoods":"softwood",
"soggier":"soggy",
"soggiest":"soggy",
"sohs":"soh",
"soiled":"soil",
"soiling":"soil",
"soils":"soil",
"soilings":"soiling",
"soilures":"soilure",
"soissonses":"soissons",
"soixante-neufs":"soixante-neuf",
"sojas":"soja",
"sojourned":"sojourn",
"sojourning":"sojourn",
"sojourns":"sojourn",
"sokemen":"sokeman",
"sols":"sol",
"sol-faed":"sol-fa",
"sol-faing":"sol-fa",
"sol-fas":"sol-fa",
"solaced":"solace",
"solaces":"solace",
"solacing":"solace",
"solacements":"solacement",
"solans":"solan",
"solanaceaes":"solanaceae",
"solandras":"solandra",
"solanopterises":"solanopteris",
"solanums":"solanum",
"solaria":"solarium",
"solariums":"solarium",
"solatia":"solatium",
"soldered":"solder",
"soldering":"solder",
"solderings":"soldering",
"soldiered":"soldier",
"soldiering":"soldier",
"soldiers":"soldier",
"soldierings":"soldiering",
"soldierships":"soldiership",
"soldieries":"soldiery",
"soldi":"soldo",
"soled":"sole",
"soles":"sole",
"soling":"sole",
"soleas":"solea",
"solecisms":"solecism",
"soleidaes":"soleidae",
"soleirolias":"soleirolia",
"solemnesses":"solemness",
"solemnified":"solemnify",
"solemnifies":"solemnify",
"solemnifying":"solemnify",
"solemnities":"solemnity",
"solemnizations":"solemnization",
"solemnized":"solemnize",
"solemnizing":"solemnize",
"solenichthyeses":"solenichthyes",
"solenidaes":"solenidae",
"solenogasters":"solenogaster",
"solenogastreses":"solenogastres",
"solenopses":"solenopsis",
"solenostemons":"solenostemon",
"soleuses":"soleus",
"solfas":"solfa",
"solfeges":"solfege",
"solfegfeggi":"solfeggio",
"solfegfeggios":"solfeggio",
"solfeggi":"solfeggio",
"solfeggios":"solfeggio",
"solferinos":"solferino",
"solicited":"solicit",
"soliciting":"solicit",
"solicits":"solicit",
"solicitations":"solicitation",
"solicitors":"solicitor",
"solicitousnesses":"solicitousness",
"solicitudes":"solicitude",
"solider":"solid",
"solidest":"solid",
"solids":"solid",
"solidagos":"solidago",
"solidarities":"solidarity",
"solidifications":"solidification",
"solidified":"solidify",
"solidifies":"solidify",
"solidifying":"solidify",
"solidifyings":"solidifying",
"solidities":"solidity",
"solidnesses":"solidness",
"solidi":"solidus",
"soliduses":"solidus",
"soliloquized":"soliloquize",
"soliloquizes":"soliloquize",
"soliloquizing":"soliloquize",
"soliloquies":"soliloquy",
"soliloquys":"soliloquy",
"solitaires":"solitaire",
"solitarinesses":"solitariness",
"solitaries":"solitary",
"solitudes":"solitude",
"solitudinarians":"solitudinarian",
"sollerets":"solleret",
"solmisations":"solmisation",
"solmizations":"solmization",
"soli":"solo",
"soloed":"solo",
"soloing":"solo",
"solos":"solo",
"solons":"solon",
"solubilities":"solubility",
"solublenesses":"solubleness",
"sola":"solum",
"solums":"solum",
"solutions":"solution",
"solved":"solve",
"solves":"solve",
"solving":"solve",
"solvents":"solvent",
"solvings":"solving",
"somas":"soma",
"somata":"soma",
"somaesthesias":"somaesthesia",
"somaestheses":"somaesthesis",
"somalis":"somali",
"somalias":"somalia",
"somatatestheses":"somatatesthesis",
"somaterias":"somateria",
"somatesthesias":"somatesthesia",
"somatotrophins":"somatotrophin",
"somatotropins":"somatotropin",
"somatotypes":"somatotype",
"sombernesses":"somberness",
"sombrenesses":"sombreness",
"sombreros":"sombrero",
"somebodies":"somebody",
"someones":"someone",
"somersaulted":"somersault",
"somersaulting":"somersault",
"somersaults":"somersault",
"somersaultings":"somersaulting",
"somesthesias":"somesthesia",
"somestheses":"somesthesis",
"somethings":"something",
"somites":"somite",
"sommes":"somme",
"sommeliers":"sommelier",
"somnambulated":"somnambulate",
"somnambulates":"somnambulate",
"somnambulating":"somnambulate",
"somnambulisms":"somnambulism",
"somnambulists":"somnambulist",
"somniloquisms":"somniloquism",
"somniloquys":"somniloquy",
"somnolences":"somnolence",
"somrais":"somrai",
"sons":"son",
"sons-in-law":"son-in-law",
"sonants":"sonant",
"sonars":"sonar",
"sonatas":"sonata",
"sonatinas":"sonatina",
"sonatine":"sonatina",
"sonchuses":"sonchus",
"sondages":"sondage",
"songs":"song",
"songbirds":"songbird",
"songfulnesses":"songfulness",
"songhais":"songhai",
"songsters":"songster",
"songwriters":"songwriter",
"sonnets":"sonnet",
"sonnies":"sonny",
"sonographies":"sonography",
"sonoras":"sonora",
"sonorities":"sonority",
"sonorousnesses":"sonorousness",
"sonsier":"sonsy",
"sonsiest":"sonsy",
"sooner":"soon",
"soonest":"soon",
"sooted":"soot",
"sooting":"soot",
"soots":"soot",
"soothed":"soothe",
"soothes":"soothe",
"soothing":"soothe",
"soothsaid":"soothsay",
"soothsaying":"soothsay",
"soothsays":"soothsay",
"soothsayers":"soothsayer",
"soothsayings":"soothsaying",
"sootinesses":"sootiness",
"sootier":"sooty",
"sootiest":"sooty",
"sopped":"sop",
"sopping":"sop",
"sops":"sop",
"sophies":"sophi",
"sophisms":"sophism",
"sophists":"sophist",
"sophisticated":"sophisticate",
"sophisticates":"sophisticate",
"sophisticating":"sophisticate",
"sophistications":"sophistication",
"sophistries":"sophistry",
"sophomores":"sophomore",
"sophoras":"sophora",
"soporifics":"soporific",
"soppier":"soppy",
"soppiest":"soppy",
"sopraninos":"sopranino",
"sopranos":"soprano",
"sopses":"sops",
"soras":"sora",
"sorbs":"sorb",
"sorbents":"sorbent",
"sorbets":"sorbet",
"sorbians":"sorbian",
"sorbuses":"sorbus",
"sorcerers":"sorcerer",
"sorceries":"sorcery",
"sordidnesses":"sordidness",
"sordini":"sordino",
"sorer":"sore",
"sores":"sore",
"sorest":"sore",
"sorenesses":"soreness",
"sorexes":"sorex",
"sorghos":"sorgho",
"sorghums":"sorghum",
"sorgos":"sorgo",
"soricidaes":"soricidae",
"sororities":"sorority",
"soroses":"sorosis",
"sorrels":"sorrel",
"sorrinesses":"sorriness",
"sorrowed":"sorrow",
"sorrowing":"sorrow",
"sorrows":"sorrow",
"sorrowfulnesses":"sorrowfulness",
"sorrier":"sorry",
"sorriest":"sorry",
"sorted":"sort",
"sorting":"sort",
"sorts":"sort",
"sorties":"sortie",
"sortings":"sorting",
"sortitions":"sortition",
"sori":"sorus",
"soss":"sos",
"sostenuti":"sostenuto",
"sostenutos":"sostenuto",
"sots":"sot",
"sothises":"sothis",
"sothos":"sotho",
"sous":"sou",
"souaris":"souari",
"soubises":"soubise",
"soubriquets":"soubriquet",
"soudans":"soudan",
"soughed":"sough",
"soughing":"sough",
"soughs":"sough",
"souls":"soul",
"soul-searchings":"soul-searching",
"soulfulnesses":"soulfulness",
"sounded":"sound",
"sounder":"sound",
"soundest":"sound",
"sounding":"sound",
"sounds":"sound",
"soundboards":"soundboard",
"soundings":"sounding",
"soundlessnesses":"soundlessness",
"soundnesses":"soundness",
"soundproofed":"soundproof",
"soundproofing":"soundproof",
"souped":"soup",
"souping":"soup",
"soups":"soup",
"soup-strainers":"soup-strainer",
"soupcons":"soupcon",
"soupfins":"soupfin",
"soupinesses":"soupiness",
"soupspoons":"soupspoon",
"soupier":"soupy",
"soupiest":"soupy",
"soured":"sour",
"sourer":"sour",
"sourest":"sour",
"souring":"sour",
"sours":"sour",
"sourbreads":"sourbread",
"sources":"source",
"sourdines":"sourdine",
"sournesses":"sourness",
"sourpusses":"sourpuss",
"soursops":"soursop",
"sourwoods":"sourwood",
"sousas":"sousa",
"sousaphones":"sousaphone",
"soused":"souse",
"souses":"souse",
"sousing":"souse",
"sousings":"sousing",
"sousliks":"souslik",
"souths":"south",
"southeasts":"southeast",
"southeasters":"southeaster",
"southeasterlies":"southeasterly",
"southers":"souther",
"southerlies":"southerly",
"southerns":"southern",
"southernwoods":"southernwood",
"southlands":"southland",
"southpaws":"southpaw",
"southwests":"southwest",
"southwesters":"southwester",
"southwesterlies":"southwesterly",
"southwesterns":"southwestern",
"souvenirs":"souvenir",
"souvlakis":"souvlaki",
"souvlakias":"souvlakia",
"sovereigns":"sovereign",
"sovereignties":"sovereignty",
"soviets":"soviet",
"sovietisms":"sovietism",
"sovkhozy":"sovkhoz",
"sowed":"sow",
"sowing":"sow",
"sown":"sow",
"sows":"sow",
"sowbanes":"sowbane",
"sowbreads":"sowbread",
"soys":"soy",
"soyas":"soya",
"soyabeans":"soyabean",
"soyamilks":"soyamilk",
"soybeans":"soybean",
"soymilks":"soymilk",
"spas":"spa",
"spaced":"space",
"spaces":"space",
"spacing":"space",
"space-times":"space-time",
"spacecrafts":"spacecraft",
"spacefarings":"spacefaring",
"spaceflights":"spaceflight",
"spacemen":"spaceman",
"spaceships":"spaceship",
"spacewomen":"spacewoman",
"spacings":"spacing",
"spaciousnesses":"spaciousness",
"spackles":"spackle",
"spaded":"spade",
"spades":"spade",
"spading":"spade",
"spadefishes":"spadefish",
"spadefoots":"spadefoot",
"spadefuls":"spadeful",
"spadices":"spadix",
"spadones":"spado",
"spados":"spado",
"spagged":"spag",
"spagging":"spag",
"spags":"spag",
"spahees":"spahee",
"spahis":"spahi",
"spains":"spain",
"spalacidaes":"spalacidae",
"spalaxes":"spalax",
"spanned":"span",
"spanning":"span",
"spans":"span",
"spanceled":"spancel",
"spanceling":"spancel",
"spancelled":"spancel",
"spancelling":"spancel",
"spancels":"spancel",
"spangled":"spangle",
"spangles":"spangle",
"spangling":"spangle",
"spanishes":"spanish",
"spanked":"spank",
"spanking":"spank",
"spanks":"spank",
"spankings":"spanking",
"spanners":"spanner",
"sparred":"spar",
"sparring":"spar",
"spars":"spar",
"sparaxes":"sparaxis",
"spared":"spare",
"sparer":"spare",
"spares":"spare",
"sparest":"spare",
"sparing":"spare",
"sparenesses":"spareness",
"spareribses":"spareribs",
"sparganiaceaes":"sparganiaceae",
"sparganiums":"sparganium",
"sparged":"sparge",
"sparging":"sparge",
"sparids":"sparid",
"sparidaes":"sparidae",
"sparked":"spark",
"sparking":"spark",
"sparks":"spark",
"sparkled":"sparkle",
"sparkles":"sparkle",
"sparkling":"sparkle",
"sparkleberries":"sparkleberry",
"sparklings":"sparkling",
"sparkplugged":"sparkplug",
"sparkplugging":"sparkplug",
"sparkplugs":"sparkplug",
"sparlings":"sparling",
"sparmannias":"sparmannia",
"sparrows":"sparrow",
"sparser":"sparse",
"sparsest":"sparse",
"sparsenesses":"sparseness",
"sparsities":"sparsity",
"spartinas":"spartina",
"spartiums":"spartium",
"spasms":"spasm",
"spasmolytics":"spasmolytic",
"spats":"spat",
"spatangoidas":"spatangoida",
"spatchcocked":"spatchcock",
"spatchcocking":"spatchcock",
"spates":"spate",
"spathiphyllums":"spathiphyllum",
"spatialities":"spatiality",
"spatses":"spats",
"spattered":"spatter",
"spattering":"spatter",
"spatters":"spatter",
"spatterdocks":"spatterdock",
"spatterings":"spattering",
"spatulas":"spatula",
"spawned":"spawn",
"spawning":"spawn",
"spawns":"spawn",
"spayed":"spay",
"spaying":"spay",
"spays":"spay",
"speaking":"speak",
"speaks":"speak",
"spoke":"speak",
"spoken":"speak",
"speakeasies":"speakeasy",
"speakers":"speaker",
"speakings":"speaking",
"speared":"spear",
"spearing":"spear",
"spears":"spear",
"spearfishes":"spearfish",
"spearheaded":"spearhead",
"spearheading":"spearhead",
"spearheads":"spearhead",
"spearmen":"spearman",
"spearmints":"spearmint",
"specs":"spec",
"specialisations":"specialisation",
"specialised":"specialise",
"specialising":"specialise",
"specialisms":"specialism",
"specialists":"specialist",
"specialities":"speciality",
"specializations":"specialization",
"specialized":"specialize",
"specializes":"specialize",
"specializing":"specialize",
"specializers":"specializer",
"specialnesses":"specialness",
"specialties":"specialty",
"specifics":"specific",
"specifications":"specification",
"specified":"specify",
"specifies":"specify",
"specifying":"specify",
"specimens":"specimen",
"speciosities":"speciosity",
"speciousnesses":"speciousness",
"specked":"speck",
"specking":"speck",
"specks":"speck",
"speckled":"speckle",
"speckles":"speckle",
"speckling":"speckle",
"specses":"specs",
"spectacles":"spectacle",
"spectacleses":"spectacles",
"spectaculars":"spectacular",
"spectated":"spectate",
"spectating":"spectate",
"spectators":"spectator",
"specters":"specter",
"spectres":"spectre",
"spectrograms":"spectrogram",
"spectrographs":"spectrograph",
"spectrometers":"spectrometer",
"spectrometries":"spectrometry",
"spectroscopes":"spectroscope",
"spectroscopies":"spectroscopy",
"spectra":"spectrum",
"spectrums":"spectrum",
"speculated":"speculate",
"speculates":"speculate",
"speculating":"speculate",
"speculations":"speculation",
"speculators":"speculator",
"specula":"speculum",
"speculums":"speculum",
"speeches":"speech",
"speechified":"speechify",
"speechifies":"speechify",
"speechifying":"speechify",
"speechmakers":"speechmaker",
"sped":"speed",
"speeded":"speed",
"speeding":"speed",
"speeds":"speed",
"speeders":"speeder",
"speedings":"speeding",
"speedos":"speedo",
"speedometers":"speedometer",
"speedreading":"speedread",
"speedups":"speedup",
"speedwells":"speedwell",
"speedier":"speedy",
"speediest":"speedy",
"spelaeologists":"spelaeologist",
"spelaeologies":"spelaeology",
"speleologists":"speleologist",
"speleologies":"speleology",
"spelled":"spell",
"spelling":"spell",
"spells":"spell",
"spelt":"spell",
"spell-checkers":"spell-checker",
"spellbinding":"spellbind",
"spellbinds":"spellbind",
"spellbound":"spellbind",
"spelldowns":"spelldown",
"spellers":"speller",
"spellings":"spelling",
"spelts":"spelt",
"spelunkers":"spelunker",
"spending":"spend",
"spends":"spend",
"spent":"spend",
"spend-alls":"spend-all",
"spenders":"spender",
"spendings":"spending",
"spendthrifts":"spendthrift",
"spensers":"spenser",
"spergulas":"spergula",
"spergularias":"spergularia",
"sperms":"sperm",
"spermaries":"spermary",
"spermatia":"spermatium",
"spermatocides":"spermatocide",
"spermatogonia":"spermatogonium",
"spermatophytas":"spermatophyta",
"spermatophytes":"spermatophyte",
"spermatozoids":"spermatozoid",
"spermatozoa":"spermatozoon",
"spermatozoons":"spermatozoon",
"spermicides":"spermicide",
"spermogonia":"spermogonium",
"spermophiles":"spermophile",
"spermophiluses":"spermophilus",
"spewed":"spew",
"spewing":"spew",
"spews":"spew",
"sphaceles":"sphacele",
"sphacelothecas":"sphacelotheca",
"sphaeralceas":"sphaeralcea",
"sphaeriaceaes":"sphaeriaceae",
"sphaerialeses":"sphaeriales",
"sphaerobolaceaes":"sphaerobolaceae",
"sphaerocarpaceaes":"sphaerocarpaceae",
"sphaerocarpaleses":"sphaerocarpales",
"sphaerocarposes":"sphaerocarpos",
"sphaerocarpuses":"sphaerocarpus",
"sphagnaleses":"sphagnales",
"sphagnums":"sphagnum",
"sphalerites":"sphalerite",
"sphecidaes":"sphecidae",
"spheciuses":"sphecius",
"sphecoids":"sphecoid",
"sphecoideas":"sphecoidea",
"sphecothereses":"sphecotheres",
"spheniscidaes":"spheniscidae",
"sphenisciformeses":"sphenisciformes",
"spheniscuses":"spheniscus",
"sphenodons":"sphenodon",
"sphenopsidas":"sphenopsida",
"sphered":"sphere",
"spheres":"sphere",
"sphering":"sphere",
"sphericalnesses":"sphericalness",
"sphericities":"sphericity",
"spheroids":"spheroid",
"sphincters":"sphincter",
"sphingids":"sphingid",
"sphingidaes":"sphingidae",
"sphinges":"sphinx",
"sphinxes":"sphinx",
"sphyraenas":"sphyraena",
"sphyraenidaes":"sphyraenidae",
"sphyrapicuses":"sphyrapicus",
"sphyrnas":"sphyrna",
"sphyrnidaes":"sphyrnidae",
"spics":"spic",
"spicae":"spica",
"spicas":"spica",
"spiced":"spice",
"spices":"spice",
"spicing":"spice",
"spiceberries":"spiceberry",
"spicebushes":"spicebush",
"spiceries":"spicery",
"spicinesses":"spiciness",
"spicks":"spick",
"spicules":"spicule",
"spiculums":"spiculum",
"spicier":"spicy",
"spiciest":"spicy",
"spiders":"spider",
"spiderflowers":"spiderflower",
"spidermen":"spiderman",
"spiderworts":"spiderwort",
"spiegels":"spiegel",
"spiegeleisens":"spiegeleisen",
"spieled":"spiel",
"spieling":"spiel",
"spiels":"spiel",
"spiffier":"spiffy",
"spiffiest":"spiffy",
"spigots":"spigot",
"spiks":"spik",
"spiked":"spike",
"spikes":"spike",
"spiking":"spike",
"spikemosses":"spikemoss",
"spikenards":"spikenard",
"spikier":"spiky",
"spikiest":"spiky",
"spiles":"spile",
"spilled":"spill",
"spilling":"spill",
"spills":"spill",
"spilt":"spill",
"spillages":"spillage",
"spillikins":"spillikin",
"spillikinses":"spillikins",
"spillways":"spillway",
"spilogales":"spilogale",
"spinning":"spin",
"spins":"spin",
"spun":"spin",
"spin-dried":"spin-dry",
"spin-dries":"spin-dry",
"spin-drying":"spin-dry",
"spin-offs":"spin-off",
"spinaches":"spinach",
"spinacias":"spinacia",
"spinals":"spinal",
"spindled":"spindle",
"spindles":"spindle",
"spindling":"spindle",
"spindleberries":"spindleberry",
"spindlelegses":"spindlelegs",
"spindleshankses":"spindleshanks",
"spindlier":"spindly",
"spindliest":"spindly",
"spindrifts":"spindrift",
"spines":"spine",
"spinners":"spinner",
"spinneries":"spinnery",
"spinneys":"spinney",
"spinsters":"spinster",
"spinuses":"spinus",
"spinier":"spiny",
"spiniest":"spiny",
"spiraeas":"spiraea",
"spiraled":"spiral",
"spiraling":"spiral",
"spiralled":"spiral",
"spiralling":"spiral",
"spirals":"spiral",
"spirants":"spirant",
"spirantheses":"spiranthes",
"spired":"spire",
"spires":"spire",
"spiring":"spire",
"spireas":"spirea",
"spirillas":"spirilla",
"spirillaceaes":"spirillaceae",
"spirilla":"spirillum",
"spirillums":"spirillum",
"spirited":"spirit",
"spiriting":"spirit",
"spirits":"spirit",
"spiritednesses":"spiritedness",
"spiritlessnesses":"spiritlessness",
"spiritses":"spirits",
"spirituals":"spiritual",
"spiritualisations":"spiritualisation",
"spiritualists":"spiritualist",
"spiritualities":"spirituality",
"spiritualizations":"spiritualization",
"spiritualized":"spiritualize",
"spiritualizing":"spiritualize",
"spiritualties":"spiritualty",
"spirochaetas":"spirochaeta",
"spirochaetaceaes":"spirochaetaceae",
"spirochaetaleses":"spirochaetales",
"spirochaetes":"spirochaete",
"spirochetes":"spirochete",
"spirodelas":"spirodela",
"spironolactones":"spironolactone",
"spirted":"spirt",
"spirting":"spirt",
"spirts":"spirt",
"spirulas":"spirula",
"spirulidaes":"spirulidae",
"spirier":"spiry",
"spiriest":"spiry",
"spat":"spit",
"spits":"spit",
"spitted":"spit",
"spitting":"spit",
"spited":"spite",
"spites":"spite",
"spiting":"spite",
"spitefulnesses":"spitefulness",
"spittings":"spitting",
"spittles":"spittle",
"spittlebugs":"spittlebug",
"spittoons":"spittoon",
"spizellas":"spizella",
"splashed":"splash",
"splashes":"splash",
"splashing":"splash",
"splashboards":"splashboard",
"splashguards":"splashguard",
"splashinesses":"splashiness",
"splashings":"splashing",
"splashier":"splashy",
"splashiest":"splashy",
"splattered":"splatter",
"splattering":"splatter",
"splatters":"splatter",
"splatterings":"splattering",
"splayed":"splay",
"splaying":"splay",
"splays":"splay",
"splayfeet":"splayfoot",
"splayfoots":"splayfoot",
"spleens":"spleen",
"splendors":"splendor",
"splendours":"splendour",
"splenectomies":"splenectomy",
"splenii":"splenius",
"spliced":"splice",
"splices":"splice",
"splicing":"splice",
"splicings":"splicing",
"splines":"spline",
"splinted":"splint",
"splinting":"splint",
"splints":"splint",
"splintered":"splinter",
"splintering":"splinter",
"splinters":"splinter",
"splinterings":"splintering",
"splinterses":"splinters",
"splits":"split",
"splitting":"split",
"splitsaws":"splitsaw",
"splitworms":"splitworm",
"splodges":"splodge",
"splotched":"splotch",
"splotches":"splotch",
"splotching":"splotch",
"splotchier":"splotchy",
"splotchiest":"splotchy",
"splurged":"splurge",
"splurges":"splurge",
"splurging":"splurge",
"spluttered":"splutter",
"spluttering":"splutter",
"splutters":"splutter",
"spodopteras":"spodoptera",
"spoiled":"spoil",
"spoiling":"spoil",
"spoils":"spoil",
"spoilt":"spoil",
"spoilableses":"spoilables",
"spoilages":"spoilage",
"spoilations":"spoilation",
"spoilers":"spoiler",
"spoilings":"spoiling",
"spoilsmen":"spoilsman",
"spoilsports":"spoilsport",
"spoked":"spoke",
"spokes":"spoke",
"spoking":"spoke",
"spokesmen":"spokesman",
"spokespersons":"spokesperson",
"spokeswomen":"spokeswoman",
"spoliated":"spoliate",
"spoliating":"spoliate",
"spoliations":"spoliation",
"spondiases":"spondias",
"sponged":"sponge",
"sponges":"sponge",
"sponging":"sponge",
"spongeflies":"spongefly",
"spongers":"sponger",
"spongillaflies":"spongillafly",
"sponginesses":"sponginess",
"spongier":"spongy",
"spongiest":"spongy",
"sponsored":"sponsor",
"sponsoring":"sponsor",
"sponsors":"sponsor",
"spontaneities":"spontaneity",
"spontaneousnesses":"spontaneousness",
"spoofed":"spoof",
"spoofing":"spoof",
"spoofs":"spoof",
"spooks":"spook",
"spookier":"spooky",
"spookiest":"spooky",
"spooled":"spool",
"spooling":"spool",
"spools":"spool",
"spooned":"spoon",
"spooning":"spoon",
"spoons":"spoon",
"spoon-fed":"spoon-feed",
"spoon-feeding":"spoon-feed",
"spoon-feeds":"spoon-feed",
"spoondrifts":"spoondrift",
"spoonies":"spooney",
"spoonflowers":"spoonflower",
"spoonfuls":"spoonful",
"spoonier":"spoony",
"spooniest":"spoony",
"spoored":"spoor",
"spooring":"spoor",
"sporangiums":"sporangium",
"spores":"spore",
"sporoboluses":"sporobolus",
"sporocarps":"sporocarp",
"sporogonia":"sporogonium",
"sporophyls":"sporophyl",
"sporophylls":"sporophyll",
"sporozoas":"sporozoa",
"sported":"sport",
"sporting":"sport",
"sports":"sport",
"sportivenesses":"sportiveness",
"sportscasters":"sportscaster",
"sportsmen":"sportsman",
"sportswomen":"sportswoman",
"sports_arenas":"sports_arena",
"sportier":"sporty",
"sportiest":"sporty",
"sporulated":"sporulate",
"sporulating":"sporulate",
"sporulations":"sporulation",
"spots":"spot",
"spotted":"spot",
"spotting":"spot",
"spot-checked":"spot-check",
"spot-checking":"spot-check",
"spotlessnesses":"spotlessness",
"spotlighted":"spotlight",
"spotlighting":"spotlight",
"spotlights":"spotlight",
"spotlit":"spotlight",
"spotsylvanias":"spotsylvania",
"spotters":"spotter",
"spottings":"spotting",
"spottier":"spotty",
"spottiest":"spotty",
"spoused":"spouse",
"spouses":"spouse",
"spousing":"spouse",
"spouted":"spout",
"spouting":"spout",
"spouts":"spout",
"spraddled":"spraddle",
"spraddling":"spraddle",
"sprags":"sprag",
"spragueas":"spraguea",
"sprained":"sprain",
"spraining":"sprain",
"sprains":"sprain",
"sprats":"sprat",
"sprawled":"sprawl",
"sprawling":"sprawl",
"sprawls":"sprawl",
"sprawlings":"sprawling",
"sprayed":"spray",
"spraying":"spray",
"sprays":"spray",
"sprayers":"sprayer",
"sprayings":"spraying",
"spreading":"spread",
"spreads":"spread",
"spread-eagled":"spread-eagle",
"spread-eagles":"spread-eagle",
"spread-eagling":"spread-eagle",
"spreaders":"spreader",
"spreadheads":"spreadhead",
"spreadings":"spreading",
"spreed":"spree",
"spreeing":"spree",
"sprees":"spree",
"sprigged":"sprig",
"sprigging":"sprig",
"sprigs":"sprig",
"sprightlinesses":"sprightliness",
"sprightlier":"sprightly",
"sprightliest":"sprightly",
"sprigtails":"sprigtail",
"sprang":"spring",
"springing":"spring",
"springs":"spring",
"sprung":"spring",
"springboks":"springbok",
"springbucks":"springbuck",
"springers":"springer",
"springfields":"springfield",
"springhase":"springhaas",
"springhouses":"springhouse",
"springinesses":"springiness",
"springtails":"springtail",
"springtimes":"springtime",
"springier":"springy",
"springiest":"springy",
"sprinkled":"sprinkle",
"sprinkles":"sprinkle",
"sprinkling":"sprinkle",
"sprinkleses":"sprinkles",
"sprinklings":"sprinkling",
"sprinted":"sprint",
"sprinting":"sprint",
"sprints":"sprint",
"sprites":"sprite",
"spriteses":"sprites",
"sprockets":"sprocket",
"sprouted":"sprout",
"sprouting":"sprout",
"sprouts":"sprout",
"sproutings":"sprouting",
"spruced":"spruce",
"sprucer":"spruce",
"spruces":"spruce",
"sprucest":"spruce",
"sprucing":"spruce",
"sprucenesses":"spruceness",
"sprier":"spry",
"spriest":"spry",
"spryer":"spry",
"spryest":"spry",
"spudded":"spud",
"spudding":"spud",
"spuds":"spud",
"spued":"spue",
"spues":"spue",
"spuing":"spue",
"spugs":"spug",
"spuggies":"spuggy",
"spumed":"spume",
"spumes":"spume",
"spuming":"spume",
"spumoni":"spumone",
"spunks":"spunk",
"spunkier":"spunky",
"spunkiest":"spunky",
"spurred":"spur",
"spurring":"spur",
"spurs":"spur",
"spurned":"spurn",
"spurning":"spurn",
"spurns":"spurn",
"spurries":"spurrey",
"spurrings":"spurring",
"spurted":"spurt",
"spurting":"spurt",
"spurts":"spurt",
"sputniks":"sputnik",
"sputtered":"sputter",
"sputtering":"sputter",
"sputters":"sputter",
"sputterings":"sputtering",
"sputa":"sputum",
"sputums":"sputum",
"spied":"spy",
"spies":"spy",
"spying":"spy",
"spyerias":"spyeria",
"spyglasses":"spyglass",
"spyholes":"spyhole",
"spyings":"spying",
"squabs":"squab",
"squabbled":"squabble",
"squabbles":"squabble",
"squabbling":"squabble",
"squabbier":"squabby",
"squabbiest":"squabby",
"squaccos":"squacco",
"squads":"squad",
"squalidaes":"squalidae",
"squalidnesses":"squalidness",
"squalled":"squall",
"squalling":"squall",
"squalls":"squall",
"squallier":"squally",
"squalliest":"squally",
"squalors":"squalor",
"squaluses":"squalus",
"squamae":"squama",
"squamatas":"squamata",
"squandered":"squander",
"squandering":"squander",
"squanders":"squander",
"squanderers":"squanderer",
"squared":"square",
"squarer":"square",
"squares":"square",
"squarest":"square",
"squaring":"square",
"square-danced":"square-dance",
"square-dancing":"square-dance",
"squarks":"squark",
"squashed":"squash",
"squashes":"squash",
"squashing":"squash",
"squashier":"squashy",
"squashiest":"squashy",
"squats":"squat",
"squatted":"squat",
"squatter":"squat",
"squattest":"squat",
"squatting":"squat",
"squatinas":"squatina",
"squatinidaes":"squatinidae",
"squatnesses":"squatness",
"squatters":"squatter",
"squattinesses":"squattiness",
"squattings":"squatting",
"squattier":"squatty",
"squattiest":"squatty",
"squaws":"squaw",
"squawbushes":"squawbush",
"squawked":"squawk",
"squawking":"squawk",
"squawks":"squawk",
"squawkers":"squawker",
"squawkier":"squawky",
"squawkiest":"squawky",
"squawroots":"squawroot",
"squeaked":"squeak",
"squeaking":"squeak",
"squeaks":"squeak",
"squeakers":"squeaker",
"squeakier":"squeaky",
"squeakiest":"squeaky",
"squealed":"squeal",
"squealing":"squeal",
"squeals":"squeal",
"squealers":"squealer",
"squeamishnesses":"squeamishness",
"squeegeed":"squeegee",
"squeegeeing":"squeegee",
"squeegees":"squeegee",
"squilgee":"squeegee",
"squeezabilities":"squeezability",
"squeezed":"squeeze",
"squeezes":"squeeze",
"squeezing":"squeeze",
"squelched":"squelch",
"squelches":"squelch",
"squelching":"squelch",
"squeteagues":"squeteague",
"squibbed":"squib",
"squibbing":"squib",
"squibs":"squib",
"squids":"squid",
"squiffier":"squiffy",
"squiffiest":"squiffy",
"squiggles":"squiggle",
"squills":"squill",
"squillas":"squilla",
"squillidaes":"squillidae",
"squinted":"squint",
"squinter":"squint",
"squintest":"squint",
"squinting":"squint",
"squints":"squint",
"squintier":"squinty",
"squintiest":"squinty",
"squired":"squire",
"squires":"squire",
"squiring":"squire",
"squirearchies":"squirearchy",
"squirmed":"squirm",
"squirming":"squirm",
"squirms":"squirm",
"squirmier":"squirmy",
"squirmiest":"squirmy",
"squirreled":"squirrel",
"squirreling":"squirrel",
"squirrelled":"squirrel",
"squirrelling":"squirrel",
"squirrels":"squirrel",
"squirrelfishes":"squirrelfish",
"squirted":"squirt",
"squirting":"squirt",
"squirts":"squirt",
"squished":"squish",
"squishes":"squish",
"squishing":"squish",
"squizzes":"squiz",
"srs":"sr",
"srbijas":"srbija",
"sses":"sse",
"ssws":"ssw",
"stabbed":"stab",
"stabbing":"stab",
"stabs":"stab",
"stabilisations":"stabilisation",
"stabilities":"stability",
"stabilizations":"stabilization",
"stabilized":"stabilize",
"stabilizing":"stabilize",
"stabled":"stable",
"stables":"stable",
"stabling":"stable",
"stableboys":"stableboy",
"stablemen":"stableman",
"stablemates":"stablemate",
"stablenesses":"stableness",
"stabroeks":"stabroek",
"staccati":"staccato",
"staccatos":"staccato",
"stachyses":"stachys",
"stacked":"stack",
"stacking":"stack",
"stacks":"stack",
"stackses":"stacks",
"stadia":"stadium",
"stadiums":"stadium",
"staffing":"staff",
"staffs":"staff",
"staves":"stave",
"staffers":"staffer",
"staffmen":"staffman",
"stagged":"stag",
"stagging":"stag",
"stags":"stag",
"staged":"stage",
"stages":"stage",
"staging":"stage",
"stage-managed":"stage-manage",
"stage-managing":"stage-manage",
"stagecoaches":"stagecoach",
"stagehands":"stagehand",
"stagers":"stager",
"staggered":"stagger",
"staggering":"stagger",
"staggers":"stagger",
"staggerbushes":"staggerbush",
"stagheads":"staghead",
"staginesses":"staginess",
"stagings":"staging",
"stagnancies":"stagnancy",
"stagnated":"stagnate",
"stagnates":"stagnate",
"stagnating":"stagnate",
"stagnations":"stagnation",
"stagier":"stagy",
"stagiest":"stagy",
"staider":"staid",
"staidest":"staid",
"staidnesses":"staidness",
"stained":"stain",
"staining":"stain",
"stains":"stain",
"stainings":"staining",
"stairs":"stair",
"staircases":"staircase",
"stairses":"stairs",
"stairways":"stairway",
"staked":"stake",
"stakes":"stake",
"staking":"stake",
"stakeses":"stakes",
"stakings":"staking",
"staled":"stale",
"staler":"stale",
"stalest":"stale",
"staling":"stale",
"stalemated":"stalemate",
"stalemates":"stalemate",
"stalemating":"stalemate",
"stalenesses":"staleness",
"stalins":"stalin",
"stalingrads":"stalingrad",
"stalinisms":"stalinism",
"stalinos":"stalino",
"stalked":"stalk",
"stalking":"stalk",
"stalks":"stalk",
"stalkings":"stalking",
"stalking-horses":"stalking-horse",
"stalkier":"stalky",
"stalkiest":"stalky",
"stalled":"stall",
"stalling":"stall",
"stalls":"stall",
"stall-fed":"stall-feed",
"stall-feeding":"stall-feed",
"stall-feeds":"stall-feed",
"stallings":"stalling",
"stallions":"stallion",
"stallses":"stalls",
"stalwarts":"stalwart",
"stalwartnesses":"stalwartness",
"stambouls":"stamboul",
"stambuls":"stambul",
"stamens":"stamen",
"stamina":"stamen",
"staminas":"stamina",
"staminodes":"staminode",
"staminonodia":"staminodium",
"stammered":"stammer",
"stammering":"stammer",
"stammers":"stammer",
"stammerers":"stammerer",
"stamped":"stamp",
"stamping":"stamp",
"stamps":"stamp",
"stampeded":"stampede",
"stampedes":"stampede",
"stampeding":"stampede",
"stanched":"stanch",
"stancher":"stanch",
"stanchest":"stanch",
"stanching":"stanch",
"stanchioned":"stanchion",
"stanchioning":"stanchion",
"standing":"stand",
"stands":"stand",
"stood":"stand",
"stand-ins":"stand-in",
"standards":"standard",
"standard-bearers":"standard-bearer",
"standardisations":"standardisation",
"standardizations":"standardization",
"standardized":"standardize",
"standardizes":"standardize",
"standardizing":"standardize",
"standbies":"standby",
"standbys":"standby",
"standings":"standing",
"standoffs":"standoff",
"standoffishnesses":"standoffishness",
"standpoints":"standpoint",
"standses":"stands",
"standstills":"standstill",
"stanfords":"stanford",
"stanleyas":"stanleya",
"stannaries":"stannary",
"stannites":"stannite",
"stanzas":"stanza",
"stapelias":"stapelia",
"stapedes":"stapes",
"stapeses":"stapes",
"staphs":"staph",
"staphylaceaes":"staphylaceae",
"staphyleas":"staphylea",
"staphylinidaes":"staphylinidae",
"staphylococcis":"staphylococci",
"staphylococci":"staphylococcus",
"staphylococcuses":"staphylococcus",
"stapled":"staple",
"staples":"staple",
"stapling":"staple",
"staplers":"stapler",
"starred":"star",
"starring":"star",
"stars":"star",
"star-duckweeds":"star-duckweed",
"star-glories":"star-glory",
"star-thistles":"star-thistle",
"starboarded":"starboard",
"starboarding":"starboard",
"starched":"starch",
"starches":"starch",
"starching":"starch",
"starchier":"starchy",
"starchiest":"starchy",
"stared":"stare",
"stares":"stare",
"staring":"stare",
"startsy":"starets",
"starfishes":"starfish",
"starflowers":"starflower",
"stargazed":"stargaze",
"stargazes":"stargaze",
"stargazing":"stargaze",
"stargazers":"stargazer",
"starker":"stark",
"starkest":"stark",
"starknesses":"starkness",
"starlets":"starlet",
"starrier":"starry",
"starriest":"starry",
"started":"start",
"starting":"start",
"starts":"start",
"start-offs":"start-off",
"starters":"starter",
"startings":"starting",
"startled":"startle",
"startles":"startle",
"startling":"startle",
"startups":"startup",
"starvations":"starvation",
"starved":"starve",
"starves":"starve",
"starving":"starve",
"starvings":"starving",
"starworts":"starwort",
"stashed":"stash",
"stashes":"stash",
"stashing":"stash",
"stases":"stasis",
"stated":"state",
"states":"state",
"stating":"state",
"statecrafts":"statecraft",
"statelinesses":"stateliness",
"statelier":"stately",
"stateliest":"stately",
"statements":"statement",
"staterooms":"stateroom",
"statesmen":"statesman",
"statesmanships":"statesmanship",
"stateswomen":"stateswoman",
"statics":"static",
"statices":"statice",
"stationed":"station",
"stationing":"station",
"stations":"station",
"stationarinesses":"stationariness",
"stationaries":"stationary",
"stationers":"stationer",
"stationeries":"stationery",
"stationmasters":"stationmaster",
"statisticians":"statistician",
"stators":"stator",
"statuaries":"statuary",
"statues":"statue",
"statuettes":"statuette",
"statures":"stature",
"statuses":"status",
"statutes":"statute",
"staunched":"staunch",
"stauncher":"staunch",
"staunchest":"staunch",
"staunching":"staunch",
"staunchnesses":"staunchness",
"staurikosaurs":"staurikosaur",
"staurikosauruses":"staurikosaurus",
"staved":"stave",
"staving":"stave",
"stove":"stave",
"staid":"stay",
"stayed":"stay",
"staying":"stay",
"stays":"stay",
"stay-at-homes":"stay-at-home",
"stayses":"stays",
"steads":"stead",
"steadfastnesses":"steadfastness",
"steadinesses":"steadiness",
"steadied":"steady",
"steadier":"steady",
"steadies":"steady",
"steadiest":"steady",
"steadying":"steady",
"steaks":"steak",
"steakhouses":"steakhouse",
"stealing":"steal",
"steals":"steal",
"stole":"steal",
"stolen":"steal",
"stealings":"stealing",
"stealths":"stealth",
"stealthinesses":"stealthiness",
"stealthier":"stealthy",
"stealthiest":"stealthy",
"steamed":"steam",
"steaming":"steam",
"steams":"steam",
"steamboats":"steamboat",
"steamers":"steamer",
"steamrollered":"steamroller",
"steamrollering":"steamroller",
"steamrollers":"steamroller",
"steamships":"steamship",
"steamier":"steamy",
"steamiest":"steamy",
"steatites":"steatite",
"steatocystomas":"steatocystoma",
"steatornises":"steatornis",
"steatornithidaes":"steatornithidae",
"steeds":"steed",
"steeked":"steek",
"steeking":"steek",
"steeled":"steel",
"steeling":"steel",
"steels":"steel",
"steelheads":"steelhead",
"steelmakers":"steelmaker",
"steelmen":"steelman",
"steelworkers":"steelworker",
"steelworkses":"steelworks",
"steelier":"steely",
"steeliest":"steely",
"steelyards":"steelyard",
"steenboks":"steenbok",
"steeped":"steep",
"steeper":"steep",
"steepest":"steep",
"steeping":"steep",
"steepened":"steepen",
"steepening":"steepen",
"steeples":"steeple",
"steepnesses":"steepness",
"steered":"steer",
"steering":"steer",
"steers":"steer",
"steerages":"steerage",
"steerings":"steering",
"steersmen":"steersman",
"steganopuses":"steganopus",
"stegocephalias":"stegocephalia",
"stegosaurs":"stegosaur",
"stegosauruses":"stegosaurus",
"steins":"stein",
"steinboks":"steinbok",
"stelae":"stela",
"stelas":"stela",
"steles":"stele",
"stellarias":"stellaria",
"stellified":"stellify",
"stellifies":"stellify",
"stellifying":"stellify",
"stemmed":"stem",
"stemming":"stem",
"stems":"stem",
"stemmata":"stemma",
"stems_from":"stem_from",
"stenches":"stench",
"stenciled":"stencil",
"stenciling":"stencil",
"stencilled":"stencil",
"stencilling":"stencil",
"stencils":"stencil",
"stencilers":"stenciler",
"stenos":"steno",
"stenocarpuses":"stenocarpus",
"stenochlaenas":"stenochlaena",
"stenographers":"stenographer",
"stenographies":"stenography",
"stenopelmatidaes":"stenopelmatidae",
"stenopelmatuses":"stenopelmatus",
"stenopterygiuses":"stenopterygius",
"stenoses":"stenosis",
"stenotaphrums":"stenotaphrum",
"stenotomuses":"stenotomus",
"stenotuses":"stenotus",
"stepped":"step",
"stepping":"step",
"steps":"step",
"step-downs":"step-down",
"step-ins":"step-in",
"step-ups":"step-up",
"stepbrothers":"stepbrother",
"stepchildren":"stepchild",
"stepdaughters":"stepdaughter",
"stepfathers":"stepfather",
"stephanomerias":"stephanomeria",
"stepheads":"stephead",
"stepladders":"stepladder",
"stepmothers":"stepmother",
"stepparents":"stepparent",
"steppingstones":"steppingstone",
"stepses":"steps",
"stepsisters":"stepsister",
"stepsons":"stepson",
"steradians":"steradian",
"stercorariidaes":"stercorariidae",
"stercorariuses":"stercorarius",
"sterculiaceaes":"sterculiaceae",
"stereos":"stereo",
"stereospondylis":"stereospondyli",
"stereotyped":"stereotype",
"stereotypes":"stereotype",
"stereotyping":"stereotype",
"sterilenesses":"sterileness",
"sterilisations":"sterilisation",
"sterilities":"sterility",
"sterilizations":"sterilization",
"sterilized":"sterilize",
"sterilizes":"sterilize",
"sterilizing":"sterilize",
"sterilizers":"sterilizer",
"sterilsations":"sterilsation",
"sterner":"stern",
"sternest":"stern",
"sterns":"stern",
"sternas":"sterna",
"sterninaes":"sterninae",
"sternnesses":"sternness",
"sternocleidomastoids":"sternocleidomastoid",
"sternotheruses":"sternotherus",
"sterna":"sternum",
"sternums":"sternum",
"sternutations":"sternutation",
"sternutators":"sternutator",
"sternutatories":"sternutatory",
"steroids":"steroid",
"sterols":"sterol",
"steropes":"sterope",
"stertors":"stertor",
"stets":"stet",
"stetted":"stet",
"stetting":"stet",
"stetsons":"stetson",
"stevedored":"stevedore",
"stevedores":"stevedore",
"stevedoring":"stevedore",
"stewed":"stew",
"stewing":"stew",
"stews":"stew",
"stewarded":"steward",
"stewarding":"steward",
"stewards":"steward",
"stewardesses":"stewardess",
"stewings":"stewing",
"stewpans":"stewpan",
"stichaeidaes":"stichaeidae",
"sticheruses":"sticherus",
"sticking":"stick",
"sticks":"stick",
"stick-in-the-muds":"stick-in-the-mud",
"stickballs":"stickball",
"stickers":"sticker",
"stickfuls":"stickful",
"stickled":"stickle",
"stickling":"stickle",
"sticklebacks":"stickleback",
"stickmen":"stickman",
"sticktights":"sticktight",
"stickups":"stickup",
"stickier":"sticky",
"stickiest":"sticky",
"stictomyses":"stictomys",
"stictopelias":"stictopelia",
"stiffs":"stiff",
"stiffened":"stiffen",
"stiffening":"stiffen",
"stiffens":"stiffen",
"stiffeners":"stiffener",
"stiffnesses":"stiffness",
"stifled":"stifle",
"stifles":"stifle",
"stifling":"stifle",
"stiflings":"stifling",
"stigmas":"stigma",
"stigmata":"stigma",
"stigmatics":"stigmatic",
"stigmatisations":"stigmatisation",
"stigmatists":"stigmatist",
"stigmatizations":"stigmatization",
"stigmatized":"stigmatize",
"stigmatizes":"stigmatize",
"stigmatizing":"stigmatize",
"stilbestrols":"stilbestrol",
"stilboestrols":"stilboestrol",
"stiles":"stile",
"stilettoed":"stiletto",
"stilettoeing":"stiletto",
"stilettoes":"stiletto",
"stilettos":"stiletto",
"stilled":"still",
"stiller":"still",
"stillest":"still",
"stilling":"still",
"stills":"still",
"stillbirths":"stillbirth",
"stillnesses":"stillness",
"stillrooms":"stillroom",
"stilts":"stilt",
"stiltbirds":"stiltbird",
"stimulants":"stimulant",
"stimulated":"stimulate",
"stimulates":"stimulate",
"stimulating":"stimulate",
"stimulations":"stimulation",
"stimuli":"stimulus",
"stimuluses":"stimulus",
"stimied":"stimy",
"stimies":"stimy",
"stimying":"stimy",
"stinging":"sting",
"stings":"sting",
"stung":"sting",
"stingaree-bushes":"stingaree-bush",
"stingers":"stinger",
"stingings":"stinging",
"stingier":"stingy",
"stingies":"stingy",
"stingiest":"stingy",
"stank":"stink",
"stinking":"stink",
"stinks":"stink",
"stunk":"stink",
"stinkbirds":"stinkbird",
"stinkers":"stinker",
"stinkhorns":"stinkhorn",
"stinkinesses":"stinkiness",
"stinkpots":"stinkpot",
"stinkweeds":"stinkweed",
"stinted":"stint",
"stinting":"stint",
"stints":"stint",
"stipendiaries":"stipendiary",
"stipites":"stipes",
"stippled":"stipple",
"stipples":"stipple",
"stippling":"stipple",
"stipulated":"stipulate",
"stipulates":"stipulate",
"stipulating":"stipulate",
"stipulations":"stipulation",
"stirred":"stir",
"stirring":"stir",
"stirs":"stir",
"stirpes":"stirps",
"stirrers":"stirrer",
"stirrings":"stirring",
"stirrups":"stirrup",
"stitched":"stitch",
"stitches":"stitch",
"stitching":"stitch",
"stitchers":"stitcher",
"stitcheries":"stitchery",
"stitchings":"stitching",
"stitchworts":"stitchwort",
"stizidaes":"stizidae",
"stizolobiums":"stizolobium",
"stizostedions":"stizostedion",
"stms":"stm",
"stoae":"stoa",
"stoai":"stoa",
"stoas":"stoa",
"stocked":"stock",
"stocking":"stock",
"stocks":"stock",
"stockaded":"stockade",
"stockades":"stockade",
"stockading":"stockade",
"stockbrokers":"stockbroker",
"stockfishes":"stockfish",
"stockholders":"stockholder",
"stockholdings":"stockholding",
"stockholdingses":"stockholdings",
"stockholms":"stockholm",
"stockhorns":"stockhorn",
"stockinets":"stockinet",
"stockinettes":"stockinette",
"stockings":"stocking",
"stockmen":"stockman",
"stockpiled":"stockpile",
"stockpiles":"stockpile",
"stockpiling":"stockpile",
"stockrooms":"stockroom",
"stockses":"stocks",
"stocktakings":"stocktaking",
"stockier":"stocky",
"stockiest":"stocky",
"stockyards":"stockyard",
"stodged":"stodge",
"stodging":"stodge",
"stodginesses":"stodginess",
"stodgier":"stodgy",
"stodgiest":"stodgy",
"stoeps":"stoep",
"stogies":"stogie",
"stoics":"stoic",
"stoicisms":"stoicism",
"stoked":"stoke",
"stoking":"stoke",
"stokeholds":"stokehold",
"stokeholes":"stokehole",
"stokers":"stoker",
"stokesias":"stokesia",
"stoles":"stole",
"stolidities":"stolidity",
"stolidnesses":"stolidness",
"stolons":"stolon",
"stomas":"stoma",
"stomached":"stomach",
"stomaches":"stomach",
"stomaching":"stomach",
"stomachs":"stomach",
"stomachaches":"stomachache",
"stomatopods":"stomatopod",
"stomatopodas":"stomatopoda",
"stomodaea":"stomodaeum",
"stomodea":"stomodeum",
"stoned":"stone",
"stones":"stone",
"stoning":"stone",
"stonechats":"stonechat",
"stonecresses":"stonecress",
"stonecutters":"stonecutter",
"stonefaces":"stoneface",
"stonefishes":"stonefish",
"stoneflies":"stonefly",
"stonemasons":"stonemason",
"stoneroots":"stoneroot",
"stonewalled":"stonewall",
"stonewalling":"stonewall",
"stoneworks":"stonework",
"stonier":"stony",
"stoniest":"stony",
"stooged":"stooge",
"stooges":"stooge",
"stooging":"stooge",
"stooled":"stool",
"stooling":"stool",
"stools":"stool",
"stoolies":"stoolie",
"stoolpigeons":"stoolpigeon",
"stooped":"stoop",
"stooping":"stoop",
"stoops":"stoop",
"stopped":"stop",
"stopping":"stop",
"stops":"stop",
"stopcocks":"stopcock",
"stopgaps":"stopgap",
"stoplights":"stoplight",
"stopovers":"stopover",
"stoppages":"stoppage",
"stoppered":"stopper",
"stoppering":"stopper",
"stoppers":"stopper",
"stoppings":"stopping",
"stoppled":"stopple",
"stopples":"stopple",
"stoppling":"stopple",
"stopses":"stops",
"stopwatches":"stopwatch",
"storages":"storage",
"stored":"store",
"stores":"store",
"storing":"store",
"storefronts":"storefront",
"storehouses":"storehouse",
"storekeepers":"storekeeper",
"storerias":"storeria",
"storerooms":"storeroom",
"storeses":"stores",
"storeys":"storey",
"storings":"storing",
"storks":"stork",
"storksbills":"storksbill",
"stormed":"storm",
"storming":"storm",
"storms":"storm",
"stormier":"stormy",
"stormiest":"stormy",
"storied":"story",
"stories":"story",
"storying":"story",
"storylines":"storyline",
"storytellers":"storyteller",
"stots":"stot",
"stotted":"stot",
"stotting":"stot",
"stotinki":"stotinka",
"stoups":"stoup",
"stouter":"stout",
"stoutest":"stout",
"stoutnesses":"stoutness",
"stoves":"stove",
"stovepipes":"stovepipe",
"stowed":"stow",
"stowing":"stow",
"stows":"stow",
"stowages":"stowage",
"stowings":"stowing",
"strabismuses":"strabismus",
"strabotomies":"strabotomy",
"straddled":"straddle",
"straddles":"straddle",
"straddling":"straddle",
"strafed":"strafe",
"strafes":"strafe",
"strafing":"strafe",
"straggled":"straggle",
"straggles":"straggle",
"straggling":"straggle",
"stragglier":"straggly",
"straggliest":"straggly",
"straighter":"straight",
"straightest":"straight",
"straights":"straight",
"straightaways":"straightaway",
"straightened":"straighten",
"straightening":"straighten",
"straightens":"straighten",
"straightforwardnesses":"straightforwardness",
"straightjackets":"straightjacket",
"straightnesses":"straightness",
"strained":"strain",
"straining":"strain",
"strains":"strain",
"strainings":"straining",
"straiter":"strait",
"straitest":"strait",
"straits":"strait",
"strait-jacketed":"strait-jacket",
"strait-jacketing":"strait-jacket",
"straitened":"straiten",
"straitening":"straiten",
"straitjackets":"straitjacket",
"straitses":"straits",
"strakes":"strake",
"stranded":"strand",
"stranding":"strand",
"strands":"strand",
"stranger":"strange",
"strangest":"strange",
"strangenesses":"strangeness",
"strangers":"stranger",
"strangled":"strangle",
"strangles":"strangle",
"strangling":"strangle",
"strangleholds":"stranglehold",
"stranglers":"strangler",
"strangleses":"strangles",
"stranglings":"strangling",
"strangulated":"strangulate",
"strangulates":"strangulate",
"strangulating":"strangulate",
"strangulations":"strangulation",
"strapping":"strap",
"straps":"strap",
"strappadoes":"strappado",
"strappers":"strapper",
"stratagems":"stratagem",
"strategians":"strategian",
"strategists":"strategist",
"strategies":"strategy",
"stratford-on-avons":"stratford-on-avon",
"stratford-upon-avons":"stratford-upon-avon",
"stratifications":"stratification",
"stratified":"stratify",
"stratifies":"stratify",
"stratifying":"stratify",
"strato-cumuli":"strato-cumulus",
"stratocracies":"stratocracy",
"stratocumuli":"stratocumulus",
"strata":"stratum",
"stratums":"stratum",
"strati":"stratus",
"stratuses":"stratus",
"stravaged":"stravage",
"stravaging":"stravage",
"stravinskies":"stravinsky",
"strawed":"straw",
"strawing":"straw",
"straws":"straw",
"strawberries":"strawberry",
"strawflowers":"strawflower",
"strawmen":"strawman",
"strawworms":"strawworm",
"strayed":"stray",
"straying":"stray",
"strays":"stray",
"streaked":"streak",
"streaking":"streak",
"streaks":"streak",
"streakers":"streaker",
"streakier":"streaky",
"streakiest":"streaky",
"streamed":"stream",
"streaming":"stream",
"streams":"stream",
"streambeds":"streambed",
"streamers":"streamer",
"streamings":"streaming",
"streamlets":"streamlet",
"streamlined":"streamline",
"streamlining":"streamline",
"streamier":"streamy",
"streamiest":"streamy",
"streets":"street",
"streetcars":"streetcar",
"streetlights":"streetlight",
"streetwalkers":"streetwalker",
"strekelias":"strekelia",
"strelitzias":"strelitzia",
"strelitziaceaes":"strelitziaceae",
"strengths":"strength",
"strengthened":"strengthen",
"strengthening":"strengthen",
"strengthens":"strengthen",
"strengtheners":"strengthener",
"strengthenings":"strengthening",
"strenuosities":"strenuosity",
"strenuousnesses":"strenuousness",
"streps":"strep",
"streperas":"strepera",
"strepsiceroses":"strepsiceros",
"strepsirhinis":"strepsirhini",
"streptococcis":"streptococci",
"streptococci":"streptococcus",
"streptococcuses":"streptococcus",
"streptomycetacaeas":"streptomycetacaea",
"streptopelias":"streptopelia",
"streptosolens":"streptosolen",
"stressed":"stress",
"stresses":"stress",
"stressing":"stress",
"stretched":"stretch",
"stretches":"stretch",
"stretching":"stretch",
"stretchabilities":"stretchability",
"stretchers":"stretcher",
"stretcher-bearers":"stretcher-bearer",
"stretchinesses":"stretchiness",
"stretchings":"stretching",
"stretchier":"stretchy",
"stretchiest":"stretchy",
"stretti":"stretto",
"strettos":"stretto",
"strewed":"strew",
"strewing":"strew",
"strewn":"strew",
"strews":"strew",
"strewings":"strewing",
"strias":"stria",
"striations":"striation",
"stricter":"strict",
"strictest":"strict",
"strictnesses":"strictness",
"strictures":"stricture",
"stridden":"stride",
"strides":"stride",
"striding":"stride",
"strode":"stride",
"stridences":"stridence",
"stridencies":"stridency",
"strifes":"strife",
"strigidaes":"strigidae",
"strigiformeses":"strigiformes",
"stricken":"strike",
"strikes":"strike",
"striking":"strike",
"struck":"strike",
"strikebreakers":"strikebreaker",
"strikers":"striker",
"strikings":"striking",
"strikingnesses":"strikingness",
"stringing":"string",
"strings":"string",
"strung":"string",
"stringencies":"stringency",
"stringier":"stringy",
"stringiest":"stringy",
"stripped":"strip",
"stripping":"strip",
"strips":"strip",
"stript":"strip",
"striped":"stripe",
"stripes":"stripe",
"striping":"stripe",
"stripers":"striper",
"stripeses":"stripes",
"striplings":"stripling",
"strippers":"stripper",
"strippings":"stripping",
"stripteases":"striptease",
"stripteasers":"stripteaser",
"stripier":"stripy",
"stripiest":"stripy",
"strived":"strive",
"striven":"strive",
"strives":"strive",
"striving":"strive",
"strove":"strive",
"strivers":"striver",
"strivings":"striving",
"strixes":"strix",
"strobiles":"strobile",
"strobilomyceses":"strobilomyces",
"strobiluses":"strobilus",
"stroked":"stroke",
"strokes":"stroke",
"stroking":"stroke",
"strokings":"stroking",
"strolled":"stroll",
"strolling":"stroll",
"strolls":"stroll",
"strollers":"stroller",
"stromata":"stroma",
"stromateids":"stromateid",
"stromateidaes":"stromateidae",
"strombidaes":"strombidae",
"strombuses":"strombus",
"stronger":"strong",
"strongest":"strong",
"strong-armed":"strong-arm",
"strong-arming":"strong-arm",
"strong-arms":"strong-arm",
"strongboxes":"strongbox",
"strongholds":"stronghold",
"strongmen":"strongman",
"strongylodons":"strongylodon",
"strontiums":"strontium",
"stropped":"strop",
"stropping":"strop",
"strops":"strop",
"stropharias":"stropharia",
"strophariaceaes":"strophariaceae",
"strophes":"strophe",
"stroppier":"stroppy",
"stroppiest":"stroppy",
"strowed":"strow",
"strowing":"strow",
"strown":"strow",
"strows":"strow",
"structured":"structure",
"structures":"structure",
"structuring":"structure",
"struggled":"struggle",
"struggles":"struggle",
"struggling":"struggle",
"strugglers":"struggler",
"strummed":"strum",
"strumming":"strum",
"strums":"strum",
"strumas":"struma",
"strumpets":"strumpet",
"struts":"strut",
"strutted":"strut",
"strutting":"strut",
"struthios":"struthio",
"struthionidaes":"struthionidae",
"struthioniformeses":"struthioniformes",
"strymons":"strymon",
"stubbed":"stub",
"stubbing":"stub",
"stubs":"stub",
"stubbinesses":"stubbiness",
"stubbles":"stubble",
"stubbornnesses":"stubbornness",
"stubbier":"stubby",
"stubbiest":"stubby",
"stuccoed":"stucco",
"stuccoes":"stucco",
"stuccoing":"stucco",
"stuccos":"stucco",
"studded":"stud",
"studding":"stud",
"studs":"stud",
"students":"student",
"studhorses":"studhorse",
"studios":"studio",
"studied":"study",
"studies":"study",
"studying":"study",
"studyings":"studying",
"stuffed":"stuff",
"stuffing":"stuff",
"stuffs":"stuff",
"stuffinesses":"stuffiness",
"stuffings":"stuffing",
"stuffier":"stuffy",
"stuffiest":"stuffy",
"stultifications":"stultification",
"stultified":"stultify",
"stultifies":"stultify",
"stultifying":"stultify",
"stummed":"stum",
"stumming":"stum",
"stums":"stum",
"stumbled":"stumble",
"stumbles":"stumble",
"stumbling":"stumble",
"stumblebums":"stumblebum",
"stumped":"stump",
"stumping":"stump",
"stumps":"stump",
"stumpers":"stumper",
"stumpknockers":"stumpknocker",
"stumpier":"stumpy",
"stumpiest":"stumpy",
"stunning":"stun",
"stuns":"stun",
"stunners":"stunner",
"stunted":"stunt",
"stunting":"stunt",
"stunts":"stunt",
"stuntednesses":"stuntedness",
"stuntings":"stunting",
"stupas":"stupa",
"stupefactions":"stupefaction",
"stupefied":"stupefy",
"stupefies":"stupefy",
"stupefying":"stupefy",
"stupider":"stupid",
"stupidest":"stupid",
"stupids":"stupid",
"stupidities":"stupidity",
"stupors":"stupor",
"sturdier":"sturdy",
"sturdiest":"sturdy",
"sturgeons":"sturgeon",
"sturnellas":"sturnella",
"sturnidaes":"sturnidae",
"sturnuses":"sturnus",
"stuttered":"stutter",
"stuttering":"stutter",
"stutters":"stutter",
"stutterers":"stutterer",
"stied":"sty",
"sties":"sty",
"stying":"sty",
"styes":"stye",
"styles":"style",
"styling":"style",
"stylemarks":"stylemark",
"stylisations":"stylisation",
"stylishnesses":"stylishness",
"stylists":"stylist",
"stylizations":"stylization",
"stylized":"stylize",
"stylizes":"stylize",
"stylizing":"stylize",
"stylomecons":"stylomecon",
"stylophorums":"stylophorum",
"stylopodia":"stylopodium",
"stylopes":"stylops",
"stylostixes":"stylostixis",
"styli":"stylus",
"styluses":"stylus",
"stymied":"stymie",
"stymieing":"stymie",
"stymies":"stymie",
"stymying":"stymie",
"styphelias":"styphelia",
"stypses":"stypsis",
"styptics":"styptic",
"styracaceaes":"styracaceae",
"styracosaurs":"styracosaur",
"styracosauruses":"styracosaurus",
"styrenes":"styrene",
"styxes":"styx",
"suasions":"suasion",
"suaver":"suave",
"suavest":"suave",
"suavenesses":"suaveness",
"suavities":"suavity",
"subbed":"sub",
"subbing":"sub",
"subs":"sub",
"subassemblies":"subassembly",
"subbings":"subbing",
"subconsciouses":"subconscious",
"subcontracted":"subcontract",
"subcontracting":"subcontract",
"subcontracts":"subcontract",
"subcontraries":"subcontrary",
"subcortices":"subcortex",
"subdelirliria":"subdelirium",
"subdelirliriums":"subdelirium",
"subdivided":"subdivide",
"subdivides":"subdivide",
"subdividing":"subdivide",
"subdivisions":"subdivision",
"subducted":"subduct",
"subducting":"subduct",
"subdued":"subdue",
"subdues":"subdue",
"subduing":"subdue",
"subduednesses":"subduedness",
"subedited":"subedit",
"subediting":"subedit",
"subedits":"subedit",
"subfamilies":"subfamily",
"subgegenera":"subgenus",
"subgegenuses":"subgenus",
"subgenera":"subgenus",
"subgenuses":"subgenus",
"subheads":"subhead",
"subheadings":"subheading",
"subindexes":"subindex",
"subindices":"subindex",
"subjected":"subject",
"subjecting":"subject",
"subjects":"subject",
"subjectified":"subjectify",
"subjectifies":"subjectify",
"subjectifying":"subjectify",
"subjections":"subjection",
"subjectivenesses":"subjectiveness",
"subjectivities":"subjectivity",
"subjoined":"subjoin",
"subjoining":"subjoin",
"subjoinings":"subjoining",
"subjugated":"subjugate",
"subjugates":"subjugate",
"subjugating":"subjugate",
"subjugations":"subjugation",
"subjunctions":"subjunction",
"subjunctives":"subjunctive",
"subleased":"sublease",
"subleases":"sublease",
"subleasing":"sublease",
"sublets":"sublet",
"subletting":"sublet",
"sublimed":"sublime",
"sublimer":"sublime",
"sublimest":"sublime",
"subliming":"sublime",
"sublimities":"sublimity",
"submarined":"submarine",
"submarines":"submarine",
"submarining":"submarine",
"submaxillas":"submaxilla",
"submenus":"submenu",
"submerged":"submerge",
"submerges":"submerge",
"submerging":"submerge",
"submergences":"submergence",
"submergings":"submerging",
"submersed":"submerse",
"submersing":"submerse",
"submersions":"submersion",
"submissions":"submission",
"submits":"submit",
"submitted":"submit",
"submitting":"submit",
"submucocosae":"submucosa",
"subnormalities":"subnormality",
"subordinaries":"subordinary",
"subordinated":"subordinate",
"subordinates":"subordinate",
"subordinating":"subordinate",
"subordinatenesses":"subordinateness",
"subordinations":"subordination",
"suborned":"suborn",
"suborning":"suborn",
"suborners":"suborner",
"subpenaed":"subpena",
"subpenaing":"subpena",
"subpenas":"subpena",
"subphyla":"subphylum",
"subpoenaed":"subpoena",
"subpoenaing":"subpoena",
"subpoenas":"subpoena",
"subprograms":"subprogram",
"subrogated":"subrogate",
"subrogating":"subrogate",
"subroutines":"subroutine",
"subscribed":"subscribe",
"subscribes":"subscribe",
"subscribing":"subscribe",
"subscribers":"subscriber",
"subscripts":"subscript",
"subscriptions":"subscription",
"subsections":"subsection",
"subsequences":"subsequence",
"subsequentnesses":"subsequentness",
"subserved":"subserve",
"subserving":"subserve",
"subserviences":"subservience",
"subservientnesses":"subservientness",
"subshrubs":"subshrub",
"subsided":"subside",
"subsides":"subside",
"subsiding":"subside",
"subsidences":"subsidence",
"subsidiarities":"subsidiarity",
"subsidiaries":"subsidiary",
"subsidings":"subsiding",
"subsidisations":"subsidisation",
"subsidizations":"subsidization",
"subsidized":"subsidize",
"subsidizing":"subsidize",
"subsidies":"subsidy",
"subsisted":"subsist",
"subsisting":"subsist",
"subsists":"subsist",
"subsoils":"subsoil",
"subspecieses":"subspecies",
"substances":"substance",
"substantials":"substantial",
"substantialities":"substantiality",
"substantialnesses":"substantialness",
"substantiated":"substantiate",
"substantiates":"substantiate",
"substantiating":"substantiate",
"substantiations":"substantiation",
"substitutabilities":"substitutability",
"substituted":"substitute",
"substitutes":"substitute",
"substituting":"substitute",
"substitutings":"substituting",
"substitutions":"substitution",
"substrates":"substrate",
"substrata":"substratum",
"substratums":"substratum",
"substructures":"substructure",
"subsumed":"subsume",
"subsumes":"subsume",
"subsuming":"subsume",
"subsumings":"subsuming",
"subsumptions":"subsumption",
"subtended":"subtend",
"subtending":"subtend",
"subtends":"subtend",
"subterfuges":"subterfuge",
"subterraneans":"subterranean",
"subtilized":"subtilize",
"subtilizes":"subtilize",
"subtilizing":"subtilize",
"subtitled":"subtitle",
"subtitles":"subtitle",
"subtitling":"subtitle",
"subtler":"subtle",
"subtlest":"subtle",
"subtleties":"subtlety",
"subtonics":"subtonic",
"subtotaled":"subtotal",
"subtotaling":"subtotal",
"subtotalled":"subtotal",
"subtotalling":"subtotal",
"subtotals":"subtotal",
"subtracted":"subtract",
"subtracting":"subtract",
"subtracts":"subtract",
"subtractions":"subtraction",
"subtreasuries":"subtreasury",
"subtropicses":"subtropics",
"subularias":"subularia",
"subunits":"subunit",
"suburbs":"suburb",
"suburbanites":"suburbanite",
"suburbias":"suburbia",
"subvened":"subvene",
"subvening":"subvene",
"subversions":"subversion",
"subversives":"subversive",
"subversivenesses":"subversiveness",
"subverted":"subvert",
"subverting":"subvert",
"subverts":"subvert",
"subverters":"subverter",
"subwayed":"subway",
"subwaying":"subway",
"subways":"subway",
"succedanea":"succedaneum",
"succeeded":"succeed",
"succeeding":"succeed",
"succeeds":"succeed",
"successes":"success",
"successfulnesses":"successfulness",
"successions":"succession",
"successivenesses":"successiveness",
"successors":"successor",
"succinctnesses":"succinctness",
"succored":"succor",
"succoring":"succor",
"succors":"succor",
"succories":"succory",
"succoses":"succos",
"succoured":"succour",
"succouring":"succour",
"succours":"succour",
"succubas":"succuba",
"succubi":"succubus",
"succubuses":"succubus",
"succulences":"succulence",
"succumbed":"succumb",
"succumbing":"succumb",
"succumbs":"succumb",
"succuses":"succus",
"sucked":"suck",
"sucking":"suck",
"sucks":"suck",
"suckered":"sucker",
"suckering":"sucker",
"suckers":"sucker",
"suckerfishes":"suckerfish",
"suckfishes":"suckfish",
"suckings":"sucking",
"suckled":"suckle",
"suckles":"suckle",
"suckling":"suckle",
"sucklings":"suckling",
"sucralfates":"sucralfate",
"sucroses":"sucrose",
"suctions":"suction",
"sudans":"sudan",
"sudardaria":"sudarium",
"sudatoria":"sudatorium",
"sudatotoria":"sudatorium",
"sudatories":"sudatory",
"suddennesses":"suddenness",
"sudors":"sudor",
"sudras":"sudra",
"sudses":"suds",
"sudsier":"sudsy",
"sudsiest":"sudsy",
"sued":"sue",
"sues":"sue",
"suing":"sue",
"suedes":"suede",
"suffered":"suffer",
"suffering":"suffer",
"suffers":"suffer",
"sufferances":"sufferance",
"sufferers":"sufferer",
"sufferings":"suffering",
"sufficed":"suffice",
"suffices":"suffice",
"sufficing":"suffice",
"sufficiencies":"sufficiency",
"suffixed":"suffix",
"suffixes":"suffix",
"suffixing":"suffix",
"suffocated":"suffocate",
"suffocates":"suffocate",
"suffocating":"suffocate",
"suffocations":"suffocation",
"suffragans":"suffragan",
"suffrages":"suffrage",
"suffragettes":"suffragette",
"suffragists":"suffragist",
"suffrutexes":"suffrutex",
"suffused":"suffuse",
"suffuses":"suffuse",
"suffusing":"suffuse",
"suffusions":"suffusion",
"Sufis":"Sufi",
"sugared":"sugar",
"sugaring":"sugar",
"sugars":"sugar",
"sugar-bushes":"sugar-bush",
"sugar-coated":"sugar-coat",
"sugar-coating":"sugar-coat",
"sugarberries":"sugarberry",
"sugarcanes":"sugarcane",
"sugargerries":"sugargerry",
"sugarhouses":"sugarhouse",
"sugarinesses":"sugariness",
"sugarloaves":"sugarloaf",
"sugarier":"sugary",
"sugariest":"sugary",
"suggested":"suggest",
"suggesting":"suggest",
"suggests":"suggest",
"suggestions":"suggestion",
"sugis":"sugi",
"suicided":"suicide",
"suicides":"suicide",
"suiciding":"suicide",
"suidaes":"suidae",
"suilluses":"suillus",
"suings":"suing",
"suisses":"suisse",
"suited":"suit",
"suiting":"suit",
"suits":"suit",
"suitabilities":"suitability",
"suitablenesses":"suitableness",
"suitcases":"suitcase",
"suites":"suite",
"suitors":"suitor",
"sukkoths":"sukkoth",
"sulas":"sula",
"sulamyds":"sulamyd",
"sulawesis":"sulawesi",
"sulci":"sulcus",
"sulfas":"sulfa",
"sulfacetamides":"sulfacetamide",
"sulfamethazines":"sulfamethazine",
"sulfamezathines":"sulfamezathine",
"sulfated":"sulfate",
"sulfates":"sulfate",
"sulfating":"sulfate",
"sulfides":"sulfide",
"sulfonamides":"sulfonamide",
"sulfured":"sulfur",
"sulfuring":"sulfur",
"sulfurs":"sulfur",
"sulidaes":"sulidae",
"sulindacs":"sulindac",
"sulked":"sulk",
"sulking":"sulk",
"sulks":"sulk",
"sulkinesses":"sulkiness",
"sulkier":"sulky",
"sulkies":"sulky",
"sulkiest":"sulky",
"sullas":"sulla",
"sullener":"sullen",
"sullenest":"sullen",
"sullennesses":"sullenness",
"sullivans":"sullivan",
"sullied":"sully",
"sullies":"sully",
"sullying":"sully",
"sulphas":"sulpha",
"sulphates":"sulphate",
"sulphides":"sulphide",
"sulphurs":"sulphur",
"sulphureted":"sulphuret",
"sulphureting":"sulphuret",
"sulphurets":"sulphuret",
"sulphuretted":"sulphuret",
"sulphuretting":"sulphuret",
"sultans":"sultan",
"sultanas":"sultana",
"sultrier":"sultry",
"sultriest":"sultry",
"summed":"sum",
"summing":"sum",
"sums":"sum",
"sumacs":"sumac",
"sumaches":"sumach",
"summae":"summa",
"summas":"summa",
"summarizations":"summarization",
"summarized":"summarize",
"summarizes":"summarize",
"summarizing":"summarize",
"summaries":"summary",
"summations":"summation",
"summered":"summer",
"summering":"summer",
"summers":"summer",
"summerhouses":"summerhouse",
"summertimes":"summertime",
"summits":"summit",
"summiteers":"summiteer",
"summitries":"summitry",
"summoned":"summon",
"summoning":"summon",
"summons":"summon",
"summonings":"summoning",
"summonsed":"summons",
"summonses":"summons",
"summonsing":"summons",
"sumps":"sump",
"sumpters":"sumpter",
"sumptuosities":"sumptuosity",
"sumptuousnesses":"sumptuousness",
"sunned":"sun",
"sunning":"sun",
"suns":"sun",
"sun-bathed":"sun-bathe",
"sun-bathing":"sun-bathe",
"sun-worships":"sun-worship",
"sunbaths":"sunbath",
"sunbeams":"sunbeam",
"sunberries":"sunberry",
"sunblinds":"sunblind",
"sunbonnets":"sunbonnet",
"sunburned":"sunburn",
"sunburning":"sunburn",
"sunburns":"sunburn",
"sunburnt":"sunburn",
"sunchokes":"sunchoke",
"sundacarpuses":"sundacarpus",
"sundaes":"sundae",
"Sundays":"Sunday",
"sundered":"sunder",
"sundering":"sunder",
"sundews":"sundew",
"sundogs":"sundog",
"sundowns":"sundown",
"sundowners":"sundowner",
"sundrieses":"sundries",
"sundropses":"sundrops",
"sundries":"sundry",
"sunfishes":"sunfish",
"sunflowers":"sunflower",
"sunglasses":"sunglass",
"sunglasseses":"sunglasses",
"sunhats":"sunhat",
"sunlamps":"sunlamp",
"sunlights":"sunlight",
"sunnis":"sunni",
"sunnites":"sunnite",
"sunnier":"sunny",
"sunniest":"sunny",
"sunrays":"sunray",
"sunrises":"sunrise",
"sunroofs":"sunroof",
"sunrooms":"sunroom",
"sunroses":"sunrose",
"sunsets":"sunset",
"sunshades":"sunshade",
"sunshines":"sunshine",
"sunshine-roofs":"sunshine-roof",
"sunspots":"sunspot",
"sunstones":"sunstone",
"sunstrokes":"sunstroke",
"suntans":"suntan",
"suntraps":"suntrap",
"sunups":"sunup",
"suomis":"suomi",
"supped":"sup",
"supping":"sup",
"sups":"sup",
"supers":"super",
"superabounded":"superabound",
"superabounding":"superabound",
"superabundances":"superabundance",
"superadded":"superadd",
"superadding":"superadd",
"superannuated":"superannuate",
"superannuating":"superannuate",
"superannuations":"superannuation",
"superbias":"superbia",
"superbugs":"superbug",
"supercargoes":"supercargo",
"supercargos":"supercargo",
"supercharged":"supercharge",
"supercharges":"supercharge",
"supercharging":"supercharge",
"superciliousnesses":"superciliousness",
"superciliums":"supercilium",
"supercooled":"supercool",
"supercooling":"supercool",
"superegos":"superego",
"supererogated":"supererogate",
"supererogating":"supererogate",
"superfamilies":"superfamily",
"superficialities":"superficiality",
"superfluities":"superfluity",
"superfused":"superfuse",
"superfusing":"superfuse",
"superheated":"superheat",
"superheating":"superheat",
"superheroes":"superhero",
"superhets":"superhet",
"superhighways":"superhighway",
"superimposed":"superimpose",
"superimposes":"superimpose",
"superimposing":"superimpose",
"superinduced":"superinduce",
"superinducing":"superinduce",
"superintended":"superintend",
"superintending":"superintend",
"superintends":"superintend",
"superintendences":"superintendence",
"superintendencies":"superintendency",
"superintendents":"superintendent",
"superiors":"superior",
"superiorities":"superiority",
"superlatives":"superlative",
"superloads":"superload",
"supermen":"superman",
"supermarkets":"supermarket",
"supermolecules":"supermolecule",
"supernaturals":"supernatural",
"supernaturalisms":"supernaturalism",
"supernaturalists":"supernaturalist",
"supernaturalnesses":"supernaturalness",
"supernovae":"supernova",
"supernovas":"supernova",
"supernumeraries":"supernumerary",
"superordinated":"superordinate",
"superordinates":"superordinate",
"superordinating":"superordinate",
"superordinations":"superordination",
"superpatriotisms":"superpatriotism",
"superposed":"superpose",
"superposing":"superpose",
"superpowers":"superpower",
"supersaturated":"supersaturate",
"supersaturating":"supersaturate",
"superscribed":"superscribe",
"superscribing":"superscribe",
"superscripts":"superscript",
"superseded":"supersede",
"supersedes":"supersede",
"superseding":"supersede",
"supersedures":"supersedure",
"supersessions":"supersession",
"superslashers":"superslasher",
"superstitions":"superstition",
"superstrata":"superstratum",
"superstratums":"superstratum",
"supertaxes":"supertax",
"supertitles":"supertitle",
"supervened":"supervene",
"supervening":"supervene",
"supervised":"supervise",
"supervises":"supervise",
"supervising":"supervise",
"supervisings":"supervising",
"supervisions":"supervision",
"supervisors":"supervisor",
"superwomen":"superwoman",
"suppers":"supper",
"suppertimes":"suppertime",
"supplanted":"supplant",
"supplanting":"supplant",
"supplants":"supplant",
"supplanters":"supplanter",
"supplantings":"supplanting",
"suppled":"supple",
"suppler":"supple",
"supplest":"supple",
"suppling":"supple",
"supplemented":"supplement",
"supplementing":"supplement",
"supplements":"supplement",
"supplementaries":"supplementary",
"supplementations":"supplementation",
"supplenesses":"suppleness",
"suppliants":"suppliant",
"supplicants":"supplicant",
"supplicated":"supplicate",
"supplicating":"supplicate",
"supplications":"supplication",
"suppliers":"supplier",
"supplieses":"supplies",
"supplied":"supply",
"supplies":"supply",
"supplying":"supply",
"supplyings":"supplying",
"supported":"support",
"supporting":"support",
"supports":"support",
"supporters":"supporter",
"supportings":"supporting",
"supposals":"supposal",
"supposes":"suppose",
"supposing":"suppose",
"suppositions":"supposition",
"suppositories":"suppository",
"suppressed":"suppress",
"suppresses":"suppress",
"suppressing":"suppress",
"suppressers":"suppresser",
"suppressions":"suppression",
"suppressors":"suppressor",
"suppurated":"suppurate",
"suppurates":"suppurate",
"suppurating":"suppurate",
"suppurations":"suppuration",
"suprarenalectomies":"suprarenalectomy",
"supremacies":"supremacy",
"supremos":"supremo",
"suras":"sura",
"surceased":"surcease",
"surceases":"surcease",
"surceasing":"surcease",
"surcharged":"surcharge",
"surcharges":"surcharge",
"surcharging":"surcharge",
"surcoats":"surcoat",
"surds":"surd",
"surer":"sure",
"surest":"sure",
"surenesses":"sureness",
"sureties":"surety",
"surfed":"surf",
"surfing":"surf",
"surfs":"surf",
"surves":"surf",
"surfaced":"surface",
"surfaces":"surface",
"surfacing":"surface",
"surfactants":"surfactant",
"surfbirds":"surfbird",
"surfboarded":"surfboard",
"surfboarding":"surfboard",
"surfboarders":"surfboarder",
"surfboardings":"surfboarding",
"surfeited":"surfeit",
"surfeiting":"surfeit",
"surfeits":"surfeit",
"surfers":"surfer",
"surffishes":"surffish",
"surfings":"surfing",
"surfperches":"surfperch",
"surfridings":"surfriding",
"surfier":"surfy",
"surfiest":"surfy",
"surged":"surge",
"surges":"surge",
"surging":"surge",
"surgeons":"surgeon",
"surgeoncies":"surgeoncy",
"surgeonfishes":"surgeonfish",
"surgeries":"surgery",
"suricatas":"suricata",
"suricates":"suricate",
"surinams":"surinam",
"surinames":"suriname",
"surlinesses":"surliness",
"surlier":"surly",
"surliest":"surly",
"surmised":"surmise",
"surmises":"surmise",
"surmising":"surmise",
"surmounted":"surmount",
"surmounting":"surmount",
"surmounts":"surmount",
"surmullets":"surmullet",
"surnamed":"surname",
"surnames":"surname",
"surnaming":"surname",
"surnias":"surnia",
"surpassed":"surpass",
"surpasses":"surpass",
"surpassing":"surpass",
"surpluses":"surplus",
"surplusages":"surplusage",
"surprints":"surprint",
"surprisals":"surprisal",
"surprises":"surprise",
"surprising":"surprise",
"surprisings":"surprising",
"surprisingnesses":"surprisingness",
"surrebuttals":"surrebuttal",
"surrebutters":"surrebutter",
"surrendered":"surrender",
"surrendering":"surrender",
"surrenders":"surrender",
"surrogates":"surrogate",
"surrounded":"surround",
"surrounding":"surround",
"surrounds":"surround",
"surroundings":"surrounding",
"surroundingses":"surroundings",
"surtaxed":"surtax",
"surtaxes":"surtax",
"surtaxing":"surtax",
"surtitles":"surtitle",
"surveyed":"survey",
"surveying":"survey",
"surveys":"survey",
"surveyors":"surveyor",
"survivals":"survival",
"survived":"survive",
"survives":"survive",
"surviving":"survive",
"survivors":"survivor",
"suses":"sus",
"susceptibilities":"susceptibility",
"susceptiblenesses":"susceptibleness",
"susians":"susian",
"susliks":"suslik",
"suspecting":"suspect",
"suspects":"suspect",
"suspended":"suspend",
"suspending":"suspend",
"suspends":"suspend",
"suspenders":"suspender",
"suspensions":"suspension",
"suspensors":"suspensor",
"suspensories":"suspensory",
"suspicioned":"suspicion",
"suspicioning":"suspicion",
"suspicions":"suspicion",
"suspiciousnesses":"suspiciousness",
"susquehannas":"susquehanna",
"sussos":"susso",
"sustaining":"sustain",
"sustains":"sustain",
"sustainments":"sustainment",
"sustenances":"sustenance",
"sustentations":"sustentation",
"susus":"susu",
"sutlers":"sutler",
"sutras":"sutra",
"suturas":"sutura",
"sutured":"suture",
"sutures":"suture",
"suturing":"suture",
"suzerainties":"suzerainty",
"svelter":"svelte",
"sveltest":"svelte",
"sveriges":"sverige",
"svizzeras":"svizzera",
"sws":"sw",
"swabbed":"swab",
"swabbing":"swab",
"swabs":"swab",
"swabbings":"swabbing",
"swaddled":"swaddle",
"swaddles":"swaddle",
"swaddling":"swaddle",
"swagged":"swag",
"swagging":"swag",
"swags":"swag",
"swaged":"swage",
"swages":"swage",
"swaging":"swage",
"swaggered":"swagger",
"swaggering":"swagger",
"swaggers":"swagger",
"swagmen":"swagman",
"swahilis":"swahili",
"swains":"swain",
"swainsonas":"swainsona",
"swallowed":"swallow",
"swallowing":"swallow",
"swallows":"swallow",
"swallowtails":"swallowtail",
"swallowworts":"swallowwort",
"swamies":"swami",
"swamis":"swami",
"swamped":"swamp",
"swamping":"swamp",
"swamps":"swamp",
"swamphens":"swamphen",
"swampier":"swampy",
"swampiest":"swampy",
"swanned":"swan",
"swanning":"swan",
"swans":"swan",
"swanflowers":"swanflower",
"swanked":"swank",
"swanker":"swank",
"swankest":"swank",
"swanking":"swank",
"swanks":"swank",
"swankier":"swanky",
"swankiest":"swanky",
"swannecks":"swanneck",
"swanneries":"swannery",
"swapped":"swap",
"swapping":"swap",
"swaps":"swap",
"swards":"sward",
"swarmed":"swarm",
"swarming":"swarm",
"swarms":"swarm",
"swarthinesses":"swarthiness",
"swarthier":"swarthy",
"swarthiest":"swarthy",
"swashed":"swash",
"swashes":"swash",
"swashing":"swash",
"swashbucklers":"swashbuckler",
"swastikas":"swastika",
"swats":"swat",
"swatted":"swat",
"swatting":"swat",
"swaths":"swath",
"swathed":"swathe",
"swathes":"swathe",
"swathing":"swathe",
"swatters":"swatter",
"swayed":"sway",
"swaying":"sway",
"sways":"sway",
"swazis":"swazi",
"swbses":"swbs",
"swbws":"swbw",
"swearing":"swear",
"swears":"swear",
"swore":"swear",
"sworn":"swear",
"swearers":"swearer",
"swearings":"swearing",
"swearwords":"swearword",
"sweated":"sweat",
"sweating":"sweat",
"sweats":"sweat",
"sweaters":"sweater",
"sweatings":"sweating",
"sweatses":"sweats",
"sweatshops":"sweatshop",
"sweatier":"sweaty",
"sweatiest":"sweaty",
"swedes":"swede",
"swedens":"sweden",
"sweeping":"sweep",
"sweeps":"sweep",
"swept":"sweep",
"sweep-seconds":"sweep-second",
"sweepers":"sweeper",
"sweepings":"sweeping",
"sweepstakes":"sweepstake",
"sweepstakeses":"sweepstakes",
"sweeter":"sweet",
"sweetest":"sweet",
"sweets":"sweet",
"sweet-talked":"sweet-talk",
"sweet-talking":"sweet-talk",
"sweet-talks":"sweet-talk",
"sweetbreads":"sweetbread",
"sweetbreadses":"sweetbreads",
"sweetbriars":"sweetbriar",
"sweetbriers":"sweetbrier",
"sweetened":"sweeten",
"sweetening":"sweeten",
"sweetens":"sweeten",
"sweeteners":"sweetener",
"sweetenings":"sweetening",
"sweethearted":"sweetheart",
"sweethearting":"sweetheart",
"sweethearts":"sweetheart",
"sweeties":"sweetie",
"sweetiewives":"sweetiewife",
"sweetleaves":"sweetleaf",
"sweetmen":"sweetman",
"sweetnesses":"sweetness",
"sweetpeas":"sweetpea",
"sweetsops":"sweetsop",
"swelled":"swell",
"sweller":"swell",
"swellest":"swell",
"swelling":"swell",
"swells":"swell",
"swollen":"swell",
"swellfishes":"swellfish",
"swellheads":"swellhead",
"swellings":"swelling",
"sweltered":"swelter",
"sweltering":"swelter",
"swertias":"swertia",
"swerved":"swerve",
"swerves":"swerve",
"swerving":"swerve",
"swervings":"swerving",
"swietinias":"swietinia",
"swifter":"swift",
"swiftest":"swift",
"swifts":"swift",
"swiftlets":"swiftlet",
"swiftnesses":"swiftness",
"swigged":"swig",
"swigging":"swig",
"swigs":"swig",
"swilled":"swill",
"swilling":"swill",
"swills":"swill",
"swillings":"swilling",
"swam":"swim",
"swimming":"swim",
"swims":"swim",
"swum":"swim",
"swimmers":"swimmer",
"swimmerets":"swimmeret",
"swimmings":"swimming",
"swimsuits":"swimsuit",
"swindled":"swindle",
"swindles":"swindle",
"swindling":"swindle",
"swindlers":"swindler",
"swineherds":"swineherd",
"swinging":"swing",
"swings":"swing",
"swung":"swing",
"swinged":"swinge",
"swingeing":"swinge",
"swinges":"swinge",
"swingings":"swinging",
"swingled":"swingle",
"swingling":"swingle",
"swingletrees":"swingletree",
"swank":"swink",
"swinking":"swink",
"swonk":"swink",
"swonken":"swink",
"swiped":"swipe",
"swipes":"swipe",
"swiping":"swipe",
"swirled":"swirl",
"swirling":"swirl",
"swirls":"swirl",
"swirlier":"swirly",
"swirliest":"swirly",
"swished":"swish",
"swishes":"swish",
"swishing":"swish",
"swisses":"swiss",
"switched":"switch",
"switches":"switch",
"switching":"switch",
"switch-ivies":"switch-ivy",
"switchblades":"switchblade",
"switchboards":"switchboard",
"switchings":"switching",
"switchmen":"switchman",
"swithers":"swither",
"switzerlands":"switzerland",
"swiveled":"swivel",
"swiveling":"swivel",
"swivelled":"swivel",
"swivelling":"swivel",
"swivels":"swivel",
"swobs":"swob",
"swooned":"swoon",
"swooning":"swoon",
"swoons":"swoon",
"swooped":"swoop",
"swooping":"swoop",
"swoops":"swoop",
"swooshed":"swoosh",
"swooshing":"swoosh",
"swops":"swop",
"swords":"sword",
"swordfishes":"swordfish",
"swordmen":"swordman",
"swordplays":"swordplay",
"swordsmen":"swordsman",
"swordtails":"swordtail",
"swots":"swot",
"swotted":"swot",
"swotting":"swot",
"sybarites":"sybarite",
"sycamores":"sycamore",
"syconia":"syconium",
"sycophants":"sycophant",
"sycoses":"sycosis",
"syllabaries":"syllabary",
"syllabicated":"syllabicate",
"syllabicates":"syllabicate",
"syllabicating":"syllabicate",
"syllabications":"syllabication",
"syllabifications":"syllabification",
"syllabified":"syllabify",
"syllabifies":"syllabify",
"syllabifying":"syllabify",
"syllabled":"syllable",
"syllables":"syllable",
"syllabling":"syllable",
"syllabubs":"syllabub",
"syllabi":"syllabus",
"syllabuses":"syllabus",
"syllepses":"syllepsis",
"sylvas":"sylva",
"sylvans":"sylvan",
"sylvanites":"sylvanite",
"sylvanuses":"sylvanus",
"sylviidaes":"sylviidae",
"sylviinaes":"sylviinae",
"sylvilaguses":"sylvilagus",
"sylvines":"sylvine",
"sylvites":"sylvite",
"symbioses":"symbiosis",
"symbols":"symbol",
"symbol-worships":"symbol-worship",
"symbolatries":"symbolatry",
"symbolizations":"symbolization",
"symbolized":"symbolize",
"symbolizes":"symbolize",
"symbolizing":"symbolize",
"symbolizings":"symbolizing",
"symbololatries":"symbololatry",
"symmetricalnesses":"symmetricalness",
"symmetrized":"symmetrize",
"symmetrizing":"symmetrize",
"symmetries":"symmetry",
"sympathectomies":"sympathectomy",
"sympathized":"sympathize",
"sympathizes":"sympathize",
"sympathizing":"sympathize",
"sympathizers":"sympathizer",
"sympathies":"sympathy",
"symphalanguses":"symphalangus",
"symphilids":"symphilid",
"symphonies":"symphony",
"symphoricarposes":"symphoricarpos",
"symphylas":"symphyla",
"symphyses":"symphysis",
"symphytums":"symphytum",
"symplocaceaes":"symplocaceae",
"symplocarpuses":"symplocarpus",
"symplocuses":"symplocus",
"sympodia":"sympodium",
"symposia":"symposium",
"symposiums":"symposium",
"symptoms":"symptom",
"synaereses":"synaeresis",
"synaesthesias":"synaesthesia",
"synagogues":"synagogue",
"synagropses":"synagrops",
"synancejas":"synanceja",
"synapsids":"synapsid",
"synapsidas":"synapsida",
"synapses":"synapsis",
"synaptomyses":"synaptomys",
"synarchies":"synarchy",
"synarthroses":"synarthrosis",
"syncarps":"syncarp",
"synchros":"synchro",
"synchroneities":"synchroneity",
"synchronicities":"synchronicity",
"synchronisations":"synchronisation",
"synchronisings":"synchronising",
"synchronisms":"synchronism",
"synchronizations":"synchronization",
"synchronized":"synchronize",
"synchronizes":"synchronize",
"synchronizing":"synchronize",
"synchronizings":"synchronizing",
"synchronies":"synchrony",
"synchytriaceaes":"synchytriaceae",
"synchytriums":"synchytrium",
"synclinoria":"synclinorium",
"syncopated":"syncopate",
"syncopating":"syncopate",
"syncopations":"syncopation",
"syncopes":"syncope",
"syncretized":"syncretize",
"syncretizing":"syncretize",
"syncytcytia":"syncytium",
"syndactylisms":"syndactylism",
"syndactylies":"syndactyly",
"syndesmoses":"syndesmosis",
"syndicalists":"syndicalist",
"syndicated":"syndicate",
"syndicates":"syndicate",
"syndicating":"syndicate",
"synentognathis":"synentognathi",
"synercuses":"synercus",
"synereses":"syneresis",
"synergisms":"synergism",
"synergies":"synergy",
"synesthesias":"synesthesia",
"synezeses":"synezesis",
"syngnathidaes":"syngnathidae",
"syngnathuses":"syngnathus",
"syngoniums":"syngonium",
"synizeses":"synizesis",
"synodontidaes":"synodontidae",
"synonyms":"synonym",
"synonymities":"synonymity",
"synonymousnesses":"synonymousness",
"synonymies":"synonymy",
"synopses":"synopsis",
"synopsises":"synopsis",
"synopsized":"synopsize",
"synopsizing":"synopsize",
"synovias":"synovia",
"synoviums":"synovium",
"syntacticians":"syntactician",
"syntagms":"syntagm",
"syntagmata":"syntagma",
"syntagtagmata":"syntagma",
"syntaxes":"syntax",
"syntheses":"synthesis",
"synthesises":"synthesise",
"synthesized":"synthesize",
"synthesizes":"synthesize",
"synthesizing":"synthesize",
"synthetics":"synthetic",
"syphs":"syph",
"syphilises":"syphilis",
"syphilomas":"syphiloma",
"syphilomata":"syphiloma",
"syphoned":"syphon",
"syphoning":"syphon",
"syphons":"syphon",
"syracuses":"syracuse",
"syringas":"syringa",
"syringed":"syringe",
"syringing":"syringe",
"syringes":"syringe",
"syrinxes":"syrinx",
"syrrhapteses":"syrrhaptes",
"syrups":"syrup",
"syssarcoses":"syssarcosis",
"systems":"system",
"systematisations":"systematisation",
"systematizations":"systematization",
"systematized":"systematize",
"systematizes":"systematize",
"systematizing":"systematize",
"systemized":"systemize",
"systemizes":"systemize",
"systemizing":"systemize",
"syzygiums":"syzygium",
"syzygies":"syzygy",
"szechuans":"szechuan",
"szechwans":"szechwan",
"ts":"t",
"t-bills":"t-bill",
"T-men":"T-man",
"t-scopes":"t-scope",
"t-shirts":"t-shirt",
"tas":"ta",
"taals":"taal",
"tabbed":"tab",
"tabbing":"tab",
"tabs":"tab",
"tabanidaes":"tabanidae",
"tabascos":"tabasco",
"tabboulehs":"tabbouleh",
"tabbied":"tabby",
"tabbies":"tabby",
"tabbying":"tabby",
"tabernacled":"tabernacle",
"tabernacles":"tabernacle",
"tabernacling":"tabernacle",
"tabernacleses":"tabernacles",
"tabernaemontanas":"tabernaemontana",
"tabis":"tabi",
"tabises":"tabis",
"tablas":"tabla",
"tabled":"table",
"tables":"table",
"tabling":"table",
"tableaus":"tableau",
"tableaux":"tableau",
"tablecloths":"tablecloth",
"tablelands":"tableland",
"tablemates":"tablemate",
"tablespoons":"tablespoon",
"tablespoonfuls":"tablespoonful",
"tablets":"tablet",
"tabloids":"tabloid",
"tabooed":"taboo",
"tabooing":"taboo",
"taboos":"taboo",
"taboolis":"tabooli",
"tabors":"tabor",
"taborets":"taboret",
"tabours":"tabour",
"tabourets":"tabouret",
"tabus":"tabu",
"tabulated":"tabulate",
"tabulates":"tabulate",
"tabulating":"tabulate",
"tabulations":"tabulation",
"tabulators":"tabulator",
"tacamahacs":"tacamahac",
"taccas":"tacca",
"taccaceaes":"taccaceae",
"taches":"tach",
"tacheometers":"tacheometer",
"tachinidaes":"tachinidae",
"tachistoscopes":"tachistoscope",
"tachometers":"tachometer",
"tachyglossidaes":"tachyglossidae",
"tachyglossuses":"tachyglossus",
"tachymeters":"tachymeter",
"tachypleuses":"tachypleus",
"taciturnities":"taciturnity",
"tacked":"tack",
"tacking":"tack",
"tacks":"tack",
"tackers":"tacker",
"tackinesses":"tackiness",
"tackings":"tacking",
"tackled":"tackle",
"tackles":"tackle",
"tackling":"tackle",
"tacklings":"tackling",
"tackier":"tacky",
"tackiest":"tacky",
"tacos":"taco",
"tacts":"tact",
"tactfulnesses":"tactfulness",
"tactics":"tactic",
"tactilities":"tactility",
"tadaridas":"tadarida",
"tadjiks":"tadjik",
"tadornas":"tadorna",
"tadpoles":"tadpole",
"tadzhiks":"tadzhik",
"tadzhikistans":"tadzhikistan",
"taegus":"taegu",
"taeniae":"taenia",
"taenias":"taenia",
"taeniidaes":"taeniidae",
"taffies":"taffy",
"tafts":"taft",
"tagged":"tag",
"tagging":"tag",
"tags":"tag",
"tagalogs":"tagalog",
"tagalongs":"tagalong",
"tagamets":"tagamet",
"tagasastes":"tagasaste",
"tagetestes":"tageteste",
"taguans":"taguan",
"taguses":"tagus",
"tais":"tai",
"taigas":"taiga",
"tailed":"tail",
"tailing":"tail",
"tails":"tail",
"tailboards":"tailboard",
"tailcoats":"tailcoat",
"tailfins":"tailfin",
"tailflowers":"tailflower",
"tailgated":"tailgate",
"tailgates":"tailgate",
"tailgating":"tailgate",
"tailings":"tailing",
"tailles":"taille",
"taillights":"taillight",
"tailored":"tailor",
"tailoring":"tailor",
"tailors":"tailor",
"tailorbirds":"tailorbird",
"tailplanes":"tailplane",
"tailses":"tails",
"tailspins":"tailspin",
"tailworts":"tailwort",
"tainos":"taino",
"tainted":"taint",
"tainting":"taint",
"taints":"taint",
"taipans":"taipan",
"taipeis":"taipei",
"tairas":"taira",
"taiwans":"taiwan",
"taiwaneses":"taiwanese",
"tajiks":"tajik",
"tajikistans":"tajikistan",
"takahes":"takahe",
"taken":"take",
"takes":"take",
"taking":"take",
"took":"take",
"takedowns":"takedown",
"takelmas":"takelma",
"takeoffs":"takeoff",
"takeouts":"takeout",
"takeovers":"takeover",
"taken_a_side":"take_a_side",
"takes_a_side":"take_a_side",
"taking_a_side":"take_a_side",
"took_a_side":"take_a_side",
"taken_pains":"take_pains",
"takes_pains":"take_pains",
"taking_pains":"take_pains",
"took_pains":"take_pains",
"taken_steps":"take_steps",
"takes_steps":"take_steps",
"taking_steps":"take_steps",
"took_steps":"take_steps",
"takilmen":"takilman",
"takins":"takin",
"takings":"taking",
"takingses":"takings",
"talapoins":"talapoin",
"talcs":"talc",
"talcums":"talcum",
"tales":"tale",
"talebearers":"talebearer",
"talents":"talent",
"talers":"taler",
"talesmen":"talesman",
"taletellers":"taleteller",
"talinums":"talinum",
"talipeses":"talipes",
"talipots":"talipot",
"talismans":"talisman",
"talismen":"talisman",
"talked":"talk",
"talking":"talk",
"talks":"talk",
"talkativenesses":"talkativeness",
"talkers":"talker",
"talkies":"talkie",
"talkings":"talking",
"talking-tos":"talking-to",
"talkses":"talks",
"talkier":"talky",
"talkiest":"talky",
"taller":"tall",
"tallest":"tall",
"tallahassees":"tallahassee",
"tallboys":"tallboy",
"tallinns":"tallinn",
"tallithim":"tallith",
"talliths":"tallith",
"tallnesses":"tallness",
"tallowed":"tallow",
"tallowing":"tallow",
"tallied":"tally",
"tallies":"tally",
"tallying":"tally",
"tally-ho'd":"tally-ho",
"tally-hoed":"tally-ho",
"tally-hoing":"tally-ho",
"tally-hos":"tally-ho",
"tallyhoed":"tallyho",
"tallyhoing":"tallyho",
"tallyhos":"tallyho",
"tallymen":"tallyman",
"talons":"talon",
"talpidaes":"talpidae",
"tali":"talus",
"taluses":"talus",
"tams":"tam",
"tam-tams":"tam-tam",
"tamales":"tamale",
"tamandus":"tamandu",
"tamanduas":"tamandua",
"tamanoirs":"tamanoir",
"tamaracks":"tamarack",
"tamaraos":"tamarao",
"tamaraus":"tamarau",
"tamaricaceaes":"tamaricaceae",
"tamarillos":"tamarillo",
"tamarins":"tamarin",
"tamarinds":"tamarind",
"tamarindos":"tamarindo",
"tamarinduses":"tamarindus",
"tamarixes":"tamarix",
"tamashas":"tamasha",
"tambacs":"tambac",
"tamboured":"tambour",
"tambouring":"tambour",
"tambours":"tambour",
"tamburlaines":"tamburlaine",
"tamed":"tame",
"tamer":"tame",
"tamest":"tame",
"taming":"tame",
"tamenesses":"tameness",
"tamerlanes":"tamerlane",
"tamiases":"tamias",
"tamiasciuruses":"tamiasciurus",
"tamils":"tamil",
"tamises":"tamis",
"tammanies":"tammany",
"tammuzs":"tammuz",
"tammies":"tammy",
"tamped":"tamp",
"tamping":"tamp",
"tamps":"tamp",
"tampered":"tamper",
"tampering":"tamper",
"tampers":"tamper",
"tamperings":"tampering",
"tamponed":"tampon",
"tamponing":"tampon",
"tamuses":"tamus",
"tanned":"tan",
"tanner":"tan",
"tannest":"tan",
"tanning":"tan",
"tans":"tan",
"tanacetums":"tanacetum",
"tandearils":"tandearil",
"tandems":"tandem",
"tanekahas":"tanekaha",
"tanged":"tang",
"tanging":"tang",
"tangs":"tang",
"tangelos":"tangelo",
"tanglos":"tangelo",
"tangencies":"tangency",
"tangents":"tangent",
"tangerines":"tangerine",
"tangibilities":"tangibility",
"tangibles":"tangible",
"tangiblenesses":"tangibleness",
"tangiers":"tangier",
"tangierses":"tangiers",
"tanginesses":"tanginess",
"tangled":"tangle",
"tangles":"tangle",
"tangling":"tangle",
"tangleberries":"tangleberry",
"tanglebushes":"tanglebush",
"tangoed":"tango",
"tangoes":"tango",
"tangoing":"tango",
"tangos":"tango",
"tangors":"tangor",
"tangier":"tangy",
"tangiest":"tangy",
"tanked":"tank",
"tanking":"tank",
"tanks":"tank",
"tankas":"tanka",
"tankers":"tanker",
"tankfuls":"tankful",
"tannenbergs":"tannenberg",
"tanners":"tanner",
"tanneries":"tannery",
"tannias":"tannia",
"tannins":"tannin",
"tanoans":"tanoan",
"tansies":"tansy",
"tantalized":"tantalize",
"tantalizes":"tantalize",
"tantalizing":"tantalize",
"tantalizers":"tantalizer",
"tantalums":"tantalum",
"tantaluses":"tantalus",
"tantaras":"tantara",
"tantillas":"tantilla",
"tantivies":"tantivy",
"tantras":"tantra",
"tantrisms":"tantrism",
"tantrums":"tantrum",
"taos":"tao",
"taoisms":"taoism",
"taoists":"taoist",
"tapped":"tap",
"tapping":"tap",
"taps":"tap",
"tap-offs":"tap-off",
"tapas":"tapa",
"taped":"tape",
"tapes":"tape",
"taping":"tape",
"tape-recorded":"tape-record",
"tape-recording":"tape-record",
"tapelines":"tapeline",
"tapered":"taper",
"tapering":"taper",
"tapers":"taper",
"tapestried":"tapestry",
"tapestries":"tapestry",
"tapestrying":"tapestry",
"tapeta":"tapetum",
"tapeworms":"tapeworm",
"taphouses":"taphouse",
"tapings":"taping",
"tapirs":"tapir",
"tapiridaes":"tapiridae",
"tapiruses":"tapirus",
"tapises":"tapis",
"tappas":"tappa",
"taprooms":"taproom",
"taproots":"taproot",
"tapses":"taps",
"tapsters":"tapster",
"tarred":"tar",
"tarring":"tar",
"tars":"tar",
"taradiddles":"taradiddle",
"taraktagenoses":"taraktagenos",
"taraktogenoses":"taraktogenos",
"tarantellas":"tarantella",
"tarantelles":"tarantelle",
"tarantulae":"tarantula",
"tarantulas":"tarantula",
"tarawas":"tarawa",
"tarawa-makins":"tarawa-makin",
"taraxacums":"taraxacum",
"tarbooshes":"tarboosh",
"tardigradas":"tardigrada",
"tardier":"tardy",
"tardiest":"tardy",
"tared":"tare",
"tares":"tare",
"taring":"tare",
"targeted":"target",
"targeting":"target",
"targets":"target",
"targummim":"targum",
"targums":"targum",
"tarichas":"taricha",
"tariffed":"tariff",
"tariffing":"tariff",
"tariffs":"tariff",
"tarmacs":"tarmac",
"tarmacadams":"tarmacadam",
"tarnished":"tarnish",
"tarnishes":"tarnish",
"tarnishing":"tarnish",
"taros":"taro",
"tarps":"tarp",
"tarpans":"tarpan",
"tarpaulins":"tarpaulin",
"tarpons":"tarpon",
"tarradiddles":"tarradiddle",
"tarragons":"tarragon",
"tarriances":"tarriance",
"tarrietias":"tarrietia",
"tarried":"tarry",
"tarrier":"tarry",
"tarries":"tarry",
"tarriest":"tarry",
"tarrying":"tarry",
"tarryings":"tarrying",
"tarsals":"tarsal",
"tarsiidaes":"tarsiidae",
"tarsioideas":"tarsioidea",
"tarsiuses":"tarsius",
"tarsometatarsi":"tarsometatarsus",
"tarsi":"tarsus",
"tarsusi":"tarsus",
"tarter":"tart",
"tartest":"tart",
"tarts":"tart",
"tartans":"tartan",
"tartars":"tartar",
"tartaruses":"tartarus",
"tartnesses":"tartness",
"tartufes":"tartufe",
"tartuffes":"tartuffe",
"tarweeds":"tarweed",
"tarwoods":"tarwood",
"tarzans":"tarzan",
"tashkents":"tashkent",
"tashmits":"tashmit",
"tashmitums":"tashmitum",
"tasked":"task",
"tasking":"task",
"tasks":"task",
"taskents":"taskent",
"tasses":"tasse",
"tasseled":"tassel",
"tasseling":"tassel",
"tasselled":"tassel",
"tasselling":"tassel",
"tassels":"tassel",
"tassets":"tasset",
"tasted":"taste",
"tastes":"taste",
"tasting":"taste",
"taste-makers":"taste-maker",
"tastelessnesses":"tastelessness",
"tasters":"taster",
"tastetesters":"tastetester",
"tastinesses":"tastiness",
"tastings":"tasting",
"tastier":"tasty",
"tastiest":"tasty",
"tats":"tat",
"tatted":"tat",
"tatting":"tat",
"tatamis":"tatami",
"tatars":"tatar",
"taters":"tater",
"tatous":"tatou",
"tatouays":"tatouay",
"tattered":"tatter",
"tattering":"tatter",
"tatters":"tatter",
"tatterdemalions":"tatterdemalion",
"tattings":"tatting",
"tattled":"tattle",
"tattles":"tattle",
"tattling":"tattle",
"tattletales":"tattletale",
"tattooed":"tattoo",
"tattooing":"tattoo",
"tattoos":"tattoo",
"tattier":"tatty",
"tattiest":"tatty",
"tatus":"tatu",
"taus":"tau",
"taunted":"taunt",
"taunting":"taunt",
"taunts":"taunt",
"tauntings":"taunting",
"tauons":"tauon",
"taurotraguses":"taurotragus",
"tauruses":"taurus",
"tauter":"taut",
"tautest":"taut",
"tautened":"tauten",
"tautening":"tauten",
"tautens":"tauten",
"tautnesses":"tautness",
"tautogs":"tautog",
"tautogas":"tautoga",
"tautogolabruses":"tautogolabrus",
"tautologized":"tautologize",
"tautologizing":"tautologize",
"tautologies":"tautology",
"taverns":"tavern",
"taws":"taw",
"tawdrinesses":"tawdriness",
"tawdrier":"tawdry",
"tawdriest":"tawdry",
"tawnier":"tawny",
"tawniest":"tawny",
"taxed":"tax",
"taxes":"tax",
"taxing":"tax",
"tax-increases":"tax-increase",
"taxaceaes":"taxaceae",
"taxaleses":"taxales",
"taxations":"taxation",
"taxied":"taxi",
"taxies":"taxi",
"taxiing":"taxi",
"taxis":"taxi",
"taxying":"taxi",
"taxicabs":"taxicab",
"taxideas":"taxidea",
"taxidermists":"taxidermist",
"taxidrivers":"taxidriver",
"taximen":"taximan",
"taxistands":"taxistand",
"taxiways":"taxiway",
"taxmen":"taxman",
"taxodiaceaes":"taxodiaceae",
"taxodiums":"taxodium",
"taxa":"taxon",
"taxons":"taxon",
"taxophytinas":"taxophytina",
"taxopsidas":"taxopsida",
"taxpayers":"taxpayer",
"taxuses":"taxus",
"tay-sachses":"tay-sachs",
"tayalics":"tayalic",
"tayassus":"tayassu",
"tayassuidaes":"tayassuidae",
"taylors":"taylor",
"tayras":"tayra",
"tazicefs":"tazicef",
"tbs":"tb",
"tbilisis":"tbilisi",
"tcs":"tc",
"tchads":"tchad",
"tcps":"tcp",
"tcp/ips":"tcp/ip",
"tdts":"tdt",
"tes":"te",
"te-heed":"te-hee",
"te-heeing":"te-hee",
"te-hees":"te-hee",
"teheed":"te-hee",
"teheeing":"te-hee",
"teas":"tea",
"teaberries":"teaberry",
"teacarts":"teacart",
"taught":"teach",
"teaches":"teach",
"teaching":"teach",
"teach-ins":"teach-in",
"teachers":"teacher",
"teachings":"teaching",
"teacups":"teacup",
"teacupfuls":"teacupful",
"teahouses":"teahouse",
"teaks":"teak",
"teakwoods":"teakwood",
"teals":"teal",
"teamed":"team",
"teaming":"team",
"teams":"team",
"teammates":"teammate",
"teamsters":"teamster",
"teapots":"teapot",
"teared":"tear",
"tearing":"tear",
"tears":"tear",
"tore":"tear",
"torn":"tear",
"tear-gassed":"tear-gas",
"tear-gassing":"tear-gas",
"teardrops":"teardrop",
"tearfulnesses":"tearfulness",
"tearings":"tearing",
"tearooms":"tearoom",
"tearses":"tears",
"tearier":"teary",
"teariest":"teary",
"teased":"tease",
"teases":"tease",
"teasing":"tease",
"teaseled":"teasel",
"teaseling":"teasel",
"teaselled":"teasel",
"teaselling":"teasel",
"teasels":"teasel",
"teasers":"teaser",
"teashops":"teashop",
"teasings":"teasing",
"teasles":"teasle",
"teaspoons":"teaspoon",
"teaspoonfuls":"teaspoonful",
"teats":"teat",
"teatimes":"teatime",
"teazels":"teazel",
"teazled":"teazle",
"teazling":"teazle",
"tebets":"tebet",
"tecs":"tec",
"teches":"tech",
"technetiums":"technetium",
"technics":"technic",
"technicalities":"technicality",
"technicians":"technician",
"techniques":"technique",
"technocracies":"technocracy",
"technologists":"technologist",
"technologies":"technology",
"techier":"techy",
"techiest":"techy",
"tecophilaeaceas":"tecophilaeacea",
"tectarias":"tectaria",
"tectonas":"tectona",
"tectonicses":"tectonics",
"tectrices":"tectrix",
"tedded":"ted",
"tedding":"ted",
"Teds":"Ted",
"teddieses":"teddies",
"teddies":"teddy",
"tediousnesses":"tediousness",
"tediums":"tedium",
"teed":"tee",
"teeing":"tee",
"tees":"tee",
"teemed":"teem",
"teeming":"teem",
"teems":"teem",
"teemingnesses":"teemingness",
"teen-agers":"teen-ager",
"teens":"teen",
"teenagers":"teenager",
"teensier":"teensy",
"teensiest":"teensy",
"teenier":"teeny",
"teeniest":"teeny",
"teepees":"teepee",
"teetered":"teeter",
"teetering":"teeter",
"teeters":"teeter",
"teeter-toters":"teeter-toter",
"teeterboards":"teeterboard",
"teethed":"teethe",
"teething":"teethe",
"teetotalers":"teetotaler",
"teetotalings":"teetotaling",
"teetotalisms":"teetotalism",
"teetotalists":"teetotalist",
"teetotallers":"teetotaller",
"teetotums":"teetotum",
"teffs":"teff",
"teflons":"teflon",
"tegmina":"tegmen",
"tegus":"tegu",
"tegucigalpas":"tegucigalpa",
"teguments":"tegument",
"teherans":"teheran",
"teiids":"teiid",
"teiidaes":"teiidae",
"telae":"tela",
"telamones":"telamon",
"telamons":"telamon",
"telangiectases":"telangiectasia",
"telangiectasias":"telangiectasia",
"telantheras":"telanthera",
"telecasted":"telecast",
"telecasting":"telecast",
"telecasts":"telecast",
"telecastings":"telecasting",
"teleconferences":"teleconference",
"teleconferencings":"teleconferencing",
"telegrammed":"telegram",
"telegramming":"telegram",
"telegrams":"telegram",
"telegraphed":"telegraph",
"telegraphing":"telegraph",
"telegraphs":"telegraph",
"telegraphers":"telegrapher",
"telegraphists":"telegraphist",
"telegraphies":"telegraphy",
"telekineses":"telekinesis",
"telemarketings":"telemarketing",
"telemetered":"telemeter",
"telemetering":"telemeter",
"telencephala":"telencephalon",
"telencephalons":"telencephalon",
"teleosts":"teleost",
"teleostans":"teleostan",
"teleosteis":"teleostei",
"telepathists":"telepathist",
"telepathies":"telepathy",
"telephoned":"telephone",
"telephones":"telephone",
"telephoning":"telephone",
"telephoners":"telephoner",
"telephonists":"telephonist",
"telephonies":"telephony",
"telephotos":"telephoto",
"telephotographs":"telephotograph",
"teleported":"teleport",
"teleporting":"teleport",
"teleprinters":"teleprinter",
"teleprocessings":"teleprocessing",
"telescoped":"telescope",
"telescopes":"telescope",
"telescoping":"telescope",
"telesellings":"teleselling",
"teletyped":"teletype",
"teletyping":"teletype",
"teletypewriters":"teletypewriter",
"televised":"televise",
"televises":"televise",
"televising":"televise",
"televisions":"television",
"telexes":"telex",
"telfers":"telfer",
"telferages":"telferage",
"telints":"telint",
"telia":"telium",
"telling":"tell",
"tells":"tell",
"told":"tell",
"tellers":"teller",
"tellimas":"tellima",
"tellings":"telling",
"telltales":"telltale",
"tellurians":"tellurian",
"telluriums":"tellurium",
"tellies":"telly",
"telopeas":"telopea",
"telosporidias":"telosporidia",
"telphers":"telpher",
"telpherages":"telpherage",
"telsontails":"telsontail",
"telugus":"telugu",
"temblors":"temblor",
"temerities":"temerity",
"temnes":"temne",
"temnospondylis":"temnospondyli",
"temps":"temp",
"tempered":"temper",
"tempering":"temper",
"tempers":"temper",
"temperas":"tempera",
"temperaments":"temperament",
"temperances":"temperance",
"temperatenesses":"temperateness",
"temperatures":"temperature",
"temperings":"tempering",
"tempested":"tempest",
"tempesting":"tempest",
"tempests":"tempest",
"templars":"templar",
"templates":"template",
"temples":"temple",
"templets":"templet",
"templetonias":"templetonia",
"tempi":"tempo",
"tempos":"tempo",
"temporals":"temporal",
"temporalities":"temporality",
"temporalized":"temporalize",
"temporalizing":"temporalize",
"temporalties":"temporalty",
"temporaries":"temporary",
"temporized":"temporize",
"temporizing":"temporize",
"tempras":"tempra",
"tempted":"tempt",
"tempting":"tempt",
"tempts":"tempt",
"temptations":"temptation",
"tempters":"tempter",
"temptingnesses":"temptingness",
"temptresses":"temptress",
"tens":"ten",
"ten-strikes":"ten-strike",
"tenabilities":"tenability",
"tenablenesses":"tenableness",
"tenaciousnesses":"tenaciousness",
"tenacities":"tenacity",
"tenacula":"tenaculum",
"tenancies":"tenancy",
"tenanted":"tenant",
"tenanting":"tenant",
"tenants":"tenant",
"tenches":"tench",
"tended":"tend",
"tending":"tend",
"tends":"tend",
"tendencies":"tendency",
"tendered":"tender",
"tenderer":"tender",
"tenderest":"tender",
"tendering":"tender",
"tenders":"tender",
"tenderfeet":"tenderfoot",
"tenderfoots":"tenderfoot",
"tendergreens":"tendergreen",
"tenderheartednesses":"tenderheartedness",
"tenderized":"tenderize",
"tenderizes":"tenderize",
"tenderizing":"tenderize",
"tenderloins":"tenderloin",
"tendernesses":"tenderness",
"tendings":"tending",
"tendinitises":"tendinitis",
"tendons":"tendon",
"tendonitises":"tendonitis",
"tendracs":"tendrac",
"tendrils":"tendril",
"tenebrionids":"tenebrionid",
"tenebrionidaes":"tenebrionidae",
"tenements":"tenement",
"tenets":"tenet",
"tenias":"tenia",
"tenners":"tenner",
"tennessees":"tennessee",
"tennises":"tennis",
"tennos":"tenno",
"tenoned":"tenon",
"tenoning":"tenon",
"tenors":"tenor",
"tenormins":"tenormin",
"tenorrhaphies":"tenorrhaphy",
"tenotomies":"tenotomy",
"tenpins":"tenpin",
"tenpinses":"tenpins",
"tenpounders":"tenpounder",
"tenrecs":"tenrec",
"tenrecidaes":"tenrecidae",
"tensed":"tense",
"tenser":"tense",
"tenses":"tense",
"tensest":"tense",
"tensing":"tense",
"tensenesses":"tenseness",
"tensioned":"tension",
"tensioning":"tension",
"tensions":"tension",
"tensities":"tensity",
"tented":"tent",
"tenting":"tent",
"tents":"tent",
"tent-flies":"tent-fly",
"tentacles":"tentacle",
"tentaculatas":"tentaculata",
"tentered":"tenter",
"tentering":"tenter",
"tenths":"tenth",
"tenthredinidaes":"tenthredinidae",
"tentings":"tenting",
"tenues":"tenuis",
"tenuities":"tenuity",
"tenures":"tenure",
"teocallis":"teocalli",
"tepees":"tepee",
"tepefied":"tepefy",
"tepefies":"tepefy",
"tepefying":"tepefy",
"tephrosias":"tephrosia",
"tepidities":"tepidity",
"tepidnesses":"tepidness",
"teras":"tera",
"terabytes":"terabyte",
"teraphim":"teraph",
"teratomas":"teratoma",
"teratomata":"teratoma",
"terbiums":"terbium",
"terces":"terce",
"tercels":"tercel",
"tercelets":"tercelet",
"tercentenaries":"tercentenary",
"tercentennials":"tercentennial",
"tercets":"tercet",
"terebellas":"terebella",
"terebellidaes":"terebellidae",
"terebinths":"terebinth",
"teredinids":"teredinid",
"teredinidaes":"teredinidae",
"teredines":"teredo",
"teredos":"teredo",
"tergiversated":"tergiversate",
"tergiversates":"tergiversate",
"tergiversating":"tergiversate",
"tergiversations":"tergiversation",
"terga":"tergum",
"termed":"term",
"terming":"term",
"terms":"term",
"termagants":"termagant",
"termeses":"termes",
"terminals":"terminal",
"terminated":"terminate",
"terminates":"terminate",
"terminating":"terminate",
"terminations":"termination",
"terminators":"terminator",
"terminologies":"terminology",
"termini":"terminus",
"terminuses":"terminus",
"termites":"termite",
"termitidaes":"termitidae",
"termses":"terms",
"ternaries":"ternary",
"ternions":"ternion",
"terpsichores":"terpsichore",
"terra-cottas":"terra-cotta",
"terraced":"terrace",
"terraces":"terrace",
"terracing":"terrace",
"terramycins":"terramycin",
"terrapenes":"terrapene",
"terraria":"terrarium",
"terrariums":"terrarium",
"terrarraria":"terrarium",
"terrarrariums":"terrarium",
"terrestrials":"terrestrial",
"terriblenesses":"terribleness",
"terriers":"terrier",
"terrietias":"terrietia",
"terrified":"terrify",
"terrifies":"terrify",
"terrifying":"terrify",
"territorials":"territorial",
"territorialisations":"territorialisation",
"territorializations":"territorialization",
"territorialized":"territorialize",
"territorializing":"territorialize",
"territories":"territory",
"terrors":"terror",
"terrorisations":"terrorisation",
"terrorizations":"terrorization",
"terrorized":"terrorize",
"terrorizes":"terrorize",
"terrorizing":"terrorize",
"terries":"terry",
"terrycloths":"terrycloth",
"terser":"terse",
"tersest":"terse",
"tertiaries":"tertiary",
"tertigravidas":"tertigravida",
"tertries":"tertry",
"terylenes":"terylene",
"terzettos":"terzetto",
"teslas":"tesla",
"tessellated":"tessellate",
"tessellating":"tessellate",
"tesserae":"tessera",
"tessins":"tessin",
"tested":"test",
"testing":"test",
"tests":"test",
"test-driven":"test-drive",
"test-driving":"test-drive",
"test-drove":"test-drive",
"test-flew":"test-fly",
"test-flown":"test-fly",
"test-flying":"test-fly",
"testae":"testa",
"testas":"testa",
"testaceas":"testacea",
"testaments":"testament",
"testates":"testate",
"testators":"testator",
"testatrices":"testatrix",
"testees":"testee",
"testers":"tester",
"testicles":"testicle",
"testieres":"testiere",
"testifiers":"testifier",
"testified":"testify",
"testifies":"testify",
"testifying":"testify",
"testimonials":"testimonial",
"testimonies":"testimony",
"testinesses":"testiness",
"testings":"testing",
"testes":"testis",
"testises":"testis",
"testudinatas":"testudinata",
"testudineses":"testudines",
"testudinidaes":"testudinidae",
"testudines":"testudo",
"testudos":"testudo",
"testier":"testy",
"testiest":"testy",
"tetanized":"tetanize",
"tetanizing":"tetanize",
"tetanuses":"tetanus",
"tetchinesses":"tetchiness",
"tetchier":"tetchy",
"tetchiest":"tetchy",
"tete-a-tetes":"tete-a-tete",
"tethered":"tether",
"tethering":"tether",
"tethers":"tether",
"tethyidaes":"tethyidae",
"tethyses":"tethys",
"tetras":"tetra",
"tetrabromo-phenolsulfonephthaleins":"tetrabromo-phenolsulfonephthalein",
"tetrachloromethanes":"tetrachloromethane",
"tetraclinises":"tetraclinis",
"tetracyclines":"tetracycline",
"tetrads":"tetrad",
"tetragons":"tetragon",
"tetragonias":"tetragonia",
"tetragoniaceaes":"tetragoniaceae",
"tetragonuruses":"tetragonurus",
"tetrahedra":"tetrahedron",
"tetrahedrons":"tetrahedron",
"tetralogies":"tetralogy",
"tetraneurises":"tetraneuris",
"tetranychids":"tetranychid",
"tetranychidaes":"tetranychidae",
"tetraos":"tetrao",
"tetraodontidaes":"tetraodontidae",
"tetraonidaes":"tetraonidae",
"tetrapodies":"tetrapody",
"tetrapturuses":"tetrapturus",
"tetterworts":"tetterwort",
"tettigoniids":"tettigoniid",
"tettigoniidaes":"tettigoniidae",
"teucriums":"teucrium",
"teutonized":"teutonize",
"teutonizes":"teutonize",
"teutonizing":"teutonize",
"teveres":"tevere",
"tevets":"tevet",
"texases":"texas",
"texts":"text",
"textbooks":"textbook",
"textiles":"textile",
"textuaries":"textuary",
"textures":"texture",
"ths":"th",
"Thais":"Thai",
"thailands":"thailand",
"thalamencephala":"thalamencephalon",
"thalamencephalons":"thalamencephalon",
"thalami":"thalamus",
"thalarctoses":"thalarctos",
"thalassaemias":"thalassaemia",
"thalassemias":"thalassemia",
"thalassocracies":"thalassocracy",
"thalassomas":"thalassoma",
"thaliaceas":"thaliacea",
"thalictrums":"thalictrum",
"thalliums":"thallium",
"thalli":"thallus",
"thalluses":"thallus",
"thalmencephalons":"thalmencephalon",
"thameses":"thames",
"thammuzs":"thammuz",
"thamnophiluses":"thamnophilus",
"thamnophises":"thamnophis",
"thanked":"thank",
"thanking":"thank",
"thanks":"thank",
"thankfulnesses":"thankfulness",
"thankings":"thanking",
"thankses":"thanks",
"thanksgivings":"thanksgiving",
"those":"those",
"thatched":"thatch",
"thatches":"thatch",
"thatching":"thatch",
"thatchers":"thatcher",
"thaumatolatries":"thaumatolatry",
"thawed":"thaw",
"thawing":"thaw",
"thaws":"thaw",
"thawings":"thawing",
"thbs":"thb",
"thds":"thd",
"theas":"thea",
"theaceaes":"theaceae",
"theanthropisms":"theanthropism",
"thearchies":"thearchy",
"theaters":"theater",
"theatergoers":"theatergoer",
"theatres":"theatre",
"theatres-in-the-round":"theatre-in-the-round",
"theatregoers":"theatregoer",
"theatricals":"theatrical",
"theatricalities":"theatricality",
"theatricalized":"theatricalize",
"theatricalizing":"theatricalize",
"thecae":"theca",
"thecas":"theca",
"thecodonts":"thecodont",
"thecodontias":"thecodontia",
"thefts":"theft",
"theias":"theia",
"thelephoraceaes":"thelephoraceae",
"thelypteridaceaes":"thelypteridaceae",
"thelypterises":"thelypteris",
"themes":"theme",
"theobromas":"theobroma",
"theocracies":"theocracy",
"theodicies":"theodicy",
"theodolites":"theodolite",
"theogonies":"theogony",
"theologians":"theologian",
"theologists":"theologist",
"theologized":"theologize",
"theologizing":"theologize",
"theologizers":"theologizer",
"theologies":"theology",
"theomachies":"theomachy",
"theophagies":"theophagy",
"theophanies":"theophany",
"theophrastaceaes":"theophrastaceae",
"theorbos":"theorbo",
"theorems":"theorem",
"theoreticians":"theoretician",
"theorisations":"theorisation",
"theorists":"theorist",
"theorizations":"theorization",
"theorized":"theorize",
"theorizes":"theorize",
"theorizing":"theorize",
"theories":"theory",
"theraphosidaes":"theraphosidae",
"therapists":"therapist",
"therapsids":"therapsid",
"therapsidas":"therapsida",
"therapies":"therapy",
"theridiids":"theridiid",
"theridiidaes":"theridiidae",
"thermals":"thermal",
"thermels":"thermel",
"thermistors":"thermistor",
"thermobias":"thermobia",
"thermocouples":"thermocouple",
"thermoformed":"thermoform",
"thermoforming":"thermoform",
"thermographs":"thermograph",
"thermogravimeters":"thermogravimeter",
"thermohydrometers":"thermohydrometer",
"thermometrographs":"thermometrograph",
"thermoplastics":"thermoplastic",
"thermopses":"thermopsis",
"thermopylaes":"thermopylae",
"thermoregulators":"thermoregulator",
"thermoses":"thermos",
"thermostats":"thermostat",
"thermostaticses":"thermostatics",
"theropods":"theropod",
"theropodas":"theropoda",
"thesauri":"thesaurus",
"thesauruses":"thesaurus",
"theses":"thesis",
"thespesias":"thespesia",
"thespians":"thespian",
"thessalias":"thessalia",
"thessalonikas":"thessalonika",
"thessalies":"thessaly",
"theurgies":"theurgy",
"thevetias":"thevetia",
"thiamins":"thiamin",
"thiamines":"thiamine",
"thibets":"thibet",
"thicker":"thick",
"thickest":"thick",
"thicks":"thick",
"thick-knees":"thick-knee",
"thickened":"thicken",
"thickening":"thicken",
"thickeners":"thickener",
"thickenings":"thickening",
"thickets":"thicket",
"thickheads":"thickhead",
"thickleaves":"thickleaf",
"thicknesses":"thickness",
"thieves":"thief",
"thielavias":"thielavia",
"thieved":"thieve",
"thieving":"thieve",
"thieveries":"thievery",
"thievings":"thieving",
"thievishnesses":"thievishness",
"thighs":"thigh",
"thigh-slappers":"thigh-slapper",
"thighbones":"thighbone",
"thimbles":"thimble",
"thimbleberries":"thimbleberry",
"thimblefuls":"thimbleful",
"thimblerigged":"thimblerig",
"thimblerigging":"thimblerig",
"thimblerigs":"thimblerig",
"thimbleweeds":"thimbleweed",
"thimerosals":"thimerosal",
"thinned":"thin",
"thinner":"thin",
"thinnest":"thin",
"thinning":"thin",
"thins":"thin",
"things":"thing",
"thing-in-itselfs":"thing-in-itself",
"things-in-themselves":"thing-in-itself",
"thingamabobs":"thingamabob",
"thingamajigs":"thingamajig",
"thingmabobs":"thingmabob",
"thingmajigs":"thingmajig",
"thingumabobs":"thingumabob",
"thingumajigs":"thingumajig",
"thingummies":"thingummy",
"thinking":"think",
"thinks":"think",
"thought":"think",
"thinkers":"thinker",
"thinkings":"thinking",
"thinners":"thinner",
"thinnesses":"thinness",
"thinnings":"thinning",
"thiobacterias":"thiobacteria",
"thiobacteriaceaes":"thiobacteriaceae",
"thiodiphenylamines":"thiodiphenylamine",
"thiopentals":"thiopental",
"thioridazines":"thioridazine",
"thirds":"third",
"third-degreed":"third-degree",
"third-degreeing":"third-degree",
"third-dimensionalities":"third-dimensionality",
"thirsted":"thirst",
"thirsting":"thirst",
"thirsts":"thirst",
"thirstier":"thirsty",
"thirstiest":"thirsty",
"thirteens":"thirteen",
"thirteenths":"thirteenth",
"thirtieses":"thirties",
"thirtieths":"thirtieth",
"thirties":"thirty",
"thirty-somethings":"thirty-something",
"thirty-twomos":"thirty-twomo",
"these":"these",
"thistles":"thistle",
"thlaspis":"thlaspi",
"thms":"thm",
"tholed":"thole",
"tholes":"thole",
"tholing":"thole",
"tholepins":"tholepin",
"tholoi":"tholos",
"thomases":"thomas",
"thomomyses":"thomomys",
"thonged":"thong",
"thonging":"thong",
"thongs":"thong",
"thoracoplasties":"thoracoplasty",
"thoracotomies":"thoracotomy",
"thoraces":"thorax",
"thoraxes":"thorax",
"thorazines":"thorazine",
"thoreaus":"thoreau",
"thoriums":"thorium",
"thorns":"thorn",
"thornier":"thorny",
"thorniest":"thorny",
"thoroughbreds":"thoroughbred",
"thoroughfares":"thoroughfare",
"thoroughworts":"thoroughwort",
"thous":"thou",
"thoughts":"thought",
"thought-images":"thought-image",
"thought-readers":"thought-reader",
"thoughtfulnesses":"thoughtfulness",
"thoughtlessnesses":"thoughtlessness",
"thousands":"thousand",
"thousandths":"thousandth",
"thraldoms":"thraldom",
"thralls":"thrall",
"thralldoms":"thralldom",
"thrashed":"thrash",
"thrashes":"thrash",
"thrashing":"thrash",
"thrashers":"thrasher",
"thrashings":"thrashing",
"thraupidaes":"thraupidae",
"threaded":"thread",
"threading":"thread",
"threads":"thread",
"threadfins":"threadfin",
"threadfishes":"threadfish",
"threadses":"threads",
"threadworms":"threadworm",
"threadier":"thready",
"threadiest":"thready",
"threaped":"threap",
"threaping":"threap",
"threats":"threat",
"threatening":"threaten",
"threatens":"threaten",
"threes":"three",
"three-baggers":"three-bagger",
"three-ds":"three-d",
"three-deckers":"three-decker",
"three-dimensionalities":"three-dimensionality",
"three-hitters":"three-hitter",
"three-sixties":"three-sixty",
"threepences":"threepence",
"threesomes":"threesome",
"threnodes":"threnode",
"threnodies":"threnody",
"threshed":"thresh",
"threshes":"thresh",
"threshing":"thresh",
"threshers":"thresher",
"thresholds":"threshold",
"threskiornises":"threskiornis",
"threskiornithidaes":"threskiornithidae",
"thrifts":"thrift",
"thriftinesses":"thriftiness",
"thriftlessnesses":"thriftlessness",
"thriftshops":"thriftshop",
"thriftier":"thrifty",
"thriftiest":"thrifty",
"thrilling":"thrill",
"thrills":"thrill",
"thrinaxes":"thrinax",
"thrips":"thrip",
"thripids":"thripid",
"thripidaes":"thripidae",
"thripses":"thrips",
"thrived":"thrive",
"thriven":"thrive",
"thrives":"thrive",
"thriving":"thrive",
"throve":"thrive",
"throats":"throat",
"throatworts":"throatwort",
"throatier":"throaty",
"throatiest":"throaty",
"throbbed":"throb",
"throbbing":"throb",
"throbs":"throb",
"throbbings":"throbbing",
"thrombocytes":"thrombocyte",
"thrombocytopenias":"thrombocytopenia",
"thrombokinases":"thrombokinase",
"thrombolytics":"thrombolytic",
"thrombopenias":"thrombopenia",
"thromboplastins":"thromboplastin",
"thrombi":"thrombus",
"throned":"throne",
"thrones":"throne",
"throning":"throne",
"thronged":"throng",
"thronging":"throng",
"throngs":"throng",
"throstles":"throstle",
"throttled":"throttle",
"throttles":"throttle",
"throttling":"throttle",
"throttleholds":"throttlehold",
"throttlings":"throttling",
"throughways":"throughway",
"threw":"throw",
"throwing":"throw",
"thrown":"throw",
"throws":"throw",
"throwaways":"throwaway",
"throwbacks":"throwback",
"threw_out":"throw_out",
"throwing_out":"throw_out",
"thrown_out":"throw_out",
"throws_out":"throw_out",
"thrummed":"thrum",
"thrumming":"thrum",
"thrums":"thrum",
"thrummier":"thrummy",
"thrummiest":"thrummy",
"thrushes":"thrush",
"thrusting":"thrust",
"thrusts":"thrust",
"thrusters":"thruster",
"thrustings":"thrusting",
"thruways":"thruway",
"thryothoruses":"thryothorus",
"thudded":"thud",
"thudding":"thud",
"thuds":"thud",
"thugs":"thug",
"thujas":"thuja",
"thujopses":"thujopsis",
"thules":"thule",
"thuliums":"thulium",
"thumbed":"thumb",
"thumbing":"thumb",
"thumbs":"thumb",
"thumbnuts":"thumbnut",
"thumbtacked":"thumbtack",
"thumbtacking":"thumbtack",
"thumbtacks":"thumbtack",
"thumped":"thump",
"thumping":"thump",
"thumps":"thump",
"thumpers":"thumper",
"thumpings":"thumping",
"thunbergias":"thunbergia",
"thundered":"thunder",
"thundering":"thunder",
"thunders":"thunder",
"thunderbolts":"thunderbolt",
"thunderclaps":"thunderclap",
"thunderclouds":"thundercloud",
"thunderers":"thunderer",
"thundershowers":"thundershower",
"thunderstorms":"thunderstorm",
"thunnuses":"thunnus",
"thuribles":"thurible",
"thursdays":"thursday",
"thwacked":"thwack",
"thwacking":"thwack",
"thwacks":"thwack",
"thwarted":"thwart",
"thwarting":"thwart",
"thwarts":"thwart",
"thwartings":"thwarting",
"thylacines":"thylacine",
"thylacinuses":"thylacinus",
"thylogales":"thylogale",
"thymelaeaceaes":"thymelaeaceae",
"thymelaealeses":"thymelaeales",
"thymols":"thymol",
"thymuses":"thymus",
"thymusmi":"thymus",
"thymier":"thymy",
"thymiest":"thymy",
"thyreophoras":"thyreophora",
"thyreophorans":"thyreophoran",
"thyroids":"thyroid",
"thyroidectomies":"thyroidectomy",
"thyrotoxicoses":"thyrotoxicosis",
"thyrotrophins":"thyrotrophin",
"thyroxins":"thyroxin",
"thyroxines":"thyroxine",
"therses":"thyrse",
"thyrsopterises":"thyrsopteris",
"thyrsi":"thyrsus",
"thyrsui":"thyrsus",
"thysanocarpuses":"thysanocarpus",
"thysanopters":"thysanopter",
"thysanopteras":"thysanoptera",
"thysanopterons":"thysanopteron",
"thysanuras":"thysanura",
"thysanurons":"thysanuron",
"tis":"ti",
"tianjins":"tianjin",
"tiaras":"tiara",
"tiarellas":"tiarella",
"tibers":"tiber",
"tibets":"tibet",
"tibeto-burmen":"tibeto-burman",
"tibiae":"tibia",
"tibias":"tibia",
"tibialises":"tibialis",
"tibicens":"tibicen",
"tic-tac-toes":"tic-tac-toe",
"ticals":"tical",
"tichodromas":"tichodroma",
"tichodromes":"tichodrome",
"ticinos":"ticino",
"ticked":"tick",
"ticking":"tick",
"ticks":"tick",
"tickers":"ticker",
"ticketed":"ticket",
"ticketing":"ticket",
"tickets":"ticket",
"tickings":"ticking",
"tickled":"tickle",
"tickles":"tickle",
"tickling":"tickle",
"ticklers":"tickler",
"ticklings":"tickling",
"tickseeds":"tickseed",
"ticktacktoes":"ticktacktoe",
"ticktacktoos":"ticktacktoo",
"ticktocks":"ticktock",
"tickweeds":"tickweed",
"tictacs":"tictac",
"tidbits":"tidbit",
"tiddlers":"tiddler",
"tided":"tide",
"tides":"tide",
"tiding":"tide",
"tidinesses":"tidiness",
"tidingses":"tidings",
"tidied":"tidy",
"tidier":"tidy",
"tidies":"tidy",
"tidiest":"tidy",
"tidying":"tidy",
"tidytipses":"tidytips",
"ties":"tie",
"tying":"tie",
"tie-dyed":"tie-dye",
"tie-dyeing":"tie-dye",
"tie-ins":"tie-in",
"tie-ups":"tie-up",
"tien-paos":"tien-pao",
"tientsins":"tientsin",
"tiepins":"tiepin",
"tiered":"tier",
"tiering":"tier",
"tiers":"tier",
"tierces":"tierce",
"tiercels":"tiercel",
"tiffed":"tiff",
"tiffing":"tiff",
"tiffs":"tiff",
"tiffanies":"tiffany",
"tiffins":"tiffin",
"tiflises":"tiflis",
"tigers":"tiger",
"tighter":"tight",
"tightest":"tight",
"tightened":"tighten",
"tightening":"tighten",
"tightens":"tighten",
"tightfistednesses":"tightfistedness",
"tightnesses":"tightness",
"tightses":"tights",
"tightwads":"tightwad",
"tiglons":"tiglon",
"tigons":"tigon",
"tigrises":"tigris",
"tikes":"tike",
"tilapias":"tilapia",
"tilburies":"tilbury",
"tildes":"tilde",
"tiled":"tile",
"tiles":"tile",
"tiling":"tile",
"tilefishes":"tilefish",
"tilias":"tilia",
"tiliaceaes":"tiliaceae",
"tiliomyceteses":"tiliomycetes",
"tilled":"till",
"tilling":"till",
"tills":"till",
"tillages":"tillage",
"tillandsias":"tillandsia",
"tillered":"tiller",
"tillering":"tiller",
"tillers":"tiller",
"tilletias":"tilletia",
"tilletiaceaes":"tilletiaceae",
"tilted":"tilt",
"tilting":"tilt",
"tilts":"tilt",
"tilths":"tilth",
"timalias":"timalia",
"timaliidaes":"timaliidae",
"timbales":"timbale",
"timbered":"timber",
"timbering":"timber",
"timbers":"timber",
"timberlands":"timberland",
"timberlines":"timberline",
"timbermen":"timberman",
"timbres":"timbre",
"timed":"time",
"times":"time",
"timing":"time",
"time-outs":"time-out",
"timekeepers":"timekeeper",
"timelessnesses":"timelessness",
"timelinesses":"timeliness",
"timelier":"timely",
"timeliest":"timely",
"timepieces":"timepiece",
"timeses":"times",
"timetables":"timetable",
"timider":"timid",
"timidest":"timid",
"timids":"timid",
"timidities":"timidity",
"timidnesses":"timidness",
"timocracies":"timocracy",
"timorousnesses":"timorousness",
"timothies":"timothy",
"timpanis":"timpani",
"timpanists":"timpanist",
"timpani":"timpano",
"timurs":"timur",
"tinned":"tin",
"tinning":"tin",
"tins":"tin",
"tin-platings":"tin-plating",
"tinamidaes":"tinamidae",
"tinamiformeses":"tinamiformes",
"tinamous":"tinamou",
"tincas":"tinca",
"tinctured":"tincture",
"tinctures":"tincture",
"tincturing":"tincture",
"tinders":"tinder",
"tineas":"tinea",
"tineids":"tineid",
"tineidaes":"tineidae",
"tineoids":"tineoid",
"tineoideas":"tineoidea",
"tineolas":"tineola",
"tinfoils":"tinfoil",
"tinged":"ting",
"tinging":"ting",
"tings":"ting",
"tingeing":"tinge",
"tinges":"tinge",
"tingidaes":"tingidae",
"tingled":"tingle",
"tingles":"tingle",
"tingling":"tingle",
"tinglings":"tingling",
"tinkered":"tinker",
"tinkering":"tinker",
"tinkers":"tinker",
"tinkled":"tinkle",
"tinkles":"tinkle",
"tinkling":"tinkle",
"tinnings":"tinning",
"tinnier":"tinny",
"tinniest":"tinny",
"tinseled":"tinsel",
"tinseling":"tinsel",
"tinselled":"tinsel",
"tinselling":"tinsel",
"tinsels":"tinsel",
"tinsnipses":"tinsnips",
"tinted":"tint",
"tinting":"tint",
"tints":"tint",
"tintinnabulations":"tintinnabulation",
"tintinnabula":"tintinnabulum",
"tintometers":"tintometer",
"tinier":"tiny",
"tiniest":"tiny",
"tinynesses":"tinyness",
"tipped":"tip",
"tipping":"tip",
"tips":"tip",
"tip-offs":"tip-off",
"tip-tops":"tip-top",
"tipis":"tipi",
"tippled":"tipple",
"tipples":"tipple",
"tippling":"tipple",
"tipplers":"tippler",
"tippier":"tippy",
"tippiest":"tippy",
"tipsinesses":"tipsiness",
"tipstaffs":"tipstaff",
"tipstaves":"tipstaff",
"tipsters":"tipster",
"tipsier":"tipsy",
"tipsiest":"tipsy",
"tiptoed":"tiptoe",
"tiptoeing":"tiptoe",
"tiptoes":"tiptoe",
"tipus":"tipu",
"tipuanas":"tipuana",
"tipulidaes":"tipulidae",
"tirades":"tirade",
"tiranas":"tirana",
"tires":"tire",
"tiring":"tire",
"tirednesses":"tiredness",
"tirelessnesses":"tirelessness",
"tiresomenesses":"tiresomeness",
"tirewomen":"tirewoman",
"tiros":"tiro",
"tirols":"tirol",
"tissued":"tissue",
"tissues":"tissue",
"tissuing":"tissue",
"tits":"tit",
"tit-tat-toes":"tit-tat-toe",
"titans":"titan",
"titanias":"titania",
"titaniums":"titanium",
"titanosaurs":"titanosaur",
"titanosaurians":"titanosaurian",
"titanosauridaes":"titanosauridae",
"titanosauruses":"titanosaurus",
"titbits":"titbit",
"titers":"titer",
"tithed":"tithe",
"tithes":"tithe",
"tithing":"tithe",
"tithers":"tither",
"tithonias":"tithonia",
"titis":"titi",
"titians":"titian",
"titillated":"titillate",
"titillates":"titillate",
"titillating":"titillate",
"titivated":"titivate",
"titivates":"titivate",
"titivating":"titivate",
"titlarks":"titlark",
"titles":"title",
"titling":"title",
"title-holders":"title-holder",
"titmen":"titman",
"titmice":"titmouse",
"titrated":"titrate",
"titrating":"titrate",
"titres":"titre",
"tittered":"titter",
"tittering":"titter",
"titters":"titter",
"tittivated":"tittivate",
"tittivates":"tittivate",
"tittivating":"tittivate",
"tittles":"tittle",
"tittle-tattled":"tittle-tattle",
"tittle-tattles":"tittle-tattle",
"tittle-tattling":"tittle-tattle",
"tittuped":"tittup",
"tittuping":"tittup",
"tittupped":"tittup",
"tittupping":"tittup",
"tittups":"tittup",
"titties":"titty",
"titulars":"titular",
"titularies":"titulary",
"tivs":"tiv",
"tizzies":"tizzy",
"tkos":"tko",
"tls":"tl",
"tlcs":"tlc",
"tlingits":"tlingit",
"tms":"tm",
"tmvs":"tmv",
"tnts":"tnt",
"to-dos":"to-do",
"toads":"toad",
"toadfishes":"toadfish",
"toadflaxes":"toadflax",
"toadfrogs":"toadfrog",
"toadshades":"toadshade",
"toadstools":"toadstool",
"toadied":"toady",
"toadies":"toady",
"toadying":"toady",
"toasted":"toast",
"toasting":"toast",
"toasts":"toast",
"toastings":"toasting",
"toastier":"toasty",
"toastiest":"toasty",
"tobaccoes":"tobacco",
"tobaccos":"tobacco",
"tobacconists":"tobacconist",
"tobogganed":"toboggan",
"tobogganing":"toboggan",
"toboggans":"toboggan",
"tobies":"toby",
"toccatas":"toccata",
"toccate":"toccata",
"tocktacts":"tocktact",
"tocologies":"tocology",
"tocopherols":"tocopherol",
"tocsins":"tocsin",
"toddled":"toddle",
"toddles":"toddle",
"toddling":"toddle",
"toddlers":"toddler",
"toddies":"toddy",
"todeas":"todea",
"todidaes":"todidae",
"toduses":"todus",
"todies":"tody",
"toed":"toe",
"toeing":"toe",
"toes":"toe",
"toetoes":"toetoe",
"toffs":"toff",
"toffees":"toffee",
"toffies":"toffy",
"tofieldias":"tofieldia",
"tofus":"tofu",
"togged":"tog",
"togging":"tog",
"togs":"tog",
"togae":"toga",
"togas":"toga",
"toggled":"toggle",
"toggles":"toggle",
"toggling":"toggle",
"togses":"togs",
"toiled":"toil",
"toiling":"toil",
"toils":"toil",
"toilets":"toilet",
"toiletrieses":"toiletries",
"toiletries":"toiletry",
"toilsomenesses":"toilsomeness",
"toitois":"toitoi",
"tokens":"token",
"tokios":"tokio",
"tokyos":"tokyo",
"tolazamides":"tolazamide",
"tolbooths":"tolbooth",
"tolectins":"tolectin",
"tolerances":"tolerance",
"tolerated":"tolerate",
"tolerates":"tolerate",
"tolerating":"tolerate",
"tolerations":"toleration",
"tolinases":"tolinase",
"tolled":"toll",
"tolling":"toll",
"tolls":"toll",
"tollbars":"tollbar",
"tollbooths":"tollbooth",
"tollers":"toller",
"tollgates":"tollgate",
"tollgatherers":"tollgatherer",
"tollhouses":"tollhouse",
"tollies":"tollie",
"tollkeepers":"tollkeeper",
"tollmen":"tollman",
"tollons":"tollon",
"tolltakers":"tolltaker",
"tolmieas":"tolmiea",
"tolstoys":"tolstoy",
"toltecs":"toltec",
"tolus":"tolu",
"toluenes":"toluene",
"tolypeuteses":"tolypeutes",
"toms":"tom",
"tom-toms":"tom-tom",
"tomahawked":"tomahawk",
"tomahawking":"tomahawk",
"tomahawks":"tomahawk",
"tomalleys":"tomalley",
"tomatillos":"tomatillo",
"tomatoes":"tomato",
"tombed":"tomb",
"tombing":"tomb",
"tombs":"tomb",
"tombacs":"tombac",
"tombaks":"tombak",
"tombigbees":"tombigbee",
"tombolos":"tombolo",
"tomboys":"tomboy",
"tomboyishnesses":"tomboyishness",
"tombstones":"tombstone",
"tomcats":"tomcat",
"tomcods":"tomcod",
"tomenta":"tomentum",
"tomentums":"tomentum",
"tomfools":"tomfool",
"tomfooleries":"tomfoolery",
"tomistomas":"tomistoma",
"tommies":"tommy",
"tommyrots":"tommyrot",
"tomographies":"tomography",
"tomorrows":"tomorrow",
"tomtates":"tomtate",
"tomtits":"tomtit",
"tomtoms":"tomtom",
"tons":"ton",
"tonalities":"tonality",
"tondi":"tondo",
"toned":"tone",
"tones":"tone",
"toning":"tone",
"tone-beginnings":"tone-beginning",
"tonged":"tong",
"tonging":"tong",
"tongas":"tonga",
"tongses":"tongs",
"tongued":"tongue",
"tongues":"tongue",
"tonguing":"tongue",
"tongue-lashed":"tongue-lash",
"tongue-lashing":"tongue-lash",
"tonics":"tonic",
"tonicities":"tonicity",
"tonnages":"tonnage",
"tonnes":"tonne",
"tonneaus":"tonneau",
"tonneaux":"tonneau",
"tonses":"tons",
"tonsils":"tonsil",
"tonsillectomies":"tonsillectomy",
"tonsillotomies":"tonsillotomy",
"tonsured":"tonsure",
"tonsuring":"tonsure",
"tontines":"tontine",
"tonuses":"tonus",
"tonier":"tony",
"toniest":"tony",
"tooled":"tool",
"tooling":"tool",
"tools":"tool",
"toolboxes":"toolbox",
"toolhouses":"toolhouse",
"toonas":"toona",
"tooshies":"tooshie",
"tooted":"toot",
"tooting":"toot",
"toots":"toot",
"teeth":"tooth",
"toothed":"tooth",
"toothing":"tooth",
"toothaches":"toothache",
"toothbrushes":"toothbrush",
"toothpicks":"toothpick",
"toothpowders":"toothpowder",
"toothsomenesses":"toothsomeness",
"toothworts":"toothwort",
"toothier":"toothy",
"toothiest":"toothy",
"tootled":"tootle",
"tootling":"tootle",
"tootses":"toots",
"tootsies":"tootsie",
"tootsy-wootsies":"tootsy-wootsy",
"topped":"top",
"topping":"top",
"tops":"top",
"topazes":"topaz",
"topazs":"topaz",
"topcoats":"topcoat",
"topdressed":"topdress",
"topdressing":"topdress",
"toped":"tope",
"topes":"tope",
"toping":"tope",
"topees":"topee",
"topekas":"topeka",
"topers":"toper",
"topgallants":"topgallant",
"tophi":"tophus",
"topis":"topi",
"topiaries":"topiary",
"topics":"topic",
"topminnows":"topminnow",
"topognosias":"topognosia",
"topognoses":"topognosis",
"topographies":"topography",
"topolatries":"topolatry",
"topologies":"topology",
"toponyms":"toponym",
"topoi":"topos",
"toppers":"topper",
"toppings":"topping",
"toppled":"topple",
"topples":"topple",
"toppling":"topple",
"topsoils":"topsoil",
"topstitched":"topstitch",
"topstitching":"topstitch",
"topsy-turvied":"topsy-turvy",
"topsy-turvies":"topsy-turvy",
"topsy-turvying":"topsy-turvy",
"topsy-turvydoms":"topsy-turvydom",
"topsy-turvynesses":"topsy-turvyness",
"topvs":"topv",
"toques":"toque",
"toradols":"toradol",
"torahs":"torah",
"torches":"torch",
"torchier":"torchy",
"torchiest":"torchy",
"tores":"tore",
"toreadors":"toreador",
"toreros":"torero",
"torinos":"torino",
"tormented":"torment",
"tormenting":"torment",
"torments":"torment",
"tormenters":"tormenter",
"tormentors":"tormentor",
"tornadoes":"tornado",
"tornados":"tornado",
"tornillos":"tornillo",
"toros":"toro",
"torodals":"torodal",
"toroids":"toroid",
"torpedinidaes":"torpedinidae",
"torpediniformeses":"torpediniformes",
"torpedoed":"torpedo",
"torpedoes":"torpedo",
"torpedoing":"torpedo",
"torpidities":"torpidity",
"torpidnesses":"torpidness",
"torpors":"torpor",
"torques":"torque",
"torrs":"torr",
"torrefied":"torrefy",
"torrefies":"torrefy",
"torrefying":"torrefy",
"torrify":"torrefy",
"torrents":"torrent",
"torreyas":"torreya",
"torricellis":"torricelli",
"torsions":"torsion",
"torsks":"torsk",
"torsi":"torso",
"torsos":"torso",
"torts":"tort",
"torticollises":"torticollis",
"tortillas":"tortilla",
"tortoises":"tortoise",
"tortoiseshells":"tortoiseshell",
"tortoiseshell-cats":"tortoiseshell-cat",
"tortricids":"tortricid",
"tortricidaes":"tortricidae",
"tortrixes":"tortrix",
"tortuosities":"tortuosity",
"tortuousnesses":"tortuousness",
"tortured":"torture",
"tortures":"torture",
"torturing":"torture",
"torturings":"torturing",
"tori":"torus",
"toruses":"torus",
"tories":"tory",
"toscanas":"toscana",
"toshes":"tosh",
"tosks":"tosk",
"tose":"toss",
"tossed":"toss",
"tosses":"toss",
"tossing":"toss",
"tost":"toss",
"toss-ups":"toss-up",
"tostadas":"tostada",
"tots":"tot",
"totted":"tot",
"totting":"tot",
"totaled":"total",
"totaling":"total",
"totalled":"total",
"totalling":"total",
"totals":"total",
"totalisators":"totalisator",
"totalisers":"totaliser",
"totalisms":"totalism",
"totalitarians":"totalitarian",
"totalitarianisms":"totalitarianism",
"totalities":"totality",
"totalizators":"totalizator",
"totalized":"totalize",
"totalizing":"totalize",
"totalizers":"totalizer",
"totaras":"totara",
"toted":"tote",
"totes":"tote",
"toting":"tote",
"toters":"toter",
"tottered":"totter",
"tottering":"totter",
"totters":"totter",
"touched":"touch",
"touches":"touch",
"touching":"touch",
"touch-me-nots":"touch-me-not",
"touch-typed":"touch-type",
"touch-typing":"touch-type",
"touchinesses":"touchiness",
"touchings":"touching",
"touchstones":"touchstone",
"touchwoods":"touchwood",
"touchier":"touchy",
"touchiest":"touchy",
"tougher":"tough",
"toughest":"tough",
"toughs":"tough",
"toughened":"toughen",
"toughening":"toughen",
"toughies":"toughie",
"toughnesses":"toughness",
"toupes":"toupe",
"toupees":"toupee",
"toured":"tour",
"touring":"tour",
"tours":"tour",
"touracos":"touraco",
"tourers":"tourer",
"tourings":"touring",
"tourisms":"tourism",
"tourists":"tourist",
"touristries":"touristry",
"tournaments":"tournament",
"tourneyed":"tourney",
"tourneying":"tourney",
"tourneys":"tourney",
"tourniquets":"tourniquet",
"tousled":"tousle",
"tousles":"tousle",
"tousling":"tousle",
"touted":"tout",
"touting":"tout",
"touts":"tout",
"towed":"tow",
"towing":"tow",
"tows":"tow",
"towages":"towage",
"towboats":"towboat",
"toweled":"towel",
"toweling":"towel",
"towelled":"towel",
"towelling":"towel",
"towels":"towel",
"towelings":"toweling",
"towellings":"towelling",
"towered":"tower",
"towering":"tower",
"towers":"tower",
"towlines":"towline",
"towns":"town",
"townees":"townee",
"townies":"townie",
"towners":"towner",
"townsendias":"townsendia",
"townsfolks":"townsfolk",
"townships":"township",
"townsmen":"townsman",
"townspeoples":"townspeople",
"townswomen":"townswoman",
"towpaths":"towpath",
"towropes":"towrope",
"toxaemias":"toxaemia",
"toxemias":"toxemia",
"toxicities":"toxicity",
"toxicodendrons":"toxicodendron",
"toxostomas":"toxostoma",
"toxoteses":"toxotes",
"toxotidaes":"toxotidae",
"toyed":"toy",
"toying":"toy",
"toys":"toy",
"toyings":"toying",
"toyons":"toyon",
"tra-las":"tra-la",
"tra-la-las":"tra-la-la",
"trabeculae":"trabecula",
"traced":"trace",
"traces":"trace",
"tracing":"trace",
"tracers":"tracer",
"traceries":"tracery",
"tracheae":"trachea",
"tracheas":"trachea",
"trachelospermums":"trachelospermum",
"tracheophytas":"tracheophyta",
"tracheophytes":"tracheophyte",
"tracheostomies":"tracheostomy",
"tracheotomies":"tracheotomy",
"trachinotuses":"trachinotus",
"trachipteridaes":"trachipteridae",
"trachipteruses":"trachipterus",
"trachodons":"trachodon",
"trachodonts":"trachodont",
"trachuruses":"trachurus",
"tracings":"tracing",
"tracking":"track",
"tracks":"track",
"trackings":"tracking",
"tracklayers":"tracklayer",
"trackmen":"trackman",
"tracts":"tract",
"tractabilities":"tractability",
"tractablenesses":"tractableness",
"tractarianisms":"tractarianism",
"tractions":"traction",
"tractors":"tractor",
"traded":"trade",
"trades":"trade",
"trading":"trade",
"trademarked":"trademark",
"trademarking":"trademark",
"trademarks":"trademark",
"traders":"trader",
"tradescantias":"tradescantia",
"tradesmen":"tradesman",
"tradeswomen":"tradeswoman",
"traditions":"tradition",
"traditionalisms":"traditionalism",
"traditionalists":"traditionalist",
"traditionalities":"traditionality",
"traditores":"traditor",
"traditors":"traditor",
"traduced":"traduce",
"traduces":"traduce",
"traducing":"traduce",
"traducements":"traducement",
"traducers":"traducer",
"trafalgars":"trafalgar",
"trafficked":"traffic",
"trafficking":"traffic",
"traffics":"traffic",
"trafficators":"trafficator",
"traffickers":"trafficker",
"tragedies":"tragedy",
"tragelaphuses":"tragelaphus",
"tragicomedies":"tragicomedy",
"tragopogons":"tragopogon",
"tragulidaes":"tragulidae",
"traguluses":"tragulus",
"tragi":"tragus",
"trailed":"trail",
"trailing":"trail",
"trails":"trail",
"trailers":"trailer",
"trailings":"trailing",
"trained":"train",
"training":"train",
"trains":"train",
"trainers":"trainer",
"trainings":"training",
"trainmen":"trainman",
"trainmasters":"trainmaster",
"traipsed":"traipse",
"traipses":"traipse",
"traipsesd":"traipse",
"traipsing":"traipse",
"traits":"trait",
"traitors":"traitor",
"traitorousnesses":"traitorousness",
"trajectories":"trajectory",
"trammed":"tram",
"tramming":"tram",
"trams":"tram",
"tramcars":"tramcar",
"tramlines":"tramline",
"trammeled":"trammel",
"trammeling":"trammel",
"trammelled":"trammel",
"trammelling":"trammel",
"trammels":"trammel",
"trammelses":"trammels",
"tramontanas":"tramontana",
"tramontanes":"tramontane",
"tramped":"tramp",
"tramping":"tramp",
"tramps":"tramp",
"trampled":"trample",
"tramples":"trample",
"trampling":"trample",
"tramplings":"trampling",
"tramways":"tramway",
"tranced":"trance",
"trances":"trance",
"trancing":"trance",
"tranquiler":"tranquil",
"tranquilest":"tranquil",
"tranquiller":"tranquil",
"tranquillest":"tranquil",
"tranquilities":"tranquility",
"tranquilized":"tranquilize",
"tranquilizes":"tranquilize",
"tranquilizing":"tranquilize",
"tranquilizers":"tranquilizer",
"tranquillities":"tranquillity",
"tranquillized":"tranquillize",
"tranquillizes":"tranquillize",
"tranquillizing":"tranquillize",
"tranquillizers":"tranquillizer",
"transacted":"transact",
"transacting":"transact",
"transactions":"transaction",
"transactionses":"transactions",
"transactors":"transactor",
"transcended":"transcend",
"transcending":"transcend",
"transcends":"transcend",
"transcendences":"transcendence",
"transcendencies":"transcendency",
"transcendentalisms":"transcendentalism",
"transcribed":"transcribe",
"transcribes":"transcribe",
"transcribing":"transcribe",
"transcripts":"transcript",
"transcriptions":"transcription",
"transduced":"transduce",
"transducing":"transduce",
"transected":"transect",
"transecting":"transect",
"transferred":"transfer",
"transferring":"transfer",
"transfers":"transfer",
"transferences":"transference",
"transferrals":"transferral",
"transfigured":"transfigure",
"transfigures":"transfigure",
"transfiguring":"transfigure",
"transfixed":"transfix",
"transfixes":"transfix",
"transfixing":"transfix",
"transfixt":"transfix",
"transformed":"transform",
"transforming":"transform",
"transforms":"transform",
"transformations":"transformation",
"transformers":"transformer",
"transfused":"transfuse",
"transfuses":"transfuse",
"transfusing":"transfuse",
"transfusions":"transfusion",
"transgressed":"transgress",
"transgresses":"transgress",
"transgressing":"transgress",
"transgressions":"transgression",
"transgressors":"transgressor",
"transhipped":"tranship",
"transhipping":"tranship",
"tranships":"tranship",
"transiences":"transience",
"transiencies":"transiency",
"transients":"transient",
"transistors":"transistor",
"transistorized":"transistorize",
"transistorizing":"transistorize",
"transited":"transit",
"transiting":"transit",
"transits":"transit",
"transitions":"transition",
"transitivenesses":"transitiveness",
"transitivities":"transitivity",
"transitorinesses":"transitoriness",
"translated":"translate",
"translates":"translate",
"translating":"translate",
"translations":"translation",
"translators":"translator",
"transliterated":"transliterate",
"transliterates":"transliterate",
"transliterating":"transliterate",
"translocated":"translocate",
"translocating":"translocate",
"translucences":"translucence",
"translucencies":"translucency",
"transmigrated":"transmigrate",
"transmigrating":"transmigrate",
"transmissions":"transmission",
"transmits":"transmit",
"transmitted":"transmit",
"transmitting":"transmit",
"transmittals":"transmittal",
"transmittances":"transmittance",
"transmitters":"transmitter",
"transmittings":"transmitting",
"transmogrified":"transmogrify",
"transmogrifies":"transmogrify",
"transmogrifying":"transmogrify",
"transmutabilities":"transmutability",
"transmutations":"transmutation",
"transmuted":"transmute",
"transmutes":"transmute",
"transmuting":"transmute",
"transoms":"transom",
"transparences":"transparence",
"transparencies":"transparency",
"transparentnesses":"transparentness",
"transpierced":"transpierce",
"transpiercing":"transpierce",
"transpirations":"transpiration",
"transpired":"transpire",
"transpires":"transpire",
"transpiring":"transpire",
"transplanted":"transplant",
"transplanting":"transplant",
"transplants":"transplant",
"transplantations":"transplantation",
"transplanters":"transplanter",
"transplantings":"transplanting",
"transported":"transport",
"transporting":"transport",
"transports":"transport",
"transportations":"transportation",
"transporters":"transporter",
"transposabilities":"transposability",
"transposed":"transpose",
"transposes":"transpose",
"transposing":"transpose",
"transpositions":"transposition",
"tranship":"transship",
"transshipped":"transship",
"transshipping":"transship",
"transships":"transship",
"transubstantiated":"transubstantiate",
"transubstantiating":"transubstantiate",
"transubstantiations":"transubstantiation",
"transudations":"transudation",
"transvalued":"transvalue",
"transvalues":"transvalue",
"transvaluing":"transvalue",
"transversalises":"transversalis",
"transverses":"transverse",
"transversuses":"transversus",
"transvestisms":"transvestism",
"transvestites":"transvestite",
"transvestitisms":"transvestitism",
"trapped":"trap",
"trapping":"trap",
"traps":"trap",
"trapas":"trapa",
"trapaceaes":"trapaceae",
"trapanned":"trapan",
"trapanning":"trapan",
"trapans":"trapan",
"trapesed":"trapes",
"trapesing":"trapes",
"trapezia":"trapezium",
"trapeziums":"trapezium",
"trapeziuses":"trapezius",
"trapezohedra":"trapezohedron",
"trapezohedrons":"trapezohedron",
"trapezoids":"trapezoid",
"trappers":"trapper",
"trappings":"trapping",
"trappingses":"trappings",
"trappists":"trappist",
"trappier":"trappy",
"trappiest":"trappy",
"trapshootings":"trapshooting",
"trapuntos":"trapunto",
"trashed":"trash",
"trashes":"trash",
"trashing":"trash",
"trashinesses":"trashiness",
"trashier":"trashy",
"trashiest":"trashy",
"trattorias":"trattoria",
"traumas":"trauma",
"traumata":"trauma",
"traumatized":"traumatize",
"traumatizes":"traumatize",
"traumatizing":"traumatize",
"trautvetterias":"trautvetteria",
"travailed":"travail",
"travailing":"travail",
"travails":"travail",
"traves":"trave",
"traveled":"travel",
"traveling":"travel",
"travelled":"travel",
"travelling":"travel",
"travels":"travel",
"travelers":"traveler",
"travelings":"traveling",
"travellers":"traveller",
"travellings":"travelling",
"travelogs":"travelog",
"travelogues":"travelogue",
"traversals":"traversal",
"traversed":"traverse",
"traverses":"traverse",
"traversing":"traverse",
"traversers":"traverser",
"travestied":"travesty",
"travesties":"travesty",
"travestying":"travesty",
"trawled":"trawl",
"trawling":"trawl",
"trawls":"trawl",
"trawlers":"trawler",
"trays":"tray",
"treacheries":"treachery",
"treacles":"treacle",
"treading":"tread",
"treads":"tread",
"trod":"tread",
"trodden":"tread",
"tread-softlies":"tread-softly",
"treadled":"treadle",
"treadles":"treadle",
"treadling":"treadle",
"treadmills":"treadmill",
"treadwheels":"treadwheel",
"treasons":"treason",
"treasonists":"treasonist",
"treasured":"treasure",
"treasures":"treasure",
"treasuring":"treasure",
"treasurers":"treasurer",
"treasurieses":"treasuries",
"treasuries":"treasury",
"treated":"treat",
"treating":"treat",
"treats":"treat",
"treatises":"treatise",
"treatments":"treatment",
"treaties":"treaty",
"trebled":"treble",
"trebles":"treble",
"trebling":"treble",
"tredecillions":"tredecillion",
"treed":"tree",
"treeing":"tree",
"trees":"tree",
"tree-worships":"tree-worship",
"treefrogs":"treefrog",
"treenails":"treenail",
"treetops":"treetop",
"trefoils":"trefoil",
"treillages":"treillage",
"trekked":"trek",
"trekking":"trek",
"treks":"trek",
"trellised":"trellis",
"trellises":"trellis",
"trellising":"trellis",
"trematodas":"trematoda",
"trematodes":"trematode",
"trembled":"tremble",
"trembles":"tremble",
"trembling":"tremble",
"trembleses":"trembles",
"tremblings":"trembling",
"tremblier":"trembly",
"trembliest":"trembly",
"tremellas":"tremella",
"tremellaceaes":"tremellaceae",
"tremellaleses":"tremellales",
"tremolos":"tremolo",
"tremored":"tremor",
"tremoring":"tremor",
"tremors":"tremor",
"trenails":"trenail",
"trenched":"trench",
"trenches":"trench",
"trenching":"trench",
"trenchancies":"trenchancy",
"trenchers":"trencher",
"trenchermen":"trencherman",
"trenchfeet":"trenchfoot",
"trended":"trend",
"trending":"trend",
"trends":"trend",
"trend-setters":"trend-setter",
"trendier":"trendy",
"trendiest":"trendy",
"trente-et-quarantes":"trente-et-quarante",
"trentons":"trenton",
"trepanned":"trepan",
"trepanning":"trepan",
"trepans":"trepan",
"trepangs":"trepang",
"trephined":"trephine",
"trephines":"trephine",
"trephining":"trephine",
"trephritidaes":"trephritidae",
"nemata":"treponema",
"trepnemata":"treponema",
"treponemas":"treponema",
"treponemata":"treponema",
"treponemataceaes":"treponemataceae",
"treponemes":"treponeme",
"trespassed":"trespass",
"trespasses":"trespass",
"trespassing":"trespass",
"trespassers":"trespasser",
"tresses":"tress",
"treys":"trey",
"triacetates":"triacetate",
"triads":"triad",
"triaenodons":"triaenodon",
"triakidaes":"triakidae",
"trials":"trial",
"trialeurodeses":"trialeurodes",
"triangles":"triangle",
"triangulated":"triangulate",
"triangulating":"triangulate",
"triarchies":"triarchy",
"triassics":"triassic",
"triatomas":"triatoma",
"tribes":"tribe",
"tribesmen":"tribesman",
"triboliums":"tribolium",
"tribonemas":"tribonema",
"tribonemaceaes":"tribonemaceae",
"tribromoethanols":"tribromoethanol",
"tribulations":"tribulation",
"tribuluses":"tribulus",
"tribunals":"tribunal",
"tribunes":"tribune",
"tributaries":"tributary",
"tributes":"tribute",
"triced":"trice",
"trices":"trice",
"tricing":"trice",
"tricepses":"triceps",
"trichechidaes":"trichechidae",
"trichechuses":"trichechus",
"trichinae":"trichina",
"trichions":"trichion",
"trichiuridaes":"trichiuridae",
"trichloromethanes":"trichloromethane",
"trichoceroses":"trichoceros",
"trichodontidaes":"trichodontidae",
"trichoglossuses":"trichoglossus",
"tricholomas":"tricholoma",
"tricholomataceaes":"tricholomataceae",
"trichomaneses":"trichomanes",
"trichophagas":"trichophaga",
"trichophytons":"trichophyton",
"trichopteras":"trichoptera",
"trichopterans":"trichopteran",
"trichopterons":"trichopteron",
"trichostemas":"trichostema",
"trichosuruses":"trichosurus",
"trichotomies":"trichotomy",
"trichyses":"trichys",
"tricked":"trick",
"tricking":"trick",
"tricks":"trick",
"trick-or-treated":"trick-or-treat",
"trick-or-treating":"trick-or-treat",
"trickeries":"trickery",
"trickinesses":"trickiness",
"trickled":"trickle",
"trickles":"trickle",
"trickling":"trickle",
"tricksters":"trickster",
"tricksier":"tricksy",
"tricksiest":"tricksy",
"trickier":"tricky",
"trickiest":"tricky",
"triclinia":"triclinium",
"tricliniia":"triclinium",
"tricolors":"tricolor",
"tricolours":"tricolour",
"tricorns":"tricorn",
"tricornes":"tricorne",
"tricycles":"tricycle",
"tricyclics":"tricyclic",
"tridacnas":"tridacna",
"tridacnidaes":"tridacnidae",
"triennials":"triennial",
"triennia":"triennium",
"trienniums":"triennium",
"trierarchies":"trierarchy",
"trifled":"trifle",
"trifles":"trifle",
"trifling":"trifle",
"triflings":"trifling",
"trifoliatas":"trifoliata",
"trifoliums":"trifolium",
"triforia":"triforium",
"trigs":"trig",
"trigas":"triga",
"trigeminals":"trigeminal",
"triggered":"trigger",
"triggering":"trigger",
"triggers":"trigger",
"triggerfishes":"triggerfish",
"triggermen":"triggerman",
"triglidaes":"triglidae",
"triglinaes":"triglinae",
"triglochins":"triglochin",
"trigons":"trigon",
"trigonellas":"trigonella",
"trigonometries":"trigonometry",
"trihedra":"trihedron",
"trihedrons":"trihedron",
"triiodomethanes":"triiodomethane",
"trikes":"trike",
"trilaterals":"trilateral",
"trilbies":"trilby",
"trilisas":"trilisa",
"trilled":"trill",
"trilling":"trill",
"trills":"trill",
"trilliaceaes":"trilliaceae",
"trillions":"trillion",
"trillionses":"trillions",
"trillionths":"trillionth",
"trilliums":"trillium",
"trilogies":"trilogy",
"trimmed":"trim",
"trimmer":"trim",
"trimmest":"trim",
"trimming":"trim",
"trims":"trim",
"trimmers":"trimmer",
"trimmings":"trimming",
"trimnesses":"trimness",
"trimorphodons":"trimorphodon",
"trines":"trine",
"trinecteses":"trinectes",
"tringas":"tringa",
"trinitroglycerins":"trinitroglycerin",
"trinitrotoluenes":"trinitrotoluene",
"trinities":"trinity",
"trinkets":"trinket",
"trios":"trio",
"trioleins":"triolein",
"trionychidaes":"trionychidae",
"trionyxes":"trionyx",
"triopidaes":"triopidae",
"triopses":"triops",
"triostiums":"triostium",
"tripped":"trip",
"tripping":"trip",
"trips":"trip",
"tripalmitins":"tripalmitin",
"tripes":"tripe",
"tripled":"triple",
"triples":"triple",
"tripling":"triple",
"triplets":"triplet",
"tripletails":"tripletail",
"tripleurospermums":"tripleurospermum",
"triplicated":"triplicate",
"triplicating":"triplicate",
"triplicities":"triplicity",
"triplochitons":"triplochiton",
"tripods":"tripod",
"tripodies":"tripody",
"tripolis":"tripoli",
"triposes":"tripos",
"trippers":"tripper",
"tripple-deckers":"tripple-decker",
"triquetrals":"triquetral",
"trisected":"trisect",
"trisecting":"trisect",
"triskeles":"triskele",
"triskelia":"triskelion",
"trisoctahedra":"trisoctahedron",
"trisoctahedrons":"trisoctahedron",
"tristans":"tristan",
"tristearins":"tristearin",
"tristrams":"tristram",
"tritanopias":"tritanopia",
"triter":"trite",
"tritest":"trite",
"tritenesses":"triteness",
"triticums":"triticum",
"tritomas":"tritoma",
"tritons":"triton",
"triturated":"triturate",
"triturating":"triturate",
"trituruses":"triturus",
"triumphed":"triumph",
"triumphing":"triumph",
"triumphs":"triumph",
"triumviri":"triumvir",
"triumvirs":"triumvir",
"trivias":"trivia",
"trivialities":"triviality",
"trivialized":"trivialize",
"trivializing":"trivialize",
"triviia":"trivium",
"triweeklies":"triweekly",
"trms":"trm",
"trnas":"trna",
"troches":"troche",
"trochilidaes":"trochilidae",
"trochleae":"trochlea",
"trochlears":"trochlear",
"trochlearises":"trochlearis",
"trogged":"trog",
"trogging":"trog",
"trogs":"trog",
"trogiums":"trogium",
"troglodytes":"troglodyte",
"troglodyteses":"troglodytes",
"troglodytidaes":"troglodytidae",
"trogonidaes":"trogonidae",
"trogoniformeses":"trogoniformes",
"troikas":"troika",
"trolled":"troll",
"trolling":"troll",
"trolls":"troll",
"trollers":"troller",
"trolleyed":"trolley",
"trolleying":"trolley",
"trolleys":"trolley",
"trolleybuses":"trolleybus",
"trolliuses":"trollius",
"trollops":"trollop",
"trombiculas":"trombicula",
"trombiculidaes":"trombiculidae",
"trombidiidaes":"trombidiidae",
"trombonists":"trombonist",
"trompillos":"trompillo",
"trondheims":"trondheim",
"trooped":"troop",
"trooping":"troop",
"troops":"troop",
"troopers":"trooper",
"troopses":"troops",
"tropaeolaceaes":"tropaeolaceae",
"tropaeolums":"tropaeolum",
"tropes":"trope",
"trophies":"trophy",
"tropics":"tropic",
"tropicbirds":"tropicbird",
"tropicses":"tropics",
"tropidoclonions":"tropidoclonion",
"tropologies":"tropology",
"troponyms":"troponym",
"trots":"trot",
"trotted":"trot",
"trotting":"trot",
"trothed":"troth",
"trothing":"troth",
"troths":"troth",
"trotters":"trotter",
"trous-de-loup":"trou-de-loup",
"troubadours":"troubadour",
"troubles":"trouble",
"troubling":"trouble",
"troublemakers":"troublemaker",
"troubleshooters":"troubleshooter",
"troublesomenesses":"troublesomeness",
"troublings":"troubling",
"troughs":"trough",
"trounced":"trounce",
"trounces":"trounce",
"trouncing":"trounce",
"trouncings":"trouncing",
"trouped":"troupe",
"troupes":"troupe",
"trouping":"troupe",
"troupers":"trouper",
"trouserings":"trousering",
"trouserses":"trousers",
"trousseaus":"trousseau",
"trousseaux":"trousseau",
"trouts":"trout",
"troves":"trove",
"trowed":"trow",
"trowing":"trow",
"troweled":"trowel",
"troweling":"trowel",
"trowelled":"trowel",
"trowelling":"trowel",
"trowels":"trowel",
"troys":"troy",
"truancies":"truancy",
"truanted":"truant",
"truanting":"truant",
"truants":"truant",
"truces":"truce",
"trucked":"truck",
"trucking":"truck",
"trucks":"truck",
"truckers":"trucker",
"truckings":"trucking",
"truckled":"truckle",
"truckles":"truckle",
"truckling":"truckle",
"trucklers":"truckler",
"truckmen":"truckman",
"truculences":"truculence",
"truculencies":"truculency",
"trudged":"trudge",
"trudges":"trudge",
"trudging":"trudge",
"trued":"true",
"trueing":"true",
"truer":"true",
"trues":"true",
"truest":"true",
"truing":"true",
"trueloves":"truelove",
"truffles":"truffle",
"trumen":"truman",
"trumped":"trump",
"trumping":"trump",
"trumps":"trump",
"trumperies":"trumpery",
"trumpeted":"trumpet",
"trumpeting":"trumpet",
"trumpets":"trumpet",
"trumpeters":"trumpeter",
"trumpetfishes":"trumpetfish",
"trumpetses":"trumpets",
"trumpetwoods":"trumpetwood",
"trumpings":"trumping",
"truncated":"truncate",
"truncates":"truncate",
"truncating":"truncate",
"truncations":"truncation",
"truncheoned":"truncheon",
"truncheoning":"truncheon",
"truncheons":"truncheon",
"truncocolumellas":"truncocolumella",
"trundled":"trundle",
"trundles":"trundle",
"trundling":"trundle",
"trunked":"trunk",
"trunking":"trunk",
"trunks":"trunk",
"trunkfishes":"trunkfish",
"trunkses":"trunks",
"trunnels":"trunnel",
"trussed":"truss",
"trusses":"truss",
"trussing":"truss",
"trusted":"trust",
"trusting":"trust",
"trusts":"trust",
"trusteed":"trustee",
"trusteeing":"trustee",
"trustees":"trustee",
"trusteeships":"trusteeship",
"trustfulnesses":"trustfulness",
"trustinesses":"trustiness",
"trustingnesses":"trustingness",
"trustworthinesses":"trustworthiness",
"trustworthier":"trustworthy",
"trustworthiest":"trustworthy",
"trustier":"trusty",
"trusties":"trusty",
"trustiest":"trusty",
"truths":"truth",
"tried":"try",
"tries":"try",
"trying":"try",
"try-ons":"try-on",
"trymata":"tryma",
"tryouts":"tryout",
"trypetidaes":"trypetidae",
"tryptophans":"tryptophan",
"tryptophanes":"tryptophane",
"trysted":"tryst",
"trysting":"tryst",
"trysts":"tryst",
"tsars":"tsar",
"tsarinas":"tsarina",
"tsaritsas":"tsaritsa",
"tsaritsyns":"tsaritsyn",
"tsetses":"tsetse",
"tshes":"tsh",
"tsines":"tsine",
"tsongas":"tsonga",
"tsugas":"tsuga",
"tsunamis":"tsunami",
"tswanas":"tswana",
"tts":"tt",
"tuaregs":"tuareg",
"tuataras":"tuatara",
"tubbed":"tub",
"tubbing":"tub",
"tubs":"tub",
"tub-carts":"tub-cart",
"tubas":"tuba",
"tubbinesses":"tubbiness",
"tubbier":"tubby",
"tubbiest":"tubby",
"tubed":"tube",
"tubes":"tube",
"tubing":"tube",
"tubelesses":"tubeless",
"tubers":"tuber",
"tuberaceaes":"tuberaceae",
"tuberaleses":"tuberales",
"tubercles":"tubercle",
"tubercularias":"tubercularia",
"tuberculariaceaes":"tuberculariaceae",
"tuberculoses":"tuberculosis",
"tuberoses":"tuberose",
"tuberosities":"tuberosity",
"tubfuls":"tubful",
"tubifexes":"tubifex",
"tubings":"tubing",
"tubocurarines":"tubocurarine",
"tubulidentatas":"tubulidentata",
"tucked":"tuck",
"tucking":"tuck",
"tucks":"tuck",
"tuckahoes":"tuckahoe",
"tuckered":"tucker",
"tuckering":"tucker",
"tuckers":"tucker",
"tudors":"tudor",
"tueses":"tues",
"tuesdays":"tuesday",
"tufted":"tuft",
"tufting":"tuft",
"tufts":"tuft",
"tugged":"tug",
"tugging":"tug",
"tugs":"tug",
"tugboats":"tugboat",
"tugelas":"tugela",
"tughriks":"tughrik",
"tugriks":"tugrik",
"tuitions":"tuition",
"tularaemias":"tularaemia",
"tularemias":"tularemia",
"tulestomas":"tulestoma",
"tulips":"tulip",
"tulipas":"tulipa",
"tulipwoods":"tulipwood",
"tullies":"tully",
"tulostomas":"tulostoma",
"tulostomaceaes":"tulostomaceae",
"tulostomataceaes":"tulostomataceae",
"tulostomataleses":"tulostomatales",
"tums":"tum",
"tumbled":"tumble",
"tumbles":"tumble",
"tumbling":"tumble",
"tumblers":"tumbler",
"tumbleweds":"tumblewed",
"tumbleweeds":"tumbleweed",
"tumblings":"tumbling",
"tumbrels":"tumbrel",
"tumbrils":"tumbril",
"tumefied":"tumefy",
"tumefies":"tumefy",
"tumefying":"tumefy",
"tumescences":"tumescence",
"tumidities":"tumidity",
"tumidnesses":"tumidness",
"tummies":"tummy",
"tumors":"tumor",
"tumours":"tumour",
"tumults":"tumult",
"tumultuousnesses":"tumultuousness",
"tumuli":"tumulus",
"tumuluses":"tumulus",
"tunned":"tun",
"tunning":"tun",
"tuns":"tun",
"tunas":"tuna",
"tundras":"tundra",
"tuned":"tune",
"tunes":"tune",
"tuning":"tune",
"tune-ups":"tune-up",
"tunefulnesses":"tunefulness",
"tuners":"tuner",
"tungs":"tung",
"tungas":"tunga",
"tungstens":"tungsten",
"Tunguses":"Tungus",
"tungusics":"tungusic",
"tunguzs":"tunguz",
"tunics":"tunic",
"tunicas":"tunica",
"tunicatas":"tunicata",
"tunicates":"tunicate",
"tunises":"tunis",
"tunkers":"tunker",
"tunnages":"tunnage",
"tunneled":"tunnel",
"tunneling":"tunnel",
"tunnelled":"tunnel",
"tunnelling":"tunnel",
"tunnels":"tunnel",
"tunnies":"tunny",
"tups":"tup",
"tupaias":"tupaia",
"tupaiidaes":"tupaiidae",
"tupamaros":"tupamaro",
"tupeks":"tupek",
"tupelos":"tupelo",
"tupis":"tupi",
"tupi-guaranis":"tupi-guarani",
"tupiks":"tupik",
"tupinambises":"tupinambis",
"tuppences":"tuppence",
"turacos":"turaco",
"turacous":"turacou",
"turakoos":"turakoo",
"turbans":"turban",
"turbaries":"turbary",
"turbatrixes":"turbatrix",
"turbellarias":"turbellaria",
"turbidities":"turbidity",
"turbidnesses":"turbidness",
"turbinals":"turbinal",
"turbinates":"turbinate",
"turbofans":"turbofan",
"turbojets":"turbojet",
"turboprops":"turboprop",
"turbots":"turbot",
"turbulences":"turbulence",
"turbulencies":"turbulency",
"turcos":"turco",
"turcomen":"turcoman",
"turds":"turd",
"turdidaes":"turdidae",
"turdinaes":"turdinae",
"turduses":"turdus",
"turfed":"turf",
"turfing":"turf",
"turfs":"turf",
"turves":"turf",
"turfans":"turfan",
"turfmen":"turfman",
"turfier":"turfy",
"turfiest":"turfy",
"turgidities":"turgidity",
"turgidnesses":"turgidness",
"turins":"turin",
"turkestans":"turkestan",
"turkeys":"turkey",
"turkis":"turki",
"turkics":"turkic",
"turkistans":"turkistan",
"turkmen":"turkman",
"Turkmens":"Turkmen",
"turkmenias":"turkmenia",
"turkmenistans":"turkmenistan",
"turko-tatars":"turko-tatar",
"turkomen":"turkoman",
"turkomens":"turkomen",
"turmerics":"turmeric",
"turmoils":"turmoil",
"turned":"turn",
"turning":"turn",
"turns":"turn",
"turnabouts":"turnabout",
"turnarounds":"turnaround",
"turncoats":"turncoat",
"turncocks":"turncock",
"turndowns":"turndown",
"turners":"turner",
"turneries":"turnery",
"turnicidaes":"turnicidae",
"turnings":"turning",
"turnips":"turnip",
"turnixes":"turnix",
"turnkeys":"turnkey",
"turnoffs":"turnoff",
"turnouts":"turnout",
"turnovers":"turnover",
"turnpikes":"turnpike",
"turnrounds":"turnround",
"turntables":"turntable",
"turnups":"turnup",
"turpentined":"turpentine",
"turpentines":"turpentine",
"turpentining":"turpentine",
"turpitudes":"turpitude",
"turpses":"turps",
"turquoises":"turquoise",
"turrets":"turret",
"turritises":"turritis",
"tursiopses":"tursiops",
"turtles":"turtle",
"turtledoves":"turtledove",
"turtleheads":"turtlehead",
"turtlenecks":"turtleneck",
"tuscanies":"tuscany",
"tuscaroras":"tuscarora",
"tushes":"tush",
"tusked":"tusk",
"tusking":"tusk",
"tusks":"tusk",
"tussahs":"tussah",
"tussehs":"tusseh",
"tussers":"tusser",
"tussilagos":"tussilago",
"tussled":"tussle",
"tussles":"tussle",
"tussling":"tussle",
"tussocks":"tussock",
"tussores":"tussore",
"tussurs":"tussur",
"tuts":"tut",
"tutted":"tut",
"tutting":"tut",
"tut-tuts":"tut-tut",
"tut-tutted":"tut-tut",
"tut-tutting":"tut-tut",
"tutelages":"tutelage",
"tutelars":"tutelar",
"tutelaries":"tutelary",
"tutelarlaries":"tutelary",
"tutored":"tutor",
"tutoring":"tutor",
"tutors":"tutor",
"tutorings":"tutoring",
"tutorships":"tutorship",
"tutsans":"tutsan",
"tutsis":"tutsi",
"tuttis":"tutti",
"tutus":"tutu",
"tuvalus":"tuvalu",
"tuxes":"tux",
"tuxedoes":"tuxedo",
"tuxedos":"tuxedo",
"tvs":"tv",
"tv-antennas":"tv-antenna",
"twaddled":"twaddle",
"twaddles":"twaddle",
"twaddling":"twaddle",
"twains":"twain",
"twanged":"twang",
"twanging":"twang",
"twangs":"twang",
"twayblades":"twayblade",
"tweaked":"tweak",
"tweaking":"tweak",
"tweaks":"tweak",
"tweeds":"tweed",
"tweedinesses":"tweediness",
"tweedier":"tweedy",
"tweediest":"tweedy",
"tweenies":"tweeny",
"tweeted":"tweet",
"tweeting":"tweet",
"tweets":"tweet",
"tweezers":"tweezer",
"twelfths":"twelfth",
"twelves":"twelve",
"twelvemos":"twelvemo",
"twelvemonths":"twelvemonth",
"twentieses":"twenties",
"twentieths":"twentieth",
"twenties":"twenty",
"twenty-eights":"twenty-eight",
"twenty-fives":"twenty-five",
"twenty-fours":"twenty-four",
"twenty-nines":"twenty-nine",
"twenty-ones":"twenty-one",
"twenty-sevens":"twenty-seven",
"twenty-sixes":"twenty-six",
"twenty-threes":"twenty-three",
"twenty-twos":"twenty-two",
"twerps":"twerp",
"twis":"twi",
"twiddled":"twiddle",
"twiddles":"twiddle",
"twiddling":"twiddle",
"twigged":"twig",
"twigging":"twig",
"twigs":"twig",
"twiggier":"twiggy",
"twiggiest":"twiggy",
"twilights":"twilight",
"twilled":"twill",
"twilling":"twill",
"twills":"twill",
"twinned":"twin",
"twinning":"twin",
"twins":"twin",
"twin-props":"twin-prop",
"twin-propeller-planes":"twin-propeller-plane",
"twinberries":"twinberry",
"twined":"twine",
"twines":"twine",
"twining":"twine",
"twinflowers":"twinflower",
"twinged":"twinge",
"twinges":"twinge",
"twinging":"twinge",
"twinkled":"twinkle",
"twinkles":"twinkle",
"twinkling":"twinkle",
"twinklings":"twinkling",
"twirled":"twirl",
"twirling":"twirl",
"twirls":"twirl",
"twirlers":"twirler",
"twirps":"twirp",
"twisted":"twist",
"twisting":"twist",
"twists":"twist",
"twisters":"twister",
"twistings":"twisting",
"twistwoods":"twistwood",
"twits":"twit",
"twitted":"twit",
"twitting":"twit",
"twitched":"twitch",
"twitches":"twitch",
"twitching":"twitch",
"twitchings":"twitching",
"twittered":"twitter",
"twittering":"twitter",
"twitters":"twitter",
"twittings":"twitting",
"twos":"two",
"two-baggers":"two-bagger",
"two-basers":"two-baser",
"two-dimensionalities":"two-dimensionality",
"two-hitters":"two-hitter",
"two-pieces":"two-piece",
"two-plies":"two-ply",
"two-seaters":"two-seater",
"two-timed":"two-time",
"two-timing":"two-time",
"twopences":"twopence",
"twosomes":"twosome",
"tycoons":"tycoon",
"tykes":"tyke",
"tylenchidaes":"tylenchidae",
"tylenchuses":"tylenchus",
"tylenols":"tylenol",
"tylers":"tyler",
"tympans":"tympan",
"tympanis":"tympani",
"tympanists":"tympanist",
"tympanuchuses":"tympanuchus",
"tympana":"tympanum",
"tympanums":"tympanum",
"tympanies":"tympany",
"tynes":"tyne",
"typed":"type",
"types":"type",
"typing":"type",
"typecasting":"typecast",
"typecasts":"typecast",
"typecastsa":"typecast",
"typefaces":"typeface",
"typesets":"typeset",
"typesetting":"typeset",
"typesetters":"typesetter",
"typewrites":"typewrite",
"typewriting":"typewrite",
"typewritten":"typewrite",
"typewrote":"typewrite",
"typewriters":"typewriter",
"typewritings":"typewriting",
"typhas":"typha",
"typhaceaes":"typhaceae",
"typhlopidaes":"typhlopidae",
"typhoids":"typhoid",
"typhoons":"typhoon",
"typhuses":"typhus",
"typifications":"typification",
"typified":"typify",
"typifies":"typify",
"typifying":"typify",
"typifyings":"typifying",
"typings":"typing",
"typists":"typist",
"typos":"typo",
"typographers":"typographer",
"typographies":"typography",
"tyrs":"tyr",
"tyrannis":"tyranni",
"tyrannidaes":"tyrannidae",
"tyrannized":"tyrannize",
"tyrannizes":"tyrannize",
"tyrannizing":"tyrannize",
"tyrannosaurs":"tyrannosaur",
"tyrannosauruses":"tyrannosaurus",
"tyrannuses":"tyrannus",
"tyrannies":"tyranny",
"tyrants":"tyrant",
"tyred":"tyre",
"tyres":"tyre",
"tyring":"tyre",
"tyros":"tyro",
"tyrocidins":"tyrocidin",
"tyrocidines":"tyrocidine",
"tyrols":"tyrol",
"tyrrs":"tyrr",
"tytos":"tyto",
"tytonidaes":"tytonidae",
"tzars":"tzar",
"tzarinas":"tzarina",
"tzetzes":"tzetze",
"u-boats":"u-boat",
"ubermensches":"ubermensch",
"ubiquitousnesses":"ubiquitousness",
"ubiquities":"ubiquity",
"ucas":"uca",
"udders":"udder",
"udmurts":"udmurt",
"udos":"udo",
"ufos":"ufo",
"uglis":"ugli",
"uglified":"uglify",
"uglifies":"uglify",
"uglifying":"uglify",
"uglier":"ugly",
"ugliest":"ugly",
"ugrians":"ugrian",
"ugrics":"ugric",
"uhfs":"uhf",
"uighurs":"uighur",
"uigurs":"uigur",
"uintatheres":"uintathere",
"uintatheriidaes":"uintatheriidae",
"uintatheriums":"uintatherium",
"uks":"uk",
"ukes":"uke",
"ukraines":"ukraine",
"ukrayinas":"ukrayina",
"ukuleles":"ukulele",
"ulaanbaatars":"ulaanbaatar",
"ulcers":"ulcer",
"ulcerated":"ulcerate",
"ulcerating":"ulcerate",
"ulcerations":"ulceration",
"ulexes":"ulex",
"ulfilas":"ulfila",
"ulfilases":"ulfilas",
"ulls":"ull",
"ullrs":"ullr",
"ulmaceaes":"ulmaceae",
"ulmuses":"ulmus",
"ulnae":"ulna",
"ulnas":"ulna",
"ulstermen":"ulsterman",
"ultimas":"ultima",
"ultimacies":"ultimacy",
"ultimates":"ultimate",
"ultimatenesses":"ultimateness",
"ultimata":"ultimatum",
"ultimatums":"ultimatum",
"ultras":"ultra",
"ultracentrifuged":"ultracentrifuge",
"ultracentrifuging":"ultracentrifuge",
"ultraconservatives":"ultraconservative",
"ultramarines":"ultramarine",
"ultramicroscopes":"ultramicroscope",
"ultranationalisms":"ultranationalism",
"ultrasonographies":"ultrasonography",
"ultrasuedes":"ultrasuede",
"ultraviolets":"ultraviolet",
"ululated":"ululate",
"ululates":"ululate",
"ululating":"ululate",
"ululations":"ululation",
"ulvas":"ulva",
"ulvaceaes":"ulvaceae",
"ulvaleses":"ulvales",
"ulvophyceaes":"ulvophyceae",
"ulysseses":"ulysses",
"umas":"uma",
"umbellaleses":"umbellales",
"umbellifers":"umbellifer",
"umbelliferaes":"umbelliferae",
"umbellularias":"umbellularia",
"umbers":"umber",
"umbilici":"umbilicus",
"umbilicuses":"umbilicus",
"umbones":"umbo",
"umbos":"umbo",
"umbrae":"umbra",
"umbras":"umbra",
"umbrages":"umbrage",
"umbrellas":"umbrella",
"umbrinas":"umbrina",
"umlauted":"umlaut",
"umlauting":"umlaut",
"umlauts":"umlaut",
"umps":"ump",
"umpirages":"umpirage",
"umpired":"umpire",
"umpires":"umpire",
"umpiring":"umpire",
"umpirings":"umpiring",
"umpies":"umpy",
"uns":"un",
"unacceptabilities":"unacceptability",
"unacceptablenesses":"unacceptableness",
"unalterabilities":"unalterability",
"unambiguities":"unambiguity",
"unarmed":"unarm",
"unarming":"unarm",
"unarms":"unarm",
"unassumingnesses":"unassumingness",
"unaus":"unau",
"unavailabilities":"unavailability",
"unawarenesses":"unawareness",
"unbalanced":"unbalance",
"unbalances":"unbalance",
"unbalancing":"unbalance",
"unbarred":"unbar",
"unbarring":"unbar",
"unbars":"unbar",
"unbeliefs":"unbelief",
"unbelieves":"unbelief",
"unbelievers":"unbeliever",
"unbending":"unbend",
"unbends":"unbend",
"unbent":"unbend",
"unbinding":"unbind",
"unbinds":"unbind",
"unbound":"unbind",
"unbolted":"unbolt",
"unbolting":"unbolt",
"unbosomed":"unbosom",
"unbosoming":"unbosom",
"unbosoms":"unbosom",
"unboundednesses":"unboundedness",
"unbraced":"unbrace",
"unbraces":"unbrace",
"unbracing":"unbrace",
"unbraided":"unbraid",
"unbraiding":"unbraid",
"unbuckled":"unbuckle",
"unbuckling":"unbuckle",
"unbuilding":"unbuild",
"unbuilt":"unbuild",
"unburdened":"unburden",
"unburdening":"unburden",
"unburdens":"unburden",
"unbuttoned":"unbutton",
"unbuttoning":"unbutton",
"uncaged":"uncage",
"uncaging":"uncage",
"uncannier":"uncanny",
"uncanniest":"uncanny",
"uncapped":"uncap",
"uncapping":"uncap",
"uncaps":"uncap",
"uncertainnesses":"uncertainness",
"uncertainties":"uncertainty",
"unchained":"unchain",
"unchaining":"unchain",
"unchangeabilities":"unchangeability",
"unchangeablenesses":"unchangeableness",
"unchangingnesses":"unchangingness",
"uncheerfulnesses":"uncheerfulness",
"uncicini":"uncinus",
"unclasped":"unclasp",
"unclasping":"unclasp",
"uncles":"uncle",
"uncleaner":"unclean",
"uncleanest":"unclean",
"uncleanlier":"uncleanly",
"uncleanliest":"uncleanly",
"uncleannesses":"uncleanness",
"uncloaked":"uncloak",
"uncloaking":"uncloak",
"uncloaks":"uncloak",
"unclogged":"unclog",
"unclogging":"unclog",
"unclogs":"unclog",
"unclosed":"unclose",
"unclosing":"unclose",
"unclad":"unclothe",
"unclothed":"unclothe",
"unclothes":"unclothe",
"unclothing":"unclothe",
"uncloudednesses":"uncloudedness",
"uncoes":"unco",
"uncos":"unco",
"uncoiled":"uncoil",
"uncoiling":"uncoil",
"uncomfortablenesses":"uncomfortableness",
"uncommoner":"uncommon",
"uncommonest":"uncommon",
"unconcerns":"unconcern",
"unconformities":"unconformity",
"unconsciouses":"unconscious",
"unconstraints":"unconstraint",
"uncorked":"uncork",
"uncorking":"uncork",
"uncoupled":"uncouple",
"uncoupling":"uncouple",
"uncouthnesses":"uncouthness",
"uncovered":"uncover",
"uncovering":"uncover",
"uncovers":"uncover",
"uncoverings":"uncovering",
"uncrossed":"uncross",
"uncrossing":"uncross",
"unctions":"unction",
"unctuousnesses":"unctuousness",
"uncurled":"uncurl",
"uncurling":"uncurl",
"unci":"uncus",
"undeceived":"undeceive",
"undeceiving":"undeceive",
"undecillions":"undecillion",
"undependabilities":"undependability",
"undependablenesses":"undependableness",
"underachieved":"underachieve",
"underachieving":"underachieve",
"underacted":"underact",
"underacting":"underact",
"underacts":"underact",
"underbellies":"underbelly",
"underbidding":"underbid",
"underbids":"underbid",
"underbodices":"underbodice",
"underbodies":"underbody",
"underbrushes":"underbrush",
"underbought":"underbuy",
"underbuying":"underbuy",
"underbuys":"underbuy",
"undercapitalized":"undercapitalize",
"undercapitalizing":"undercapitalize",
"undercharged":"undercharge",
"undercharging":"undercharge",
"underclassmen":"underclassman",
"underclotheses":"underclothes",
"underclothings":"underclothing",
"undercoats":"undercoat",
"undercurrents":"undercurrent",
"undercuts":"undercut",
"undercutting":"undercut",
"underdeveloped":"underdevelop",
"underdeveloping":"underdevelop",
"underdid":"underdo",
"underdoing":"underdo",
"underdone":"underdo",
"underdogs":"underdog",
"underdressed":"underdress",
"underdresses":"underdress",
"underdressing":"underdress",
"underemphasized":"underemphasize",
"underemphasizing":"underemphasize",
"underestimated":"underestimate",
"underestimates":"underestimate",
"underestimating":"underestimate",
"underestimations":"underestimation",
"underexposed":"underexpose",
"underexposing":"underexpose",
"underfed":"underfeed",
"underfeeding":"underfeed",
"underfeeds":"underfeed",
"underframes":"underframe",
"underfurs":"underfur",
"undergirded":"undergird",
"undergirding":"undergird",
"undergirds":"undergird",
"undergirt":"undergird",
"undergurded":"undergird",
"undergoes":"undergo",
"undergoing":"undergo",
"undergone":"undergo",
"underwent":"undergo",
"undergrads":"undergrad",
"undergraduates":"undergraduate",
"undergrounds":"underground",
"undergrowths":"undergrowth",
"underlapped":"underlap",
"underlapping":"underlap",
"underlaid":"underlay",
"underlaying":"underlay",
"underlays":"underlay",
"underlayments":"underlayment",
"underlets":"underlet",
"underletting":"underlet",
"underlain":"underlie",
"underlay":"underlie",
"underlies":"underlie",
"underlying":"underlie",
"underlined":"underline",
"underlines":"underline",
"underlining":"underline",
"underlings":"underling",
"undermined":"undermine",
"undermines":"undermine",
"undermining":"undermine",
"undernourishments":"undernourishment",
"underpasses":"underpass",
"underpaid":"underpay",
"underpaying":"underpay",
"underpays":"underpay",
"underpinned":"underpin",
"underpinning":"underpin",
"underpins":"underpin",
"underplayed":"underplay",
"underplaying":"underplay",
"underplays":"underplay",
"underpropped":"underprop",
"underpropping":"underprop",
"underprops":"underprop",
"underrated":"underrate",
"underrates":"underrate",
"underrating":"underrate",
"underratings":"underrating",
"underreckonings":"underreckoning",
"underran":"underrun",
"underrunning":"underrun",
"underscored":"underscore",
"underscores":"underscore",
"underscoring":"underscore",
"underseals":"underseal",
"undersecretaries":"undersecretary",
"underselling":"undersell",
"undersells":"undersell",
"undersold":"undersell",
"undersets":"underset",
"undersetting":"underset",
"undershirts":"undershirt",
"undershooting":"undershoot",
"undershoots":"undershoot",
"undershot":"undershoot",
"undersides":"underside",
"undersigned":"undersign",
"undersigning":"undersign",
"underskirts":"underskirt",
"undersoils":"undersoil",
"understands":"understand",
"understood":"understand",
"understandabilities":"understandability",
"understandings":"understanding",
"understated":"understate",
"understates":"understate",
"understating":"understate",
"understeered":"understeer",
"understeering":"understeer",
"understocked":"understock",
"understocking":"understock",
"understructures":"understructure",
"understudied":"understudy",
"understudies":"understudy",
"understudying":"understudy",
"undersurfaces":"undersurface",
"undertaken":"undertake",
"undertakes":"undertake",
"undertaking":"undertake",
"undertook":"undertake",
"undertakers":"undertaker",
"undertakings":"undertaking",
"undertides":"undertide",
"undertones":"undertone",
"undertows":"undertow",
"undervalued":"undervalue",
"undervalues":"undervalue",
"undervaluing":"undervalue",
"underwears":"underwear",
"underwoods":"underwood",
"underworked":"underwork",
"underworking":"underwork",
"underworlds":"underworld",
"underwrites":"underwrite",
"underwriting":"underwrite",
"underwritten":"underwrite",
"underwrote":"underwrite",
"underwriters":"underwriter",
"undesirables":"undesirable",
"undisciplines":"undiscipline",
"undid":"undo",
"undoes":"undo",
"undoing":"undo",
"undone":"undo",
"undocked":"undock",
"undocking":"undock",
"undoers":"undoer",
"undoings":"undoing",
"undraped":"undrape",
"undraping":"undrape",
"undrawing":"undraw",
"undrawn":"undraw",
"undrew":"undraw",
"undressed":"undress",
"undresses":"undress",
"undressing":"undress",
"undulated":"undulate",
"undulates":"undulate",
"undulating":"undulate",
"undulations":"undulation",
"unearthed":"unearth",
"unearthing":"unearth",
"uneases":"unease",
"uneasinesses":"uneasiness",
"uneasier":"uneasy",
"uneasiest":"uneasy",
"unemotionalities":"unemotionality",
"unequals":"unequal",
"unequivocalnesses":"unequivocalness",
"unevennesses":"unevenness",
"unexpectednesses":"unexpectedness",
"unfairnesses":"unfairness",
"unfaithfulnesses":"unfaithfulness",
"unfamiliarities":"unfamiliarity",
"unfastened":"unfasten",
"unfastening":"unfasten",
"unfastenings":"unfastening",
"unfavorablenesses":"unfavorableness",
"unfavourablenesses":"unfavourableness",
"unfeasibilities":"unfeasibility",
"unfeelingnesses":"unfeelingness",
"unfettered":"unfetter",
"unfettering":"unfetter",
"unfits":"unfit",
"unfitted":"unfit",
"unfitting":"unfit",
"unfitnesses":"unfitness",
"unfixed":"unfix",
"unfixing":"unfix",
"unfolded":"unfold",
"unfolding":"unfold",
"unfolds":"unfold",
"unfoldings":"unfolding",
"unfortunates":"unfortunate",
"unfreezes":"unfreeze",
"unfreezing":"unfreeze",
"unfroze":"unfreeze",
"unfrozen":"unfreeze",
"unfriendlier":"unfriendly",
"unfriendliest":"unfriendly",
"unfrocked":"unfrock",
"unfrocking":"unfrock",
"unfrocks":"unfrock",
"unfurled":"unfurl",
"unfurling":"unfurl",
"unfurls":"unfurl",
"ungainlinesses":"ungainliness",
"ungainlier":"ungainly",
"ungainliest":"ungainly",
"ungirded":"ungird",
"ungirding":"ungird",
"ungirt":"ungird",
"unglued":"unglue",
"ungluing":"unglue",
"ungodlinesses":"ungodliness",
"ungodlier":"ungodly",
"ungodliest":"ungodly",
"ungoliest":"ungodly",
"ungracefulnesses":"ungracefulness",
"ungratefulnesses":"ungratefulness",
"unguents":"unguent",
"unguiculates":"unguiculate",
"unguises":"unguis",
"ungulae":"ungula",
"ungulates":"ungulate",
"unhs":"unh",
"unhaired":"unhair",
"unhairing":"unhair",
"unhanded":"unhand",
"unhanding":"unhand",
"unhandier":"unhandy",
"unhandiest":"unhandy",
"unhappinesses":"unhappiness",
"unhappier":"unhappy",
"unhappiest":"unhappy",
"unharnessed":"unharness",
"unharnessing":"unharness",
"unhealthinesses":"unhealthiness",
"unhealthier":"unhealthy",
"unhealthiest":"unhealthy",
"unhinged":"unhinge",
"unhinges":"unhinge",
"unhinging":"unhinge",
"unhitched":"unhitch",
"unhitching":"unhitch",
"unholier":"unholy",
"unholiest":"unholy",
"unhooked":"unhook",
"unhooking":"unhook",
"unhorsed":"unhorse",
"unhorses":"unhorse",
"unhorsing":"unhorse",
"unhurriednesses":"unhurriedness",
"uniats":"uniat",
"uniates":"uniate",
"unicycles":"unicycle",
"unifications":"unification",
"uniformed":"uniform",
"uniforming":"uniform",
"uniforms":"uniform",
"uniformities":"uniformity",
"uniformnesses":"uniformness",
"unified":"unify",
"unifies":"unify",
"unifying":"unify",
"unimportances":"unimportance",
"unintelligibilities":"unintelligibility",
"unios":"unio",
"unions":"union",
"unionidaes":"unionidae",
"unionisations":"unionisation",
"unionisms":"unionism",
"unionists":"unionist",
"unionizations":"unionization",
"unionized":"unionize",
"unionizes":"unionize",
"unionizing":"unionize",
"uniquenesses":"uniqueness",
"units":"unit",
"unites":"unite",
"uniting":"unite",
"unitings":"uniting",
"unities":"unity",
"univalves":"univalve",
"universals":"universal",
"universalities":"universality",
"universalized":"universalize",
"universalizing":"universalize",
"universes":"universe",
"universities":"university",
"unixes":"unix",
"unjustnesses":"unjustness",
"unkemptnesses":"unkemptness",
"unkenelled":"unkennel",
"unkenneled":"unkennel",
"unkenneling":"unkennel",
"unkennelled":"unkennel",
"unkennelling":"unkennel",
"unkennels":"unkennel",
"unkinder":"unkind",
"unkindest":"unkind",
"unknits":"unknit",
"unknitted":"unknit",
"unknitting":"unknit",
"unknowings":"unknowing",
"unknowingnesses":"unknowingness",
"unknowns":"unknown",
"unlaced":"unlace",
"unlaces":"unlace",
"unlacing":"unlace",
"unladed":"unlade",
"unlading":"unlade",
"unlatched":"unlatch",
"unlatching":"unlatch",
"unlaid":"unlay",
"unlaying":"unlay",
"unlays":"unlay",
"unlearned":"unlearn",
"unlearning":"unlearn",
"unlearns":"unlearn",
"unlearnt":"unlearn",
"unleashed":"unleash",
"unleashes":"unleash",
"unleashing":"unleash",
"unlikelihoods":"unlikelihood",
"unlikelinesses":"unlikeliness",
"unlikenesses":"unlikeness",
"unlimbered":"unlimber",
"unlimbering":"unlimber",
"unlinked":"unlink",
"unlinking":"unlink",
"unloaded":"unload",
"unloading":"unload",
"unloads":"unload",
"unlocked":"unlock",
"unlocking":"unlock",
"unloosed":"unloose",
"unlooses":"unloose",
"unloosing":"unloose",
"unluckier":"unlucky",
"unluckiest":"unlucky",
"unmade":"unmake",
"unmakes":"unmake",
"unmaking":"unmake",
"unmanned":"unman",
"unmanning":"unman",
"unmans":"unman",
"unmanageablenesses":"unmanageableness",
"unmanlinesses":"unmanliness",
"unmanlier":"unmanly",
"unmanliest":"unmanly",
"unmasked":"unmask",
"unmasking":"unmask",
"unmasks":"unmask",
"unmaskings":"unmasking",
"unmercifulnesses":"unmercifulness",
"unmindfulnesses":"unmindfulness",
"unmuzzled":"unmuzzle",
"unmuzzling":"unmuzzle",
"unnerved":"unnerve",
"unnerves":"unnerve",
"unnerving":"unnerve",
"unnilhexiums":"unnilhexium",
"unnilpentiums":"unnilpentium",
"unnilquadiums":"unnilquadium",
"unnilquintiums":"unnilquintium",
"unnilseptiums":"unnilseptium",
"unorthodoxies":"unorthodoxy",
"unps":"unp",
"unpacked":"unpack",
"unpacking":"unpack",
"unpacks":"unpack",
"unpalatabilities":"unpalatability",
"unpalatablenesses":"unpalatableness",
"unpegged":"unpeg",
"unpegging":"unpeg",
"unpegs":"unpeg",
"unpenned":"unpen",
"unpenning":"unpen",
"unpeopled":"unpeople",
"unpeopling":"unpeople",
"unpicked":"unpick",
"unpicking":"unpick",
"unpicks":"unpick",
"unpinned":"unpin",
"unpinning":"unpin",
"unpins":"unpin",
"unplugged":"unplug",
"unplugging":"unplug",
"unplugs":"unplug",
"unpredictabilities":"unpredictability",
"unprofitabilities":"unprofitability",
"unprofitablenesses":"unprofitableness",
"unpropitiousnesses":"unpropitiousness",
"unprotectednesses":"unprotectedness",
"unqs":"unq",
"unquestionabilities":"unquestionability",
"unquestionablenesses":"unquestionableness",
"unquoted":"unquote",
"unquoting":"unquote",
"unraveled":"unravel",
"unraveling":"unravel",
"unravelled":"unravel",
"unravelling":"unravel",
"unravels":"unravel",
"unrealisms":"unrealism",
"unrealities":"unreality",
"unreasons":"unreason",
"unreeled":"unreel",
"unreeling":"unreel",
"unreeved":"unreeve",
"unreeves":"unreeve",
"unreeving":"unreeve",
"unrove":"unreeve",
"unregularities":"unregularity",
"unreliabilities":"unreliability",
"unreliablenesses":"unreliableness",
"unrespectabilities":"unrespectability",
"unrests":"unrest",
"unriddled":"unriddle",
"unriddling":"unriddle",
"unrigged":"unrig",
"unrigging":"unrig",
"unrigs":"unrig",
"unripped":"unrip",
"unripping":"unrip",
"unrips":"unrip",
"unrolled":"unroll",
"unrolling":"unroll",
"unrolls":"unroll",
"unroofed":"unroof",
"unroofing":"unroof",
"unrooted":"unroot",
"unrooting":"unroot",
"unrounded":"unround",
"unrounding":"unround",
"unrulinesses":"unruliness",
"unrulier":"unruly",
"unruliest":"unruly",
"unses":"uns",
"unsaddled":"unsaddle",
"unsaddles":"unsaddle",
"unsaddling":"unsaddle",
"unsanctifications":"unsanctification",
"unsavorinesses":"unsavoriness",
"unsaid":"unsay",
"unsaying":"unsay",
"unsays":"unsay",
"unscrambled":"unscramble",
"unscrambles":"unscramble",
"unscrambling":"unscramble",
"unscrewed":"unscrew",
"unscrewing":"unscrew",
"unsealed":"unseal",
"unsealing":"unseal",
"unseamed":"unseam",
"unseaming":"unseam",
"unseasonablenesses":"unseasonableness",
"unseated":"unseat",
"unseating":"unseat",
"unseemlier":"unseemly",
"unseemliest":"unseemly",
"unseens":"unseen",
"unselfishnesses":"unselfishness",
"unselling":"unsell",
"unsold":"unsell",
"unsettled":"unsettle",
"unsettles":"unsettle",
"unsettling":"unsettle",
"unsexed":"unsex",
"unsexes":"unsex",
"unsexing":"unsex",
"unshackled":"unshackle",
"unshackling":"unshackle",
"unsheathed":"unsheathe",
"unsheathing":"unsheathe",
"unshelled":"unshell",
"unshelling":"unshell",
"unshipped":"unship",
"unshipping":"unship",
"unships":"unship",
"unsightlier":"unsightly",
"unsightliest":"unsightly",
"unsimilarities":"unsimilarity",
"unslinging":"unsling",
"unslings":"unsling",
"unslung":"unsling",
"unsnapped":"unsnap",
"unsnapping":"unsnap",
"unsnaps":"unsnap",
"unsnarled":"unsnarl",
"unsnarling":"unsnarl",
"unsnarls":"unsnarl",
"unsnarlings":"unsnarling",
"unsociabilities":"unsociability",
"unsociablenesses":"unsociableness",
"unspeaking":"unspeak",
"unspeaks":"unspeak",
"unspoke":"unspeak",
"unspoken":"unspeak",
"unstablenesses":"unstableness",
"unsteadied":"unsteady",
"unsteadies":"unsteady",
"unsteadying":"unsteady",
"unstepped":"unstep",
"unstepping":"unstep",
"unsteps":"unstep",
"unsticking":"unstick",
"unsticks":"unstick",
"unstuck":"unstick",
"unstopped":"unstop",
"unstopping":"unstop",
"unstops":"unstop",
"unstrapped":"unstrap",
"unstrapping":"unstrap",
"unstringing":"unstring",
"unstrings":"unstring",
"unstrung":"unstring",
"unsuitabilities":"unsuitability",
"unsuitablenesses":"unsuitableness",
"unsusceptibilities":"unsusceptibility",
"unswearing":"unswear",
"unswears":"unswear",
"unswore":"unswear",
"unsworn":"unswear",
"untangled":"untangle",
"untangles":"untangle",
"untangling":"untangle",
"untanglings":"untangling",
"untaught":"unteach",
"unteaches":"unteach",
"unteaching":"unteach",
"unthinking":"unthink",
"unthinks":"unthink",
"unthought":"unthink",
"unthoughtfulnesses":"unthoughtfulness",
"unthreaded":"unthread",
"unthreading":"unthread",
"untidinesses":"untidiness",
"untidied":"untidy",
"untidier":"untidy",
"untidies":"untidy",
"untidiest":"untidy",
"untidying":"untidy",
"untied":"untie",
"unties":"untie",
"untying":"untie",
"untimelinesses":"untimeliness",
"untreading":"untread",
"untreads":"untread",
"untrod":"untread",
"untrodden":"untread",
"untruer":"untrue",
"untruest":"untrue",
"untrussed":"untruss",
"untrussing":"untruss",
"untrustinesses":"untrustiness",
"untrustworthinesses":"untrustworthiness",
"untruths":"untruth",
"untucked":"untuck",
"untucking":"untuck",
"untwined":"untwine",
"untwining":"untwine",
"untwisted":"untwist",
"untwisting":"untwist",
"untyings":"untying",
"untypicalities":"untypicality",
"unusefulnesses":"unusefulness",
"unveiled":"unveil",
"unveiling":"unveil",
"unveils":"unveil",
"unveilings":"unveiling",
"unvoiced":"unvoice",
"unvoicing":"unvoice",
"unweaving":"unweave",
"unwove":"unweave",
"unwoven":"unweave",
"unwholesomenesses":"unwholesomeness",
"unwieldinesses":"unwieldiness",
"unwieldier":"unwieldy",
"unwieldiest":"unwieldy",
"unwinding":"unwind",
"unwinds":"unwind",
"unwound":"unwind",
"unwiser":"unwise",
"unwisest":"unwise",
"unwisenesses":"unwiseness",
"unworthier":"unworthy",
"unworthiest":"unworthy",
"unwrapped":"unwrap",
"unwrapping":"unwrap",
"unwraps":"unwrap",
"unyieldingnesses":"unyieldingness",
"unyoked":"unyoke",
"unyoking":"unyoke",
"unzipped":"unzip",
"unzipping":"unzip",
"unzips":"unzip",
"upped":"up",
"upping":"up",
"ups":"up",
"up-to-datenesses":"up-to-dateness",
"upbeats":"upbeat",
"upbraided":"upbraid",
"upbraiding":"upbraid",
"upbraids":"upbraid",
"upbraidings":"upbraiding",
"upbringings":"upbringing",
"upbuilding":"upbuild",
"upbuilds":"upbuild",
"upbuilt":"upbuild",
"upcasting":"upcast",
"upcasts":"upcast",
"updated":"update",
"updating":"update",
"upended":"upend",
"upending":"upend",
"upendings":"upending",
"upgraded":"upgrade",
"upgrades":"upgrade",
"upgrading":"upgrade",
"upheavals":"upheaval",
"upheaved":"upheave",
"upheaves":"upheave",
"upheaving":"upheave",
"uphove":"upheave",
"upheld":"uphold",
"upholding":"uphold",
"upholds":"uphold",
"upholstered":"upholster",
"upholstering":"upholster",
"upholsterers":"upholsterer",
"upholsteries":"upholstery",
"upkeeps":"upkeep",
"uplands":"upland",
"uplifted":"uplift",
"uplifting":"uplift",
"uplifts":"uplift",
"uppers":"upper",
"upper-cased":"upper-case",
"upper-casing":"upper-case",
"upper-normandies":"upper-normandy",
"uppercuts":"uppercut",
"uppercutting":"uppercut",
"uppishnesses":"uppishness",
"uppitynesses":"uppityness",
"upraised":"upraise",
"upraises":"upraise",
"upraising":"upraise",
"upreared":"uprear",
"uprearing":"uprear",
"uprighted":"upright",
"uprighting":"upright",
"uprights":"upright",
"uprightnesses":"uprightness",
"uprisen":"uprise",
"uprises":"uprise",
"uprising":"uprise",
"uprose":"uprise",
"uprisings":"uprising",
"uproars":"uproar",
"uprooted":"uproot",
"uprooting":"uproot",
"uproots":"uproot",
"upsets":"upset",
"upsetting":"upset",
"upshots":"upshot",
"upsides":"upside",
"upsprang":"upspring",
"upspringing":"upspring",
"upsprings":"upspring",
"upsprung":"upspring",
"upstaged":"upstage",
"upstaging":"upstage",
"upstarts":"upstart",
"upsurged":"upsurge",
"upsurges":"upsurge",
"upsurging":"upsurge",
"upsweeping":"upsweep",
"upsweeps":"upsweep",
"upswept":"upsweep",
"upswelled":"upswell",
"upswelling":"upswell",
"upswells":"upswell",
"upswollen":"upswell",
"upswinging":"upswing",
"upswings":"upswing",
"upswung":"upswing",
"uptakes":"uptake",
"upthrows":"upthrow",
"upthrusts":"upthrust",
"upturned":"upturn",
"upturning":"upturn",
"upturns":"upturn",
"upupas":"upupa",
"upupidaes":"upupidae",
"upwelled":"upwell",
"upwelling":"upwell",
"uraemias":"uraemia",
"uraeuses":"uraeus",
"uralics":"uralic",
"uralses":"urals",
"uranalyses":"uranalysis",
"uranias":"urania",
"uraninites":"uraninite",
"uraniums":"uranium",
"uranologists":"uranologist",
"uranologies":"uranology",
"uranoscopidaes":"uranoscopidae",
"uranuses":"uranus",
"uranyls":"uranyl",
"urarthritises":"urarthritis",
"urbanities":"urbanity",
"urchins":"urchin",
"urds":"urd",
"ureas":"urea",
"uredinaleses":"uredinales",
"uredinia":"uredinium",
"uredinidinia":"uredinium",
"uredidia":"uredium",
"uredines":"uredo",
"uredososori":"uredosorus",
"uremias":"uremia",
"urethrae":"urethra",
"urethras":"urethra",
"urged":"urge",
"urges":"urge",
"urging":"urge",
"urgencies":"urgency",
"urgineas":"urginea",
"urgings":"urging",
"urias":"uria",
"urials":"urial",
"urinalyses":"urinalysis",
"urinaries":"urinary",
"urinated":"urinate",
"urinates":"urinate",
"urinating":"urinate",
"urinations":"urination",
"urines":"urine",
"urns":"urn",
"urochords":"urochord",
"urochordas":"urochorda",
"urochordatas":"urochordata",
"urochordates":"urochordate",
"urocyons":"urocyon",
"urocystises":"urocystis",
"urodeles":"urodele",
"urodellas":"urodella",
"urologies":"urology",
"urophycises":"urophycis",
"uropsiluses":"uropsilus",
"uropygis":"uropygi",
"urosauruses":"urosaurus",
"ursidaes":"ursidae",
"ursuses":"ursus",
"urths":"urth",
"urticas":"urtica",
"urticaceaes":"urticaceae",
"urticaleses":"urticales",
"urticarias":"urticaria",
"urticated":"urticate",
"urticating":"urticate",
"urtications":"urtication",
"urubupungas":"urubupunga",
"uruses":"urus",
"uses":"use",
"usas":"usa",
"usablenesses":"usableness",
"usages":"usage",
"usances":"usance",
"usbegs":"usbeg",
"usbeks":"usbek",
"using":"use",
"usefulnesses":"usefulness",
"uselessnesses":"uselessness",
"users":"user",
"ushered":"usher",
"ushering":"usher",
"ushers":"usher",
"usings":"using",
"usneas":"usnea",
"usneaceaes":"usneaceae",
"ussrs":"ussr",
"ustilaginaceaes":"ustilaginaceae",
"ustilaginaleses":"ustilaginales",
"ustilaginoideas":"ustilaginoidea",
"ustilagos":"ustilago",
"usufructuaries":"usufructuary",
"usumburas":"usumbura",
"usurers":"usurer",
"usurped":"usurp",
"usurping":"usurp",
"usurps":"usurp",
"usurpers":"usurper",
"usuries":"usury",
"uts":"ut",
"ut1s":"ut1",
"utas":"uta",
"utahs":"utah",
"utahraptors":"utahraptor",
"utcs":"utc",
"utes":"ute",
"utensils":"utensil",
"uteri":"uterus",
"uteruses":"uterus",
"utilisations":"utilisation",
"utilities":"utility",
"utilizations":"utilization",
"utilized":"utilize",
"utilizes":"utilize",
"utilizing":"utilize",
"utmosts":"utmost",
"uto-aztecans":"uto-aztecan",
"utopias":"utopia",
"utopians":"utopian",
"utricles":"utricle",
"utricularias":"utricularia",
"utriculuses":"utriculus",
"utrillos":"utrillo",
"uttered":"utter",
"uttering":"utter",
"utters":"utter",
"utterances":"utterance",
"uttermosts":"uttermost",
"utus":"utu",
"utugs":"utug",
"uvs":"uv",
"uvulae":"uvula",
"uvulas":"uvula",
"uvularias":"uvularia",
"uvulariaceaes":"uvulariaceae",
"uxes":"ux",
"uxors":"uxor",
"uzbaks":"uzbak",
"uzbegs":"uzbeg",
"uzbeks":"uzbek",
"uzbekistans":"uzbekistan",
"uzbekistons":"uzbekiston",
"vs":"v",
"v-1s":"v-1",
"v-days":"v-day",
"vacancies":"vacancy",
"vacated":"vacate",
"vacates":"vacate",
"vacating":"vacate",
"vacationed":"vacation",
"vacationing":"vacation",
"vacations":"vacation",
"vacationers":"vacationer",
"vacationists":"vacationist",
"vaccarias":"vaccaria",
"vaccinated":"vaccinate",
"vaccinates":"vaccinate",
"vaccinating":"vaccinate",
"vaccinatings":"vaccinating",
"vaccinations":"vaccination",
"vaccinias":"vaccinia",
"vacciniums":"vaccinium",
"vacillated":"vacillate",
"vacillates":"vacillate",
"vacillating":"vacillate",
"vacillations":"vacillation",
"vacillators":"vacillator",
"vacuities":"vacuity",
"vacuolations":"vacuolation",
"vacuolizations":"vacuolization",
"vacuousnesses":"vacuousness",
"vacua":"vacuum",
"vacuumed":"vacuum",
"vacuuming":"vacuum",
"vacuums":"vacuum",
"vaduzs":"vaduz",
"vagged":"vag",
"vagging":"vag",
"vags":"vag",
"vagabonded":"vagabond",
"vagabonding":"vagabond",
"vagabonds":"vagabond",
"vagabondages":"vagabondage",
"vagaries":"vagary",
"vaginae":"vagina",
"vaginas":"vagina",
"vaginoceles":"vaginocele",
"vagotomies":"vagotomy",
"vagrancies":"vagrancy",
"vagrants":"vagrant",
"vaguer":"vague",
"vaguest":"vague",
"vagi":"vagus",
"vaguses":"vagus",
"vailed":"vail",
"vailing":"vail",
"vainer":"vain",
"vainest":"vain",
"vainglories":"vainglory",
"vaishnavisms":"vaishnavism",
"vaisnavisms":"vaisnavism",
"valances":"valance",
"vales":"vale",
"valedictions":"valediction",
"valedictorians":"valedictorian",
"valedictories":"valedictory",
"valences":"valence",
"valencies":"valency",
"valentines":"valentine",
"valerianas":"valeriana",
"valerianaceaes":"valerianaceae",
"valerianellas":"valerianella",
"valeted":"valet",
"valeting":"valet",
"valets":"valet",
"valettas":"valetta",
"valetudinarians":"valetudinarian",
"valetudinarnarians":"valetudinarian",
"valetudinaries":"valetudinary",
"valguses":"valgus",
"valhallas":"valhalla",
"valiances":"valiance",
"valiancies":"valiancy",
"valiants":"valiant",
"validated":"validate",
"validates":"validate",
"validating":"validate",
"validatings":"validating",
"validations":"validation",
"validities":"validity",
"validnesses":"validness",
"valises":"valise",
"Valiums":"Valium",
"valleculae":"vallecula",
"vallettas":"valletta",
"valleys":"valley",
"vallisnerias":"vallisneria",
"valmies":"valmy",
"valors":"valor",
"valorized":"valorize",
"valorizing":"valorize",
"valorousnesses":"valorousness",
"valours":"valour",
"valourousnesses":"valourousness",
"valses":"valse",
"valuables":"valuable",
"valuablenesses":"valuableness",
"valuated":"valuate",
"valuating":"valuate",
"valuations":"valuation",
"valuators":"valuator",
"valued":"value",
"values":"value",
"valuing":"value",
"value-systems":"value-system",
"valved":"valve",
"valves":"valve",
"valving":"valve",
"vambraces":"vambrace",
"vamoosed":"vamoose",
"vamooses":"vamoose",
"vamoosing":"vamoose",
"vamped":"vamp",
"vamping":"vamp",
"vamps":"vamp",
"vampers":"vamper",
"vampires":"vampire",
"vanned":"van",
"vanning":"van",
"vans":"van",
"vanadiums":"vanadium",
"vancocins":"vancocin",
"vancomycins":"vancomycin",
"vandals":"vandal",
"vandalisms":"vandalism",
"vandalized":"vandalize",
"vandalizes":"vandalize",
"vandalizing":"vandalize",
"vanes":"vane",
"vanelluses":"vanellus",
"vanessas":"vanessa",
"vanguards":"vanguard",
"vanguerias":"vangueria",
"vanillas":"vanilla",
"vanished":"vanish",
"vanishes":"vanish",
"vanishing":"vanish",
"vanities":"vanity",
"vanquished":"vanquish",
"vanquishes":"vanquish",
"vanquishing":"vanquish",
"vanquishers":"vanquisher",
"vantages":"vantage",
"vanuatus":"vanuatu",
"vapidities":"vapidity",
"vapidnesses":"vapidness",
"vapored":"vapor",
"vaporing":"vapor",
"vapors":"vapor",
"vaporetti":"vaporetto",
"vaporettos":"vaporetto",
"vaporings":"vaporing",
"vaporisations":"vaporisation",
"vaporizations":"vaporization",
"vaporized":"vaporize",
"vaporizes":"vaporize",
"vaporizing":"vaporize",
"vapoured":"vapour",
"vapouring":"vapour",
"vapours":"vapour",
"vaqueros":"vaquero",
"vars":"var",
"varans":"varan",
"varanidaes":"varanidae",
"varanuses":"varanus",
"variabilities":"variability",
"variables":"variable",
"variablenesses":"variableness",
"variances":"variance",
"variants":"variant",
"variates":"variate",
"variations":"variation",
"variationals":"variational",
"varicellas":"varicella",
"varicosities":"varicosity",
"varicosties":"varicosity",
"varicotomies":"varicotomy",
"variednesses":"variedness",
"variegated":"variegate",
"variegates":"variegate",
"variegating":"variegate",
"varieties":"variety",
"variolas":"variola",
"variorums":"variorum",
"varices":"varix",
"varlets":"varlet",
"varments":"varment",
"varmints":"varmint",
"varnas":"varna",
"varnished":"varnish",
"varnishes":"varnish",
"varnishing":"varnish",
"varsities":"varsity",
"varied":"vary",
"varies":"vary",
"varying":"vary",
"vasa":"vas",
"vases":"vase",
"vascularized":"vascularize",
"vascularizing":"vascularize",
"vascula":"vasculum",
"vasculums":"vasculum",
"vase-fines":"vase-fine",
"vasectomies":"vasectomy",
"vasopressins":"vasopressin",
"vassals":"vassal",
"vassalages":"vassalage",
"vaster":"vast",
"vastest":"vast",
"vastnesses":"vastness",
"vastier":"vasty",
"vastiest":"vasty",
"vats":"vat",
"vatted":"vat",
"vatting":"vat",
"vaticans":"vatican",
"vaticinations":"vaticination",
"vaudevilles":"vaudeville",
"vaulted":"vault",
"vaulting":"vault",
"vaults":"vault",
"vaulters":"vaulter",
"vaultings":"vaulting",
"vaunting":"vaunt",
"vaunts":"vaunt",
"vaunters":"vaunter",
"VCRs":"VCR",
"vds":"vd",
"veadars":"veadar",
"veals":"veal",
"veaus":"veau",
"vectored":"vector",
"vectoring":"vector",
"vedas":"veda",
"vedalias":"vedalia",
"veddas":"vedda",
"veered":"veer",
"veering":"veer",
"veers":"veer",
"veerings":"veering",
"veeries":"veery",
"vegetables":"vegetable",
"vegetated":"vegetate",
"vegetating":"vegetate",
"vegetations":"vegetation",
"veggies":"veggie",
"vehemences":"vehemence",
"vehicles":"vehicle",
"veiled":"veil",
"veiling":"veil",
"veils":"veil",
"veilings":"veiling",
"veined":"vein",
"veining":"vein",
"veins":"vein",
"veinier":"veiny",
"veiniest":"veiny",
"velalamina":"velamen",
"velamina":"velamen",
"velarlaria":"velarium",
"velarized":"velarize",
"velarizing":"velarize",
"velbans":"velban",
"velds":"veld",
"veldts":"veldt",
"velleities":"velleity",
"velocipedes":"velocipede",
"velocities":"velocity",
"velours":"velour",
"velourses":"velours",
"vela":"velum",
"velums":"velum",
"velveteens":"velveteen",
"velvetleaves":"velvetleaf",
"velvetweeds":"velvetweed",
"venae":"vena",
"venas":"vena",
"vended":"vend",
"vending":"vend",
"vends":"vend",
"vendas":"venda",
"vendaces":"vendace",
"vendees":"vendee",
"venders":"vender",
"vendettas":"vendetta",
"vendings":"vending",
"venditions":"vendition",
"vendors":"vendor",
"vendues":"vendue",
"veneered":"veneer",
"veneering":"veneer",
"veneers":"veneer",
"veneerings":"veneering",
"venerated":"venerate",
"venerates":"venerate",
"venerating":"venerate",
"venerations":"veneration",
"venerators":"venerator",
"veneridaes":"veneridae",
"venesections":"venesection",
"venetias":"venetia",
"venetos":"veneto",
"venezias":"venezia",
"venezia-euganeas":"venezia-euganea",
"vengeances":"vengeance",
"vengefulnesses":"vengefulness",
"venices":"venice",
"veniremen":"venireman",
"venograms":"venogram",
"venoms":"venom",
"vented":"vent",
"venting":"vent",
"vents":"vent",
"ventails":"ventail",
"venters":"venter",
"ventholes":"venthole",
"ventilated":"ventilate",
"ventilates":"ventilate",
"ventilating":"ventilate",
"ventilations":"ventilation",
"ventings":"venting",
"ventolins":"ventolin",
"ventricles":"ventricle",
"ventriculi":"ventriculus",
"ventriculuses":"ventriculus",
"ventriloquisms":"ventriloquism",
"ventriloquized":"ventriloquize",
"ventriloquizing":"ventriloquize",
"ventriloquys":"ventriloquy",
"ventured":"venture",
"ventures":"venture",
"venturing":"venture",
"venturesomenesses":"venturesomeness",
"venues":"venue",
"venulas":"venula",
"venules":"venule",
"venuses":"venus",
"venushairs":"venushair",
"vepses":"veps",
"vepsians":"vepsian",
"veracities":"veracity",
"verandas":"veranda",
"verandahs":"verandah",
"verapamils":"verapamil",
"veratrums":"veratrum",
"verbs":"verb",
"verbals":"verbal",
"verbalized":"verbalize",
"verbalizes":"verbalize",
"verbalizing":"verbalize",
"verbascums":"verbascum",
"verbenas":"verbena",
"verbenaceaes":"verbenaceae",
"verbesinas":"verbesina",
"verbiages":"verbiage",
"verbified":"verbify",
"verbifies":"verbify",
"verbifying":"verbify",
"verbolatries":"verbolatry",
"verbosenesses":"verboseness",
"verbosities":"verbosity",
"verdancies":"verdancy",
"verdandis":"verdandi",
"verdicts":"verdict",
"verdigrises":"verdigris",
"verdins":"verdin",
"verdolagases":"verdolagas",
"verduns":"verdun",
"verdures":"verdure",
"verged":"verge",
"verges":"verge",
"verging":"verge",
"vergils":"vergil",
"verifications":"verification",
"verified":"verify",
"verifies":"verify",
"verifying":"verify",
"verities":"verity",
"vermiculated":"vermiculate",
"vermiculating":"vermiculate",
"vermiculations":"vermiculation",
"vermifuges":"vermifuge",
"vermilions":"vermilion",
"vermins":"vermin",
"vermes":"vermis",
"vermonts":"vermont",
"vernaculars":"vernacular",
"vernalized":"vernalize",
"vernalizing":"vernalize",
"verniers":"vernier",
"vernonias":"vernonia",
"veronals":"veronal",
"veronicas":"veronica",
"verpas":"verpa",
"verrazanos":"verrazano",
"verrazzanos":"verrazzano",
"verrucae":"verruca",
"verrucas":"verruca",
"versed":"verse",
"verses":"verse",
"versing":"verse",
"versifiers":"versifier",
"versified":"versify",
"versifies":"versify",
"versifying":"versify",
"versions":"version",
"versos":"verso",
"vertebrae":"vertebra",
"vertebras":"vertebra",
"vertebratas":"vertebrata",
"vertebrates":"vertebrate",
"vertexes":"vertex",
"vertices":"vertex",
"verthandis":"verthandi",
"verticals":"vertical",
"verticalities":"verticality",
"verticalnesses":"verticalness",
"vertigines":"vertigo",
"vertigoes":"vertigo",
"vertigos":"vertigo",
"vertus":"vertu",
"vervains":"vervain",
"verves":"verve",
"vervets":"vervet",
"vesaliuses":"vesalius",
"vesicae":"vesica",
"vesicas":"vesica",
"vesicants":"vesicant",
"vesicarias":"vesicaria",
"vesicated":"vesicate",
"vesicating":"vesicate",
"vesicatories":"vesicatory",
"vesicles":"vesicle",
"vesiculated":"vesiculate",
"vesiculating":"vesiculate",
"vespas":"vespa",
"Africans":"African",
"ADRs":"ADR",
"vespertilios":"vespertilio",
"vespertilionids":"vespertilionid",
"vespertilionidaes":"vespertilionidae",
"vespiaries":"vespiary",
"vespids":"vespid",
"vespidaes":"vespidae",
"vespuccis":"vespucci",
"vespulas":"vespula",
"vessels":"vessel",
"vested":"vest",
"vesting":"vest",
"vests":"vest",
"vestibuled":"vestibule",
"vestibules":"vestibule",
"vestibuling":"vestibule",
"vestiges":"vestige",
"vestments":"vestment",
"vestries":"vestry",
"vestrymen":"vestryman",
"vestured":"vesture",
"vestures":"vesture",
"vesturing":"vesture",
"vesuvians":"vesuvian",
"vesuvianites":"vesuvianite",
"vesuviuses":"vesuvius",
"vets":"vet",
"vetted":"vet",
"vetting":"vet",
"vetchworms":"vetchworm",
"veterans":"veteran",
"veterinarians":"veterinarian",
"veterinaries":"veterinary",
"vetoed":"veto",
"vetoes":"veto",
"vetoing":"veto",
"vexes":"vex",
"vexing":"vex",
"vexations":"vexation",
"vexilia":"vexillum",
"vexilla":"vexillum",
"vfws":"vfw",
"vhfs":"vhf",
"vis":"vi",
"vials":"vial",
"viandses":"viands",
"viatications":"viatication",
"viatica":"viaticum",
"viaticums":"viaticum",
"viaticuses":"viaticus",
"viatores":"viator",
"vibeses":"vibes",
"vibracula":"vibraculum",
"vibraharps":"vibraharp",
"vibramycins":"vibramycin",
"vibrancies":"vibrancy",
"vibraphones":"vibraphone",
"vibrated":"vibrate",
"vibrates":"vibrate",
"vibrating":"vibrate",
"vibrations":"vibration",
"vibrationses":"vibrations",
"vibratos":"vibrato",
"vibrios":"vibrio",
"vibrions":"vibrion",
"vibrissae":"vibrissa",
"vibrissas":"vibrissa",
"viburnums":"viburnum",
"vicars":"vicar",
"vicarages":"vicarage",
"vicariates":"vicariate",
"vicarships":"vicarship",
"viced":"vice",
"vices":"vice",
"vicing":"vice",
"vice-chairmann":"vice-chairman",
"vicegerencies":"vicegerency",
"vicereines":"vicereine",
"viceroys":"viceroy",
"viceroyalties":"viceroyalty",
"vicias":"vicia",
"vicinities":"vicinity",
"viciousnesses":"viciousness",
"vicissitudes":"vicissitude",
"vicksburgs":"vicksburg",
"victims":"victim",
"victimisations":"victimisation",
"victimizations":"victimization",
"victimized":"victimize",
"victimizes":"victimize",
"victimizing":"victimize",
"victors":"victor",
"victorias":"victoria",
"victories":"victory",
"victualed":"victual",
"victualing":"victual",
"victualled":"victual",
"victualling":"victual",
"victuals":"victual",
"victualers":"victualer",
"victuallers":"victualler",
"victualses":"victuals",
"vicugnas":"vicugna",
"vicunas":"vicuna",
"vidars":"vidar",
"vided":"vide",
"viding":"vide",
"videos":"video",
"viduas":"vidua",
"vied":"vie",
"vies":"vie",
"vying":"vie",
"viennas":"vienna",
"vientianes":"vientiane",
"vietnams":"vietnam",
"vietnameses":"vietnamese",
"viewed":"view",
"viewing":"view",
"views":"view",
"viewers":"viewer",
"viewerses":"viewers",
"viewfinders":"viewfinder",
"viewgraphs":"viewgraph",
"viewings":"viewing",
"viewpoints":"viewpoint",
"viewier":"viewy",
"viewiest":"viewy",
"vigils":"vigil",
"vigilances":"vigilance",
"vigilantes":"vigilante",
"vignas":"vigna",
"vignettes":"vignette",
"vigors":"vigor",
"vigours":"vigour",
"viis":"vii",
"viiis":"viii",
"vilas":"vila",
"viler":"vile",
"vilest":"vile",
"vilenesses":"vileness",
"vilifications":"vilification",
"vilified":"vilify",
"vilifies":"vilify",
"vilifying":"vilify",
"vilipended":"vilipend",
"vilipending":"vilipend",
"villas":"villa",
"villages":"village",
"villagers":"villager",
"villains":"villain",
"villainages":"villainage",
"villainousnesses":"villainousness",
"villainies":"villainy",
"villanellas":"villanella",
"villanelle":"villanella",
"villeins":"villein",
"villeinages":"villeinage",
"villomas":"villoma",
"villosities":"villosity",
"villi":"villus",
"vilnas":"vilna",
"vilniuses":"vilnius",
"vilnos":"vilno",
"vims":"vim",
"vimina":"vimen",
"viminarias":"viminaria",
"vinas":"vina",
"vinaigrettes":"vinaigrette",
"vinblastines":"vinblastine",
"vincas":"vinca",
"vincetoxicums":"vincetoxicum",
"vincristines":"vincristine",
"vincula":"vinculum",
"vindicated":"vindicate",
"vindicates":"vindicate",
"vindicating":"vindicate",
"vindications":"vindication",
"vindicators":"vindicator",
"vindictivenesses":"vindictiveness",
"vined":"vine",
"vines":"vine",
"vining":"vine",
"vinegarinesses":"vinegariness",
"vinegarishnesses":"vinegarishness",
"vinegarroons":"vinegarroon",
"vinegarweeds":"vinegarweed",
"vineries":"vinery",
"vineyards":"vineyard",
"vingt-et-uns":"vingt-et-un",
"viniferas":"vinifera",
"vinos":"vino",
"vintages":"vintage",
"vintners":"vintner",
"vinyls":"vinyl",
"vinylbenzenes":"vinylbenzene",
"viocins":"viocin",
"violas":"viola",
"violaceaes":"violaceae",
"violated":"violate",
"violates":"violate",
"violating":"violate",
"violations":"violation",
"violators":"violator",
"violences":"violence",
"violets":"violet",
"violins":"violin",
"violinists":"violinist",
"violoncellos":"violoncello",
"viomycins":"viomycin",
"vips":"vip",
"vipers":"viper",
"viperas":"vipera",
"viperidaes":"viperidae",
"viragoes":"virago",
"viragos":"virago",
"vireos":"vireo",
"vireonidaes":"vireonidae",
"virgils":"virgil",
"virgilias":"virgilia",
"virgins":"virgin",
"virginals":"virginal",
"virginias":"virginia",
"virgos":"virgo",
"virgules":"virgule",
"viricides":"viricide",
"viridities":"viridity",
"virilities":"virility",
"virilizations":"virilization",
"virilized":"virilize",
"virilizing":"virilize",
"viroids":"viroid",
"virtus":"virtu",
"virtues":"virtue",
"virtuosi":"virtuoso",
"virtuosos":"virtuoso",
"virtuousnesses":"virtuousness",
"virucides":"virucide",
"viruses":"virus",
"virusoids":"virusoid",
"vires":"vis",
"vis-a-vises":"vis-a-vis",
"visaed":"visa",
"visaing":"visa",
"visas":"visa",
"visages":"visage",
"visayans":"visayan",
"viscaceaes":"viscaceae",
"viscachas":"viscacha",
"visceras":"viscera",
"viscidities":"viscidity",
"viscidnesses":"viscidness",
"viscometers":"viscometer",
"viscoses":"viscose",
"viscosimeters":"viscosimeter",
"viscosities":"viscosity",
"viscounts":"viscount",
"viscountcies":"viscountcy",
"viscounties":"viscounty",
"viscousnesses":"viscousness",
"viscums":"viscum",
"viscera":"viscus",
"vised":"vise",
"vises":"vise",
"vising":"vise",
"vishnuisms":"vishnuism",
"visibilities":"visibility",
"visiblenesses":"visibleness",
"visioned":"vision",
"visioning":"vision",
"visions":"vision",
"visionaries":"visionary",
"visited":"visit",
"visiting":"visit",
"visits":"visit",
"visitants":"visitant",
"visitations":"visitation",
"visitors":"visitor",
"visors":"visor",
"vistas":"vista",
"vistulas":"vistula",
"visualisations":"visualisation",
"visualizations":"visualization",
"visualized":"visualize",
"visualizes":"visualize",
"visualizing":"visualize",
"vitae":"vita",
"vitaceaes":"vitaceae",
"vitals":"vital",
"vitalities":"vitality",
"vitalized":"vitalize",
"vitalizes":"vitalize",
"vitalizing":"vitalize",
"vitalnesses":"vitalness",
"vitalses":"vitals",
"vitamins":"vitamin",
"vitamines":"vitamine",
"vitelli":"vitellus",
"vitelluses":"vitellus",
"vithars":"vithar",
"vitharrs":"vitharr",
"vitiated":"vitiate",
"vitiates":"vitiate",
"vitiating":"vitiate",
"vitidaceaes":"vitidaceae",
"vitises":"vitis",
"vitrectomies":"vitrectomy",
"vitrified":"vitrify",
"vitrifies":"vitrify",
"vitrifying":"vitrify",
"vitriols":"vitriol",
"vittae":"vitta",
"vittarias":"vittaria",
"vittariaceaes":"vittariaceae",
"vituperated":"vituperate",
"vituperates":"vituperate",
"vituperating":"vituperate",
"vituperations":"vituperation",
"vivaed":"viva",
"vivaing":"viva",
"vivas":"viva",
"vivacities":"vivacity",
"vivaria":"vivarium",
"vivariums":"vivarium",
"viverras":"viverra",
"viverriculas":"viverricula",
"viverridaes":"viverridae",
"viverrinaes":"viverrinae",
"viverrines":"viverrine",
"vividnesses":"vividness",
"vivifications":"vivification",
"vivified":"vivify",
"vivifies":"vivify",
"vivifying":"vivify",
"vivifyings":"vivifying",
"vivisected":"vivisect",
"vivisecting":"vivisect",
"vixens":"vixen",
"vizlas":"vizla",
"vizored":"vizor",
"vizoring":"vizor",
"vizors":"vizor",
"vozored":"vizor",
"vlfs":"vlf",
"vocables":"vocable",
"vocabularies":"vocabulary",
"vocals":"vocal",
"vocalists":"vocalist",
"vocalizations":"vocalization",
"vocalized":"vocalize",
"vocalizes":"vocalize",
"vocalizing":"vocalize",
"vocalizings":"vocalizing",
"vocations":"vocation",
"vocatives":"vocative",
"vociferated":"vociferate",
"vociferates":"vociferate",
"vociferating":"vociferate",
"vociferations":"vociferation",
"vodouns":"vodoun",
"vogues":"vogue",
"voguls":"vogul",
"voiced":"voice",
"voices":"voice",
"voicing":"voice",
"voicelessnesses":"voicelessness",
"voided":"void",
"voider":"void",
"voidest":"void",
"voiding":"void",
"voids":"void",
"voidances":"voidance",
"voidings":"voiding",
"volailles":"volaille",
"volaries":"volary",
"volatilities":"volatility",
"volatilized":"volatilize",
"volatilizing":"volatilize",
"volcanoes":"volcano",
"volcanos":"volcano",
"volcanologies":"volcanology",
"voles":"vole",
"volgas":"volga",
"volgograds":"volgograd",
"volitions":"volition",
"volkslieder":"volkslied",
"volleyed":"volley",
"volleying":"volley",
"volleys":"volley",
"volleyballs":"volleyball",
"volplaned":"volplane",
"volplaning":"volplane",
"volts":"volt",
"volt-amperes":"volt-ampere",
"volte":"volta",
"voltages":"voltage",
"voltaics":"voltaic",
"voltaires":"voltaire",
"voltarens":"voltaren",
"volte-faces":"volte-face",
"volubilities":"volubility",
"volumes":"volume",
"voluminosities":"voluminosity",
"voluminousnesses":"voluminousness",
"voluntaries":"voluntary",
"volunteered":"volunteer",
"volunteering":"volunteer",
"volunteers":"volunteer",
"voluptuaries":"voluptuary",
"voluptuousnesses":"voluptuousness",
"volutes":"volute",
"volvae":"volva",
"volvas":"volva",
"volvarias":"volvaria",
"volvariaceaes":"volvariaceae",
"volvariellas":"volvariella",
"volvocaceaes":"volvocaceae",
"volvocaleses":"volvocales",
"volvoxes":"volvox",
"volvuluses":"volvulus",
"vombatidaes":"vombatidae",
"vomited":"vomit",
"vomiting":"vomit",
"vomits":"vomit",
"vomitings":"vomiting",
"vomitives":"vomitive",
"vomitoria":"vomitorium",
"vomitories":"vomitory",
"vomituses":"vomitus",
"voodooed":"voodoo",
"voodooing":"voodoo",
"voodoos":"voodoo",
"voodooisms":"voodooism",
"voraciousnesses":"voraciousness",
"voracities":"voracity",
"vortexes":"vortex",
"vortices":"vortex",
"vorticellae":"vorticella",
"vorticellas":"vorticella",
"votaries":"votary",
"voted":"vote",
"votes":"vote",
"voting":"vote",
"voters":"voter",
"votings":"voting",
"votyaks":"votyak",
"vouched":"vouch",
"vouches":"vouch",
"vouching":"vouch",
"vouchers":"voucher",
"vouchsafed":"vouchsafe",
"vouchsafing":"vouchsafe",
"vowed":"vow",
"vowing":"vow",
"vows":"vow",
"vowels":"vowel",
"voces":"vox",
"voyaged":"voyage",
"voyages":"voyage",
"voyaging":"voyage",
"voyeurs":"voyeur",
"vroomed":"vroom",
"vrooming":"vroom",
"vulcanisations":"vulcanisation",
"vulcanites":"vulcanite",
"vulcanizations":"vulcanization",
"vulcanized":"vulcanize",
"vulcanizing":"vulcanize",
"vulcanologies":"vulcanology",
"vulgarisations":"vulgarisation",
"vulgarisms":"vulgarism",
"vulgarities":"vulgarity",
"vulgarizations":"vulgarization",
"vulgarized":"vulgarize",
"vulgarizes":"vulgarize",
"vulgarizing":"vulgarize",
"vulnerabilities":"vulnerability",
"vulneraries":"vulnerary",
"vulpeses":"vulpes",
"vulturs":"vultur",
"vultures":"vulture",
"vulvae":"vulva",
"vulvas":"vulva",
"ws":"w",
"wabashes":"wabash",
"wabbled":"wabble",
"wabbling":"wabble",
"wackier":"wacky",
"wackiest":"wacky",
"wadded":"wad",
"wadding":"wad",
"wads":"wad",
"waddings":"wadding",
"waddled":"waddle",
"waddles":"waddle",
"waddling":"waddle",
"waddied":"waddy",
"waddies":"waddy",
"waddying":"waddy",
"waded":"wade",
"wading":"wade",
"waders":"wader",
"wadies":"wadi",
"wadis":"wadi",
"wadses":"wads",
"wadsets":"wadset",
"wadsetted":"wadset",
"wadsetting":"wadset",
"wafered":"wafer",
"wafering":"wafer",
"wafers":"wafer",
"waffled":"waffle",
"waffles":"waffle",
"waffling":"waffle",
"wafted":"waft",
"wafting":"waft",
"wafts":"waft",
"waftures":"wafture",
"wagged":"wag",
"wagging":"wag",
"wags":"wag",
"wages":"wage",
"waging":"wage",
"wagered":"wager",
"wagering":"wager",
"wagers":"wager",
"wagerers":"wagerer",
"wageses":"wages",
"waggeries":"waggery",
"waggishnesses":"waggishness",
"waggled":"waggle",
"waggles":"waggle",
"waggling":"waggle",
"wagglier":"waggly",
"waggliest":"waggly",
"waggons":"waggon",
"waggoners":"waggoner",
"waggonwrights":"waggonwright",
"wagners":"wagner",
"wagoned":"wagon",
"wagoning":"wagon",
"wagons":"wagon",
"wagon-lits":"wagon-lit",
"wagons-lits":"wagon-lit",
"wagoners":"wagoner",
"wagonwrights":"wagonwright",
"wagrams":"wagram",
"wahhabis":"wahabi",
"wahoos":"wahoo",
"wahunsonacocks":"wahunsonacock",
"wahveys":"wahvey",
"wailed":"wail",
"wailing":"wail",
"wails":"wail",
"wailings":"wailing",
"wainscoted":"wainscot",
"wainscoting":"wainscot",
"wainscots":"wainscot",
"wainscotted":"wainscot",
"wainscotting":"wainscot",
"wainscotings":"wainscoting",
"wainscottings":"wainscotting",
"wainwrights":"wainwright",
"waists":"waist",
"waistbands":"waistband",
"waistcloths":"waistcloth",
"waistcoats":"waistcoat",
"waistlines":"waistline",
"waited":"wait",
"waiting":"wait",
"waits":"wait",
"waiters":"waiter",
"waitings":"waiting",
"waitressed":"waitress",
"waitresses":"waitress",
"waitressing":"waitress",
"waived":"waive",
"waives":"waive",
"waiving":"waive",
"waivers":"waiver",
"wakashans":"wakashan",
"waked":"wake",
"wakes":"wake",
"waking":"wake",
"woke":"wake",
"woken":"wake",
"wake-robins":"wake-robin",
"wakefulnesses":"wakefulness",
"wakened":"waken",
"wakening":"waken",
"wakens":"waken",
"wakenings":"wakening",
"walapais":"walapai",
"walbiris":"walbiri",
"waldmeisters":"waldmeister",
"waled":"wale",
"wales":"wale",
"waling":"wale",
"waleses":"wales",
"walked":"walk",
"walking":"walk",
"walks":"walk",
"walk-ups":"walk-up",
"walkaways":"walkaway",
"walkers":"walker",
"walkie-talkies":"walkie-talkie",
"walkings":"walking",
"walkingsticks":"walkingstick",
"walkovers":"walkover",
"walkways":"walkway",
"walky-talkies":"walky-talky",
"walling":"wall",
"walls":"wall",
"wallabies":"wallaby",
"wallahs":"wallah",
"wallaroos":"wallaroo",
"wallets":"wallet",
"walleyes":"walleye",
"wallflowers":"wallflower",
"walloped":"wallop",
"walloping":"wallop",
"wallops":"wallop",
"wallopings":"walloping",
"wallowed":"wallow",
"wallowing":"wallow",
"wallows":"wallow",
"wallpapered":"wallpaper",
"wallpapering":"wallpaper",
"wallpapers":"wallpaper",
"wallies":"wally",
"walnuts":"walnut",
"walpoles":"walpole",
"walruses":"walrus",
"waltzed":"waltz",
"waltzes":"waltz",
"waltzing":"waltz",
"waltzs":"waltz",
"wambled":"wamble",
"wambles":"wamble",
"wambling":"wamble",
"wampanoags":"wampanoag",
"wampees":"wampee",
"wampums":"wampum",
"wanned":"wan",
"wanner":"wan",
"wannest":"wan",
"wanning":"wan",
"wans":"wan",
"wands":"wand",
"wandalas":"wandala",
"wandered":"wander",
"wandering":"wander",
"wanders":"wander",
"wanderers":"wanderer",
"wanderings":"wandering",
"wanderjahre":"wanderjahr",
"wanderoos":"wanderoo",
"wandflowers":"wandflower",
"waned":"wane",
"wanes":"wane",
"waning":"wane",
"wangled":"wangle",
"wangles":"wangle",
"wangling":"wangle",
"wanglings":"wangling",
"wanks":"wank",
"wannabes":"wannabe",
"wannabees":"wannabee",
"wannesses":"wanness",
"wanted":"want",
"wanting":"want",
"wants":"want",
"wantoned":"wanton",
"wantoning":"wanton",
"wantons":"wanton",
"wantonnesses":"wantonness",
"wapitis":"wapiti",
"warred":"war",
"warring":"war",
"wars":"war",
"waratahs":"waratah",
"warbled":"warble",
"warbles":"warble",
"warbling":"warble",
"warblers":"warbler",
"warded":"ward",
"warding":"ward",
"wards":"ward",
"ward-heelers":"ward-heeler",
"wardens":"warden",
"warders":"warder",
"wardrobes":"wardrobe",
"wared":"ware",
"wares":"ware",
"waring":"ware",
"warehoused":"warehouse",
"warehouses":"warehouse",
"warehousing":"warehouse",
"warehousemen":"warehouseman",
"warehousers":"warehouser",
"warehousings":"warehousing",
"wareses":"wares",
"warfares":"warfare",
"warfarins":"warfarin",
"warheads":"warhead",
"warhorses":"warhorse",
"warinesses":"wariness",
"warlords":"warlord",
"warlpiris":"warlpiri",
"warmed":"warm",
"warmer":"warm",
"warmest":"warm",
"warming":"warm",
"warm-ups":"warm-up",
"warmers":"warmer",
"warmheartednesses":"warmheartedness",
"warmings":"warming",
"warmnesses":"warmness",
"warmongers":"warmonger",
"warmongerings":"warmongering",
"warmths":"warmth",
"warned":"warn",
"warning":"warn",
"warns":"warn",
"warnings":"warning",
"warped":"warp",
"warping":"warp",
"warps":"warp",
"warpaths":"warpath",
"warpings":"warping",
"warragals":"warragal",
"warranted":"warrant",
"warranting":"warrant",
"warrants":"warrant",
"warrantors":"warrantor",
"warranties":"warranty",
"warrens":"warren",
"warrigals":"warrigal",
"warriors":"warrior",
"warsaws":"warsaw",
"warships":"warship",
"warsled":"warsle",
"warsling":"warsle",
"warstled":"warsle",
"warts":"wart",
"wartweeds":"wartweed",
"wartworts":"wartwort",
"wartier":"warty",
"wartiest":"warty",
"warier":"wary",
"wariest":"wary",
"washed":"wash",
"washes":"wash",
"washing":"wash",
"wash-and-wears":"wash-and-wear",
"washables":"washable",
"washableses":"washables",
"washbasins":"washbasin",
"washboards":"washboard",
"washbowls":"washbowl",
"washcloths":"washcloth",
"washdays":"washday",
"washers":"washer",
"washermen":"washerman",
"washerwomen":"washerwoman",
"washings":"washing",
"washingtons":"washington",
"washouts":"washout",
"washrags":"washrag",
"washstands":"washstand",
"washups":"washup",
"washwomen":"washwoman",
"washier":"washy",
"washiest":"washy",
"wasps":"wasp",
"waspier":"waspy",
"waspiest":"waspy",
"wassailed":"wassail",
"wassailing":"wassail",
"wassails":"wassail",
"wassailers":"wassailer",
"wasted":"waste",
"wastes":"waste",
"wasting":"waste",
"wastebaskets":"wastebasket",
"wastebins":"wastebin",
"wastefulnesses":"wastefulness",
"wastelands":"wasteland",
"wasters":"waster",
"wastewaters":"wastewater",
"wasteweirs":"wasteweir",
"wasteyards":"wasteyard",
"wastings":"wasting",
"wastrels":"wastrel",
"watched":"watch",
"watches":"watch",
"watching":"watch",
"watchbands":"watchband",
"watchdogs":"watchdog",
"watchers":"watcher",
"watchfulnesses":"watchfulness",
"watchings":"watching",
"watchmakers":"watchmaker",
"watchmen":"watchman",
"watchstraps":"watchstrap",
"watchwords":"watchword",
"watered":"water",
"watering":"water",
"waters":"water",
"water-cooled":"water-cool",
"water-cooling":"water-cool",
"water-shields":"water-shield",
"water-ski'd":"water-ski",
"water-skied":"water-ski",
"water-skiing":"water-ski",
"water-skis":"water-ski",
"water-soaked":"water-soak",
"water-soaking":"water-soak",
"water-targets":"water-target",
"water-waved":"water-wave",
"water-waving":"water-wave",
"waterbirds":"waterbird",
"watercannons":"watercannon",
"watercolors":"watercolor",
"watercolorists":"watercolorist",
"watercolourists":"watercolourist",
"watercolouses":"watercolous",
"watercourses":"watercourse",
"watercrafts":"watercraft",
"watered-silks":"watered-silk",
"waterfalls":"waterfall",
"waterfinders":"waterfinder",
"waterfowls":"waterfowl",
"waterfronts":"waterfront",
"waterings":"watering",
"waterlessnesses":"waterlessness",
"waterlines":"waterline",
"waterloos":"waterloo",
"watermen":"waterman",
"watermarks":"watermark",
"watermelons":"watermelon",
"watermints":"watermint",
"waterproofed":"waterproof",
"waterproofing":"waterproof",
"waterproofs":"waterproof",
"waterproofings":"waterproofing",
"waterses":"waters",
"watersheds":"watershed",
"waterskins":"waterskin",
"waterspouts":"waterspout",
"waterways":"waterway",
"waterwheels":"waterwheel",
"waterworkses":"waterworks",
"waterier":"watery",
"wateriest":"watery",
"watses":"wats",
"watts":"watt",
"wattages":"wattage",
"wattled":"wattle",
"wattles":"wattle",
"wattling":"wattle",
"watusis":"watusi",
"waved":"wave",
"waves":"wave",
"waving":"wave",
"wave-offs":"wave-off",
"waveforms":"waveform",
"waveguides":"waveguide",
"wavelengths":"wavelength",
"wavelets":"wavelet",
"wavered":"waver",
"wavering":"waver",
"wavers":"waver",
"waverers":"waverer",
"waverings":"wavering",
"wavings":"waving",
"wavier":"wavy",
"waviest":"wavy",
"waxed":"wax",
"waxes":"wax",
"waxing":"wax",
"waxberries":"waxberry",
"waxflowers":"waxflower",
"waxflowerls":"waxflowerl",
"waxmallows":"waxmallow",
"waxworks":"waxwork",
"waxier":"waxy",
"waxiest":"waxy",
"ways":"way",
"waybills":"waybill",
"wayfarers":"wayfarer",
"waylands":"wayland",
"waylaid":"waylay",
"waylaying":"waylay",
"waylays":"waylay",
"wayses":"ways",
"waysides":"wayside",
"wbs":"wb",
"wbns":"wbn",
"wbses":"wbs",
"weaker":"weak",
"weakest":"weak",
"weakened":"weaken",
"weakening":"weaken",
"weakens":"weaken",
"weakfishes":"weakfish",
"weaklings":"weakling",
"weaklier":"weakly",
"weakliest":"weakly",
"weaknesses":"weakness",
"weals":"weal",
"wealths":"wealth",
"wealthinesses":"wealthiness",
"wealthier":"wealthy",
"wealthiest":"wealthy",
"weaned":"wean",
"weaning":"wean",
"weanings":"weaning",
"weapons":"weapon",
"weaponries":"weaponry",
"wearing":"wear",
"wears":"wear",
"wore":"wear",
"worn":"wear",
"wearinesses":"weariness",
"wearings":"wearing",
"wearied":"weary",
"wearier":"weary",
"wearies":"weary",
"weariest":"weary",
"wearying":"weary",
"weaseled":"weasel",
"weaseling":"weasel",
"weasels":"weasel",
"weathered":"weather",
"weathering":"weather",
"weathers":"weather",
"weatherboarded":"weatherboard",
"weatherboarding":"weatherboard",
"weatherboards":"weatherboard",
"weatherboardings":"weatherboarding",
"weathercocks":"weathercock",
"weathermen":"weatherman",
"weatherproofed":"weatherproof",
"weatherproofing":"weatherproof",
"weathervanes":"weathervane",
"weaved":"weave",
"weaves":"weave",
"weaving":"weave",
"wove":"weave",
"woven":"weave",
"weavers":"weaver",
"weaverbirds":"weaverbird",
"webbed":"web",
"webbing":"web",
"webs":"web",
"webbier":"webby",
"webbiest":"webby",
"webers":"weber",
"webfeet":"webfoot",
"websters":"webster",
"wedded":"wed",
"weds":"wed",
"weddings":"wedding",
"wedged":"wedge",
"wedges":"wedge",
"wedging":"wedge",
"wedgies":"wedgie",
"wedgieses":"wedgies",
"wedgier":"wedgy",
"wedgiest":"wedgy",
"wedlocks":"wedlock",
"wednesdays":"wednesday",
"weer":"wee",
"wees":"wee",
"weest":"wee",
"weeded":"weed",
"weeding":"weed",
"weeds":"weed",
"weedses":"weeds",
"weedier":"weedy",
"weediest":"weedy",
"weeks":"week",
"weekdays":"weekday",
"weekended":"weekend",
"weekending":"weekend",
"weekends":"weekend",
"weeklies":"weekly",
"weened":"ween",
"weening":"ween",
"weenesses":"weeness",
"weenies":"weenie",
"weensier":"weensy",
"weensiest":"weensy",
"weenier":"weeny",
"weeniest":"weeny",
"weeping":"weep",
"weeps":"weep",
"wept":"weep",
"weepers":"weeper",
"weepinesses":"weepiness",
"weepings":"weeping",
"weepier":"weepy",
"weepies":"weepy",
"weepiest":"weepy",
"weevils":"weevil",
"weeweed":"weewee",
"weeweeing":"weewee",
"weewees":"weewee",
"wefts":"weft",
"weigelas":"weigela",
"weighed":"weigh",
"weighing":"weigh",
"weighs":"weigh",
"weighings":"weighing",
"weighted":"weight",
"weighting":"weight",
"weights":"weight",
"weightinesses":"weightiness",
"weightings":"weighting",
"weightlessnesses":"weightlessness",
"weightlifters":"weightlifter",
"weightier":"weighty",
"weightiest":"weighty",
"weirder":"weird",
"weirdest":"weird",
"weirds":"weird",
"weirdies":"weirdie",
"weirdnesses":"weirdness",
"weirdoes":"weirdo",
"weisenheimers":"weisenheimer",
"wekas":"weka",
"welched":"welch",
"welching":"welch",
"welchers":"welcher",
"welcomed":"welcome",
"welcomes":"welcome",
"welcoming":"welcome",
"welcomings":"welcoming",
"welded":"weld",
"welding":"weld",
"welds":"weld",
"welders":"welder",
"welfares":"welfare",
"welkins":"welkin",
"welled":"well",
"welling":"well",
"wells":"well",
"well-beings":"well-being",
"best-off":"well-off",
"better-off":"well-off",
"well-wishers":"well-wisher",
"wellheads":"wellhead",
"wellingtons":"wellington",
"wellpoints":"wellpoint",
"wellsprings":"wellspring",
"welshed":"welsh",
"welshes":"welsh",
"welshing":"welsh",
"welshers":"welsher",
"Welshmen":"Welshman",
"welshwomen":"welshmen",
"welted":"welt",
"welting":"welt",
"welts":"welt",
"weltanschauungs":"weltanschauung",
"weltered":"welter",
"weltering":"welter",
"welters":"welter",
"weltschmerzs":"weltschmerz",
"welwitschias":"welwitschia",
"welwitschiaceaes":"welwitschiaceae",
"wens":"wen",
"wen-tis":"wen-ti",
"wenched":"wench",
"wenches":"wench",
"wenching":"wench",
"wended":"wend",
"wending":"wend",
"werewolves":"werewolf",
"wesleys":"wesley",
"wesleyanisms":"wesleyanism",
"wesleyisms":"wesleyism",
"wests":"west",
"westers":"wester",
"westerlies":"westerly",
"westerns":"western",
"westernized":"westernize",
"westernizes":"westernize",
"westernizing":"westernize",
"wets":"wet",
"wetted":"wet",
"wetter":"wet",
"wettest":"wet",
"wetting":"wet",
"wetbacks":"wetback",
"wettings":"wetting",
"whacked":"whack",
"whacking":"whack",
"whacks":"whack",
"whackers":"whacker",
"whackings":"whacking",
"whackier":"whacky",
"whackiest":"whacky",
"whaled":"whale",
"whales":"whale",
"whaling":"whale",
"whalebones":"whalebone",
"whalers":"whaler",
"whalesuckers":"whalesucker",
"whammed":"wham",
"whamming":"wham",
"whams":"wham",
"whammies":"whammy",
"whanged":"whang",
"whanging":"whang",
"whangs":"whang",
"whapped":"whap",
"whapping":"whap",
"whaps":"whap",
"wharfed":"wharf",
"wharfing":"wharf",
"wharfs":"wharf",
"wharves":"wharf",
"wharfages":"wharfage",
"whatchamacallits":"whatchamacallit",
"whatnots":"whatnot",
"whatses":"whatsis",
"wheals":"wheal",
"wheats":"wheat",
"wheatworms":"wheatworm",
"wheedled":"wheedle",
"wheedles":"wheedle",
"wheedling":"wheedle",
"wheedlings":"wheedling",
"wheeled":"wheel",
"wheeling":"wheel",
"wheels":"wheel",
"wheelbarrows":"wheelbarrow",
"wheelers":"wheeler",
"wheelhouses":"wheelhouse",
"wheelies":"wheelie",
"wheelings":"wheeling",
"wheelmen":"wheelman",
"wheezed":"wheeze",
"wheezes":"wheeze",
"wheezing":"wheeze",
"wheezier":"wheezy",
"wheeziest":"wheezy",
"whelmed":"whelm",
"whelming":"whelm",
"whelms":"whelm",
"whelped":"whelp",
"whelping":"whelp",
"whelps":"whelp",
"wherefores":"wherefore",
"wherries":"wherry",
"whets":"whet",
"whetted":"whet",
"whetting":"whet",
"whetters":"whetter",
"wheys":"whey",
"whickered":"whicker",
"whickering":"whicker",
"whickers":"whicker",
"whidahs":"whidah",
"whiffed":"whiff",
"whiffing":"whiff",
"whiffs":"whiff",
"whiffled":"whiffle",
"whiffling":"whiffle",
"whiffletrees":"whiffletree",
"whigmaleeries":"whigmaleerie",
"whiled":"while",
"whiles":"while",
"whiling":"while",
"whims":"whim",
"whimpered":"whimper",
"whimpering":"whimper",
"whimpers":"whimper",
"whimseys":"whimsey",
"whimsicalities":"whimsicality",
"whimsies":"whimsy",
"whins":"whin",
"whinberries":"whinberry",
"whinchats":"whinchat",
"whined":"whine",
"whines":"whine",
"whining":"whine",
"whiners":"whiner",
"whinnied":"whinny",
"whinnies":"whinny",
"whinnying":"whinny",
"whinier":"whiny",
"whiniest":"whiny",
"whipped":"whip",
"whipping":"whip",
"whips":"whip",
"whipt":"whip",
"whiplashes":"whiplash",
"whippers-in":"whipper-in",
"whippersnappers":"whippersnapper",
"whippings":"whipping",
"whippletrees":"whippletree",
"whippoorwills":"whippoorwill",
"whippier":"whippy",
"whippiest":"whippy",
"whipsawed":"whipsaw",
"whipsawing":"whipsaw",
"whipsawn":"whipsaw",
"whipsaws":"whipsaw",
"whipscorpions":"whipscorpion",
"whipsnakes":"whipsnake",
"whipstitched":"whipstitch",
"whipstitches":"whipstitch",
"whipstitching":"whipstitch",
"whipstitchings":"whipstitching",
"whiptails":"whiptail",
"whirred":"whirr",
"whirring":"whirr",
"whirs":"whir",
"whirled":"whirl",
"whirling":"whirl",
"whirls":"whirl",
"whirligigs":"whirligig",
"whirlings":"whirling",
"whirlpooled":"whirlpool",
"whirlpooling":"whirlpool",
"whirlpools":"whirlpool",
"whirlwinds":"whirlwind",
"whirlies":"whirly",
"whirlybirds":"whirlybird",
"whirrs":"whirr",
"whirrings":"whirring",
"whirried":"whirry",
"whirrying":"whirry",
"whished":"whish",
"whishing":"whish",
"whisked":"whisk",
"whisking":"whisk",
"whisks":"whisk",
"whiskbrooms":"whiskbroom",
"whiskered":"whisker",
"whiskering":"whisker",
"whiskers":"whisker",
"whiskerses":"whiskers",
"whiskeys":"whiskey",
"whiskies":"whisky",
"whispered":"whisper",
"whispering":"whisper",
"whispers":"whisper",
"whisperings":"whispering",
"whists":"whist",
"whistled":"whistle",
"whistles":"whistle",
"whistling":"whistle",
"whistle-stopped":"whistle-stop",
"whistle-stopping":"whistle-stop",
"whistle-stops":"whistle-stop",
"whistlers":"whistler",
"whistlings":"whistling",
"whits":"whit",
"whit-tuesdays":"whit-tuesday",
"whiter":"white",
"whites":"white",
"whitest":"white",
"whitecaps":"whitecap",
"whitecups":"whitecup",
"whitefaces":"whiteface",
"whitefishes":"whitefish",
"whiteflies":"whitefly",
"whiteheads":"whitehead",
"whitelashes":"whitelash",
"whitened":"whiten",
"whitening":"whiten",
"whitens":"whiten",
"whiteners":"whitener",
"whitenesses":"whiteness",
"whitenings":"whitening",
"whitetails":"whitetail",
"whitethorns":"whitethorn",
"whitethroats":"whitethroat",
"whitewashed":"whitewash",
"whitewashes":"whitewash",
"whitewashing":"whitewash",
"whitewoods":"whitewood",
"whiteys":"whitey",
"whitings":"whiting",
"whitlavias":"whitlavia",
"whitlows":"whitlow",
"whitmondays":"whitmonday",
"whitneys":"whitney",
"whitsuns":"whitsun",
"whitsundays":"whitsunday",
"whitsuntides":"whitsuntide",
"whittled":"whittle",
"whittles":"whittle",
"whittling":"whittle",
"whitweeks":"whitweek",
"whitier":"whity",
"whities":"whity",
"whitiest":"whity",
"whizs":"whiz",
"whizzed":"whiz",
"whizzes":"whiz",
"whizzing":"whiz",
"whiz-kids":"whiz-kid",
"whizbangs":"whizbang",
"whizzs":"whizz",
"whizz-kids":"whizz-kid",
"whizzbangs":"whizzbang",
"whos":"who",
"whodunits":"whodunit",
"wholes":"whole",
"wholeheartednesses":"wholeheartedness",
"wholenesses":"wholeness",
"wholesaled":"wholesale",
"wholesaling":"wholesale",
"wholesalers":"wholesaler",
"whomped":"whomp",
"whomping":"whomp",
"whomps":"whomp",
"whooped":"whoop",
"whooping":"whoop",
"whoops":"whoop",
"whoopers":"whooper",
"whooshed":"whoosh",
"whooshes":"whoosh",
"whooshing":"whoosh",
"whopped":"whop",
"whopping":"whop",
"whops":"whop",
"whoppers":"whopper",
"whored":"whore",
"whores":"whore",
"whoring":"whore",
"whoredoms":"whoredom",
"whorehouses":"whorehouse",
"whoremasters":"whoremaster",
"whoremongers":"whoremonger",
"whorls":"whorl",
"whorlyworts":"whorlywort",
"whortleberries":"whortleberry",
"whies":"why",
"whys":"why",
"whydahs":"whydah",
"wicks":"wick",
"wickeder":"wicked",
"wickedest":"wicked",
"wickednesses":"wickedness",
"wickers":"wicker",
"wickerworks":"wickerwork",
"wickets":"wicket",
"wickups":"wickup",
"wicopies":"wicopy",
"wider":"wide",
"widest":"wide",
"wide-awakes":"wide-awake",
"widened":"widen",
"widening":"widen",
"widens":"widen",
"widenesses":"wideness",
"widenings":"widening",
"widgeons":"widgeon",
"widgets":"widget",
"widowed":"widow",
"widowing":"widow",
"widows":"widow",
"widowers":"widower",
"widowmen":"widowman",
"widths":"width",
"wielands":"wieland",
"wielded":"wield",
"wielding":"wield",
"wields":"wield",
"wieldier":"wieldy",
"wieldiest":"wieldy",
"wieners":"wiener",
"wienerwursts":"wienerwurst",
"wives":"wife",
"wifelier":"wifely",
"wifeliest":"wifely",
"wiffles":"wiffle",
"wigged":"wig",
"wigging":"wig",
"wigs":"wig",
"wigeons":"wigeon",
"wiggings":"wigging",
"wiggled":"wiggle",
"wiggles":"wiggle",
"wiggling":"wiggle",
"wigglers":"wiggler",
"wigglier":"wiggly",
"wiggliest":"wiggly",
"wights":"wight",
"wigwagged":"wigwag",
"wigwagging":"wigwag",
"wigwags":"wigwag",
"wigwams":"wigwam",
"wilder":"wild",
"wildest":"wild",
"wilds":"wild",
"wildcats":"wildcat",
"wildcatted":"wildcat",
"wildcatting":"wildcat",
"wildebeests":"wildebeest",
"wildered":"wilder",
"wildering":"wilder",
"wildernesses":"wilderness",
"wildflowers":"wildflower",
"wildnesses":"wildness",
"wiled":"wile",
"wiles":"wile",
"wiling":"wile",
"wilfulnesses":"wilfulness",
"wilinesses":"wiliness",
"willed":"will",
"willing":"will",
"wills":"will",
"willets":"willet",
"willfulnesses":"willfulness",
"willings":"willing",
"willowed":"willow",
"willowing":"willow",
"willows":"willow",
"willow-patterns":"willow-pattern",
"willowwares":"willowware",
"willowier":"willowy",
"willowiest":"willowy",
"willpowers":"willpower",
"wilsons":"wilson",
"wilted":"wilt",
"wilting":"wilt",
"wilts":"wilt",
"wiltings":"wilting",
"wilier":"wily",
"wiliest":"wily",
"wimbles":"wimble",
"wimps":"wimp",
"wimpled":"wimple",
"wimpling":"wimple",
"winning":"win",
"wins":"win",
"won":"win",
"winced":"wince",
"winces":"wince",
"wincing":"wince",
"winched":"winch",
"winches":"winch",
"winching":"winch",
"winded":"wind",
"winding":"wind",
"winds":"wind",
"wound":"wind",
"windages":"windage",
"windbags":"windbag",
"windbreaks":"windbreak",
"windbreakers":"windbreaker",
"windcheaters":"windcheater",
"winders":"winder",
"windfalls":"windfall",
"windflowers":"windflower",
"windinesses":"windiness",
"windings":"winding",
"winding-clotheses":"winding-clothes",
"winding-sheets":"winding-sheet",
"windlassed":"windlass",
"windlasses":"windlass",
"windlassing":"windlass",
"windlessnesses":"windlessness",
"windmills":"windmill",
"windowed":"window",
"windowing":"window",
"windows":"window",
"window-shopped":"window-shop",
"window-shopping":"window-shop",
"window-shops":"window-shop",
"windowpanes":"windowpane",
"windpipes":"windpipe",
"windrowed":"windrow",
"windrowing":"windrow",
"windscreens":"windscreen",
"windshields":"windshield",
"windsocks":"windsock",
"windsors":"windsor",
"windups":"windup",
"windier":"windy",
"windiest":"windy",
"wined":"wine",
"wines":"wine",
"wining":"wine",
"wine-coloreds":"wine-colored",
"wineberries":"wineberry",
"winemakers":"winemaker",
"wineries":"winery",
"winged":"wing",
"winging":"wing",
"wings":"wing",
"wingspans":"wingspan",
"wingspreads":"wingspread",
"wingstems":"wingstem",
"wingier":"wingy",
"wingiest":"wingy",
"winked":"wink",
"winking":"wink",
"winks":"wink",
"winkers":"winker",
"winkled":"winkle",
"winkles":"winkle",
"winkling":"winkle",
"winnebagoes":"winnebago",
"winnebagos":"winnebago",
"winners":"winner",
"winnings":"winning",
"winningses":"winnings",
"winnowed":"winnow",
"winnowing":"winnow",
"winnows":"winnow",
"winnowings":"winnowing",
"winos":"wino",
"wintered":"winter",
"wintering":"winter",
"winters":"winter",
"winteras":"wintera",
"winteraceaes":"winteraceae",
"winterberries":"winterberry",
"winterfed":"winterfeed",
"winterfeeding":"winterfeed",
"winterfeeds":"winterfeed",
"wintergreens":"wintergreen",
"winterized":"winterize",
"winterizing":"winterize",
"winterkilled":"winterkill",
"winterkilling":"winterkill",
"wintertimes":"wintertime",
"winterier":"wintery",
"winteriest":"wintery",
"wintrier":"wintry",
"wintriest":"wintry",
"winier":"winy",
"winiest":"winy",
"wiped":"wipe",
"wipes":"wipe",
"wiping":"wipe",
"wipers":"wiper",
"wired":"wire",
"wires":"wire",
"wiring":"wire",
"wiredrawing":"wiredraw",
"wiredrawn":"wiredraw",
"wiredraws":"wiredraw",
"wiredrew":"wiredraw",
"wirehairs":"wirehair",
"wirelessed":"wireless",
"wirelesses":"wireless",
"wirelessing":"wireless",
"wiremen":"wireman",
"wirephotos":"wirephoto",
"wiretapped":"wiretap",
"wiretapping":"wiretap",
"wiretaps":"wiretap",
"wireworks":"wirework",
"wirier":"wiry",
"wiriest":"wiry",
"wisconsins":"wisconsin",
"wisdoms":"wisdom",
"wiser":"wise",
"wises":"wise",
"wisest":"wise",
"wiseacres":"wiseacre",
"wisecracked":"wisecrack",
"wisecracking":"wisecrack",
"wisecracks":"wisecrack",
"wisenesses":"wiseness",
"wisenheimers":"wisenheimer",
"wisents":"wisent",
"wished":"wish",
"wishes":"wish",
"wishing":"wish",
"wish-washes":"wish-wash",
"wishbones":"wishbone",
"wishings":"wishing",
"wishy-washier":"wishy-washy",
"wishy-washiest":"wishy-washy",
"wisped":"wisp",
"wisping":"wisp",
"wisps":"wisp",
"wispier":"wispy",
"wispiest":"wispy",
"wistarias":"wistaria",
"wisterias":"wisteria",
"wist":"wit",
"wits":"wit",
"witting":"wit",
"witched":"witch",
"witches":"witch",
"witching":"witch",
"witchcrafts":"witchcraft",
"witcheries":"witchery",
"witchgrasses":"witchgrass",
"witchier":"witchy",
"witchiest":"witchy",
"withdrawing":"withdraw",
"withdrawn":"withdraw",
"withdrew":"withdraw",
"withdrawals":"withdrawal",
"withdraws":"withdraw",
"withdrawnnesses":"withdrawnness",
"withed":"withe",
"withes":"withe",
"withing":"withe",
"withered":"wither",
"withering":"wither",
"withers":"wither",
"witherings":"withering",
"withheld":"withhold",
"withholding":"withhold",
"withholds":"withhold",
"withholdings":"withholding",
"withstanding":"withstand",
"withstands":"withstand",
"withstood":"withstand",
"withies":"withy",
"witloofs":"witloof",
"witnessed":"witness",
"witnesses":"witness",
"witnessing":"witness",
"wittgensteins":"wittgenstein",
"witticisms":"witticism",
"wittinesses":"wittiness",
"wittier":"witty",
"wittiest":"witty",
"wived":"wive",
"wiving":"wive",
"wiverns":"wivern",
"wizs":"wiz",
"wizards":"wizard",
"wizardries":"wizardry",
"wmos":"wmo",
"wnws":"wnw",
"wos":"wo",
"woadwaxens":"woadwaxen",
"wobbled":"wobble",
"wobbles":"wobble",
"wobbling":"wobble",
"wobblier":"wobbly",
"wobblies":"wobbly",
"wobbliest":"wobbly",
"wodans":"wodan",
"wodens":"woden",
"woes":"woe",
"woefulnesses":"woefulness",
"wolds":"wold",
"wolfed":"wolf",
"wolfing":"wolf",
"wolfs":"wolf",
"wolves":"wolf",
"wolfbanes":"wolfbane",
"wolffias":"wolffia",
"wolffiellas":"wolffiella",
"wolffishes":"wolffish",
"wolfmen":"wolfman",
"wolframs":"wolfram",
"wolframites":"wolframite",
"wolfsbanes":"wolfsbane",
"wollies":"wolly",
"wolofs":"wolof",
"wolverines":"wolverine",
"women":"woman",
"woman-worships":"woman-worship",
"womanhoods":"womanhood",
"womanisers":"womaniser",
"womanishnesses":"womanishness",
"womanized":"womanize",
"womanizes":"womanize",
"womanizing":"womanize",
"womanizers":"womanizer",
"womanlikes":"womanlike",
"womanlinesses":"womanliness",
"womanlier":"womanly",
"womanliest":"womanly",
"wombs":"womb",
"wons":"won",
"wondered":"wonder",
"wondering":"wonder",
"wonders":"wonder",
"wonderberries":"wonderberry",
"wonderfulnesses":"wonderfulness",
"wonderments":"wonderment",
"wonks":"wonk",
"wonkier":"wonky",
"wonkiest":"wonky",
"wonted":"wont",
"wonting":"wont",
"wonts":"wont",
"wontons":"wonton",
"wooed":"woo",
"wooing":"woo",
"woos":"woo",
"wooded":"wood",
"wooding":"wood",
"woods":"wood",
"wood-ferns":"wood-fern",
"woodbines":"woodbine",
"woodborers":"woodborer",
"woodcarvers":"woodcarver",
"woodchucks":"woodchuck",
"woodcocks":"woodcock",
"woodcreepers":"woodcreeper",
"woodcuts":"woodcut",
"woodcutters":"woodcutter",
"woodferns":"woodfern",
"woodfrogs":"woodfrog",
"woodgrainings":"woodgraining",
"woodhewers":"woodhewer",
"woodlands":"woodland",
"woodlets":"woodlet",
"woodlouses":"woodlouse",
"woodmen":"woodman",
"woodpeckers":"woodpecker",
"woodrats":"woodrat",
"woodruffs":"woodruff",
"woodses":"woods",
"woodshedded":"woodshed",
"woodshedding":"woodshed",
"woodsmen":"woodsman",
"woodsier":"woodsy",
"woodsiest":"woodsy",
"woodwardias":"woodwardia",
"woodwaxens":"woodwaxen",
"woodwinds":"woodwind",
"woodworks":"woodwork",
"woodworkers":"woodworker",
"woodworkings":"woodworking",
"woodier":"woody",
"woodiest":"woody",
"wooers":"wooer",
"woofed":"woof",
"woofing":"woof",
"woofs":"woof",
"wooings":"wooing",
"wools":"wool",
"woolens":"woolen",
"woolgatherers":"woolgatherer",
"woollens":"woollen",
"woollier":"woolly",
"woollies":"woolly",
"woolliest":"woolly",
"woolier":"wooly",
"wooliest":"wooly",
"woomeras":"woomera",
"woozier":"woozy",
"wooziest":"woozy",
"wops":"wop",
"worded":"word",
"wording":"word",
"words":"word",
"word-paintings":"word-painting",
"word-splittings":"word-splitting",
"word-worships":"word-worship",
"wordinesses":"wordiness",
"wordings":"wording",
"wordplays":"wordplay",
"wordses":"words",
"wordsworths":"wordsworth",
"wordier":"wordy",
"wordiest":"wordy",
"worked":"work",
"working":"work",
"works":"work",
"wrought":"work",
"work-clotheses":"work-clothes",
"work-clothings":"work-clothing",
"workbags":"workbag",
"workbaskets":"workbasket",
"workbenches":"workbench",
"workboxes":"workbox",
"workdays":"workday",
"workers":"worker",
"workfellows":"workfellow",
"workforces":"workforce",
"workhouses":"workhouse",
"workings":"working",
"workingmen":"workingman",
"workingses":"workings",
"workingwomen":"workingwoman",
"workmen":"workman",
"workmanships":"workmanship",
"workouts":"workout",
"workplaces":"workplace",
"workses":"works",
"workshops":"workshop",
"worktables":"worktable",
"workweeks":"workweek",
"workwomen":"workwoman",
"worlds":"world",
"world-beaters":"world-beater",
"world-wearinesses":"world-weariness",
"worldlinesses":"worldliness",
"worldlier":"worldly",
"worldliest":"worldly",
"wormed":"worm",
"worming":"worm",
"worms":"worm",
"wormseeds":"wormseed",
"wormier":"wormy",
"wormiest":"wormy",
"worriers":"worrier",
"worriments":"worriment",
"worries":"worry",
"worrying":"worry",
"worryings":"worrying",
"worrywarts":"worrywart",
"worsened":"worsen",
"worsening":"worsen",
"worsens":"worsen",
"worsenings":"worsening",
"worshiped":"worship",
"worshiping":"worship",
"worshipped":"worship",
"worshipping":"worship",
"worships":"worship",
"worshipers":"worshiper",
"worshippers":"worshipper",
"worthier":"worthy",
"worthies":"worthy",
"worthiest":"worthy",
"wounding":"wound",
"wounds":"wound",
"woundeds":"wounded",
"woundings":"wounding",
"wowed":"wow",
"wowing":"wow",
"wows":"wow",
"wpms":"wpm",
"wracks":"wrack",
"wraiths":"wraith",
"wrangled":"wrangle",
"wrangles":"wrangle",
"wrangling":"wrangle",
"wranglers":"wrangler",
"wranglings":"wrangling",
"wrapped":"wrap",
"wrapping":"wrap",
"wraps":"wrap",
"wrapt":"wrap",
"wrappers":"wrapper",
"wrappings":"wrapping",
"wraths":"wrath",
"wreaked":"wreak",
"wreaking":"wreak",
"wreaks":"wreak",
"wreathed":"wreathe",
"wreathing":"wreathe",
"wreaths":"wreath",
"wreathes":"wreathe",
"wrecked":"wreck",
"wrecking":"wreck",
"wrecks":"wreck",
"wreckers":"wrecker",
"wreckfishes":"wreckfish",
"wreckings":"wrecking",
"wrens":"wren",
"wren-tits":"wren-tit",
"wrenched":"wrench",
"wrenches":"wrench",
"wrenching":"wrench",
"wrested":"wrest",
"wresting":"wrest",
"wrests":"wrest",
"wrestled":"wrestle",
"wrestles":"wrestle",
"wrestling":"wrestle",
"wrestlers":"wrestler",
"wrestlings":"wrestling",
"wretches":"wretch",
"wretchednesses":"wretchedness",
"wricked":"wrick",
"wricking":"wrick",
"wricks":"wrick",
"wriggled":"wriggle",
"wriggles":"wriggle",
"wriggling":"wriggle",
"wrigglers":"wriggler",
"wrigglier":"wriggly",
"wriggliest":"wriggly",
"wringing":"wring",
"wrings":"wring",
"wrung":"wring",
"wrinkled":"wrinkle",
"wrinkles":"wrinkle",
"wrinkling":"wrinkle",
"wrinklier":"wrinkly",
"wrinkliest":"wrinkly",
"wrists":"wrist",
"wristbands":"wristband",
"wristlets":"wristlet",
"wristwatches":"wristwatch",
"writs":"writ",
"writes":"write",
"writing":"write",
"written":"write",
"wrote":"write",
"write-downs":"write-down",
"write-offs":"write-off",
"writers":"writer",
"writhed":"writhe",
"writhes":"writhe",
"writhing":"writhe",
"writings":"writing",
"writingses":"writings",
"wroclaws":"wroclaw",
"wronged":"wrong",
"wronging":"wrong",
"wrongs":"wrong",
"wrongdoers":"wrongdoer",
"wrongdoings":"wrongdoing",
"wrongfulnesses":"wrongfulness",
"wrongnesses":"wrongness",
"wried":"wry",
"wrier":"wry",
"wries":"wry",
"wriest":"wry",
"wryer":"wry",
"wryest":"wry",
"wrying":"wry",
"wrymouths":"wrymouth",
"wrynecks":"wryneck",
"wsws":"wsw",
"wtvs":"wtv",
"wus":"wu",
"wuerzburgs":"wuerzburg",
"wulfilas":"wulfila",
"wunderkinder":"wunderkind",
"wunderkinds":"wunderkind",
"wurzburgs":"wurzburg",
"wwws":"www",
"wyandots":"wyandot",
"wyethias":"wyethia",
"wynneas":"wynnea",
"wyomings":"wyoming",
"wyrds":"wyrd",
"wyverns":"wyvern",
"xes":"x",
"x-radiations":"x-radiation",
"x-rayed":"x-ray",
"x-raying":"x-ray",
"x-rays":"x-ray",
"x-rayings":"x-raying",
"xanadus":"xanadu",
"xanaxes":"xanax",
"xanthemias":"xanthemia",
"xanthiums":"xanthium",
"xanthomas":"xanthoma",
"xanthomata":"xanthoma",
"xanthomonases":"xanthomonas",
"xanthophyceaes":"xanthophyceae",
"xanthophyls":"xanthophyl",
"xanthophylls":"xanthophyll",
"xanthorrhoeaceaes":"xanthorrhoeaceae",
"xanthorroeas":"xanthorroea",
"xanthosomas":"xanthosoma",
"xantusiidaes":"xantusiidae",
"xcs":"xc",
"xenarthras":"xenarthra",
"xenicidaes":"xenicidae",
"xenicuses":"xenicus",
"xenogeneses":"xenogenesis",
"xenografts":"xenograft",
"xenons":"xenon",
"xenopodidaes":"xenopodidae",
"xenopuses":"xenopus",
"xenorhyncuses":"xenorhyncus",
"xenosauridaes":"xenosauridae",
"xenosauruses":"xenosaurus",
"xerobateses":"xerobates",
"xerophiles":"xerophile",
"xerophyllums":"xerophyllum",
"xerophytes":"xerophyte",
"xeroxed":"xerox",
"xeroxes":"xerox",
"xeroxing":"xerox",
"xhosas":"xhosa",
"xis":"xi",
"xians":"xian",
"xiis":"xii",
"xiiis":"xiii",
"xiphiases":"xiphias",
"xiphiidaes":"xiphiidae",
"xiphisterna":"xiphisternum",
"xiphosuras":"xiphosura",
"xivs":"xiv",
"xixes":"xix",
"xls":"xl",
"xmases":"xmas",
"xts":"xt",
"xvs":"xv",
"xvis":"xvi",
"xviis":"xvii",
"xviiis":"xviii",
"xxes":"xx",
"xxis":"xxi",
"xxiis":"xxii",
"xxiiis":"xxiii",
"xxivs":"xxiv",
"xxixes":"xxix",
"xxvs":"xxv",
"xxvis":"xxvi",
"xxviis":"xxvii",
"xxviiis":"xxviii",
"xxxes":"xxx",
"xylarias":"xylaria",
"xylariaceaes":"xylariaceae",
"xylenes":"xylene",
"xylocaines":"xylocaine",
"xylocopas":"xylocopa",
"xylols":"xylol",
"xylomelums":"xylomelum",
"xylophones":"xylophone",
"xylophonists":"xylophonist",
"xylopias":"xylopia",
"xyloses":"xylose",
"xylosmas":"xylosma",
"xyphophoruses":"xyphophorus",
"xyridaceaes":"xyridaceae",
"xyridaleses":"xyridales",
"xyrises":"xyris",
"y-axes":"y-axis",
"yabbered":"yabber",
"yabbering":"yabber",
"yabbies":"yabbie",
"yaccas":"yacca",
"yachted":"yacht",
"yachting":"yacht",
"yachts":"yacht",
"yachtings":"yachting",
"yachtsmen":"yachtsman",
"yachtswomen":"yachtswoman",
"yacks":"yack",
"yafos":"yafo",
"yagis":"yagi",
"yahoos":"yahoo",
"yahves":"yahve",
"yahvehs":"yahveh",
"yahwes":"yahwe",
"yahwehs":"yahweh",
"yakked":"yak",
"yakking":"yak",
"yaks":"yak",
"yakety-yaks":"yakety-yak",
"yakuts":"yakut",
"yales":"yale",
"yaltopyas":"yaltopya",
"yalus":"yalu",
"yams":"yam",
"yamaltus":"yamaltu",
"yammered":"yammer",
"yammering":"yammer",
"yammers":"yammer",
"yangons":"yangon",
"yangtzes":"yangtze",
"yanked":"yank",
"yanking":"yank",
"yanks":"yank",
"yankees":"yankee",
"yankee-doddles":"yankee-doddle",
"yankeefied":"yankeefy",
"yankeefying":"yankeefy",
"yanquapins":"yanquapin",
"yanquis":"yanqui",
"yaoundes":"yaounde",
"yapped":"yap",
"yapping":"yap",
"yaps":"yap",
"yarded":"yard",
"yarding":"yard",
"yards":"yard",
"yardgrasses":"yardgrass",
"yardmen":"yardman",
"yardmasters":"yardmaster",
"yardsticks":"yardstick",
"yarer":"yare",
"yarest":"yare",
"yarmelkes":"yarmelke",
"yarmulkas":"yarmulka",
"yarmulkes":"yarmulke",
"yarned":"yarn",
"yarning":"yarn",
"yarns":"yarn",
"yarrows":"yarrow",
"yashmacs":"yashmac",
"yashmaks":"yashmak",
"yautias":"yautia",
"yawed":"yaw",
"yawing":"yaw",
"yaws":"yaw",
"yawned":"yawn",
"yawning":"yawn",
"yawns":"yawn",
"yawses":"yaws",
"ybs":"yb",
"yeas":"yea",
"yeaned":"yean",
"yeaning":"yean",
"years":"year",
"yearbooks":"yearbook",
"yearlings":"yearling",
"yearlies":"yearly",
"yearned":"yearn",
"yearning":"yearn",
"yearns":"yearn",
"yearnings":"yearning",
"yearses":"years",
"yeasts":"yeast",
"yeastier":"yeasty",
"yeastiest":"yeasty",
"yeatses":"yeats",
"yeddos":"yeddo",
"yedos":"yedo",
"yelled":"yell",
"yelling":"yell",
"yells":"yell",
"yellers":"yeller",
"yellings":"yelling",
"yellowed":"yellow",
"yellower":"yellow",
"yellowest":"yellow",
"yellowing":"yellow",
"yellows":"yellow",
"yellow-bellies":"yellow-belly",
"yellowbellies":"yellowbelly",
"yellowbirds":"yellowbird",
"yellowfins":"yellowfin",
"yellowhammers":"yellowhammer",
"yellownesses":"yellowness",
"yellowstones":"yellowstone",
"yellowtails":"yellowtail",
"yellowwoods":"yellowwood",
"yelped":"yelp",
"yelping":"yelp",
"yelps":"yelp",
"yelpings":"yelping",
"yemens":"yemen",
"yenned":"yen",
"yenning":"yen",
"yens":"yen",
"yeniseis":"yenisei",
"yenisei-samoyeds":"yenisei-samoyed",
"yeniseians":"yeniseian",
"yeniseys":"yenisey",
"yentas":"yenta",
"yeomen":"yeoman",
"yeses":"yes",
"yessed":"yes",
"yessing":"yes",
"yes-men":"yes-man",
"yeshivahs":"yeshiva",
"yeshivoth":"yeshiva",
"yesterdays":"yesterday",
"yesteryears":"yesteryear",
"yetis":"yeti",
"yews":"yew",
"yezos":"yezo",
"yis":"yi",
"yielded":"yield",
"yielding":"yield",
"yields":"yield",
"yieldings":"yielding",
"yipped":"yip",
"yipping":"yip",
"yips":"yip",
"yisraels":"yisrael",
"ylang-ylangs":"ylang-ylang",
"yo-yos":"yo-yo",
"yobs":"yob",
"yobbos":"yobbo",
"yobos":"yobo",
"yocked":"yock",
"yocking":"yock",
"yodeled":"yodel",
"yodeling":"yodel",
"yodelled":"yodel",
"yodelling":"yodel",
"yodels":"yodel",
"yoghourts":"yoghourt",
"yoghurts":"yoghurt",
"yogin":"yogi",
"yogis":"yogi",
"yogurts":"yogurt",
"yoked":"yoke",
"yokes":"yoke",
"yoking":"yoke",
"yokels":"yokel",
"yokutses":"yokuts",
"yolks":"yolk",
"yonis":"yoni",
"yores":"yore",
"yorks":"york",
"yorubas":"yoruba",
"yosemites":"yosemite",
"younger":"young",
"youngest":"young",
"youngs":"young",
"youngberries":"youngberry",
"youngsters":"youngster",
"younkers":"younker",
"yourselves":"yourself",
"youths":"youth",
"youth-on-ages":"youth-on-age",
"youthfulnesses":"youthfulness",
"yowled":"yowl",
"yowling":"yowl",
"yowls":"yowl",
"yowlings":"yowling",
"ypreses":"ypres",
"yrs":"yr",
"ytterbites":"ytterbite",
"ytterbiums":"ytterbium",
"yttriums":"yttrium",
"yuans":"yuan",
"yucatans":"yucatan",
"yucatecs":"yucatec",
"yucatecos":"yucateco",
"yuccas":"yucca",
"yues":"yue",
"yugoslavs":"yugoslav",
"yugoslavias":"yugoslavia",
"yugoslavians":"yugoslavian",
"yukked":"yuk",
"yukking":"yuk",
"yukons":"yukon",
"yules":"yule",
"yuletides":"yuletide",
"yummier":"yummy",
"yummiest":"yummy",
"yurak-samoyeds":"yurak-samoyed",
"zs":"z",
"z-axes":"z-axis",
"zaars":"zaar",
"zabagliones":"zabaglione",
"zags":"zag",
"zaglossuses":"zaglossus",
"zaires":"zaire",
"zaireans":"zairean",
"zaireses":"zairese",
"zalophuses":"zalophus",
"zamas":"zama",
"zamen":"zaman",
"zamangs":"zamang",
"zambezis":"zambezi",
"zamias":"zamia",
"zamiaceaes":"zamiaceae",
"zamindaris":"zamindari",
"zannichellias":"zannichellia",
"zannichelliaceaes":"zannichelliaceae",
"zantacs":"zantac",
"zantedeschias":"zantedeschia",
"zanthoxylums":"zanthoxylum",
"zanies":"zany",
"zapped":"zap",
"zapping":"zap",
"zaps":"zap",
"zapateados":"zapateado",
"zapodidaes":"zapodidae",
"zapotecs":"zapotec",
"zapuses":"zapus",
"zaragozas":"zaragoza",
"zarathustras":"zarathustra",
"zarebas":"zareba",
"zarontins":"zarontin",
"zarpanits":"zarpanit",
"zarzuelas":"zarzuela",
"zeas":"zea",
"zeals":"zeal",
"zealands":"zealand",
"zealots":"zealot",
"zealotries":"zealotry",
"zebras":"zebra",
"zebrawoods":"zebrawood",
"zebus":"zebu",
"zecchini":"zecchino",
"zeds":"zed",
"zees":"zee",
"zeidaes":"zeidae",
"zelkovas":"zelkova",
"zemstvos":"zemstvo",
"zens":"zen",
"zenaiduras":"zenaidura",
"zenanas":"zenana",
"zends":"zend",
"zend-avestas":"zend-avesta",
"zendos":"zendo",
"zeniths":"zenith",
"zenos":"zeno",
"zeomorphis":"zeomorphi",
"zeps":"zep",
"zephyrs":"zephyr",
"zeppelins":"zeppelin",
"zeroed":"zero",
"zeroes":"zero",
"zeroing":"zero",
"zeros":"zero",
"zests":"zest",
"zestfulnesses":"zestfulness",
"zestrils":"zestril",
"zestier":"zesty",
"zestiest":"zesty",
"zetas":"zeta",
"zetlands":"zetland",
"zeuses":"zeus",
"zhos":"zho",
"zidovudines":"zidovudine",
"zigs":"zig",
"zigadenes":"zigadene",
"zigadenuses":"zigadenus",
"zigzagged":"zigzag",
"zigzagging":"zigzag",
"zigzags":"zigzag",
"zilches":"zilch",
"zillions":"zillion",
"zillionses":"zillions",
"zimbabwes":"zimbabwe",
"zinacefs":"zinacef",
"zinced":"zinc",
"zincing":"zinc",
"zincked":"zinc",
"zincking":"zinc",
"zincs":"zinc",
"zinged":"zing",
"zinging":"zing",
"zings":"zing",
"zingibers":"zingiber",
"zingiberaceaes":"zingiberaceae",
"zingier":"zingy",
"zingiest":"zingy",
"zinjanthropuses":"zinjanthropus",
"zinnias":"zinnia",
"zions":"zion",
"zipped":"zip",
"zipping":"zip",
"zips":"zip",
"zip-fasteners":"zip-fastener",
"ziphiidaes":"ziphiidae",
"zippers":"zipper",
"zippier":"zippy",
"zippies":"zippy",
"zippiest":"zippy",
"zirbanits":"zirbanit",
"zircons":"zircon",
"zirconias":"zirconia",
"zirconiums":"zirconium",
"zithers":"zither",
"zitherns":"zithern",
"zizanias":"zizania",
"ziziphuses":"ziziphus",
"zlotys":"zloty",
"zns":"zn",
"zos":"zo",
"zoaeae":"zoaea",
"zoaeas":"zoaea",
"zoarceses":"zoarces",
"zoarcidaes":"zoarcidae",
"zoeae":"zoea",
"zoeas":"zoea",
"zoisias":"zoisia",
"zolas":"zola",
"zombis":"zombi",
"zombies":"zombie",
"zoned":"zone",
"zones":"zone",
"zoning":"zone",
"zonotrichias":"zonotrichia",
"zoos":"zoo",
"zooerastias":"zooerastia",
"zooerasties":"zooerasty",
"zooflagellates":"zooflagellate",
"zoogloeae":"zoogloea",
"zoogloeas":"zoogloea",
"zoolatries":"zoolatry",
"zoologists":"zoologist",
"zoologies":"zoology",
"zoomed":"zoom",
"zooming":"zoom",
"zooms":"zoom",
"zoomastiginas":"zoomastigina",
"zoomastigotes":"zoomastigote",
"zoa":"zoon",
"zoons":"zoon",
"zoonoses":"zoonosis",
"zooplasties":"zooplasty",
"zoosporangia":"zoosporangium",
"zoris":"zori",
"zorils":"zoril",
"zorilles":"zorille",
"zoroasters":"zoroaster",
"zoroastrianisms":"zoroastrianism",
"zosters":"zoster",
"zosteras":"zostera",
"zosteraceaes":"zosteraceae",
"zoviraxes":"zovirax",
"zrs":"zr",
"zus":"zu",
"zubirds":"zubird",
"zucchetti":"zucchetto",
"zucchettos":"zucchetto",
"zucchinis":"zucchini",
"zulus":"zulu",
"zwiebacks":"zwieback",
"zygapophyses":"zygapophysis",
"zygnemas":"zygnema",
"zygnemaleses":"zygnemales",
"zygnemataceaes":"zygnemataceae",
"zygnemataleses":"zygnematales",
"zygocactuses":"zygocactus",
"zygomas":"zygoma",
"zygomata":"zygoma",
"zygomyceteses":"zygomycetes",
"zygomycotas":"zygomycota",
"zygomycotinas":"zygomycotina",
"zygophyllaceaes":"zygophyllaceae",
"zygophyllums":"zygophyllum",
"zygopteras":"zygoptera",
"zygotes":"zygote",
"zyloprims":"zyloprim",
"zymolyses":"zymolysis",
"zymoses":"zymosis",
"zyrians":"zyrian",
"n't":"not",
"'ve":"have",
"deputising":"deputise",
"hillwalkers":"hillwalker",
"roommates":"roommate",
"bevviying":"bevvy",
"recognising":"recognise",
"libertarians":"libertarian",
"costed":"cost",
"privatisations":"privatisation",
"lives":"live",
"shelves":"shelve",
"calves":"calve",
"halves":"halve",
"organized":"organize",
"bloggers":"blogger",
"click-throughs":"click-through",
"stabbings":"stabbing",
"minuter":"minute",
"minutest":"minute",
"'s":"be",
"'d":"had",
"'ll":"will",
"'d":"would",
"conflations":"conflation",
"contemplatives":"contemplative",
"immortalising":"immortalise",
"fictionalises":"fictionalise",
"enculturates":"enculturate",
"immortalised":"immortalise",
"immortalises":"immortalise",
"pharaohs":"pharaoh",
"politics":"politic",
"fictionalised":"fictionalise",
"fictionalising":"fictionalise",
"oxygenators":"oxygenator",
"conveyancers":"conveyancer",
"naturalises":"naturalise",
"naturalised":"naturalise",
"naturalising":"naturalise",
"hybridises":"hybridise",
"hybridised":"hybridise",
"hybridising":"hybridise",
"criminalises":"criminalise",
"criminalised":"criminalise",
"criminalising":"criminalise",
"criminalizes":"criminalize",
"criminalized":"criminalize",
"criminalizing":"criminalize",
"spiderwebs":"spiderweb",
"ergonomists":"ergonomist",
"manoeuvrings":"manoeuvring",
"italicizes":"italicize",
"italicises":"italicise",
"italicised":"italicise",
"italicising":"italicise",
"workgroups":"workgroup",
"econometricians":"econometrician",
"commissionaires":"commissionaire",
"lawcourts":"lawcourt",
"strategises":"strategise",
"strategised":"strategise",
"strategising":"strategise",
"strategizes":"strategize",
"strategized":"strategize",
"strategizing":"strategize",
"chatrooms":"chatroom",
"bitching":"bitch",
"bitched":"bitch",
"I":"I",
"blipped":"blip",
"blipping":"blip",
"computerizes":"computerize",
"computerises":"computerise",
"computerised":"computerise",
"computerising":"computerise",
"micromanages":"micromanage",
"micromanaged":"micromanage",
"micromanaging":"micromanage",
"sell-offs":"sell-off",
"co-pilots":"co-pilot",
"roll-calls":"roll-call",
"hyperventilates":"hyperventilate",
"hyperventilating":"hyperventilate",
"hyperventilated":"hyperventilate",
"salaams":"salaam",
"humanists":"humanist",
"trimesters":"trimester",
"second-guesses":"second-guess",
"second-guessers":"second-guesser",
"reorderings":"reordering",
"reorders":"reorder",
"nosedives":"nosedive",
"nosediving":"nosedive",
"nosedived":"nosedive",
"nose-dives":"nose-dive",
"nose-dived":"nose-dive",
"nose-diving":"nose-dive",
"modernises":"modernise",
"modernising":"modernise",
"modernised":"modernise",
"modernisers":"moderniser",
"modernizers":"modernizer",
"separatists":"separatist",
"chain-smokers":"chain-smoker",
"cell-phones":"cell-phone",
"cellphones":"cellphone",
"archaises":"archaise",
"archaised":"archaise",
"archaising":"archaise",
"archaisers":"archaiser",
"archaizes":"archaize",
"archaizers":"archaizer",
"archaists":"archaist",
"wo":"will",
"ca":"can",
"sha":"shall",
"serializes":"serialize",
"serialises":"serialise",
"serialised":"serialise",
"serialising":"serialise",
"Russians":"Russian",
"addicted":"addict",
"realises":"realise",
"landers":"lander",
"realising":"realise",
"Normans":"Norman",
"acclimatises":"acclimatise",
"acclimatised":"acclimatise",
"acclimatising":"acclimatise",
"actioned":"action",
"actioning":"action",
"actualises":"actualise",
"actualised":"actualise",
"actualising":"actualise",
"adulates":"adulate",
"adumbrations":"adumbration",
"adventurists":"adventurist",
"aggrandises":"aggrandise",
"aggrandised":"aggrandise",
"aggrandising":"aggrandise",
"airbrushes":"airbrush",
"alarmists":"alarmist",
"amethysts":"amethyst",
"amortises":"amortise",
"amortised":"amortise",
"amortising":"amortise",
"amortizes":"amortize",
"amortized":"amortize",
"amortizing":"amortize",
"amphipods":"amphipod",
"anaesthetizes":"anaesthetize",
"anaesthetized":"anaesthetize",
"anaesthetizing":"anaesthetize",
"anaesthetises":"anaesthetise",
"anaesthetised":"anaesthetise",
"anaesthetising":"anaesthetise",
"analogizes":"analogize",
"anatomises":"anatomise",
"anatomised":"anatomise",
"anatomising":"anatomise",
"anesthetises":"anesthetise",
"anesthetised":"anesthetise",
"anesthetising":"anesthetise",
"apologises":"apologise",
"apologised":"apologise",
"apologising":"apologise",
"atomises":"atomise",
"atomised":"atomise",
"atomising":"atomise",
"autoclaved":"autoclave",
"autoclaving":"autoclave",
"ballsed":"balls",
"ballsing":"balls",
"belaboured":"belabour",
"belabouring":"belabour",
"bellyflops":"bellyflop",
"bellyflopped":"bellyflop",
"bellyflopping":"bellyflop",
"benchmarked":"benchmark",
"benchmarking":"benchmark",
"bigs":"big",
"bigged":"big",
"bigging":"big",
"bingeing":"binge",
"binged":"binge",
"biodegrades":"biodegrade",
"bipeds":"biped",
"bisons":"bison",
"blabbers":"blabber",
"blabbered":"blabber",
"blabbering":"blabber",
"bloviates":"bloviate",
"bloviated":"bloviate",
"bloviating":"bloviate",
"blunts":"blunt",
"bodges":"bodge",
"bodged":"bodge",
"bodging":"bodge",
"bookmarked":"bookmark",
"bookmarking":"bookmark",
"bootlaces":"bootlace",
"bopped":"bop",
"bopping":"bop",
"boppers":"bopper",
"botch-ups":"botch-up",
"bottlefeeds":"bottlefeed",
"bottlefeeding":"bottlefeed",
"bottlefed":"bottlefeed",
"bottlenecked":"bottleneck",
"bottlenecking":"bottleneck",
"bowdlerises":"bowdlerise",
"bowdlerised":"bowdlerise",
"bowdlerising":"bowdlerise",
"brainstormed":"brainstorm",
"brainstorming":"brainstorm",
"brainwashes":"brainwash",
"braises":"braise",
"breastfeeds":"breastfeed",
"breastfeeding":"breastfeed",
"breastfed":"breastfeed",
"breathalyses":"breathalyse",
"breathalysing":"breathalyse",
"breathalysed":"breathalyse",
"breathalyzes":"breathalyze",
"breathalyzing":"breathalyze",
"breathalyzed":"breathalyze",
"broadsided":"broadside",
"broadsiding":"broadside",
"brutalises":"brutalise",
"brutalised":"brutalise",
"brutalising":"brutalise",
"cachinnates":"cachinnate",
"calcimines":"calcimine",
"calcines":"calcine",
"calenders":"calender",
"canalises":"canalise",
"canalised":"canalise",
"canalising":"canalise",
"cannibalised":"cannibalise",
"cannibalising":"cannibalise",
"canonises":"canonise",
"canonised":"canonise",
"canonising":"canonise",
"capitalises":"capitalise",
"capitalised":"capitalise",
"capitalising":"capitalise",
"caramelises":"caramelise",
"caramelised":"caramelise",
"caramelising":"caramelise",
"caramelizes":"caramelize",
"caramelized":"caramelize",
"caramelizing":"caramelize",
"carbonises":"carbonise",
"carbonised":"carbonise",
"carbonising":"carbonise",
"carjacks":"carjack",
"carjacking":"carjack",
"carjacked":"carjack",
"carjackers":"carjacker",
"carnalises":"carnalise",
"carnalised":"carnalise",
"carnalising":"carnalise",
"carnalizes":"carnalize",
"carnalized":"carnalize",
"carnalizing":"carnalize",
"catalysed":"catalyse",
"catalysing":"catalyse",
"catalyzes":"catalyze",
"categorises":"categorise",
"categorised":"categorise",
"categorising":"categorise",
"categorizes":"categorize",
"caterers":"caterer",
"catnapped":"catnap",
"catnapping":"catnap",
"cauterises":"cauterise",
"cauterised":"cauterise",
"cauterising":"cauterise",
"chairmaning":"chairman",
"chairmaned":"chairman",
"characterises":"characterise",
"characterised":"characterise",
"characterising":"characterise",
"charbroils":"charbroil",
"charbroiled":"charbroil",
"charbroiling":"charbroil",
"chuffs":"chuff",
"chuffed":"chuff",
"chuffing":"chuff",
"circumcises":"circumcise",
"civilises":"civilise",
"civilised":"civilise",
"civilising":"civilise",
"classicises":"classicise",
"clangouring":"clangour",
"clangoured":"clangour",
"classicised":"classicise",
"classicising":"classicise",
"classicizes":"classicize",
"co-authors":"co-author",
"co-authored":"co-author",
"co-authoring":"co-author",
"colorizes":"colorize",
"colorized":"colorize",
"colorizing":"colorize",
"commercialises":"commercialise",
"commercialised":"commercialise",
"commercialising":"commercialise",
"compartmentalises":"compartmentalise",
"compartmentalised":"compartmentalise",
"compartmentalising":"compartmentalise",
"composts":"compost",
"conceptualises":"conceptualise",
"conceptualised":"conceptualise",
"conceptualising":"conceptualise",
"containerizes":"containerize",
"containerises":"containerise",
"containerised":"containerise",
"containerising":"containerise",
"diagnoses":"diagnosis",
#"does":"doe",
"metamorphoses":"metamorphosis",
"misdiagnoses":"misdiagnosis",
"misdiagnoses":"misdiagnose",
"shoppers":"shopper",
"being":"be",
"resends":"resend",
"thieves":"thieve",
"thromboses":"thrombose",
"thromboses":"thrombosis",
"trivia":"trivium",
"trousers":"trouser",
"wives":"wive",
"best":"well",
"better":"well",
"hydrolyses":"hydrolysis",
"paralyses":"paralyse",
"interleaves":"interleave",
"Airbuses":"Airbus",
"Alabamans":"Alabaman",
"Albanians":"Albanian",
"Algerians":"Algerian",
"Americanised":"Americanise",
"Americanises":"Americanise",
"Americanising":"Americanise",
"Americanized":"Americanize",
"Americanizes":"Americanize",
"Anabaptists":"Anabaptist",
"Anglicans":"Anglican",
"Angolans":"Angolan",
"Arabists":"Arabist",
"Arcadians":"Arcadian",
"Argentines":"Argentine",
"Argentinians":"Argentinian",
"Asian-Americans":"Asian-American",
"Athenians":"Athenian",
"Austrians":"Austrian",
"B-cells":"B-cell",
"B-movies":"B-movie",
"Babylonians":"Babylonian",
"Bahamians":"Bahamian",
"Bangladeshis":"Bangladeshi",
"Baptists":"Baptist",
"Basques":"Basque",
"Belgians":"Belgian",
"Benedictines":"Benedictine",
"Bengalis":"Bengali",
"Berbers":"Berber",
"Berliners":"Berliner",
"Boeings":"Boeing",
"Bohemians":"Bohemian",
"Bolivians":"Bolivian",
"Bosnians":"Bosnian",
"Bostonians":"Bostonian",
"Brazilians":"Brazilian",
"Buddhists":"Buddhist",
"Budweisers":"Budweiser",
"Bulgarians":"Bulgarian",
"Cadillacs":"Cadillac",
"Cajuns":"Cajun",
"Californians":"Californian",
"Calvinists":"Calvinist",
"Carolinians":"Carolinian",
"Catholics":"Catholic",
"Chevrolets":"Chevrolet",
"Chicagoans":"Chicagoan",
"Chihuahuas":"Chihuahua",
"Christians":"Christian",
"Colombians":"Colombian",
"Congregationalists":"Congregationalist",
"Cossacks":"Cossack",
"Cubans":"Cuban",
"Cuisinarts":"Cuisinart",
"Czechoslovaks":"Czechoslovak",
"Czechs":"Czech",
"D.A.s":"D.A.",
"DVDs":"DVD",
"Danes":"Dane",
"Druids":"Druid",
"Dumpsters":"Dumpster",
"Elizabethans":"Elizabethan",
"Englanders":"Englander",
"Episcopalians":"Episcopalian",
"Ethiopians":"Ethiopian",
"Eurasians":"Eurasian",
"Eurobonds":"Eurobond",
"Eurocrats":"Eurocrat",
"Eurodollars":"Eurodollar",
"Europeans":"European",
"Filofaxes":"Filofax",
"Finns":"Finn",
"Flemings":"Fleming",
"Floridians":"Floridian",
"Francophones":"Francophone",
"Frisbees":"Frisbee",
"Georgians":"Georgian",
"Germans":"German",
"Ghanaians":"Ghanaian",
"HDTVs":"HDTV",
"Haitians":"Haitian",
"Hamiltonians":"Hamiltonian",
"Hondurans":"Honduran",
"IDed":"ID",
"IDing":"ID",
"ISPs":"ISP",
"IUDs":"IUD",
"Icelanders":"Icelander",
"Impressionists":"Impressionist",
"Islamised":"Islamise",
"Islamises":"Islamise",
"Islamising":"Islamise",
"Islamists":"Islamist",
"Islamizes":"Islamize",
"Israelites":"Israelite",
"Italians":"Italian",
"Jacuzzis":"Jacuzzi",
"Jamaicans":"Jamaican",
"Jaycees":"Jaycee",
"Jeffersonians":"Jeffersonian",
"Jesuits":"Jesuit",
"Jordanians":"Jordanian",
"Julys":"July",
"Junes":"June",
"KO'd":"KO",
"KO's":"KO",
"Kalashnikovs":"Kalashnikov",
"Karaites":"Karaite",
"Koreans":"Korean",
"Latin-Americans":"Latin-American",
"Latinised":"Latinise",
"Latinises":"Latinise",
"Latinising":"Latinise",
"Latinized":"Latinize",
"Latinizes":"Latinize",
"Latinizing":"Latinize",
"Luddites":"Luddite",
"MIAs":"MIA",
"Maghs":"Magh",
"Mancunians":"Mancunian",
"Mauritians":"Mauritian",
"NGOs":"NGO",
"Nazified":"nazify",
"Nazifies":"nazify",
"Nazifying":"Nazify",
"Negresses":"Negress",
"Nicaraguans":"Nicaraguan",
"Northeasterners":"Northeasterner",
"OD'd":"OD",
"OD'ing":"OD",
"OD's":"OD",
"Occidentalised":"Occidentalise",
"Occidentalises":"Occidentalise",
"Occidentalising":"Occidentalise",
"Palestinians":"Palestinian",
"Paraguayans":"Paraguayan",
"PhDs":"PhD",
"Pharisees":"Pharisee",
"Rastafarians":"Rastafarian",
"SUVs":"SUV",
"Saxons":"Saxon",
"Scots":"Scot",
"Singaporeans":"Singaporean",
"Sovietologists":"Sovietologist",
"Spaniards":"Spaniard",
"T-cells":"T-cell",
"T-junctions":"T-junction",
"Tibetans":"Tibetan",
"Trotskyists":"Trotskyist",
"Tunisians":"Tunisian",
"Tuscans":"Tuscan",
"Ugandans":"Ugandan",
"VDUs":"VDU",
"Walkmans":"Walkman",
"amici":"amicus",
"automated":"automate",
"blurred":"blur",
"brandied":"brandy",
"brandy-snaps":"brandy-snap",
"braves":"brave",
"bravoed":"bravo",
"bravoing":"bravo",
"buzzsaws":"buzzsaw",
"candelabra":"candelabrum",
"catch-alls":"catch-all",
"catchalls":"catchall",
"catching":"catch",
"centralised":"centralise",
"centralises":"centralise",
"centralising":"centralise",
"centralists":"centralist",
"ceramics":"ceramic",
"chain-stores":"chain-store",
"characterisations":"characterisation",
"charring":"char",
"cheers":"cheer",
"circumnavigations":"circumnavigation",
"cissies":"cissy",
"clairvoyants":"clairvoyant",
"clamoured":"clamour",
"clamouring":"clamouring",
"clapperclawed":"clapperclaw",
"clapperclawing":"clapperclaw",
"clapperclaws":"clapperclaw",
"clawbacks":"clawback",
"cloned":"clone",
"cloning":"clone",
"clunked":"clunk",
"clunkers":"clunker",
"clunking":"clunk",
"co-operatives":"co-operative",
"coastguards":"coastguard",
"coastlines":"coastline",
"coauthored":"coauthor",
"coauthoring":"coauthor",
"collateralizes":"collateralize",
"collectivised":"collectivise",
"collectivises":"collectivise",
"collectivising":"collectivise",
"collocations":"collocation",
"colonised":"colonise",
"colonises":"colonise",
"colonising":"colonise",
"colonizes":"colonize",
"colourized":"colourize",
"colourizes":"colourize",
"colourizing":"colourize",
"combusted":"combust",
"combusting":"combust",
"combusts":"combust",
"committeewomen":"committeewoman",
"communicants":"communicant",
"companionways":"companionway",
"comped":"comp",
"comping":"comp",
"complected":"complect",
"complecting":"complect",
"complects":"complect",
"complexified":"complexify",
"complexifies":"complexify",
"complexifying":"complexify",
"comrades-in-arms":"comrade-in-arms",
"concretised":"concretise",
"concretises":"concretise",
"concretising":"concretise",
"concretizes":"concretize",
"consignees":"consignee",
"constipated":"constipate",
"consultancies":"consultancy",
"continuums":"continuum",
"convectors":"convector",
"convects":"convect",
"conventionalises":"conventionalise",
"conventionalising":"conventionalise",
"convoluted":"convolute",
"cooler":"cool",
"coppiced":"coppice",
"coppicing":"coppice",
"corraled":"corral",
"corraling":"corral",
"costumers":"costumer",
"couchettes":"couchette",
"counter-attacking":"counter-attack",
"counter-attacks":"counter-attack",
"counter-cultures":"counter-culture",
"counterblasts":"counterblast",
"countermarches":"countermarch",
"countermoved":"countermove",
"countermoving":"countermove",
"counterposed":"counterpose",
"counterposes":"counterpose",
"counterposing":"counterpose",
"counterprogrammed":"counterprogram",
"counterprogramming":"counterprogram",
"counterprograms":"counterprogram",
"counterpunched":"counterpunch",
"counterpunchers":"counterpuncher",
"counterpunching":"counterpunch",
"counterstriked":"counterstrike",
"counterstrikes":"counterstrike",
"counterstriking":"counterstrike",
"countertops":"countertop",
"couriered":"courier",
"couriering":"courier",
"cowbells":"cowbell",
"cowgirls":"cowgirl",
"crankshafts":"crankshaft",
"crappier":"crappy",
"crappiest":"crappy",
"crash-dives":"crash-dive",
"crash-landing":"crash-land",
"crash-lands":"crash-land",
"creamerier":"creamery",
"creationists":"creationist",
"cremations":"cremation",
"creoles":"creole",
"creolized":"creolize",
"creolizes":"creolize",
"creolizing":"creolize",
"cricketers":"cricketer",
"crispened":"crispen",
"crispening":"crispen",
"crispens":"crispen",
"criss-crossed":"criss-cross",
"criss-crosses":"criss-cross",
"criss-crossing":"criss-cross",
"cross-checks":"cross-check",
"cross-countries":"cross-country",
"cross-dressed":"cross-dress",
"cross-dresses":"cross-dress",
"cross-dressing":"cross-dress",
"cross-fertilised":"cross-fertilise",
"cross-fertilises":"cross-fertilise",
"cross-fertilising":"cross-fertilise",
"cross-refers":"cross-refer",
"cross-stitches":"cross-stitch",
"crossbred":"crossbreed",
"crosschecked":"crosscheck",
"crosschecking":"crosscheck",
"crosschecks":"crosscheck",
"crosscuting":"crosscut",
"crosshatching":"crosshatch",
"crumbs":"crumb",
"crunchier":"crunchy",
"crunchiest":"crunchy",
"crustaceans":"crustacean",
"crystallised":"crystallise",
"crystallises":"crystallise",
"crystallising":"crystallise",
"cuddlier":"cuddly",
"cuddliest":"cuddly",
"cueing":"cue",
"cultivated":"cultivate",
"cupcakes":"cupcake",
"curlews":"curlew",
"curtain-raisers":"curtain-raiser",
"customised":"customise",
"customises":"customise",
"customising":"customise",
"cyanobacteria":"cyanobacterium",
"cyclostyled":"cyclostyle",
"cyclostyles":"cyclostyle",
"cyclostyling":"cyclostyle",
"damascenes":"damascene",
"damper":"damp",
"danged":"dang",
"danging":"dang",
"dangs":"dang",
"daubers":"dauber",
"de-iced":"de-ice",
"de-ices":"de-ice",
"de-icing":"de-ice",
"deadheaded":"deadhead",
"deadheading":"deadhead",
"deadheads":"deadhead",
"deadlocked":"deadlock",
"dearest":"dear",
"deathlier":"deathly",
"deathliest":"deathly",
"debriefings":"debriefing",
"debunkers":"debunker",
"decentralised":"decentralise",
"decentralises":"decentralise",
"decentralising":"decentralise",
"decerebrated":"decerebrate",
"decerebrates":"decerebrate",
"decerebrating":"decerebrate",
"deck-chairs":"deck-chair",
"deck-hands":"deck-hand",
"decoders":"decoder",
"decolonised":"decolonise",
"decolonises":"decolonise",
"decolonising":"decolonise",
"decolonizes":"decolonize",
"decommissions":"decommission",
"deconsecrated":"deconsecrate",
"deconsecrates":"deconsecrate",
"deconsecrating":"deconsecrate",
"deconstructed":"deconstruct",
"deconstructing":"deconstruct",
"deconstructs":"deconstruct",
"decorticates":"decorticate",
"decriminalised":"decriminalise",
"decriminalises":"decriminalise",
"decriminalising":"decriminalise",
"decriminalized":"decriminalize",
"decriminalizes":"decriminalize",
"decriminalizing":"decriminalize",
"deerstalkers":"deerstalker",
"defervesced":"defervesce",
"defervesces":"defervesce",
"defervescing":"defervesce",
"defogs":"defog",
"defuses":"defuse",
"deglazed":"deglaze",
"deglazes":"deglaze",
"deglazing":"deglaze",
"dehumanised":"dehumanise",
"dehumanises":"dehumanise",
"dehumanising":"dehumanise",
"dehumanizes":"dehumanize",
"dehumanizing":"dehumanize",
"delouses":"delouse",
"demagnetised":"demagnetise",
"demagnetises":"demagnetise",
"demagnetising":"demagnetise",
"demilitarised":"demilitarise",
"demilitarises":"demilitarise",
"demilitarising":"demilitarise",
"demisted":"demist",
"demisters":"demister",
"demisting":"demist",
"demists":"demist",
"demobilised":"demobilise",
"demobilises":"demobilise",
"demobilising":"demobilise",
"democratised":"democratise",
"democratises":"democratise",
"democratising":"democratise",
"democratizes":"democratize",
"demodulates":"demodulate",
"demoed":"demo",
"demoing":"demo",
"demonetised":"demonetise",
"demonetises":"demonetise",
"demonetising":"demonetise",
"demonetizes":"demonetize",
"demonised":"demonise",
"demonises":"demonise",
"demonising":"demonise",
"demonizes":"demonize",
"demoralised":"demoralise",
"demoralises":"demoralise",
"demoralising":"demoralise",
"demotions":"demotion",
"demotivated":"demotivate",
"demotivates":"demotivate",
"demotivating":"demotivate",
"demythologised":"demythologise",
"demythologises":"demythologise",
"demythologising":"demythologise",
"demythologizes":"demythologize",
"denationalised":"denationalise",
"denationalises":"denationalise",
"denationalising":"denationalise",
"denationalizes":"denationalize",
"denaturalises":"denaturalise",
"denaturalising":"denaturalise",
"denaturalizes":"denaturalize",
"denatures":"denature",
"denaturised":"denaturalise",
"denaturized":"denaturalize",
"deodorised":"deodorise",
"deodorises":"deodorise",
"deodorising":"deodorise",
"deodorizes":"deodorize",
"departed":"depart",
"depersonalised":"depersonalise",
"depersonalises":"depersonalise",
"depersonalising":"depersonalise",
"depersonalizes":"depersonalize",
"depilates":"depilate",
"deplanes":"deplane",
"depopulated":"depopulate",
"depraved":"deprave",
"depressed":"depress",
"depressives":"depressive",
"depressurised":"depressurise",
"depressurises":"depressurise",
"depressurising":"depressurise",
"depressurized":"depressurize",
"depressurizes":"depressurize",
"depressurizing":"depressurize",
"deputised":"deputise",
"deputises":"deputise",
"deregulates":"deregulate",
"derides":"deride",
"descaled":"descale",
"descales":"descale",
"descaling":"descale",
"desensitised":"desensitise",
"desensitises":"desensitise",
"desensitising":"desensitise",
"desiccates":"desiccate",
"destabilised":"destabilise",
"destabilises":"destabilise",
"destabilising":"destabilise",
"deterges":"deterge",
"detoxed":"detox",
"detoxes":"detox",
"detoxicationg":"detoxicate",
"detoxing":"detox",
"detrains":"detrain",
"dewatering":"dewater",
"dewaters":"dewater",
"dialysed":"dialyse",
"dialysing":"dialyse",
"dicked":"dick",
"dickier":"dicky",
"dickiest":"dicky",
"dicking":"dick",
"diffracts":"diffract",
"digitalised":"digitalise",
"digitalising":"digitalise",
"digitised":"digitise",
"digitises":"digitise",
"digitising":"digitise",
"dillydallied":"dillydally",
"dillydallies":"dillydally",
"dillydallying":"dillydally",
"dimmer":"dim",
"dinettes":"dinette",
"dining-cars":"dining-car",
"dining-tables":"dining-table",
"dinner-jackets":"dinner-jacket",
"dinner-parties":"dinner-party",
"diphthongised":"diphthongise",
"diphthongises":"diphthongise",
"diphthongising":"diphthongise",
"diphthongizes":"diphthongize",
"dipsticks":"dipstick",
"disavowals":"disavowal",
"discountenances":"discountenance",
"disengaged":"disengage",
"disestablishes":"disestablish",
"disgruntled":"disgruntle",
"disgruntles":"disgruntle",
"dishonoured":"dishonour",
"disinclined":"disincline",
"disinterested":"disinterest",
"disinvested":"disinvest",
"disinvesting":"disinvest",
"disinvests":"disinvest",
"disinvolved":"disinvolve",
"disinvolves":"disinvolve",
"disinvolving":"disinvolve",
"disorganised":"disorganise",
"disorganises":"disorganise",
"disorganising":"disorganise",
"disorientated":"disorientate",
"disorientates":"disorientate",
"disorientating":"disorientate",
"dispatch-boxes":"dispatch-box",
"dispatch-riders":"dispatch-rider",
"dispiriting":"dispirit",
"displumed":"displume",
"displumes":"displume",
"displuming":"displume",
"dispreaded":"dispread",
"dispreads":"dispread",
"disproportions":"disproportion",
"disquisitions":"disquisition",
"dissertates":"dissertate",
"disses":"diss",
"dissimilates":"dissimilate",
"dissimulates":"dissimulate",
"distrains":"distrain",
"distributorships":"distributorship",
"disunited":"disunite",
"ditherers":"ditherer",
"divaricates":"divaricate",
"dive-bombed":"dive-bomb",
"dive-bombers":"dive-bomber",
"dive-bombing":"dive-bomb",
"dive-bombs":"dive-bomb",
"diviners":"diviner",
"divots":"divot",
"do-si-doed":"do-si-do",
"do-si-doing":"do-si-do",
"do-si-dos":"do-si-do",
"docents":"docent",
"dog-biscuits":"dog-biscuit",
"dog-collars":"dog-collar",
"dog-legs":"dog-leg",
"dog-paddled":"dog-paddle",
"dog-paddles":"dog-paddle",
"dog-paddling":"dog-paddle",
"dogcarts":"dogcart",
"dogmatised":"dogmatise",
"dogmatises":"dogmatise",
"dogmatising":"dogmatise",
"dollopped":"dollop",
"dollopping":"dollop",
"dollops":"dollop",
"domiciliated":"domiciliate",
"domiciliates":"domiciliate",
"domiciliating":"domiciliate",
"dominoes":"domino",
"doomsters":"doomster",
"doorstepped":"doorstep",
"doorstepping":"doorstep",
"dopeier":"dopey",
"dopeiest":"dopey",
"doss-houses":"doss-house",
"doth":"do",
"double-checked":"double-check",
"double-checking":"double-check",
"double-checks":"double-check",
"double-crosses":"double-cross",
"double-dated":"double-date",
"double-dates":"double-date",
"double-dating":"double-date",
"double-glazed":"double-glaze",
"double-glazes":"double-glaze",
"double-glazing":"double-glaze",
"double-headers":"double-header",
"double-parked":"double-park",
"double-parking":"double-park",
"double-parks":"double-park",
"double-spaced":"double-space",
"double-spaces":"double-space",
"double-spacing":"double-space",
"double-teamed":"double-team",
"double-teaming":"double-team",
"double-teams":"double-team",
"double-tongued":"double-tongue",
"down-and-outers":"down-and-outer",
"down-and-outs":"down-and-out",
"downbeats":"downbeat",
"downloaded":"download",
"downloading":"download",
"downloads":"download",
"downscaled":"downscale",
"downscales":"downscale",
"downscaling":"downscale",
"doyennes":"doyenne",
"draggled":"draggle",
"draggles":"draggle",
"dragsters":"dragster",
"dramatised":"dramatise",
"dramatises":"dramatise",
"dramatising":"dramatise",
"drawing-boards":"drawing-board",
"drawing-pins":"drawing-pin",
"dredgers":"dredger",
"drier":"dry",
"driftnets":"driftnet",
"drip-dries":"drip-dry",
"drive-bys":"drive-by",
"drive-ins":"drive-in",
"driving-licences":"driving-licence",
"driving-tests":"driving-test",
"driving-wheels":"driving-wheel",
"drum-kits":"drum-kit",
"dry-walled":"dry-wall",
"dry-walling":"dry-wall",
"dry-walls":"dry-wall",
"dubbined":"dubbin",
"dubbining":"dubbin",
"dubbins":"dubbin",
"ducats":"ducat",
"duckboards":"duckboard",
"duetted":"duet",
"duetting":"duet",
"duffed":"duff",
"duffing":"duff",
"duffle-coats":"duffle-coat",
"duffs":"duff",
"dulcimers":"dulcimer",
"dust-covers":"dust-cover",
"dust-jackets":"dust-jacket",
"dust-sheets":"dust-sheet",
"dust-ups":"dust-up",
"duty-frees":"duty-free",
"dwelling-houses":"dwelling-house",
"dynamised":"dynamise",
"dynamises":"dynamise",
"dynamising":"dynamise",
"dynamized":"dynamize",
"dynamizes":"dynamize",
"dynamizing":"dynamize",
"dysfunctions":"dysfunction",
"eaglets":"eaglet",
"earliest":"early",
"earlobes":"earlobe",
"earplugs":"earplug",
"earthworks":"earthwork",
"earwigs":"earwig",
"easterners":"easterner",
"eating-houses":"eating-house",
"eating-places":"eating-place",
"ebonised":"ebonise",
"ebonises":"ebonise",
"ebonising":"ebonise",
"ebonizes":"ebonize",
"economised":"economise",
"economises":"economise",
"economising":"economise",
"ecoterrorists":"ecoterrorist",
"ecotourists":"ecotourist",
"editorialised":"editorialise",
"editorialises":"editorialise",
"editorialising":"editorialise",
"editorializes":"editorialize",
"editorships":"editorship",
"effed":"eff",
"effeminised":"effeminise",
"effeminises":"effeminise",
"effeminising":"effeminise",
"effeminized":"effeminize",
"effeminizes":"effeminize",
"effeminizing":"effeminize",
"effing":"eff",
"effleuraged":"effleurage",
"effleurages":"effleurage",
"effleuraging":"effleurage",
"effs":"eff",
"egg-cups":"egg-cup",
"egg-plants":"egg-plant",
"egg-timers":"egg-timer",
"egg-whisks":"egg-whisk",
"eggheads":"egghead",
"egotripped":"egotrip",
"egotripping":"egotrip",
"egotrips":"egotrip",
"egressed":"egress",
"egressing":"egress",
"elasticated":"elasticate",
"elasticates":"elasticate",
"elasticating":"elasticate",
"electioneering":"electioneer",
"electioneers":"electioneer",
"electives":"elective",
"electrified":"electrify",
"electrodes":"electrode",
"electroencephalographs":"electroencephalograph",
"electrolytes":"electrolyte",
"electromagnets":"electromagnet",
"electroplates":"electroplate",
"elegised":"elegise",
"elegises":"elegise",
"elegising":"elegise",
"elegizes":"elegize",
"elementary-schools":"elementary-school",
"eliminators":"eliminator",
"elisions":"elision",
"elixirs":"elixir",
"elocuted":"elocute",
"elocutes":"elocute",
"elocuting":"elocute",
"elocutionists":"elocutionist",
"eluted":"elute",
"elutes":"elute",
"eluting":"elute",
"emaciated":"emaciate",
"emailed":"email",
"emailing":"email",
"embanks":"embank",
"embattled":"embattle",
"embattles":"embattle",
"embosoms":"embosom",
"embrocates":"embrocate",
"embryologists":"embryologist",
"emends":"emend",
"emery-boards":"emery-board",
"emirates":"emirate",
"emoluments":"emolument",
"emotes":"emote",
"empaled":"empale",
"empales":"empale",
"empaling":"empale",
"empathised":"empathise",
"empathises":"empathise",
"empathising":"empathise",
"emphasised":"emphasise",
"emphasises":"emphasise",
"emphasising":"emphasise",
"empiricists":"empiricist",
"emplaces":"emplace",
"enamoured":"enamour",
"enamouring":"enamour",
"enamours":"enamour",
"enchains":"enchain",
"enchanters":"enchanter",
"enclothed":"enclothe",
"enclothes":"enclothe",
"enclothing":"enclothe",
"encrimsons":"encrimson",
"end-products":"end-product",
"end-users":"end-user",
"endgames":"endgame",
"endoscopes":"endoscope",
"energised":"energise",
"energises":"energise",
"energising":"energise",
"enervated":"enervate",
"enervating":"enervate",
"enfants":"enfant",
"enfeoffs":"enfeoff",
"enfilades":"enfilade",
"engilded":"engild",
"engilding":"engild",
"engilds":"engild",
"engorged":"engorge",
"enhancers":"enhancer",
"enlarged":"enlarge",
"enquiring":"enquire",
"enrobes":"enrobe",
"ensiles":"ensile",
"enskies":"ensky",
"ensnarled":"ensnarl",
"ensnarling":"ensnarl",
"ensnarls":"ensnarl",
"enucleates":"enucleate",
"enures":"enure",
"epees":"epee",
"epitomised":"epitomise",
"epitomises":"epitomise",
"epitomising":"epitomise",
"epochs":"epoch",
"equalised":"equalise",
"equalises":"equalise",
"equalising":"equalise",
"equilibria":"equilibrium",
"eroticised":"eroticise",
"eroticises":"eroticise",
"eroticising":"eroticise",
"eroticizes":"eroticize",
"escalades":"escalade",
"escheats":"escheat",
"espadrilles":"espadrille",
"espaliered":"espalier",
"espaliering":"espalier",
"espaliers":"espalier",
"esplanades":"esplanade",
"eternalised":"eternalise",
"eternalises":"eternalise",
"eternalising":"eternalise",
"etherealised":"etherealise",
"etherealises":"etherealise",
"etherealising":"etherealise",
"etherealizes":"etherealize",
"ethnicities":"ethnicity",
"ethnics":"ethnic",
"ethnographers":"ethnographer",
"ethnologists":"ethnologist",
"etiolated":"etiolate",
"etiolates":"etiolate",
"etymologised":"etymologise",
"etymologises":"etymologise",
"etymologising":"etymologise",
"etymologists":"etymologist",
"etymologizes":"etymologize",
"eubacteria":"eubacterium",
"eulogised":"eulogise",
"eulogises":"eulogise",
"eulogising":"eulogise",
"eunuchs":"eunuch",
"euphemised":"euphemise",
"euphemises":"euphemise",
"euphemising":"euphemise",
"euphemizes":"euphemize",
"europeanised":"europeanise",
"europeanises":"europeanise",
"europeanising":"europeanise",
"europeanizes":"europeanize",
"euthanised":"euthanise",
"euthanises":"euthanise",
"euthanising":"euthanise",
"euthanized":"euthanize",
"euthanizes":"euthanize",
"euthanizing":"euthanize",
"evacuees":"evacuee",
"evangelised":"evangelise",
"evangelises":"evangelise",
"evangelising":"evangelise",
"evil-doers":"evil-doer",
"excruciating":"excruciate",
"exenterates":"exenterate",
"exhilarating":"exhilarate",
"existents":"existent",
"exit-visas":"exit-visa",
"expats":"expat",
"expectorants":"expectorant",
"explications":"explication",
"exposited":"exposit",
"expositing":"exposit",
"exposits":"exposit",
"expropriations":"expropriation",
"exserted":"exsert",
"exserts":"exsert",
"exsiccates":"exsiccate",
"extemporised":"extemporise",
"extemporises":"extemporise",
"extemporising":"extemporise",
"exteriorised":"exteriorise",
"exteriorises":"exteriorise",
"exteriorising":"exteriorise",
"externalised":"externalise",
"externalises":"externalise",
"externalising":"externalise",
"externed":"extern",
"externing":"extern",
"extravasates":"extravasate",
"exuberates":"exuberate",
"exuviated":"exuviate",
"exuviates":"exuviate",
"exuviating":"exuviate",
"eyasses":"eyas",
"eye-teeth":"eye-tooth",
"eyeliners":"eyeliner",
"face-offs":"face-off",
"factorised":"factorise",
"factorises":"factorise",
"factorising":"factorise",
"factorized":"factorize",
"factorizes":"factorize",
"factorizing":"factorize",
"factotums":"factotum",
"fade-ins":"fade-in",
"fade-outs":"fade-out",
"fag-ends":"fag-end",
"fairgoers":"fairgoer",
"fairgrounds":"fairground",
"faith-healers":"faith-healer",
"familiarised":"familiarise",
"familiarises":"familiarise",
"familiarising":"familiarise",
"fancifies":"fancify",
"fangirls":"fangirl",
"fantasied":"fantasy",
"fantasised":"fantasise",
"fantasises":"fantasise",
"fantasising":"fantasise",
"fantasists":"fantasist",
"fantasying":"fantasy",
"fantods":"fantod",
"farragos":"farrago",
"fasces":"fascis",
"fast-forwarded":"fast-forward",
"fast-forwarding":"fast-forward",
"fast-forwards":"fast-forward",
"father-figures":"father-figure",
"father-in-laws":"father-in-law",
"fatwas":"fatwa",
"faultlines":"faultline",
"fauns":"faun",
"featherbedded":"featherbed",
"featherbedding":"featherbed",
"fed":"feed",
"federalised":"federalise",
"federalises":"federalise",
"federalising":"federalise",
"federated":"federate",
"feints":"feint",
"fellated":"fellate",
"fellates":"fellate",
"fellating":"fellate",
"fellow-travellers":"fellow-traveller",
"felt-tips":"felt-tip",
"feminised":"feminise",
"feminises":"feminise",
"feminising":"feminise",
"feminizes":"feminize",
"fends":"fend",
"fertilised":"fertilise",
"fertilisers":"fertiliser",
"fertilises":"fertilise",
"fertilising":"fertilise",
"fessed":"fess",
"fessing":"fess",
"festinates":"festinate",
"fetishised":"fetishise",
"fetishises":"fetishise",
"fetishising":"fetishise",
"fetishists":"fetishist",
"fetishizes":"fetishize",
"feudalised":"feudalise",
"feudalises":"feudalise",
"feudalising":"feudalise",
"feudalizes":"feudalize",
"fibrillated":"fibrillate",
"fibrillates":"fibrillate",
"fibrillating":"fibrillate",
"fibroids":"fibroid",
"field-hands":"field-hand",
"field-tests":"field-test",
"fieldworkers":"fieldworker",
"fileted":"filet",
"fileting":"filet",
"filiated":"filiate",
"filiates":"filiate",
"filiating":"filiate",
"filmstrips":"filmstrip",
"filter-tips":"filter-tip",
"finalised":"finalise",
"finalises":"finalise",
"finalising":"finalise",
"finches":"finch",
"fine-tuning":"fine-tune",
"finedrawing":"finedraw",
"finedrawn":"finedraw",
"finedraws":"finedraw",
"finedrew":"finedraw",
"finger-nails":"finger-nail",
"finger-painted":"finger-paint",
"finger-painting":"finger-paint",
"finger-paints":"finger-paint",
"finned":"fin",
"fire-alarms":"fire-alarm",
"fire-drills":"fire-drill",
"fire-engines":"fire-engine",
"fire-escapes":"fire-escape",
"fire-fighters":"fire-fighter",
"fire-raisers":"fire-raiser",
"firebricks":"firebrick",
"firelighters":"firelighter",
"firestorms":"firestorm",
"firing-lines":"firing-line",
"firing-squads":"firing-squad",
"first-floors":"first-floor",
"fish-kettles":"fish-kettle",
"fish-knives":"fish-knife",
"fish-slices":"fish-slice",
"fishbowls":"fishbowl",
"fishhooks":"fishhook",
"fishing-rods":"fishing-rod",
"fishmen":"fishman",
"fishtails":"fishtail",
"fitments":"fitment",
"fitter":"fit",
"fitters":"fitter",
"fixatives":"fixative",
"flabbergasted":"flabbergast",
"flacks":"flack",
"flagellants":"flagellant",
"flagellated":"flagellate",
"flans":"flan",
"flash-bulbs":"flash-bulb",
"flashcards":"flashcard",
"flashpoints":"flashpoint",
"flat-mates":"flat-mate",
"flatbeds":"flatbed",
"flatlets":"flatlet",
"flatmates":"flatmate",
"flea-pits":"flea-pit",
"fleabags":"fleabag",
"fleapits":"fleapit",
"fledged":"fledge",
"fleers":"fleer",
"fleshpots":"fleshpot",
"flick-knives":"flick-knife",
"flight-decks":"flight-deck",
"flight-recorders":"flight-recorder",
"flight-tests":"flight-test",
"flocculates":"flocculate",
"flood-tides":"flood-tide",
"floor-boards":"floor-board",
"florets":"floret",
"flounced":"flounce",
"flower-girls":"flower-girl",
"flunkeies":"flunkey",
"fluoresces":"fluoresce",
"fluoridised":"fluoridise",
"fluoridises":"fluoridise",
"fluoridising":"fluoridise",
"fluorinates":"fluorinate",
"fluorocarbons":"fluorocarbon",
"fly-by-nights":"fly-by-night",
"fly-bys":"fly-by",
"fly-fishes":"fly-fish",
"fly-fishing":"fly-fish",
"fly-halves":"fly-half",
"flyspecks":"flyspeck",
"flyweights":"flyweight",
"flywheels":"flywheel",
"foals":"foal",
"focalised":"focalise",
"focalises":"focalise",
"focalising":"focalise",
"focalizes":"focalize",
"fogeies":"fogey",
"fogys":"fogy",
"foliated":"foliate",
"follicles":"follicle",
"fomites":"fomes",
"food-chains":"food-chain",
"foodies":"foodie",
"footplates":"footplate",
"foragers":"forager",
"forecourts":"forecourt",
"foredated":"foredate",
"foredates":"foredate",
"foredating":"foredate",
"foredecks":"foredeck",
"forelegs":"foreleg",
"foreshores":"foreshore",
"formalised":"formalise",
"formalises":"formalise",
"formalising":"formalise",
"formalists":"formalist",
"formals":"formal",
"formicated":"formicate",
"formicates":"formicate",
"formicating":"formicate",
"formularised":"formularise",
"formularises":"formularise",
"formularising":"formularise",
"fornicates":"fornicate",
"fortified":"fortify",
"fortune-cookies":"fortune-cookie",
"fortune-tellers":"fortune-teller",
"forwarders":"forwarder",
"fossilised":"fossilise",
"fossilises":"fossilise",
"fossilising":"fossilise",
"foundation-stones":"foundation-stone",
"fractals":"fractal",
"fractionates":"fractionate",
"fragmentised":"fragmentise",
"fragmentises":"fragmentise",
"fragmentising":"fragmentise",
"franchisors":"franchisor",
"fraternised":"fraternise",
"fraternises":"fraternise",
"fraternising":"fraternise",
"free-associated":"free-associate",
"free-associates":"free-associate",
"free-associating":"free-associate",
"free-marketeers":"free-marketeer",
"free-thinkers":"free-thinker",
"freebased":"freebase",
"freebases":"freebase",
"freebasing":"freebase",
"freelanced":"freelance",
"freelancing":"freelance",
"freeloaded":"freeload",
"freeloading":"freeload",
"freeloads":"freeload",
"frescoed":"fresco",
"frescoing":"fresco",
"frigging":"frig",
"frogmarched":"frogmarch",
"frogmarches":"frogmarch",
"frogmarching":"frogmarch",
"front-lines":"front-line",
"front-loaded":"front-load",
"front-loading":"front-load",
"front-loads":"front-load",
"frontispieces":"frontispiece",
"fruiterers":"fruiterer",
"fry-ups":"fry-up",
"frying-pans":"frying-pan",
"ftped":"ftp",
"ftping":"ftp",
"fuckers":"fucker",
"fulgurates":"fulgurate",
"fulgurating":"fulgurate",
"fullbacks":"fullback",
"functionalists":"functionalist",
"fund-raised":"fund-raise",
"fund-raises":"fund-raise",
"fund-raising":"fund-raise",
"fundraised":"fundraise",
"fundraises":"fundraise",
"fundraising":"fundraise",
"funneled":"funnel",
"funnelled":"funnel",
"furrier":"furry",
"further":"far",
"fuselages":"fuselage",
"fusiliers":"fusilier",
"fustigates":"fustigate",
"futons":"futon",
"gaggles":"gaggle",
"gaited":"gait",
"gaiting":"gait",
"galleons":"galleon",
"gang-raped":"gang-rape",
"gang-rapes":"gang-rape",
"gang-raping":"gang-rape",
"gangstas":"gangsta",
"gannets":"gannet",
"gargoyles":"gargoyle",
"garotted":"garotte",
"garotting":"garotte",
"garroted":"garrote",
"garroting":"garrote",
"garrotted":"garrotte",
"garrotting":"garrotte",
"gartered":"garter",
"gartering":"garter",
"gas-guzzlers":"gas-guzzler",
"gas-stations":"gas-station",
"gate-crashed":"gate-crash",
"gate-crashes":"gate-crash",
"gate-crashing":"gate-crash",
"gatecrashed":"gatecrash",
"gatecrashes":"gatecrash",
"gatecrashing":"gatecrash",
"gateposts":"gatepost",
"gators":"gator",
"gazetteers":"gazetteer",
"gazillions":"gazillion",
"gazumped":"gazump",
"gazumping":"gazump",
"gazumps":"gazump",
"gear-levers":"gear-lever",
"gear-sticks":"gear-stick",
"gee-gees":"gee-gee",
"geed":"gee",
"geeing":"gee",
"gelatinised":"gelatinise",
"gelatinises":"gelatinise",
"gelatinising":"gelatinise",
"gelatinized":"gelatinize",
"gelatinizes":"gelatinize",
"gelatinizing":"gelatinize",
"geminates":"geminate",
"genealogists":"genealogist",
"generalisations":"generalisation",
"generalised":"generalise",
"generalises":"generalise",
"generalising":"generalise",
"genies":"genie",
"genomes":"genome",
"gentians":"gentian",
"gentrified":"gentrify",
"gentrifies":"gentrify",
"gentrifying":"gentrify",
"ghettoised":"ghettoise",
"ghettoises":"ghettoise",
"ghettoising":"ghettoise",
"ghettoizes":"ghettoize",
"giantesses":"giantess",
"gibbetted":"gibbet",
"gibbetting":"gibbet",
"gift-wraps":"gift-wrap",
"gimbaled":"gimbal",
"gimbaling":"gimbal",
"gimballed":"gimbal",
"gimballing":"gimbal",
"gimbals":"gimbal",
"ginger-ales":"ginger-ale",
"ginger-beers":"ginger-beer",
"ginger-nuts":"ginger-nut",
"girlies":"girlie",
"gits":"git",
"glaciates":"glaciate",
"glaciations":"glaciation",
"glad-hands":"glad-hand",
"glads":"glad",
"glamorised":"glamorise",
"glamorises":"glamorise",
"glamorising":"glamorise",
"glasshousees":"glasshouse",
"glide-bombing":"glide-bomb",
"glide-bombs":"glide-bomb",
"glimmerings":"glimmering",
"glioblastomas":"glioblastoma",
"glioblastomata":"glioblastoma",
"glissades":"glissade",
"glitzier":"glitzy",
"glitziest":"glitzy",
"gloaters":"gloater",
"globalised":"globalise",
"globalises":"globalise",
"globalising":"globalise",
"globe-trots":"globe-trot",
"globe-trotted":"globe-trot",
"globe-trotters":"globe-trotter",
"globe-trotting":"globe-trot",
"globules":"globule",
"glutted":"glut",
"go-karts":"go-kart",
"go-slows":"go-slow",
"goal-lines":"goal-line",
"goalmouths":"goalmouth",
"goalposts":"goalpost",
"goatees":"goatee",
"gobbets":"gobbet",
"goddaughters":"goddaughter",
"godparents":"godparent",
"godsons":"godson",
"gofers":"gofer",
"gold-diggers":"gold-digger",
"gold-plated":"gold-plate",
"gold-plates":"gold-plate",
"gold-plating":"gold-plate",
"gold-rushs":"gold-rush",
"golf-clubs":"golf-club",
"golf-courses":"golf-course",
"goners":"goner",
"goofballs":"goofball",
"goosebumps":"goosebump",
"gorgons":"gorgon",
"gormandised":"gormandise",
"gormandises":"gormandise",
"gormandising":"gormandise",
"goslings":"gosling",
"governorships":"governorship",
"grab-bags":"grab-bag",
"gradates":"gradate",
"grammar-schools":"grammar-school",
"grand-juries":"grand-jury",
"grandaddies":"grandaddy",
"granites":"granite",
"grans":"gran",
"granulated":"granulate",
"grappling-hooks":"grappling-hook",
"grappling-irons":"grappling-iron",
"graunted":"graunt",
"graunting":"graunt",
"graunts":"graunt",
"gravediggers":"gravedigger",
"graver":"grave",
"graving":"grave",
"grebes":"grebe",
"greenhouse-gases":"greenhouse-gas",
"greenrooms":"greenroom",
"griddles":"griddle",
"grieved":"grieve",
"grifters":"grifter",
"grill-rooms":"grill-room",
"groaked":"groak",
"groakers":"groaker",
"groaking":"groak",
"groaks":"groak",
"grocers":"grocer",
"grokked":"grok",
"grokking":"grok",
"groks":"grok",
"gropings":"groping",
"ground-plans":"ground-plan",
"ground-rents":"ground-rent",
"groupies":"groupie",
"gruntled":"gruntle",
"gruntles":"gruntle",
"gruntling":"gruntle",
"guardrooms":"guardroom",
"guide-dogs":"guide-dog",
"guide-lines":"guide-line",
"guided-missiles":"guided-missile",
"guildhalls":"guildhall",
"gulags":"gulag",
"gum-trees":"gum-tree",
"gumboots":"gumboot",
"gumdrops":"gumdrop",
"gun-carriages":"gun-carriage",
"gun-runners":"gun-runner",
"gunfighters":"gunfighter",
"gunkier":"gunky",
"gunkiest":"gunky",
"gunsmiths":"gunsmith",
"gurneys":"gurney",
"gussies":"gussy",
"guttering":"gutter",
"guttled":"guttle",
"guttles":"guttle",
"guttling":"guttle",
"guvnors":"guvnor",
"gybed":"gybe",
"gybes":"gybe",
"gybing":"gybe",
"habited":"habit",
"habiting":"habit",
"hadjes":"hadj",
"haemorrhaged":"haemorrhage",
"haemorrhaging":"haemorrhage",
"haggises":"haggis",
"haikus":"haiku",
"hailstorms":"hailstorm",
"hair-grips":"hair-grip",
"hair-restorers":"hair-restorer",
"hair-shirts":"hair-shirt",
"hair-slides":"hair-slide",
"hair-stylists":"hair-stylist",
"hair-triggers":"hair-trigger",
"hairbrushes":"hairbrush",
"hairgrips":"hairgrip",
"hairlines":"hairline",
"hairnets":"hairnet",
"hairpins":"hairpin",
"hairstyles":"hairstyle",
"halberds":"halberd",
"half-castes":"half-caste",
"half-inched":"half-inch",
"half-inches":"half-inch",
"half-inching":"half-inch",
"half-measures":"half-measure",
"hamsters":"hamster",
"hand-builded":"hand-build",
"hand-building":"hand-build",
"hand-builds":"hand-build",
"hand-grenades":"hand-grenade",
"hand-guns":"hand-gun",
"hand-me-downs":"hand-me-down",
"hand-picked":"hand-pick",
"hand-picking":"hand-pick",
"hand-picks":"hand-pick",
"hand-tools":"hand-tool",
"handballs":"handball",
"handbrakes":"handbrake",
"handcars":"handcar",
"handclaps":"handclap",
"handhelds":"handheld",
"handholds":"handhold",
"handlooms":"handloom",
"handovers":"handover",
"handpicked":"handpick",
"handsprings":"handspring",
"handwashed":"handwash",
"handwashes":"handwash",
"handwashing":"handwash",
"handwrites":"handwrite",
"handwriting":"handwrite",
"handwritten":"handwrite",
"handwrote":"handwrite",
"hard-currencies":"hard-currency",
"hard-disks":"hard-disk",
"hardheads":"hardhead",
"hared":"hare",
"haring":"hare",
"harlequins":"harlequin",
"harmonics":"harmonic",
"harmonised":"harmonise",
"harmonises":"harmonise",
"harmonising":"harmonise",
"harpsichordists":"harpsichordist",
"harpsichords":"harpsichord",
"harridans":"harridan",
"harrumphing":"harrumph",
"harrumphs":"harrumph",
"harshens":"harshen",
"hassled":"hassle",
"hassling":"hassle",
"hatbands":"hatband",
"hatboxes":"hatbox",
"hatchbacks":"hatchback",
"hatpins":"hatpin",
"haunted":"haunt",
"havers":"haver",
"havocked":"havoc",
"havocking":"havoc",
"hawsers":"hawser",
"hays":"hay",
"hazing":"haze",
"head-dresses":"head-dress",
"head-hunters":"head-hunter",
"head-to-heads":"head-to-head",
"headbands":"headband",
"headboards":"headboard",
"headbutted":"headbutt",
"headbutting":"headbutt",
"headbutts":"headbutt",
"headlocks":"headlock",
"headmistresses":"headmistress",
"headquartered":"headquarter",
"headquartering":"headquarter",
"headquarters":"headquarter",
"headscarves":"headscarf",
"headships":"headship",
"headwinds":"headwind",
"headwords":"headword",
"health-clubs":"health-club",
"health-foods":"health-food",
"hearing-aids":"hearing-aid",
"hearses":"hearse",
"heart-breaks":"heart-break",
"heart-throbs":"heart-throb",
"heart-to-hearts":"heart-to-heart",
"hearted":"heart",
"heartened":"hearten",
"hearting":"heart",
"heartlands":"heartland",
"heartthrobs":"heartthrob",
"hectoring":"hector",
"hedgehopping":"hedgehop",
"hedgers":"hedger",
"heeled":"heel",
"heelers":"heeler",
"heirs-apparent":"heir-apparent",
"hellholes":"hellhole",
"helloes":"hello",
"hemorrhaged":"hemorrhage",
"hemorrhaging":"hemorrhage",
"hen-parties":"hen-party",
"hennaed":"henna",
"hennaing":"henna",
"henpecks":"henpeck",
"herbals":"herbal",
"herbivores":"herbivore",
"herniates":"herniate",
"hero-worshipped":"hero-worship",
"hero-worshipping":"hero-worship",
"heterodyned":"heterodyne",
"heterodynes":"heterodyne",
"heterodyning":"heterodyne",
"hexagons":"hexagon",
"hiding-places":"hiding-place",
"hies":"hie",
"high-fliers":"high-flier",
"high-flyers":"high-flyer",
"high-pressures":"high-pressure",
"highballed":"highball",
"highballing":"highball",
"highballs":"highball",
"highbrows":"highbrow",
"highlighters":"highlighter",
"hightails":"hightail",
"hikers":"hiker",
"hinged":"hinge",
"hipper":"hip",
"hippest":"hip",
"hipsters":"hipster",
"historicised":"historicise",
"historicises":"historicise",
"historicising":"historicise",
"historicized":"historicize",
"historicizes":"historicize",
"historicizing":"historicize",
"hitchhikers":"hitchhiker",
"hitmen":"hitman",
"hobbed":"hob",
"hobbing":"hob",
"hods":"hod",
"hog-tied":"hog-tie",
"hog-ties":"hog-tie",
"hog-tying":"hog-tie",
"hogsheads":"hogshead",
"hoked":"hoke",
"hokes":"hoke",
"hoking":"hoke",
"hold-alls":"hold-all",
"holloaed":"holloa",
"holloaing":"holloa",
"holloed":"hollo",
"holloing":"hollo",
"holocausts":"holocaust",
"holograms":"hologram",
"home-fields":"home-field",
"home-owners":"home-owner",
"home-schooled":"home-school",
"home-schooling":"home-school",
"home-schools":"home-school",
"homeboys":"homeboy",
"homegirls":"homegirl",
"homeies":"homey",
"homepages":"homepage",
"homered":"homer",
"homering":"homer",
"homesteaded":"homestead",
"homesteading":"homestead",
"hometowns":"hometown",
"homogenised":"homogenise",
"homogenises":"homogenise",
"homogenising":"homogenise",
"homogenizes":"homogenize",
"homographs":"homograph",
"homologised":"homologise",
"homologises":"homologise",
"homologising":"homologise",
"homologizes":"homologize",
"hooded":"hood",
"hooped":"hoop",
"hoorays":"hooray",
"hoovered":"hoover",
"hoovering":"hoover",
"hopples":"hopple",
"horizontals":"horizontal",
"hornbills":"hornbill",
"horripilated":"horripilate",
"horripilates":"horripilate",
"horripilating":"horripilate",
"horse-chestnuts":"horse-chestnut",
"horse-traded":"horse-trade",
"horse-trades":"horse-trade",
"horse-trading":"horse-trade",
"horse-whipped":"horse-whip",
"horse-whipping":"horse-whip",
"horse-whips":"horse-whip",
"hospitalised":"hospitalise",
"hospitalises":"hospitalise",
"hospitalising":"hospitalise",
"hospitalizes":"hospitalize",
"hosteled":"hostel",
"hosteling":"hostel",
"hot-dogged":"hot-dog",
"hot-dogging":"hot-dog",
"hot-dogs":"hot-dog",
"hot-rods":"hot-rod",
"hot-wired":"hot-wire",
"hot-wires":"hot-wire",
"hot-wiring":"hot-wire",
"hot-worked":"hot-work",
"hot-working":"hot-work",
"hot-works":"hot-work",
"hotpots":"hotpot",
"hots":"hot",
"hour-hands":"hour-hand",
"house-flies":"house-fly",
"house-martins":"house-martin",
"house-trained":"house-train",
"house-training":"house-train",
"house-trains":"house-train",
"housebreaks":"housebreak",
"househusbands":"househusband",
"housekeeping":"housekeep",
"housekeeps":"housekeep",
"housemasters":"housemaster",
"housemates":"housemate",
"housemistresses":"housemistress",
"houseplants":"houseplant",
"housewarmings":"housewarming",
"hovercrafts":"hovercraft",
"howdahs":"howdah",
"hubcaps":"hubcap",
"humanised":"humanise",
"humanises":"humanise",
"humanising":"humanise",
"humbles":"humble",
"humdingers":"humdinger",
"humified":"humify",
"humifies":"humify",
"humifying":"humify",
"humiliated":"humiliate",
"hummingbirds":"hummingbird",
"hunched":"hunch",
"hunkers":"hunker",
"huntresses":"huntress",
"hussars":"hussar",
"hydrates":"hydrate",
"hydrogen-bombs":"hydrogen-bomb",
"hydrogenates":"hydrogenate",
"hydrolised":"hydrolise",
"hydrolises":"hydrolise",
"hydrolising":"hydrolise",
"hydrolized":"hydrolize",
"hydrolizes":"hydrolize",
"hydrolizing":"hydrolize",
"hydrolysed":"hydrolyse",
"hydrolysing":"hydrolyse",
"hydroplaned":"hydroplane",
"hydroplaning":"hydroplane",
"hygienised":"hygienise",
"hygienises":"hygienise",
"hygienising":"hygienise",
"hygienists":"hygienist",
"hygienized":"hygienize",
"hygienizes":"hygienize",
"hygienizing":"hygienize",
"hyperbolised":"hyperbolise",
"hyperbolises":"hyperbolise",
"hyperbolising":"hyperbolise",
"hyperextended":"hyperextend",
"hyperextending":"hyperextend",
"hyperextends":"hyperextend",
"hyphenated":"hyphenate",
"hypnotised":"hypnotise",
"hypnotises":"hypnotise",
"hypnotising":"hypnotise",
"hypochondriacs":"hypochondriac",
"hypophysectomised":"hypophysectomise",
"hypophysectomises":"hypophysectomise",
"hypophysectomising":"hypophysectomise",
"hypophysectomized":"hypophysectomize",
"hypophysectomizes":"hypophysectomize",
"hypophysectomizing":"hypophysectomize",
"hypostatised":"hypostatise",
"hypostatises":"hypostatise",
"hypostatising":"hypostatise",
"hypostatized":"hypostatize",
"hypostatizes":"hypostatize",
"hypostatizing":"hypostatize",
"hypothesised":"hypothesise",
"hypothesises":"hypothesise",
"hypothesising":"hypothesise",
"hypotheticals":"hypothetical",
"iambics":"iambic",
"ice-breakers":"ice-breaker",
"ice-creams":"ice-cream",
"ice-skated":"ice-skate",
"ice-skaters":"ice-skater",
"ice-skates":"ice-skate",
"ice-skating":"ice-skate",
"idealised":"idealise",
"idealises":"idealise",
"idealising":"idealise",
"idiotypes":"idiotype",
"idler":"idle",
"idles":"idle",
"idolised":"idolise",
"idolises":"idolise",
"idolising":"idolise",
"illegalised":"illegalise",
"illegalises":"illegalise",
"illegalising":"illegalise",
"imbricated":"imbricate",
"imbricates":"imbricate",
"imbricating":"imbricate",
"imbued":"imbue",
"immaterialised":"immaterialise",
"immaterialises":"immaterialise",
"immaterialising":"immaterialise",
"immersed":"immerse",
"immigrates":"immigrate",
"immobilised":"immobilise",
"immobilises":"immobilise",
"immobilising":"immobilise",
"immolates":"immolate",
"immunised":"immunise",
"immunises":"immunise",
"immunising":"immunise",
"impaired":"impair",
"impalements":"impalement",
"impassions":"impassion",
"impends":"impend",
"imperialists":"imperialist",
"imperils":"imperil",
"implied":"imply",
"implosions":"implosion",
"importers":"importer",
"imposing":"impose",
"impregnated":"impregnate",
"imprisoned":"imprison",
"impugns":"impugn",
"in-groups":"in-group",
"in-patients":"in-patient",
"inaugurators":"inaugurator",
"incandesces":"incandesce",
"incantations":"incantation",
"incanted":"incant",
"incanting":"incant",
"incants":"incant",
"incapacitated":"incapacitate",
"incases":"incase",
"incepts":"incept",
"incised":"incise",
"incises":"incise",
"incisors":"incisor",
"inciting":"incite",
"incompletes":"incomplete",
"incrusts":"incrust",
"incurvates":"incurvate",
"indented":"indent",
"indentured":"indenture",
"indexed":"index",
"indicts":"indict",
"individualised":"individualise",
"individualises":"individualise",
"individualising":"individualise",
"individualists":"individualist",
"individuates":"individuate",
"indoctrinates":"indoctrinate",
"indulgenced":"indulgence",
"indulgencing":"indulgence",
"indurates":"indurate",
"industrialised":"industrialise",
"industrialises":"industrialise",
"industrialising":"industrialise",
"infatuated":"infatuate",
"infatuates":"infatuate",
"infected":"infect",
"infiltrators":"infiltrator",
"inflected":"inflect",
"infolds":"infold",
"infomercials":"infomercial",
"informs":"inform",
"ingeminated":"ingeminate",
"ingeminates":"ingeminate",
"ingeminating":"ingeminate",
"ingenues":"ingenue",
"ingratiates":"ingratiate",
"inhaled":"inhale",
"inheres":"inhere",
"inherited":"inherit",
"inhibited":"inhibit",
"inhumes":"inhume",
"initialised":"initialise",
"initialises":"initialise",
"initialising":"initialise",
"initialized":"initialize",
"initializes":"initialize",
"initializing":"initialize",
"injured":"injure",
"inks":"ink",
"inkwells":"inkwell",
"inlaid":"inlay",
"inner-cities":"inner-city",
"innervates":"innervate",
"inosculates":"inosculate",
"insolates":"insolate",
"inspissates":"inspissate",
"instantiated":"instantiate",
"instantiates":"instantiate",
"instantiating":"instantiate",
"instates":"instate",
"insteps":"instep",
"instills":"instill",
"institutionalised":"institutionalise",
"institutionalises":"institutionalise",
"institutionalising":"institutionalise",
"institutionalized":"institutionalize",
"insufflates":"insufflate",
"insulated":"insulate",
"intellectualised":"intellectualise",
"intellectualises":"intellectualise",
"intellectualising":"intellectualise",
"intellectualizes":"intellectualize",
"intenser":"intense",
"intensest":"intense",
"interacts":"interact",
"intercalates":"intercalate",
"interconnecting":"interconnect",
"intercrosses":"intercross",
"interdepended":"interdepend",
"interdepending":"interdepend",
"interdepends":"interdepend",
"interfaced":"interface",
"interfacing":"interface",
"interiorised":"interiorise",
"interiorises":"interiorise",
"interiorising":"interiorise",
"interlineated":"interlineate",
"interlineates":"interlineate",
"interlineating":"interlineate",
"interlines":"interline",
"interlining":"interline",
"interlopes":"interlope",
"intermeshed":"intermesh",
"intermeshes":"intermesh",
"intermeshing":"intermesh",
"intermingled":"intermingle",
"internalised":"internalise",
"internalises":"internalise",
"internalising":"internalise",
"internationalised":"internationalise",
"internationalises":"internationalise",
"internationalising":"internationalise",
"internees":"internee",
"internships":"internship",
"interpellates":"interpellate",
"interpenetrations":"interpenetration",
"interplays":"interplay",
"interrupted":"interrupt",
"intimidated":"intimidate",
"intranets":"intranet",
"introjected":"introject",
"introjecting":"introject",
"introjects":"introject",
"introspects":"introspect",
"intubates":"intubate",
"intuits":"intuit",
"intumesces":"intumesce",
"intussuscepts":"intussuscept",
"inuncted":"inunct",
"inuncting":"inunct",
"inuncts":"inunct",
"investment-bankers":"investment-banker",
"investment-banks":"investment-bank",
"iodinated":"iodinate",
"iodinates":"iodinate",
"iodinating":"iodinate",
"iodised":"iodise",
"iodises":"iodise",
"iodising":"iodise",
"ionised":"ionise",
"ionises":"ionise",
"ionising":"ionise",
"ionizes":"ionize",
"iridesced":"iridesce",
"iridesces":"iridesce",
"iridescing":"iridesce",
"irked":"irk",
"isobars":"isobar",
"isolated":"isolate",
"isomerised":"isomerise",
"isomerises":"isomerise",
"isomerising":"isomerise",
"isomerized":"isomerize",
"isomerizes":"isomerize",
"isomerizing":"isomerize",
"isotherms":"isotherm",
"isotopes":"isotope",
"itemised":"itemise",
"itemises":"itemise",
"itemising":"itemise",
"itinerates":"itinerate",
"jackrabbits":"jackrabbit",
"jackstones":"jackstone",
"jam-packed":"jam-pack",
"jam-packs":"jam-pack",
"jambs":"jamb",
"jampacked":"jampack",
"jampacking":"jampack",
"jampacks":"jampack",
"jasmines":"jasmine",
"jawboned":"jawbone",
"jawboning":"jawbone",
"jawbreakers":"jawbreaker",
"jaywalking":"jaywalk",
"jaywalks":"jaywalk",
"jazzes":"jazz",
"jemmied":"jemmy",
"jemmying":"jemmy",
"jeopardised":"jeopardise",
"jeopardises":"jeopardise",
"jeopardising":"jeopardise",
"jerry-building":"jerry-build",
"jerry-built":"jerry-build",
"jessed":"jess",
"jesses":"jess",
"jessing":"jess",
"jet-engines":"jet-engine",
"jet-setters":"jet-setter",
"jettisons":"jettison",
"jilts":"jilt",
"jinks":"jink",
"jinxed":"jinx",
"jinxing":"jinx",
"jitterbuged":"jitterbug",
"jitterbuging":"jitterbug",
"jobbing":"job",
"joists":"joist",
"joshes":"josh",
"joyrided":"joyride",
"joyriders":"joyrider",
"joyrides":"joyride",
"joyriding":"joyride",
"judging":"judge",
"juiced":"juice",
"jump-starts":"jump-start",
"junkyards":"junkyard",
"jurisconsults":"jurisconsult",
"jury-rigged":"jury-rig",
"jury-rigging":"jury-rig",
"jury-rigs":"jury-rig",
"juxtaposes":"juxtapose",
"kaleidoscopes":"kaleidoscope",
"kayaks":"kayak",
"keens":"keen",
"keratinised":"keratinise",
"keratinises":"keratinise",
"keratinising":"keratinise",
"keratinizes":"keratinize",
"keyboardists":"keyboardist",
"keyholes":"keyhole",
"keystrokes":"keystroke",
"keywords":"keyword",
"kick-started":"kick-start",
"kick-starting":"kick-start",
"kick-starts":"kick-start",
"kickstands":"kickstand",
"kidding":"kid",
"kilted":"kilt",
"kilts":"kilt",
"kingmakers":"kingmaker",
"kitchenettes":"kitchenette",
"kleptomaniacs":"kleptomaniac",
"kludged":"kludge",
"kludges":"kludge",
"kludging":"kludge",
"klutzes":"klutz",
"knackered":"knacker",
"knackering":"knacker",
"knackers":"knacker",
"kneecapped":"kneecap",
"kneecapping":"kneecap",
"knifes":"knife",
"knifing":"knife",
"knifings":"knifing",
"knitters":"knitter",
"knockdowns":"knockdown",
"know-nothings":"know-nothing",
"knuckle-dusters":"knuckle-duster",
"knucklebones":"knucklebone",
"knuckledusters":"knuckleduster",
"kraals":"kraal",
"labialised":"labialise",
"labialises":"labialise",
"labialising":"labialise",
"labradors":"labrador",
"lacerates":"lacerate",
"lackeyed":"lackey",
"lackeying":"lackey",
"lacquers":"lacquer",
"lady-bugs":"lady-bug",
"laicised":"laicise",
"laicises":"laicise",
"laicising":"laicise",
"lairds":"laird",
"lambing":"lamb",
"lames":"lame",
"laminates":"laminate",
"landaus":"landau",
"landfalls":"landfall",
"lapsed":"lapse",
"larged":"large",
"larges":"large",
"larging":"large",
"larned":"larn",
"larning":"larn",
"larns":"larn",
"lateralised":"lateralise",
"lateralises":"lateralise",
"lateralising":"lateralise",
"lateralized":"lateralize",
"lateralizes":"lateralize",
"lateralizing":"lateralize",
"latest":"late",
"latrines":"latrine",
"lattes":"latte",
"latticed":"lattice",
"latticing":"lattice",
"launderettes":"launderette",
"laundromats":"laundromat",
"lavas":"lava",
"lavenders":"lavender",
"lawnmowers":"lawnmower",
"lay-bys":"lay-by",
"lay-ups":"lay-up",
"layettes":"layette",
"laypeople":"layperson",
"leaguers":"leaguer",
"leasebacks":"leaseback",
"leaseholds":"leasehold",
"least":"little",
"leavened":"leaven",
"leches":"lech",
"lectureships":"lectureship",
"legalised":"legalise",
"legalises":"legalise",
"legalising":"legalise",
"legatees":"legatee",
"legitimatised":"legitimatise",
"legitimatises":"legitimatise",
"legitimatising":"legitimatise",
"legitimised":"legitimise",
"legitimises":"legitimise",
"legitimising":"legitimise",
"leitmotifs":"leitmotif",
"lemonades":"lemonade",
"lemurs":"lemur",
"lengthens":"lengthen",
"lenified":"lenify",
"lenifies":"lenify",
"lenifying":"lenify",
"let-downs":"let-down",
"levants":"levant",
"levelling":"level",
"leveraged":"leverage",
"leveraging":"leverage",
"leviathans":"leviathan",
"lexicalised":"lexicalise",
"lexicalises":"lexicalise",
"lexicalising":"lexicalise",
"lexicalized":"lexicalize",
"lexicalizes":"lexicalize",
"lexicalizing":"lexicalize",
"libations":"libation",
"liberalised":"liberalise",
"liberalises":"liberalise",
"liberalising":"liberalise",
"liberalizes":"liberalize",
"liberated":"liberate",
"librated":"librate",
"librates":"librate",
"librating":"librate",
"licenced":"licence",
"licensed":"license",
"licentiates":"licentiate",
"lichened":"lichen",
"lichens":"lichen",
"lied":"lie",
"life-guards":"life-guard",
"life-jackets":"life-jacket",
"life-preservers":"life-preserver",
"life-rafts":"life-raft",
"life-savers":"life-saver",
"lifebelts":"lifebelt",
"lifehacked":"lifehack",
"lifehacking":"lifehack",
"lifehacks":"lifehack",
"lift-attendants":"lift-attendant",
"lift-offs":"lift-off",
"lifting":"lift",
"ligates":"ligate",
"light-bulbs":"light-bulb",
"light-heavyweights":"light-heavyweight",
"lightships":"lightship",
"likelier":"likely",
"likeliest":"likely",
"limestones":"limestone",
"limited-editions":"limited-edition",
"limper":"limp",
"limpest":"limp",
"limpets":"limpet",
"line-drawings":"line-drawing",
"linearised":"linearise",
"linearises":"linearise",
"linearising":"linearise",
"linearized":"linearize",
"linearizes":"linearize",
"linearizing":"linearize",
"lingos":"lingo",
"links":"link",
"linocuts":"linocut",
"lionised":"lionise",
"lionises":"lionise",
"lionising":"lionise",
"lip-glosses":"lip-gloss",
"lip-synched":"lip-synch",
"lip-synching":"lip-synch",
"lip-synchs":"lip-synch",
"lipreading":"lip-read",
"liquid-crystals":"liquid-crystal",
"liquidised":"liquidise",
"liquidisers":"liquidiser",
"liquidises":"liquidise",
"liquidising":"liquidise",
"liquified":"liquify",
"lisente":"sente",
"literalised":"literalise",
"literalises":"literalise",
"literalising":"literalise",
"literalizes":"literalize",
"litter-baskets":"litter-basket",
"litter-bins":"litter-bin",
"lived":"live",
"living-rooms":"living-room",
"livres":"livres",
"loafs":"loaf",
"loan-words":"loan-word",
"lobotomizes":"lobotomize",
"lobster-pots":"lobster-pot",
"lobules":"lobule",
"local-governments":"local-government",
"localised":"localise",
"localises":"localise",
"localising":"localise",
"lochs":"loch",
"lock-keepers":"lock-keeper",
"lock-ups":"lock-up",
"lockets":"locket",
"locknuts":"locknut",
"lockouts":"lockout",
"locksmiths":"locksmith",
"lofted":"loft",
"log-books":"log-book",
"logbooks":"logbook",
"loggers":"logger",
"logjams":"logjam",
"logrolling":"logroll",
"logrolls":"logroll",
"lollops":"lollop",
"longbows":"longbow",
"look-alikes":"look-alike",
"lookalikes":"lookalike",
"loony-bins":"loony-bin",
"looses":"loose",
"loping":"lope",
"loss-leaders":"loss-leader",
"lots":"lot",
"loudens":"louden",
"lounge-suits":"lounge-suit",
"low-brows":"low-brow",
"lowballed":"lowball",
"lowballing":"lowball",
"lowballs":"lowball",
"lower":"low",
"lower-classes":"lower-class",
"lowered":"lower",
"lowering":"lower",
"lucubrates":"lucubrate",
"luges":"luge",
"luggage-racks":"luggage-rack",
"luggage-vans":"luggage-van",
"luggers":"lugger",
"lumber-rooms":"lumber-room",
"luminesces":"luminesce",
"lump-sums":"lump-sum",
"lumpectomies":"lumpectomy",
"lunch-boxes":"lunch-box",
"lunch-times":"lunch-time",
"lunchtimes":"lunchtime",
"lustrates":"lustrate",
"luxates":"luxate",
"lynch-mobs":"lynch-mob",
"lynches":"lynch",
"lynchings":"lynching",
"lyophilised":"lyophilise",
"lyophilises":"lyophilise",
"lyophilising":"lyophilise",
"lyricists":"lyricist",
"lysogenised":"lysogenise",
"lysogenises":"lysogenise",
"lysogenising":"lysogenise",
"lysogenized":"lysogenize",
"lysogenizes":"lysogenize",
"lysogenizing":"lysogenize",
"macadamised":"macadamise",
"macadamises":"macadamise",
"macadamising":"macadamise",
"macaroons":"macaroon",
"macaws":"macaw",
"machinates":"machinate",
"machine-tools":"machine-tool",
"machine-washed":"machine-wash",
"machine-washes":"machine-wash",
"machine-washing":"machine-wash",
"machinegunning":"machine-gun",
"macrocrystals":"macrocrystal",
"maculated":"maculate",
"maculates":"maculate",
"maculating":"maculate",
"madder":"mad",
"made":"make",
"madrigals":"madrigal",
"madstones":"madstone",
"magicked":"magic",
"magicking":"magic",
"magnetic-tapes":"magnetic-tape",
"magnetised":"magnetise",
"magnetises":"magnetise",
"magnetising":"magnetise",
"magnifiers":"magnifier",
"mahouts":"mahout",
"maildrops":"maildrop",
"mailrooms":"mailroom",
"maims":"maim",
"mainlines":"mainline",
"mainmasts":"mainmast",
"mainsails":"mainsail",
"mainsprings":"mainspring",
"mainstreamed":"mainstream",
"mainstreaming":"mainstream",
"mainstreams":"mainstream",
"maisonettes":"maisonette",
"maisonnettes":"maisonnette",
"majorettes":"majorette",
"majoritarians":"majoritarian",
"makeovers":"makeover",
"maketh":"make",
"malcontents":"malcontent",
"maledicted":"maledict",
"maledicting":"maledict",
"maledicts":"maledict",
"mallows":"mallow",
"mammograms":"mammogram",
"mams":"mam",
"man-hours":"man-hour",
"manacled":"manacle",
"manageresses":"manageress",
"mandolins":"mandolin",
"manducated":"manducate",
"manducates":"manducate",
"manducating":"manducate",
"mangled":"mangle",
"manhandles":"manhandle",
"manholes":"manhole",
"manhunts":"manhunt",
"manic-depressives":"manic-depressive",
"manicurists":"manicurist",
"manned":"man",
"mans":"man",
"manservants":"manservant",
"mantras":"mantra",
"map-readers":"map-reader",
"maquiladoras":"maquiladora",
"maquilas":"maquila",
"marbleised":"marbleise",
"marbleises":"marbleise",
"marbleising":"marbleise",
"marbleized":"marbleize",
"marbleizes":"marbleize",
"marbleizing":"marbleize",
"marginalised":"marginalise",
"marginalises":"marginalise",
"marginalising":"marginalise",
"marginalized":"marginalize",
"marginalizes":"marginalize",
"marginalizing":"marginalize",
"mark-ups":"mark-up",
"markdowns":"markdown",
"market-days":"market-day",
"market-places":"market-place",
"market-squares":"market-square",
"marketeers":"marketeer",
"marketers":"marketer",
"marking-inks":"marking-ink",
"markups":"markup",
"marmalades":"marmalade",
"marmosets":"marmoset",
"marooned":"maroon",
"marshmallows":"marshmallow",
"martes":"marten",
"martins":"martin",
"martyred":"martyr",
"martyrised":"martyrise",
"martyrises":"martyrise",
"martyrising":"martyrise",
"martyrized":"martyrize",
"martyrizes":"martyrize",
"martyrizing":"martyrize",
"mascaras":"mascara",
"masculinised":"masculinise",
"masculinises":"masculinise",
"masculinising":"masculinise",
"masculinizes":"masculinize",
"masers":"maser",
"mashed":"mash",
"masochists":"masochist",
"mass-produced":"mass-produce",
"mass-produces":"mass-produce",
"massifs":"massif",
"masterstrokes":"masterstroke",
"masterworks":"masterwork",
"mastheads":"masthead",
"mastiffs":"mastiff",
"mattocks":"mattock",
"matures":"mature",
"maxed":"max",
"maxes":"max",
"maximised":"maximise",
"maximises":"maximise",
"maximising":"maximise",
"maximizes":"maximize",
"maxing":"max",
"maydays":"mayday",
"mayoresses":"mayoress",
"maypoles":"maypole",
"meal-tickets":"meal-ticket",
"mealies":"mealie",
"mealtimes":"mealtime",
"means":"mean",
"meat-packers":"meat-packer",
"meatballs":"meatball",
"meatheads":"meathead",
"meatpackers":"meatpacker",
"meccas":"mecca",
"mechanics":"mechanic",
"mechanised":"mechanise",
"mechanises":"mechanise",
"mechanising":"mechanise",
"mechanists":"mechanist",
"medaled":"medal",
"medaling":"medal",
"medalled":"medal",
"medalling":"medal",
"meddlers":"meddler",
"medevacked":"medevac",
"medevacking":"medevac",
"medevacs":"medevac",
"media":"medium",
"medicated":"medicate",
"medivacked":"medivac",
"medivacking":"medivac",
"medivacs":"medivac",
"meeting-houses":"meeting-house",
"meeting-places":"meeting-place",
"megalomaniacs":"megalomaniac",
"megaphones":"megaphone",
"megatons":"megaton",
"megawatts":"megawatt",
"melanised":"melanise",
"melanises":"melanise",
"melanising":"melanise",
"melanized":"melanize",
"melanizes":"melanize",
"melanizing":"melanize",
"mellows":"mellow",
"melodised":"melodise",
"melodises":"melodise",
"melodising":"melodise",
"melodizes":"melodize",
"meltdowns":"meltdown",
"melting-points":"melting-point",
"melting-pots":"melting-pot",
"memorialised":"memorialise",
"memorialises":"memorialise",
"memorialising":"memorialise",
"memorialists":"memorialist",
"memorised":"memorise",
"memorisers":"memoriser",
"memorises":"memorise",
"memorising":"memorise",
"memorizers":"memorizer",
"memsahibs":"memsahib",
"menorahs":"menorah",
"menschen":"mensch",
"mensurated":"mensurate",
"mensurates":"mensurate",
"mensurating":"mensurate",
"mentored":"mentor",
"mentoring":"mentor",
"mercantilists":"mercantilist",
"mercerised":"mercerise",
"mercerises":"mercerise",
"mercerising":"mercerise",
"mercerized":"mercerize",
"mercerizes":"mercerize",
"mercurialised":"mercurialise",
"mercurialising":"mercurialise",
"mercurialized":"mercurialize",
"mercurializes":"mercurialize",
"mercurializing":"mercurialize",
"merest":"mere",
"meringues":"meringue",
"mesmerised":"mesmerise",
"mesmerises":"mesmerise",
"mesmerising":"mesmerise",
"mesmerized":"mesmerize",
"messaged":"message",
"messaging":"message",
"messengered":"messenger",
"messengering":"messenger",
"metabolised":"metabolise",
"metabolises":"metabolise",
"metabolising":"metabolise",
"metabolizes":"metabolize",
"metagrabolised":"metagrabolise",
"metagrabolises":"metagrabolise",
"metagrabolising":"metagrabolise",
"metagrabolized":"metagrabolize",
"metagrabolizes":"metagrabolize",
"metagrabolizing":"metagrabolize",
"metagrobolised":"metagrobolise",
"metagrobolises":"metagrobolise",
"metagrobolising":"metagrobolise",
"metagrobolizes":"metagrobolize",
"metagrobolizing":"metagrobolize",
"metalanguages":"metalanguage",
"metaled":"metal",
"metalizes":"metalize",
"metalled":"metal",
"metallised":"metallise",
"metallises":"metallise",
"metallising":"metallise",
"metallized":"metallize",
"metallizes":"metallize",
"metallizing":"metallize",
"metalsmiths":"metalsmith",
"metaphorized":"metaphorize",
"metaphorizes":"metaphorize",
"metaphorizing":"metaphorize",
"metaphors":"metaphor",
"metastasised":"metastasise",
"metastasises":"metastasise",
"metastasising":"metastasise",
"metastasizes":"metastasize",
"meteorologists":"meteorologist",
"metes":"mete",
"methodists":"methodist",
"methylates":"methylate",
"metricates":"metricate",
"metronomes":"metronome",
"mezzotints":"mezzotint",
"miaowed":"miaow",
"miaowing":"miaow",
"micro-organisms":"micro-organism",
"microbiologists":"microbiologist",
"microbreweries":"microbrewery",
"microcosms":"microcosm",
"microdots":"microdot",
"microfilms":"microfilm",
"microfossils":"microfossil",
"micrometeorites":"micrometeorite",
"microorganisms":"microorganism",
"microprocessors":"microprocessor",
"micros":"micro",
"microscopists":"microscopist",
"microseconds":"microsecond",
"microspheres":"microsphere",
"microwaved":"microwave",
"microwaving":"microwave",
"middleweights":"middleweight",
"midfielders":"midfielder",
"midges":"midge",
"midwifed":"midwife",
"midwifes":"midwife",
"midwifing":"midwife",
"midwived":"midwife",
"midwiving":"midwife",
"miffed":"miff",
"migrants":"migrant",
"migrates":"migrate",
"mildewed":"mildew",
"milers":"miler",
"militarised":"militarise",
"militarises":"militarise",
"militarising":"militarise",
"militarized":"militarize",
"militarizes":"militarize",
"militates":"militate",
"milk-loaves":"milk-loaf",
"milk-teeth":"milk-tooth",
"millboards":"millboard",
"milldams":"milldam",
"millionairesses":"millionairess",
"millisieverts":"millisievert",
"millponds":"millpond",
"millwheels":"millwheel",
"milted":"milt",
"milting":"milt",
"minarets":"minaret",
"mind-readers":"mind-reader",
"mindsets":"mindset",
"minefields":"minefield",
"mineralised":"mineralise",
"mineralises":"mineralise",
"mineralising":"mineralise",
"mineralized":"mineralize",
"mineralizes":"mineralize",
"mineralogists":"mineralogist",
"mineshafts":"mineshaft",
"minesweepers":"minesweeper",
"miniaturised":"miniaturise",
"miniaturises":"miniaturise",
"miniaturising":"miniaturise",
"miniaturists":"miniaturist",
"miniaturized":"miniaturize",
"minibuses":"minibus",
"minicabs":"minicab",
"minicars":"minicar",
"minicomputers":"minicomputer",
"minimalists":"minimalist",
"minimi":"minimus",
"minimills":"minimill",
"minimised":"minimise",
"minimises":"minimise",
"minimising":"minimise",
"minivans":"minivan",
"minuets":"minuet",
"minuscules":"minuscule",
"minute-books":"minute-book",
"minute-guns":"minute-gun",
"minute-hands":"minute-hand",
"minute-men":"minute-man",
"mirages":"mirage",
"mirrored":"mirror",
"misaddressed":"misaddress",
"misaddresses":"misaddress",
"misaddressing":"misaddress",
"misadjusted":"misadjust",
"misadjusting":"misadjust",
"misadjusts":"misadjust",
"misadvised":"misadvise",
"misadvises":"misadvise",
"misadvising":"misadvise",
"misaimed":"misaim",
"misaiming":"misaim",
"misaims":"misaim",
"misaligned":"misalign",
"misaligning":"misalign",
"misaligns":"misalign",
"misalliances":"misalliance",
"misallies":"misally",
"misallocated":"misallocate",
"misallocates":"misallocate",
"misallocating":"misallocate",
"misanalyses":"misanalysis",
"misanthropes":"misanthrope",
"misanthropists":"misanthropist",
"misapplied":"misapply",
"misappraisals":"misappraisal",
"misappropriates":"misappropriate",
"misassumptions":"misassumption",
"misattributed":"misattribute",
"misattributes":"misattribute",
"misattributing":"misattribute",
"misbelieved":"misbelieve",
"misbelieves":"misbelieve",
"misbelieving":"misbelieve",
"misbinding":"misbind",
"misbinds":"misbind",
"misbound":"misbind",
"misbranded":"misbrand",
"misbranding":"misbrand",
"misbrands":"misbrand",
"misbuttoned":"misbutton",
"misbuttoning":"misbutton",
"misbuttons":"misbutton",
"miscalculated":"miscalculate",
"miscalculates":"miscalculate",
"miscalculating":"miscalculate",
"miscegenated":"miscegenate",
"miscegenates":"miscegenate",
"miscegenating":"miscegenate",
"mischaracterizations":"mischaracterization",
"mischaracterized":"mischaracterize",
"mischaracterizes":"mischaracterize",
"mischaracterizing":"mischaracterize",
"mischarged":"mischarge",
"mischarges":"mischarge",
"mischarging":"mischarge",
"mischoices":"mischoice",
"miscitations":"miscitation",
"misclassifications":"misclassification",
"misclassified":"misclassify",
"misclassifies":"misclassify",
"misclassifying":"misclassify",
"miscomprehensions":"miscomprehension",
"miscomputations":"miscomputation",
"miscomputed":"miscompute",
"miscomputes":"miscompute",
"miscomputing":"miscompute",
"misconceived":"misconceive",
"misconceivers":"misconceiver",
"misconnected":"misconnect",
"misconnecting":"misconnect",
"misconnections":"misconnection",
"misconnects":"misconnect",
"miscopied":"miscopy",
"miscopies":"miscopy",
"miscopying":"miscopy",
"miscorrelations":"miscorrelation",
"miscounts":"miscount",
"miscreates":"miscreate",
"miscueing":"miscue",
"miscuts":"miscut",
"miscutting":"miscut",
"misdated":"misdate",
"misdates":"misdate",
"misdating":"misdate",
"misdeemed":"misdeem",
"misdeeming":"misdeem",
"misdeems":"misdeem",
"misdefined":"misdefine",
"misdefines":"misdefine",
"misdefining":"misdefine",
"misdelivered":"misdeliver",
"misdelivering":"misdeliver",
"misdelivers":"misdeliver",
"misdemeaned":"misdemean",
"misdemeaning":"misdemean",
"misdemeans":"misdemean",
"misdescribed":"misdescribe",
"misdescribes":"misdescribe",
"misdescribing":"misdescribe",
"misdescriptions":"misdescription",
"misdiagnosed":"misdiagnose",
"misdiagnosing":"misdiagnose",
"misdialed":"misdial",
"misdialing":"misdial",
"misdialled":"misdial",
"misdialling":"misdial",
"misdials":"misdial",
"misdirected":"misdirect",
"misdistributions":"misdistribution",
"misdivisions":"misdivision",
"misdoes":"misdo",
"misdrawing":"misdraw",
"misdrawn":"misdraw",
"misdraws":"misdraw",
"misdrew":"misdraw",
"miseducated":"miseducate",
"miseducates":"miseducate",
"miseducating":"miseducate",
"misemphases":"misemphasis",
"misemploys":"misemploy",
"misestimated":"misestimate",
"misestimates":"misestimate",
"misestimating":"misestimate",
"misevaluated":"misevaluate",
"misevaluates":"misevaluate",
"misevaluating":"misevaluate",
"misfed":"misfeed",
"misfeeding":"misfeed",
"misfeeds":"misfeed",
"misfielded":"misfield",
"misfielding":"misfield",
"misfields":"misfield",
"misfocused":"misfocus",
"misfocuses":"misfocus",
"misfocusing":"misfocus",
"misfocussed":"misfocus",
"misfocusses":"misfocus",
"misfocussing":"misfocus",
"misfunctioned":"misfunction",
"misfunctioning":"misfunction",
"misfunctions":"misfunction",
"misgauged":"misgauge",
"misgauges":"misgauge",
"misgauging":"misgauge",
"misgiving":"misgive",
"misgoverned":"misgovern",
"misgoverning":"misgovern",
"misgoverns":"misgovern",
"misgraded":"misgrade",
"misgrades":"misgrade",
"misgrading":"misgrade",
"misguided":"misguide",
"mishandling":"mishandle",
"misidentifications":"misidentification",
"misidentified":"misidentify",
"misidentifies":"misidentify",
"misidentifying":"misidentify",
"misimpressions":"misimpression",
"misjudgements":"misjudgement",
"misjudges":"misjudge",
"misjudgments":"misjudgment",
"miskicked":"miskick",
"miskicking":"miskick",
"miskicks":"miskick",
"mislabeled":"mislabel",
"mislabeling":"mislabel",
"mislabelled":"mislabel",
"mislabelling":"mislabel",
"mislabels":"mislabel",
"mislearned":"mislearn",
"mislearning":"mislearn",
"mislearns":"mislearn",
"mislearnt":"mislearn",
"mislocated":"mislocate",
"mislocates":"mislocate",
"mislocating":"mislocate",
"mislocations":"mislocation",
"mismarked":"mismark",
"mismarking":"mismark",
"mismarks":"mismark",
"mismarried":"mismarry",
"mismarries":"mismarry",
"mismarrying":"mismarry",
"mismatched":"mismatch",
"mismatches":"mismatch",
"mismated":"mismate",
"mismates":"mismate",
"mismating":"mismate",
"mismeasured":"mismeasure",
"mismeasurements":"mismeasurement",
"mismeasures":"mismeasure",
"mismeasuring":"mismeasure",
"misnamed":"misname",
"misnames":"misname",
"misnaming":"misname",
"misnomers":"misnomer",
"misordered":"misorder",
"misordering":"misorder",
"misorders":"misorder",
"misorientations":"misorientation",
"misorients":"misorient",
"misperceived":"misperceive",
"misperceives":"misperceive",
"misperceiving":"misperceive",
"misperceptions":"misperception",
"misplaced":"misplace",
"misplanned":"misplan",
"misplanning":"misplan",
"misplans":"misplan",
"mispriced":"misprice",
"misprices":"misprice",
"mispricing":"misprice",
"misprogrammed":"misprogram",
"misprogramming":"misprogram",
"misprograms":"misprogram",
"mispronounces":"mispronounce",
"mispronunciations":"mispronunciation",
"misquotes":"misquote",
"misreadings":"misreading",
"misreckoned":"misreckon",
"misreckoning":"misreckon",
"misreckons":"misreckon",
"misrecollections":"misrecollection",
"misrecorded":"misrecord",
"misrecording":"misrecord",
"misrecords":"misrecord",
"misreferences":"misreference",
"misregistrations":"misregistration",
"misrelated":"misrelate",
"misrelates":"misrelate",
"misrelating":"misrelate",
"misremembers":"misremember",
"misrendered":"misrender",
"misrendering":"misrender",
"misrenders":"misrender",
"misreports":"misreport",
"misrouted":"misroute",
"misroutes":"misroute",
"misrouting":"misroute",
"missals":"missal",
"missets":"misset",
"missetting":"misset",
"misshapes":"misshape",
"missorted":"missort",
"missorting":"missort",
"missorts":"missort",
"misspeaking":"misspeak",
"misspeaks":"misspeak",
"misspellings":"misspelling",
"misspoke":"misspeak",
"misspoken":"misspeak",
"misstatements":"misstatement",
"misstates":"misstate",
"misthrew":"misthrow",
"misthrowing":"misthrow",
"misthrown":"misthrow",
"misthrows":"misthrow",
"mistimed":"mistime",
"mistimes":"mistime",
"mistiming":"mistime",
"mistitled":"mistitle",
"mistitles":"mistitle",
"mistitling":"mistitle",
"mistrained":"mistrain",
"mistraining":"mistrain",
"mistrains":"mistrain",
"mistranscribed":"mistranscribe",
"mistranscribes":"mistranscribe",
"mistranscribing":"mistranscribe",
"mistranslated":"mistranslate",
"mistranslates":"mistranslate",
"mistranslating":"mistranslate",
"mistranslations":"mistranslation",
"mistrials":"mistrial",
"mistruths":"mistruth",
"mistuned":"mistune",
"mistunes":"mistune",
"mistuning":"mistune",
"mistyped":"mistype",
"mistypes":"mistype",
"mistyping":"mistype",
"misunderstanders":"misunderstander",
"miswrites":"miswrite",
"miswriting":"miswrite",
"miswritten":"miswrite",
"miswrote":"miswrite",
"mithridates":"mithridate",
"mitred":"mitre",
"mitring":"mitre",
"mnemonics":"mnemonic",
"mnemonists":"mnemonist",
"mobcaps":"mobcap",
"mobilised":"mobilise",
"mobilises":"mobilise",
"mobilising":"mobilise",
"mock-ups":"mock-up",
"mockups":"mockup",
"modals":"modal",
"modems":"modem",
"moderators":"moderator",
"modernists":"modernist",
"modernizing":"modernize",
"mods":"mod",
"moisturised":"moisturise",
"moisturisers":"moisturiser",
"moisturises":"moisturise",
"moisturising":"moisturise",
"moisturizers":"moisturizer",
"molehills":"molehill",
"molesters":"molester",
"momentoes":"momento",
"momentos":"momento",
"momos":"momo",
"monarchs":"monarch",
"moneies":"money",
"monetarists":"monetarist",
"monetised":"monetise",
"monetises":"monetise",
"monetising":"monetise",
"monetizes":"monetize",
"money-boxes":"money-box",
"money-changers":"money-changer",
"money-grubbers":"money-grubber",
"money-lenders":"money-lender",
"money-makers":"money-maker",
"mongrelised":"mongrelise",
"mongrelises":"mongrelise",
"mongrelising":"mongrelise",
"mongrelizes":"mongrelize",
"monished":"monish",
"monishes":"monish",
"monishing":"monish",
"monkey-nuts":"monkey-nut",
"monogramed":"monogram",
"monograming":"monogram",
"monographs":"monograph",
"monoliths":"monolith",
"monologged":"monolog",
"monologging":"monolog",
"monologs":"monolog",
"monologued":"monologue",
"monologuing":"monologue",
"monologuised":"monologuise",
"monologuises":"monologuise",
"monologuising":"monologuise",
"monologuized":"monologuize",
"monologuizes":"monologuize",
"monologuizing":"monologuize",
"monomaniacs":"monomaniac",
"monomers":"monomer",
"monoplanes":"monoplane",
"monopolised":"monopolise",
"monopolisers":"monopoliser",
"monopolises":"monopolise",
"monopolising":"monopolise",
"monopolizes":"monopolize",
"monorails":"monorail",
"monotheists":"monotheist",
"monsieurs":"monsieur",
"monsoons":"monsoon",
"monumentalised":"monumentalise",
"monumentalises":"monumentalise",
"monumentalising":"monumentalise",
"monumentalizes":"monumentalize",
"mooncakes":"mooncake",
"moonlighters":"moonlighter",
"moonshined":"moonshine",
"moonshining":"moonshine",
"moonstones":"moonstone",
"moonwalked":"moonwalk",
"moonwalking":"moonwalk",
"moonwalks":"moonwalk",
"mooted":"moot",
"mooting":"moot",
"moots":"moot",
"mopeds":"moped",
"moppets":"moppet",
"moraines":"moraine",
"moralised":"moralise",
"moralises":"moralise",
"moralising":"moralise",
"moralizers":"moralizer",
"mornings":"morning",
"morphed":"morph",
"morphemes":"morpheme",
"morphing":"morph",
"morphs":"morph",
"mortarboards":"mortarboard",
"mortgagees":"mortgagee",
"mortgagers":"mortgager",
"mortgagors":"mortgagor",
"mortified":"mortify",
"moshed":"mosh",
"moshes":"mosh",
"moshing":"mosh",
"motets":"motet",
"mothering":"mother",
"mothproofs":"mothproof",
"motivated":"motivate",
"motivators":"motivator",
"motorcades":"motorcade",
"motorcycling":"motorcycle",
"motorised":"motorise",
"motorises":"motorise",
"motorising":"motorise",
"motorized":"motorize",
"mots":"mot",
"mottled":"mottle",
"moulded":"mould",
"mouldered":"moulder",
"mouldering":"moulder",
"moulders":"moulder",
"moulding":"mould",
"mountainsides":"mountainside",
"mountaintops":"mountaintop",
"mounters":"mounter",
"mourns":"mourn",
"mousers":"mouser",
"mouses":"mouse",
"moussakas":"moussaka",
"mouthed":"mouth",
"movie-goers":"movie-goer",
"moviemakers":"moviemaker",
"mowing":"mow",
"muck-rakers":"muck-raker",
"muckrakes":"muckrake",
"muckraking":"muckrake",
"mud-flats":"mud-flat",
"mud-wrestled":"mud-wrestle",
"mud-wrestles":"mud-wrestle",
"mud-wrestling":"mud-wrestle",
"mudded":"mud",
"mudding":"mud",
"mudslides":"mudslide",
"muggins":"mugging",
"mugshots":"mugshot",
"mulches":"mulch",
"mulcts":"mulct",
"mullions":"mullion",
"multi-millionaires":"multi-millionaire",
"multiculturalists":"multiculturalist",
"multifamilies":"multifamily",
"multimillionaires":"multimillionaire",
"multimillions":"multimillion",
"multinationals":"multinational",
"multiplexers":"multiplexer",
"multiplexes":"multiplex",
"multivitamins":"multivitamin",
"mummed":"mum",
"mumming":"mum",
"murderees":"murderee",
"murderesses":"murderess",
"muscled":"muscle",
"music-halls":"music-hall",
"music-stands":"music-stand",
"music-stools":"music-stool",
"musicales":"musicale",
"musicologists":"musicologist",
"musketeers":"musketeer",
"muslins":"muslin",
"mussitated":"mussitate",
"mussitates":"mussitate",
"mussitating":"mussitate",
"mustangs":"mustang",
"mutates":"mutate",
"mutilators":"mutilator",
"muzzlings":"muzzling",
"mycobacteria":"mycobacterium",
"mythicised":"mythicise",
"mythicises":"mythicise",
"mythicising":"mythicise",
"mythicizes":"mythicize",
"mythologised":"mythologise",
"mythologises":"mythologise",
"mythologising":"mythologise",
"mythologizes":"mythologize",
"naans":"naan",
"naderites":"naderite",
"naggings":"nagging",
"nailbrushes":"nailbrush",
"nailers":"nailer",
"nailings":"nailing",
"name-dropped":"name-drop",
"name-droppers":"name-dropper",
"name-dropping":"name-drop",
"name-drops":"name-drop",
"name-tapes":"name-tape",
"nameplates":"nameplate",
"napalmed":"napalm",
"napalming":"napalm",
"napalms":"napalm",
"narced":"narc",
"narcotised":"narcotise",
"narcotises":"narcotise",
"narcotising":"narcotise",
"narcotizes":"narcotize",
"naring":"narc",
"narked":"nark",
"narking":"nark",
"nasalised":"nasalise",
"nasalising":"nasalise",
"nation-states":"nation-state",
"nationalised":"nationalise",
"nationalises":"nationalise",
"nationalising":"nationalise",
"nationalizes":"nationalize",
"naturopaths":"naturopath",
"naysayers":"naysayer",
"naysays":"naysay",
"neared":"near",
"nearing":"near",
"nebulised":"nebulise",
"nebulises":"nebulise",
"nebulising":"nebulise",
"nebulizes":"nebulize",
"neckerchiefs":"neckerchief",
"necklets":"necklet",
"necklines":"neckline",
"needs":"need",
"negociants":"negociant",
"negotiated":"negotiate",
"negotiatrices":"negotiatrix",
"neighbouring":"neighbour",
"nellies":"nelly",
"nentsy":"nenets",
"neo-fascists":"neo-fascist",
"nepenthes":"nepenthe",
"nerdier":"nerdy",
"nerdiest":"nerdy",
"nerve-cells":"nerve-cell",
"nest-eggs":"nest-egg",
"nested":"nest",
"netizens":"netizen",
"neurotransmitters":"neurotransmitter",
"neutered":"neuter",
"neutering":"neuter",
"neuters":"neuter",
"neutralised":"neutralise",
"neutralises":"neutralise",
"neutralising":"neutralise",
"neutralists":"neutralist",
"neutrons":"neutron",
"neutrophils":"neutrophil",
"newbies":"newbie",
"news-letters":"news-letter",
"news-readers":"news-reader",
"news-rooms":"news-room",
"news-sheets":"news-sheet",
"news-stands":"news-stand",
"news-vendors":"news-vendor",
"newsbreaks":"newsbreak",
"newscasters":"newscaster",
"newscasts":"newscast",
"newsreaders":"newsreader",
"newsreels":"newsreel",
"newsrooms":"newsroom",
"newsstands":"newsstand",
"newsweeklies":"newsweekly",
"newswires":"newswire",
"newswomen":"newswoman",
"nibbed":"nib",
"nibbing":"nib",
"nickel-and-dimed":"nickel-and-dime",
"nickel-and-diming":"nickel-and-dime",
"nickeled-and-dimed":"nickel-and-dime",
"nickeling-and-diming":"nickel-and-dime",
"nickels-and-dimes":"nickel-and-dime",
"nictated":"nictate",
"nictates":"nictate",
"nictating":"nictate",
"nictations":"nictation",
"nictitations":"nictitation",
"nights":"night",
"nightshades":"nightshade",
"nightshirts":"nightshirt",
"nightspots":"nightspot",
"nigrae":"nigra",
"nimbies":"nimby",
"ninepins":"ninepin",
"ninjas":"ninja",
"nipping":"nip",
"nitpicked":"nitpick",
"nitpickers":"nitpicker",
"nitpicking":"nitpick",
"nitpicks":"nitpick",
"nitrobacteria":"nitrobacterium",
"nitrogenised":"nitrogenise",
"nitrogenises":"nitrogenise",
"nitrogenising":"nitrogenise",
"nitrogenized":"nitrogenize",
"nitrogenizes":"nitrogenize",
"nitrogenizing":"nitrogenize",
"nits":"nit",
"nixed":"nix",
"nixing":"nix",
"no-balled":"no-ball",
"no-balling":"no-ball",
"no-balls":"no-ball",
"no-brainers":"no-brainer",
"no-men":"no-man",
"noctambulations":"noctambulation",
"nocturnes":"nocturne",
"noddles":"noddle",
"nogged":"nog",
"nogging":"nog",
"noggings":"nogging",
"noisemakers":"noisemaker",
"nol-proses":"nol-pros",
"nol-prossed":"nol-pros",
"nol-prossing":"nol-pros",
"nominators":"nominator",
"non-actors":"non-actor",
"non-events":"non-event",
"non-executives":"non-executive",
"non-members":"non-member",
"non-readers":"non-reader",
"non-residents":"non-resident",
"non-smokers":"non-smoker",
"nonagenarians":"nonagenarian",
"noncombatants":"noncombatant",
"noncommunists":"noncommunist",
"nonevents":"nonevent",
"nonmembers":"nonmember",
"nonplused":"nonplus",
"nonplussed":"nonplus",
"nonreactors":"nonreactor",
"nonreaders":"nonreader",
"nonresidents":"nonresident",
"nonstrikers":"nonstriker",
"noodled":"noodle",
"noodling":"noodle",
"normalised":"normalise",
"normalises":"normalise",
"normalising":"normalise",
"nose-cones":"nose-cone",
"nose-dove":"nose-dive",
"noshed":"nosh",
"noshing":"nosh",
"notarised":"notarise",
"notarises":"notarise",
"notarising":"notarise",
"notarized":"notarize",
"notarizes":"notarize",
"notates":"notate",
"noteholders":"noteholder",
"notepads":"notepad",
"notice-boards":"notice-board",
"notitiae":"notitia",
"nouveaux-riches":"nouveau-riche",
"novelised":"novelise",
"novelises":"novelise",
"novelising":"novelise",
"novelizes":"novelize",
"nubbins":"nubbin",
"nucleated":"nucleate",
"nucleates":"nucleate",
"nucleating":"nucleate",
"nucleotides":"nucleotide",
"nudibranchs":"nudibranch",
"nullifiers":"nullifier",
"nulliparas":"nullipara",
"number-crunchers":"number-cruncher",
"numerates":"numerate",
"numerators":"numerator",
"nursers":"nurser",
"nursing-homes":"nursing-home",
"nut-cases":"nut-case",
"nut-houses":"nut-house",
"nutates":"nutate",
"nutmegged":"nutmeg",
"nutmegging":"nutmeg",
"nutrified":"nutrify",
"nutrifies":"nutrify",
"nutrifying":"nutrify",
"nuts":"nut",
"nutters":"nutter",
"nymphets":"nymphet",
"oarswomen":"oarswoman",
"obeys":"obey",
"obfuscates":"obfuscate",
"obligated":"obligate",
"obliged":"oblige",
"obligers":"obliger",
"obnubilated":"obnubilate",
"obnubilates":"obnubilate",
"obnubilating":"obnubilate",
"oboists":"oboist",
"obscurantists":"obscurantist",
"obscures":"obscure",
"obsessives":"obsessive",
"obsoletes":"obsolete",
"obstipated":"obstipate",
"obstipates":"obstipate",
"obstipating":"obstipate",
"obstructers":"obstructer",
"obtrusions":"obtrusion",
"obtunds":"obtund",
"obturates":"obturate",
"obturators":"obturator",
"occultists":"occultist",
"oceanographers":"oceanographer",
"octagons":"octagon",
"oculi":"oculus",
"odorised":"odorise",
"odorises":"odorise",
"odorising":"odorise",
"odorized":"odorize",
"odorizes":"odorize",
"odorizing":"odorize",
"odourised":"odourise",
"odourises":"odourise",
"odourising":"odourise",
"off-days":"off-day",
"offed":"off",
"office-blocks":"office-block",
"officialised":"officialise",
"officialises":"officialise",
"officialising":"officialise",
"officialized":"officialize",
"officializes":"officialize",
"officializing":"officialize",
"offing":"off",
"offloaded":"offload",
"offloading":"offload",
"offloads":"offload",
"offs":"off",
"offsaddled":"offsaddle",
"offsaddles":"offsaddle",
"offsaddling":"offsaddle",
"oglers":"ogler",
"ogles":"ogle",
"ogresses":"ogress",
"ohmmeters":"ohmmeter",
"oil-colours":"oil-colour",
"oil-paintings":"oil-painting",
"oil-paints":"oil-paint",
"oil-palms":"oil-palm",
"oil-tankers":"oil-tanker",
"oilcloths":"oilcloth",
"oilfields":"oilfield",
"oilseeds":"oilseed",
"old-boys":"old-boy",
"old-women":"old-woman",
"older":"old",
"oldies":"oldie",
"oligarchs":"oligarch",
"oligosaccharides":"oligosaccharide",
"omnivores":"omnivore",
"on-ramps":"on-ramp",
"oncologists":"oncologist",
"one-acters":"one-acter",
"one-liners":"one-liner",
"one-offs":"one-off",
"one-pieces":"one-piece",
"one-steps":"one-step",
"one-twos":"one-two",
"oohed":"ooh",
"oohing":"ooh",
"oohs":"ooh",
"opacifies":"opacify",
"opalesced":"opalesce",
"opalesces":"opalesce",
"opalescing":"opalesce",
"opalised":"opalise",
"opalises":"opalise",
"opalising":"opalise",
"opalized":"opalize",
"opalizes":"opalize",
"opalizing":"opalize",
"opera-houses":"opera-house",
"operagoers":"operagoer",
"operands":"operand",
"operating-rooms":"operating-room",
"operating-tables":"operating-table",
"operating-theatres":"operating-theatre",
"operatingrooms":"operatingroom",
"opiates":"opiate",
"ops":"op",
"opsonised":"opsonise",
"opsonises":"opsonise",
"opsonising":"opsonise",
"optimised":"optimise",
"optimises":"optimise",
"optimising":"optimise",
"optimists":"optimist",
"optimizes":"optimize",
"optioned":"option",
"optioning":"option",
"opts":"opt",
"opuscules":"opuscule",
"orang-utangs":"orang-utang",
"orang-utans":"orang-utan",
"orangeades":"orangeade",
"orates":"orate",
"orbitals":"orbital",
"orchardists":"orchardist",
"orchestrations":"orchestration",
"orchestrators":"orchestrator",
"orcs":"orc",
"order-books":"order-book",
"order-forms":"order-form",
"order-papers":"order-paper",
"ordinands":"ordinand",
"ordinated":"ordinate",
"ordinates":"ordinate",
"ordinating":"ordinate",
"organ-grinders":"organ-grinder",
"organised":"organise",
"organisers":"organiser",
"organises":"organise",
"organising":"organise",
"organized":"organize",
"organizing":"organize",
"organophosphates":"organophosphate",
"orientalised":"orientalise",
"orientalises":"orientalise",
"orientalising":"orientalise",
"orientalists":"orientalist",
"orientalizes":"orientalize",
"oriented":"orient",
"ornamented":"ornament",
"orthodontists":"orthodontist",
"orthoepists":"orthoepist",
"orthopaedists":"orthopaedist",
"orthopedists":"orthopedist",
"oscillators":"oscillator",
"oscillograms":"oscillogram",
"oscillographs":"oscillograph",
"ostensoria":"ostensorium",
"ostensories":"ostensory",
"ostentated":"ostentate",
"ostentates":"ostentate",
"ostentating":"ostentate",
"ostinati":"ostinato",
"ostinatos":"ostinato",
"ostracised":"ostracise",
"ostracises":"ostracise",
"ostracising":"ostracise",
"ostracizes":"ostracize",
"oubliettes":"oubliette",
"ousting":"oust",
"out-Herodded":"out-Herod",
"out-Herodding":"out-Herod",
"out-Herods":"out-Herod",
"outages":"outage",
"outboards":"outboard",
"outbraves":"outbrave",
"outbreeding":"outbreed",
"outbuildings":"outbuilding",
"outcalls":"outcall",
"outcasted":"outcaste",
"outcastes":"outcaste",
"outcasting":"outcaste",
"outclasses":"outclass",
"outcompeted":"outcompete",
"outcompetes":"outcompete",
"outcompeting":"outcompete",
"outcropping":"outcrop",
"outdated":"outdate",
"outdates":"outdate",
"outdraws":"outdraw",
"outfalls":"outfall",
"outfielders":"outfielder",
"outfighting":"outfight",
"outfights":"outfight",
"outfitters":"outfitter",
"outflies":"outfly",
"outfought":"outfight",
"outgained":"outgain",
"outgaining":"outgain",
"outgains":"outgain",
"outgunned":"outgun",
"outgunning":"outgun",
"outguns":"outgun",
"outlawed":"outlaw",
"outleaps":"outleap",
"outliers":"outlier",
"outmanoeuvred":"outmanoeuvre",
"outmanoeuvres":"outmanoeuvre",
"outmanoeuvring":"outmanoeuvre",
"outmarches":"outmarch",
"outmodes":"outmode",
"outnumbers":"outnumber",
"outpaces":"outpace",
"outpatients":"outpatient",
"outperforms":"outperform",
"outplacements":"outplacement",
"outplays":"outplay",
"outpouring":"outpour",
"outpours":"outpour",
"outranges":"outrange",
"outreaches":"outreach",
"outriders":"outrider",
"outriggers":"outrigger",
"outrivaled":"outrival",
"outrivaling":"outrival",
"outroars":"outroar",
"outsailed":"outsail",
"outsailing":"outsail",
"outsails":"outsail",
"outshouted":"outshout",
"outshouting":"outshout",
"outshouts":"outshout",
"outslugged":"outslug",
"outslugging":"outslug",
"outslugs":"outslug",
"outsoles":"outsole",
"outsourced":"outsource",
"outsources":"outsource",
"outsourcing":"outsource",
"outspends":"outspend",
"outstares":"outstare",
"outstretched":"outstretch",
"outstretches":"outstretch",
"outtraded":"outtrade",
"outtrades":"outtrade",
"outtrading":"outtrade",
"outvied":"outvie",
"outvies":"outvie",
"outvotes":"outvote",
"outvying":"outvie",
"outworks":"outwork",
"outworn":"outwear",
"ovenbaked":"ovenbake",
"ovenbakes":"ovenbake",
"ovenbaking":"ovenbake",
"over-achievers":"over-achiever",
"over-allotments":"over-allotment",
"overabstracted":"overabstract",
"overabstracting":"overabstract",
"overabstracts":"overabstract",
"overaccentuated":"overaccentuate",
"overaccentuates":"overaccentuate",
"overaccentuating":"overaccentuate",
"overachieves":"overachieve",
"overadvertised":"overadvertise",
"overadvertises":"overadvertise",
"overadvertising":"overadvertise",
"overages":"overage",
"overallotments":"overallotment",
"overanalysed":"overanalyse",
"overanalyses":"overanalyse",
"overanalysing":"overanalyse",
"overanalyzed":"overanalyze",
"overanalyzes":"overanalyze",
"overanalyzing":"overanalyze",
"overanxieties":"overanxiety",
"overapplications":"overapplication",
"overarranged":"overarrange",
"overarranges":"overarrange",
"overarranging":"overarrange",
"overarticulated":"overarticulate",
"overarticulates":"overarticulate",
"overarticulating":"overarticulate",
"overasserted":"overassert",
"overasserting":"overassert",
"overasserts":"overassert",
"overattributed":"overattribute",
"overattributes":"overattribute",
"overattributing":"overattribute",
"overawed":"overawe",
"overbaked":"overbake",
"overbakes":"overbake",
"overbaking":"overbake",
"overbars":"overbar",
"overbearing":"overbear",
"overbeaten":"overbeat",
"overbeating":"overbeat",
"overbeats":"overbeat",
"overbending":"overbend",
"overbends":"overbend",
"overbent":"overbend",
"overbets":"overbet",
"overbetting":"overbet",
"overbidders":"overbidder",
"overbilled":"overbill",
"overbilling":"overbill",
"overbills":"overbill",
"overbinded":"overbind",
"overbinding":"overbind",
"overbinds":"overbind",
"overbites":"overbite",
"overblankets":"overblanket",
"overbleached":"overbleach",
"overbleaches":"overbleach",
"overbleaching":"overbleach",
"overblouses":"overblouse",
"overboiled":"overboil",
"overboiling":"overboil",
"overboils":"overboil",
"overbookers":"overbooker",
"overbookings":"overbooking",
"overboots":"overboot",
"overborrowed":"overborrow",
"overborrowing":"overborrow",
"overborrows":"overborrow",
"overbought":"overbuy",
"overbounded":"overbound",
"overbounding":"overbound",
"overbounds":"overbound",
"overbowed":"overbow",
"overbowing":"overbow",
"overbows":"overbow",
"overbraked":"overbrake",
"overbrakes":"overbrake",
"overbraking":"overbrake",
"overbranded":"overbrand",
"overbranding":"overbrand",
"overbrands":"overbrand",
"overbred":"overbreed",
"overbreeding":"overbreed",
"overbreeds":"overbreed",
"overbridges":"overbridge",
"overbrimmed":"overbrim",
"overbrimming":"overbrim",
"overbrims":"overbrim",
"overbrowed":"overbrow",
"overbrowing":"overbrow",
"overbrows":"overbrow",
"overbrowsed":"overbrowse",
"overbrowses":"overbrowse",
"overbrowsing":"overbrowse",
"overbubbled":"overbubble",
"overbubbles":"overbubble",
"overbubbling":"overbubble",
"overbudgetd":"overbudget",
"overbudgeting":"overbudget",
"overbudgets":"overbudget",
"overbuilders":"overbuilder",
"overbuilt":"overbuild",
"overbulked":"overbulk",
"overbulking":"overbulk",
"overbulks":"overbulk",
"overburned":"overburn",
"overburning":"overburn",
"overburns":"overburn",
"overburnt":"overburn",
"overbuys":"overbuy",
"overcalculated":"overcalculate",
"overcalculates":"overcalculate",
"overcalculating":"overcalculate",
"overcalculations":"overcalculation",
"overcallers":"overcaller",
"overcanopied":"overcanopy",
"overcanopies":"overcanopy",
"overcanopying":"overcanopy",
"overcapitalised":"overcapitalise",
"overcapitalises":"overcapitalise",
"overcapitalising":"overcapitalise",
"overcapitalized":"overcapitalize",
"overcapitalizes":"overcapitalize",
"overcared":"overcare",
"overcares":"overcare",
"overcaring":"overcare",
"overcarked":"overcark",
"overcarking":"overcark",
"overcarks":"overcark",
"overcarried":"overcarry",
"overcarries":"overcarry",
"overcarrying":"overcarry",
"overcarved":"overcarve",
"overcarves":"overcarve",
"overcarving":"overcarve",
"overcatches":"overcatch",
"overcatching":"overcatch",
"overcategorizations":"overcategorization",
"overcategorized":"overcategorize",
"overcategorizes":"overcategorize",
"overcategorizing":"overcategorize",
"overcaught":"overcatch",
"overcentralised":"overcentralise",
"overcentralises":"overcentralise",
"overcentralising":"overcentralise",
"overcentralized":"overcentralize",
"overcentralizes":"overcentralize",
"overcentralizing":"overcentralize",
"overchargers":"overcharger",
"overchecks":"overcheck",
"overchilled":"overchill",
"overchilling":"overchill",
"overchills":"overchill",
"overchoreographed":"overchoreograph",
"overchoreographing":"overchoreograph",
"overchoreographs":"overchoreograph",
"overcited":"overcite",
"overcites":"overcite",
"overciting":"overcite",
"overclaimed":"overclaim",
"overclaiming":"overclaim",
"overclaims":"overclaim",
"overclasses":"overclass",
"overclassified":"overclassify",
"overclassifies":"overclassify",
"overclassifying":"overclassify",
"overcleaned":"overclean",
"overcleaning":"overclean",
"overcleans":"overclean",
"overclimbed":"overclimb",
"overclimbing":"overclimb",
"overclimbs":"overclimb",
"overclocked":"overclock",
"overclockers":"overclocker",
"overclocking":"overclock",
"overclocks":"overclock",
"overclouding":"overcloud",
"overcloyed":"overcloy",
"overcloying":"overcloy",
"overcloys":"overcloy",
"overclubbed":"overclub",
"overclubbing":"overclub",
"overclubs":"overclub",
"overcoached":"overcoach",
"overcoaches":"overcoach",
"overcoaching":"overcoach",
"overcoddled":"overcoddle",
"overcoddles":"overcoddle",
"overcoddling":"overcoddle",
"overcoils":"overcoil",
"overcollateralized":"overcollateralize",
"overcollateralizes":"overcollateralize",
"overcollateralizing":"overcollateralize",
"overcollections":"overcollection",
"overcolors":"overcolor",
"overcoloured":"overcolour",
"overcolouring":"overcolour",
"overcolours":"overcolour",
"overcomers":"overcomer",
"overcomings":"overcoming",
"overcommercialized":"overcommercialize",
"overcommercializes":"overcommercialize",
"overcommercializing":"overcommercialize",
"overcommits":"overcommit",
"overcommitted":"overcommit",
"overcommitting":"overcommit",
"overcommunicated":"overcommunicate",
"overcommunicates":"overcommunicate",
"overcommunicating":"overcommunicate",
"overcompensations":"overcompensation",
"overcomplexities":"overcomplexity",
"overcomplicated":"overcomplicate",
"overcomplicates":"overcomplicate",
"overcomplicating":"overcomplicate",
"overcomplications":"overcomplication",
"overcomplicators":"overcomplicator",
"overcomplimented":"overcompliment",
"overcomplimenting":"overcompliment",
"overcompliments":"overcompliment",
"overconsumed":"overconsume",
"overconsumes":"overconsume",
"overconsuming":"overconsume",
"overcooked":"overcook",
"overcooking":"overcook",
"overcooks":"overcook",
"overcorrected":"overcorrect",
"overcorrecting":"overcorrect",
"overcorrects":"overcorrect",
"overcrowds":"overcrowd",
"overcultivated":"overcultivate",
"overcultivates":"overcultivate",
"overcultivating":"overcultivate",
"overdeveloped":"overdevelop",
"overdevelops":"overdevelop",
"overdrafts":"overdraft",
"overdramatised":"overdramatise",
"overdramatises":"overdramatise",
"overdramatising":"overdramatise",
"overdramatized":"overdramatize",
"overdramatizes":"overdramatize",
"overdramatizing":"overdramatize",
"overdressed":"overdress",
"overeats":"overeat",
"overemphasised":"overemphasise",
"overemphasises":"overemphasise",
"overemphasising":"overemphasise",
"overexcited":"overexcite",
"overexcites":"overexcite",
"overexercised":"overexercise",
"overexercises":"overexercise",
"overexercising":"overexercise",
"overexerts":"overexert",
"overexploited":"overexploit",
"overexploiting":"overexploit",
"overexploits":"overexploit",
"overexposes":"overexpose",
"overfatigued":"overfatigue",
"overfatigues":"overfatigue",
"overfatiguing":"overfatigue",
"overfeeds":"overfeed",
"overfills":"overfill",
"overflights":"overflight",
"overfunded":"overfund",
"overfunding":"overfund",
"overfunds":"overfund",
"overgeneralised":"overgeneralise",
"overgeneralises":"overgeneralise",
"overgeneralising":"overgeneralise",
"overgeneralized":"overgeneralize",
"overgeneralizes":"overgeneralize",
"overgeneralizing":"overgeneralize",
"overgorged":"overgorge",
"overgorges":"overgorge",
"overgorging":"overgorge",
"overgrazes":"overgraze",
"overgrown":"overgrow",
"overhanded":"overhand",
"overhands":"overhand",
"overheats":"overheat",
"overhyped":"overhype",
"overhypes":"overhype",
"overhyping":"overhype",
"overinvested":"overinvest",
"overinvesting":"overinvest",
"overinvests":"overinvest",
"overjoys":"overjoy",
"overkilled":"overkill",
"overkilling":"overkill",
"overkills":"overkill",
"overlay":"overlie",
"overleaps":"overleap",
"overleveraged":"overleverage",
"overleverages":"overleverage",
"overleveraging":"overleverage",
"overlying":"overlie",
"overmatches":"overmatch",
"overmedicated":"overmedicate",
"overmedicates":"overmedicate",
"overmedicating":"overmedicate",
"overnighted":"overnight",
"overnighting":"overnight",
"overnights":"overnight",
"overpayments":"overpayment",
"overplanted":"overplant",
"overplanting":"overplant",
"overplants":"overplant",
"overpopulated":"overpopulate",
"overpopulates":"overpopulate",
"overpopulating":"overpopulate",
"overpraises":"overpraise",
"overpriced":"overprice",
"overprices":"overprice",
"overproducers":"overproducer",
"overproduces":"overproduce",
"overprotected":"overprotect",
"overprotecting":"overprotect",
"overprotects":"overprotect",
"overpurchased":"overpurchase",
"overpurchases":"overpurchase",
"overpurchasing":"overpurchase",
"overrated":"overrate",
"overreacts":"overreact",
"overrefined":"overrefine",
"overrefines":"overrefine",
"overregulated":"overregulate",
"overregulates":"overregulate",
"overregulating":"overregulate",
"overs":"over",
"oversaturated":"oversaturate",
"oversaturates":"oversaturate",
"oversaturating":"oversaturate",
"overshoes":"overshoe",
"oversimplifications":"oversimplification",
"oversimplified":"oversimplify",
"oversold":"oversell",
"overspecialised":"overspecialise",
"overspecialises":"overspecialise",
"overspecialising":"overspecialise",
"overspecialized":"overspecialize",
"overspecializes":"overspecialize",
"overspecializing":"overspecialize",
"overstaffed":"overstaff",
"overstaffing":"overstaff",
"overstaffs":"overstaff",
"overstocks":"overstock",
"overstored":"overstore",
"overstores":"overstore",
"overstoring":"overstore",
"overstressed":"overstress",
"overstresses":"overstress",
"overstressing":"overstress",
"overstuffs":"overstuff",
"overtaxex":"overtax",
"overtimed":"overtime",
"overtiming":"overtime",
"overtrumps":"overtrump",
"overused":"overuse",
"overvalued":"overvalue",
"overviews":"overview",
"overweighs":"overweigh",
"overweighted":"overweight",
"overwhelmed":"overwhelm",
"overwinters":"overwinter",
"ovoids":"ovoid",
"ovulates":"ovulate",
"owes":"owe",
"owlclaws":"owlclaw",
"owlets":"owlet",
"owner-occupiers":"owner-occupier",
"oxcarts":"oxcart",
"oxidated":"oxidate",
"oxidates":"oxidate",
"oxidating":"oxidate",
"oxidised":"oxidise",
"oxidises":"oxidise",
"oxidising":"oxidise",
"oxtails":"oxtail",
"oxygenised":"oxygenise",
"oxygenises":"oxygenise",
"oxygenising":"oxygenise",
"oxygenized":"oxygenize",
"oxygenizes":"oxygenize",
"oxygenizing":"oxygenize",
"oyster-catchers":"oyster-catcher",
"oystered":"oyster",
"oystering":"oyster",
"ozonised":"ozonise",
"ozonisers":"ozoniser",
"ozonises":"ozonise",
"ozonising":"ozonise",
"ozonized":"ozonize",
"ozonizers":"ozonizer",
"ozonizes":"ozonize",
"ozonizing":"ozonize",
"ozs":"oz",
"pace-setters":"pace-setter",
"pachyderms":"pachyderm",
"pack-animals":"pack-animal",
"pack-saddles":"pack-saddle",
"packaged":"package",
"packet-boats":"packet-boat",
"packsacks":"packsack",
"packsaddles":"packsaddle",
"packthreads":"packthread",
"paddle-boats":"paddle-boat",
"paddle-steamers":"paddle-steamer",
"paddle-wheels":"paddle-wheel",
"padlocks":"padlock",
"paedophiles":"paedophile",
"paganised":"paganise",
"paganises":"paganise",
"paganising":"paganise",
"paganized":"paganize",
"paganizes":"paganize",
"paganizing":"paganize",
"pagers":"pager",
"paintboxes":"paintbox",
"paintbrushes":"paintbrush",
"painted":"paint",
"paisleys":"paisley",
"palatalised":"palatalise",
"palatalises":"palatalise",
"palatalising":"palatalise",
"palazzi":"palazzo",
"palazzos":"palazzo",
"pales":"pale",
"palimpsests":"palimpsest",
"palindromes":"palindrome",
"palm-trees":"palm-tree",
"palmtops":"palmtop",
"pamphleteers":"pamphleteer",
"pan-broils":"pan-broil",
"pan-fried":"pan-fry",
"pan-fries":"pan-fry",
"pan-frying":"pan-fry",
"pancreases":"pancreas",
"pandemics":"pandemic",
"paneled":"panel",
"panelled":"panel",
"panellists":"panellist",
"panfries":"panfry",
"panhandlers":"panhandler",
"panhandles":"panhandle",
"panhandling":"panhandle",
"paninis":"panini",
"panjandra":"panjandrum",
"pannikins":"pannikin",
"pant-legs":"pant-leg",
"pantheists":"pantheist",
"pantheons":"pantheon",
"pantiles":"pantile",
"pantographs":"pantograph",
"pants":"pant",
"pantsuits":"pantsuit",
"panzers":"panzer",
"paper-boys":"paper-boy",
"paper-clips":"paper-clip",
"paper-girls":"paper-girl",
"paper-knives":"paper-knife",
"paper-pushers":"paper-pusher",
"paperboys":"paperboy",
"papercuts":"papercut",
"paperweights":"paperweight",
"papists":"papist",
"parade-grounds":"parade-ground",
"paraglided":"paraglide",
"paragliders":"paraglider",
"paraglides":"paraglide",
"paragliding":"paraglide",
"paragoned":"paragon",
"paragoning":"paragon",
"paragraphers":"paragrapher",
"parallaxes":"parallax",
"parallelised":"parallelise",
"parallelises":"parallelise",
"parallelising":"parallelise",
"parallelized":"parallelize",
"parallelizes":"parallelize",
"parallelizing":"parallelize",
"parallelograms":"parallelogram",
"paralysed":"paralyse",
"paralysing":"paralyse",
"paralytics":"paralytic",
"paraplegics":"paraplegic",
"parasailed":"parasail",
"parasailers":"parasailer",
"parasailing":"parasail",
"parasails":"parasail",
"parimutuels":"parimutuel",
"parishioners":"parishioner",
"parking-lots":"parking-lot",
"parking-meters":"parking-meter",
"parking-tickets":"parking-ticket",
"parricides":"parricide",
"parsers":"parser",
"parses":"parse",
"part-timers":"part-timer",
"particularised":"particularise",
"particularises":"particularise",
"particularising":"particularise",
"particulates":"particulate",
"partied":"party",
"partitives":"partitive",
"partygoers":"partygoer",
"partying":"party",
"pas":"pa",
"passed":"pass",
"passion-flowers":"passion-flower",
"passion-fruits":"passion-fruit",
"passion-plays":"passion-play",
"paste-ups":"paste-up",
"pasters":"paster",
"pasteurised":"pasteurise",
"pasteurises":"pasteurise",
"pasteurising":"pasteurise",
"pasteurized":"pasteurize",
"pasteurizes":"pasteurize",
"pastored":"pastor",
"pastoring":"pastor",
"patentees":"patentee",
"paternalists":"paternalist",
"pathogens":"pathogen",
"patinae":"patina",
"patisseries":"patisserie",
"patricides":"patricide",
"patronesses":"patroness",
"patronised":"patronise",
"patronises":"patronise",
"patronising":"patronise",
"pauperised":"pauperise",
"pauperises":"pauperise",
"pauperising":"pauperise",
"paved":"pave",
"paves":"pave",
"pavlovas":"pavlova",
"pawnbrokers":"pawnbroker",
"pay-outs":"pay-out",
"payables":"payable",
"paybacks":"payback",
"payees":"payee",
"paymasters":"paymaster",
"payouts":"payout",
"payslips":"payslip",
"pea-shooters":"pea-shooter",
"peace-pipes":"peace-pipe",
"peacekeepers":"peacekeeper",
"peahens":"peahen",
"peakier":"peaky",
"peakiest":"peaky",
"pearlier":"pearly",
"pearliest":"pearly",
"pearmains":"pearmain",
"peashooters":"peashooter",
"pectins":"pectin",
"pedagogs":"pedagog",
"pedicels":"pedicel",
"pedicles":"pedicle",
"pedicures":"pedicure",
"pediments":"pediment",
"pedometers":"pedometer",
"pedophiles":"pedophile",
"peduncles":"peduncle",
"pee-peed":"pee-pee",
"pee-peeing":"pee-pee",
"pee-pees":"pee-pee",
"peelings":"peeling",
"peens":"peen",
"peep-holes":"peep-hole",
"peep-shows":"peep-show",
"peeves":"peeve",
"peg-legs":"peg-leg",
"pegboards":"pegboard",
"pegmatites":"pegmatite",
"pelages":"pelage",
"pelicans":"pelican",
"pelters":"pelter",
"pen-names":"pen-name",
"pen-pals":"pen-pal",
"pen-pushers":"pen-pusher",
"penalised":"penalise",
"penalises":"penalise",
"penalising":"penalise",
"penetrators":"penetrator",
"penitentials":"penitential",
"penlights":"penlight",
"penny-pinched":"penny-pinch",
"penny-pinches":"penny-pinch",
"penny-pinching":"penny-pinch",
"penny-stocks":"penny-stock",
"penologists":"penologist",
"pentagons":"pentagon",
"pentameters":"pentameter",
"pentathlons":"pentathlon",
"pepper-mills":"pepper-mill",
"pepper-pots":"pepper-pot",
"peptides":"peptide",
"peptised":"peptise",
"peptises":"peptise",
"peptising":"peptise",
"peptizes":"peptize",
"percentiles":"percentile",
"perchers":"percher",
"percolations":"percolation",
"percolators":"percolator",
"percusses":"percuss",
"percussionists":"percussionist",
"peregrinates":"peregrinate",
"peregrinations":"peregrination",
"perennated":"perennate",
"perennates":"perennate",
"perennating":"perennate",
"perfectionists":"perfectionist",
"perforations":"perforation",
"perfumers":"perfumer",
"perigees":"perigee",
"perinatologists":"perinatologist",
"perineuria":"perineurium",
"periodontists":"periodontist",
"periscopes":"periscope",
"perishers":"perisher",
"peristyles":"peristyle",
"perjured":"perjure",
"perjures":"perjure",
"permalloys":"permalloy",
"permed":"perm",
"perming":"perm",
"peronei":"peroneus",
"perorates":"perorate",
"perorations":"peroration",
"perpetuates":"perpetuate",
"perseverated":"perseverate",
"perseverates":"perseverate",
"perseverating":"perseverate",
"personalised":"personalise",
"personalises":"personalise",
"personalising":"personalise",
"persuaded":"persuade",
"persuaders":"persuader",
"peruses":"peruse",
"pervaporated":"pervaporate",
"pervaporates":"pervaporate",
"pervaporating":"pervaporate",
"perversions":"perversion",
"pesticides":"pesticide",
"petrels":"petrel",
"petrochemicals":"petrochemical",
"phagocytes":"phagocyte",
"phalaropes":"phalarope",
"phantasmas":"phantasma",
"phantasms":"phantasm",
"pharmaceuticals":"pharmaceutical",
"phenoms":"phenom",
"pheromones":"pheromone",
"philharmonics":"philharmonic",
"philosophised":"philosophise",
"philosophises":"philosophise",
"philosophising":"philosophise",
"phlebotomised":"phlebotomise",
"phlebotomises":"phlebotomise",
"phlebotomising":"phlebotomise",
"phlebotomists":"phlebotomist",
"phlebotomized":"phlebotomize",
"phlebotomizes":"phlebotomize",
"phlebotomizing":"phlebotomize",
"phobics":"phobic",
"phonates":"phonate",
"phone-ins":"phone-in",
"phoneier":"phoney",
"phoneiest":"phoney",
"phonemes":"phoneme",
"phoneticians":"phonetician",
"phonologists":"phonologist",
"phosphines":"phosphine",
"phosphoresces":"phosphoresce",
"phosphors":"phosphor",
"photocathodes":"photocathode",
"photocopiers":"photocopier",
"photoelectrons":"photoelectron",
"photoengraved":"photoengrave",
"photoengraves":"photoengrave",
"photoengraving":"photoengrave",
"photojournalists":"photojournalist",
"photons":"photon",
"photosensitised":"photosensitise",
"photosensitises":"photosensitise",
"photosensitising":"photosensitise",
"photosensitized":"photosensitize",
"photosensitizes":"photosensitize",
"photosensitizing":"photosensitize",
"photosynthesised":"photosynthesise",
"photosynthesises":"photosynthesise",
"photosynthesising":"photosynthesise",
"photosynthesized":"photosynthesize",
"photosynthesizes":"photosynthesize",
"photosynthesizing":"photosynthesize",
"phots":"phot",
"phrase-books":"phrase-book",
"phubbings":"phubbing",
"physicals":"physical",
"physiotherapists":"physiotherapist",
"pianissimi":"pianissimo",
"pick-ups":"pick-up",
"pickers":"picker",
"picketers":"picketer",
"pickins":"pickin",
"pickling":"pickle",
"pickoffs":"pickoff",
"pics":"pic",
"pictograms":"pictogram",
"picture-books":"picture-book",
"picture-cards":"picture-card",
"picture-postcards":"picture-postcard",
"piebalds":"piebald",
"piercings":"piercing",
"piezometers":"piezometer",
"pigeon-holed":"pigeon-hole",
"pigeon-holes":"pigeon-hole",
"pigeon-holing":"pigeon-hole",
"piggy-backed":"piggy-back",
"piggy-backing":"piggy-back",
"piggy-backs":"piggy-back",
"piggybacks":"piggyback",
"pigtails":"pigtail",
"piing":"pi",
"pikers":"piker",
"pilasters":"pilaster",
"pile-drivers":"pile-driver",
"pile-ups":"pile-up",
"pileups":"pileup",
"pilgrimaged":"pilgrimage",
"pilgrimaging":"pilgrimage",
"pillaging":"pillage",
"pillared":"pillar",
"pillions":"pillion",
"pillocks":"pillock",
"pilot-boats":"pilot-boat",
"pimping":"pimp",
"pimples":"pimple",
"pin-heads":"pin-head",
"pin-tables":"pin-table",
"pinch-hitters":"pinch-hitter",
"pincushions":"pincushion",
"pine-cones":"pine-cone",
"pine-needles":"pine-needle",
"pinholes":"pinhole",
"pinpricks":"pinprick",
"pinstripes":"pinstripe",
"pinups":"pinup",
"pipe-clayed":"pipe-clay",
"pipe-claying":"pipe-clay",
"pipe-clays":"pipe-clay",
"pipe-dreams":"pipe-dream",
"pipeclayed":"pipeclay",
"pipeclaying":"pipeclay",
"pipettes":"pipette",
"pippins":"pippin",
"pipsqueaks":"pipsqueak",
"pirouettes":"pirouette",
"pissed":"piss",
"pissers":"pisser",
"pistes":"piste",
"pistoleers":"pistoleer",
"pit-heads":"pit-head",
"pitch-pines":"pitch-pine",
"pitheads":"pithead",
"pithecanthropi":"pithecanthropus",
"pitons":"piton",
"pittances":"pittance",
"pittas":"pitta",
"pituitary-glands":"pituitary-gland",
"pitying":"pity",
"place-mats":"place-mat",
"place-names":"place-name",
"place-settings":"place-setting",
"placeholders":"placeholder",
"placings":"placing",
"plagiarised":"plagiarise",
"plagiarises":"plagiarise",
"plagiarising":"plagiarise",
"plagiarisms":"plagiarism",
"plane-tables":"plane-table",
"plane-trees":"plane-tree",
"planeloads":"planeload",
"plantings":"planting",
"plantsmen":"plantsman",
"plantswomen":"plantswoman",
"plasterers":"plasterer",
"plasticised":"plasticise",
"plasticises":"plasticise",
"plasticising":"plasticise",
"plasticized":"plasticize",
"plasticizes":"plasticize",
"plasticizing":"plasticize",
"plastics":"plastic",
"plateaued":"plateau",
"plateauing":"plateau",
"plated":"plate",
"platens":"platen",
"platinized":"platinize",
"platinizes":"platinize",
"platinizing":"platinize",
"platitudinized":"platitudinize",
"platitudinizes":"platitudinize",
"platitudinizing":"platitudinize",
"platooned":"platoon",
"platooning":"platoon",
"platoons":"platoon",
"play-acted":"play-act",
"play-acting":"play-act",
"play-acts":"play-act",
"play-backs":"play-back",
"play-offs":"play-off",
"play-pens":"play-pen",
"play-rooms":"play-room",
"playacted":"playact",
"playacting":"playact",
"playacts":"playact",
"playbacks":"playback",
"playbills":"playbill",
"player-pianos":"player-piano",
"playlets":"playlet",
"playlisted":"playlist",
"playlisting":"playlist",
"playlists":"playlist",
"playoffs":"playoff",
"playsuits":"playsuit",
"plea-bargained":"plea-bargain",
"plea-bargaining":"plea-bargain",
"plea-bargains":"plea-bargain",
"pleaders":"pleader",
"pleadings":"pleading",
"pleased":"please",
"pleasure-boats":"pleasure-boat",
"pleasure-grounds":"pleasure-ground",
"pleated":"pleat",
"pledgees":"pledgee",
"pledgers":"pledger",
"plenaries":"plenary",
"pliers":"plier",
"plinks":"plink",
"plonked":"plonk",
"plonking":"plonk",
"plonks":"plonk",
"plovers":"plover",
"plug-holes":"plug-hole",
"plug-ins":"plug-in",
"plugholes":"plughole",
"plumed":"plume",
"plumps":"plump",
"pluralised":"pluralise",
"pluralises":"pluralise",
"pluralising":"pluralise",
"pluralists":"pluralist",
"pluralizes":"pluralize",
"plutocrats":"plutocrat",
"plyers":"plyer",
"poaches":"poach",
"pockmarked":"pockmark",
"pockmarking":"pockmark",
"pockmarks":"pockmark",
"podcasted":"podcast",
"podcasting":"podcast",
"podcasts":"podcast",
"poetesses":"poetess",
"poeticised":"poeticise",
"poeticises":"poeticise",
"poeticising":"poeticise",
"poeticized":"poeticize",
"poeticizes":"poeticize",
"poeticizing":"poeticize",
"poetised":"poetise",
"poetises":"poetise",
"poetising":"poetise",
"pogroms":"pogrom",
"pointillists":"pointillist",
"pointing":"point",
"poisoners":"poisoner",
"poisonings":"poisoning",
"pokeies":"pokey",
"polarised":"polarise",
"polarising":"polarise",
"polarizes":"polarize",
"pole-vaulters":"pole-vaulter",
"pole-vaulting":"pole-vault",
"pole-vaults":"pole-vault",
"poleaxed":"poleax",
"poleaxing":"poleax",
"polemicised":"polemicise",
"polemicises":"polemicise",
"polemicising":"polemicise",
"polemicists":"polemicist",
"polemicized":"polemicize",
"polemicizes":"polemicize",
"polemicizing":"polemicize",
"polemics":"polemic",
"policy-makers":"policy-maker",
"policyholders":"policyholder",
"policymakers":"policymaker",
"politburos":"politburo",
"politicised":"politicise",
"politicises":"politicise",
"politicising":"politicise",
"politicized":"politicize",
"politicizes":"politicize",
"politicks":"politick",
"poll-takers":"poll-taker",
"polled":"poll",
"pollenated":"pollenate",
"pollenates":"pollenate",
"pollenating":"pollenate",
"pollens":"pollen",
"pollices":"pollex",
"pollinators":"pollinator",
"polling-booths":"polling-booth",
"polling-days":"polling-day",
"polling-stations":"polling-station",
"pollutants":"pollutant",
"polluters":"polluter",
"poltergeists":"poltergeist",
"polyanthi":"polyanthus",
"polyelectrolytes":"polyelectrolyte",
"polyesters":"polyester",
"polyethers":"polyether",
"polygraphs":"polygraph",
"polyisocyanates":"polyisocyanate",
"polymaths":"polymath",
"polymerised":"polymerise",
"polymerises":"polymerise",
"polymerising":"polymerise",
"polymerized":"polymerize",
"polymerizes":"polymerize",
"polymerizing":"polymerize",
"polymers":"polymer",
"polynomials":"polynomial",
"polyols":"polyol",
"polyphosphates":"polyphosphate",
"polytheists":"polytheist",
"polyunsaturates":"polyunsaturate",
"ponced":"ponce",
"poncing":"ponce",
"ponderables":"ponderable",
"pongs":"pong",
"pontoons":"pontoon",
"pony-tails":"pony-tail",
"ponytails":"ponytail",
"pooed":"poo",
"poofters":"poofter",
"poohpoohs":"pooh-pooh",
"pooing":"poo",
"poolrooms":"poolroom",
"pooped":"poop",
"poor-boxes":"poor-box",
"poos":"poo",
"pop-ups":"pop-up",
"popovers":"popover",
"poppers":"popper",
"popularised":"popularise",
"popularises":"popularise",
"popularising":"popularise",
"populated":"populate",
"porcelainised":"porcelainise",
"porcelainises":"porcelainise",
"porcelainising":"porcelainise",
"porcelainized":"porcelainize",
"porcelainizes":"porcelainize",
"porcelainizing":"porcelainize",
"porcelains":"porcelain",
"porkers":"porker",
"portages":"portage",
"portcullises":"portcullis",
"porting":"port",
"portwatchers":"portwatcher",
"posher":"posh",
"poshest":"posh",
"possibles":"possible",
"post-bags":"post-bag",
"post-modernists":"post-modernist",
"post-mortems":"post-mortem",
"posting":"post",
"postmarked":"postmark",
"postmistresses":"postmistress",
"postmodernists":"postmodernist",
"postposed":"postpose",
"postposes":"postpose",
"postposing":"postpose",
"postulators":"postulator",
"posturings":"posturing",
"pot-boilers":"pot-boiler",
"pot-holers":"pot-holer",
"pot-holes":"pot-hole",
"pot-hunters":"pot-hunter",
"pot-roasts":"pot-roast",
"pot-shots":"pot-shot",
"potboilers":"potboiler",
"potentiates":"potentiate",
"potholders":"potholder",
"potions":"potion",
"potting-sheds":"potting-shed",
"pouring":"pour",
"pouters":"pouter",
"pouting":"pout",
"powder-kegs":"powder-keg",
"powder-rooms":"powder-room",
"power-dived":"power-dive",
"power-dives":"power-dive",
"power-diving":"power-dive",
"power-plays":"power-play",
"practicalities":"practicality",
"practicals":"practical",
"praesidia":"praesidium",
"praetoria":"praetorium",
"pragmatists":"pragmatist",
"prairie-dogs":"prairie-dog",
"praisablenesses":"praisableness",
"pralines":"praline",
"pranged":"prang",
"pranging":"prang",
"prangs":"prang",
"pratfalls":"pratfall",
"prattlers":"prattler",
"prayer-books":"prayer-book",
"prayer-mats":"prayer-mat",
"prayer-meetings":"prayer-meeting",
"prayer-rugs":"prayer-rug",
"prayer-wheels":"prayer-wheel",
"pre-Socratics":"pre-Socratic",
"pre-arranged":"pre-arrange",
"pre-arranges":"pre-arrange",
"pre-arranging":"pre-arrange",
"pre-conditions":"pre-condition",
"pre-empted":"pre-empt",
"pre-empting":"pre-empt",
"pre-empts":"pre-empt",
"pre-schools":"pre-school",
"pre-selling":"pre-sell",
"pre-sells":"pre-sell",
"pre-sets":"pre-set",
"pre-setting":"pre-set",
"pre-soaked":"pre-soak",
"pre-soaking":"pre-soak",
"pre-soaks":"pre-soak",
"pre-sold":"pre-sell",
"pre-teens":"pre-teen",
"preachifying":"preachify",
"preambles":"preamble",
"preannounced":"preannounce",
"preannounces":"preannounce",
"preannouncing":"preannounce",
"preapproved":"preapprove",
"preapproves":"preapprove",
"preapproving":"preapprove",
"prearranges":"prearrange",
"precesses":"precess",
"preconceived":"preconceive",
"preconceives":"preconceive",
"preconcerts":"preconcert",
"precooked":"precook",
"precooks":"precook",
"precooled":"precool",
"precooling":"precool",
"precools":"precool",
"precuting":"precut",
"precuts":"precut",
"predeceases":"predecease",
"predestinarians":"predestinarian",
"predestined":"predestine",
"predigested":"predigest",
"predigests":"predigest",
"predisposed":"predispose",
"predisposes":"predispose",
"preemptors":"preemptor",
"preempts":"preempt",
"preexists":"preexist",
"prefabricated":"prefabricate",
"prefabs":"prefab",
"preferred":"prefer",
"preforms":"preform",
"prefunded":"prefund",
"prefunding":"prefund",
"prefunds":"prefund",
"preheated":"preheat",
"preheats":"preheat",
"prehended":"prehend",
"prehending":"prehend",
"prehends":"prehend",
"prejudges":"prejudge",
"premediated":"premediate",
"premediates":"premediate",
"premediating":"premediate",
"premeditated":"premeditate",
"premeditates":"premeditate",
"premised":"premise",
"preordained":"preordain",
"prepackaged":"prepackage",
"prepackages":"prepackage",
"preparatives":"preparative",
"prepared":"prepare",
"preparers":"preparer",
"prepayments":"prepayment",
"preposed":"prepose",
"preposes":"prepose",
"preposing":"prepose",
"prerecording":"prerecord",
"prerecordings":"prerecording",
"prerecords":"prerecord",
"presbyters":"presbyter",
"presbytes":"presbyte",
"preschoolers":"preschooler",
"preschools":"preschool",
"prescribers":"prescriber",
"preservationists":"preservationist",
"presets":"preset",
"press-ganged":"press-gang",
"press-ganging":"press-gang",
"press-gangs":"press-gang",
"pressure-cooked":"pressure-cook",
"pressure-cookers":"pressure-cooker",
"pressure-cooking":"pressure-cook",
"pressure-cooks":"pressure-cook",
"pressurised":"pressurise",
"pressurises":"pressurise",
"pressurising":"pressurise",
"pressurized":"pressurize",
"presumed":"presume",
"presuming":"presume",
"presupposes":"presuppose",
"preteens":"preteen",
"pretests":"pretest",
"pretexted":"pretext",
"pretexting":"pretext",
"pretzels":"pretzel",
"prevised":"previse",
"previses":"previse",
"prevising":"previse",
"price-lists":"price-list",
"price-tags":"price-tag",
"priced":"price",
"pricings":"pricing",
"priestesses":"priestess",
"prigged":"prig",
"prigging":"prig",
"print-outs":"print-out",
"printed":"print",
"printouts":"printout",
"prions":"prion",
"prioritised":"prioritise",
"prioritises":"prioritise",
"prioritising":"prioritise",
"prioritized":"prioritize",
"prioritizes":"prioritize",
"prioritizing":"prioritize",
"prised":"prise",
"prises":"prise",
"prising":"prise",
"privatised":"privatise",
"privatises":"privatise",
"privatising":"privatise",
"privatizations":"privatization",
"privatized":"privatize",
"privatizes":"privatize",
"privatizing":"privatize",
"probables":"probable",
"probiotics":"probiotic",
"probosces":"proboscis",
"proconsuls":"proconsul",
"professionalised":"professionalise",
"professionalises":"professionalise",
"professionalising":"professionalise",
"professionalizes":"professionalize",
"profs":"prof",
"programmed":"program",
"projected":"project",
"projectors":"projector",
"proliferates":"proliferate",
"prologised":"prologise",
"prologises":"prologise",
"prologising":"prologise",
"prologized":"prologize",
"prologizes":"prologize",
"prologizing":"prologize",
"prologuised":"prologuise",
"prologuises":"prologuise",
"prologuising":"prologuise",
"prologuizes":"prologuize",
"promenaders":"promenader",
"promisees":"promisee",
"prompting":"prompt",
"promulgators":"promulgator",
"pronates":"pronate",
"prongs":"prong",
"pronked":"pronk",
"pronking":"pronk",
"pronks":"pronk",
"proofreaders":"proofreader",
"proofreading":"proofread",
"propaedeutics":"propaedeutic",
"propagandised":"propagandise",
"propagandises":"propagandise",
"propagandising":"propagandise",
"propagandizes":"propagandize",
"propfans":"propfan",
"prophetesses":"prophetess",
"proportioned":"proportion",
"proposed":"propose",
"propositae":"proposita",
"propounds":"propound",
"proprietresses":"proprietress",
"props":"prop",
"prorates":"prorate",
"prorogues":"prorogue",
"proselytes":"proselyte",
"proselytised":"proselytise",
"proselytises":"proselytise",
"proselytising":"proselytise",
"proselytizers":"proselytizer",
"proselytizes":"proselytize",
"proselytizing":"proselytize",
"prospecting":"prospect",
"prostrations":"prostration",
"prosumers":"prosumer",
"protected":"protect",
"protectionists":"protectionist",
"protects":"protect",
"protegees":"protegee",
"proteges":"protege",
"protestors":"protestor",
"proto-oncogenes":"proto-oncogene",
"protocolled":"protocol",
"protocolling":"protocol",
"protons":"proton",
"protractors":"protractor",
"proven":"prove",
"provided":"provide",
"provocateurs":"provocateur",
"provosts":"provost",
"psalmists":"psalmist",
"psalteria":"psalterium",
"psephologists":"psephologist",
"pseudocyeses":"pseudocyesis",
"psychoanalysed":"psychoanalyse",
"psychoanalysing":"psychoanalyse",
"publicised":"publicise",
"publicises":"publicise",
"publicising":"publicise",
"publicized":"publicize",
"published":"publish",
"puckered":"pucker",
"puerperia":"puerperium",
"puff-balls":"puff-ball",
"pugged":"pug",
"pugging":"pug",
"pullbacks":"pullback",
"pullers":"puller",
"pulsars":"pulsar",
"pulverised":"pulverise",
"pulverises":"pulverise",
"pulverising":"pulverise",
"pumice-stones":"pumice-stone",
"pummeling":"pummel",
"pummelling":"pummel",
"pumped":"pump",
"punch-balls":"punch-ball",
"punch-bowls":"punch-bowl",
"punch-ups":"punch-up",
"punkahs":"punkah",
"punkier":"punky",
"punkiest":"punky",
"punnets":"punnet",
"punsters":"punster",
"pupates":"pupate",
"puppet-plays":"puppet-play",
"puppet-shows":"puppet-show",
"puppeteers":"puppeteer",
"purchased":"purchase",
"pure-breds":"pure-bred",
"purifiers":"purifier",
"purists":"purist",
"pursued":"pursue",
"purtier":"purty",
"purtiest":"purty",
"push-bikes":"push-bike",
"push-carts":"push-cart",
"push-chairs":"push-chair",
"pushed":"push",
"pustulated":"pustulate",
"pustulates":"pustulate",
"pustulating":"pustulate",
"pustules":"pustule",
"putamina":"putamen",
"putouts":"putout",
"putt-putted":"putt-putt",
"putt-putting":"putt-putt",
"putt-putts":"putt-putt",
"putzed":"putz",
"putzes":"putz",
"putzing":"putz",
"pylons":"pylon",
"pyromaniacs":"pyromaniac",
"pyrometers":"pyrometer",
"pythons":"python",
"quadrates":"quadrate",
"quadrilles":"quadrille",
"quadriplegics":"quadriplegic",
"quadrupeds":"quadruped",
"quadruples":"quadruple",
"qualified":"qualify",
"quantifiers":"quantifier",
"quantised":"quantise",
"quantises":"quantise",
"quantising":"quantise",
"quantizes":"quantize",
"quarantines":"quarantine",
"quarks":"quark",
"quarreling":"quarrel",
"quarrellers":"quarreller",
"quarrelling":"quarrel",
"quarterdecks":"quarterdeck",
"quartered":"quarter",
"quarterfinals":"quarterfinal",
"quarterstaffs":"quarterstaff",
"queening":"queen",
"questing":"quest",
"quibs":"quib",
"quiches":"quiche",
"quicksands":"quicksand",
"quiesced":"quiesce",
"quiesces":"quiesce",
"quiescing":"quiesce",
"quietened":"quieten",
"quietening":"quieten",
"quietens":"quieten",
"quietists":"quietist",
"quiffs":"quiff",
"quintuples":"quintuple",
"quires":"quire",
"quirkier":"quirky",
"quirkiest":"quirky",
"quits":"quit",
"quitters":"quitter",
"quizzers":"quizzer",
"quoits":"quoit",
"quos":"quo",
"quoters":"quoter",
"quotients":"quotient",
"quoting":"quote",
"rabbit-warrens":"rabbit-warren",
"race-drivers":"race-driver",
"race-goers":"race-goer",
"race-meetings":"race-meeting",
"race-riots":"race-riot",
"race-tracks":"race-track",
"racecards":"racecard",
"racegoers":"racegoer",
"rack-rents":"rack-rent",
"raddled":"raddle",
"raddles":"raddle",
"raddling":"raddle",
"radicalised":"radicalise",
"radicalises":"radicalise",
"radicalising":"radicalise",
"radicalized":"radicalize",
"radicalizes":"radicalize",
"radicalizing":"radicalize",
"radiographers":"radiographer",
"radiomen":"radioman",
"radiosterilized":"radiosterilize",
"radiosterilizes":"radiosterilize",
"radiosterilizing":"radiosterilize",
"railbikers":"railbiker",
"railbikes":"railbike",
"railbirds":"railbird",
"railheads":"railhead",
"rainflies":"rainfly",
"rainforests":"rainforest",
"rainmakers":"rainmaker",
"rainstorms":"rainstorm",
"raised":"raise",
"rake-offs":"rake-off",
"raked":"rake",
"rallentandi":"rallentando",
"rallentandos":"rallentando",
"ramblers":"rambler",
"rammers":"rammer",
"ranchers":"rancher",
"randomised":"randomise",
"randomises":"randomise",
"randomising":"randomise",
"randomizes":"randomize",
"rands":"rand",
"rangefinders":"rangefinder",
"rangelands":"rangeland",
"ranging":"range",
"ransacking":"ransack",
"rapeseeds":"rapeseed",
"rapiers":"rapier",
"rappers":"rapper",
"rapporteurs":"rapporteur",
"raptuses":"raptus",
"rarefied":"rarefy",
"rarified":"rarify",
"rarifis":"rarify",
"rarifying":"rarify",
"rasher":"rash",
"ratbags":"ratbag",
"ratcheted":"ratchet",
"ratcheting":"ratchet",
"rate-capped":"rate-cap",
"rate-capping":"rate-cap",
"rate-caps":"rate-cap",
"ratfinks":"ratfink",
"ratholes":"rathole",
"rathskellers":"rathskeller",
"ratiocinates":"ratiocinate",
"rationalised":"rationalise",
"rationalises":"rationalise",
"rationalising":"rationalise",
"rats":"rat",
"rattled":"rattle",
"razor-cuts":"razor-cut",
"razor-cutting":"razor-cut",
"razzes":"razz",
"re-argued":"re-argue",
"re-argues":"re-argue",
"re-arguing":"re-argue",
"re-armed":"re-arm",
"re-arming":"re-arm",
"re-arms":"re-arm",
"re-created":"re-create",
"re-creates":"re-create",
"re-creating":"re-create",
"re-creations":"re-creation",
"re-echoes":"re-echo",
"re-edits":"re-edit",
"re-educates":"re-educate",
"re-elects":"re-elect",
"re-emerged":"re-emerge",
"re-emerges":"re-emerge",
"re-emerging":"re-emerge",
"re-emphases":"re-emphasis",
"re-emphasised":"re-emphasise",
"re-emphasises":"re-emphasise",
"re-emphasising":"re-emphasise",
"re-emphasized":"re-emphasize",
"re-emphasizes":"re-emphasize",
"re-emphasizing":"re-emphasize",
"re-enactments":"re-enactment",
"re-enacts":"re-enact",
"re-energised":"re-energise",
"re-energises":"re-energise",
"re-energising":"re-energise",
"re-energized":"re-energize",
"re-energizes":"re-energize",
"re-energizing":"re-energize",
"re-enforced":"re-enforce",
"re-enforces":"re-enforce",
"re-enforcing":"re-enforce",
"re-engineered":"re-engineer",
"re-engineering":"re-engineer",
"re-engineers":"re-engineer",
"re-entered":"re-enter",
"re-entering":"re-enter",
"re-enters":"re-enter",
"re-establishes":"re-establish",
"re-evaluates":"re-evaluate",
"re-examined":"re-examine",
"re-examines":"re-examine",
"re-examining":"re-examine",
"re-experiences":"re-experience",
"re-explained":"re-explain",
"re-explaining":"re-explain",
"re-explains":"re-explain",
"re-explored":"re-explore",
"re-explores":"re-explore",
"re-exploring":"re-explore",
"re-exported":"re-export",
"re-exporting":"re-export",
"re-exports":"re-export",
"re-formed":"re-form",
"re-forms":"re-form",
"re-offered":"re-offer",
"re-offering":"re-offer",
"re-offers":"re-offer",
"re-ran":"re-run",
"re-running":"re-run",
"re-runs":"re-run",
"reabsorbed":"reabsorb",
"reabsorbing":"reabsorb",
"reabsorbs":"reabsorb",
"reaccelerated":"reaccelerate",
"reaccelerates":"reaccelerate",
"reaccelerating":"reaccelerate",
"reacquainted":"reacquaint",
"reacquainting":"reacquaint",
"reacquaints":"reacquaint",
"reacquired":"reacquire",
"reacquires":"reacquire",
"reacquiring":"reacquire",
"reactants":"reactant",
"reactivates":"reactivate",
"reactivating":"reactivate",
"readapted":"readapt",
"readapting":"readapt",
"readapts":"readapt",
"readdresses":"readdress",
"readerships":"readership",
"readies":"ready",
"reading-desks":"reading-desk",
"reading-lamps":"reading-lamp",
"reading-lights":"reading-light",
"reading-rooms":"reading-room",
"readmits":"readmit",
"readmitted":"readmit",
"readmitting":"readmit",
"readopts":"readopt",
"readouts":"readout",
"reaffirms":"reaffirm",
"reafforested":"reafforest",
"reafforesting":"reafforest",
"reafforests":"reafforest",
"reagents":"reagent",
"realignments":"realignment",
"reallocated":"reallocate",
"reallocating":"reallocate",
"reallots":"reallot",
"reallotted":"reallot",
"reallotting":"reallot",
"reams":"ream",
"reappearances":"reappearance",
"reappoints":"reappoint",
"reappraises":"reappraise",
"rear-admirals":"rear-admiral",
"rear-ended":"rear-end",
"rear-ending":"rear-end",
"rear-ends":"rear-end",
"rearrangements":"rearrangement",
"rearranges":"rearrange",
"reassembles":"reassemble",
"reassignments":"reassignment",
"reassumes":"reassume",
"reassurances":"reassurance",
"reassured":"reassure",
"reattached":"reattach",
"reattaches":"reattach",
"reattaching":"reattach",
"reattributed":"reattribute",
"reattributes":"reattribute",
"reattributing":"reattribute",
"reauthorised":"reauthorise",
"reauthorises":"reauthorise",
"reauthorising":"reauthorise",
"reauthorized":"reauthorize",
"reauthorizes":"reauthorize",
"reauthorizing":"reauthorize",
"reawakened":"reawaken",
"reawakening":"reawaken",
"reawakens":"reawaken",
"rebalanced":"rebalance",
"rebalances":"rebalance",
"rebalancing":"rebalance",
"rebinds":"rebind",
"rebooted":"reboot",
"rebooting":"reboot",
"reboots":"reboot",
"rebounders":"rebounder",
"reburies":"rebury",
"recalcitrates":"recalcitrate",
"recalculated":"recalculate",
"recalculating":"recalculate",
"recalculations":"recalculation",
"recapitalizations":"recapitalization",
"recapitalizes":"recapitalize",
"recced":"recce",
"recceing":"recce",
"receiverships":"receivership",
"recentralized":"recentralize",
"recentralizes":"recentralize",
"recentralizing":"recentralize",
"receptionists":"receptionist",
"rechannelled":"rechannel",
"rechannelling":"rechannel",
"rechannels":"rechannel",
"rechargeables":"rechargeable",
"rechartered":"recharter",
"rechartering":"recharter",
"recharters":"recharter",
"rechecked":"recheck",
"rechecking":"recheck",
"rechecks":"recheck",
"rechristens":"rechristen",
"reciprocates":"reciprocate",
"recirculated":"recirculate",
"recirculates":"recirculate",
"recirculating":"recirculate",
"recitatives":"recitative",
"reciters":"reciter",
"reclassifies":"reclassify",
"recoated":"recoat",
"recoating":"recoat",
"recoats":"recoat",
"recoded":"recode",
"recodes":"recode",
"recoding":"recode",
"recognised":"recognise",
"recognises":"recognise",
"recognized":"recognize",
"recombines":"recombine",
"recommenced":"recommence",
"recommences":"recommence",
"recommencing":"recommence",
"recomposes":"recompose",
"reconditions":"recondition",
"reconfigured":"reconfigure",
"reconfigures":"reconfigure",
"reconfiguring":"reconfigure",
"reconfirmed":"reconfirm",
"reconfirming":"reconfirm",
"reconfirms":"reconfirm",
"reconnects":"reconnect",
"reconquers":"reconquer",
"reconsiders":"reconsider",
"reconstitutes":"reconstitute",
"reconvenes":"reconvene",
"reconverts":"reconvert",
"reconvicts":"reconvict",
"record-players":"record-player",
"recorded":"record",
"recriminates":"recriminate",
"recriminations":"recrimination",
"recrudescences":"recrudescence",
"recrudesces":"recrudesce",
"recruiters":"recruiter",
"recruiting":"recruit",
"rectifiers":"rectifier",
"recursions":"recursion",
"recurves":"recurve",
"recused":"recuse",
"recuses":"recuse",
"recusing":"recuse",
"recuts":"recut",
"recutting":"recut",
"red-eyes":"red-eye",
"red-flagged":"red-flag",
"red-flagging":"red-flag",
"red-flags":"red-flag",
"redacted":"redact",
"redacting":"redact",
"redacts":"redact",
"redecorated":"redecorate",
"redecorates":"redecorate",
"redecorating":"redecorate",
"reded":"rede",
"rededicated":"rededicate",
"rededicates":"rededicate",
"rededicating":"rededicate",
"redefined":"redefine",
"redefines":"redefine",
"redefining":"redefine",
"redelivered":"redeliver",
"redelivering":"redeliver",
"redelivers":"redeliver",
"redeploys":"redeploy",
"redes":"rede",
"redesignated":"redesignate",
"redesignates":"redesignate",
"redesignating":"redesignate",
"redesigns":"redesign",
"redetermined":"redetermine",
"redetermines":"redetermine",
"redetermining":"redetermine",
"redevelopers":"redeveloper",
"redialed":"redial",
"redialing":"redial",
"redialled":"redial",
"redialling":"redial",
"redials":"redial",
"reding":"rede",
"redisposed":"redispose",
"redisposes":"redispose",
"redisposing":"redispose",
"redistributes":"redistribute",
"redistricts":"redistrict",
"redlined":"redline",
"redlines":"redline",
"redlining":"redline",
"redounds":"redound",
"redrafts":"redraft",
"redraws":"redraw",
"redshirted":"redshirt",
"redshirting":"redshirt",
"redshirts":"redshirt",
"redstreaks":"redstreak",
"reduced":"reduce",
"reducers":"reducer",
"reducing":"reduce",
"reechoes":"reecho",
"reef-knots":"reef-knot",
"reefer-jackets":"reefer-jacket",
"reefier":"reefy",
"reefiest":"reefy",
"reelected":"reelect",
"reelecting":"reelect",
"reelects":"reelect",
"reemphasized":"reemphasize",
"reemphasizes":"reemphasize",
"reemphasizing":"reemphasize",
"reenacted":"reenact",
"reenacting":"reenact",
"reenactments":"reenactment",
"reenacts":"reenact",
"reengineered":"reengineer",
"reengineering":"reengineer",
"reengineers":"reengineer",
"reenlistments":"reenlistment",
"reenters":"reenter",
"reestablished":"reestablish",
"reestablishes":"reestablish",
"reestablishing":"reestablish",
"reevaluated":"reevaluate",
"reevaluates":"reevaluate",
"reevaluating":"reevaluate",
"refaces":"reface",
"referrals":"referral",
"refighted":"refight",
"refighting":"refight",
"refights":"refight",
"refiled":"refile",
"refiles":"refile",
"refiling":"refile",
"refinances":"refinance",
"refinancings":"refinancing",
"refiners":"refiner",
"refinishes":"refinish",
"reflated":"reflate",
"reflates":"reflate",
"reflating":"reflate",
"reflected":"reflect",
"reflectorised":"reflectorise",
"reflectorises":"reflectorise",
"reflectorising":"reflectorise",
"reflectorizes":"reflectorize",
"reflexologists":"reflexologist",
"refloated":"refloat",
"refloating":"refloat",
"refloats":"refloat",
"refluxed":"reflux",
"refluxing":"reflux",
"refocused":"refocus",
"refocuses":"refocus",
"refocusing":"refocus",
"refolded":"refold",
"refolding":"refold",
"refolds":"refold",
"reforests":"reforest",
"reforged":"reforge",
"reforges":"reforge",
"reforging":"reforge",
"reformed":"reform",
"refracts":"refract",
"refrigerates":"refrigerate",
"refuelling":"refuel",
"refurbishing":"refurbish",
"refurbishments":"refurbishment",
"refurnishes":"refurnish",
"refusers":"refuser",
"regicides":"regicide",
"regimented":"regiment",
"registered":"register",
"registrants":"registrant",
"regrew":"regrow",
"regrowing":"regrow",
"regrown":"regrow",
"regrows":"regrow",
"regularised":"regularise",
"regularises":"regularise",
"regularising":"regularise",
"regulated":"regulate",
"reguli":"regulus",
"rehabbed":"rehab",
"rehabbing":"rehab",
"rehabilitates":"rehabilitate",
"rehabs":"rehab",
"reheats":"reheat",
"reheeled":"reheel",
"reheeling":"reheel",
"reheels":"reheel",
"rehouses":"rehouse",
"reignites":"reignite",
"reimbursements":"reimbursement",
"reimposes":"reimpose",
"reincarnates":"reincarnate",
"reincorporated":"reincorporate",
"reincorporates":"reincorporate",
"reincorporating":"reincorporate",
"reindicted":"reindict",
"reindicting":"reindict",
"reindicts":"reindict",
"reinjects":"reinject",
"reinstalls":"reinstall",
"reinstatements":"reinstatement",
"reinstitutes":"reinstitute",
"reinsurers":"reinsurer",
"reinsures":"reinsure",
"reintegrates":"reintegrate",
"reintroduces":"reintroduce",
"reinvents":"reinvent",
"reinvestigates":"reinvestigate",
"reinvests":"reinvest",
"reissued":"reissue",
"reissuing":"reissue",
"rejigged":"rejig",
"rejiggered":"rejigger",
"rejiggering":"rejigger",
"rejiggers":"rejigger",
"rejigging":"rejig",
"rejigs":"rejig",
"rejuvenates":"rejuvenate",
"rejuvenating":"rejuvenate",
"rekindles":"rekindle",
"relabeled":"relabel",
"relabeling":"relabel",
"relabels":"relabel",
"relaced":"relace",
"relaces":"relace",
"relacing":"relace",
"related":"relate",
"relatives-in-law":"relative-in-law",
"relativised":"relativise",
"relativises":"relativise",
"relativising":"relativise",
"relativists":"relativist",
"relativized":"relativize",
"relativizes":"relativize",
"relativizing":"relativize",
"relaunches":"relaunch",
"relearned":"relearn",
"relearning":"relearn",
"relearns":"relearn",
"relicensed":"relicense",
"relicenses":"relicense",
"relicensing":"relicense",
"relieved":"relieve",
"relines":"reline",
"relisted":"relist",
"relisting":"relist",
"relists":"relist",
"relyriced":"relyric",
"relyricing":"relyric",
"relyrics":"relyric",
"remarketed":"remarket",
"remarketing":"remarket",
"remarkets":"remarket",
"remarriages":"remarriage",
"remarries":"remarry",
"remediated":"remediate",
"remediates":"remediate",
"remediating":"remediate",
"remilitarised":"remilitarise",
"remilitarises":"remilitarise",
"remilitarising":"remilitarise",
"remilitarizes":"remilitarize",
"reminisces":"reminisce",
"remises":"remise",
"remodelling":"remodel",
"remodels":"remodel",
"remolded":"remold",
"remolding":"remold",
"remolds":"remold",
"remonstrations":"remonstration",
"remoralised":"remoralise",
"remoralises":"remoralise",
"remoralising":"remoralise",
"remoralized":"remoralize",
"remoralizes":"remoralize",
"remoralizing":"remoralize",
"remoulded":"remould",
"remoulding":"remould",
"remoulds":"remould",
"remounts":"remount",
"removed":"remove",
"removers":"remover",
"renames":"rename",
"renationalised":"renationalise",
"renationalises":"renationalise",
"renationalising":"renationalise",
"renationalized":"renationalize",
"renationalizes":"renationalize",
"renationalizing":"renationalize",
"rended":"rend",
"renegaded":"renegade",
"renegading":"renegade",
"reneged":"renege",
"reneging":"renege",
"renegotiates":"renegotiate",
"renegotiations":"renegotiation",
"renewed":"renew",
"renormalised":"renormalise",
"renormalises":"renormalise",
"renormalising":"renormalise",
"renormalized":"renormalize",
"renormalizes":"renormalize",
"renormalizing":"renormalize",
"rented":"rent",
"reoccupies":"reoccupy",
"reopens":"reopen",
"reorganised":"reorganise",
"reorganises":"reorganise",
"reorganising":"reorganise",
"reorientated":"reorientate",
"reorientates":"reorientate",
"reorientating":"reorientate",
"repackages":"repackage",
"repacked":"repack",
"repacking":"repack",
"repacks":"repack",
"repassed":"repass",
"repasses":"repass",
"repassing":"repass",
"repasted":"repast",
"repasting":"repast",
"repatriations":"repatriation",
"repeated":"repeat",
"repercussed":"repercuss",
"repercusses":"repercuss",
"repercussing":"repercuss",
"repines":"repine",
"replants":"replant",
"replastered":"replaster",
"replastering":"replaster",
"replasters":"replaster",
"repointed":"repoint",
"repointing":"repoint",
"repoints":"repoint",
"repos":"repo",
"reposits":"reposit",
"repossessed":"repossess",
"repossessions":"repossession",
"reprehends":"reprehend",
"repressers":"represser",
"repressions":"repression",
"repressors":"repressor",
"repriced":"reprice",
"reprices":"reprice",
"repricing":"reprice",
"reprisals":"reprisal",
"reproachers":"reproacher",
"reprogrammes":"reprogramme",
"reprograms":"reprogram",
"republishes":"republish",
"requalified":"requalify",
"requalifies":"requalify",
"requalifying":"requalify",
"requesters":"requester",
"required":"require",
"rereads":"reread",
"reroofed":"reroof",
"reroofing":"reroof",
"reroofs":"reroof",
"reroutes":"reroute",
"rescaled":"rescale",
"rescales":"rescale",
"rescaling":"rescale",
"rescheduled":"reschedule",
"reschedules":"reschedule",
"rescheduling":"reschedule",
"resealed":"reseal",
"resealing":"reseal",
"reseals":"reseal",
"reseats":"reseat",
"resections":"resection",
"resects":"resect",
"reseeded":"reseed",
"reseeding":"reseed",
"reseeds":"reseed",
"resellers":"reseller",
"resells":"resell",
"resembles":"resemble",
"reserved":"reserve",
"reservists":"reservist",
"resettles":"resettle",
"reshipped":"reship",
"reshipping":"reship",
"reships":"reship",
"reshooting":"reshoot",
"reshoots":"reshoot",
"reshot":"reshoot",
"resifted":"resift",
"resifting":"resift",
"resifts":"resift",
"resiles":"resile",
"resinates":"resinate",
"resized":"resize",
"resizes":"resize",
"resizing":"resize",
"resolved":"resolve",
"resorbed":"resorb",
"resorbing":"resorb",
"resorbs":"resorb",
"resourced":"resource",
"resourcing":"resource",
"respected":"respect",
"respecters":"respecter",
"respited":"respite",
"respiting":"respite",
"restaffed":"restaff",
"restaffing":"restaff",
"restaffs":"restaff",
"restaged":"restage",
"restages":"restage",
"restaging":"restage",
"restarted":"restart",
"restarters":"restart",
"restarting":"restart",
"restatements":"restatement",
"rested":"rest",
"restocks":"restock",
"restored":"restore",
"restricted":"restrict",
"restructures":"restructure",
"restructurings":"restructuring",
"restudied":"restudy",
"restudies":"restudy",
"restudying":"restudy",
"restyled":"restyle",
"restyles":"restyle",
"restyling":"restyle",
"resublimed":"resublime",
"resublimes":"resublime",
"resubliming":"resublime",
"resubmits":"resubmit",
"resubmitted":"resubmit",
"resubmitting":"resubmit",
"resupplied":"resupply",
"resupplies":"resupply",
"resupplying":"resupply",
"resurfaces":"resurface",
"resurges":"resurge",
"resuspended":"resuspend",
"resuspending":"resuspend",
"resuspends":"resuspend",
"retails":"retail",
"retardants":"retardant",
"retargeted":"retarget",
"retargeting":"retarget",
"retargets":"retarget",
"retellings":"retelling",
"reticulates":"reticulate",
"retied":"retie",
"reties":"retie",
"retractors":"retractor",
"retraining":"retrain",
"retrains":"retrain",
"retranslated":"retranslate",
"retranslates":"retranslate",
"retranslating":"retranslate",
"retransmissions":"retransmission",
"retransmits":"retransmit",
"retransmitted":"retransmit",
"retransmitting":"retransmit",
"retrenches":"retrench",
"retrials":"retrial",
"retrievers":"retriever",
"retrogradations":"retrogradation",
"retrospectives":"retrospective",
"retroviruses":"retrovirus",
"returned":"return",
"returnees":"returnee",
"returners":"returner",
"retying":"retie",
"reupholstering":"reupholster",
"reused":"reuse",
"reuses":"reuse",
"reusing":"reuse",
"revenuers":"revenuer",
"revered":"revere",
"revised":"revise",
"revisionists":"revisionist",
"revisits":"revisit",
"revitalised":"revitalise",
"revitalises":"revitalise",
"revitalising":"revitalise",
"revived":"revive",
"revocations":"revocation",
"revolutionised":"revolutionise",
"revolutionises":"revolutionise",
"revolutionising":"revolutionise",
"rewarded":"reward",
"rewires":"rewire",
"rewiring":"rewire",
"reworking":"rework",
"reworkings":"reworking",
"reworks":"rework",
"rewrapped":"rewrap",
"rewrapping":"rewrap",
"rewraps":"rewrap",
"rhapsodised":"rhapsodise",
"rhapsodises":"rhapsodise",
"rhapsodising":"rhapsodise",
"rhapsodizes":"rhapsodize",
"rheumatologists":"rheumatologist",
"rhinestones":"rhinestone",
"rhododendrons":"rhododendron",
"rhomboids":"rhomboid",
"rhymers":"rhymer",
"rhymesters":"rhymester",
"ribozymes":"ribozyme",
"rices":"rice",
"riches":"rich",
"ridged":"ridge",
"riggers":"rigger",
"right-angles":"right-angle",
"ringmasters":"ringmaster",
"ringsiders":"ringsider",
"ringtones":"ringtone",
"rioters":"rioter",
"ripcords":"ripcord",
"ripens":"ripen",
"rippers":"ripper",
"risk-takers":"risk-taker",
"rissoles":"rissole",
"ritualised":"ritualise",
"ritualises":"ritualise",
"ritualising":"ritualise",
"ritualists":"ritualist",
"ritualized":"ritualize",
"ritualizes":"ritualize",
"ritualizing":"ritualize",
"river-beds":"river-bed",
"riverboats":"riverboat",
"roasted":"roast",
"roasters":"roaster",
"rock-gardens":"rock-garden",
"rocket-bombs":"rocket-bomb",
"rocking-chairs":"rocking-chair",
"rocking-horses":"rocking-horse",
"rodders":"rodder",
"roisterers":"roisterer",
"role-played":"role-play",
"role-playing":"role-play",
"role-plays":"role-play",
"roll-ons":"roll-on",
"roll-outs":"roll-out",
"roll-ups":"roll-up",
"roller-coasters":"roller-coaster",
"roller-skating":"roller-skate",
"rollerblades":"rollerblade",
"rolling-mills":"rolling-mill",
"rolling-pins":"rolling-pin",
"rollovers":"rollover",
"romancers":"romancer",
"romanticised":"romanticise",
"romanticises":"romanticise",
"romanticising":"romanticise",
"romanticized":"romanticize",
"roof-gardens":"roof-garden",
"roof-racks":"roof-rack",
"roof-tops":"roof-top",
"roofers":"roofer",
"roofier":"roofy",
"roofiest":"roofy",
"rooftops":"rooftop",
"room-mates":"room-mate",
"roomettes":"roomette",
"rooming-houses":"rooming-house",
"rooted":"root",
"rooters":"rooter",
"rootled":"rootle",
"rootles":"rootle",
"rootling":"rootle",
"ropemakers":"ropemaker",
"ropers":"roper",
"rosarians":"rosarian",
"rose-hips":"rose-hip",
"rose-windows":"rose-window",
"rosehips":"rosehip",
"rostered":"roster",
"rostering":"roster",
"rotisseries":"rotisserie",
"rottweilers":"rottweiler",
"rough-hewn":"rough-hew",
"roughens":"roughen",
"roughriders":"roughrider",
"rouletted":"roulette",
"rouletting":"roulette",
"round-tables":"round-table",
"round-trips":"round-trip",
"round-ups":"round-up",
"roundups":"roundup",
"roused":"rouse",
"rousers":"rouser",
"rousts":"roust",
"routers":"router",
"routings":"routing",
"row-boats":"row-boat",
"rowing-boats":"rowing-boat",
"rubber-stamped":"rubber-stamp",
"rubber-stamping":"rubber-stamp",
"rubber-stamps":"rubber-stamp",
"rubberised":"rubberise",
"rubberises":"rubberise",
"rubberising":"rubberise",
"rubberized":"rubberize",
"rubberneckers":"rubbernecker",
"rubbernecking":"rubberneck",
"rubbished":"rubbish",
"rubbishing":"rubbish",
"rubdowns":"rubdown",
"rubricated":"rubricate",
"rubricates":"rubricate",
"rubricating":"rubricate",
"ruffed":"ruff",
"ruffing":"ruff",
"ruminants":"ruminant",
"ruminators":"ruminator",
"rumored":"rumor",
"rumoured":"rumour",
"rumpled":"rumple",
"run-offs":"run-off",
"run-ups":"run-up",
"rush-hours":"rush-hour",
"rushed":"rush",
"rust-proofed":"rust-proof",
"rust-proofing":"rust-proof",
"rust-proofs":"rust-proof",
"rustproofing":"rustproof",
"rustproofs":"rustproof",
"rutting":"rut",
"saccharised":"saccharise",
"saccharises":"saccharise",
"saccharising":"saccharise",
"saccharized":"saccharize",
"saccharizes":"saccharize",
"saccharizing":"saccharize",
"sacculi":"sacculus",
"sachems":"sachem",
"sachets":"sachet",
"sackcloths":"sackcloth",
"saddened":"sadden",
"saddening":"sadden",
"saddle-bags":"saddle-bag",
"saddlebags":"saddlebag",
"saddlers":"saddler",
"sadists":"sadist",
"sadomasochists":"sadomasochist",
"safe-conducts":"safe-conduct",
"safety-belts":"safety-belt",
"safety-catches":"safety-catch",
"safety-pins":"safety-pin",
"safety-valves":"safety-valve",
"sahibs":"sahib",
"sailing-boats":"sailing-boat",
"sailing-ships":"sailing-ship",
"sailplaned":"sailplane",
"sailplaners":"sailplaner",
"sailplaning":"sailplane",
"saith":"say",
"salad-dressings":"salad-dressing",
"salarymen":"salaryman",
"salemen":"saleman",
"sales-taxes":"sales-tax",
"salespeople":"salesperson",
"salespersons":"salesperson",
"salicylates":"salicylate",
"salivates":"salivate",
"salsas":"salsa",
"salt-cellars":"salt-cellar",
"salt-shakers":"salt-shaker",
"saltated":"saltate",
"saltates":"saltate",
"saltating":"saltate",
"saltines":"saltine",
"salvers":"salver",
"sambaed":"samba",
"sambaing":"samba",
"sammed":"sam",
"samming":"sam",
"samosas":"samosa",
"samovars":"samovar",
"sampans":"sampan",
"samplings":"sampling",
"sand-bars":"sand-bar",
"sand-castles":"sand-castle",
"sand-pits":"sand-pit",
"sandbaggers":"sandbagger",
"sandbanks":"sandbank",
"sandblasts":"sandblast",
"sandcastles":"sandcastle",
"sandpipers":"sandpiper",
"sandpits":"sandpit",
"sandstones":"sandstone",
"sandwiched":"sandwich",
"sanitated":"sanitate",
"sanitates":"sanitate",
"sanitating":"sanitate",
"sanitationists":"sanitationist",
"sanitised":"sanitise",
"sanitises":"sanitise",
"sanitising":"sanitise",
"santimi":"santims",
"saponins":"saponin",
"sappers":"sapper",
"sarongs":"sarong",
"sated":"sate",
"satins":"satin",
"satirised":"satirise",
"satirises":"satirise",
"satirising":"satirise",
"satisficed":"satisfice",
"satisfices":"satisfice",
"satisficing":"satisfice",
"satisfied":"satisfy",
"saturated":"saturate",
"sauce-boats":"sauce-boat",
"sausage-dogs":"sausage-dog",
"savoured":"savour",
"savouring":"savour",
"savvier":"savvy",
"savviest":"savvy",
"saxophonists":"saxophonist",
"scalpels":"scalpel",
"scalpers":"scalper",
"scammed":"scam",
"scammers":"scammer",
"scamming":"scam",
"scandalised":"scandalise",
"scandalises":"scandalise",
"scandalising":"scandalise",
"scandalmongers":"scandalmonger",
"scanners":"scanner",
"scants":"scant",
"scapegoated":"scapegoat",
"scapegoating":"scapegoat",
"scared":"scare",
"scathing":"scathe",
"scatter-brains":"scatter-brain",
"scatter-guns":"scatter-gun",
"scattered":"scatter",
"scenarists":"scenarist",
"scheduled":"schedule",
"schematised":"schematise",
"schematises":"schematise",
"schematising":"schematise",
"schematizes":"schematize",
"schillings":"schilling",
"schizoids":"schizoid",
"schizomycetes":"schizomycete",
"schizophrenics":"schizophrenic",
"schmaltzier":"schmaltzy",
"schmaltziest":"schmaltzy",
"schmalzier":"schmalzy",
"schmalziest":"schmalzy",
"schmoozed":"schmooze",
"schmoozes":"schmooze",
"schmoozing":"schmooze",
"schnooks":"schnook",
"school-leavers":"school-leaver",
"school-marms":"school-marm",
"schoolbags":"schoolbag",
"schooled":"school",
"schoolyards":"schoolyard",
"schticks":"schtick",
"scimitars":"scimitar",
"scintillating":"scintillate",
"sciolists":"sciolist",
"scions":"scion",
"scissors":"scissor",
"scofflaws":"scofflaw",
"scolloping":"scollop",
"scones":"scone",
"scoped":"scope",
"scoping":"scope",
"scops":"scop",
"score-boards":"score-board",
"score-cards":"score-card",
"scoreboards":"scoreboard",
"scourers":"scourer",
"scouters":"scouter",
"scramblers":"scrambler",
"scrap-books":"scrap-book",
"scratchpads":"scratchpad",
"screamers":"screamer",
"screaming":"scream",
"screeds":"screed",
"screeners":"screener",
"screenplays":"screenplay",
"screwdrivers":"screwdriver",
"script-writers":"script-writer",
"scriptwriters":"scriptwriter",
"scrubbers":"scrubber",
"scrublands":"scrubland",
"scrutinised":"scrutinise",
"scrutinises":"scrutinise",
"scrutinising":"scrutinise",
"scuffed":"scuff",
"scuffling":"scuffle",
"scullers":"sculler",
"sculls":"scull",
"sculpted":"sculpt",
"sculptresses":"sculptress",
"scuppered":"scupper",
"scuppering":"scupper",
"scuppers":"scupper",
"sea-breezes":"sea-breeze",
"sea-dogs":"sea-dog",
"sea-horses":"sea-horse",
"sea-lions":"sea-lion",
"sea-urchins":"sea-urchin",
"sea-walls":"sea-wall",
"sea-ways":"sea-way",
"seadogs":"seadog",
"seafronts":"seafront",
"sealed":"seal",
"seamed":"seam",
"search-parties":"search-party",
"search-warrants":"search-warrant",
"seascapes":"seascape",
"season-tickets":"season-ticket",
"seated":"seat",
"seaweeds":"seaweed",
"secants":"secant",
"secessionists":"secessionist",
"secluded":"seclude",
"seconders":"seconder",
"secondments":"secondment",
"secretions":"secretion",
"sectionalised":"sectionalise",
"sectionalises":"sectionalise",
"sectionalising":"sectionalise",
"sectionalized":"sectionalize",
"sectionalizes":"sectionalize",
"sectionalizing":"sectionalize",
"secularised":"secularise",
"secularises":"secularise",
"secularising":"secularise",
"secularizes":"secularize",
"secured":"secure",
"secures":"secure",
"sedan-chairs":"sedan-chair",
"sedated":"sedate",
"sedating":"sedate",
"sedges":"sedge",
"seductresses":"seductress",
"see-sawed":"see-saw",
"see-sawing":"see-saw",
"see-saws":"see-saw",
"seed-beds":"seed-bed",
"seed-cakes":"seed-cake",
"seed-pearls":"seed-pearl",
"seedbeds":"seedbed",
"seedcakes":"seedcake",
"seedcoats":"seedcoat",
"seeders":"seeder",
"seeled":"seel",
"seeling":"seel",
"seels":"seel",
"segregated":"segregate",
"segregates":"segregate",
"segued":"segue",
"segueing":"segue",
"segues":"segue",
"seismographies":"seismography",
"seismographs":"seismograph",
"seismologists":"seismologist",
"selected":"select",
"self-destructed":"self-destruct",
"self-destructing":"self-destruct",
"self-destructs":"self-destruct",
"self-images":"self-image",
"self-portraits":"self-portrait",
"selling-points":"selling-point",
"selloffs":"selloff",
"sellotaped":"sellotape",
"sellotapes":"sellotape",
"sellotaping":"sellotape",
"semaphores":"semaphore",
"semi-abstractions":"semi-abstraction",
"semi-conductors":"semi-conductor",
"semi-finalists":"semi-finalist",
"semiabstractions":"semiabstraction",
"semifinalists":"semifinalist",
"semiologists":"semiologist",
"send-ups":"send-up",
"sensationalised":"sensationalise",
"sensationalises":"sensationalise",
"sensationalising":"sensationalise",
"sensationalized":"sensationalize",
"sensationalizes":"sensationalize",
"sensationalizing":"sensationalize",
"sense-organs":"sense-organ",
"sensitised":"sensitise",
"sensitises":"sensitise",
"sensitising":"sensitise",
"sensitives":"sensitive",
"sensualists":"sensualist",
"sentencings":"sentencing",
"sentimentalised":"sentimentalise",
"sentimentalises":"sentimentalise",
"sentimentalising":"sentimentalise",
"sentry-boxes":"sentry-box",
"sepals":"sepal",
"separated":"separate",
"septuagenarians":"septuagenarian",
"septums":"septum",
"sepulchred":"sepulchre",
"sepulchring":"sepulchre",
"sequenced":"sequence",
"sequencers":"sequencer",
"sequencing":"sequence",
"sergeant-majors":"sergeant-major",
"serjeants-at-arms":"serjeant-at-arms",
"serjeants-at-law":"serjeant-at-law",
"sermonised":"sermonise",
"sermonises":"sermonise",
"sermonising":"sermonise",
"serrated":"serrate",
"serrates":"serrate",
"serrating":"serrate",
"servicewomen":"servicewoman",
"servitors":"servitor",
"set-asides":"set-aside",
"set-ups":"set-up",
"setters":"setter",
"settled":"settle",
"sexagenarians":"sexagenarian",
"sexologists":"sexologist",
"sexpots":"sexpot",
"sextants":"sextant",
"sextuples":"sextuple",
"sexualised":"sexualise",
"sexualises":"sexualise",
"sexualising":"sexualise",
"sexualizes":"sexualize",
"sexualizing":"sexualize",
"shadow-boxed":"shadow-box",
"shadow-boxes":"shadow-box",
"shadow-boxing":"shadow-box",
"shakedowns":"shakedown",
"shakeouts":"shakeout",
"shakers":"shaker",
"shakeups":"shakeup",
"shales":"shale",
"shamans":"shaman",
"shambles":"shamble",
"shambling":"shamble",
"shammers":"shammer",
"shantytowns":"shantytown",
"shaped":"shape",
"shared":"share",
"shareholdings":"shareholding",
"sharpeners":"sharpener",
"shays":"shay",
"sheafed":"sheaf",
"sheafing":"sheaf",
"sheafs":"sheaf",
"sheathes":"sheathe",
"sheep-dips":"sheep-dip",
"sheep-dogs":"sheep-dog",
"sheers":"sheer",
"shellacked":"shellac",
"shellacking":"shellac",
"sheltered":"shelter",
"shelvier":"shelvy",
"shelviest":"shelvy",
"shepherdesses":"shepherdess",
"shifters":"shifter",
"shilled":"shill",
"shilling":"shill",
"shills":"shill",
"shillyshallied":"shillyshally",
"shillyshallying":"shillyshally",
"shingled":"shingle",
"shingles":"shingle",
"shipbuilders":"shipbuilder",
"shipmates":"shipmate",
"shipowners":"shipowner",
"shipwrights":"shipwright",
"shirring":"shirr",
"shirt-tails":"shirt-tail",
"shirtsleeves":"shirtsleeve",
"shirttails":"shirttail",
"shitted":"shit",
"shocked":"shock",
"shockers":"shocker",
"shoe-horns":"shoe-horn",
"shoe-strings":"shoe-string",
"shoeboxes":"shoebox",
"shoehorned":"shoehorn",
"shoehorning":"shoehorn",
"shoehorns":"shoehorn",
"shoot-em-ups":"shoot-em-up",
"shoot-outs":"shoot-out",
"shooting-galleries":"shooting-gallery",
"shop-assistants":"shop-assistant",
"shop-stewards":"shop-steward",
"shopaholics":"shopaholic",
"shoplifted":"shoplift",
"shoplifting":"shoplift",
"shoplifts":"shoplift",
"short-changed":"short-change",
"short-changes":"short-change",
"short-changing":"short-change",
"short-cuts":"short-cut",
"short-listed":"short-list",
"short-listing":"short-list",
"short-lists":"short-list",
"shorted":"short",
"shortenings":"shortening",
"shorting":"short",
"shortlisted":"shortlist",
"shortlisting":"shortlist",
"shortlists":"shortlist",
"shot":"shoot",
"shoulder-bags":"shoulder-bag",
"shoulder-blades":"shoulder-blade",
"shoulder-straps":"shoulder-strap",
"show-downs":"show-down",
"show-pieces":"show-piece",
"show-stoppers":"show-stopper",
"showgrounds":"showground",
"showplaces":"showplace",
"shrimpers":"shrimper",
"shrink-wrapped":"shrink-wrap",
"shrivelled":"shrivel",
"shrouded":"shroud",
"shucks":"shuck",
"shushes":"shush",
"shut-downs":"shut-down",
"sicced":"sic",
"siccing":"sic",
"sick-bays":"sick-bay",
"sick-beds":"sick-bed",
"sickbags":"sickbag",
"sickbeds":"sickbed",
"sickened":"sicken",
"sickrooms":"sickroom",
"side-cars":"side-car",
"side-dishes":"side-dish",
"side-effects":"side-effect",
"side-issues":"side-issue",
"side-roads":"side-road",
"side-shows":"side-show",
"side-slipped":"side-slip",
"side-slipping":"side-slip",
"side-slips":"side-slip",
"side-steps":"side-step",
"side-streets":"side-street",
"side-tracked":"side-track",
"side-tracking":"side-track",
"side-tracks":"side-track",
"side-views":"side-view",
"side-wheelers":"side-wheeler",
"sidearms":"sidearm",
"sidebars":"sidebar",
"sidecars":"sidecar",
"sided":"side",
"sidelined":"sideline",
"sidelining":"sideline",
"sideshows":"sideshow",
"sideswipes":"sideswipe",
"sifters":"sifter",
"sight-readers":"sight-reader",
"sight-reading":"sight-read",
"sightings":"sighting",
"signal-boxes":"signal-box",
"signalised":"signalise",
"signalises":"signalise",
"signalising":"signalise",
"signed":"sign",
"signposted":"signpost",
"signposting":"signpost",
"silhouetted":"silhouette",
"silicates":"silicate",
"silked":"silk",
"silking":"silk",
"siltier":"silty",
"siltiest":"silty",
"silvered":"silver",
"similes":"simile",
"simmers":"simmer",
"simperers":"simperer",
"simplified":"simplify",
"simulators":"simulator",
"simulcasts":"simulcast",
"sinecures":"sinecure",
"sing-songs":"sing-song",
"singa-longs":"singa-long",
"singalongs":"singalong",
"singer-songwriters":"singer-songwriter",
"single-deckers":"single-decker",
"singsongs":"singsong",
"singularised":"singularise",
"singularises":"singularise",
"singularising":"singularise",
"singularizes":"singularize",
"sinologists":"sinologist",
"sirloins":"sirloin",
"sit-ups":"sit-up",
"sitars":"sitar",
"sitcoms":"sitcom",
"situated":"situate",
"six-footers":"six-footer",
"six-packs":"six-pack",
"sixth-formers":"sixth-former",
"sixth-forms":"sixth-form",
"sizzles":"sizzle",
"skateboarders":"skateboarder",
"skateboards":"skateboard",
"skating-rinks":"skating-rink",
"skedaddles":"skedaddle",
"sketch-books":"sketch-book",
"sketch-maps":"sketch-map",
"sketch-pads":"sketch-pad",
"ski-bobs":"ski-bob",
"ski-jumps":"ski-jump",
"ski-lifts":"ski-lift",
"ski-planes":"ski-plane",
"skiers":"skier",
"skiffs":"skiff",
"skinheads":"skinhead",
"skinny-dipping":"skinny-dip",
"skirmishers":"skirmisher",
"skirting-boards":"skirting-board",
"skirtings":"skirting",
"skits":"skit",
"skittled":"skittle",
"skittling":"skittle",
"skivers":"skiver",
"skives":"skive",
"skivvied":"skivvy",
"skivvying":"skivvy",
"skull-caps":"skull-cap",
"sky-divers":"sky-diver",
"sky-rocketed":"sky-rocket",
"sky-rocketing":"sky-rocket",
"sky-rockets":"sky-rocket",
"skycaps":"skycap",
"skyjackers":"skyjacker",
"skyjacks":"skyjack",
"slackening":"slacken",
"slag-heaps":"slag-heap",
"slagheaps":"slagheap",
"slaloms":"slalom",
"slam-dunked":"slam-dunk",
"slam-dunking":"slam-dunk",
"slam-dunks":"slam-dunk",
"slappers":"slapper",
"slathered":"slather",
"slathering":"slather",
"slathers":"slather",
"slaughtered":"slaughter",
"slave-drivers":"slave-driver",
"sledge-hammered":"sledge-hammer",
"sledge-hammering":"sledge-hammer",
"sledge-hammers":"sledge-hammer",
"sleeks":"sleek",
"sleep-overs":"sleep-over",
"sleeping-bags":"sleeping-bag",
"sleeping-cars":"sleeping-car",
"sleeping-pills":"sleeping-pill",
"sleepovers":"sleepover",
"sleepyheads":"sleepyhead",
"sleets":"sleet",
"slenderer":"slender",
"slenderest":"slender",
"sleuthed":"sleuth",
"sleuthing":"sleuth",
"sliced":"slice",
"slicers":"slicer",
"slicker":"slick",
"slide-rules":"slide-rule",
"slimmers":"slimmer",
"slims":"slim",
"slingers":"slinger",
"slip-ons":"slip-on",
"slip-roads":"slip-road",
"slip-ups":"slip-up",
"slipknots":"slipknot",
"slippages":"slippage",
"slitters":"slitter",
"slobbed":"slob",
"slobbing":"slob",
"sloganeering":"sloganeer",
"sloganeers":"sloganeer",
"slot-machines":"slot-machine",
"slotted":"slot",
"slow-downs":"slow-down",
"slows":"slow",
"slubbed":"slub",
"slubbing":"slub",
"sluglines":"slugline",
"slurps":"slurp",
"smackers":"smacker",
"small-timers":"small-timer",
"smallholders":"smallholder",
"smallholdings":"smallholding",
"smartens":"smarten",
"smelting":"smelt",
"smitten":"smite",
"smocked":"smock",
"smoggier":"smoggy",
"smoggiest":"smoggy",
"smoke-bombs":"smoke-bomb",
"smoke-grenades":"smoke-grenade",
"smoke-stacks":"smoke-stack",
"smokescreens":"smokescreen",
"smoking-jackets":"smoking-jacket",
"smoking-rooms":"smoking-room",
"smooth-talked":"smooth-talk",
"smooth-talking":"smooth-talk",
"smooth-talks":"smooth-talk",
"smoothened":"smoothen",
"smoothening":"smoothen",
"smoothens":"smoothen",
"smooths":"smooth",
"smothered":"smother",
"smutchier":"smutchy",
"smutchiest":"smutchy",
"snack-bars":"snack-bar",
"snake-bites":"snake-bite",
"snake-charmers":"snake-charmer",
"snakebites":"snakebite",
"snapdragons":"snapdragon",
"snarfed":"snarf",
"snarfing":"snarf",
"snarfs":"snarf",
"sniffers":"sniffer",
"sniggered":"snigger",
"sniggering":"snigger",
"snivelling":"snivel",
"snobbier":"snobby",
"snobbiest":"snobby",
"snogging":"snog",
"snookered":"snooker",
"snookering":"snooker",
"snookers":"snooker",
"snorkeled":"snorkel",
"snorkeling":"snorkel",
"snorkelled":"snorkel",
"snorkelling":"snorkel",
"snow-drifts":"snow-drift",
"snow-fields":"snow-field",
"snowboards":"snowboard",
"snowdrifts":"snowdrift",
"snowfields":"snowfield",
"snowmobiles":"snowmobile",
"snuff-boxes":"snuff-box",
"snuffboxes":"snuffbox",
"snuffers":"snuffer",
"soap-bubbles":"soap-bubble",
"sob-stories":"sob-story",
"sobering":"sober",
"sobers":"sober",
"socialised":"socialise",
"socialises":"socialise",
"socialising":"socialise",
"socialites":"socialite",
"sociologists":"sociologist",
"soda-fountains":"soda-fountain",
"soda-waters":"soda-water",
"soddens":"sodden",
"soft-soaps":"soft-soap",
"softcovers":"softcover",
"softeners":"softener",
"soirees":"soiree",
"sojourners":"sojourner",
"soldering-irons":"soldering-iron",
"solders":"solder",
"solemnised":"solemnise",
"solemnises":"solemnise",
"solemnising":"solemnise",
"solemnizes":"solemnize",
"soliciting":"solicit",
"soliloquised":"soliloquise",
"soliloquises":"soliloquise",
"soliloquising":"soliloquise",
"soloists":"soloist",
"solstices":"solstice",
"solvated":"solvate",
"solvates":"solvate",
"solvating":"solvate",
"solvers":"solver",
"somniloquists":"somniloquist",
"song-books":"song-book",
"song-writers":"song-writer",
"songbooks":"songbook",
"songstresses":"songstress",
"sonograms":"sonogram",
"sons-of-a-bitches":"son-of-a-bitch",
"soothsaying":"soothsay",
"sorceresses":"sorceress",
"soreheads":"sorehead",
"sorters":"sorter",
"sortied":"sortie",
"sortieing":"sortie",
"sou'westers":"sou'wester",
"souffles":"souffle",
"souks":"souk",
"soulmates":"soulmate",
"sound-proofed":"sound-proof",
"sound-proofing":"sound-proof",
"sound-proofs":"sound-proof",
"sounders":"sounder",
"sounding-boards":"sounding-board",
"soundproofing":"soundproof",
"soundproofs":"soundproof",
"soundtracks":"soundtrack",
"soundwaves":"soundwave",
"soup-kitchens":"soup-kitchen",
"soup-plates":"soup-plate",
"sourced":"source",
"sourcing":"source",
"soused":"souse",
"southerners":"southerner",
"southernisms":"southernism",
"sovietised":"sovietise",
"sovietises":"sovietise",
"sovietising":"sovietise",
"sovietized":"sovietize",
"sovietizes":"sovietize",
"sovietizing":"sovietize",
"sowers":"sower",
"space-bars":"space-bar",
"spaceier":"spacey",
"spaceiest":"spacey",
"spacers":"spacer",
"spacesuits":"spacesuit",
"spacewalked":"spacewalk",
"spacewalkers":"spacewalker",
"spacewalking":"spacewalk",
"spacewalks":"spacewalk",
"spackled":"spackle",
"spackling":"spackle",
"spammed":"spam",
"spamming":"spam",
"spams":"spam",
"spandrels":"spandrel",
"spangled":"spangle",
"spaniels":"spaniel",
"spare-parts":"spare-part",
"spareribs":"sparerib",
"sparges":"sparge",
"spark-plugs":"spark-plug",
"sparking-plugs":"sparking-plug",
"sparklers":"sparkler",
"sparring-partners":"sparring-partner",
"spastics":"spastic",
"spatchcocks":"spatchcock",
"spatted":"spat",
"spatting":"spat",
"speak-easies":"speak-easy",
"speakerphones":"speakerphone",
"specialised":"specialise",
"specialises":"specialise",
"specials":"special",
"spectates":"spectate",
"speech-days":"speech-day",
"speechwriters":"speechwriter",
"speed-indicators":"speed-indicator",
"speedboats":"speedboat",
"speedways":"speedway",
"spell-checked":"spell-check",
"spell-checking":"spell-check",
"spell-checks":"spell-check",
"spellbinders":"spellbinder",
"spellbinding":"spellbind",
"spellbound":"spellbind",
"spelunked":"spelunk",
"spelunking":"spelunk",
"spelunks":"spelunk",
"sphagna":"sphagnum",
"spherules":"spherule",
"sphynxes":"sphinx",
"spider-men":"spider-man",
"spillovers":"spillover",
"spine-chillers":"spine-chiller",
"spiralling":"spiral",
"spirit-levels":"spirit-level",
"spitballs":"spitball",
"spivs":"spiv",
"splashdowns":"splashdown",
"splats":"splat",
"splatted":"splat",
"splatting":"splat",
"splicers":"splicer",
"spliffs":"spliff",
"splined":"spline",
"splining":"spline",
"spoilt":"spoil",
"spokespeople":"spokesperson",
"sponge-bags":"sponge-bag",
"sponge-cakes":"sponge-cake",
"sponge-puddings":"sponge-pudding",
"spooked":"spook",
"spooking":"spook",
"spoonbills":"spoonbill",
"spoonerisms":"spoonerism",
"sporrans":"sporran",
"sports-editors":"sports-editor",
"sportscasts":"sportscast",
"sportswriters":"sportswriter",
"sporulates":"sporulate",
"spot-checks":"spot-check",
"spot-welded":"spot-weld",
"spot-welding":"spot-weld",
"spot-welds":"spot-weld",
"spotlit":"spotlight",
"spouted":"spout",
"sprained":"sprain",
"sprawled":"sprawl",
"spray-guns":"spray-gun",
"spread-eagled":"spread-eagle",
"spreadsheets":"spreadsheet",
"spring-cleaned":"spring-clean",
"spring-cleaning":"spring-clean",
"spring-cleans":"spring-clean",
"spring-tides":"spring-tide",
"springboards":"springboard",
"sprinklers":"sprinkler",
"sprinters":"sprinter",
"sprints":"sprint",
"spritzed":"spritz",
"spritzers":"spritzer",
"spritzes":"spritz",
"spritzing":"spritz",
"sprogs":"sprog",
"spurred":"spur",
"spymasters":"spymaster",
"squaddies":"squaddie",
"squadrons":"squadron",
"squashed":"squash",
"squatter":"squat",
"squeezers":"squeezer",
"squinched":"squinch",
"squishier":"squishy",
"squishiest":"squishy",
"stabbers":"stabber",
"stabilised":"stabilise",
"stabilisers":"stabiliser",
"stabilises":"stabilise",
"stabilising":"stabilise",
"stabilizers":"stabilizer",
"stabilizes":"stabilize",
"stable-boys":"stable-boy",
"stable-lads":"stable-lad",
"stacked":"stack",
"stackers":"stacker",
"staffed":"staff",
"stag-parties":"stag-party",
"stage-coaches":"stage-coach",
"stage-managers":"stage-manager",
"stage-manages":"stage-manage",
"stage-whispers":"stage-whisper",
"staggered":"stagger",
"stainers":"stainer",
"stairwells":"stairwell",
"stake-outs":"stake-out",
"stakeholders":"stakeholder",
"stakeouts":"stakeout",
"stalactites":"stalactite",
"stalagmites":"stalagmite",
"stales":"stale",
"stalkers":"stalker",
"stall-fed":"stall-feed",
"stall-holders":"stall-holder",
"stamp-collectors":"stamp-collector",
"stamped":"stamp",
"stamping-grounds":"stamping-ground",
"stances":"stance",
"stanches":"stanch",
"stanchions":"stanchion",
"stand-bys":"stand-by",
"stand-offs":"stand-off",
"stand-outs":"stand-out",
"standardised":"standardise",
"standardises":"standardise",
"standardising":"standardise",
"standees":"standee",
"standouts":"standout",
"standpipes":"standpipe",
"star-gazers":"star-gazer",
"starched":"starch",
"starlings":"starling",
"start-ups":"start-up",
"starting-blocks":"starting-block",
"starting-gates":"starting-gate",
"statehouses":"statehouse",
"statemented":"statement",
"statementing":"statement",
"statistics":"statistic",
"staunches":"staunch",
"stayers":"stayer",
"steak-houses":"steak-house",
"steepens":"steepen",
"steeplechasers":"steeplechaser",
"steeplechases":"steeplechase",
"steeplejacks":"steeplejack",
"steeps":"steep",
"steerers":"steerer",
"stemmed":"stem",
"step-brothers":"step-brother",
"step-children":"step-child",
"step-daughters":"step-daughter",
"step-fathers":"step-father",
"step-mothers":"step-mother",
"step-parents":"step-parent",
"step-sisters":"step-sister",
"step-sons":"step-son",
"steppes":"steppe",
"stepping-stones":"stepping-stone",
"stept":"step",
"stereotyping":"stereotype",
"sterilised":"sterilise",
"sterilisers":"steriliser",
"sterilises":"sterilise",
"sterilising":"sterilise",
"stethoscopes":"stethoscope",
"sticking-plasters":"sticking-plaster",
"sticklers":"stickler",
"stickles":"stickle",
"stickpins":"stickpin",
"stiffed":"stiff",
"stiffer":"stiff",
"stiffest":"stiff",
"stiffing":"stiff",
"stigmatised":"stigmatise",
"stigmatises":"stigmatise",
"stigmatising":"stigmatise",
"stigmatized":"stigmatize",
"stillier":"stilly",
"stilliest":"stilly",
"stilted":"stilt",
"stilting":"stilt",
"stimulators":"stimulator",
"stingrays":"stingray",
"stinkier":"stinky",
"stinkiest":"stinky",
"stipends":"stipend",
"stippled":"stipple",
"stippling":"stipple",
"stir-fried":"stir-fry",
"stir-fries":"stir-fry",
"stir-frying":"stir-fry",
"stoats":"stoat",
"stock-cars":"stock-car",
"stock-cubes":"stock-cube",
"stockists":"stockist",
"stockjobbers":"stockjobber",
"stockpots":"stockpot",
"stocktaken":"stocktake",
"stocktakes":"stocktake",
"stocktaking":"stocktake",
"stocktook":"stocktake",
"stokes":"stoke",
"stomach-aches":"stomach-ache",
"stomped":"stomp",
"stomping":"stomp",
"stomps":"stomp",
"stoners":"stoner",
"stonewalling":"stonewall",
"stonewalls":"stonewall",
"stooped":"stoop",
"stop-lights":"stop-light",
"stop-watches":"stop-watch",
"stoped":"stope",
"stopes":"stope",
"stoping":"stope",
"storm-clouds":"storm-cloud",
"storm-doors":"storm-door",
"storm-lanterns":"storm-lantern",
"storm-troopers":"storm-trooper",
"storm-windows":"storm-window",
"stormclouds":"stormcloud",
"stormtroopers":"stormtrooper",
"story-books":"story-book",
"story-lines":"story-line",
"story-tellers":"story-teller",
"storybooks":"storybook",
"stouts":"stout",
"stowaways":"stowaway",
"stragglers":"straggler",
"straight-armed":"straight-arm",
"straight-arming":"straight-arm",
"straight-arms":"straight-arm",
"straighteners":"straightener",
"strainers":"strainer",
"strangled":"strangle",
"strapped":"strap",
"stratified":"stratify",
"straw-hats":"straw-hat",
"strawhats":"strawhat",
"streamlines":"streamline",
"streams-of-consciousness":"stream-of-consciousness",
"stressors":"stressor",
"stretchered":"stretcher",
"stretchering":"stretcher",
"strewn":"strew",
"striated":"striate",
"striates":"striate",
"striating":"striate",
"stricken":"strike",
"strickled":"strickle",
"strickles":"strickle",
"strickling":"strickle",
"stridulated":"stridulate",
"stridulates":"stridulate",
"stridulating":"stridulate",
"strikeouts":"strikeout",
"stringers":"stringer",
"strip-mined":"strip-mine",
"strip-mines":"strip-mine",
"strip-mining":"strip-mine",
"strip-searched":"strip-search",
"strip-searches":"strip-search",
"strip-searching":"strip-search",
"strip-teases":"strip-tease",
"strobes":"strobe",
"strong-boxes":"strong-box",
"strongrooms":"strongroom",
"structuralists":"structuralist",
"strudels":"strudel",
"stuccoed":"stucco",
"stuck":"stick",
"stud-books":"stud-book",
"studbooks":"studbook",
"stultifying":"stultify",
"stumbling-blocks":"stumbling-block",
"stumped":"stump",
"stung":"sting",
"stunned":"stun",
"stunted":"stunt",
"stupefied":"stupefy",
"stupefying":"stupefy",
"stuttering":"stutter",
"styled":"style",
"stylized":"stylize",
"sub-continents":"sub-continent",
"sub-groups":"sub-group",
"sub-sections":"sub-section",
"sub-stations":"sub-station",
"sub-totals":"sub-total",
"subalterns":"subaltern",
"subchiefs":"subchief",
"subcommittees":"subcommittee",
"subcompacts":"subcompact",
"subcontinents":"subcontinent",
"subcontractors":"subcontractor",
"subcultures":"subculture",
"subfigures":"subfigure",
"subgroups":"subgroup",
"sublieutenants":"sublieutenant",
"sublimated":"sublimate",
"sublimates":"sublimate",
"sublimating":"sublimate",
"sublimes":"sublime",
"submariners":"submariner",
"submersed":"submerse",
"submerses":"submerse",
"subordinated":"subordinate",
"suborns":"suborn",
"subparts":"subpart",
"subplots":"subplot",
"subsets":"subset",
"subsidised":"subsidise",
"subsidises":"subsidise",
"subsidising":"subsidise",
"subsidized":"subsidize",
"subsidizes":"subsidize",
"subsidizing":"subsidize",
"subskills":"subskill",
"subsoiled":"subsoil",
"subsoiling":"subsoil",
"subspaces":"subspace",
"substations":"substation",
"subsystems":"subsystem",
"subtests":"subtest",
"subtexts":"subtext",
"subtitled":"subtitle",
"subtypes":"subtype",
"suburbanised":"suburbanise",
"suburbanises":"suburbanise",
"suburbanising":"suburbanise",
"suburbanized":"suburbanize",
"suburbanizes":"suburbanize",
"suburbanizing":"suburbanize",
"subventions":"subvention",
"succulents":"succulent",
"suctioned":"suction",
"suctioning":"suction",
"suffocated":"suffocate",
"sugar-daddies":"sugar-daddy",
"sugar-lumps":"sugar-lump",
"suited":"suit",
"suitings":"suiting",
"sulfonylureas":"sulfonylurea",
"sulfureted":"sulfuret",
"sulfureting":"sulfuret",
"sulfurets":"sulfuret",
"sulfuretted":"sulfuret",
"sulfuretting":"sulfuret",
"sulfurized":"sulfurize",
"sulfurizes":"sulfurize",
"sulfurizing":"sulfurize",
"sulphated":"sulphate",
"sulphating":"sulphate",
"summarised":"summarise",
"summarises":"summarise",
"summarising":"summarise",
"summated":"summate",
"summates":"summate",
"summating":"summate",
"summer-houses":"summer-house",
"summings-up":"summing-up",
"sun-hats":"sun-hat",
"sun-lamps":"sun-lamp",
"sun-roofs":"sun-roof",
"sun-tans":"sun-tan",
"sun-worshippers":"sun-worshipper",
"sunbathed":"sunbathe",
"sunbathers":"sunbather",
"sunbathes":"sunbathe",
"sunbathing":"sunbathe",
"sunblocks":"sunblock",
"sunbursts":"sunburst",
"sunders":"sunder",
"sundials":"sundial",
"sundresses":"sundress",
"sunk":"sink",
"sunscreens":"sunscreen",
"super-egos":"super-ego",
"superannuated":"superannuate",
"superannuates":"superannuate",
"superceded":"supercede",
"supercedes":"supercede",
"superceding":"supercede",
"superchargers":"supercharger",
"supercomputers":"supercomputer",
"superconductors":"superconductor",
"supergiants":"supergiant",
"supergrasses":"supergrass",
"supermodels":"supermodel",
"superposes":"superpose",
"superstars":"superstar",
"superstates":"superstate",
"superstores":"superstore",
"superstructures":"superstructure",
"supertankers":"supertanker",
"supervenes":"supervene",
"supplicates":"supplicate",
"supported":"support",
"supposed":"suppose",
"suppressants":"suppressant",
"suppressed":"suppress",
"supremacists":"supremacist",
"surfboards":"surfboard",
"surgicenters":"surgicenter",
"surplices":"surplice",
"surprised":"surprise",
"surrealists":"surrealist",
"surreys":"surrey",
"surrogated":"surrogate",
"surrogating":"surrogate",
"surveilled":"surveil",
"surveilling":"surveil",
"survivalists":"survivalist",
"susceptors":"susceptor",
"suspected":"suspect",
"suspended":"suspend",
"sussed":"sus",
"susses":"sus",
"sussing":"sus",
"sustained":"sustain",
"susurrated":"susurrate",
"susurrates":"susurrate",
"susurrating":"susurrate",
"swamplands":"swampland",
"swatches":"swatch",
"swear-words":"swear-word",
"sweat-bands":"sweat-band",
"sweat-glands":"sweat-gland",
"sweat-shirts":"sweat-shirt",
"sweatbands":"sweatband",
"sweated":"sweat",
"sweatshirts":"sweatshirt",
"sweatsuits":"sweatsuit",
"sweepstakes":"sweepstake",
"sweetmeats":"sweetmeat",
"swelled":"swell",
"swellen":"swell",
"swelters":"swelter",
"swines":"swine",
"swingeing":"swinge",
"swingers":"swinger",
"swingier":"swingy",
"swingiest":"swingy",
"swishier":"swishy",
"swishiest":"swishy",
"switch-men":"switch-man",
"switchers":"switcher",
"swobbed":"swob",
"swobbing":"swob",
"swooshes":"swoosh",
"symbolised":"symbolise",
"symbolises":"symbolise",
"symbolising":"symbolise",
"symbolists":"symbolist",
"sympathised":"sympathise",
"sympathisers":"sympathiser",
"sympathises":"sympathise",
"sympathising":"sympathise",
"sympathomimetics":"sympathomimetic",
"synced":"sync",
"synces":"sync",
"synched":"synch",
"synches":"synch",
"synching":"synch",
"synchronised":"synchronise",
"synchronisers":"synchroniser",
"synchronises":"synchronise",
"synchronising":"synchronise",
"synchronizers":"synchronizer",
"syncing":"sync",
"syncopated":"syncopate",
"syncopates":"syncopate",
"syndicators":"syndicator",
"syndromes":"syndrome",
"synods":"synod",
"synthesised":"synthesise",
"synthesisers":"synthesiser",
"synthesising":"synthesise",
"synthesizers":"synthesizer",
"systematised":"systematise",
"systematises":"systematise",
"systematising":"systematise",
"tabards":"tabard",
"table-cloths":"table-cloth",
"table-tops":"table-top",
"tabued":"tabu",
"tabuing":"tabu",
"tachographs":"tachograph",
"tacklers":"tackler",
"tacticians":"tactician",
"taggers":"tagger",
"taglines":"tagline",
"tail-lamps":"tail-lamp",
"tail-lights":"tail-light",
"tailbacks":"tailback",
"tailed":"tail",
"tailgating":"tailgate",
"tailor-made":"tailor-make",
"tailor-makes":"tailor-make",
"tailor-making":"tailor-make",
"tailored":"tailor",
"tailpieces":"tailpiece",
"tailpipes":"tailpipe",
"tailwinds":"tailwind",
"take-offs":"take-off",
"takeaways":"takeaway",
"taken":"take",
"takers":"taker",
"talent-scouts":"talent-scout",
"talent-spotters":"talent-spotter",
"talk-shows":"talk-show",
"talking-points":"talking-point",
"tallywomen":"tallywoman",
"tamarisks":"tamarisk",
"tambourines":"tambourine",
"tamer":"tame",
"tamers":"tamer",
"tames":"tame",
"tampons":"tampon",
"tankards":"tankard",
"tanked":"tank",
"tantalised":"tantalise",
"tantalises":"tantalise",
"tantalising":"tantalise",
"tap-danced":"tap-dance",
"tap-dancers":"tap-dancer",
"tap-dances":"tap-dance",
"tap-dancing":"tap-dance",
"tape-measures":"tape-measure",
"tape-recorded":"tape-record",
"tape-recorders":"tape-recorder",
"tape-recording":"tape-record",
"tape-recordings":"tape-recording",
"tape-records":"tape-record",
"tappers":"tapper",
"tappets":"tappet",
"targeted":"target",
"tarmacked":"tarmac",
"tarmacking":"tarmac",
"tarnished":"tarnish",
"tarns":"tarn",
"tarred":"tar",
"tarted":"tart",
"tarting":"tart",
"taskforces":"taskforce",
"taskmasters":"taskmaster",
"tasselled":"tassel",
"tattle-tales":"tattle-tale",
"tattlers":"tattler",
"tattooed":"tattoo",
"taxonomies":"taxonomy",
"taxonomists":"taxonomist",
"tea-bags":"tea-bag",
"tea-breaks":"tea-break",
"tea-caddies":"tea-caddy",
"tea-chests":"tea-chest",
"tea-cloths":"tea-cloth",
"tea-cosies":"tea-cosy",
"tea-cups":"tea-cup",
"tea-leaves":"tea-leaf",
"tea-parties":"tea-party",
"tea-rooms":"tea-room",
"tea-services":"tea-service",
"tea-sets":"tea-set",
"tea-shops":"tea-shop",
"tea-towels":"tea-towel",
"tea-trays":"tea-tray",
"tea-trolleys":"tea-trolley",
"tea-urns":"tea-urn",
"tea-wagons":"tea-wagon",
"teabags":"teabag",
"teacakes":"teacake",
"teakettles":"teakettle",
"team-mates":"team-mate",
"tear-jerkers":"tear-jerker",
"tearaways":"tearaway",
"tearjerkers":"tearjerker",
"teazles":"teazle",
"techies":"techie",
"technocrats":"technocrat",
"technologized":"technologize",
"technologizes":"technologize",
"technologizing":"technologize",
"technophobes":"technophobe",
"techs":"tech",
"teddy-bears":"teddy-bear",
"teensy-weensier":"teensy-weensy",
"teensy-weensiest":"teensy-weensy",
"teeny-weenier":"teeny-weeny",
"teeny-weeniest":"teeny-weeny",
"teethes":"teethe",
"teething":"teethe",
"tektites":"tektite",
"telecommunications":"telecommunication",
"telecommuters":"telecommuter",
"teleconferenced":"teleconference",
"teleconferencing":"teleconference",
"telemarketers":"telemarketer",
"telemeters":"telemeter",
"teleprompters":"teleprompter",
"telesystems":"telesystem",
"teletypes":"teletype",
"televangelists":"televangelist",
"televised":"televise",
"teleworkers":"teleworker",
"telexed":"telex",
"telexing":"telex",
"temping":"temp",
"temporised":"temporise",
"temporises":"temporise",
"temporising":"temporise",
"temporizes":"temporize",
"temporizing":"temporize",
"tenantries":"tenantry",
"tenderised":"tenderise",
"tenderisers":"tenderiser",
"tenderises":"tenderise",
"tenderising":"tenderise",
"tenderizers":"tenderizer",
"tented":"tent",
"tenterhooks":"tenterhook",
"tequilas":"tequila",
"teraflops":"teraflop",
"teratologies":"teratology",
"terns":"tern",
"terpenes":"terpene",
"terraced":"terrace",
"terracing":"terrace",
"terrains":"terrain",
"terrapins":"terrapin",
"territorialised":"territorialise",
"territorialises":"territorialise",
"territorialising":"territorialise",
"territorializes":"territorialize",
"terrorised":"terrorise",
"terrorises":"terrorise",
"terrorising":"terrorise",
"terrorists":"terrorist",
"terzetti":"terzetto",
"tessellated":"tessellate",
"tessellates":"tessellate",
"test-drives":"test-drive",
"test-marketed":"test-market",
"test-marketing":"test-market",
"test-markets":"test-market",
"tetrahalides":"tetrahalide",
"tetris":"tetri",
"texted":"text",
"texting":"text",
"textured":"texture",
"texturing":"texture",
"thank-yous":"thank-you",
"thanks":"thank",
"thars":"thar",
"thatching":"thatch",
"theatre-goers":"theatre-goer",
"theologised":"theologise",
"theologises":"theologise",
"theologising":"theologise",
"theologizes":"theologize",
"theorised":"theorise",
"theorises":"theorise",
"theorising":"theorise",
"thermoforms":"thermoform",
"thermometers":"thermometer",
"therms":"therm",
"thickens":"thicken",
"thieving":"thieve",
"thigh-bones":"thigh-bone",
"thills":"thill",
"thirtysomethings":"thirtysomething",
"threatened":"threaten",
"threepennies":"threepenny",
"thrilled":"thrill",
"thrillers":"thriller",
"throes":"throe",
"thrombosed":"thrombose",
"thrombosing":"thrombose",
"thronged":"throng",
"throw-ins":"throw-in",
"throwers":"thrower",
"throwsters":"throwster",
"thumb-nails":"thumb-nail",
"thumbnails":"thumbnail",
"thumbprints":"thumbprint",
"thumbscrews":"thumbscrew",
"tickings-off":"ticking-off",
"tickled":"tickle",
"tiddlier":"tiddly",
"tiddliest":"tiddly",
"tide-marks":"tide-mark",
"tidelands":"tideland",
"tie-breakers":"tie-breaker",
"tie-breaks":"tie-break",
"tie-dyes":"tie-dye",
"tie-pins":"tie-pin",
"tied":"tie",
"tiered":"tier",
"tightropes":"tightrope",
"tigresses":"tigress",
"tilers":"tiler",
"timbering":"timber",
"time-keepers":"time-keeper",
"time-limits":"time-limit",
"time-scales":"time-scale",
"time-servers":"time-server",
"time-shares":"time-share",
"time-switches":"time-switch",
"time-zones":"time-zone",
"timelines":"timeline",
"timeouts":"timeout",
"timers":"timer",
"times":"time",
"timeservers":"timeserver",
"timetabled":"timetable",
"timetabling":"timetable",
"tin-openers":"tin-opener",
"tinder-boxes":"tinder-box",
"tinderboxes":"tinderbox",
"tines":"tine",
"tinkling":"tinkle",
"tinted":"tint",
"tipoffs":"tipoff",
"tiptops":"tiptop",
"tired":"tire",
"tithing":"tithe",
"title-roles":"title-role",
"titled":"title",
"toasters":"toaster",
"toastmasters":"toastmaster",
"toeholds":"toehold",
"toenails":"toenail",
"toffee-apples":"toffee-apple",
"toilet-rolls":"toilet-roll",
"toilet-trained":"toilet-train",
"toilet-training":"toilet-train",
"toilet-trains":"toilet-train",
"toitoes":"toitoi",
"toked":"toke",
"tokened":"token",
"tokening":"token",
"tokes":"toke",
"toking":"toke",
"tollways":"tollway",
"tomes":"tome",
"tongs":"tong",
"tongue-lashings":"tongue-lashing",
"tongue-twisters":"tongue-twister",
"tons":"ton",
"tonsured":"tonsure",
"tonsures":"tonsure",
"toothpastes":"toothpaste",
"tootles":"tootle",
"top-dressed":"top-dress",
"top-dresses":"top-dress",
"top-dressing":"top-dress",
"top-dressings":"top-dressing",
"top-ups":"top-up",
"topknots":"topknot",
"topographers":"topographer",
"topping":"top",
"tops":"top",
"topsides":"topside",
"torched":"torch",
"torching":"torch",
"torquers":"torquer",
"tortured":"torture",
"torturers":"torturer",
"tossers":"tosser",
"toucans":"toucan",
"touch-types":"touch-type",
"touchdowns":"touchdown",
"toughed":"tough",
"toughens":"toughen",
"toughing":"tough",
"touring":"tour",
"towing":"tow",
"townhouses":"townhouse",
"toxicologists":"toxicologist",
"toxins":"toxin",
"toymakers":"toymaker",
"trackballs":"trackball",
"tracked":"track",
"trackers":"tracker",
"tractor-trailers":"tractor-trailer",
"trade-ins":"trade-in",
"trade-offs":"trade-off",
"traded":"trade",
"tradeoffs":"tradeoff",
"traditionalized":"traditionalize",
"traditionalizes":"traditionalize",
"traditionalizing":"traditionalize",
"traffic-lights":"traffic-light",
"tragedians":"tragedian",
"trailblazers":"trailblazer",
"trailered":"trailer",
"trailering":"trailer",
"trained":"train",
"trainees":"trainee",
"traineeships":"traineeship",
"training-colleges":"training-college",
"trampolines":"trampoline",
"tranches":"tranche",
"tranquilised":"tranquilise",
"tranquilisers":"tranquiliser",
"tranquilises":"tranquilise",
"tranquilising":"tranquilise",
"tranquillised":"tranquillise",
"tranquillisers":"tranquilliser",
"tranquillises":"tranquillise",
"tranquillising":"tranquillise",
"transacts":"transact",
"transalpines":"transalpine",
"transducers":"transducer",
"transepts":"transept",
"transferors":"transferor",
"transistorised":"transistorise",
"transistorises":"transistorise",
"transistorising":"transistorise",
"transistorized":"transistorize",
"transistorizes":"transistorize",
"transliterations":"transliteration",
"translocates":"translocate",
"translocations":"translocation",
"transmigrates":"transmigrate",
"transmitted":"transmit",
"transponders":"transponder",
"transsexuals":"transsexual",
"transubstantiates":"transubstantiate",
"trapdoors":"trapdoor",
"trapezes":"trapeze",
"trapped":"trap",
"trashed":"trash",
"traumatised":"traumatise",
"traumatises":"traumatise",
"traumatising":"traumatise",
"traumatized":"traumatize",
"treasured":"treasure",
"trebling":"treble",
"tree-tops":"tree-top",
"treehouses":"treehouse",
"trendies":"trendy",
"trendsetters":"trendsetter",
"trestles":"trestle",
"triaged":"triage",
"triages":"triage",
"triaging":"triage",
"trialled":"trial",
"trialling":"trial",
"triangulates":"triangulate",
"triceratopses":"triceratops",
"triers":"trier",
"trigged":"trig",
"triggered":"trigger",
"trigging":"trig",
"triglycerides":"triglyceride",
"trigrams":"trigram",
"trijets":"trijet",
"trimarans":"trimaran",
"triptychs":"triptych",
"trivets":"trivet",
"trivialised":"trivialise",
"trivialises":"trivialise",
"trivialising":"trivialise",
"trivializes":"trivialize",
"trochees":"trochee",
"trollied":"trolly",
"trollies":"trolly",
"trollying":"trolly",
"trombones":"trombone",
"troopships":"troopship",
"trouble-makers":"trouble-maker",
"trouble-shooters":"trouble-shooter",
"trouble-shooting":"trouble-shoot",
"trouble-shoots":"trouble-shoot",
"trouble-shot":"trouble-shoot",
"trouble-spots":"trouble-spot",
"troubled":"trouble",
"troubleshooting":"troubleshoot",
"troubleshoots":"troubleshoot",
"troubleshot":"troubleshoot",
"trousered":"trouser",
"trousering":"trouser",
"truanting":"truant",
"truckloads":"truckload",
"tsarists":"tsarist",
"tsked":"tsk",
"tsking":"tsk",
"tsks":"tsk",
"tub-thumpers":"tub-thumper",
"tubules":"tubule",
"tugs-of-war":"tug-of-war",
"tumble-dryers":"tumble-dryer",
"tupped":"tup",
"tupping":"tup",
"turbines":"turbine",
"turbocharged":"turbocharge",
"turbochargers":"turbocharger",
"turbocharges":"turbocharge",
"turbocharging":"turbocharge",
"turbogenerators":"turbogenerator",
"turbos":"turbo",
"tureens":"tureen",
"turn-offs":"turn-off",
"turn-ups":"turn-up",
"turning":"turn",
"turnstiles":"turnstile",
"turtle-doves":"turtle-dove",
"turtlebacks":"turtleback",
"turtled":"turtle",
"turtling":"turtle",
"tutorials":"tutorial",
"twats":"twat",
"tweaking":"tweak",
"tweedled":"tweedle",
"tweedles":"tweedle",
"tweedling":"tweedle",
"tweeters":"tweeter",
"tweezed":"tweeze",
"tweezes":"tweeze",
"tweezing":"tweeze",
"twinjets":"twinjet",
"two-timers":"two-timer",
"two-times":"two-time",
"type-casting":"type-cast",
"type-casts":"type-cast",
"typecasting":"typecast",
"typescripts":"typescript",
"typologies":"typology",
"tyrannised":"tyrannise",
"tyrannises":"tyrannise",
"tyrannising":"tyrannise",
"uglies":"ugli",
"ukeleles":"ukelele",
"ulcerates":"ulcerate",
"ullaged":"ullage",
"ullages":"ullage",
"ullaging":"ullage",
"ultracentrifuges":"ultracentrifuge",
"umboes":"umbo",
"umped":"ump",
"umping":"ump",
"unbolts":"unbolt",
"unbridled":"unbridle",
"unbridles":"unbridle",
"unbridling":"unbridle",
"unbuckles":"unbuckle",
"unbundled":"unbundle",
"unbundles":"unbundle",
"unbundling":"unbundle",
"unbuttoned":"unbutton",
"unbuttons":"unbutton",
"uncapped":"uncap",
"unclad":"unclothe",
"unclenched":"unclench",
"unclenches":"unclench",
"unclenching":"unclench",
"unclothed":"unclothe",
"uncluttered":"unclutter",
"uncoer":"unco",
"uncoest":"unco",
"uncoils":"uncoil",
"uncorks":"uncork",
"uncouples":"uncouple",
"uncrossed":"uncross",
"uncurls":"uncurl",
"undeceives":"undeceive",
"under-secretaries":"under-secretary",
"underachievers":"underachiever",
"underachieves":"underachieve",
"underarms":"underarm",
"underbosses":"underboss",
"undercapitalised":"undercapitalise",
"undercapitalises":"undercapitalise",
"undercapitalising":"undercapitalise",
"undercapitalized":"undercapitalize",
"undercapitalizes":"undercapitalize",
"undercarriages":"undercarriage",
"undercharges":"undercharge",
"undercoated":"undercoat",
"undercoating":"undercoat",
"underdeveloped":"underdevelop",
"underdevelops":"underdevelop",
"underdressed":"underdress",
"underexposed":"underexpose",
"underexposes":"underexpose",
"underfunded":"underfund",
"underfunding":"underfund",
"underfunds":"underfund",
"undergarments":"undergarment",
"underlaid":"underlay",
"undermined":"undermine",
"underperformed":"underperform",
"underperformers":"underperformer",
"underperforming":"underperform",
"underperforms":"underperform",
"underpinnings":"underpinning",
"underpriced":"underprice",
"underprices":"underprice",
"underpricing":"underprice",
"underproduced":"underproduce",
"underproduces":"underproduce",
"underproducing":"underproduce",
"underquoted":"underquote",
"underquotes":"underquote",
"underquoting":"underquote",
"underrated":"underrate",
"underreacted":"underreact",
"underreacting":"underreact",
"underreacts":"underreact",
"underreported":"underreport",
"underreporting":"underreport",
"underreports":"underreport",
"undersealed":"underseal",
"undersealing":"underseal",
"underspending":"underspend",
"underspends":"underspend",
"underspent":"underspend",
"understanding":"understand",
"understated":"understate",
"understatements":"understatement",
"underused":"underuse",
"underuses":"underuse",
"underusing":"underuse",
"undervalued":"undervalue",
"underwhelmed":"underwhelm",
"underwhelming":"underwhelm",
"underwhelms":"underwhelm",
"underwritings":"underwriting",
"undrapes":"undrape",
"undraws":"undraw",
"unearths":"unearth",
"unfastens":"unfasten",
"unfitted":"unfit",
"ungues":"unguis",
"unhinged":"unhinge",
"unhitches":"unhitch",
"unhooks":"unhook",
"unhusked":"unhusk",
"unhusking":"unhusk",
"unhusks":"unhusk",
"unicorns":"unicorn",
"unificationists":"unificationist",
"unilateralists":"unilateralist",
"unionised":"unionise",
"unionises":"unionise",
"unionising":"unionise",
"united":"unite",
"unitholders":"unitholder",
"unitised":"unitise",
"unitises":"unitise",
"unitising":"unitise",
"unitized":"unitize",
"unitizes":"unitize",
"unitizing":"unitize",
"universalised":"universalise",
"universalises":"universalise",
"universalising":"universalise",
"universalizes":"universalize",
"unknots":"unknot",
"unknotted":"unknot",
"unknotting":"unknot",
"unlaced":"unlace",
"unladen":"unlade",
"unlades":"unlade",
"unlashed":"unlash",
"unlatches":"unlatch",
"unlaxed":"unlax",
"unlaxes":"unlax",
"unlaxing":"unlax",
"unlikelier":"unlikely",
"unlikeliest":"unlikely",
"unlived":"unlive",
"unlives":"unlive",
"unliving":"unlive",
"unlocks":"unlock",
"unnerved":"unnerve",
"unnerving":"unnerve",
"unreels":"unreel",
"unsanctified":"unsanctify",
"unsanctifies":"unsanctify",
"unsanctifying":"unsanctify",
"unscrews":"unscrew",
"unseals":"unseal",
"unseats":"unseat",
"unseeing":"unsee",
"unsexier":"unsexy",
"unsexiest":"unsexy",
"unshackles":"unshackle",
"unsheathes":"unsheathe",
"unstrained":"unstrain",
"unstraps":"unstrap",
"unstrung":"unstring",
"unstuffier":"unstuffy",
"unstuffiest":"unstuffy",
"untaught":"unteach",
"unthawed":"unthaw",
"unthawing":"unthaw",
"unthaws":"unthaw",
"unthinking":"unthink",
"unthought":"unthink",
"untouchables":"untouchable",
"untwisted":"untwist",
"untwists":"untwist",
"unweaves":"unweave",
"unwired":"unwire",
"unyokes":"unyoke",
"upchucked":"upchuck",
"upchucking":"upchuck",
"upchucks":"upchuck",
"updates":"update",
"upends":"upend",
"upgraded":"upgrade",
"upholders":"upholder",
"upholstered":"upholster",
"upholsters":"upholster",
"uplifted":"uplift",
"uploaded":"upload",
"uploading":"upload",
"uploads":"upload",
"upperclassmen":"upperclassman",
"upraised":"upraise",
"uprising":"uprise",
"upscaled":"upscale",
"upscales":"upscale",
"upscaling":"upscale",
"upsetting":"upset",
"upstages":"upstage",
"upstarted":"upstart",
"upstarting":"upstart",
"upthrew":"upthrow",
"upthrowing":"upthrow",
"upthrown":"upthrow",
"urbanised":"urbanise",
"urbanized":"urbanize",
"urceoles":"urceole",
"urethanes":"urethane",
"urinals":"urinal",
"used":"use",
"utilised":"utilise",
"utilises":"utilise",
"utilising":"utilise",
"utilitarians":"utilitarian",
"vaccinees":"vaccinee",
"vaccines":"vaccine",
"vacs":"vac",
"vacuoles":"vacuole",
"vailes":"vail",
"valuates":"valuate",
"valued":"value",
"valuers":"valuer",
"vandalised":"vandalise",
"vandalises":"vandalise",
"vandalising":"vandalise",
"vanished":"vanish",
"vantage-points":"vantage-point",
"vaporised":"vaporise",
"vaporisers":"vaporiser",
"vaporises":"vaporise",
"vaporising":"vaporise",
"vaporizers":"vaporizer",
"varityped":"varitype",
"varitypes":"varitype",
"varityping":"varitype",
"varnishing":"varnish",
"vasoconstrictors":"vasoconstrictor",
"vaunted":"vaunt",
"vectors":"vector",
"vegans":"vegan",
"vegetarians":"vegetarian",
"vegetates":"vegetate",
"vegged":"veg",
"vegges":"veg",
"vegging":"veg",
"vellicated":"vellicate",
"vellicates":"vellicate",
"vellicating":"vellicate",
"venerated":"venerate",
"ventilators":"ventilator",
"ventriloquists":"ventriloquist",
"venturers":"venturer",
"verbalisations":"verbalisation",
"verbalised":"verbalise",
"verbalises":"verbalise",
"verbalising":"verbalise",
"verbalizations":"verbalization",
"verdolagas":"verdolaga",
"vergers":"verger",
"verifiers":"verifier",
"vermiculates":"vermiculate",
"vermouths":"vermouth",
"versed":"verse",
"vesiculates":"vesiculate",
"vestals":"vestal",
"vetches":"vetch",
"vexed":"vex",
"viaducts":"viaduct",
"vialed":"vial",
"vialing":"vial",
"vialled":"vial",
"vialling":"vial",
"viands":"viand",
"vibes":"vibe",
"vibrators":"vibrator",
"vice-chancellors":"vice-chancellor",
"vice-presidents":"vice-president",
"victimised":"victimise",
"victimises":"victimise",
"victimising":"victimise",
"videocams":"videocam",
"videocassettes":"videocassette",
"videodiscs":"videodisc",
"videodisks":"videodisk",
"videoed":"video",
"videoing":"video",
"videotaped":"videotape",
"videotapes":"videotape",
"videotaping":"videotape",
"vides":"vide",
"vinegars":"vinegar",
"vinified":"vinify",
"vinifies":"vinify",
"vinifying":"vinify",
"viols":"viol",
"virologists":"virologist",
"visiting":"visit",
"visored":"visor",
"visoring":"visor",
"visualised":"visualise",
"visualises":"visualise",
"visualising":"visualise",
"visuals":"visual",
"vitalised":"vitalise",
"vitalises":"vitalise",
"vitalising":"vitalise",
"vitrioled":"vitriol",
"vitrioling":"vitriol",
"vitriolled":"vitriol",
"vitriolling":"vitriol",
"vivisectionists":"vivisectionist",
"vodkas":"vodka",
"voice-overs":"voice-over",
"voiceovers":"voiceover",
"volatilised":"volatilise",
"voltmeters":"voltmeter",
"vote-getters":"vote-getter",
"vouchsafes":"vouchsafe",
"voyagers":"voyager",
"voyageurs":"voyageur",
"voyaging":"voyage",
"wackos":"wacko",
"waddlers":"waddler",
"waddling":"waddle",
"wades":"wade",
"waffling":"waffle",
"waged":"wage",
"wagtails":"wagtail",
"waifs":"waif",
"wailing":"wail",
"wainscoted":"wainscot",
"wainscoting":"wainscot",
"wainscotting":"wainscot",
"waitressing":"waitress",
"walk-ons":"walk-on",
"walk-outs":"walk-out",
"walk-overs":"walk-over",
"walkabouts":"walkabout",
"walkouts":"walkout",
"wallcoverings":"wallcovering",
"walled":"wall",
"wandering":"wander",
"wankers":"wanker",
"warded":"ward",
"warehousing":"warehouse",
"warms":"warm",
"warners":"warner",
"warranted":"warrant",
"warthogs":"warthog",
"wash-outs":"wash-out",
"washrooms":"washroom",
"watchtowers":"watchtower",
"water-buffaloes":"water-buffalo",
"water-colours":"water-colour",
"waterbucks":"waterbuck",
"watercolours":"watercolour",
"waterleafs":"waterleaf",
"waterlogged":"waterlog",
"waterlogging":"waterlog",
"waterlogs":"waterlog",
"watermarked":"watermark",
"watermarking":"watermark",
"waterproofed":"waterproof",
"wauled":"waul",
"wauling":"waul",
"wauls":"waul",
"wavebands":"waveband",
"weakened":"weaken",
"weans":"wean",
"weaponized":"weaponize",
"weaponizes":"weaponize",
"weaponizing":"weaponize",
"wearers":"wearer",
"wearying":"weary",
"weaselled":"weasel",
"weaselling":"weasel",
"weatherboarding":"weatherboard",
"weatherstripped":"weatherstrip",
"weatherstripping":"weatherstrip",
"weatherstrips":"weatherstrip",
"webbed":"web",
"webbing":"web",
"webmasters":"webmaster",
"webpages":"webpage",
"websites":"website",
"wedding":"wed",
"wee-weed":"wee-wee",
"wee-weeing":"wee-wee",
"wee-wees":"wee-wee",
"weed":"wee",
"weeding":"weed",
"weedkillers":"weedkiller",
"weeing":"wee",
"weekdays":"weekday",
"weekenders":"weekender",
"weeknights":"weeknight",
"weens":"ween",
"weighted":"weight",
"weirdos":"weirdo",
"weirs":"weir",
"welches":"welch",
"welterweights":"welterweight",
"wends":"wend",
"westerners":"westerner",
"westernised":"westernise",
"westernises":"westernise",
"westernising":"westernise",
"westernized":"westernize",
"wetlands":"wetland",
"wetter":"wet",
"whackos":"whacko",
"wheelbases":"wheelbase",
"wheelchairs":"wheelchair",
"wheeler-dealers":"wheeler-dealer",
"wheelwrights":"wheelwright",
"whelks":"whelk",
"whetstones":"whetstone",
"whiffles":"whiffle",
"whippets":"whippet",
"whipping-boys":"whipping-boy",
"whirring":"whirr",
"whistle-blowers":"whistle-blower",
"whistleblowers":"whistleblower",
"whited":"white",
"whiting":"white",
"whodunnits":"whodunnit",
"wholesales":"wholesale",
"whoops":"whoop",
"whopping":"whop",
"whupped":"whup",
"whupping":"whup",
"whups":"whup",
"wicked":"wick",
"wicket-keepers":"wicket-keeper",
"wicking":"wick",
"wiggier":"wiggy",
"wiggiest":"wiggy",
"wigmakers":"wigmaker",
"wildcatters":"wildcatter",
"wilder":"wild",
"wilders":"wilder",
"wildfires":"wildfire",
"will-o'-the-wisps":"will-o'-the-wisp",
"willies":"willy",
"wimped":"wimp",
"wimping":"wimp",
"wimples":"wimple",
"windjammers":"windjammer",
"windmilled":"windmill",
"windmilling":"windmill",
"window-boxes":"window-box",
"window-dressing":"window-dress",
"window-shoppers":"window-shopper",
"windowsills":"windowsill",
"windstorms":"windstorm",
"windsurfed":"windsurf",
"windsurfers":"windsurfer",
"windsurfing":"windsurf",
"windsurfs":"windsurf",
"wingbacks":"wingback",
"wingers":"winger",
"wingmen":"wingman",
"wire-cutters":"wire-cutter",
"wirelines":"wireline",
"wisecracking":"wisecrack",
"wised":"wise",
"wish-lists":"wish-list",
"wising":"wise",
"witch-hunts":"witch-hunt",
"woadwaxes":"woadwax",
"wogs":"wog",
"woks":"wok",
"wolf-whistled":"wolf-whistle",
"wolf-whistles":"wolf-whistle",
"wolf-whistling":"wolf-whistle",
"wolfhounds":"wolfhound",
"womanised":"womanise",
"womanises":"womanise",
"womanising":"womanise",
"womanizing":"womanize",
"wombats":"wombat",
"wonderlands":"wonderland",
"wongs":"wong",
"wood-lice":"wood-louse",
"woodlice":"woodlouse",
"woodlots":"woodlot",
"woodpiles":"woodpile",
"woodsheds":"woodshed",
"woodworms":"woodworm",
"woolgathered":"woolgather",
"woolgathering":"woolgather",
"woolgatherings":"woolgathering",
"woolgathers":"woolgather",
"woolies":"wooly",
"wooshed":"woosh",
"wooshes":"woosh",
"wooshing":"woosh",
"wordsmiths":"wordsmith",
"work-hardened":"work-harden",
"work-hardening":"work-harden",
"work-hardens":"work-harden",
"work-outs":"work-out",
"work-to-rules":"work-to-rule",
"workaholics":"workaholic",
"workbooks":"workbook",
"workhorses":"workhorse",
"workloads":"workload",
"workmates":"workmate",
"workpieces":"workpiece",
"workrooms":"workroom",
"worksheets":"worksheet",
"workstations":"workstation",
"worried":"worry",
"worsted":"worst",
"worsteds":"worsted",
"worsting":"worst",
"worsts":"worst",
"wounded":"wound",
"wracked":"wrack",
"wracking":"wrack",
"wrapped":"wrap",
"wrasses":"wrasse",
"wrinklies":"wrinkly",
"write-ins":"write-in",
"wrong-footed":"wrong-foot",
"wrong-footing":"wrong-foot",
"wrong-foots":"wrong-foot",
"wusses":"wuss",
"wussier":"wussy",
"wussies":"wussy",
"wussiest":"wussy",
"yachtels":"yachtel",
"yachters":"yachter",
"yammering":"yammer",
"yds":"yd",
"yds.":"yd.",
"yeasted":"yeast",
"yeasting":"yeast",
"yo-yoed":"yo-yo",
"yo-yoing":"yo-yo",
"yodelling":"yodel",
"yowling":"yowl",
"yrs.":"yr.",
"yuks":"yuk",
"yuppies":"yuppie",
"zagged":"zag",
"zagging":"zag",
"zanier":"zany",
"zaniest":"zany",
"zappers":"zapper",
"zarfs":"zarf",
"zested":"zest",
"zesting":"zest",
"zigged":"zig",
"zigging":"zig",
"zincks":"zinc",
"zingers":"zinger",
"zipped":"zip",
"zippered":"zipper",
"zippering":"zipper",
"zits":"zit",
"zizzed":"zizz",
"zizzes":"zizz",
"zizzing":"zizz",
"zloties":"zloty",
"zoned":"zone",
"assorted":"assort",
"balls":"ball",
"banned":"ban",
"barred":"bar"}